diff --git a/Documentation/filesystems/00-INDEX b/Documentation/filesystems/00-INDEX
index 8042050..2922607 100644
--- a/Documentation/filesystems/00-INDEX
+++ b/Documentation/filesystems/00-INDEX
@@ -114,6 +114,8 @@ udf.txt
 	- info and mount options for the UDF filesystem.
 ufs.txt
 	- info on the ufs filesystem.
+unionfs/
+	- info on the unionfs filesystem
 vfat.txt
 	- info on using the VFAT filesystem used in Windows NT and Windows 95
 vfs.txt
diff --git a/Documentation/filesystems/unionfs/00-INDEX b/Documentation/filesystems/unionfs/00-INDEX
new file mode 100644
index 00000000..96fdf67
--- /dev/null
+++ b/Documentation/filesystems/unionfs/00-INDEX
@@ -0,0 +1,10 @@
+00-INDEX
+	- this file.
+concepts.txt
+	- A brief introduction of concepts.
+issues.txt
+	- A summary of known issues with unionfs.
+rename.txt
+	- Information regarding rename operations.
+usage.txt
+	- Usage information and examples.
diff --git a/Documentation/filesystems/unionfs/concepts.txt b/Documentation/filesystems/unionfs/concepts.txt
new file mode 100644
index 00000000..b853788
--- /dev/null
+++ b/Documentation/filesystems/unionfs/concepts.txt
@@ -0,0 +1,287 @@
+Unionfs 2.x CONCEPTS:
+=====================
+
+This file describes the concepts needed by a namespace unification file
+system.
+
+
+Branch Priority:
+================
+
+Each branch is assigned a unique priority - starting from 0 (highest
+priority).  No two branches can have the same priority.
+
+
+Branch Mode:
+============
+
+Each branch is assigned a mode - read-write or read-only. This allows
+directories on media mounted read-write to be used in a read-only manner.
+
+
+Whiteouts:
+==========
+
+A whiteout removes a file name from the namespace. Whiteouts are needed when
+one attempts to remove a file on a read-only branch.
+
+Suppose we have a two-branch union, where branch 0 is read-write and branch
+1 is read-only. And a file 'foo' on branch 1:
+
+./b0/
+./b1/
+./b1/foo
+
+The unified view would simply be:
+
+./union/
+./union/foo
+
+Since 'foo' is stored on a read-only branch, it cannot be removed. A
+whiteout is used to remove the name 'foo' from the unified namespace. Again,
+since branch 1 is read-only, the whiteout cannot be created there. So, we
+try on a higher priority (lower numerically) branch and create the whiteout
+there.
+
+./b0/
+./b0/.wh.foo
+./b1/
+./b1/foo
+
+Later, when Unionfs traverses branches (due to lookup or readdir), it
+eliminate 'foo' from the namespace (as well as the whiteout itself.)
+
+
+Opaque Directories:
+===================
+
+Assume we have a unionfs mount comprising of two branches.  Branch 0 is
+empty; branch 1 has the directory /a and file /a/f.  Let's say we mount a
+union of branch 0 as read-write and branch 1 as read-only.  Now, let's say
+we try to perform the following operation in the union:
+
+	rm -fr a
+
+Because branch 1 is not writable, we cannot physically remove the file /a/f
+or the directory /a.  So instead, we will create a whiteout in branch 0
+named /.wh.a, masking out the name "a" from branch 1.  Next, let's say we
+try to create a directory named "a" as follows:
+
+	mkdir a
+
+Because we have a whiteout for "a" already, Unionfs behaves as if "a"
+doesn't exist, and thus will delete the whiteout and replace it with an
+actual directory named "a".
+
+The problem now is that if you try to "ls" in the union, Unionfs will
+perform is normal directory name unification, for *all* directories named
+"a" in all branches.  This will cause the file /a/f from branch 1 to
+re-appear in the union's namespace, which violates Unix semantics.
+
+To avoid this problem, we have a different form of whiteouts for
+directories, called "opaque directories" (same as BSD Union Mount does).
+Whenever we replace a whiteout with a directory, that directory is marked as
+opaque.  In Unionfs 2.x, it means that we create a file named
+/a/.wh.__dir_opaque in branch 0, after having created directory /a there.
+When unionfs notices that a directory is opaque, it stops all namespace
+operations (including merging readdir contents) at that opaque directory.
+This prevents re-exposing names from masked out directories.
+
+
+Duplicate Elimination:
+======================
+
+It is possible for files on different branches to have the same name.
+Unionfs then has to select which instance of the file to show to the user.
+Given the fact that each branch has a priority associated with it, the
+simplest solution is to take the instance from the highest priority
+(numerically lowest value) and "hide" the others.
+
+
+Unlinking:
+=========
+
+Unlink operation on non-directory instances is optimized to remove the
+maximum possible objects in case multiple underlying branches have the same
+file name.  The unlink operation will first try to delete file instances
+from highest priority branch and then move further to delete from remaining
+branches in order of their decreasing priority.  Consider a case (F..D..F),
+where F is a file and D is a directory of the same name; here, some
+intermediate branch could have an empty directory instance with the same
+name, so this operation also tries to delete this directory instance and
+proceed further to delete from next possible lower priority branch.  The
+unionfs unlink operation will smoothly delete the files with same name from
+all possible underlying branches.  In case if some error occurs, it creates
+whiteout in highest priority branch that will hide file instance in rest of
+the branches.  An error could occur either if an unlink operations in any of
+the underlying branch failed or if a branch has no write permission.
+
+This unlinking policy is known as "delete all" and it has the benefit of
+overall reducing the number of inodes used by duplicate files, and further
+reducing the total number of inodes consumed by whiteouts.  The cost is of
+extra processing, but testing shows this extra processing is well worth the
+savings.
+
+
+Copyup:
+=======
+
+When a change is made to the contents of a file's data or meta-data, they
+have to be stored somewhere.  The best way is to create a copy of the
+original file on a branch that is writable, and then redirect the write
+though to this copy.  The copy must be made on a higher priority branch so
+that lookup and readdir return this newer "version" of the file rather than
+the original (see duplicate elimination).
+
+An entire unionfs mount can be read-only or read-write.  If it's read-only,
+then none of the branches will be written to, even if some of the branches
+are physically writeable.  If the unionfs mount is read-write, then the
+leftmost (highest priority) branch must be writeable (for copyup to take
+place); the remaining branches can be any mix of read-write and read-only.
+
+In a writeable mount, unionfs will create new files/dir in the leftmost
+branch.  If one tries to modify a file in a read-only branch/media, unionfs
+will copyup the file to the leftmost branch and modify it there.  If you try
+to modify a file from a writeable branch which is not the leftmost branch,
+then unionfs will modify it in that branch; this is useful if you, say,
+unify differnet packages (e.g., apache, sendmail, ftpd, etc.) and you want
+changes to specific package files to remain logically in the directory where
+they came from.
+
+Cache Coherency:
+================
+
+Unionfs users often want to be able to modify files and directories directly
+on the lower branches, and have those changes be visible at the Unionfs
+level.  This means that data (e.g., pages) and meta-data (dentries, inodes,
+open files, etc.) have to be synchronized between the upper and lower
+layers.  In other words, the newest changes from a layer below have to be
+propagated to the Unionfs layer above.  If the two layers are not in sync, a
+cache incoherency ensues, which could lead to application failures and even
+oopses.  The Linux kernel, however, has a rather limited set of mechanisms
+to ensure this inter-layer cache coherency---so Unionfs has to do most of
+the hard work on its own.
+
+Maintaining Invariants:
+
+The way Unionfs ensures cache coherency is as follows.  At each entry point
+to a Unionfs file system method, we call a utility function to validate the
+primary objects of this method.  Generally, we call unionfs_file_revalidate
+on open files, and __unionfs_d_revalidate_chain on dentries (which also
+validates inodes).  These utility functions check to see whether the upper
+Unionfs object is in sync with any of the lower objects that it represents.
+The checks we perform include whether the Unionfs superblock has a newer
+generation number, or if any of the lower objects mtime's or ctime's are
+newer.  (Note: generation numbers change when branch-management commands are
+issued, so in a way, maintaining cache coherency is also very important for
+branch-management.)  If indeed we determine that any Unionfs object is no
+longer in sync with its lower counterparts, then we rebuild that object
+similarly to how we do so for branch-management.
+
+While rebuilding Unionfs's objects, we also purge any page mappings and
+truncate inode pages (see fs/unionfs/dentry.c:purge_inode_data).  This is to
+ensure that Unionfs will re-get the newer data from the lower branches.  We
+perform this purging only if the Unionfs operation in question is a reading
+operation; if Unionfs is performing a data writing operation (e.g., ->write,
+->commit_write, etc.) then we do NOT flush the lower mappings/pages: this is
+because (1) a self-deadlock could occur and (2) the upper Unionfs pages are
+considered more authoritative anyway, as they are newer and will overwrite
+any lower pages.
+
+Unionfs maintains the following important invariant regarding mtime's,
+ctime's, and atime's: the upper inode object's times are the max() of all of
+the lower ones.  For non-directory objects, there's only one object below,
+so the mapping is simple; for directory objects, there could me multiple
+lower objects and we have to sync up with the newest one of all the lower
+ones.  This invariant is important to maintain, especially for directories
+(besides, we need this to be POSIX compliant).  A union could comprise
+multiple writable branches, each of which could change.  If we don't reflect
+the newest possible mtime/ctime, some applications could fail.  For example,
+NFSv2/v3 exports check for newer directory mtimes on the server to determine
+if the client-side attribute cache should be purged.
+
+To maintain these important invariants, of course, Unionfs carefully
+synchronizes upper and lower times in various places.  For example, if we
+copy-up a file to a top-level branch, the parent directory where the file
+was copied up to will now have a new mtime: so after a successful copy-up,
+we sync up with the new top-level branch's parent directory mtime.
+
+Implementation:
+
+This cache-coherency implementation is efficient because it defers any
+synchronizing between the upper and lower layers until absolutely needed.
+Consider the example a common situation where users perform a lot of lower
+changes, such as untarring a whole package.  While these take place,
+typically the user doesn't access the files via Unionfs; only after the
+lower changes are done, does the user try to access the lower files.  With
+our cache-coherency implementation, the entirety of the changes to the lower
+branches will not result in a single CPU cycle spent at the Unionfs level
+until the user invokes a system call that goes through Unionfs.
+
+We have considered two alternate cache-coherency designs.  (1) Using the
+dentry/inode notify functionality to register interest in finding out about
+any lower changes.  This is a somewhat limited and also a heavy-handed
+approach which could result in many notifications to the Unionfs layer upon
+each small change at the lower layer (imagine a file being modified multiple
+times in rapid succession).  (2) Rewriting the VFS to support explicit
+callbacks from lower objects to upper objects.  We began exploring such an
+implementation, but found it to be very complicated--it would have resulted
+in massive VFS/MM changes which are unlikely to be accepted by the LKML
+community.  We therefore believe that our current cache-coherency design and
+implementation represent the best approach at this time.
+
+Limitations:
+
+Our implementation works in that as long as a user process will have caused
+Unionfs to be called, directly or indirectly, even to just do
+->d_revalidate; then we will have purged the current Unionfs data and the
+process will see the new data.  For example, a process that continually
+re-reads the same file's data will see the NEW data as soon as the lower
+file had changed, upon the next read(2) syscall (even if the file is still
+open!)  However, this doesn't work when the process re-reads the open file's
+data via mmap(2) (unless the user unmaps/closes the file and remaps/reopens
+it).  Once we respond to ->readpage(s), then the kernel maps the page into
+the process's address space and there doesn't appear to be a way to force
+the kernel to invalidate those pages/mappings, and force the process to
+re-issue ->readpage.  If there's a way to invalidate active mappings and
+force a ->readpage, let us know please (invalidate_inode_pages2 doesn't do
+the trick).
+
+Our current Unionfs code has to perform many file-revalidation calls.  It
+would be really nice if the VFS would export an optional file system hook
+->file_revalidate (similarly to dentry->d_revalidate) that will be called
+before each VFS op that has a "struct file" in it.
+
+Certain file systems have micro-second granularity (or better) for inode
+times, and asynchronous actions could cause those times to change with some
+small delay.  In such cases, Unionfs may see a changed inode time that only
+differs by a tiny fraction of a second: such a change may be a false
+positive indication that the lower object has changed, whereas if unionfs
+waits a little longer, that false indication will not be seen.  (These false
+positives are harmless, because they would at most cause unionfs to
+re-validate an object that may need no revalidation, and print a debugging
+message that clutters the console/logs.)  Therefore, to minimize the chances
+of these situations, we delay the detection of changed times by a small
+factor of a few seconds, called UNIONFS_MIN_CC_TIME (which defaults to 3
+seconds, as does NFS).  This means that we will detect the change, only a
+couple of seconds later, if indeed the time change persists in the lower
+file object.  This delayed detection has an added performance benefit: we
+reduce the number of times that unionfs has to revalidate objects, in case
+there's a lot of concurrent activity on both the upper and lower objects,
+for the same file(s).  Lastly, this delayed time attribute detection is
+similar to how NFS clients operate (e.g., acregmin).
+
+Finally, there is no way currently in Linux to prevent lower directories
+from being moved around (i.e., topology changes); there's no way to prevent
+modifications to directory sub-trees of whole file systems which are mounted
+read-write.  It is therefore possible for in-flight operations in unionfs to
+take place, while a lower directory is being moved around.  Therefore, if
+you try to, say, create a new file in a directory through unionfs, while the
+directory is being moved around directly, then the new file may get created
+in the new location where that directory was moved to.  This is a somewhat
+similar behaviour in NFS: an NFS client could be creating a new file while
+th NFS server is moving th directory around; the file will get successfully
+created in the new location.  (The one exception in unionfs is that if the
+branch is marked read-only by unionfs, then a copyup will take place.)
+
+For more information, see <http://unionfs.filesystems.org/>.
diff --git a/Documentation/filesystems/unionfs/issues.txt b/Documentation/filesystems/unionfs/issues.txt
new file mode 100644
index 00000000..f4b7e7e2
--- /dev/null
+++ b/Documentation/filesystems/unionfs/issues.txt
@@ -0,0 +1,28 @@
+KNOWN Unionfs 2.x ISSUES:
+=========================
+
+1. Unionfs should not use lookup_one_len() on the underlying f/s as it
+   confuses NFSv4.  Currently, unionfs_lookup() passes lookup intents to the
+   lower file-system, this eliminates part of the problem.  The remaining
+   calls to lookup_one_len may need to be changed to pass an intent.  We are
+   currently introducing VFS changes to fs/namei.c's do_path_lookup() to
+   allow proper file lookup and opening in stackable file systems.
+
+2. Lockdep (a debugging feature) isn't aware of stacking, and so it
+   incorrectly complains about locking problems.  The problem boils down to
+   this: Lockdep considers all objects of a certain type to be in the same
+   class, for example, all inodes.  Lockdep doesn't like to see a lock held
+   on two inodes within the same task, and warns that it could lead to a
+   deadlock.  However, stackable file systems do precisely that: they lock
+   an upper object, and then a lower object, in a strict order to avoid
+   locking problems; in addition, Unionfs, as a fan-out file system, may
+   have to lock several lower inodes.  We are currently looking into Lockdep
+   to see how to make it aware of stackable file systems.  For now, we
+   temporarily disable lockdep when calling vfs methods on lower objects,
+   but only for those places where lockdep complained.  While this solution
+   may seem unclean, it is not without precedent: other places in the kernel
+   also do similar temporary disabling, of course after carefully having
+   checked that it is the right thing to do.  Anyway, you get any warnings
+   from Lockdep, please report them to the Unionfs maintainers.
+
+For more information, see <http://unionfs.filesystems.org/>.
diff --git a/Documentation/filesystems/unionfs/rename.txt b/Documentation/filesystems/unionfs/rename.txt
new file mode 100644
index 00000000..e20bb82
--- /dev/null
+++ b/Documentation/filesystems/unionfs/rename.txt
@@ -0,0 +1,31 @@
+Rename is a complex beast. The following table shows which rename(2) operations
+should succeed and which should fail.
+
+o: success
+E: error (either unionfs or vfs)
+X: EXDEV
+
+none = file does not exist
+file = file is a file
+dir  = file is a empty directory
+child= file is a non-empty directory
+wh   = file is a directory containing only whiteouts; this makes it logically
+		empty
+
+                      none    file    dir     child   wh
+file                  o       o       E       E       E
+dir                   o       E       o       E       o
+child                 X       E       X       E       X
+wh                    o       E       o       E       o
+
+
+Renaming directories:
+=====================
+
+Whenever a empty (either physically or logically) directory is being renamed,
+the following sequence of events should take place:
+
+1) Remove whiteouts from both source and destination directory
+2) Rename source to destination
+3) Make destination opaque to prevent anything under it from showing up
+
diff --git a/Documentation/filesystems/unionfs/usage.txt b/Documentation/filesystems/unionfs/usage.txt
new file mode 100644
index 00000000..1adde69
--- /dev/null
+++ b/Documentation/filesystems/unionfs/usage.txt
@@ -0,0 +1,134 @@
+Unionfs is a stackable unification file system, which can appear to merge
+the contents of several directories (branches), while keeping their physical
+content separate.  Unionfs is useful for unified source tree management,
+merged contents of split CD-ROM, merged separate software package
+directories, data grids, and more.  Unionfs allows any mix of read-only and
+read-write branches, as well as insertion and deletion of branches anywhere
+in the fan-out.  To maintain Unix semantics, Unionfs handles elimination of
+duplicates, partial-error conditions, and more.
+
+GENERAL SYNTAX
+==============
+
+# mount -t unionfs -o <OPTIONS>,<BRANCH-OPTIONS> none MOUNTPOINT
+
+OPTIONS can be any legal combination of:
+
+- ro		# mount file system read-only
+- rw		# mount file system read-write
+- remount	# remount the file system (see Branch Management below)
+- incgen	# increment generation no. (see Cache Consistency below)
+
+BRANCH-OPTIONS can be either (1) a list of branches given to the "dirs="
+option, or (2) a list of individual branch manipulation commands, combined
+with the "remount" option, and is further described in the "Branch
+Management" section below.
+
+The syntax for the "dirs=" mount option is:
+
+	dirs=branch[=ro|=rw][:...]
+
+The "dirs=" option takes a colon-delimited list of directories to compose
+the union, with an optional branch mode for each of those directories.
+Directories that come earlier (specified first, on the left) in the list
+have a higher precedence than those which come later.  Additionally,
+read-only or read-write permissions of the branch can be specified by
+appending =ro or =rw (default) to each directory.  See the Copyup section in
+concepts.txt, for a description of Unionfs's behavior when mixing read-only
+and read-write branches and mounts.
+
+Syntax:
+
+	dirs=/branch1[=ro|=rw]:/branch2[=ro|=rw]:...:/branchN[=ro|=rw]
+
+Example:
+
+	dirs=/writable_branch=rw:/read-only_branch=ro
+
+
+BRANCH MANAGEMENT
+=================
+
+Once you mount your union for the first time, using the "dirs=" option, you
+can then change the union's overall mode or reconfigure the branches, using
+the remount option, as follows.
+
+To downgrade a union from read-write to read-only:
+
+# mount -t unionfs -o remount,ro none MOUNTPOINT
+
+To upgrade a union from read-only to read-write:
+
+# mount -t unionfs -o remount,rw none MOUNTPOINT
+
+To delete a branch /foo, regardless where it is in the current union:
+
+# mount -t unionfs -o remount,del=/foo none MOUNTPOINT
+
+To insert (add) a branch /foo before /bar:
+
+# mount -t unionfs -o remount,add=/bar:/foo none MOUNTPOINT
+
+To insert (add) a branch /foo (with the "rw" mode flag) before /bar:
+
+# mount -t unionfs -o remount,add=/bar:/foo=rw none MOUNTPOINT
+
+To insert (add) a branch /foo (in "rw" mode) at the very beginning (i.e., a
+new highest-priority branch), you can use the above syntax, or use a short
+hand version as follows:
+
+# mount -t unionfs -o remount,add=/foo none MOUNTPOINT
+
+To append a branch to the very end (new lowest-priority branch):
+
+# mount -t unionfs -o remount,add=:/foo none MOUNTPOINT
+
+To append a branch to the very end (new lowest-priority branch), in
+read-only mode:
+
+# mount -t unionfs -o remount,add=:/foo=ro none MOUNTPOINT
+
+Finally, to change the mode of one existing branch, say /foo, from read-only
+to read-write, and change /bar from read-write to read-only:
+
+# mount -t unionfs -o remount,mode=/foo=rw,mode=/bar=ro none MOUNTPOINT
+
+Note: in Unionfs 2.x, you cannot set the leftmost branch to readonly because
+then Unionfs won't have any writable place for copyups to take place.
+Moreover, the VFS can get confused when it tries to modify something in a
+file system mounted read-write, but isn't permitted to write to it.
+Instead, you should set the whole union as readonly, as described above.
+If, however, you must set the leftmost branch as readonly, perhaps so you
+can get a snapshot of it at a point in time, then you should insert a new
+writable top-level branch, and mark the one you want as readonly.  This can
+be accomplished as follows, assuming that /foo is your current leftmost
+branch:
+
+# mount -t tmpfs -o size=NNN /new
+# mount -t unionfs -o remount,add=/new,mode=/foo=ro none MOUNTPOINT
+<do what you want safely in /foo>
+# mount -t unionfs -o remount,del=/new,mode=/foo=rw none MOUNTPOINT
+<check if there's anything in /new you want to preserve>
+# umount /new
+
+CACHE CONSISTENCY
+=================
+
+If you modify any file on any of the lower branches directly, while there is
+a Unionfs 2.x mounted above any of those branches, you should tell Unionfs
+to purge its caches and re-get the objects.  To do that, you have to
+increment the generation number of the superblock using the following
+command:
+
+# mount -t unionfs -o remount,incgen none MOUNTPOINT
+
+Note that the older way of incrementing the generation number using an
+ioctl, is no longer supported in Unionfs 2.0 and newer.  Ioctls in general
+are not encouraged.  Plus, an ioctl is per-file concept, whereas the
+generation number is a per-file-system concept.  Worse, such an ioctl
+requires an open file, which then has to be invalidated by the very nature
+of the generation number increase (read: the old generation increase ioctl
+was pretty racy).
+
+
+For more information, see <http://unionfs.filesystems.org/>.
diff --git a/Documentation/target/tcm_mod_builder.py b/Documentation/target/tcm_mod_builder.py
index 3fe0d81..230ce71 100755
--- a/Documentation/target/tcm_mod_builder.py
+++ b/Documentation/target/tcm_mod_builder.py
@@ -300,7 +300,7 @@ def tcm_mod_build_configfs(proto_ident, fabric_mod_dir_var, fabric_mod_name):
 	buf += "	int ret;\n\n"
 	buf += "	if (strstr(name, \"tpgt_\") != name)\n"
 	buf += "		return ERR_PTR(-EINVAL);\n"
-	buf += "	if (strict_strtoul(name + 5, 10, &tpgt) || tpgt > UINT_MAX)\n"
+	buf += "	if (kstrtoul(name + 5, 10, &tpgt) || tpgt > UINT_MAX)\n"
 	buf += "		return ERR_PTR(-EINVAL);\n\n"
 	buf += "	tpg = kzalloc(sizeof(struct " + fabric_mod_name + "_tpg), GFP_KERNEL);\n"
 	buf += "	if (!tpg) {\n"
@@ -440,15 +440,15 @@ def tcm_mod_build_configfs(proto_ident, fabric_mod_dir_var, fabric_mod_name):
 	buf += "	/*\n"
 	buf += "	 * Setup default attribute lists for various fabric->tf_cit_tmpl\n"
 	buf += "	 */\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = " + fabric_mod_name + "_wwn_attrs;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;\n"
-	buf += "	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = " + fabric_mod_name + "_wwn_attrs;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;\n"
+	buf += "	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;\n"
 	buf += "	/*\n"
 	buf += "	 * Register the fabric for use within TCM\n"
 	buf += "	 */\n"
diff --git a/MAINTAINERS b/MAINTAINERS
index 48c7480..edd7440 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -8394,6 +8394,15 @@ F:	drivers/cdrom/cdrom.c
 F:	include/linux/cdrom.h
 F:	include/uapi/linux/cdrom.h
 
+UNION FILE SYSTEM
+M:	Erez Zadok <ezk@cs.sunysb.edu>
+L:	unionfs@filesystems.org
+W:	http://unionfs.filesystems.org/
+T:	git git://git.fsl.cs.sunysb.edu/unionfs-latest.git
+S:	Maintained
+F:	Documentation/filesystems/unionfs/
+F:	fs/unionfs/
+
 UNIVERSAL FLASH STORAGE HOST CONTROLLER DRIVER
 M:	Vinayak Holikatti <vinholikatti@gmail.com>
 M:	Santosh Y <santoshsy@gmail.com>
diff --git a/Makefile b/Makefile
index 7ba3e2e..ed05bd5 100644
--- a/Makefile
+++ b/Makefile
@@ -1,7 +1,7 @@
 VERSION = 3
 PATCHLEVEL = 10
 SUBLEVEL = 20
-EXTRAVERSION = -al-5.0-pr2
+EXTRAVERSION = -al-5.0-pr2-buffalo
 NAME = TOSSUG Baby Fish
 
 # *DOCUMENTATION*
@@ -366,6 +366,11 @@ LINUXINCLUDE    := \
 		$(if $(KBUILD_SRC), -I$(srctree)/include) \
 		-Iinclude \
 		$(USERINCLUDE)
+BUFFALOINCLUDE := -I$(srctree)/buffalo/arch/$(hdr-arch)/include \
+		-Ibuffalo/arch/$(hdr-arch)/include/generated \
+		-Ibuffalo/include/generated \
+		-I$(srctree)/buffalo/include
+LINUXINCLUDE   += $(BUFFALOINCLUDE)
 
 KBUILD_CPPFLAGS := -D__KERNEL__
 
@@ -733,6 +738,7 @@ export mod_sign_cmd
 
 
 ifeq ($(KBUILD_EXTMOD),)
+core-y		+= buffalo/
 core-y		+= kernel/ mm/ fs/ ipc/ security/ crypto/ block/
 
 vmlinux-dirs	:= $(patsubst %/,%,$(filter %/, $(init-y) $(init-m) \
@@ -1019,6 +1025,7 @@ CLEAN_DIRS  += $(MODVERDIR)
 # Directories & files removed with 'make mrproper'
 MRPROPER_DIRS  += include/config usr/include include/generated          \
                   arch/*/include/generated
+MRPRPPER_DIRS  += buffalo/include/generated buffalo/arch/*/include/generated
 MRPROPER_FILES += .config .config.old .version .old_version $(version_h) \
 		  Module.symvers tags TAGS cscope* GPATH GTAGS GRTAGS GSYMS \
 		  signing_key.priv signing_key.x509 x509.genkey		\
@@ -1084,8 +1091,10 @@ rpm: include/config/kernel.release FORCE
 # ---------------------------------------------------------------------------
 
 boards := $(wildcard $(srctree)/arch/$(SRCARCH)/configs/*_defconfig)
+boards += $(wildcard $(srctree)/buffalo/arch/$(SRCARCH)/configs/*_defconfig)
 boards := $(notdir $(boards))
 board-dirs := $(dir $(wildcard $(srctree)/arch/$(SRCARCH)/configs/*/*_defconfig))
+board-dirs += $(dir $(wildcard $(srctree)/buffalo/arch/$(SRCARCH)/configs/*/*_defconfig))
 board-dirs := $(sort $(notdir $(board-dirs:/=)))
 
 help:
diff --git a/README-TSx010.txt b/README-TSx010.txt
new file mode 100644
index 00000000..f8dfcae
--- /dev/null
+++ b/README-TSx010.txt
@@ -0,0 +1,72 @@
+BUFFALO TeraStation [537]010 Series kernel README
+=================================================
+
+Repository Infomation
+---------------------
+
+Branch:	linux-3.10.y
+Commit:	a4c01ca3b76b28c41fb3b07a1eb1389dae24bf4a
+Tag:	v3.10.20
+Description:
+	Base revision of Annapurna SDK 5.0
+
+Branch:	alpine-sdk-5.0-kernel-3.10-lsp-storage-adv
+Commit:	a7632867010bcbc428444ed7b7a6c4d98b210f26
+Tag:	al_storage_adv-al-V_5.0-ga_d63
+Description:
+	Base revision of TS[537]010 series kernel development.
+	This is 'linux-3.10.20' source + patches followed:
+	+ al_lsp-al-V_5.0-ga_d63.patch
+	+ al_storage_adv-al-V_5.0-ga_d63.patch
+
+Branch: develop-3.10.20-alpine-sdk-5.0-buffalo-ts5010
+Commit: HEAD
+Tag:	(not-yet)
+Description:
+	Development line of TS[537]010 series kernel.
+
+
+How to build the standalone kernel
+-----------------------------------
+This section describes how to build standalone (not packaged) kernel, DTBs,
+modules.  See [How to build kernel debian package] section instead, if you
+want kernel packages.
+
+Abstract of kernel building step is followed:
+
+* make *_defconfig
+* make uImage dtbs modules
+* make modules_install
+
+typical build script is followed:
+
+<pre>
+#!/bin/sh
+ARCH="arm"
+#MACHINE=alpine
+MACHINE=ts5010
+CROSS_COMPILE=arm-linux-gnueabihf-
+BUILDDIR="${HOME}/obj/${ARCH}/${MACHINE}"
+MODULEDIR="${BUILDDIR}/modules"
+MAKEOPTS="V=1 ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} O=${BUILDDIR}"
+export ARCH CROSS_COMPILE
+
+mkdir -p ${BUILDDIR} ${MODULEDIR}
+
+case "${MACHINE}" in
+alpine) DEFCONFIG=alpine_defconfig;;
+*)      DEFCONFIG=buffalo_ts5010_defconfig;;
+esac
+
+make ${MAKEOPTS} ${DEFCONFIG} || exit 1
+make ${MAKEOPTS} uImage dtbs modules || exit 1
+make ${MAKEOPTS} INSTALL_MOD_PATH=${MODULEDIR} modules_install || exit 1
+</pre>
+
+
+How to build kernel debian package
+----------------------------------
+Debian style kernel packages for ubuntu-14.04 can be built by script
+named "debiansize.sh".  At the top of kernel source tree, ivoke:
+
+	sh buffalo/scripts/debianize.sh
diff --git a/arch/arm/Kconfig b/arch/arm/Kconfig
index c4ad8b0..fe262e0 100644
--- a/arch/arm/Kconfig
+++ b/arch/arm/Kconfig
@@ -2307,3 +2307,5 @@ source "crypto/Kconfig"
 source "lib/Kconfig"
 
 source "arch/arm/kvm/Kconfig"
+
+source "buffalo/Kconfig"
diff --git a/arch/arm/Makefile b/arch/arm/Makefile
index 4eda02f..3ef5fb0 100644
--- a/arch/arm/Makefile
+++ b/arch/arm/Makefile
@@ -301,6 +301,9 @@ zinstall uinstall install: vmlinux
 
 dtbs: scripts
 	$(Q)$(MAKE) $(build)=$(boot)/dts MACHINE=$(MACHINE) dtbs
+ifeq ($(CONFIG_BUFFALO_PLATFORM),y)
+	$(Q)$(MAKE) $(build)=buffalo/$(boot)/dts MACHINE=$(MACHINE) dtbs
+endif
 
 # We use MRPROPER_FILES and CLEAN_FILES now
 archclean:
diff --git a/arch/arm/boot/compressed/misc.c b/arch/arm/boot/compressed/misc.c
index 31bd43b..af0149b 100644
--- a/arch/arm/boot/compressed/misc.c
+++ b/arch/arm/boot/compressed/misc.c
@@ -21,6 +21,11 @@ unsigned int __machine_arch_type;
 #include <linux/compiler.h>	/* for inline */
 #include <linux/types.h>
 #include <linux/linkage.h>
+#ifdef CONFIG_BUFFALO_PLATFORM
+#include "builddate.h"
+const char buffalo_builddate[] =
+	"BUILDDATE=" BUFFALO_BUILD_DATE " " BUFFALO_BUILD_TIME "\n";
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 
 static void putstr(const char *ptr);
 extern void error(char *x);
diff --git a/arch/arm/boot/dts/alpine_db.dts b/arch/arm/boot/dts/alpine_db.dts
index 4aa7286..863e707 100644
--- a/arch/arm/boot/dts/alpine_db.dts
+++ b/arch/arm/boot/dts/alpine_db.dts
@@ -694,15 +694,23 @@
 			};
 			partition@1 {
 				label = "device_tree";
-				reg = <0x00200000 0x00100000>;
+				reg = <0x00200000 0x00200000>;
 			};
 			partition@2 {
 				label = "linux_kernel";
-				reg = <0x00300000 0x00d00000>;
+				reg = <0x00400000 0x00800000>;
 			};
 			partition@3 {
+				label = "initrd";
+				reg = <0x00c00000 0x01800000>;
+			};
+			partition@4 {
 				label = "ubifs";
-				reg = <0x01000000 0x03f000000>;
+				reg = <0x02400000 0x0a000000>;
+			};
+			partition@5 {
+				label = "squashfs";
+				reg = <0x0c400000 0x33c00000>;
 			};
 		};
 
@@ -733,15 +741,20 @@
 
 				partition@0 {
 					reg = <0x0 0x00200000>; /* 2MB */
-					label = "spi_part0";
+					label = "al_boot";
 				};
 
 				partition@1 {
-					reg = <0x00200000 0x00200000>; /* 2MB */
-					label = "spi_part1";
+					reg = <0x00200000 0x00010000>; /* 64KB */
+					label = "nas-feature";
 				};
 
 				partition@2 {
+					reg = <0x00210000 0x001f0000>; /* 2MB- */
+					label = "spi_part1";
+				};
+
+				partition@3 {
 					reg = <0x00400000 0x00C00000>; /* 12MB */
 					label = "spi_part2";
 				};
diff --git a/arch/arm/boot/install.sh b/arch/arm/boot/install.sh
index 06ea7d4..c085362 100644
--- a/arch/arm/boot/install.sh
+++ b/arch/arm/boot/install.sh
@@ -21,6 +21,10 @@
 #
 
 # User may have a custom install script
+if [ -x ${srctree}/buffalo/arch/arm/boot/${INSTALLKERNEL} ]; then
+	# Don't execute /sbin/installkernel on host ubuntu system
+	exec ${srctree}/buffalo/arch/arm/boot/${INSTALLKERNEL} "$@";
+fi
 if [ -x ~/bin/${INSTALLKERNEL} ]; then exec ~/bin/${INSTALLKERNEL} "$@"; fi
 if [ -x /sbin/${INSTALLKERNEL} ]; then exec /sbin/${INSTALLKERNEL} "$@"; fi
 
diff --git a/arch/arm/configs/alpine_sa_defconfig b/arch/arm/configs/alpine_sa_defconfig
new file mode 100644
index 00000000..0477096
--- /dev/null
+++ b/arch/arm/configs/alpine_sa_defconfig
@@ -0,0 +1,245 @@
+CONFIG_EXPERIMENTAL=y
+# CONFIG_LOCALVERSION_AUTO is not set
+CONFIG_SYSVIPC=y
+CONFIG_NO_HZ=y
+CONFIG_HIGH_RES_TIMERS=y
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+CONFIG_BLK_DEV_INITRD=y
+CONFIG_SLAB=y
+CONFIG_PROFILING=y
+CONFIG_MODULES=y
+CONFIG_MODULE_UNLOAD=y
+CONFIG_PARTITION_ADVANCED=y
+CONFIG_ARCH_ALPINE=y
+CONFIG_PCI_MSI=y
+CONFIG_PCI_IOV=y
+CONFIG_SMP=y
+# CONFIG_SMP_ON_UP is not set
+CONFIG_ARM_ARCH_TIMER=y
+CONFIG_AEABI=y
+CONFIG_HIGHMEM=y
+CONFIG_HIGHPTE=y
+CONFIG_USE_OF=y
+CONFIG_ZBOOT_ROM_TEXT=0x0
+CONFIG_ZBOOT_ROM_BSS=0x0
+CONFIG_CMDLINE="root=1f03 mem=32M"
+CONFIG_CPU_IDLE=y
+CONFIG_VFP=y
+CONFIG_NEON=y
+CONFIG_NET=y
+CONFIG_PACKET=y
+CONFIG_UNIX=y
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+CONFIG_INET=y
+CONFIG_IP_MULTICAST=y
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_BOOTP=y
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_DIAG is not set
+# CONFIG_IPV6 is not set
+CONFIG_DEVTMPFS=y
+CONFIG_DEVTMPFS_MOUNT=y
+CONFIG_MTD=y
+CONFIG_MTD_CMDLINE_PARTS=y
+CONFIG_MTD_CHAR=y
+CONFIG_MTD_BLOCK=y
+CONFIG_MTD_CFI=y
+CONFIG_MTD_CFI_ADV_OPTIONS=y
+CONFIG_MTD_CFI_INTELEXT=y
+CONFIG_MTD_PHYSMAP_OF=y
+CONFIG_MTD_M25P80=y
+CONFIG_MTD_NAND=y
+CONFIG_MTD_NAND_AL=y
+CONFIG_MTD_UBI=y
+CONFIG_PROC_DEVICETREE=y
+CONFIG_BLK_DEV_LOOP=y
+CONFIG_BLK_DEV_NVME=y
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_SD=y
+CONFIG_SCSI_MPT2SAS=m
+CONFIG_ATA=y
+CONFIG_SATA_AHCI=y
+CONFIG_SATA_AHCI_PLATFORM=y
+CONFIG_SATA_SIL24=m
+# CONFIG_ATA_BMDMA is not set
+CONFIG_MD=y
+CONFIG_BLK_DEV_MD=y
+CONFIG_MD_LINEAR=y
+CONFIG_MD_RAID0=y
+CONFIG_MD_RAID1=y
+CONFIG_MD_RAID10=y
+CONFIG_MD_RAID456=y
+CONFIG_MD_FAULTY=y
+CONFIG_BLK_DEV_DM=y
+CONFIG_DM_CRYPT=y
+CONFIG_TARGET_CORE=m
+CONFIG_TCM_IBLOCK=m
+CONFIG_TCM_FILEIO=m
+CONFIG_TCM_PSCSI=m
+CONFIG_LOOPBACK_TARGET=m
+CONFIG_ISCSI_TARGET=m
+CONFIG_NETDEVICES=y
+CONFIG_BONDING=m
+CONFIG_MII=y
+CONFIG_NET_TEAM=m
+CONFIG_NET_TEAM_MODE_BROADCAST=m
+CONFIG_NET_TEAM_MODE_ROUNDROBIN=m
+CONFIG_NET_TEAM_MODE_ACTIVEBACKUP=m
+CONFIG_NET_TEAM_MODE_LOADBALANCE=m
+# CONFIG_NET_VENDOR_3COM is not set
+# CONFIG_NET_VENDOR_ADAPTEC is not set
+# CONFIG_NET_VENDOR_ALTEON is not set
+CONFIG_NET_AL_ETH=y
+# CONFIG_NET_VENDOR_AMD is not set
+# CONFIG_NET_VENDOR_ATHEROS is not set
+# CONFIG_NET_CADENCE is not set
+# CONFIG_NET_VENDOR_BROADCOM is not set
+# CONFIG_NET_VENDOR_BROCADE is not set
+# CONFIG_NET_VENDOR_CHELSIO is not set
+# CONFIG_NET_VENDOR_CIRRUS is not set
+# CONFIG_NET_VENDOR_CISCO is not set
+# CONFIG_NET_VENDOR_DEC is not set
+# CONFIG_NET_VENDOR_DLINK is not set
+# CONFIG_NET_VENDOR_EMULEX is not set
+# CONFIG_NET_VENDOR_EXAR is not set
+# CONFIG_NET_VENDOR_FARADAY is not set
+# CONFIG_NET_VENDOR_HP is not set
+CONFIG_E100=m
+CONFIG_E1000=m
+CONFIG_E1000E=m
+CONFIG_IGB=m
+CONFIG_IXGBE=m
+# CONFIG_NET_VENDOR_I825XX is not set
+# CONFIG_NET_VENDOR_MARVELL is not set
+# CONFIG_NET_VENDOR_MELLANOX is not set
+# CONFIG_NET_VENDOR_MICREL is not set
+# CONFIG_NET_VENDOR_MYRI is not set
+# CONFIG_NET_VENDOR_NATSEMI is not set
+# CONFIG_NET_VENDOR_NVIDIA is not set
+# CONFIG_NET_VENDOR_OKI is not set
+# CONFIG_NET_PACKET_ENGINE is not set
+# CONFIG_NET_VENDOR_QLOGIC is not set
+# CONFIG_NET_VENDOR_REALTEK is not set
+# CONFIG_NET_VENDOR_RDC is not set
+# CONFIG_NET_VENDOR_SEEQ is not set
+# CONFIG_NET_VENDOR_SILAN is not set
+# CONFIG_NET_VENDOR_SIS is not set
+# CONFIG_NET_VENDOR_SMSC is not set
+# CONFIG_NET_VENDOR_STMICRO is not set
+# CONFIG_NET_VENDOR_SUN is not set
+# CONFIG_NET_VENDOR_TEHUTI is not set
+# CONFIG_NET_VENDOR_TI is not set
+# CONFIG_NET_VENDOR_VIA is not set
+# CONFIG_NET_VENDOR_WIZNET is not set
+CONFIG_AT803X_PHY=y
+CONFIG_AQR105_PHY=y
+CONFIG_INPUT_EVDEV=y
+# CONFIG_SERIO_SERPORT is not set
+CONFIG_SERIO_AMBAKMI=y
+CONFIG_LEGACY_PTY_COUNT=16
+CONFIG_SERIAL_8250=y
+CONFIG_SERIAL_8250_CONSOLE=y
+CONFIG_SERIAL_8250_EXTENDED=y
+CONFIG_SERIAL_8250_MANY_PORTS=y
+CONFIG_SERIAL_8250_SHARE_IRQ=y
+CONFIG_SERIAL_8250_RSA=y
+CONFIG_SERIAL_8250_DW=y
+CONFIG_SERIAL_AMBA_PL011=y
+CONFIG_SERIAL_AMBA_PL011_CONSOLE=y
+CONFIG_SERIAL_OF_PLATFORM=y
+CONFIG_I2C=y
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+CONFIG_I2C_MUX_PCA954x=y
+CONFIG_I2C_DESIGNWARE_PLATFORM=y
+CONFIG_SPI=y
+CONFIG_SPI_DESIGNWARE=y
+CONFIG_SPI_DW_MMIO=y
+CONFIG_PTP_1588_CLOCK=y
+CONFIG_GPIOLIB=y
+CONFIG_GPIO_SYSFS=y
+CONFIG_GPIO_PL061=y
+# CONFIG_HWMON is not set
+CONFIG_THERMAL=y
+CONFIG_AL_THERMAL=y
+CONFIG_WATCHDOG=y
+CONFIG_ARM_SP805_WATCHDOG=y
+# CONFIG_HID is not set
+# CONFIG_USB_HID is not set
+CONFIG_USB=y
+CONFIG_USB_XHCI_HCD=y
+CONFIG_USB_STORAGE=y
+CONFIG_NEW_LEDS=y
+CONFIG_LEDS_CLASS=y
+CONFIG_LEDS_GPIO=y
+CONFIG_LEDS_TRIGGERS=y
+CONFIG_LEDS_TRIGGER_TIMER=y
+CONFIG_LEDS_TRIGGER_ONESHOT=y
+CONFIG_LEDS_TRIGGER_HEARTBEAT=y
+CONFIG_LEDS_TRIGGER_BACKLIGHT=y
+CONFIG_LEDS_TRIGGER_CPU=y
+CONFIG_LEDS_TRIGGER_GPIO=y
+CONFIG_LEDS_TRIGGER_DEFAULT_ON=y
+CONFIG_LEDS_TRIGGER_NETDEV=y
+CONFIG_EDAC=y
+CONFIG_EDAC_MM_EDAC=y
+CONFIG_EDAC_AL_MC=y
+CONFIG_RTC_CLASS=y
+CONFIG_RTC_DRV_BQ32K=y
+CONFIG_DMADEVICES=y
+CONFIG_AL_DMA=y
+CONFIG_AL_PCIE_RMN_1010=n
+CONFIG_AL_DMA_PCI_IOV=y
+CONFIG_AL_DMA_STATS=y
+CONFIG_ASYNC_TX_DMA=y
+# CONFIG_IOMMU_SUPPORT is not set
+CONFIG_EXT2_FS=y
+CONFIG_EXT3_FS=y
+CONFIG_EXT4_FS=y
+CONFIG_XFS_FS=y
+CONFIG_BTRFS_FS=y
+CONFIG_VFAT_FS=y
+CONFIG_TMPFS=y
+CONFIG_TMPFS_POSIX_ACL=y
+CONFIG_CONFIGFS_FS=y
+CONFIG_ECRYPT_FS=y
+CONFIG_JFFS2_FS=y
+CONFIG_UBIFS_FS=y
+CONFIG_CRAMFS=y
+CONFIG_MINIX_FS=y
+CONFIG_ROMFS_FS=y
+CONFIG_NFS_FS=y
+CONFIG_ROOT_NFS=y
+CONFIG_NFSD=y
+CONFIG_NFSD_V3=y
+CONFIG_CIFS=y
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_850=y
+CONFIG_NLS_ISO8859_1=y
+CONFIG_MAGIC_SYSRQ=y
+CONFIG_DEBUG_KERNEL=y
+CONFIG_DEBUG_INFO=y
+CONFIG_ENABLE_DEFAULT_TRACERS=y
+CONFIG_DEBUG_USER=y
+CONFIG_DEBUG_LL=y
+CONFIG_EARLY_PRINTK=y
+CONFIG_KEYS=y
+CONFIG_ENCRYPTED_KEYS=y
+# CONFIG_CRYPTO_MANAGER_DISABLE_TESTS is not set
+CONFIG_CRYPTO_TEST=m
+CONFIG_CRYPTO_SHA1=y
+CONFIG_CRYPTO_SHA512=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO_STATS=y
+CONFIG_LOCALVERSION="_sa"
+CONFIG_ARM_LPAE=y
+CONFIG_ARM_PAGE_SIZE_LARGE=y
+CONFIG_ARM_PAGE_SIZE_32KB=y
+CONFIG_LFS_ON_32CPU=y
+CONFIG_BTRFS_FS_AHASH_CRC=y
+CONFIG_NET_DMA=y
+CONFIG_ISCSI_TCP=m
+# CONFIG_XFRM_ALGO is not set
diff --git a/arch/arm/kernel/process.c b/arch/arm/kernel/process.c
index ab1fe3b..1ffcb96 100644
--- a/arch/arm/kernel/process.c
+++ b/arch/arm/kernel/process.c
@@ -46,6 +46,11 @@ unsigned long __stack_chk_guard __read_mostly;
 EXPORT_SYMBOL(__stack_chk_guard);
 #endif
 
+#ifdef CONFIG_BUFFALO_MICON_V3
+#include <buffalo/micon_v3.h>
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
+
+
 static const char *processor_modes[] = {
   "USER_26", "FIQ_26" , "IRQ_26" , "SVC_26" , "UK4_26" , "UK5_26" , "UK6_26" , "UK7_26" ,
   "UK8_26" , "UK9_26" , "UK10_26", "UK11_26", "UK12_26", "UK13_26", "UK14_26", "UK15_26",
@@ -196,6 +201,12 @@ __setup("reboot=", reboot_setup);
 void machine_shutdown(void)
 {
 	disable_nonboot_cpus();
+
+#if 0	/* XXX: this function is for kexec, maybe it is no need to micon op */
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
+#endif
 }
 
 /*
@@ -208,9 +219,27 @@ void machine_halt(void)
 	smp_send_stop();
 
 	local_irq_disable();
+
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON halt.\n");
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	while (1);
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 }
 
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+static inline void longdelay(int sec)
+{
+	int i;
+	for (i = 0; i < sec; i++) {
+	    mdelay(1000);
+	    touch_softlockup_watchdog();
+	}
+}
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 /*
  * Power-off simply requires that the secondary CPUs stop performing any
  * activity (executing tasks, handling interrupts). smp_send_stop()
@@ -221,8 +250,16 @@ void machine_power_off(void)
 {
 	smp_send_stop();
 
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_PowerOff();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON power-off.\n");
+	longdelay(10);	/* wait 10 secends */
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	if (pm_power_off)
 		pm_power_off();
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 }
 
 /*
@@ -240,7 +277,15 @@ void machine_restart(char *cmd)
 {
 	smp_send_stop();
 
+#ifdef CONFIG_BUFFALO_MICON_V3
+	miconCntl_Reboot();
+#else	/* CONFIG_BUFFALO_MICON_V3 */
+#ifdef CONFIG_BUFFALO_MICON_REBOOT
+	printk(KERN_EMERG "Waiting for MICON restart.\n");
+	longdelay(10);	/* wait 10 seconds */
+#endif	/* CONFIG_BUFFALO_MICON_REBOOT */
 	arm_pm_restart(reboot_mode, cmd);
+#endif	/* CONFIG_BUFFALO_MICON_V3 */
 
 	/* Give a grace period for failure to restart of 1s */
 	mdelay(1000);
diff --git a/arch/arm/mach-alpine/alpine_machine.c b/arch/arm/mach-alpine/alpine_machine.c
index 7920eba..3fba45f 100644
--- a/arch/arm/mach-alpine/alpine_machine.c
+++ b/arch/arm/mach-alpine/alpine_machine.c
@@ -312,6 +312,20 @@ static int __init gettimeofday_use_jiffies(char *str)
 
 early_param("gettimeofday_use_jiffies", gettimeofday_use_jiffies);
 
+unsigned int al_sss_enable __read_mostly = 0;
+EXPORT_SYMBOL(al_sss_enable);
+
+static int __init sss_enable(char *str)
+{
+	get_option(&str, &al_sss_enable);
+	if (al_sss_enable)
+		al_sss_enable = 1;
+	return 0;
+}
+early_param("sata_sss_enable", sss_enable);
+
+
+
 DT_MACHINE_START(AL_DT, "AnnapurnaLabs Alpine (Device Tree)")
 	.smp		= smp_ops(al_smp_ops),
 	.map_io		= al_map_io,
diff --git a/arch/x86/Kconfig b/arch/x86/Kconfig
index 7d5c1d5..404d8b3 100644
--- a/arch/x86/Kconfig
+++ b/arch/x86/Kconfig
@@ -2346,3 +2346,5 @@ source "crypto/Kconfig"
 source "arch/x86/kvm/Kconfig"
 
 source "lib/Kconfig"
+
+source "buffalo/Kconfig"
diff --git a/arch/x86/boot/install.sh b/arch/x86/boot/install.sh
index d13ec1c..a3e0981 100644
--- a/arch/x86/boot/install.sh
+++ b/arch/x86/boot/install.sh
@@ -33,6 +33,10 @@ verify "$3"
 
 # User may have a custom install script
 
+if [ -x ${srctree}/buffalo/arch/x86/boot/${INSTALLKERNEL} ]; then
+	# Don't execute /sbin/installkernel on host ubuntu system
+	exec ${srctree}/buffalo/arch/x86/boot/${INSTALLKERNEL} "$@";
+fi
 if [ -x ~/bin/${INSTALLKERNEL} ]; then exec ~/bin/${INSTALLKERNEL} "$@"; fi
 if [ -x /sbin/${INSTALLKERNEL} ]; then exec /sbin/${INSTALLKERNEL} "$@"; fi
 
diff --git a/block/blk-core.c b/block/blk-core.c
index d5745b5..a4b1245 100644
--- a/block/blk-core.c
+++ b/block/blk-core.c
@@ -38,6 +38,10 @@
 #include "blk.h"
 #include "blk-cgroup.h"
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include <buffalo/kernevnt.h>
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_rq_remap);
 EXPORT_TRACEPOINT_SYMBOL_GPL(block_bio_complete);
@@ -1703,6 +1707,29 @@ generic_make_request_checks(struct bio *bio)
 		goto end_io;
 	}
 
+#ifdef CONFIG_BUFFALO_IOERRS
+	if (bio->bi_bdev->bd_disk->limit_io_errors > 0 &&
+	    (bio->bi_bdev->bd_disk->io_errors > bio->bi_bdev->bd_disk->limit_io_errors)) {
+		//printk("%s:io error limit\n",bdevname(bio->bi_bdev, b));
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		/* NOTE: (Temporary Fix)
+		 *	Skip setting the QUEUE_FLAG_DEAD flag here, because
+		 *	this setting causes process hang-up when opening
+		 *	'/dev/sd*' device file at Alpine platform by unknown
+		 *	reason.  Instead, stop issueing 'ioerror' event
+		 *	when ioerror counter reaches its limit.
+		 *	See NOTE in blk_update_request() function below.
+		 */
+#else /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+		set_bit(QUEUE_FLAG_DEAD, &q->queue_flags);
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+		kernevnt_DriveDead(bdevname(bio->bi_bdev, b));
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+		goto end_io;
+	}
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
 	part = bio->bi_bdev->bd_part;
 	if (should_fail_request(part, bio->bi_size) ||
 	    should_fail_request(&part_to_disk(part)->part0,
@@ -2327,6 +2354,32 @@ bool blk_update_request(struct request *req, int error, unsigned int nr_bytes)
 
 	}
 
+#ifdef CONFIG_BUFFALO_IOERRS
+	if (error && req->cmd_type != REQ_TYPE_BLOCK_PC && req->rq_disk) {
+#ifdef CONFIG_BUFFALO_ERRCNT
+		if (atomic_inc_return(&req->rq_disk->nr_errs) < 0)
+			atomic_set(&req->rq_disk->nr_errs, INT_MAX);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		if (req->rq_disk->io_errors > req->rq_disk->limit_io_errors) {
+			/* NOTE: (Temporary Fix)
+			 *	Stop issueing 'ioerror' event when io_erroes
+			 *	counter reaches its limit, to avoid process
+			 *	hang-up at open() system-call for disk-device
+			 *	on Alpine Platform.
+			 */
+			;
+		} else
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
+		kernevnt_IOErr(req->rq_disk->disk_name,
+			       (rq_data_dir(req) == WRITE) ? "WRITE" : "READ",
+			       (unsigned long long)blk_rq_pos(req),
+			       ++req->rq_disk->io_errors);
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+	}
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
 	blk_account_io_completion(req, nr_bytes);
 
 	total_bytes = 0;
diff --git a/block/blk-ioc.c b/block/blk-ioc.c
index 9c4bb82..3be61ba 100644
--- a/block/blk-ioc.c
+++ b/block/blk-ioc.c
@@ -366,7 +366,7 @@ struct io_cq *ioc_create_icq(struct io_context *ioc, struct request_queue *q,
 	if (!icq)
 		return NULL;
 
-	if (radix_tree_preload(gfp_mask) < 0) {
+	if (radix_tree_maybe_preload(gfp_mask) < 0) {
 		kmem_cache_free(et->icq_cache, icq);
 		return NULL;
 	}
diff --git a/block/genhd.c b/block/genhd.c
index cdeb527..8538526 100644
--- a/block/genhd.c
+++ b/block/genhd.c
@@ -976,6 +976,74 @@ static ssize_t disk_discard_alignment_show(struct device *dev,
 	return sprintf(buf, "%d\n", queue_discard_alignment(disk->queue));
 }
 
+#ifdef CONFIG_BUFFALO_IOERRS
+static ssize_t disk_io_error_show(struct device *dev,
+				  struct device_attribute *attr, char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%u\n", disk->io_errors);
+}
+
+static ssize_t disk_limit_io_error_show(struct device *dev,
+					struct device_attribute *attr,
+					char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%u\n", disk->limit_io_errors);
+}
+
+#define STORE_FUNCTION(__FUNC, __PTR, MIN, MAX, __CONV)			\
+ssize_t __FUNC(struct device *dev, struct device_attribute *attr,	\
+	       const char *buf, size_t count)				\
+{									\
+	struct gendisk *disk = dev_to_disk(dev);			\
+	unsigned int __data;						\
+	char *p = (char *) buf;						\
+									\
+	__data = simple_strtoul(p, &p, 10);				\
+	if (__data < (MIN))						\
+		__data = (MIN);						\
+	else if (__data > (MAX))					\
+		__data = (MAX);						\
+	if (__CONV)							\
+		*(__PTR) = msecs_to_jiffies(__data);			\
+	else								\
+		*(__PTR) = __data;					\
+	return count;							\
+}
+
+static STORE_FUNCTION(disk_io_error_store, &disk->io_errors, 0, UINT_MAX, 0)
+static STORE_FUNCTION(disk_limit_io_error_store, &disk->limit_io_errors, 0, UINT_MAX, 0)
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+static ssize_t disk_nr_errs_show(struct device *dev,
+				 struct device_attribute *attr, char *buf)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+
+	return sprintf(buf, "%d\n", atomic_read(&disk->nr_errs));
+}
+
+static ssize_t disk_nr_errs_store(struct device *dev,
+				  struct device_attribute *attr,
+				  const char *buf, size_t count)
+{
+	struct gendisk *disk = dev_to_disk(dev);
+	long n;
+	char *e, *p = (char *) buf;
+
+	n = simple_strtoul(p, &e, 10);
+	if (*p && (*e == 0 || *e == '\n') && n >= 0 ) {
+		atomic_set(&disk->nr_errs, n);
+		return count;
+	}
+	return -EINVAL;
+}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
 static DEVICE_ATTR(range, S_IRUGO, disk_range_show, NULL);
 static DEVICE_ATTR(ext_range, S_IRUGO, disk_ext_range_show, NULL);
 static DEVICE_ATTR(removable, S_IRUGO, disk_removable_show, NULL);
@@ -997,6 +1065,15 @@ static struct device_attribute dev_attr_fail_timeout =
 		part_timeout_store);
 #endif
 
+#ifdef CONFIG_BUFFALO_IOERRS
+static DEVICE_ATTR(io_errors, S_IRUGO|S_IWUSR, disk_io_error_show, disk_io_error_store);
+static DEVICE_ATTR(limit_io_errors, S_IRUGO|S_IWUSR, disk_limit_io_error_show, disk_limit_io_error_store);
+#ifdef CONFIG_BUFFALO_ERRCNT
+static DEVICE_ATTR(nr_errs, S_IRUGO|S_IWUSR, disk_nr_errs_show, disk_nr_errs_store);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
+
 static struct attribute *disk_attrs[] = {
 	&dev_attr_range.attr,
 	&dev_attr_ext_range.attr,
@@ -1014,6 +1091,15 @@ static struct attribute *disk_attrs[] = {
 #ifdef CONFIG_FAIL_IO_TIMEOUT
 	&dev_attr_fail_timeout.attr,
 #endif
+
+#ifdef CONFIG_BUFFALO_IOERRS
+	&dev_attr_io_errors.attr,
+	&dev_attr_limit_io_errors.attr,
+#ifdef CONFIG_BUFFALO_ERRCNT
+	&dev_attr_nr_errs.attr,
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
+
 	NULL
 };
 
@@ -1280,6 +1366,9 @@ struct gendisk *alloc_disk_node(int minors, int node_id)
 		hd_ref_init(&disk->part0);
 
 		disk->minors = minors;
+#ifdef CONFIG_BUFFALO_ERRCNT
+		atomic_set(&disk->nr_errs, 0);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		rand_initialize_disk(disk);
 		disk_to_dev(disk)->class = &block_class;
 		disk_to_dev(disk)->type = &disk_type;
diff --git a/buffalo/Kconfig b/buffalo/Kconfig
new file mode 100644
index 00000000..d757f09
--- /dev/null
+++ b/buffalo/Kconfig
@@ -0,0 +1,141 @@
+menu "BUFFALO Features"
+
+config BUFFALO_PLATFORM
+	bool "BUFFALO_PLATFORM"
+	---help---
+	  Hardware/Software is for BUFFALO platfrom
+
+config BUFFALO_USE_KERNEVNT
+	bool "BUFFALO_USE_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  Use kernelevent
+
+config BUFFALO_USE_MD_KERNEVNT
+	bool "BUFFALO_USE_MD_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_DEGRADE_KERNEVNT
+	bool "BUFFALO_USE_MD_DEGRADE_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_SCAN_KERNEVNT
+	bool "BUFFALO_USE_MD_SCAN_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_USE_MD_REBUILD_KERNEVNT
+	bool "BUFFALO_USE_MD_REBUILD_KERNEVNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_USE_MD_KERNEVNT
+	---help---
+	  Use kernelevent of md driver.
+
+config BUFFALO_ERRCNT
+	bool "BUFFALO_ERRCNT"
+	depends on BUFFALO_PLATFORM
+	depends on BUFFALO_IOERRS
+	---help---
+	disk I/O error counter and auto MD degrading.	 
+
+config BUFFALO_USE_UPS
+	bool "BUFFALO_USE_UPS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	Enable kernel support of ups shutdown.
+
+config BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+       bool "BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN"
+       depends on BUFFALO_USE_UPS
+       default n
+       ---help---
+	 Support OMRON UPS
+
+config BUFFALO_SUPPORT_UPS_RECOVER
+       bool "BUFFALO_SUPPORT_UPS_RECOVER"
+       depends on BUFFALO_USE_UPS
+       default n
+       ---help---
+	 Support /proc/buffalo/ups/ups_recover
+
+config BUFFALO_DUPLICATE_SUPERBLOCK_DEBUG
+	bool "BUFFALO_DUPLICATE_SUPERBLOCK_DEBUG"
+	depends on BUFFALO_DUPLICATE_SUPERBLOCK
+	---help---
+	  enable duplicate superblock debug mode.
+
+config BUFFALO_UBOOT_PARAMS
+	bool "BUFFALO_UBOOT_PARAMS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  add u-boot parameters
+
+config BUFFALO_IOERRS
+	bool "BUFFALO_IOERRS"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  disk I/O error counter
+
+config BUFFALO_SKIP_RESYNC
+	bool "BUFFALO_SKIP_RESYNC"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  skip resync of md device
+
+config BUFFALO_IGNORE_LUN
+	bool "BUFFALO_IGNORE_LUN"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  ignore lun of SCSI device
+
+config BUFFALO_SCSI_GUID
+	bool "BUFFALO_SCSI_GUID"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  add guid of SCSI device
+
+config BUFFALO_EXT23_EXTENSION
+	bool "BUFFALO_EXT23_EXTENSION"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  extend ext2/ext3 magic number
+
+choice BUFFALO_SATA_HOTPLUG_EVENT_CHOICE
+	prompt "support SATA HOTPLUG EVENT"
+	depends on BUFFALO_SATA_HOTPLUG_EVENT
+	default BUFFALO_SATA_HOTPLUG_EVENT_INTERRUPT
+
+config BUFFALO_SATA_HOTPLUG_EVENT_INTERRUPT
+	bool "SATA HOTPLUG EVENT INTERRUPT"
+
+config BUFFALO_SATA_HOTPLUG_EVENT_POLLING
+	bool "SATA HOTPLUG EVENT POLLING"
+
+endchoice
+
+config BUFFALO_SUPPORT_WOL
+	bool "BUFFALO_SUPPORT_WOL"
+	depends on BUFFALO_PLATFORM
+	---help---
+	  Support WOL function.
+	  Below is supported phy lists.
+	    1318
+
+config BUFFALO_UNIONFS_FIX
+	bool "BUFFALO_UNIONFS_FIX"
+	depends on UNION_FS
+	default y
+	help
+	   Fix unionfs bug, when using ubifs as read-write filesystem.
+
+source "buffalo/arch/$SRCARCH/Kconfig"
+
+endmenu
diff --git a/buffalo/Makefile b/buffalo/Makefile
new file mode 100644
index 00000000..6376ae6
--- /dev/null
+++ b/buffalo/Makefile
@@ -0,0 +1,3 @@
+obj-y					+= drivers/
+
+include $(srctree)/buffalo/arch/$(SRCARCH)/Makefile
diff --git a/buffalo/arch/arm/Kconfig b/buffalo/arch/arm/Kconfig
new file mode 100644
index 00000000..32e5af0
--- /dev/null
+++ b/buffalo/arch/arm/Kconfig
@@ -0,0 +1,44 @@
+config BUFFALO_SUPPORT_BOARD_INFO
+	 bool "support board info from kernel"
+	 depends on BUFFALO_PLATFORM
+	 depends on ARM
+	 default y
+	 ---help---
+	  BUFFALO board information
+
+config BUFFALO_ALPINE_PLATFORM
+	bool "ALPINE_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on ARCH_ALPINE
+	---help---
+	  for TS5x10 (featured Annapurna alpine SoC)
+
+config BUFFALO_USE_MICON
+	bool "USE MICON control"
+	depends on ARM
+	default y
+	---help---
+	  BUFFALO Micon
+
+config BUFFALO_MICON_V3
+	bool "featuring Micon version 3"
+	depends on BUFFALO_USE_MICON
+	depends on BUFFALO_ALPINE_PLATFORM
+	default y
+	---help---
+	  BUFFALO Micon version 3
+
+config BUFFALO_MICON_V3_DEVTTY
+	string "tty device name used by Micon v3"
+	depends on BUFFALO_MICON_V3
+	default "/dev/ttyS1"
+	---help---
+	  Micon connected tty device name
+
+config BUFFALO_MICON_REBOOT
+	bool "USE MICON level reboot"
+	depends on BUFFALO_PLATFORM
+	depends on ARCH_ALPINE
+	default n
+	---help---
+	    Uer Micon level reboot instead of kernel level reboot.
diff --git a/buffalo/arch/arm/Makefile b/buffalo/arch/arm/Makefile
new file mode 100644
index 00000000..db48cf8
--- /dev/null
+++ b/buffalo/arch/arm/Makefile
@@ -0,0 +1,4 @@
+# Note:	This file is included from $(srctree)/buffalo/Makefile,
+#	you have to specify relatively from $(srctree)/buffalo
+
+obj-$(CONFIG_BUFFALO_ALPINE_PLATFORM)	+= arch/arm/plat-alpine/
diff --git a/buffalo/arch/arm/boot/installkernel b/buffalo/arch/arm/boot/installkernel
new file mode 100644
index 00000000..b38fa11
--- /dev/null
+++ b/buffalo/arch/arm/boot/installkernel
@@ -0,0 +1,12 @@
+#!/bin/sh
+#
+# "make install" script for arm architecture
+#
+# Arguments:
+#   $1 - kernel version
+#   $2 - kernel image file
+#   $3 - kernel map file
+#   $4 - default install path (blank if root directory)
+#
+
+cp $2 $4
diff --git a/buffalo/arch/arm/configs/buffalo_ts5010_defconfig b/buffalo/arch/arm/configs/buffalo_ts5010_defconfig
new file mode 100755
index 00000000..f5defbe
--- /dev/null
+++ b/buffalo/arch/arm/configs/buffalo_ts5010_defconfig
@@ -0,0 +1,302 @@
+CONFIG_EXPERIMENTAL=y
+# CONFIG_LOCALVERSION_AUTO is not set
+CONFIG_SYSVIPC=y
+CONFIG_NO_HZ=y
+CONFIG_HIGH_RES_TIMERS=y
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+CONFIG_BLK_DEV_INITRD=y
+CONFIG_SLAB=y
+CONFIG_PROFILING=y
+CONFIG_MODULES=y
+CONFIG_MODULE_UNLOAD=y
+CONFIG_PARTITION_ADVANCED=y
+CONFIG_ARCH_ALPINE=y
+CONFIG_PCI_MSI=y
+CONFIG_PCI_IOV=y
+CONFIG_SMP=y
+# CONFIG_SMP_ON_UP is not set
+CONFIG_VMSPLIT_2G=y
+CONFIG_ARM_ARCH_TIMER=y
+CONFIG_AEABI=y
+CONFIG_HIGHMEM=y
+CONFIG_HIGHPTE=y
+CONFIG_USE_OF=y
+CONFIG_ZBOOT_ROM_TEXT=0x0
+CONFIG_ZBOOT_ROM_BSS=0x0
+CONFIG_CMDLINE="root=1f03 mem=32M"
+CONFIG_CPU_IDLE=y
+CONFIG_VFP=y
+CONFIG_NEON=y
+CONFIG_NET=y
+CONFIG_PACKET=y
+CONFIG_UNIX=y
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+CONFIG_INET=y
+CONFIG_IP_MULTICAST=y
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_BOOTP=y
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_DIAG is not set
+# CONFIG_IPV6 is not set
+CONFIG_DEVTMPFS=y
+CONFIG_DEVTMPFS_MOUNT=y
+CONFIG_MTD=y
+CONFIG_MTD_CMDLINE_PARTS=y
+CONFIG_MTD_CHAR=y
+CONFIG_MTD_BLOCK=y
+CONFIG_MTD_CFI=y
+CONFIG_MTD_CFI_ADV_OPTIONS=y
+CONFIG_MTD_CFI_INTELEXT=y
+CONFIG_MTD_PHYSMAP_OF=y
+CONFIG_MTD_M25P80=y
+CONFIG_MTD_NAND=y
+CONFIG_MTD_NAND_AL=y
+CONFIG_MTD_UBI=y
+CONFIG_PROC_DEVICETREE=y
+CONFIG_BLK_DEV_LOOP=y
+CONFIG_BLK_DEV_NVME=y
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_RAM_COUNT=8
+CONFIG_BLK_DEV_RAM_SIZE=131072
+CONFIG_BLK_DEV_SD=y
+CONFIG_SCSI_MPT2SAS=m
+CONFIG_ATA=y
+CONFIG_SATA_AHCI=y
+CONFIG_SATA_AHCI_PLATFORM=y
+CONFIG_SATA_SIL24=m
+# CONFIG_ATA_BMDMA is not set
+CONFIG_MD=y
+CONFIG_BLK_DEV_MD=y
+CONFIG_MD_LINEAR=y
+CONFIG_MD_RAID0=y
+CONFIG_MD_RAID1=y
+CONFIG_MD_RAID10=y
+CONFIG_MD_RAID456=y
+CONFIG_MD_FAULTY=y
+CONFIG_BLK_DEV_DM=y
+CONFIG_DM_CRYPT=y
+CONFIG_TARGET_CORE=m
+CONFIG_TCM_IBLOCK=m
+CONFIG_TCM_FILEIO=m
+CONFIG_TCM_PSCSI=m
+CONFIG_LOOPBACK_TARGET=m
+CONFIG_ISCSI_TARGET=m
+CONFIG_NETDEVICES=y
+CONFIG_BONDING=m
+CONFIG_MII=y
+CONFIG_NET_TEAM=m
+CONFIG_NET_TEAM_MODE_BROADCAST=m
+CONFIG_NET_TEAM_MODE_ROUNDROBIN=m
+CONFIG_NET_TEAM_MODE_ACTIVEBACKUP=m
+CONFIG_NET_TEAM_MODE_LOADBALANCE=m
+# CONFIG_NET_VENDOR_3COM is not set
+# CONFIG_NET_VENDOR_ADAPTEC is not set
+# CONFIG_NET_VENDOR_ALTEON is not set
+CONFIG_NET_AL_ETH=y
+# CONFIG_NET_VENDOR_AMD is not set
+# CONFIG_NET_VENDOR_ATHEROS is not set
+# CONFIG_NET_CADENCE is not set
+# CONFIG_NET_VENDOR_BROADCOM is not set
+# CONFIG_NET_VENDOR_BROCADE is not set
+# CONFIG_NET_VENDOR_CHELSIO is not set
+# CONFIG_NET_VENDOR_CIRRUS is not set
+# CONFIG_NET_VENDOR_CISCO is not set
+# CONFIG_NET_VENDOR_DEC is not set
+# CONFIG_NET_VENDOR_DLINK is not set
+# CONFIG_NET_VENDOR_EMULEX is not set
+# CONFIG_NET_VENDOR_EXAR is not set
+# CONFIG_NET_VENDOR_FARADAY is not set
+# CONFIG_NET_VENDOR_HP is not set
+CONFIG_E100=m
+CONFIG_E1000=m
+CONFIG_E1000E=m
+CONFIG_IGB=m
+CONFIG_IXGBE=m
+# CONFIG_NET_VENDOR_I825XX is not set
+# CONFIG_NET_VENDOR_MARVELL is not set
+# CONFIG_NET_VENDOR_MELLANOX is not set
+# CONFIG_NET_VENDOR_MICREL is not set
+# CONFIG_NET_VENDOR_MYRI is not set
+# CONFIG_NET_VENDOR_NATSEMI is not set
+# CONFIG_NET_VENDOR_NVIDIA is not set
+# CONFIG_NET_VENDOR_OKI is not set
+# CONFIG_NET_PACKET_ENGINE is not set
+# CONFIG_NET_VENDOR_QLOGIC is not set
+# CONFIG_NET_VENDOR_REALTEK is not set
+# CONFIG_NET_VENDOR_RDC is not set
+# CONFIG_NET_VENDOR_SEEQ is not set
+# CONFIG_NET_VENDOR_SILAN is not set
+# CONFIG_NET_VENDOR_SIS is not set
+# CONFIG_NET_VENDOR_SMSC is not set
+# CONFIG_NET_VENDOR_STMICRO is not set
+# CONFIG_NET_VENDOR_SUN is not set
+# CONFIG_NET_VENDOR_TEHUTI is not set
+# CONFIG_NET_VENDOR_TI is not set
+# CONFIG_NET_VENDOR_VIA is not set
+# CONFIG_NET_VENDOR_WIZNET is not set
+CONFIG_AT803X_PHY=y
+CONFIG_AQR105_PHY=y
+CONFIG_INPUT_EVDEV=y
+# CONFIG_SERIO_SERPORT is not set
+CONFIG_SERIO_AMBAKMI=y
+CONFIG_LEGACY_PTY_COUNT=16
+CONFIG_SERIAL_8250=y
+CONFIG_SERIAL_8250_CONSOLE=y
+CONFIG_SERIAL_8250_EXTENDED=y
+CONFIG_SERIAL_8250_MANY_PORTS=y
+CONFIG_SERIAL_8250_SHARE_IRQ=y
+CONFIG_SERIAL_8250_RSA=y
+CONFIG_SERIAL_8250_DW=y
+CONFIG_SERIAL_AMBA_PL011=y
+CONFIG_SERIAL_AMBA_PL011_CONSOLE=y
+CONFIG_SERIAL_OF_PLATFORM=y
+CONFIG_I2C=y
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+CONFIG_I2C_MUX_PCA954x=y
+CONFIG_I2C_DESIGNWARE_PLATFORM=y
+CONFIG_SPI=y
+CONFIG_SPI_DESIGNWARE=y
+CONFIG_SPI_DW_MMIO=y
+CONFIG_PTP_1588_CLOCK=y
+CONFIG_GPIOLIB=y
+CONFIG_GPIO_SYSFS=y
+CONFIG_GPIO_PL061=y
+# CONFIG_HWMON is not set
+CONFIG_THERMAL=y
+CONFIG_AL_THERMAL=y
+CONFIG_WATCHDOG=y
+CONFIG_ARM_SP805_WATCHDOG=y
+# CONFIG_HID is not set
+CONFIG_USB_HID=m
+CONFIG_USB=y
+CONFIG_USB_XHCI_HCD=y
+CONFIG_USB_ETRON_HCD=y
+CONFIG_USB_STORAGE=y
+CONFIG_NEW_LEDS=y
+CONFIG_LEDS_CLASS=y
+CONFIG_LEDS_GPIO=y
+CONFIG_LEDS_TRIGGERS=y
+CONFIG_LEDS_TRIGGER_TIMER=y
+CONFIG_LEDS_TRIGGER_ONESHOT=y
+CONFIG_LEDS_TRIGGER_HEARTBEAT=y
+CONFIG_LEDS_TRIGGER_BACKLIGHT=y
+CONFIG_LEDS_TRIGGER_CPU=y
+CONFIG_LEDS_TRIGGER_GPIO=y
+CONFIG_LEDS_TRIGGER_DEFAULT_ON=y
+CONFIG_LEDS_TRIGGER_NETDEV=y
+# CONFIG_INFINIBAND is not set
+CONFIG_EDAC=y
+CONFIG_EDAC_MM_EDAC=y
+CONFIG_EDAC_AL_MC=y
+CONFIG_RTC_CLASS=y
+CONFIG_RTC_DRV_BQ32K=y
+CONFIG_RTC_DRV_RX8010=y
+CONFIG_DMADEVICES=y
+CONFIG_AL_DMA=y
+CONFIG_AL_PCIE_RMN_1010=n
+CONFIG_AL_DMA_PCI_IOV=y
+CONFIG_AL_DMA_STATS=y
+CONFIG_ASYNC_TX_DMA=y
+# CONFIG_IOMMU_SUPPORT is not set
+CONFIG_EXT2_FS=y
+CONFIG_EXT3_FS=y
+CONFIG_EXT4_FS=y
+CONFIG_XFS_FS=y
+CONFIG_XFS_QUOTA=y
+CONFIG_XFS_POSIX_ACL=y
+CONFIG_BTRFS_FS=y
+CONFIG_QUOTA=y
+CONFIG_QUOTACTL=y
+CONFIG_VFAT_FS=y
+CONFIG_TMPFS=y
+CONFIG_TMPFS_POSIX_ACL=y
+CONFIG_CONFIGFS_FS=y
+CONFIG_ECRYPT_FS=y
+CONFIG_UNION_FS=y
+# CONFIG_UNION_FS_XATTR is not set
+# CONFIG_UNION_FS_DEBUG is not set
+CONFIG_JFFS2_FS=y
+CONFIG_UBIFS_FS=y
+CONFIG_CRAMFS=y
+CONFIG_SQUASHFS=y
+CONFIG_SQUASHFS_ZLIB=y
+CONFIG_SQUASHFS_LZO=y
+CONFIG_SQUASHFS_XZ=y
+CONFIG_SQUASHFS_4K_DEVBLK_SIZE=y
+CONFIG_SQUASHFS_EMBEDDED=y
+CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE=3
+CONFIG_MINIX_FS=y
+CONFIG_ROMFS_FS=y
+CONFIG_NFS_FS=y
+CONFIG_ROOT_NFS=y
+CONFIG_NFSD=y
+CONFIG_NFSD_V3=y
+CONFIG_CIFS=y
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_850=y
+CONFIG_NLS_ISO8859_1=y
+CONFIG_MAGIC_SYSRQ=y
+CONFIG_DEBUG_KERNEL=y
+CONFIG_DEBUG_INFO=y
+CONFIG_ENABLE_DEFAULT_TRACERS=y
+CONFIG_DEBUG_USER=y
+CONFIG_DEBUG_LL=y
+CONFIG_EARLY_PRINTK=y
+CONFIG_KEYS=y
+CONFIG_ENCRYPTED_KEYS=y
+# CONFIG_CRYPTO_MANAGER_DISABLE_TESTS is not set
+CONFIG_CRYPTO_TEST=m
+CONFIG_CRYPTO_SHA1=y
+CONFIG_CRYPTO_SHA512=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO=y
+CONFIG_CRYPTO_DEV_AL_CRYPTO_STATS=y
+CONFIG_LOCALVERSION="_sa"
+CONFIG_ARM_LPAE=y
+CONFIG_ARM_PAGE_SIZE_LARGE=y
+# CONFIG_ARM_PAGE_SIZE_64KB is not set
+CONFIG_ARM_PAGE_SIZE_32KB=y
+# CONFIG_ARM_PAGE_SIZE_4KB is not set
+CONFIG_LFS_ON_32CPU=y
+CONFIG_BTRFS_FS_AHASH_CRC=y
+CONFIG_NET_DMA=y
+CONFIG_ISCSI_TCP=m
+# CONFIG_XFRM_ALGO is not set
+CONFIG_ZLIB_INFLATE=y
+CONFIG_ZLIB_DEFLATE=y
+CONFIG_LZO_COMPRESS=y
+CONFIG_LZO_DECOMPRESS=y
+CONFIG_XZ_DEC=y
+#
+# BUFFALO Features
+#
+CONFIG_BUFFALO_PLATFORM=y
+CONFIG_BUFFALO_USE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT=y
+CONFIG_BUFFALO_ERRCNT=y
+CONFIG_BUFFALO_USE_UPS=y
+CONFIG_BUFFALO_SUPPORT_UPS_RECOVER=y
+# CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN is not set
+# CONFIG_BUFFALO_UBOOT_PARAMS is not set
+CONFIG_BUFFALO_DISABLE_NCQ=y
+CONFIG_BUFFALO_IOERRS=y
+CONFIG_BUFFALO_SKIP_RESYNC=y
+CONFIG_BUFFALO_IGNORE_LUN=y
+CONFIG_BUFFALO_SCSI_GUID=y
+CONFIG_BUFFALO_EXT23_EXTENSION=y
+# CONFIG_BUFFALO_SUPPORT_WOL is not set
+CONFIG_BUFFALO_SUPPORT_BOARD_INFO=y
+CONFIG_BUFFALO_ALPINE_PLATFORM=y
+# CONFIG_BUFFALO_USE_MICON is not set
+# CONFIG_BUFFALO_MICON_V3 is not set
+# CONFIG_BUFFALO_MICON_V3_DEVTTY is not set
+CONFIG_BUFFALO_MICON_REBOOT=y
+CONFIG_BUFFALO_UNIONFS_FIX=y
+
+CONFIG_ISCSI_CHAP_BASE64_SUPPORT=y
diff --git a/buffalo/arch/arm/plat-alpine/Makefile b/buffalo/arch/arm/plat-alpine/Makefile
new file mode 100644
index 00000000..56bafc7
--- /dev/null
+++ b/buffalo/arch/arm/plat-alpine/Makefile
@@ -0,0 +1 @@
+obj-$(CONFIG_BUFFALO_ALPINE_PLATFORM)	+= sysfs.o
diff --git a/buffalo/arch/arm/plat-alpine/sysfs.c b/buffalo/arch/arm/plat-alpine/sysfs.c
new file mode 100644
index 00000000..5520b46
--- /dev/null
+++ b/buffalo/arch/arm/plat-alpine/sysfs.c
@@ -0,0 +1,35 @@
+/*
+ *
+ */
+
+#include <linux/device.h>
+#include <linux/module.h>
+#include <linux/sysfs.h>
+
+static struct class *ts5010_cls = NULL;
+
+static int
+init_sysfs_files(void)
+{
+	/* create /sys/class/ts5010 */
+	ts5010_cls = class_create(THIS_MODULE, "ts5010");
+
+	return 0;
+}
+
+static int __init
+ts5010_platform_init(void)
+{  	
+	return init_sysfs_files();
+}
+
+static void __exit
+ts5010_platform_exit(void)
+{
+	class_destroy(ts5010_cls);
+}
+
+module_init(ts5010_platform_init);
+module_exit(ts5010_platform_exit);
+MODULE_LICENSE("GPL");
+MODULE_AUTHOR("BUFFALO");
diff --git a/buffalo/arch/x86/Kconfig b/buffalo/arch/x86/Kconfig
new file mode 100644
index 00000000..9970e60
--- /dev/null
+++ b/buffalo/arch/x86/Kconfig
@@ -0,0 +1,31 @@
+config BUFFALO_MATSU_PLATFORM
+	bool "MATSU_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	---help---
+	  Enable hdd control driver / button control driver for matsu platform.
+
+config BUFFALO_MATSU_USE_EVT_BOARD
+	bool "MATSU_EVT_BOARD"
+	depends on BUFFALO_MATSU_PLATFORM
+	---help---
+	  EVT board and DVT board has difference for GPIO pin.
+	  If this value set to enable, use EVT GPIO settings.
+
+config BUFFALO_KIRI_PLATFORM
+	bool "KIRI_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	---help---
+	  Enable hdd control driver / button control driver for kiri platform.
+
+config BUFFALO_USI_PLATFORM
+	bool "USI_PLATFORM"
+	depends on BUFFALO_PLATFORM
+	depends on X86
+	--help---
+	  Enable below drivers for usi platform.
+	  * hdd control driver(hot plug / power control)
+	  * fan control driver
+	  * button control driver
+	  * CMOS settings control driver
diff --git a/buffalo/arch/x86/Makefile b/buffalo/arch/x86/Makefile
new file mode 100644
index 00000000..e974bbf
--- /dev/null
+++ b/buffalo/arch/x86/Makefile
@@ -0,0 +1,4 @@
+# Note:	This file is included from $(srctree)/buffalo/Makefile,
+#	you have to specify relatively from $(srctree)/buffalo
+
+obj-$(CONFIG_BUFFALO_USI_PLATFORM)	+= arch/x86/plat-usi/
diff --git a/buffalo/arch/x86/boot/installkernel b/buffalo/arch/x86/boot/installkernel
new file mode 100755
index 00000000..1c5f89b
--- /dev/null
+++ b/buffalo/arch/x86/boot/installkernel
@@ -0,0 +1,83 @@
+#!/bin/sh
+# 
+# Copyright (C) 1995 - 1998, Ian A. Murdock <imurdock@debian.org>
+# Copyright (C) 1998, 1999, Guy Maor
+# Copyright (C) 2002, Matthew Wilcox
+# Copyright (C) 2002, 2004, 2005, 2007, 2009  Clint Adams
+# Copyright (C) 2009  Manoj Srivasta
+#
+# Install the kernel on a Debian Linux system.
+#
+# This script is called from /usr/src/linux/arch/i386/boot/install.sh.
+# If you install it as /sbin/installkernel, you can do a "make install"
+# from a generic kernel source tree, and the image will be installed to
+# the proper place for Debian GNU/Linux.
+
+set -e
+
+# Parse the command line options.  Of course, powerpc has to be all
+# different, and passes in a fifth argument, just because it is
+# "special". We ignore the fifth argument, and do not flag is as an
+# error, which it would be for any arch apart from powerpc
+if [ $# -eq 3 ] || [ $# -eq 4 ] || [ $# -eq 5 ] ; then
+  img="$2"
+  map="$3"
+  ver="$1"
+  if [ $# -ge 4 ] && [ -n "$4" ] ; then
+      dir="$4"
+  else
+      dir="/boot"
+  fi
+else
+  echo "Usage: installkernel <version> <image> <System.map> <directory>"
+  exit 1
+fi
+
+# Create backups of older versions before installing
+updatever () {
+  if [ -f "$dir/$1-$ver" ] ; then
+    mv "$dir/$1-$ver" "$dir/$1-$ver.old"
+  fi
+
+  cat "$2" > "$dir/$1-$ver"
+
+  # This section is for backwards compatibility only
+  if test -f "$dir/$1" ; then
+    # The presence of "$dir/$1" is unusual in modern intallations, and
+    # the results are mostly unused.  So only recreate them if they
+    # already existed.
+    if test -L "$dir/$1" ; then
+        # If we were using links, continue to use links, updating if
+        # we need to.
+        if [ "$(readlink -f ${dir}/${1})" = "${dir}/${1}-${ver}" ]; then
+            # Yup, we need to change
+            ln -sf "$1-$ver.old" "$dir/$1.old"
+        else
+            mv "$dir/$1" "$dir/$1.old"
+        fi
+        ln -sf "$1-$ver" "$dir/$1"
+    else                        # No links
+        mv "$dir/$1" "$dir/$1.old"
+        cat "$2" > "$dir/$1"
+    fi
+  fi
+}
+
+if [ "$(basename $img)" = "vmlinux" ] ; then
+  img_dest=vmlinux
+else
+  img_dest=vmlinuz
+fi
+updatever $img_dest "$img"
+updatever System.map "$map"
+
+config=$(dirname "$map")
+config="${config}/.config"
+if [ -f "$config" ] ; then
+  updatever config "$config"
+fi
+
+#run-parts --verbose --exit-on-error --arg="$ver" --arg="$dir/$img_dest-$ver" \
+#  /etc/kernel/postinst.d
+ 
+exit 0
diff --git a/buffalo/arch/x86/configs/buffalo_ts5000_defconfig b/buffalo/arch/x86/configs/buffalo_ts5000_defconfig
new file mode 100644
index 00000000..3a57f5d
--- /dev/null
+++ b/buffalo/arch/x86/configs/buffalo_ts5000_defconfig
@@ -0,0 +1,3042 @@
+#
+# Automatically generated file; DO NOT EDIT.
+# Linux/x86_64 3.10.20-buffalo Kernel Configuration
+#
+CONFIG_64BIT=y
+CONFIG_X86_64=y
+CONFIG_X86=y
+CONFIG_INSTRUCTION_DECODER=y
+CONFIG_OUTPUT_FORMAT="elf64-x86-64"
+CONFIG_ARCH_DEFCONFIG="arch/x86/configs/x86_64_defconfig"
+CONFIG_LOCKDEP_SUPPORT=y
+CONFIG_STACKTRACE_SUPPORT=y
+CONFIG_HAVE_LATENCYTOP_SUPPORT=y
+CONFIG_MMU=y
+CONFIG_NEED_DMA_MAP_STATE=y
+CONFIG_NEED_SG_DMA_LENGTH=y
+CONFIG_GENERIC_BUG=y
+CONFIG_GENERIC_BUG_RELATIVE_POINTERS=y
+CONFIG_GENERIC_HWEIGHT=y
+CONFIG_RWSEM_XCHGADD_ALGORITHM=y
+CONFIG_GENERIC_CALIBRATE_DELAY=y
+CONFIG_ARCH_HAS_CPU_RELAX=y
+CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
+CONFIG_ARCH_HAS_CPU_AUTOPROBE=y
+CONFIG_HAVE_SETUP_PER_CPU_AREA=y
+CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
+CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
+CONFIG_ARCH_HIBERNATION_POSSIBLE=y
+CONFIG_ARCH_SUSPEND_POSSIBLE=y
+CONFIG_ZONE_DMA32=y
+CONFIG_AUDIT_ARCH=y
+CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
+CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
+CONFIG_X86_64_SMP=y
+CONFIG_X86_HT=y
+CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
+CONFIG_ARCH_CPU_PROBE_RELEASE=y
+CONFIG_ARCH_SUPPORTS_UPROBES=y
+CONFIG_DEFCONFIG_LIST="/lib/modules/$UNAME_RELEASE/.config"
+CONFIG_IRQ_WORK=y
+CONFIG_BUILDTIME_EXTABLE_SORT=y
+
+#
+# General setup
+#
+CONFIG_INIT_ENV_ARG_LIMIT=32
+CONFIG_CROSS_COMPILE=""
+CONFIG_LOCALVERSION=""
+# CONFIG_LOCALVERSION_AUTO is not set
+CONFIG_HAVE_KERNEL_GZIP=y
+CONFIG_HAVE_KERNEL_BZIP2=y
+CONFIG_HAVE_KERNEL_LZMA=y
+CONFIG_HAVE_KERNEL_XZ=y
+CONFIG_HAVE_KERNEL_LZO=y
+CONFIG_KERNEL_GZIP=y
+# CONFIG_KERNEL_BZIP2 is not set
+# CONFIG_KERNEL_LZMA is not set
+# CONFIG_KERNEL_XZ is not set
+# CONFIG_KERNEL_LZO is not set
+CONFIG_DEFAULT_HOSTNAME="(none)"
+CONFIG_SWAP=y
+CONFIG_SYSVIPC=y
+CONFIG_SYSVIPC_SYSCTL=y
+CONFIG_POSIX_MQUEUE=y
+CONFIG_POSIX_MQUEUE_SYSCTL=y
+# CONFIG_FHANDLE is not set
+CONFIG_AUDIT=y
+CONFIG_AUDITSYSCALL=y
+CONFIG_AUDIT_WATCH=y
+CONFIG_AUDIT_TREE=y
+# CONFIG_AUDIT_LOGINUID_IMMUTABLE is not set
+CONFIG_HAVE_GENERIC_HARDIRQS=y
+
+#
+# IRQ subsystem
+#
+CONFIG_GENERIC_HARDIRQS=y
+CONFIG_GENERIC_IRQ_PROBE=y
+CONFIG_GENERIC_IRQ_SHOW=y
+CONFIG_GENERIC_PENDING_IRQ=y
+CONFIG_IRQ_DOMAIN=y
+# CONFIG_IRQ_DOMAIN_DEBUG is not set
+CONFIG_IRQ_FORCED_THREADING=y
+CONFIG_SPARSE_IRQ=y
+CONFIG_CLOCKSOURCE_WATCHDOG=y
+CONFIG_ARCH_CLOCKSOURCE_DATA=y
+CONFIG_GENERIC_TIME_VSYSCALL=y
+CONFIG_GENERIC_CLOCKEVENTS=y
+CONFIG_GENERIC_CLOCKEVENTS_BUILD=y
+CONFIG_GENERIC_CLOCKEVENTS_BROADCAST=y
+CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST=y
+CONFIG_GENERIC_CMOS_UPDATE=y
+
+#
+# Timers subsystem
+#
+CONFIG_TICK_ONESHOT=y
+CONFIG_NO_HZ_COMMON=y
+# CONFIG_HZ_PERIODIC is not set
+CONFIG_NO_HZ_IDLE=y
+# CONFIG_NO_HZ_FULL is not set
+CONFIG_NO_HZ=y
+CONFIG_HIGH_RES_TIMERS=y
+
+#
+# CPU/Task time and stats accounting
+#
+CONFIG_TICK_CPU_ACCOUNTING=y
+# CONFIG_VIRT_CPU_ACCOUNTING_GEN is not set
+# CONFIG_IRQ_TIME_ACCOUNTING is not set
+CONFIG_BSD_PROCESS_ACCT=y
+CONFIG_BSD_PROCESS_ACCT_V3=y
+CONFIG_TASKSTATS=y
+CONFIG_TASK_DELAY_ACCT=y
+CONFIG_TASK_XACCT=y
+CONFIG_TASK_IO_ACCOUNTING=y
+
+#
+# RCU Subsystem
+#
+CONFIG_TREE_RCU=y
+# CONFIG_PREEMPT_RCU is not set
+CONFIG_RCU_STALL_COMMON=y
+# CONFIG_RCU_USER_QS is not set
+CONFIG_RCU_FANOUT=64
+CONFIG_RCU_FANOUT_LEAF=16
+# CONFIG_RCU_FANOUT_EXACT is not set
+CONFIG_RCU_FAST_NO_HZ=y
+# CONFIG_TREE_RCU_TRACE is not set
+# CONFIG_RCU_NOCB_CPU is not set
+CONFIG_IKCONFIG=y
+CONFIG_IKCONFIG_PROC=y
+CONFIG_LOG_BUF_SHIFT=18
+CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
+CONFIG_ARCH_SUPPORTS_NUMA_BALANCING=y
+CONFIG_ARCH_WANTS_PROT_NUMA_PROT_NONE=y
+# CONFIG_NUMA_BALANCING is not set
+CONFIG_CGROUPS=y
+# CONFIG_CGROUP_DEBUG is not set
+CONFIG_CGROUP_FREEZER=y
+CONFIG_CGROUP_DEVICE=y
+CONFIG_CPUSETS=y
+CONFIG_PROC_PID_CPUSET=y
+CONFIG_CGROUP_CPUACCT=y
+CONFIG_RESOURCE_COUNTERS=y
+# CONFIG_MEMCG is not set
+# CONFIG_CGROUP_HUGETLB is not set
+# CONFIG_CGROUP_PERF is not set
+CONFIG_CGROUP_SCHED=y
+CONFIG_FAIR_GROUP_SCHED=y
+# CONFIG_CFS_BANDWIDTH is not set
+CONFIG_RT_GROUP_SCHED=y
+CONFIG_BLK_CGROUP=y
+# CONFIG_DEBUG_BLK_CGROUP is not set
+# CONFIG_CHECKPOINT_RESTORE is not set
+CONFIG_NAMESPACES=y
+CONFIG_UTS_NS=y
+CONFIG_IPC_NS=y
+CONFIG_PID_NS=y
+CONFIG_NET_NS=y
+CONFIG_SCHED_AUTOGROUP=y
+# CONFIG_SYSFS_DEPRECATED is not set
+CONFIG_RELAY=y
+CONFIG_BLK_DEV_INITRD=y
+CONFIG_INITRAMFS_SOURCE=""
+CONFIG_RD_GZIP=y
+CONFIG_RD_BZIP2=y
+CONFIG_RD_LZMA=y
+CONFIG_RD_XZ=y
+CONFIG_RD_LZO=y
+# CONFIG_CC_OPTIMIZE_FOR_SIZE is not set
+CONFIG_SYSCTL=y
+CONFIG_ANON_INODES=y
+CONFIG_HAVE_UID16=y
+CONFIG_SYSCTL_EXCEPTION_TRACE=y
+CONFIG_HOTPLUG=y
+CONFIG_HAVE_PCSPKR_PLATFORM=y
+CONFIG_EXPERT=y
+CONFIG_UID16=y
+CONFIG_SYSCTL_SYSCALL=y
+CONFIG_KALLSYMS=y
+# CONFIG_KALLSYMS_ALL is not set
+CONFIG_PRINTK=y
+CONFIG_BUG=y
+CONFIG_ELF_CORE=y
+CONFIG_PCSPKR_PLATFORM=y
+CONFIG_BASE_FULL=y
+CONFIG_FUTEX=y
+CONFIG_EPOLL=y
+CONFIG_SIGNALFD=y
+CONFIG_TIMERFD=y
+CONFIG_EVENTFD=y
+CONFIG_SHMEM=y
+CONFIG_AIO=y
+CONFIG_PCI_QUIRKS=y
+# CONFIG_EMBEDDED is not set
+CONFIG_HAVE_PERF_EVENTS=y
+
+#
+# Kernel Performance Events And Counters
+#
+CONFIG_PERF_EVENTS=y
+# CONFIG_DEBUG_PERF_USE_VMALLOC is not set
+CONFIG_VM_EVENT_COUNTERS=y
+# CONFIG_SLUB_DEBUG is not set
+# CONFIG_COMPAT_BRK is not set
+# CONFIG_SLAB is not set
+CONFIG_SLUB=y
+# CONFIG_SLOB is not set
+CONFIG_PROFILING=y
+CONFIG_TRACEPOINTS=y
+# CONFIG_OPROFILE is not set
+CONFIG_HAVE_OPROFILE=y
+CONFIG_OPROFILE_NMI_TIMER=y
+CONFIG_KPROBES=y
+CONFIG_JUMP_LABEL=y
+CONFIG_OPTPROBES=y
+CONFIG_KPROBES_ON_FTRACE=y
+# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
+CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
+CONFIG_ARCH_USE_BUILTIN_BSWAP=y
+CONFIG_KRETPROBES=y
+CONFIG_HAVE_IOREMAP_PROT=y
+CONFIG_HAVE_KPROBES=y
+CONFIG_HAVE_KRETPROBES=y
+CONFIG_HAVE_OPTPROBES=y
+CONFIG_HAVE_KPROBES_ON_FTRACE=y
+CONFIG_HAVE_ARCH_TRACEHOOK=y
+CONFIG_HAVE_DMA_ATTRS=y
+CONFIG_USE_GENERIC_SMP_HELPERS=y
+CONFIG_GENERIC_SMP_IDLE_THREAD=y
+CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
+CONFIG_HAVE_DMA_API_DEBUG=y
+CONFIG_HAVE_HW_BREAKPOINT=y
+CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
+CONFIG_HAVE_USER_RETURN_NOTIFIER=y
+CONFIG_HAVE_PERF_EVENTS_NMI=y
+CONFIG_HAVE_PERF_REGS=y
+CONFIG_HAVE_PERF_USER_STACK_DUMP=y
+CONFIG_HAVE_ARCH_JUMP_LABEL=y
+CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG=y
+CONFIG_HAVE_ALIGNED_STRUCT_PAGE=y
+CONFIG_HAVE_CMPXCHG_LOCAL=y
+CONFIG_HAVE_CMPXCHG_DOUBLE=y
+CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION=y
+CONFIG_ARCH_WANT_OLD_COMPAT_IPC=y
+CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
+CONFIG_SECCOMP_FILTER=y
+CONFIG_HAVE_CONTEXT_TRACKING=y
+CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
+CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
+CONFIG_MODULES_USE_ELF_RELA=y
+CONFIG_OLD_SIGSUSPEND3=y
+CONFIG_COMPAT_OLD_SIGACTION=y
+
+#
+# GCOV-based kernel profiling
+#
+# CONFIG_GCOV_KERNEL is not set
+# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
+CONFIG_RT_MUTEXES=y
+CONFIG_BASE_SMALL=0
+CONFIG_MODULES=y
+# CONFIG_MODULE_FORCE_LOAD is not set
+CONFIG_MODULE_UNLOAD=y
+# CONFIG_MODULE_FORCE_UNLOAD is not set
+CONFIG_MODVERSIONS=y
+CONFIG_MODULE_SRCVERSION_ALL=y
+# CONFIG_MODULE_SIG is not set
+CONFIG_STOP_MACHINE=y
+CONFIG_BLOCK=y
+CONFIG_BLK_DEV_BSG=y
+# CONFIG_BLK_DEV_BSGLIB is not set
+CONFIG_BLK_DEV_INTEGRITY=y
+CONFIG_BLK_DEV_THROTTLING=y
+
+#
+# Partition Types
+#
+CONFIG_PARTITION_ADVANCED=y
+# CONFIG_ACORN_PARTITION is not set
+# CONFIG_OSF_PARTITION is not set
+# CONFIG_AMIGA_PARTITION is not set
+# CONFIG_ATARI_PARTITION is not set
+CONFIG_MAC_PARTITION=y
+CONFIG_MSDOS_PARTITION=y
+CONFIG_BSD_DISKLABEL=y
+CONFIG_MINIX_SUBPARTITION=y
+CONFIG_SOLARIS_X86_PARTITION=y
+CONFIG_UNIXWARE_DISKLABEL=y
+# CONFIG_LDM_PARTITION is not set
+# CONFIG_SGI_PARTITION is not set
+# CONFIG_ULTRIX_PARTITION is not set
+# CONFIG_SUN_PARTITION is not set
+# CONFIG_KARMA_PARTITION is not set
+CONFIG_EFI_PARTITION=y
+# CONFIG_SYSV68_PARTITION is not set
+CONFIG_BLOCK_COMPAT=y
+
+#
+# IO Schedulers
+#
+CONFIG_IOSCHED_NOOP=y
+CONFIG_IOSCHED_DEADLINE=y
+CONFIG_IOSCHED_CFQ=y
+CONFIG_CFQ_GROUP_IOSCHED=y
+# CONFIG_DEFAULT_DEADLINE is not set
+CONFIG_DEFAULT_CFQ=y
+# CONFIG_DEFAULT_NOOP is not set
+CONFIG_DEFAULT_IOSCHED="cfq"
+CONFIG_INLINE_SPIN_UNLOCK_IRQ=y
+CONFIG_INLINE_READ_UNLOCK=y
+CONFIG_INLINE_READ_UNLOCK_IRQ=y
+CONFIG_INLINE_WRITE_UNLOCK=y
+CONFIG_INLINE_WRITE_UNLOCK_IRQ=y
+CONFIG_MUTEX_SPIN_ON_OWNER=y
+CONFIG_FREEZER=y
+
+#
+# Processor type and features
+#
+CONFIG_ZONE_DMA=y
+CONFIG_SMP=y
+CONFIG_X86_MPPARSE=y
+CONFIG_X86_EXTENDED_PLATFORM=y
+# CONFIG_X86_VSMP is not set
+# CONFIG_X86_INTEL_LPSS is not set
+CONFIG_X86_SUPPORTS_MEMORY_FAILURE=y
+CONFIG_SCHED_OMIT_FRAME_POINTER=y
+# CONFIG_HYPERVISOR_GUEST is not set
+CONFIG_NO_BOOTMEM=y
+# CONFIG_MEMTEST is not set
+# CONFIG_MK8 is not set
+# CONFIG_MPSC is not set
+# CONFIG_MCORE2 is not set
+# CONFIG_MATOM is not set
+CONFIG_GENERIC_CPU=y
+CONFIG_X86_INTERNODE_CACHE_SHIFT=6
+CONFIG_X86_L1_CACHE_SHIFT=6
+CONFIG_X86_TSC=y
+CONFIG_X86_CMPXCHG64=y
+CONFIG_X86_CMOV=y
+CONFIG_X86_MINIMUM_CPU_FAMILY=64
+CONFIG_X86_DEBUGCTLMSR=y
+CONFIG_PROCESSOR_SELECT=y
+CONFIG_CPU_SUP_INTEL=y
+CONFIG_CPU_SUP_AMD=y
+CONFIG_CPU_SUP_CENTAUR=y
+CONFIG_HPET_TIMER=y
+CONFIG_HPET_EMULATE_RTC=y
+CONFIG_DMI=y
+CONFIG_GART_IOMMU=y
+CONFIG_CALGARY_IOMMU=y
+CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT=y
+CONFIG_SWIOTLB=y
+CONFIG_IOMMU_HELPER=y
+# CONFIG_MAXSMP is not set
+CONFIG_NR_CPUS=256
+CONFIG_SCHED_SMT=y
+CONFIG_SCHED_MC=y
+# CONFIG_PREEMPT_NONE is not set
+CONFIG_PREEMPT_VOLUNTARY=y
+# CONFIG_PREEMPT is not set
+CONFIG_X86_LOCAL_APIC=y
+CONFIG_X86_IO_APIC=y
+CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS=y
+CONFIG_X86_MCE=y
+CONFIG_X86_MCE_INTEL=y
+CONFIG_X86_MCE_AMD=y
+CONFIG_X86_MCE_THRESHOLD=y
+# CONFIG_X86_MCE_INJECT is not set
+CONFIG_X86_THERMAL_VECTOR=y
+# CONFIG_I8K is not set
+# CONFIG_MICROCODE is not set
+# CONFIG_X86_MSR is not set
+# CONFIG_X86_CPUID is not set
+CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
+CONFIG_ARCH_DMA_ADDR_T_64BIT=y
+CONFIG_DIRECT_GBPAGES=y
+CONFIG_NUMA=y
+CONFIG_AMD_NUMA=y
+CONFIG_X86_64_ACPI_NUMA=y
+CONFIG_NODES_SPAN_OTHER_NODES=y
+# CONFIG_NUMA_EMU is not set
+CONFIG_NODES_SHIFT=6
+CONFIG_ARCH_SPARSEMEM_ENABLE=y
+CONFIG_ARCH_SPARSEMEM_DEFAULT=y
+CONFIG_ARCH_SELECT_MEMORY_MODEL=y
+CONFIG_ARCH_PROC_KCORE_TEXT=y
+CONFIG_ILLEGAL_POINTER_VALUE=0xdead000000000000
+CONFIG_SELECT_MEMORY_MODEL=y
+CONFIG_SPARSEMEM_MANUAL=y
+CONFIG_SPARSEMEM=y
+CONFIG_NEED_MULTIPLE_NODES=y
+CONFIG_HAVE_MEMORY_PRESENT=y
+CONFIG_SPARSEMEM_EXTREME=y
+CONFIG_SPARSEMEM_VMEMMAP_ENABLE=y
+CONFIG_SPARSEMEM_ALLOC_MEM_MAP_TOGETHER=y
+CONFIG_SPARSEMEM_VMEMMAP=y
+CONFIG_HAVE_MEMBLOCK=y
+CONFIG_HAVE_MEMBLOCK_NODE_MAP=y
+CONFIG_ARCH_DISCARD_MEMBLOCK=y
+CONFIG_MEMORY_ISOLATION=y
+# CONFIG_MOVABLE_NODE is not set
+# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
+# CONFIG_MEMORY_HOTPLUG is not set
+CONFIG_PAGEFLAGS_EXTENDED=y
+CONFIG_SPLIT_PTLOCK_CPUS=4
+CONFIG_COMPACTION=y
+CONFIG_MIGRATION=y
+CONFIG_PHYS_ADDR_T_64BIT=y
+CONFIG_ZONE_DMA_FLAG=1
+CONFIG_BOUNCE=y
+CONFIG_NEED_BOUNCE_POOL=y
+CONFIG_VIRT_TO_BUS=y
+CONFIG_KSM=y
+CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
+CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE=y
+CONFIG_MEMORY_FAILURE=y
+# CONFIG_HWPOISON_INJECT is not set
+# CONFIG_TRANSPARENT_HUGEPAGE is not set
+CONFIG_CROSS_MEMORY_ATTACH=y
+# CONFIG_CLEANCACHE is not set
+# CONFIG_FRONTSWAP is not set
+CONFIG_X86_CHECK_BIOS_CORRUPTION=y
+CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK=y
+CONFIG_X86_RESERVE_LOW=64
+CONFIG_MTRR=y
+CONFIG_MTRR_SANITIZER=y
+CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=0
+CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT=1
+CONFIG_X86_PAT=y
+CONFIG_ARCH_USES_PG_UNCACHED=y
+CONFIG_ARCH_RANDOM=y
+CONFIG_X86_SMAP=y
+CONFIG_EFI=y
+# CONFIG_EFI_STUB is not set
+CONFIG_SECCOMP=y
+CONFIG_CC_STACKPROTECTOR=y
+CONFIG_HZ_100=y
+# CONFIG_HZ_250 is not set
+# CONFIG_HZ_300 is not set
+# CONFIG_HZ_1000 is not set
+CONFIG_HZ=100
+CONFIG_SCHED_HRTICK=y
+CONFIG_KEXEC=y
+CONFIG_CRASH_DUMP=y
+CONFIG_KEXEC_JUMP=y
+CONFIG_PHYSICAL_START=0x1000000
+CONFIG_RELOCATABLE=y
+CONFIG_PHYSICAL_ALIGN=0x1000000
+CONFIG_HOTPLUG_CPU=y
+# CONFIG_BOOTPARAM_HOTPLUG_CPU0 is not set
+# CONFIG_DEBUG_HOTPLUG_CPU0 is not set
+# CONFIG_COMPAT_VDSO is not set
+# CONFIG_CMDLINE_BOOL is not set
+CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG=y
+CONFIG_USE_PERCPU_NUMA_NODE_ID=y
+
+#
+# Power management and ACPI options
+#
+CONFIG_ARCH_HIBERNATION_HEADER=y
+CONFIG_SUSPEND=y
+CONFIG_SUSPEND_FREEZER=y
+CONFIG_HIBERNATE_CALLBACKS=y
+CONFIG_HIBERNATION=y
+CONFIG_PM_STD_PARTITION=""
+CONFIG_PM_SLEEP=y
+CONFIG_PM_SLEEP_SMP=y
+# CONFIG_PM_AUTOSLEEP is not set
+# CONFIG_PM_WAKELOCKS is not set
+CONFIG_PM_RUNTIME=y
+CONFIG_PM=y
+# CONFIG_PM_DEBUG is not set
+CONFIG_ACPI=y
+CONFIG_ACPI_SLEEP=y
+CONFIG_ACPI_PROCFS=y
+CONFIG_ACPI_PROCFS_POWER=y
+# CONFIG_ACPI_EC_DEBUGFS is not set
+CONFIG_ACPI_PROC_EVENT=y
+CONFIG_ACPI_AC=y
+CONFIG_ACPI_BATTERY=y
+CONFIG_ACPI_BUTTON=y
+CONFIG_ACPI_VIDEO=y
+CONFIG_ACPI_FAN=y
+CONFIG_ACPI_DOCK=y
+CONFIG_ACPI_I2C=y
+CONFIG_ACPI_PROCESSOR=y
+CONFIG_ACPI_HOTPLUG_CPU=y
+# CONFIG_ACPI_PROCESSOR_AGGREGATOR is not set
+CONFIG_ACPI_THERMAL=y
+CONFIG_ACPI_NUMA=y
+CONFIG_ACPI_CUSTOM_DSDT_FILE=""
+# CONFIG_ACPI_CUSTOM_DSDT is not set
+# CONFIG_ACPI_INITRD_TABLE_OVERRIDE is not set
+CONFIG_ACPI_BLACKLIST_YEAR=0
+# CONFIG_ACPI_DEBUG is not set
+CONFIG_ACPI_PCI_SLOT=y
+CONFIG_X86_PM_TIMER=y
+CONFIG_ACPI_CONTAINER=y
+CONFIG_ACPI_SBS=y
+# CONFIG_ACPI_HED is not set
+# CONFIG_ACPI_CUSTOM_METHOD is not set
+# CONFIG_ACPI_BGRT is not set
+CONFIG_ACPI_APEI=y
+# CONFIG_ACPI_APEI_GHES is not set
+# CONFIG_ACPI_APEI_PCIEAER is not set
+# CONFIG_ACPI_APEI_MEMORY_FAILURE is not set
+# CONFIG_ACPI_APEI_EINJ is not set
+# CONFIG_ACPI_APEI_ERST_DEBUG is not set
+CONFIG_SFI=y
+
+#
+# CPU Frequency scaling
+#
+CONFIG_CPU_FREQ=y
+CONFIG_CPU_FREQ_TABLE=y
+CONFIG_CPU_FREQ_GOV_COMMON=y
+CONFIG_CPU_FREQ_STAT=y
+CONFIG_CPU_FREQ_STAT_DETAILS=y
+CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y
+# CONFIG_CPU_FREQ_DEFAULT_GOV_POWERSAVE is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND is not set
+# CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE is not set
+CONFIG_CPU_FREQ_GOV_PERFORMANCE=y
+CONFIG_CPU_FREQ_GOV_POWERSAVE=y
+CONFIG_CPU_FREQ_GOV_USERSPACE=y
+CONFIG_CPU_FREQ_GOV_ONDEMAND=y
+CONFIG_CPU_FREQ_GOV_CONSERVATIVE=y
+
+#
+# x86 CPU frequency scaling drivers
+#
+# CONFIG_X86_INTEL_PSTATE is not set
+# CONFIG_X86_PCC_CPUFREQ is not set
+CONFIG_X86_ACPI_CPUFREQ=y
+CONFIG_X86_ACPI_CPUFREQ_CPB=y
+CONFIG_X86_POWERNOW_K8=y
+# CONFIG_X86_AMD_FREQ_SENSITIVITY is not set
+CONFIG_X86_SPEEDSTEP_CENTRINO=y
+# CONFIG_X86_P4_CLOCKMOD is not set
+
+#
+# shared options
+#
+# CONFIG_X86_SPEEDSTEP_LIB is not set
+CONFIG_CPU_IDLE=y
+# CONFIG_CPU_IDLE_MULTIPLE_DRIVERS is not set
+CONFIG_CPU_IDLE_GOV_LADDER=y
+CONFIG_CPU_IDLE_GOV_MENU=y
+# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
+CONFIG_INTEL_IDLE=y
+
+#
+# Memory power savings
+#
+# CONFIG_I7300_IDLE is not set
+
+#
+# Bus options (PCI etc.)
+#
+CONFIG_PCI=y
+CONFIG_PCI_DIRECT=y
+CONFIG_PCI_MMCONFIG=y
+CONFIG_PCI_DOMAINS=y
+# CONFIG_PCI_CNB20LE_QUIRK is not set
+CONFIG_PCIEPORTBUS=y
+CONFIG_HOTPLUG_PCI_PCIE=y
+CONFIG_PCIEAER=y
+# CONFIG_PCIE_ECRC is not set
+# CONFIG_PCIEAER_INJECT is not set
+CONFIG_PCIEASPM=y
+# CONFIG_PCIEASPM_DEBUG is not set
+CONFIG_PCIEASPM_DEFAULT=y
+# CONFIG_PCIEASPM_POWERSAVE is not set
+# CONFIG_PCIEASPM_PERFORMANCE is not set
+CONFIG_PCIE_PME=y
+CONFIG_ARCH_SUPPORTS_MSI=y
+CONFIG_PCI_MSI=y
+# CONFIG_PCI_DEBUG is not set
+# CONFIG_PCI_REALLOC_ENABLE_AUTO is not set
+# CONFIG_PCI_STUB is not set
+CONFIG_HT_IRQ=y
+CONFIG_PCI_ATS=y
+# CONFIG_PCI_IOV is not set
+CONFIG_PCI_PRI=y
+CONFIG_PCI_PASID=y
+CONFIG_PCI_IOAPIC=y
+CONFIG_PCI_LABEL=y
+# CONFIG_ISA_DMA_API is not set
+CONFIG_AMD_NB=y
+# CONFIG_PCCARD is not set
+CONFIG_HOTPLUG_PCI=y
+# CONFIG_HOTPLUG_PCI_ACPI is not set
+CONFIG_HOTPLUG_PCI_CPCI=y
+# CONFIG_HOTPLUG_PCI_CPCI_ZT5550 is not set
+# CONFIG_HOTPLUG_PCI_CPCI_GENERIC is not set
+# CONFIG_HOTPLUG_PCI_SHPC is not set
+# CONFIG_RAPIDIO is not set
+
+#
+# Executable file formats / Emulations
+#
+CONFIG_BINFMT_ELF=y
+CONFIG_COMPAT_BINFMT_ELF=y
+CONFIG_ARCH_BINFMT_ELF_RANDOMIZE_PIE=y
+CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
+CONFIG_BINFMT_SCRIPT=y
+# CONFIG_HAVE_AOUT is not set
+CONFIG_BINFMT_MISC=y
+CONFIG_COREDUMP=y
+CONFIG_IA32_EMULATION=y
+# CONFIG_IA32_AOUT is not set
+# CONFIG_X86_X32 is not set
+CONFIG_COMPAT=y
+CONFIG_COMPAT_FOR_U64_ALIGNMENT=y
+CONFIG_SYSVIPC_COMPAT=y
+CONFIG_KEYS_COMPAT=y
+CONFIG_HAVE_TEXT_POKE_SMP=y
+CONFIG_X86_DEV_DMA_OPS=y
+CONFIG_NET=y
+
+#
+# Networking options
+#
+CONFIG_PACKET=y
+# CONFIG_PACKET_DIAG is not set
+CONFIG_UNIX=y
+# CONFIG_UNIX_DIAG is not set
+# CONFIG_XFRM_USER is not set
+# CONFIG_NET_KEY is not set
+CONFIG_INET=y
+CONFIG_IP_MULTICAST=y
+CONFIG_IP_ADVANCED_ROUTER=y
+# CONFIG_IP_FIB_TRIE_STATS is not set
+CONFIG_IP_MULTIPLE_TABLES=y
+CONFIG_IP_ROUTE_MULTIPATH=y
+CONFIG_IP_ROUTE_VERBOSE=y
+CONFIG_IP_PNP=y
+CONFIG_IP_PNP_DHCP=y
+CONFIG_IP_PNP_BOOTP=y
+CONFIG_IP_PNP_RARP=y
+# CONFIG_NET_IPIP is not set
+# CONFIG_NET_IPGRE_DEMUX is not set
+# CONFIG_NET_IP_TUNNEL is not set
+CONFIG_IP_MROUTE=y
+# CONFIG_IP_MROUTE_MULTIPLE_TABLES is not set
+CONFIG_IP_PIMSM_V1=y
+CONFIG_IP_PIMSM_V2=y
+# CONFIG_ARPD is not set
+CONFIG_SYN_COOKIES=y
+# CONFIG_INET_AH is not set
+# CONFIG_INET_ESP is not set
+# CONFIG_INET_IPCOMP is not set
+# CONFIG_INET_XFRM_TUNNEL is not set
+# CONFIG_INET_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_TRANSPORT is not set
+# CONFIG_INET_XFRM_MODE_TUNNEL is not set
+# CONFIG_INET_XFRM_MODE_BEET is not set
+CONFIG_INET_LRO=y
+# CONFIG_INET_DIAG is not set
+CONFIG_TCP_CONG_ADVANCED=y
+# CONFIG_TCP_CONG_BIC is not set
+CONFIG_TCP_CONG_CUBIC=y
+# CONFIG_TCP_CONG_WESTWOOD is not set
+# CONFIG_TCP_CONG_HTCP is not set
+# CONFIG_TCP_CONG_HSTCP is not set
+# CONFIG_TCP_CONG_HYBLA is not set
+# CONFIG_TCP_CONG_VEGAS is not set
+# CONFIG_TCP_CONG_SCALABLE is not set
+# CONFIG_TCP_CONG_LP is not set
+# CONFIG_TCP_CONG_VENO is not set
+# CONFIG_TCP_CONG_YEAH is not set
+# CONFIG_TCP_CONG_ILLINOIS is not set
+CONFIG_DEFAULT_CUBIC=y
+# CONFIG_DEFAULT_RENO is not set
+CONFIG_DEFAULT_TCP_CONG="cubic"
+CONFIG_TCP_MD5SIG=y
+# CONFIG_IPV6 is not set
+CONFIG_NETLABEL=y
+CONFIG_NETWORK_SECMARK=y
+# CONFIG_NETWORK_PHY_TIMESTAMPING is not set
+CONFIG_NETFILTER=y
+# CONFIG_NETFILTER_DEBUG is not set
+# CONFIG_NETFILTER_ADVANCED is not set
+
+#
+# Core Netfilter Configuration
+#
+CONFIG_NETFILTER_NETLINK=y
+CONFIG_NETFILTER_NETLINK_LOG=y
+# CONFIG_NF_CONNTRACK is not set
+CONFIG_NETFILTER_XTABLES=y
+
+#
+# Xtables combined modules
+#
+# CONFIG_NETFILTER_XT_MARK is not set
+
+#
+# Xtables targets
+#
+CONFIG_NETFILTER_XT_TARGET_LOG=m
+CONFIG_NETFILTER_XT_TARGET_NFLOG=y
+CONFIG_NETFILTER_XT_TARGET_SECMARK=y
+CONFIG_NETFILTER_XT_TARGET_TCPMSS=y
+
+#
+# Xtables matches
+#
+# CONFIG_IP_SET is not set
+# CONFIG_IP_VS is not set
+
+#
+# IP: Netfilter Configuration
+#
+# CONFIG_NF_DEFRAG_IPV4 is not set
+CONFIG_IP_NF_IPTABLES=y
+CONFIG_IP_NF_FILTER=y
+CONFIG_IP_NF_TARGET_REJECT=y
+CONFIG_IP_NF_TARGET_ULOG=y
+CONFIG_IP_NF_MANGLE=y
+# CONFIG_IP_NF_RAW is not set
+# CONFIG_IP_DCCP is not set
+# CONFIG_IP_SCTP is not set
+# CONFIG_RDS is not set
+# CONFIG_TIPC is not set
+# CONFIG_ATM is not set
+# CONFIG_L2TP is not set
+# CONFIG_BRIDGE is not set
+CONFIG_HAVE_NET_DSA=y
+# CONFIG_VLAN_8021Q is not set
+# CONFIG_DECNET is not set
+# CONFIG_LLC2 is not set
+# CONFIG_IPX is not set
+# CONFIG_ATALK is not set
+# CONFIG_X25 is not set
+# CONFIG_LAPB is not set
+# CONFIG_PHONET is not set
+# CONFIG_IEEE802154 is not set
+CONFIG_NET_SCHED=y
+
+#
+# Queueing/Scheduling
+#
+# CONFIG_NET_SCH_CBQ is not set
+# CONFIG_NET_SCH_HTB is not set
+# CONFIG_NET_SCH_HFSC is not set
+# CONFIG_NET_SCH_PRIO is not set
+# CONFIG_NET_SCH_MULTIQ is not set
+# CONFIG_NET_SCH_RED is not set
+# CONFIG_NET_SCH_SFB is not set
+# CONFIG_NET_SCH_SFQ is not set
+# CONFIG_NET_SCH_TEQL is not set
+# CONFIG_NET_SCH_TBF is not set
+# CONFIG_NET_SCH_GRED is not set
+# CONFIG_NET_SCH_DSMARK is not set
+# CONFIG_NET_SCH_NETEM is not set
+# CONFIG_NET_SCH_DRR is not set
+# CONFIG_NET_SCH_MQPRIO is not set
+# CONFIG_NET_SCH_CHOKE is not set
+# CONFIG_NET_SCH_QFQ is not set
+# CONFIG_NET_SCH_CODEL is not set
+# CONFIG_NET_SCH_FQ_CODEL is not set
+# CONFIG_NET_SCH_INGRESS is not set
+# CONFIG_NET_SCH_PLUG is not set
+
+#
+# Classification
+#
+CONFIG_NET_CLS=y
+# CONFIG_NET_CLS_BASIC is not set
+# CONFIG_NET_CLS_TCINDEX is not set
+# CONFIG_NET_CLS_ROUTE4 is not set
+# CONFIG_NET_CLS_FW is not set
+# CONFIG_NET_CLS_U32 is not set
+# CONFIG_NET_CLS_RSVP is not set
+# CONFIG_NET_CLS_RSVP6 is not set
+# CONFIG_NET_CLS_FLOW is not set
+CONFIG_NET_CLS_CGROUP=y
+CONFIG_NET_EMATCH=y
+CONFIG_NET_EMATCH_STACK=32
+# CONFIG_NET_EMATCH_CMP is not set
+# CONFIG_NET_EMATCH_NBYTE is not set
+# CONFIG_NET_EMATCH_U32 is not set
+# CONFIG_NET_EMATCH_META is not set
+# CONFIG_NET_EMATCH_TEXT is not set
+CONFIG_NET_CLS_ACT=y
+# CONFIG_NET_ACT_POLICE is not set
+# CONFIG_NET_ACT_GACT is not set
+# CONFIG_NET_ACT_MIRRED is not set
+# CONFIG_NET_ACT_IPT is not set
+# CONFIG_NET_ACT_NAT is not set
+# CONFIG_NET_ACT_PEDIT is not set
+# CONFIG_NET_ACT_SIMP is not set
+# CONFIG_NET_ACT_SKBEDIT is not set
+# CONFIG_NET_ACT_CSUM is not set
+CONFIG_NET_SCH_FIFO=y
+# CONFIG_DCB is not set
+CONFIG_DNS_RESOLVER=y
+# CONFIG_BATMAN_ADV is not set
+# CONFIG_OPENVSWITCH is not set
+# CONFIG_VSOCKETS is not set
+# CONFIG_NETLINK_MMAP is not set
+# CONFIG_NETLINK_DIAG is not set
+CONFIG_RPS=y
+CONFIG_RFS_ACCEL=y
+CONFIG_XPS=y
+# CONFIG_NETPRIO_CGROUP is not set
+CONFIG_BQL=y
+# CONFIG_BPF_JIT is not set
+
+#
+# Network testing
+#
+# CONFIG_NET_PKTGEN is not set
+# CONFIG_NET_TCPPROBE is not set
+# CONFIG_NET_DROP_MONITOR is not set
+CONFIG_HAMRADIO=y
+
+#
+# Packet Radio protocols
+#
+# CONFIG_AX25 is not set
+# CONFIG_CAN is not set
+# CONFIG_IRDA is not set
+# CONFIG_BT is not set
+# CONFIG_AF_RXRPC is not set
+CONFIG_FIB_RULES=y
+CONFIG_WIRELESS=y
+# CONFIG_CFG80211 is not set
+# CONFIG_LIB80211 is not set
+
+#
+# CFG80211 needs to be enabled for MAC80211
+#
+# CONFIG_WIMAX is not set
+CONFIG_RFKILL=y
+CONFIG_RFKILL_INPUT=y
+# CONFIG_NET_9P is not set
+# CONFIG_CAIF is not set
+# CONFIG_CEPH_LIB is not set
+# CONFIG_NFC is not set
+CONFIG_HAVE_BPF_JIT=y
+
+#
+# Device Drivers
+#
+
+#
+# Generic Driver Options
+#
+CONFIG_UEVENT_HELPER_PATH="/sbin/hotplug"
+# CONFIG_DEVTMPFS is not set
+# CONFIG_STANDALONE is not set
+CONFIG_PREVENT_FIRMWARE_BUILD=y
+CONFIG_FW_LOADER=y
+CONFIG_FIRMWARE_IN_KERNEL=y
+CONFIG_EXTRA_FIRMWARE=""
+CONFIG_FW_LOADER_USER_HELPER=y
+# CONFIG_DEBUG_DRIVER is not set
+# CONFIG_DEBUG_DEVRES is not set
+# CONFIG_SYS_HYPERVISOR is not set
+# CONFIG_GENERIC_CPU_DEVICES is not set
+CONFIG_DMA_SHARED_BUFFER=y
+
+#
+# Bus devices
+#
+CONFIG_CONNECTOR=y
+CONFIG_PROC_EVENTS=y
+# CONFIG_MTD is not set
+# CONFIG_PARPORT is not set
+CONFIG_PNP=y
+# CONFIG_PNP_DEBUG_MESSAGES is not set
+
+#
+# Protocols
+#
+CONFIG_PNPACPI=y
+CONFIG_BLK_DEV=y
+# CONFIG_BLK_DEV_PCIESSD_MTIP32XX is not set
+# CONFIG_BLK_CPQ_DA is not set
+# CONFIG_BLK_CPQ_CISS_DA is not set
+# CONFIG_BLK_DEV_DAC960 is not set
+# CONFIG_BLK_DEV_UMEM is not set
+# CONFIG_BLK_DEV_COW_COMMON is not set
+CONFIG_BLK_DEV_LOOP=y
+CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
+# CONFIG_BLK_DEV_CRYPTOLOOP is not set
+# CONFIG_BLK_DEV_DRBD is not set
+# CONFIG_BLK_DEV_NBD is not set
+# CONFIG_BLK_DEV_NVME is not set
+# CONFIG_BLK_DEV_SX8 is not set
+CONFIG_BLK_DEV_RAM=y
+CONFIG_BLK_DEV_RAM_COUNT=16
+CONFIG_BLK_DEV_RAM_SIZE=65536
+# CONFIG_BLK_DEV_XIP is not set
+# CONFIG_CDROM_PKTCDVD is not set
+# CONFIG_ATA_OVER_ETH is not set
+# CONFIG_BLK_DEV_HD is not set
+# CONFIG_BLK_DEV_RBD is not set
+# CONFIG_BLK_DEV_RSXX is not set
+
+#
+# Misc devices
+#
+# CONFIG_SENSORS_LIS3LV02D is not set
+# CONFIG_AD525X_DPOT is not set
+# CONFIG_DUMMY_IRQ is not set
+# CONFIG_IBM_ASM is not set
+# CONFIG_PHANTOM is not set
+# CONFIG_INTEL_MID_PTI is not set
+# CONFIG_SGI_IOC4 is not set
+# CONFIG_TIFM_CORE is not set
+# CONFIG_ICS932S401 is not set
+# CONFIG_ATMEL_SSC is not set
+# CONFIG_ENCLOSURE_SERVICES is not set
+# CONFIG_HP_ILO is not set
+# CONFIG_APDS9802ALS is not set
+# CONFIG_ISL29003 is not set
+# CONFIG_ISL29020 is not set
+# CONFIG_SENSORS_TSL2550 is not set
+# CONFIG_SENSORS_BH1780 is not set
+# CONFIG_SENSORS_BH1770 is not set
+# CONFIG_SENSORS_APDS990X is not set
+# CONFIG_HMC6352 is not set
+# CONFIG_DS1682 is not set
+# CONFIG_BMP085_I2C is not set
+# CONFIG_PCH_PHUB is not set
+# CONFIG_USB_SWITCH_FSA9480 is not set
+# CONFIG_SRAM is not set
+# CONFIG_C2PORT is not set
+
+#
+# EEPROM support
+#
+# CONFIG_EEPROM_AT24 is not set
+# CONFIG_EEPROM_LEGACY is not set
+# CONFIG_EEPROM_MAX6875 is not set
+# CONFIG_EEPROM_93CX6 is not set
+# CONFIG_CB710_CORE is not set
+
+#
+# Texas Instruments shared transport line discipline
+#
+# CONFIG_SENSORS_LIS3_I2C is not set
+
+#
+# Altera FPGA firmware download module
+#
+# CONFIG_ALTERA_STAPL is not set
+# CONFIG_VMWARE_VMCI is not set
+CONFIG_HAVE_IDE=y
+# CONFIG_IDE is not set
+
+#
+# SCSI device support
+#
+CONFIG_SCSI_MOD=y
+# CONFIG_RAID_ATTRS is not set
+CONFIG_SCSI=y
+CONFIG_SCSI_DMA=y
+# CONFIG_SCSI_TGT is not set
+# CONFIG_SCSI_NETLINK is not set
+CONFIG_SCSI_PROC_FS=y
+
+#
+# SCSI support type (disk, tape, CD-ROM)
+#
+CONFIG_BLK_DEV_SD=y
+# CONFIG_CHR_DEV_ST is not set
+# CONFIG_CHR_DEV_OSST is not set
+CONFIG_BLK_DEV_SR=y
+# CONFIG_BLK_DEV_SR_VENDOR is not set
+CONFIG_CHR_DEV_SG=y
+# CONFIG_CHR_DEV_SCH is not set
+# CONFIG_SCSI_MULTI_LUN is not set
+CONFIG_SCSI_CONSTANTS=y
+CONFIG_SCSI_LOGGING=y
+# CONFIG_SCSI_SCAN_ASYNC is not set
+
+#
+# SCSI Transports
+#
+# CONFIG_SCSI_SPI_ATTRS is not set
+# CONFIG_SCSI_FC_ATTRS is not set
+# CONFIG_SCSI_ISCSI_ATTRS is not set
+CONFIG_SCSI_SAS_ATTRS=y
+CONFIG_SCSI_SAS_LIBSAS=y
+CONFIG_SCSI_SAS_ATA=y
+CONFIG_SCSI_SAS_HOST_SMP=y
+# CONFIG_SCSI_SRP_ATTRS is not set
+CONFIG_SCSI_LOWLEVEL=y
+# CONFIG_ISCSI_TCP is not set
+# CONFIG_ISCSI_BOOT_SYSFS is not set
+# CONFIG_SCSI_CXGB3_ISCSI is not set
+# CONFIG_SCSI_CXGB4_ISCSI is not set
+# CONFIG_SCSI_BNX2_ISCSI is not set
+# CONFIG_SCSI_BNX2X_FCOE is not set
+# CONFIG_BE2ISCSI is not set
+# CONFIG_BLK_DEV_3W_XXXX_RAID is not set
+# CONFIG_SCSI_HPSA is not set
+# CONFIG_SCSI_3W_9XXX is not set
+# CONFIG_SCSI_3W_SAS is not set
+# CONFIG_SCSI_ACARD is not set
+# CONFIG_SCSI_AACRAID is not set
+# CONFIG_SCSI_AIC7XXX is not set
+# CONFIG_SCSI_AIC7XXX_OLD is not set
+# CONFIG_SCSI_AIC79XX is not set
+# CONFIG_SCSI_AIC94XX is not set
+# CONFIG_SCSI_MVSAS is not set
+# CONFIG_SCSI_MVUMI is not set
+# CONFIG_SCSI_DPT_I2O is not set
+# CONFIG_SCSI_ADVANSYS is not set
+# CONFIG_SCSI_ARCMSR is not set
+# CONFIG_MEGARAID_NEWGEN is not set
+# CONFIG_MEGARAID_LEGACY is not set
+# CONFIG_MEGARAID_SAS is not set
+# CONFIG_SCSI_MPT2SAS is not set
+# CONFIG_SCSI_MPT3SAS is not set
+# CONFIG_SCSI_UFSHCD is not set
+# CONFIG_SCSI_HPTIOP is not set
+# CONFIG_VMWARE_PVSCSI is not set
+# CONFIG_LIBFC is not set
+# CONFIG_LIBFCOE is not set
+# CONFIG_FCOE is not set
+# CONFIG_FCOE_FNIC is not set
+# CONFIG_SCSI_DMX3191D is not set
+# CONFIG_SCSI_FUTURE_DOMAIN is not set
+# CONFIG_SCSI_ISCI is not set
+# CONFIG_SCSI_IPS is not set
+# CONFIG_SCSI_INITIO is not set
+# CONFIG_SCSI_INIA100 is not set
+# CONFIG_SCSI_STEX is not set
+# CONFIG_SCSI_SYM53C8XX_2 is not set
+# CONFIG_SCSI_IPR is not set
+# CONFIG_SCSI_QLOGIC_1280 is not set
+# CONFIG_SCSI_QLA_FC is not set
+# CONFIG_SCSI_QLA_ISCSI is not set
+# CONFIG_SCSI_LPFC is not set
+# CONFIG_SCSI_DC395x is not set
+# CONFIG_SCSI_DC390T is not set
+# CONFIG_SCSI_DEBUG is not set
+# CONFIG_SCSI_PMCRAID is not set
+# CONFIG_SCSI_PM8001 is not set
+# CONFIG_SCSI_SRP is not set
+# CONFIG_SCSI_BFA_FC is not set
+# CONFIG_SCSI_CHELSIO_FCOE is not set
+# CONFIG_SCSI_DH is not set
+# CONFIG_SCSI_OSD_INITIATOR is not set
+CONFIG_ATA=y
+# CONFIG_ATA_NONSTANDARD is not set
+CONFIG_ATA_VERBOSE_ERROR=y
+CONFIG_ATA_ACPI=y
+# CONFIG_SATA_ZPODD is not set
+CONFIG_SATA_PMP=y
+
+#
+# Controllers with non-SFF native interface
+#
+CONFIG_SATA_AHCI=y
+# CONFIG_SATA_AHCI_PLATFORM is not set
+# CONFIG_SATA_INIC162X is not set
+# CONFIG_SATA_ACARD_AHCI is not set
+# CONFIG_SATA_SIL24 is not set
+CONFIG_ATA_SFF=y
+
+#
+# SFF controllers with custom DMA interface
+#
+# CONFIG_PDC_ADMA is not set
+# CONFIG_SATA_QSTOR is not set
+# CONFIG_SATA_SX4 is not set
+CONFIG_ATA_BMDMA=y
+
+#
+# SATA SFF controllers with BMDMA
+#
+CONFIG_ATA_PIIX=y
+# CONFIG_SATA_HIGHBANK is not set
+CONFIG_SATA_MV=y
+# CONFIG_SATA_NV is not set
+# CONFIG_SATA_PROMISE is not set
+# CONFIG_SATA_SIL is not set
+# CONFIG_SATA_SIS is not set
+# CONFIG_SATA_SVW is not set
+# CONFIG_SATA_ULI is not set
+# CONFIG_SATA_VIA is not set
+# CONFIG_SATA_VITESSE is not set
+
+#
+# PATA SFF controllers with BMDMA
+#
+# CONFIG_PATA_ALI is not set
+# CONFIG_PATA_AMD is not set
+# CONFIG_PATA_ARTOP is not set
+# CONFIG_PATA_ATIIXP is not set
+# CONFIG_PATA_ATP867X is not set
+# CONFIG_PATA_CMD64X is not set
+# CONFIG_PATA_CS5520 is not set
+# CONFIG_PATA_CS5530 is not set
+# CONFIG_PATA_CS5536 is not set
+# CONFIG_PATA_CYPRESS is not set
+# CONFIG_PATA_EFAR is not set
+# CONFIG_PATA_HPT366 is not set
+# CONFIG_PATA_HPT37X is not set
+# CONFIG_PATA_HPT3X2N is not set
+# CONFIG_PATA_HPT3X3 is not set
+# CONFIG_PATA_IT8213 is not set
+# CONFIG_PATA_IT821X is not set
+# CONFIG_PATA_JMICRON is not set
+# CONFIG_PATA_MARVELL is not set
+# CONFIG_PATA_NETCELL is not set
+# CONFIG_PATA_NINJA32 is not set
+# CONFIG_PATA_NS87415 is not set
+# CONFIG_PATA_OLDPIIX is not set
+# CONFIG_PATA_OPTIDMA is not set
+# CONFIG_PATA_PDC2027X is not set
+# CONFIG_PATA_PDC_OLD is not set
+# CONFIG_PATA_RADISYS is not set
+# CONFIG_PATA_RDC is not set
+# CONFIG_PATA_SC1200 is not set
+CONFIG_PATA_SCH=y
+# CONFIG_PATA_SERVERWORKS is not set
+# CONFIG_PATA_SIL680 is not set
+# CONFIG_PATA_SIS is not set
+# CONFIG_PATA_TOSHIBA is not set
+# CONFIG_PATA_TRIFLEX is not set
+# CONFIG_PATA_VIA is not set
+# CONFIG_PATA_WINBOND is not set
+
+#
+# PIO-only SFF controllers
+#
+# CONFIG_PATA_CMD640_PCI is not set
+# CONFIG_PATA_MPIIX is not set
+# CONFIG_PATA_NS87410 is not set
+# CONFIG_PATA_OPTI is not set
+# CONFIG_PATA_PLATFORM is not set
+# CONFIG_PATA_RZ1000 is not set
+
+#
+# Generic fallback / legacy drivers
+#
+# CONFIG_PATA_ACPI is not set
+# CONFIG_ATA_GENERIC is not set
+# CONFIG_PATA_LEGACY is not set
+CONFIG_MD=y
+CONFIG_BLK_DEV_MD=y
+CONFIG_MD_AUTODETECT=y
+# CONFIG_MD_LINEAR is not set
+CONFIG_MD_RAID0=y
+CONFIG_MD_RAID1=y
+# CONFIG_MD_RAID10 is not set
+CONFIG_MD_RAID456=y
+# CONFIG_MD_MULTIPATH is not set
+# CONFIG_MD_FAULTY is not set
+# CONFIG_BCACHE is not set
+CONFIG_BLK_DEV_DM=y
+# CONFIG_DM_DEBUG is not set
+CONFIG_DM_CRYPT=y
+# CONFIG_DM_SNAPSHOT is not set
+# CONFIG_DM_THIN_PROVISIONING is not set
+# CONFIG_DM_CACHE is not set
+CONFIG_DM_MIRROR=y
+# CONFIG_DM_RAID is not set
+# CONFIG_DM_LOG_USERSPACE is not set
+CONFIG_DM_ZERO=y
+# CONFIG_DM_MULTIPATH is not set
+# CONFIG_DM_DELAY is not set
+# CONFIG_DM_UEVENT is not set
+# CONFIG_DM_FLAKEY is not set
+# CONFIG_DM_VERITY is not set
+# CONFIG_TARGET_CORE is not set
+# CONFIG_FUSION is not set
+
+#
+# IEEE 1394 (FireWire) support
+#
+# CONFIG_FIREWIRE is not set
+# CONFIG_FIREWIRE_NOSY is not set
+# CONFIG_I2O is not set
+# CONFIG_MACINTOSH_DRIVERS is not set
+CONFIG_NETDEVICES=y
+CONFIG_NET_CORE=y
+CONFIG_BONDING=m
+# CONFIG_DUMMY is not set
+# CONFIG_EQUALIZER is not set
+# CONFIG_NET_FC is not set
+# CONFIG_MII is not set
+# CONFIG_IFB is not set
+# CONFIG_NET_TEAM is not set
+# CONFIG_MACVLAN is not set
+# CONFIG_VXLAN is not set
+# CONFIG_NETCONSOLE is not set
+# CONFIG_NETPOLL is not set
+# CONFIG_NET_POLL_CONTROLLER is not set
+# CONFIG_TUN is not set
+# CONFIG_VETH is not set
+# CONFIG_ARCNET is not set
+
+#
+# CAIF transport drivers
+#
+
+#
+# Distributed Switch Architecture drivers
+#
+# CONFIG_NET_DSA_MV88E6XXX is not set
+# CONFIG_NET_DSA_MV88E6060 is not set
+# CONFIG_NET_DSA_MV88E6XXX_NEED_PPU is not set
+# CONFIG_NET_DSA_MV88E6131 is not set
+# CONFIG_NET_DSA_MV88E6123_61_65 is not set
+CONFIG_ETHERNET=y
+CONFIG_NET_VENDOR_3COM=y
+# CONFIG_VORTEX is not set
+# CONFIG_TYPHOON is not set
+CONFIG_NET_VENDOR_ADAPTEC=y
+# CONFIG_ADAPTEC_STARFIRE is not set
+CONFIG_NET_VENDOR_ALTEON=y
+# CONFIG_ACENIC is not set
+CONFIG_NET_VENDOR_AMD=y
+# CONFIG_AMD8111_ETH is not set
+# CONFIG_PCNET32 is not set
+CONFIG_NET_VENDOR_ATHEROS=y
+# CONFIG_ATL2 is not set
+# CONFIG_ATL1 is not set
+# CONFIG_ATL1E is not set
+# CONFIG_ATL1C is not set
+# CONFIG_ALX is not set
+CONFIG_NET_CADENCE=y
+# CONFIG_ARM_AT91_ETHER is not set
+# CONFIG_MACB is not set
+CONFIG_NET_VENDOR_BROADCOM=y
+# CONFIG_B44 is not set
+# CONFIG_BNX2 is not set
+# CONFIG_CNIC is not set
+# CONFIG_TIGON3 is not set
+# CONFIG_BNX2X is not set
+CONFIG_NET_VENDOR_BROCADE=y
+# CONFIG_BNA is not set
+# CONFIG_NET_CALXEDA_XGMAC is not set
+CONFIG_NET_VENDOR_CHELSIO=y
+# CONFIG_CHELSIO_T1 is not set
+# CONFIG_CHELSIO_T3 is not set
+# CONFIG_CHELSIO_T4 is not set
+# CONFIG_CHELSIO_T4VF is not set
+CONFIG_NET_VENDOR_CISCO=y
+# CONFIG_ENIC is not set
+# CONFIG_DNET is not set
+CONFIG_NET_VENDOR_DEC=y
+# CONFIG_NET_TULIP is not set
+CONFIG_NET_VENDOR_DLINK=y
+# CONFIG_DL2K is not set
+# CONFIG_SUNDANCE is not set
+CONFIG_NET_VENDOR_EMULEX=y
+# CONFIG_BE2NET is not set
+CONFIG_NET_VENDOR_EXAR=y
+# CONFIG_S2IO is not set
+# CONFIG_VXGE is not set
+CONFIG_NET_VENDOR_HP=y
+# CONFIG_HP100 is not set
+CONFIG_NET_VENDOR_INTEL=y
+# CONFIG_E100 is not set
+CONFIG_E1000=y
+CONFIG_E1000E=m
+CONFIG_IGB=y
+CONFIG_IGB_HWMON=y
+# CONFIG_IGBVF is not set
+# CONFIG_IXGB is not set
+# CONFIG_IXGBE is not set
+# CONFIG_IXGBEVF is not set
+CONFIG_NET_VENDOR_I825XX=y
+# CONFIG_IP1000 is not set
+# CONFIG_JME is not set
+CONFIG_NET_VENDOR_MARVELL=y
+# CONFIG_MVMDIO is not set
+# CONFIG_SKGE is not set
+# CONFIG_SKY2 is not set
+CONFIG_NET_VENDOR_MELLANOX=y
+# CONFIG_MLX4_EN is not set
+# CONFIG_MLX4_CORE is not set
+CONFIG_NET_VENDOR_MICREL=y
+# CONFIG_KS8851_MLL is not set
+# CONFIG_KSZ884X_PCI is not set
+CONFIG_NET_VENDOR_MYRI=y
+# CONFIG_MYRI10GE is not set
+# CONFIG_FEALNX is not set
+CONFIG_NET_VENDOR_NATSEMI=y
+# CONFIG_NATSEMI is not set
+# CONFIG_NS83820 is not set
+CONFIG_NET_VENDOR_8390=y
+# CONFIG_NE2K_PCI is not set
+CONFIG_NET_VENDOR_NVIDIA=y
+# CONFIG_FORCEDETH is not set
+CONFIG_NET_VENDOR_OKI=y
+# CONFIG_PCH_GBE is not set
+# CONFIG_ETHOC is not set
+CONFIG_NET_PACKET_ENGINE=y
+# CONFIG_HAMACHI is not set
+# CONFIG_YELLOWFIN is not set
+CONFIG_NET_VENDOR_QLOGIC=y
+# CONFIG_QLA3XXX is not set
+# CONFIG_QLCNIC is not set
+# CONFIG_QLGE is not set
+# CONFIG_NETXEN_NIC is not set
+CONFIG_NET_VENDOR_REALTEK=y
+# CONFIG_8139CP is not set
+# CONFIG_8139TOO is not set
+# CONFIG_R8169 is not set
+CONFIG_NET_VENDOR_RDC=y
+# CONFIG_R6040 is not set
+CONFIG_NET_VENDOR_SEEQ=y
+CONFIG_NET_VENDOR_SILAN=y
+# CONFIG_SC92031 is not set
+CONFIG_NET_VENDOR_SIS=y
+# CONFIG_SIS900 is not set
+# CONFIG_SIS190 is not set
+# CONFIG_SFC is not set
+CONFIG_NET_VENDOR_SMSC=y
+# CONFIG_EPIC100 is not set
+# CONFIG_SMSC9420 is not set
+CONFIG_NET_VENDOR_STMICRO=y
+# CONFIG_STMMAC_ETH is not set
+CONFIG_NET_VENDOR_SUN=y
+# CONFIG_HAPPYMEAL is not set
+# CONFIG_SUNGEM is not set
+# CONFIG_CASSINI is not set
+# CONFIG_NIU is not set
+CONFIG_NET_VENDOR_TEHUTI=y
+# CONFIG_TEHUTI is not set
+CONFIG_NET_VENDOR_TI=y
+# CONFIG_TLAN is not set
+CONFIG_NET_VENDOR_VIA=y
+# CONFIG_VIA_RHINE is not set
+# CONFIG_VIA_VELOCITY is not set
+CONFIG_NET_VENDOR_WIZNET=y
+# CONFIG_WIZNET_W5100 is not set
+# CONFIG_WIZNET_W5300 is not set
+# CONFIG_FDDI is not set
+# CONFIG_HIPPI is not set
+# CONFIG_NET_SB1000 is not set
+CONFIG_PHYLIB=y
+
+#
+# MII PHY device drivers
+#
+# CONFIG_AT803X_PHY is not set
+# CONFIG_AMD_PHY is not set
+CONFIG_MARVELL_PHY=y
+CONFIG_DAVICOM_PHY=y
+CONFIG_QSEMI_PHY=y
+CONFIG_LXT_PHY=y
+CONFIG_CICADA_PHY=y
+CONFIG_VITESSE_PHY=y
+CONFIG_SMSC_PHY=y
+CONFIG_BROADCOM_PHY=y
+# CONFIG_BCM87XX_PHY is not set
+CONFIG_ICPLUS_PHY=y
+CONFIG_REALTEK_PHY=y
+CONFIG_NATIONAL_PHY=y
+CONFIG_STE10XP=y
+CONFIG_LSI_ET1011C_PHY=y
+# CONFIG_MICREL_PHY is not set
+CONFIG_FIXED_PHY=y
+CONFIG_MDIO_BITBANG=y
+# CONFIG_PPP is not set
+# CONFIG_SLIP is not set
+
+#
+# USB Network Adapters
+#
+# CONFIG_USB_CATC is not set
+# CONFIG_USB_KAWETH is not set
+# CONFIG_USB_PEGASUS is not set
+# CONFIG_USB_RTL8150 is not set
+# CONFIG_USB_RTL8152 is not set
+# CONFIG_USB_USBNET is not set
+# CONFIG_USB_HSO is not set
+# CONFIG_USB_IPHETH is not set
+# CONFIG_WLAN is not set
+
+#
+# Enable WiMAX (Networking options) to see the WiMAX drivers
+#
+# CONFIG_WAN is not set
+# CONFIG_VMXNET3 is not set
+# CONFIG_ISDN is not set
+
+#
+# Input device support
+#
+CONFIG_INPUT=y
+# CONFIG_INPUT_FF_MEMLESS is not set
+# CONFIG_INPUT_POLLDEV is not set
+# CONFIG_INPUT_SPARSEKMAP is not set
+# CONFIG_INPUT_MATRIXKMAP is not set
+
+#
+# Userland interfaces
+#
+CONFIG_INPUT_MOUSEDEV=y
+CONFIG_INPUT_MOUSEDEV_PSAUX=y
+CONFIG_INPUT_MOUSEDEV_SCREEN_X=1024
+CONFIG_INPUT_MOUSEDEV_SCREEN_Y=768
+# CONFIG_INPUT_JOYDEV is not set
+CONFIG_INPUT_EVDEV=y
+# CONFIG_INPUT_EVBUG is not set
+
+#
+# Input Device Drivers
+#
+CONFIG_INPUT_KEYBOARD=y
+# CONFIG_KEYBOARD_ADP5588 is not set
+# CONFIG_KEYBOARD_ADP5589 is not set
+CONFIG_KEYBOARD_ATKBD=y
+# CONFIG_KEYBOARD_QT1070 is not set
+# CONFIG_KEYBOARD_QT2160 is not set
+# CONFIG_KEYBOARD_LKKBD is not set
+# CONFIG_KEYBOARD_TCA6416 is not set
+# CONFIG_KEYBOARD_TCA8418 is not set
+# CONFIG_KEYBOARD_LM8333 is not set
+# CONFIG_KEYBOARD_MAX7359 is not set
+# CONFIG_KEYBOARD_MCS is not set
+# CONFIG_KEYBOARD_MPR121 is not set
+# CONFIG_KEYBOARD_NEWTON is not set
+# CONFIG_KEYBOARD_OPENCORES is not set
+# CONFIG_KEYBOARD_STOWAWAY is not set
+# CONFIG_KEYBOARD_SUNKBD is not set
+# CONFIG_KEYBOARD_XTKBD is not set
+CONFIG_INPUT_MOUSE=y
+CONFIG_MOUSE_PS2=y
+CONFIG_MOUSE_PS2_ALPS=y
+CONFIG_MOUSE_PS2_LOGIPS2PP=y
+CONFIG_MOUSE_PS2_SYNAPTICS=y
+CONFIG_MOUSE_PS2_CYPRESS=y
+CONFIG_MOUSE_PS2_LIFEBOOK=y
+CONFIG_MOUSE_PS2_TRACKPOINT=y
+CONFIG_MOUSE_PS2_ELANTECH=y
+CONFIG_MOUSE_PS2_SENTELIC=y
+# CONFIG_MOUSE_PS2_TOUCHKIT is not set
+# CONFIG_MOUSE_SERIAL is not set
+# CONFIG_MOUSE_APPLETOUCH is not set
+# CONFIG_MOUSE_BCM5974 is not set
+# CONFIG_MOUSE_CYAPA is not set
+# CONFIG_MOUSE_VSXXXAA is not set
+# CONFIG_MOUSE_SYNAPTICS_I2C is not set
+# CONFIG_MOUSE_SYNAPTICS_USB is not set
+CONFIG_INPUT_JOYSTICK=y
+# CONFIG_JOYSTICK_ANALOG is not set
+# CONFIG_JOYSTICK_A3D is not set
+# CONFIG_JOYSTICK_ADI is not set
+# CONFIG_JOYSTICK_COBRA is not set
+# CONFIG_JOYSTICK_GF2K is not set
+# CONFIG_JOYSTICK_GRIP is not set
+# CONFIG_JOYSTICK_GRIP_MP is not set
+# CONFIG_JOYSTICK_GUILLEMOT is not set
+# CONFIG_JOYSTICK_INTERACT is not set
+# CONFIG_JOYSTICK_SIDEWINDER is not set
+# CONFIG_JOYSTICK_TMDC is not set
+# CONFIG_JOYSTICK_IFORCE is not set
+# CONFIG_JOYSTICK_WARRIOR is not set
+# CONFIG_JOYSTICK_MAGELLAN is not set
+# CONFIG_JOYSTICK_SPACEORB is not set
+# CONFIG_JOYSTICK_SPACEBALL is not set
+# CONFIG_JOYSTICK_STINGER is not set
+# CONFIG_JOYSTICK_TWIDJOY is not set
+# CONFIG_JOYSTICK_ZHENHUA is not set
+# CONFIG_JOYSTICK_AS5011 is not set
+# CONFIG_JOYSTICK_JOYDUMP is not set
+# CONFIG_JOYSTICK_XPAD is not set
+CONFIG_INPUT_TABLET=y
+# CONFIG_TABLET_USB_ACECAD is not set
+# CONFIG_TABLET_USB_AIPTEK is not set
+# CONFIG_TABLET_USB_GTCO is not set
+# CONFIG_TABLET_USB_HANWANG is not set
+# CONFIG_TABLET_USB_KBTAB is not set
+# CONFIG_TABLET_USB_WACOM is not set
+CONFIG_INPUT_TOUCHSCREEN=y
+# CONFIG_TOUCHSCREEN_AD7879 is not set
+# CONFIG_TOUCHSCREEN_ATMEL_MXT is not set
+# CONFIG_TOUCHSCREEN_BU21013 is not set
+# CONFIG_TOUCHSCREEN_CYTTSP_CORE is not set
+# CONFIG_TOUCHSCREEN_DYNAPRO is not set
+# CONFIG_TOUCHSCREEN_HAMPSHIRE is not set
+# CONFIG_TOUCHSCREEN_EETI is not set
+# CONFIG_TOUCHSCREEN_FUJITSU is not set
+# CONFIG_TOUCHSCREEN_ILI210X is not set
+# CONFIG_TOUCHSCREEN_GUNZE is not set
+# CONFIG_TOUCHSCREEN_ELO is not set
+# CONFIG_TOUCHSCREEN_WACOM_W8001 is not set
+# CONFIG_TOUCHSCREEN_WACOM_I2C is not set
+# CONFIG_TOUCHSCREEN_MAX11801 is not set
+# CONFIG_TOUCHSCREEN_MCS5000 is not set
+# CONFIG_TOUCHSCREEN_MMS114 is not set
+# CONFIG_TOUCHSCREEN_MTOUCH is not set
+# CONFIG_TOUCHSCREEN_INEXIO is not set
+# CONFIG_TOUCHSCREEN_MK712 is not set
+# CONFIG_TOUCHSCREEN_PENMOUNT is not set
+# CONFIG_TOUCHSCREEN_EDT_FT5X06 is not set
+# CONFIG_TOUCHSCREEN_TOUCHRIGHT is not set
+# CONFIG_TOUCHSCREEN_TOUCHWIN is not set
+# CONFIG_TOUCHSCREEN_PIXCIR is not set
+# CONFIG_TOUCHSCREEN_USB_COMPOSITE is not set
+# CONFIG_TOUCHSCREEN_TOUCHIT213 is not set
+# CONFIG_TOUCHSCREEN_TSC_SERIO is not set
+# CONFIG_TOUCHSCREEN_TSC2007 is not set
+# CONFIG_TOUCHSCREEN_ST1232 is not set
+# CONFIG_TOUCHSCREEN_TPS6507X is not set
+CONFIG_INPUT_MISC=y
+# CONFIG_INPUT_AD714X is not set
+# CONFIG_INPUT_BMA150 is not set
+# CONFIG_INPUT_PCSPKR is not set
+# CONFIG_INPUT_MMA8450 is not set
+# CONFIG_INPUT_MPU3050 is not set
+# CONFIG_INPUT_ATLAS_BTNS is not set
+# CONFIG_INPUT_ATI_REMOTE2 is not set
+# CONFIG_INPUT_KEYSPAN_REMOTE is not set
+# CONFIG_INPUT_KXTJ9 is not set
+# CONFIG_INPUT_POWERMATE is not set
+# CONFIG_INPUT_YEALINK is not set
+# CONFIG_INPUT_CM109 is not set
+CONFIG_INPUT_UINPUT=y
+# CONFIG_INPUT_PCF8574 is not set
+# CONFIG_INPUT_ADXL34X is not set
+# CONFIG_INPUT_CMA3000 is not set
+
+#
+# Hardware I/O ports
+#
+CONFIG_SERIO=y
+CONFIG_SERIO_I8042=y
+CONFIG_SERIO_SERPORT=y
+# CONFIG_SERIO_CT82C710 is not set
+# CONFIG_SERIO_PCIPS2 is not set
+CONFIG_SERIO_LIBPS2=y
+# CONFIG_SERIO_RAW is not set
+# CONFIG_SERIO_ALTERA_PS2 is not set
+# CONFIG_SERIO_PS2MULT is not set
+# CONFIG_SERIO_ARC_PS2 is not set
+# CONFIG_GAMEPORT is not set
+
+#
+# Character devices
+#
+CONFIG_TTY=y
+CONFIG_VT=y
+CONFIG_CONSOLE_TRANSLATIONS=y
+CONFIG_VT_CONSOLE=y
+CONFIG_VT_CONSOLE_SLEEP=y
+CONFIG_HW_CONSOLE=y
+CONFIG_VT_HW_CONSOLE_BINDING=y
+CONFIG_UNIX98_PTYS=y
+CONFIG_DEVPTS_MULTIPLE_INSTANCES=y
+CONFIG_LEGACY_PTYS=y
+CONFIG_LEGACY_PTY_COUNT=0
+CONFIG_SERIAL_NONSTANDARD=y
+# CONFIG_ROCKETPORT is not set
+# CONFIG_CYCLADES is not set
+# CONFIG_MOXA_INTELLIO is not set
+# CONFIG_MOXA_SMARTIO is not set
+# CONFIG_SYNCLINKMP is not set
+# CONFIG_SYNCLINK_GT is not set
+# CONFIG_NOZOMI is not set
+# CONFIG_ISI is not set
+# CONFIG_N_HDLC is not set
+# CONFIG_N_GSM is not set
+# CONFIG_TRACE_SINK is not set
+# CONFIG_DEVKMEM is not set
+CONFIG_STALDRV=y
+
+#
+# Serial drivers
+#
+CONFIG_SERIAL_8250=y
+CONFIG_SERIAL_8250_DEPRECATED_OPTIONS=y
+CONFIG_SERIAL_8250_PNP=y
+CONFIG_SERIAL_8250_CONSOLE=y
+CONFIG_FIX_EARLYCON_MEM=y
+CONFIG_SERIAL_8250_PCI=y
+CONFIG_SERIAL_8250_NR_UARTS=48
+CONFIG_SERIAL_8250_RUNTIME_UARTS=32
+CONFIG_SERIAL_8250_EXTENDED=y
+CONFIG_SERIAL_8250_MANY_PORTS=y
+CONFIG_SERIAL_8250_SHARE_IRQ=y
+# CONFIG_SERIAL_8250_DETECT_IRQ is not set
+CONFIG_SERIAL_8250_RSA=y
+# CONFIG_SERIAL_8250_DW is not set
+
+#
+# Non-8250 serial port support
+#
+# CONFIG_SERIAL_MFD_HSU is not set
+CONFIG_SERIAL_CORE=y
+CONFIG_SERIAL_CORE_CONSOLE=y
+# CONFIG_SERIAL_JSM is not set
+# CONFIG_SERIAL_SCCNXP is not set
+# CONFIG_SERIAL_TIMBERDALE is not set
+# CONFIG_SERIAL_ALTERA_JTAGUART is not set
+# CONFIG_SERIAL_ALTERA_UART is not set
+# CONFIG_SERIAL_PCH_UART is not set
+# CONFIG_SERIAL_ARC is not set
+# CONFIG_SERIAL_RP2 is not set
+CONFIG_TTY_PRINTK=y
+# CONFIG_IPMI_HANDLER is not set
+CONFIG_HW_RANDOM=y
+# CONFIG_HW_RANDOM_TIMERIOMEM is not set
+CONFIG_HW_RANDOM_INTEL=y
+CONFIG_HW_RANDOM_AMD=y
+CONFIG_HW_RANDOM_VIA=y
+# CONFIG_NVRAM is not set
+# CONFIG_R3964 is not set
+# CONFIG_APPLICOM is not set
+# CONFIG_MWAVE is not set
+# CONFIG_RAW_DRIVER is not set
+CONFIG_HPET=y
+CONFIG_HPET_MMAP=y
+# CONFIG_HANGCHECK_TIMER is not set
+# CONFIG_TCG_TPM is not set
+# CONFIG_TELCLOCK is not set
+CONFIG_DEVPORT=y
+CONFIG_I2C=y
+CONFIG_I2C_BOARDINFO=y
+CONFIG_I2C_COMPAT=y
+CONFIG_I2C_CHARDEV=y
+CONFIG_I2C_MUX=y
+
+#
+# Multiplexer I2C Chip support
+#
+CONFIG_I2C_MUX_PCA9541=y
+CONFIG_I2C_MUX_PCA954x=y
+CONFIG_I2C_HELPER_AUTO=y
+CONFIG_I2C_SMBUS=y
+CONFIG_I2C_ALGOBIT=y
+CONFIG_I2C_ALGOPCA=y
+
+#
+# I2C Hardware Bus support
+#
+
+#
+# PC SMBus host controller drivers
+#
+CONFIG_I2C_ALI1535=y
+CONFIG_I2C_ALI1563=y
+CONFIG_I2C_ALI15X3=y
+CONFIG_I2C_AMD756=y
+CONFIG_I2C_AMD756_S4882=y
+CONFIG_I2C_AMD8111=y
+CONFIG_I2C_I801=y
+CONFIG_I2C_ISCH=y
+# CONFIG_I2C_ISMT is not set
+CONFIG_I2C_PIIX4=y
+CONFIG_I2C_NFORCE2=y
+CONFIG_I2C_NFORCE2_S4985=y
+CONFIG_I2C_SIS5595=y
+CONFIG_I2C_SIS630=y
+CONFIG_I2C_SIS96X=y
+CONFIG_I2C_VIA=y
+CONFIG_I2C_VIAPRO=y
+
+#
+# ACPI drivers
+#
+CONFIG_I2C_SCMI=y
+
+#
+# I2C system bus drivers (mostly embedded / system-on-chip)
+#
+# CONFIG_I2C_DESIGNWARE_PCI is not set
+CONFIG_I2C_EG20T=y
+CONFIG_I2C_INTEL_MID=y
+CONFIG_I2C_OCORES=y
+CONFIG_I2C_PCA_PLATFORM=y
+# CONFIG_I2C_PXA_PCI is not set
+CONFIG_I2C_SIMTEC=y
+CONFIG_I2C_XILINX=y
+
+#
+# External I2C/SMBus adapter drivers
+#
+CONFIG_I2C_DIOLAN_U2C=m
+CONFIG_I2C_PARPORT_LIGHT=y
+CONFIG_I2C_TAOS_EVM=y
+CONFIG_I2C_TINY_USB=m
+
+#
+# Other I2C/SMBus bus drivers
+#
+# CONFIG_I2C_STUB is not set
+CONFIG_I2C_DEBUG_CORE=y
+CONFIG_I2C_DEBUG_ALGO=y
+CONFIG_I2C_DEBUG_BUS=y
+# CONFIG_SPI is not set
+
+#
+# Qualcomm MSM SSBI bus support
+#
+# CONFIG_SSBI is not set
+# CONFIG_HSI is not set
+
+#
+# PPS support
+#
+CONFIG_PPS=y
+# CONFIG_PPS_DEBUG is not set
+
+#
+# PPS clients support
+#
+# CONFIG_PPS_CLIENT_KTIMER is not set
+# CONFIG_PPS_CLIENT_LDISC is not set
+# CONFIG_PPS_CLIENT_GPIO is not set
+
+#
+# PPS generators support
+#
+
+#
+# PTP clock support
+#
+CONFIG_PTP_1588_CLOCK=y
+
+#
+# Enable PHYLIB and NETWORK_PHY_TIMESTAMPING to see the additional clocks.
+#
+# CONFIG_PTP_1588_CLOCK_PCH is not set
+CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
+CONFIG_GPIO_DEVRES=y
+# CONFIG_GPIOLIB is not set
+# CONFIG_W1 is not set
+CONFIG_POWER_SUPPLY=y
+# CONFIG_POWER_SUPPLY_DEBUG is not set
+# CONFIG_PDA_POWER is not set
+# CONFIG_TEST_POWER is not set
+# CONFIG_BATTERY_DS2780 is not set
+# CONFIG_BATTERY_DS2781 is not set
+# CONFIG_BATTERY_DS2782 is not set
+# CONFIG_BATTERY_SBS is not set
+# CONFIG_BATTERY_BQ27x00 is not set
+# CONFIG_BATTERY_MAX17040 is not set
+# CONFIG_BATTERY_MAX17042 is not set
+# CONFIG_CHARGER_MAX8903 is not set
+# CONFIG_CHARGER_LP8727 is not set
+# CONFIG_CHARGER_BQ2415X is not set
+# CONFIG_CHARGER_SMB347 is not set
+# CONFIG_BATTERY_GOLDFISH is not set
+# CONFIG_POWER_RESET is not set
+# CONFIG_POWER_AVS is not set
+CONFIG_HWMON=y
+# CONFIG_HWMON_VID is not set
+# CONFIG_HWMON_DEBUG_CHIP is not set
+
+#
+# Native drivers
+#
+# CONFIG_SENSORS_ABITUGURU is not set
+# CONFIG_SENSORS_ABITUGURU3 is not set
+# CONFIG_SENSORS_AD7414 is not set
+# CONFIG_SENSORS_AD7418 is not set
+# CONFIG_SENSORS_ADM1021 is not set
+# CONFIG_SENSORS_ADM1025 is not set
+# CONFIG_SENSORS_ADM1026 is not set
+# CONFIG_SENSORS_ADM1029 is not set
+# CONFIG_SENSORS_ADM1031 is not set
+# CONFIG_SENSORS_ADM9240 is not set
+# CONFIG_SENSORS_ADT7410 is not set
+# CONFIG_SENSORS_ADT7411 is not set
+# CONFIG_SENSORS_ADT7462 is not set
+# CONFIG_SENSORS_ADT7470 is not set
+# CONFIG_SENSORS_ADT7475 is not set
+# CONFIG_SENSORS_ASC7621 is not set
+# CONFIG_SENSORS_K8TEMP is not set
+# CONFIG_SENSORS_K10TEMP is not set
+# CONFIG_SENSORS_FAM15H_POWER is not set
+# CONFIG_SENSORS_ASB100 is not set
+# CONFIG_SENSORS_ATXP1 is not set
+# CONFIG_SENSORS_DS620 is not set
+# CONFIG_SENSORS_DS1621 is not set
+# CONFIG_SENSORS_I5K_AMB is not set
+# CONFIG_SENSORS_F71805F is not set
+# CONFIG_SENSORS_F71882FG is not set
+# CONFIG_SENSORS_F75375S is not set
+# CONFIG_SENSORS_FSCHMD is not set
+# CONFIG_SENSORS_G760A is not set
+# CONFIG_SENSORS_GL518SM is not set
+# CONFIG_SENSORS_GL520SM is not set
+# CONFIG_SENSORS_HIH6130 is not set
+# CONFIG_SENSORS_CORETEMP is not set
+# CONFIG_SENSORS_IT87 is not set
+# CONFIG_SENSORS_JC42 is not set
+# CONFIG_SENSORS_LINEAGE is not set
+# CONFIG_SENSORS_LM63 is not set
+# CONFIG_SENSORS_LM73 is not set
+# CONFIG_SENSORS_LM75 is not set
+# CONFIG_SENSORS_LM77 is not set
+# CONFIG_SENSORS_LM78 is not set
+# CONFIG_SENSORS_LM80 is not set
+# CONFIG_SENSORS_LM83 is not set
+# CONFIG_SENSORS_LM85 is not set
+# CONFIG_SENSORS_LM87 is not set
+# CONFIG_SENSORS_LM90 is not set
+# CONFIG_SENSORS_LM92 is not set
+# CONFIG_SENSORS_LM93 is not set
+# CONFIG_SENSORS_LTC4151 is not set
+# CONFIG_SENSORS_LTC4215 is not set
+# CONFIG_SENSORS_LTC4245 is not set
+# CONFIG_SENSORS_LTC4261 is not set
+# CONFIG_SENSORS_LM95234 is not set
+# CONFIG_SENSORS_LM95241 is not set
+# CONFIG_SENSORS_LM95245 is not set
+# CONFIG_SENSORS_MAX16065 is not set
+# CONFIG_SENSORS_MAX1619 is not set
+# CONFIG_SENSORS_MAX1668 is not set
+# CONFIG_SENSORS_MAX197 is not set
+# CONFIG_SENSORS_MAX6639 is not set
+# CONFIG_SENSORS_MAX6642 is not set
+# CONFIG_SENSORS_MAX6650 is not set
+# CONFIG_SENSORS_MAX6697 is not set
+# CONFIG_SENSORS_MCP3021 is not set
+# CONFIG_SENSORS_NCT6775 is not set
+# CONFIG_SENSORS_NTC_THERMISTOR is not set
+# CONFIG_SENSORS_PC87360 is not set
+# CONFIG_SENSORS_PC87427 is not set
+# CONFIG_SENSORS_PCF8591 is not set
+# CONFIG_PMBUS is not set
+# CONFIG_SENSORS_SHT21 is not set
+# CONFIG_SENSORS_SIS5595 is not set
+# CONFIG_SENSORS_SMM665 is not set
+# CONFIG_SENSORS_DME1737 is not set
+# CONFIG_SENSORS_EMC1403 is not set
+# CONFIG_SENSORS_EMC2103 is not set
+# CONFIG_SENSORS_EMC6W201 is not set
+# CONFIG_SENSORS_SMSC47M1 is not set
+# CONFIG_SENSORS_SMSC47M192 is not set
+# CONFIG_SENSORS_SMSC47B397 is not set
+# CONFIG_SENSORS_SCH56XX_COMMON is not set
+# CONFIG_SENSORS_ADS1015 is not set
+# CONFIG_SENSORS_ADS7828 is not set
+# CONFIG_SENSORS_AMC6821 is not set
+# CONFIG_SENSORS_INA209 is not set
+# CONFIG_SENSORS_INA2XX is not set
+# CONFIG_SENSORS_THMC50 is not set
+# CONFIG_SENSORS_TMP102 is not set
+# CONFIG_SENSORS_TMP401 is not set
+# CONFIG_SENSORS_TMP421 is not set
+# CONFIG_SENSORS_VIA_CPUTEMP is not set
+# CONFIG_SENSORS_VIA686A is not set
+# CONFIG_SENSORS_VT1211 is not set
+# CONFIG_SENSORS_VT8231 is not set
+# CONFIG_SENSORS_W83781D is not set
+# CONFIG_SENSORS_W83791D is not set
+# CONFIG_SENSORS_W83792D is not set
+# CONFIG_SENSORS_W83793 is not set
+# CONFIG_SENSORS_W83795 is not set
+# CONFIG_SENSORS_W83L785TS is not set
+# CONFIG_SENSORS_W83L786NG is not set
+# CONFIG_SENSORS_W83627HF is not set
+# CONFIG_SENSORS_W83627EHF is not set
+# CONFIG_SENSORS_APPLESMC is not set
+
+#
+# ACPI drivers
+#
+# CONFIG_SENSORS_ACPI_POWER is not set
+# CONFIG_SENSORS_ATK0110 is not set
+CONFIG_THERMAL=y
+CONFIG_THERMAL_HWMON=y
+CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE=y
+# CONFIG_THERMAL_DEFAULT_GOV_FAIR_SHARE is not set
+# CONFIG_THERMAL_DEFAULT_GOV_USER_SPACE is not set
+# CONFIG_THERMAL_GOV_FAIR_SHARE is not set
+CONFIG_THERMAL_GOV_STEP_WISE=y
+# CONFIG_THERMAL_GOV_USER_SPACE is not set
+# CONFIG_CPU_THERMAL is not set
+# CONFIG_THERMAL_EMULATION is not set
+# CONFIG_INTEL_POWERCLAMP is not set
+# CONFIG_WATCHDOG is not set
+CONFIG_SSB_POSSIBLE=y
+
+#
+# Sonics Silicon Backplane
+#
+# CONFIG_SSB is not set
+CONFIG_BCMA_POSSIBLE=y
+
+#
+# Broadcom specific AMBA
+#
+# CONFIG_BCMA is not set
+
+#
+# Multifunction device drivers
+#
+CONFIG_MFD_CORE=y
+# CONFIG_MFD_CS5535 is not set
+# CONFIG_MFD_AS3711 is not set
+# CONFIG_PMIC_ADP5520 is not set
+# CONFIG_MFD_CROS_EC is not set
+# CONFIG_PMIC_DA903X is not set
+# CONFIG_MFD_DA9052_I2C is not set
+# CONFIG_MFD_DA9055 is not set
+# CONFIG_MFD_MC13XXX_I2C is not set
+# CONFIG_HTC_PASIC3 is not set
+# CONFIG_LPC_ICH is not set
+CONFIG_LPC_SCH=y
+# CONFIG_MFD_JANZ_CMODIO is not set
+# CONFIG_MFD_88PM800 is not set
+# CONFIG_MFD_88PM805 is not set
+# CONFIG_MFD_88PM860X is not set
+# CONFIG_MFD_MAX77686 is not set
+# CONFIG_MFD_MAX77693 is not set
+# CONFIG_MFD_MAX8907 is not set
+# CONFIG_MFD_MAX8925 is not set
+# CONFIG_MFD_MAX8997 is not set
+# CONFIG_MFD_MAX8998 is not set
+# CONFIG_MFD_VIPERBOARD is not set
+# CONFIG_MFD_RETU is not set
+# CONFIG_MFD_PCF50633 is not set
+# CONFIG_MFD_RDC321X is not set
+# CONFIG_MFD_RTSX_PCI is not set
+# CONFIG_MFD_RC5T583 is not set
+# CONFIG_MFD_SEC_CORE is not set
+# CONFIG_MFD_SI476X_CORE is not set
+# CONFIG_MFD_SM501 is not set
+# CONFIG_MFD_SMSC is not set
+# CONFIG_ABX500_CORE is not set
+# CONFIG_MFD_STMPE is not set
+# CONFIG_MFD_SYSCON is not set
+# CONFIG_MFD_TI_AM335X_TSCADC is not set
+# CONFIG_MFD_LP8788 is not set
+# CONFIG_MFD_PALMAS is not set
+# CONFIG_TPS6105X is not set
+# CONFIG_TPS6507X is not set
+# CONFIG_MFD_TPS65090 is not set
+# CONFIG_MFD_TPS65217 is not set
+# CONFIG_MFD_TPS6586X is not set
+# CONFIG_MFD_TPS80031 is not set
+# CONFIG_TWL4030_CORE is not set
+# CONFIG_TWL6040_CORE is not set
+# CONFIG_MFD_WL1273_CORE is not set
+# CONFIG_MFD_LM3533 is not set
+# CONFIG_MFD_TC3589X is not set
+# CONFIG_MFD_TMIO is not set
+# CONFIG_MFD_VX855 is not set
+# CONFIG_MFD_ARIZONA_I2C is not set
+# CONFIG_MFD_WM8400 is not set
+# CONFIG_MFD_WM831X_I2C is not set
+# CONFIG_MFD_WM8350_I2C is not set
+# CONFIG_MFD_WM8994 is not set
+# CONFIG_REGULATOR is not set
+# CONFIG_MEDIA_SUPPORT is not set
+
+#
+# Graphics support
+#
+CONFIG_AGP=y
+CONFIG_AGP_AMD64=y
+CONFIG_AGP_INTEL=y
+# CONFIG_AGP_SIS is not set
+CONFIG_AGP_VIA=y
+CONFIG_VGA_ARB=y
+CONFIG_VGA_ARB_MAX_GPUS=16
+CONFIG_VGA_SWITCHEROO=y
+CONFIG_DRM=y
+CONFIG_DRM_KMS_HELPER=y
+# CONFIG_DRM_LOAD_EDID_FIRMWARE is not set
+
+#
+# I2C encoder or helper chips
+#
+# CONFIG_DRM_I2C_CH7006 is not set
+# CONFIG_DRM_I2C_SIL164 is not set
+# CONFIG_DRM_I2C_NXP_TDA998X is not set
+# CONFIG_DRM_TDFX is not set
+# CONFIG_DRM_R128 is not set
+# CONFIG_DRM_RADEON is not set
+# CONFIG_DRM_NOUVEAU is not set
+# CONFIG_DRM_I810 is not set
+CONFIG_DRM_I915=y
+# CONFIG_DRM_I915_KMS is not set
+# CONFIG_DRM_MGA is not set
+# CONFIG_DRM_SIS is not set
+# CONFIG_DRM_VIA is not set
+# CONFIG_DRM_SAVAGE is not set
+# CONFIG_DRM_VMWGFX is not set
+# CONFIG_DRM_GMA500 is not set
+# CONFIG_DRM_UDL is not set
+# CONFIG_DRM_AST is not set
+# CONFIG_DRM_MGAG200 is not set
+# CONFIG_DRM_CIRRUS_QEMU is not set
+# CONFIG_DRM_QXL is not set
+# CONFIG_VGASTATE is not set
+CONFIG_VIDEO_OUTPUT_CONTROL=y
+CONFIG_HDMI=y
+CONFIG_FB=y
+CONFIG_FIRMWARE_EDID=y
+# CONFIG_FB_DDC is not set
+# CONFIG_FB_BOOT_VESA_SUPPORT is not set
+CONFIG_FB_CFB_FILLRECT=y
+CONFIG_FB_CFB_COPYAREA=y
+CONFIG_FB_CFB_IMAGEBLIT=y
+# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
+# CONFIG_FB_SYS_FILLRECT is not set
+# CONFIG_FB_SYS_COPYAREA is not set
+# CONFIG_FB_SYS_IMAGEBLIT is not set
+# CONFIG_FB_FOREIGN_ENDIAN is not set
+# CONFIG_FB_SYS_FOPS is not set
+# CONFIG_FB_SVGALIB is not set
+# CONFIG_FB_MACMODES is not set
+# CONFIG_FB_BACKLIGHT is not set
+CONFIG_FB_MODE_HELPERS=y
+CONFIG_FB_TILEBLITTING=y
+
+#
+# Frame buffer hardware drivers
+#
+# CONFIG_FB_CIRRUS is not set
+# CONFIG_FB_PM2 is not set
+# CONFIG_FB_CYBER2000 is not set
+# CONFIG_FB_ARC is not set
+CONFIG_FB_ASILIANT=y
+CONFIG_FB_IMSTT=y
+# CONFIG_FB_VGA16 is not set
+# CONFIG_FB_UVESA is not set
+# CONFIG_FB_VESA is not set
+CONFIG_FB_EFI=y
+# CONFIG_FB_N411 is not set
+# CONFIG_FB_HGA is not set
+# CONFIG_FB_S1D13XXX is not set
+# CONFIG_FB_NVIDIA is not set
+# CONFIG_FB_RIVA is not set
+# CONFIG_FB_I740 is not set
+# CONFIG_FB_LE80578 is not set
+# CONFIG_FB_MATROX is not set
+# CONFIG_FB_RADEON is not set
+# CONFIG_FB_ATY128 is not set
+# CONFIG_FB_ATY is not set
+# CONFIG_FB_S3 is not set
+# CONFIG_FB_SAVAGE is not set
+# CONFIG_FB_SIS is not set
+# CONFIG_FB_VIA is not set
+# CONFIG_FB_NEOMAGIC is not set
+# CONFIG_FB_KYRO is not set
+# CONFIG_FB_3DFX is not set
+# CONFIG_FB_VOODOO1 is not set
+# CONFIG_FB_VT8623 is not set
+# CONFIG_FB_TRIDENT is not set
+# CONFIG_FB_ARK is not set
+# CONFIG_FB_PM3 is not set
+# CONFIG_FB_CARMINE is not set
+CONFIG_FB_GEODE=y
+# CONFIG_FB_GEODE_LX is not set
+# CONFIG_FB_GEODE_GX is not set
+# CONFIG_FB_GEODE_GX1 is not set
+# CONFIG_FB_TMIO is not set
+# CONFIG_FB_SMSCUFX is not set
+# CONFIG_FB_UDL is not set
+# CONFIG_FB_GOLDFISH is not set
+# CONFIG_FB_VIRTUAL is not set
+# CONFIG_FB_METRONOME is not set
+# CONFIG_FB_MB862XX is not set
+# CONFIG_FB_BROADSHEET is not set
+# CONFIG_FB_AUO_K190X is not set
+# CONFIG_EXYNOS_VIDEO is not set
+CONFIG_BACKLIGHT_LCD_SUPPORT=y
+CONFIG_LCD_CLASS_DEVICE=m
+# CONFIG_LCD_PLATFORM is not set
+CONFIG_BACKLIGHT_CLASS_DEVICE=y
+CONFIG_BACKLIGHT_GENERIC=y
+# CONFIG_BACKLIGHT_APPLE is not set
+# CONFIG_BACKLIGHT_SAHARA is not set
+# CONFIG_BACKLIGHT_ADP8860 is not set
+# CONFIG_BACKLIGHT_ADP8870 is not set
+# CONFIG_BACKLIGHT_LM3630 is not set
+# CONFIG_BACKLIGHT_LM3639 is not set
+# CONFIG_BACKLIGHT_LP855X is not set
+
+#
+# Console display driver support
+#
+CONFIG_VGA_CONSOLE=y
+# CONFIG_VGACON_SOFT_SCROLLBACK is not set
+CONFIG_DUMMY_CONSOLE=y
+CONFIG_FRAMEBUFFER_CONSOLE=y
+CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY=y
+# CONFIG_FRAMEBUFFER_CONSOLE_ROTATION is not set
+# CONFIG_FONTS is not set
+CONFIG_FONT_8x8=y
+CONFIG_FONT_8x16=y
+# CONFIG_LOGO is not set
+# CONFIG_SOUND is not set
+
+#
+# HID support
+#
+CONFIG_HID=y
+# CONFIG_HID_BATTERY_STRENGTH is not set
+CONFIG_HIDRAW=y
+# CONFIG_UHID is not set
+CONFIG_HID_GENERIC=y
+
+#
+# Special HID drivers
+#
+# CONFIG_HID_A4TECH is not set
+# CONFIG_HID_ACRUX is not set
+# CONFIG_HID_APPLE is not set
+# CONFIG_HID_APPLEIR is not set
+# CONFIG_HID_AUREAL is not set
+# CONFIG_HID_BELKIN is not set
+# CONFIG_HID_CHERRY is not set
+# CONFIG_HID_CHICONY is not set
+# CONFIG_HID_CYPRESS is not set
+# CONFIG_HID_DRAGONRISE is not set
+# CONFIG_HID_EMS_FF is not set
+# CONFIG_HID_ELECOM is not set
+# CONFIG_HID_EZKEY is not set
+# CONFIG_HID_HOLTEK is not set
+# CONFIG_HID_KEYTOUCH is not set
+# CONFIG_HID_KYE is not set
+# CONFIG_HID_UCLOGIC is not set
+# CONFIG_HID_WALTOP is not set
+# CONFIG_HID_GYRATION is not set
+# CONFIG_HID_ICADE is not set
+# CONFIG_HID_TWINHAN is not set
+# CONFIG_HID_KENSINGTON is not set
+# CONFIG_HID_LCPOWER is not set
+# CONFIG_HID_LENOVO_TPKBD is not set
+# CONFIG_HID_LOGITECH is not set
+# CONFIG_HID_MAGICMOUSE is not set
+# CONFIG_HID_MICROSOFT is not set
+# CONFIG_HID_MONTEREY is not set
+# CONFIG_HID_MULTITOUCH is not set
+# CONFIG_HID_NTRIG is not set
+# CONFIG_HID_ORTEK is not set
+# CONFIG_HID_PANTHERLORD is not set
+# CONFIG_HID_PETALYNX is not set
+# CONFIG_HID_PICOLCD is not set
+# CONFIG_HID_PRIMAX is not set
+# CONFIG_HID_PS3REMOTE is not set
+# CONFIG_HID_ROCCAT is not set
+# CONFIG_HID_SAITEK is not set
+# CONFIG_HID_SAMSUNG is not set
+# CONFIG_HID_SONY is not set
+# CONFIG_HID_SPEEDLINK is not set
+# CONFIG_HID_STEELSERIES is not set
+# CONFIG_HID_SUNPLUS is not set
+# CONFIG_HID_GREENASIA is not set
+# CONFIG_HID_SMARTJOYPLUS is not set
+# CONFIG_HID_TIVO is not set
+# CONFIG_HID_TOPSEED is not set
+# CONFIG_HID_THRUSTMASTER is not set
+# CONFIG_HID_ZEROPLUS is not set
+# CONFIG_HID_ZYDACRON is not set
+# CONFIG_HID_SENSOR_HUB is not set
+
+#
+# USB HID support
+#
+CONFIG_USB_HID=m
+CONFIG_HID_PID=y
+CONFIG_USB_HIDDEV=y
+
+#
+# USB HID Boot Protocol drivers
+#
+# CONFIG_USB_KBD is not set
+# CONFIG_USB_MOUSE is not set
+
+#
+# I2C HID support
+#
+# CONFIG_I2C_HID is not set
+CONFIG_USB_ARCH_HAS_OHCI=y
+CONFIG_USB_ARCH_HAS_EHCI=y
+CONFIG_USB_ARCH_HAS_XHCI=y
+CONFIG_USB_SUPPORT=y
+CONFIG_USB_COMMON=m
+CONFIG_USB_ARCH_HAS_HCD=y
+CONFIG_USB=m
+# CONFIG_USB_DEBUG is not set
+CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
+
+#
+# Miscellaneous USB options
+#
+CONFIG_USB_DEFAULT_PERSIST=y
+# CONFIG_USB_DYNAMIC_MINORS is not set
+# CONFIG_USB_OTG is not set
+# CONFIG_USB_OTG_WHITELIST is not set
+# CONFIG_USB_OTG_BLACKLIST_HUB is not set
+# CONFIG_USB_MON is not set
+# CONFIG_USB_WUSB_CBAF is not set
+
+#
+# USB Host Controller Drivers
+#
+# CONFIG_USB_C67X00_HCD is not set
+CONFIG_USB_XHCI_HCD=m
+# CONFIG_USB_XHCI_HCD_DEBUGGING is not set
+CONFIG_USB_EHCI_HCD=m
+# CONFIG_USB_EHCI_ROOT_HUB_TT is not set
+# CONFIG_USB_EHCI_TT_NEWSCHED is not set
+CONFIG_USB_EHCI_PCI=m
+# CONFIG_USB_EHCI_HCD_PLATFORM is not set
+# CONFIG_USB_OXU210HP_HCD is not set
+# CONFIG_USB_ISP116X_HCD is not set
+# CONFIG_USB_ISP1760_HCD is not set
+# CONFIG_USB_ISP1362_HCD is not set
+CONFIG_USB_OHCI_HCD=m
+# CONFIG_USB_OHCI_HCD_PLATFORM is not set
+# CONFIG_USB_OHCI_BIG_ENDIAN_DESC is not set
+# CONFIG_USB_OHCI_BIG_ENDIAN_MMIO is not set
+CONFIG_USB_OHCI_LITTLE_ENDIAN=y
+CONFIG_USB_UHCI_HCD=m
+# CONFIG_USB_SL811_HCD is not set
+# CONFIG_USB_R8A66597_HCD is not set
+
+#
+# USB Device Class drivers
+#
+# CONFIG_USB_ACM is not set
+CONFIG_USB_PRINTER=m
+# CONFIG_USB_WDM is not set
+# CONFIG_USB_TMC is not set
+
+#
+# NOTE: USB_STORAGE depends on SCSI but BLK_DEV_SD may
+#
+
+#
+# also be needed; see USB_STORAGE Help for more info
+#
+CONFIG_USB_STORAGE=m
+# CONFIG_USB_STORAGE_DEBUG is not set
+# CONFIG_USB_STORAGE_REALTEK is not set
+# CONFIG_USB_STORAGE_DATAFAB is not set
+# CONFIG_USB_STORAGE_FREECOM is not set
+# CONFIG_USB_STORAGE_ISD200 is not set
+# CONFIG_USB_STORAGE_USBAT is not set
+# CONFIG_USB_STORAGE_SDDR09 is not set
+# CONFIG_USB_STORAGE_SDDR55 is not set
+# CONFIG_USB_STORAGE_JUMPSHOT is not set
+# CONFIG_USB_STORAGE_ALAUDA is not set
+# CONFIG_USB_STORAGE_ONETOUCH is not set
+# CONFIG_USB_STORAGE_KARMA is not set
+# CONFIG_USB_STORAGE_CYPRESS_ATACB is not set
+# CONFIG_USB_STORAGE_ENE_UB6250 is not set
+
+#
+# USB Imaging devices
+#
+# CONFIG_USB_MDC800 is not set
+# CONFIG_USB_MICROTEK is not set
+# CONFIG_USB_DWC3 is not set
+# CONFIG_USB_CHIPIDEA is not set
+
+#
+# USB port drivers
+#
+# CONFIG_USB_SERIAL is not set
+
+#
+# USB Miscellaneous drivers
+#
+# CONFIG_USB_EMI62 is not set
+# CONFIG_USB_EMI26 is not set
+# CONFIG_USB_ADUTUX is not set
+# CONFIG_USB_SEVSEG is not set
+# CONFIG_USB_RIO500 is not set
+# CONFIG_USB_LEGOTOWER is not set
+# CONFIG_USB_LCD is not set
+# CONFIG_USB_LED is not set
+# CONFIG_USB_CYPRESS_CY7C63 is not set
+# CONFIG_USB_CYTHERM is not set
+# CONFIG_USB_IDMOUSE is not set
+# CONFIG_USB_FTDI_ELAN is not set
+# CONFIG_USB_APPLEDISPLAY is not set
+# CONFIG_USB_SISUSBVGA is not set
+# CONFIG_USB_LD is not set
+# CONFIG_USB_TRANCEVIBRATOR is not set
+# CONFIG_USB_IOWARRIOR is not set
+# CONFIG_USB_TEST is not set
+# CONFIG_USB_ISIGHTFW is not set
+# CONFIG_USB_YUREX is not set
+# CONFIG_USB_EZUSB_FX2 is not set
+# CONFIG_USB_HSIC_USB3503 is not set
+# CONFIG_USB_PHY is not set
+# CONFIG_USB_GADGET is not set
+# CONFIG_UWB is not set
+# CONFIG_MMC is not set
+# CONFIG_MEMSTICK is not set
+# CONFIG_NEW_LEDS is not set
+# CONFIG_ACCESSIBILITY is not set
+# CONFIG_INFINIBAND is not set
+# CONFIG_EDAC is not set
+CONFIG_RTC_LIB=y
+CONFIG_RTC_CLASS=y
+CONFIG_RTC_HCTOSYS=y
+CONFIG_RTC_SYSTOHC=y
+CONFIG_RTC_HCTOSYS_DEVICE="rtc0"
+# CONFIG_RTC_DEBUG is not set
+
+#
+# RTC interfaces
+#
+CONFIG_RTC_INTF_SYSFS=y
+CONFIG_RTC_INTF_PROC=y
+CONFIG_RTC_INTF_DEV=y
+# CONFIG_RTC_INTF_DEV_UIE_EMUL is not set
+# CONFIG_RTC_DRV_TEST is not set
+
+#
+# I2C RTC drivers
+#
+# CONFIG_RTC_DRV_DS1307 is not set
+# CONFIG_RTC_DRV_DS1374 is not set
+# CONFIG_RTC_DRV_DS1672 is not set
+# CONFIG_RTC_DRV_DS3232 is not set
+# CONFIG_RTC_DRV_MAX6900 is not set
+# CONFIG_RTC_DRV_RS5C372 is not set
+# CONFIG_RTC_DRV_ISL1208 is not set
+# CONFIG_RTC_DRV_ISL12022 is not set
+# CONFIG_RTC_DRV_X1205 is not set
+# CONFIG_RTC_DRV_PCF8523 is not set
+# CONFIG_RTC_DRV_PCF8563 is not set
+# CONFIG_RTC_DRV_PCF8583 is not set
+# CONFIG_RTC_DRV_M41T80 is not set
+# CONFIG_RTC_DRV_BQ32K is not set
+# CONFIG_RTC_DRV_S35390A is not set
+# CONFIG_RTC_DRV_FM3130 is not set
+# CONFIG_RTC_DRV_RX8581 is not set
+# CONFIG_RTC_DRV_RX8025 is not set
+# CONFIG_RTC_DRV_EM3027 is not set
+# CONFIG_RTC_DRV_RV3029C2 is not set
+
+#
+# SPI RTC drivers
+#
+
+#
+# Platform RTC drivers
+#
+CONFIG_RTC_DRV_CMOS=y
+# CONFIG_RTC_DRV_DS1286 is not set
+# CONFIG_RTC_DRV_DS1511 is not set
+# CONFIG_RTC_DRV_DS1553 is not set
+# CONFIG_RTC_DRV_DS1742 is not set
+# CONFIG_RTC_DRV_STK17TA8 is not set
+# CONFIG_RTC_DRV_M48T86 is not set
+# CONFIG_RTC_DRV_M48T35 is not set
+# CONFIG_RTC_DRV_M48T59 is not set
+# CONFIG_RTC_DRV_MSM6242 is not set
+# CONFIG_RTC_DRV_BQ4802 is not set
+# CONFIG_RTC_DRV_RP5C01 is not set
+# CONFIG_RTC_DRV_V3020 is not set
+# CONFIG_RTC_DRV_DS2404 is not set
+
+#
+# on-CPU RTC drivers
+#
+
+#
+# HID Sensor RTC drivers
+#
+# CONFIG_RTC_DRV_HID_SENSOR_TIME is not set
+# CONFIG_DMADEVICES is not set
+# CONFIG_AUXDISPLAY is not set
+# CONFIG_UIO is not set
+# CONFIG_VFIO is not set
+# CONFIG_VIRT_DRIVERS is not set
+
+#
+# Virtio drivers
+#
+# CONFIG_VIRTIO_PCI is not set
+# CONFIG_VIRTIO_MMIO is not set
+
+#
+# Microsoft Hyper-V guest support
+#
+# CONFIG_STAGING is not set
+# CONFIG_X86_PLATFORM_DEVICES is not set
+
+#
+# Hardware Spinlock drivers
+#
+CONFIG_CLKEVT_I8253=y
+CONFIG_I8253_LOCK=y
+CONFIG_CLKBLD_I8253=y
+# CONFIG_MAILBOX is not set
+CONFIG_IOMMU_API=y
+CONFIG_IOMMU_SUPPORT=y
+CONFIG_AMD_IOMMU=y
+CONFIG_AMD_IOMMU_STATS=y
+# CONFIG_AMD_IOMMU_V2 is not set
+# CONFIG_INTEL_IOMMU is not set
+# CONFIG_IRQ_REMAP is not set
+
+#
+# Remoteproc drivers
+#
+# CONFIG_STE_MODEM_RPROC is not set
+
+#
+# Rpmsg drivers
+#
+# CONFIG_PM_DEVFREQ is not set
+# CONFIG_EXTCON is not set
+# CONFIG_MEMORY is not set
+# CONFIG_IIO is not set
+# CONFIG_NTB is not set
+# CONFIG_VME_BUS is not set
+# CONFIG_PWM is not set
+# CONFIG_IPACK_BUS is not set
+# CONFIG_RESET_CONTROLLER is not set
+
+#
+# Firmware Drivers
+#
+CONFIG_EDD=y
+CONFIG_EDD_OFF=y
+CONFIG_FIRMWARE_MEMMAP=y
+# CONFIG_DELL_RBU is not set
+# CONFIG_DCDBAS is not set
+CONFIG_DMIID=y
+# CONFIG_DMI_SYSFS is not set
+CONFIG_ISCSI_IBFT_FIND=y
+# CONFIG_ISCSI_IBFT is not set
+# CONFIG_GOOGLE_FIRMWARE is not set
+
+#
+# EFI (Extensible Firmware Interface) Support
+#
+CONFIG_EFI_VARS=y
+CONFIG_EFI_VARS_PSTORE=y
+# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
+
+#
+# File systems
+#
+CONFIG_DCACHE_WORD_ACCESS=y
+CONFIG_EXT2_FS=y
+CONFIG_EXT2_FS_XATTR=y
+CONFIG_EXT2_FS_POSIX_ACL=y
+CONFIG_EXT2_FS_SECURITY=y
+# CONFIG_EXT2_FS_XIP is not set
+CONFIG_EXT3_FS=y
+CONFIG_EXT3_DEFAULTS_TO_ORDERED=y
+CONFIG_EXT3_FS_XATTR=y
+CONFIG_EXT3_FS_POSIX_ACL=y
+CONFIG_EXT3_FS_SECURITY=y
+CONFIG_EXT4_FS=y
+CONFIG_EXT4_FS_POSIX_ACL=y
+CONFIG_EXT4_FS_SECURITY=y
+# CONFIG_EXT4_DEBUG is not set
+CONFIG_JBD=y
+# CONFIG_JBD_DEBUG is not set
+CONFIG_JBD2=y
+# CONFIG_JBD2_DEBUG is not set
+CONFIG_FS_MBCACHE=y
+# CONFIG_REISERFS_FS is not set
+# CONFIG_JFS_FS is not set
+CONFIG_XFS_FS=y
+CONFIG_XFS_QUOTA=y
+CONFIG_XFS_POSIX_ACL=y
+# CONFIG_XFS_RT is not set
+# CONFIG_XFS_WARN is not set
+# CONFIG_XFS_DEBUG is not set
+# CONFIG_GFS2_FS is not set
+# CONFIG_BTRFS_FS is not set
+# CONFIG_NILFS2_FS is not set
+CONFIG_FS_POSIX_ACL=y
+CONFIG_EXPORTFS=y
+CONFIG_FILE_LOCKING=y
+CONFIG_FSNOTIFY=y
+CONFIG_DNOTIFY=y
+CONFIG_INOTIFY_USER=y
+CONFIG_FANOTIFY=y
+CONFIG_FANOTIFY_ACCESS_PERMISSIONS=y
+CONFIG_QUOTA=y
+CONFIG_QUOTA_NETLINK_INTERFACE=y
+# CONFIG_PRINT_QUOTA_WARNING is not set
+# CONFIG_QUOTA_DEBUG is not set
+# CONFIG_QFMT_V1 is not set
+# CONFIG_QFMT_V2 is not set
+CONFIG_QUOTACTL=y
+CONFIG_QUOTACTL_COMPAT=y
+CONFIG_AUTOFS4_FS=y
+CONFIG_FUSE_FS=y
+# CONFIG_CUSE is not set
+CONFIG_GENERIC_ACL=y
+
+#
+# Caches
+#
+# CONFIG_FSCACHE is not set
+
+#
+# CD-ROM/DVD Filesystems
+#
+CONFIG_ISO9660_FS=y
+CONFIG_JOLIET=y
+CONFIG_ZISOFS=y
+# CONFIG_UDF_FS is not set
+
+#
+# DOS/FAT/NT Filesystems
+#
+CONFIG_FAT_FS=y
+CONFIG_MSDOS_FS=y
+CONFIG_VFAT_FS=y
+CONFIG_FAT_DEFAULT_CODEPAGE=437
+CONFIG_FAT_DEFAULT_IOCHARSET="iso8859-1"
+CONFIG_NTFS_FS=y
+# CONFIG_NTFS_DEBUG is not set
+CONFIG_NTFS_RW=y
+
+#
+# Pseudo filesystems
+#
+CONFIG_PROC_FS=y
+CONFIG_PROC_KCORE=y
+CONFIG_PROC_VMCORE=y
+CONFIG_PROC_SYSCTL=y
+CONFIG_PROC_PAGE_MONITOR=y
+CONFIG_SYSFS=y
+CONFIG_TMPFS=y
+CONFIG_TMPFS_POSIX_ACL=y
+CONFIG_TMPFS_XATTR=y
+CONFIG_HUGETLBFS=y
+CONFIG_HUGETLB_PAGE=y
+# CONFIG_CONFIGFS_FS is not set
+CONFIG_MISC_FILESYSTEMS=y
+# CONFIG_ADFS_FS is not set
+# CONFIG_AFFS_FS is not set
+# CONFIG_ECRYPT_FS is not set
+# CONFIG_HFS_FS is not set
+# CONFIG_HFSPLUS_FS is not set
+# CONFIG_BEFS_FS is not set
+# CONFIG_BFS_FS is not set
+# CONFIG_EFS_FS is not set
+# CONFIG_LOGFS is not set
+# CONFIG_CRAMFS is not set
+# CONFIG_SQUASHFS is not set
+# CONFIG_VXFS_FS is not set
+# CONFIG_MINIX_FS is not set
+# CONFIG_OMFS_FS is not set
+# CONFIG_HPFS_FS is not set
+# CONFIG_QNX4FS_FS is not set
+# CONFIG_QNX6FS_FS is not set
+# CONFIG_ROMFS_FS is not set
+CONFIG_PSTORE=y
+# CONFIG_PSTORE_CONSOLE is not set
+# CONFIG_PSTORE_FTRACE is not set
+# CONFIG_PSTORE_RAM is not set
+# CONFIG_SYSV_FS is not set
+# CONFIG_UFS_FS is not set
+# CONFIG_F2FS_FS is not set
+# CONFIG_EFIVAR_FS is not set
+CONFIG_NETWORK_FILESYSTEMS=y
+CONFIG_NFS_FS=y
+CONFIG_NFS_V2=y
+CONFIG_NFS_V3=y
+CONFIG_NFS_V3_ACL=y
+CONFIG_NFS_V4=y
+# CONFIG_NFS_SWAP is not set
+# CONFIG_NFS_V4_1 is not set
+CONFIG_ROOT_NFS=y
+# CONFIG_NFS_USE_LEGACY_DNS is not set
+CONFIG_NFS_USE_KERNEL_DNS=y
+CONFIG_NFSD=y
+CONFIG_NFSD_V3=y
+# CONFIG_NFSD_V3_ACL is not set
+# CONFIG_NFSD_V4 is not set
+CONFIG_LOCKD=y
+CONFIG_LOCKD_V4=y
+CONFIG_NFS_ACL_SUPPORT=y
+CONFIG_NFS_COMMON=y
+CONFIG_SUNRPC=y
+CONFIG_SUNRPC_GSS=y
+# CONFIG_SUNRPC_DEBUG is not set
+# CONFIG_CEPH_FS is not set
+# CONFIG_CIFS is not set
+# CONFIG_NCP_FS is not set
+# CONFIG_CODA_FS is not set
+# CONFIG_AFS_FS is not set
+CONFIG_NLS=y
+CONFIG_NLS_DEFAULT="utf8"
+CONFIG_NLS_CODEPAGE_437=y
+CONFIG_NLS_CODEPAGE_737=m
+CONFIG_NLS_CODEPAGE_775=m
+CONFIG_NLS_CODEPAGE_850=m
+CONFIG_NLS_CODEPAGE_852=m
+CONFIG_NLS_CODEPAGE_855=m
+CONFIG_NLS_CODEPAGE_857=m
+CONFIG_NLS_CODEPAGE_860=m
+CONFIG_NLS_CODEPAGE_861=m
+CONFIG_NLS_CODEPAGE_862=m
+CONFIG_NLS_CODEPAGE_863=m
+CONFIG_NLS_CODEPAGE_864=m
+CONFIG_NLS_CODEPAGE_865=m
+CONFIG_NLS_CODEPAGE_866=m
+CONFIG_NLS_CODEPAGE_869=m
+CONFIG_NLS_CODEPAGE_936=m
+CONFIG_NLS_CODEPAGE_950=m
+CONFIG_NLS_CODEPAGE_932=y
+CONFIG_NLS_CODEPAGE_949=m
+CONFIG_NLS_CODEPAGE_874=m
+CONFIG_NLS_ISO8859_8=m
+CONFIG_NLS_CODEPAGE_1250=m
+CONFIG_NLS_CODEPAGE_1251=m
+CONFIG_NLS_ASCII=m
+CONFIG_NLS_ISO8859_1=m
+CONFIG_NLS_ISO8859_2=m
+CONFIG_NLS_ISO8859_3=m
+CONFIG_NLS_ISO8859_4=m
+CONFIG_NLS_ISO8859_5=m
+CONFIG_NLS_ISO8859_6=m
+CONFIG_NLS_ISO8859_7=m
+CONFIG_NLS_ISO8859_9=m
+CONFIG_NLS_ISO8859_13=m
+CONFIG_NLS_ISO8859_14=m
+CONFIG_NLS_ISO8859_15=m
+CONFIG_NLS_KOI8_R=m
+CONFIG_NLS_KOI8_U=m
+# CONFIG_NLS_MAC_ROMAN is not set
+# CONFIG_NLS_MAC_CELTIC is not set
+# CONFIG_NLS_MAC_CENTEURO is not set
+# CONFIG_NLS_MAC_CROATIAN is not set
+# CONFIG_NLS_MAC_CYRILLIC is not set
+# CONFIG_NLS_MAC_GAELIC is not set
+# CONFIG_NLS_MAC_GREEK is not set
+# CONFIG_NLS_MAC_ICELAND is not set
+# CONFIG_NLS_MAC_INUIT is not set
+# CONFIG_NLS_MAC_ROMANIAN is not set
+# CONFIG_NLS_MAC_TURKISH is not set
+CONFIG_NLS_UTF8=m
+
+#
+# Kernel hacking
+#
+CONFIG_TRACE_IRQFLAGS_SUPPORT=y
+CONFIG_PRINTK_TIME=y
+CONFIG_DEFAULT_MESSAGE_LOGLEVEL=4
+# CONFIG_ENABLE_WARN_DEPRECATED is not set
+# CONFIG_ENABLE_MUST_CHECK is not set
+CONFIG_FRAME_WARN=1024
+CONFIG_MAGIC_SYSRQ=y
+# CONFIG_STRIP_ASM_SYMS is not set
+# CONFIG_READABLE_ASM is not set
+CONFIG_UNUSED_SYMBOLS=y
+CONFIG_DEBUG_FS=y
+# CONFIG_HEADERS_CHECK is not set
+# CONFIG_DEBUG_SECTION_MISMATCH is not set
+CONFIG_DEBUG_KERNEL=y
+# CONFIG_DEBUG_SHIRQ is not set
+# CONFIG_LOCKUP_DETECTOR is not set
+# CONFIG_PANIC_ON_OOPS is not set
+CONFIG_PANIC_ON_OOPS_VALUE=0
+# CONFIG_DETECT_HUNG_TASK is not set
+CONFIG_SCHED_DEBUG=y
+# CONFIG_SCHEDSTATS is not set
+# CONFIG_TIMER_STATS is not set
+# CONFIG_DEBUG_OBJECTS is not set
+# CONFIG_SLUB_STATS is not set
+CONFIG_HAVE_DEBUG_KMEMLEAK=y
+# CONFIG_DEBUG_KMEMLEAK is not set
+# CONFIG_DEBUG_RT_MUTEXES is not set
+# CONFIG_RT_MUTEX_TESTER is not set
+# CONFIG_DEBUG_SPINLOCK is not set
+# CONFIG_DEBUG_MUTEXES is not set
+# CONFIG_DEBUG_LOCK_ALLOC is not set
+# CONFIG_PROVE_LOCKING is not set
+# CONFIG_LOCK_STAT is not set
+# CONFIG_DEBUG_ATOMIC_SLEEP is not set
+# CONFIG_DEBUG_LOCKING_API_SELFTESTS is not set
+CONFIG_STACKTRACE=y
+# CONFIG_DEBUG_STACK_USAGE is not set
+# CONFIG_DEBUG_KOBJECT is not set
+CONFIG_DEBUG_BUGVERBOSE=y
+# CONFIG_DEBUG_INFO is not set
+# CONFIG_DEBUG_VM is not set
+# CONFIG_DEBUG_VIRTUAL is not set
+# CONFIG_DEBUG_WRITECOUNT is not set
+# CONFIG_DEBUG_MEMORY_INIT is not set
+# CONFIG_DEBUG_LIST is not set
+# CONFIG_TEST_LIST_SORT is not set
+# CONFIG_DEBUG_SG is not set
+# CONFIG_DEBUG_NOTIFIERS is not set
+# CONFIG_DEBUG_CREDENTIALS is not set
+CONFIG_ARCH_WANT_FRAME_POINTERS=y
+CONFIG_FRAME_POINTER=y
+# CONFIG_BOOT_PRINTK_DELAY is not set
+
+#
+# RCU Debugging
+#
+# CONFIG_SPARSE_RCU_POINTER is not set
+# CONFIG_RCU_TORTURE_TEST is not set
+CONFIG_RCU_CPU_STALL_TIMEOUT=21
+# CONFIG_RCU_CPU_STALL_INFO is not set
+# CONFIG_RCU_TRACE is not set
+# CONFIG_KPROBES_SANITY_TEST is not set
+# CONFIG_BACKTRACE_SELF_TEST is not set
+# CONFIG_DEBUG_BLOCK_EXT_DEVT is not set
+# CONFIG_DEBUG_FORCE_WEAK_PER_CPU is not set
+# CONFIG_DEBUG_PER_CPU_MAPS is not set
+# CONFIG_LKDTM is not set
+# CONFIG_NOTIFIER_ERROR_INJECTION is not set
+# CONFIG_FAULT_INJECTION is not set
+# CONFIG_LATENCYTOP is not set
+CONFIG_ARCH_HAS_DEBUG_STRICT_USER_COPY_CHECKS=y
+# CONFIG_DEBUG_STRICT_USER_COPY_CHECKS is not set
+# CONFIG_DEBUG_PAGEALLOC is not set
+CONFIG_USER_STACKTRACE_SUPPORT=y
+CONFIG_NOP_TRACER=y
+CONFIG_HAVE_FUNCTION_TRACER=y
+CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
+CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
+CONFIG_HAVE_FUNCTION_TRACE_MCOUNT_TEST=y
+CONFIG_HAVE_DYNAMIC_FTRACE=y
+CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS=y
+CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
+CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
+CONFIG_HAVE_FENTRY=y
+CONFIG_HAVE_C_RECORDMCOUNT=y
+CONFIG_TRACER_MAX_TRACE=y
+CONFIG_TRACE_CLOCK=y
+CONFIG_RING_BUFFER=y
+CONFIG_EVENT_TRACING=y
+CONFIG_CONTEXT_SWITCH_TRACER=y
+CONFIG_TRACING=y
+CONFIG_GENERIC_TRACER=y
+CONFIG_TRACING_SUPPORT=y
+CONFIG_FTRACE=y
+CONFIG_FUNCTION_TRACER=y
+CONFIG_FUNCTION_GRAPH_TRACER=y
+# CONFIG_IRQSOFF_TRACER is not set
+CONFIG_SCHED_TRACER=y
+CONFIG_FTRACE_SYSCALLS=y
+CONFIG_TRACER_SNAPSHOT=y
+# CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP is not set
+CONFIG_BRANCH_PROFILE_NONE=y
+# CONFIG_PROFILE_ANNOTATED_BRANCHES is not set
+# CONFIG_PROFILE_ALL_BRANCHES is not set
+CONFIG_STACK_TRACER=y
+CONFIG_BLK_DEV_IO_TRACE=y
+CONFIG_KPROBE_EVENT=y
+# CONFIG_UPROBE_EVENT is not set
+CONFIG_PROBE_EVENTS=y
+CONFIG_DYNAMIC_FTRACE=y
+CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
+CONFIG_FUNCTION_PROFILER=y
+CONFIG_FTRACE_MCOUNT_RECORD=y
+# CONFIG_FTRACE_STARTUP_TEST is not set
+CONFIG_MMIOTRACE=y
+# CONFIG_MMIOTRACE_TEST is not set
+# CONFIG_RING_BUFFER_BENCHMARK is not set
+# CONFIG_RING_BUFFER_STARTUP_TEST is not set
+# CONFIG_RBTREE_TEST is not set
+# CONFIG_INTERVAL_TREE_TEST is not set
+# CONFIG_PROVIDE_OHCI1394_DMA_INIT is not set
+# CONFIG_DYNAMIC_DEBUG is not set
+# CONFIG_DMA_API_DEBUG is not set
+# CONFIG_ATOMIC64_SELFTEST is not set
+# CONFIG_ASYNC_RAID6_TEST is not set
+# CONFIG_SAMPLES is not set
+CONFIG_HAVE_ARCH_KGDB=y
+# CONFIG_KGDB is not set
+CONFIG_HAVE_ARCH_KMEMCHECK=y
+# CONFIG_TEST_STRING_HELPERS is not set
+# CONFIG_TEST_KSTRTOX is not set
+CONFIG_STRICT_DEVMEM=y
+# CONFIG_X86_VERBOSE_BOOTUP is not set
+CONFIG_EARLY_PRINTK=y
+# CONFIG_EARLY_PRINTK_DBGP is not set
+# CONFIG_DEBUG_STACKOVERFLOW is not set
+# CONFIG_X86_PTDUMP is not set
+CONFIG_DEBUG_RODATA=y
+CONFIG_DEBUG_RODATA_TEST=y
+# CONFIG_DEBUG_SET_MODULE_RONX is not set
+# CONFIG_DEBUG_NX_TEST is not set
+# CONFIG_DEBUG_TLBFLUSH is not set
+# CONFIG_IOMMU_DEBUG is not set
+# CONFIG_IOMMU_STRESS is not set
+CONFIG_HAVE_MMIOTRACE_SUPPORT=y
+# CONFIG_X86_DECODER_SELFTEST is not set
+CONFIG_IO_DELAY_TYPE_0X80=0
+CONFIG_IO_DELAY_TYPE_0XED=1
+CONFIG_IO_DELAY_TYPE_UDELAY=2
+CONFIG_IO_DELAY_TYPE_NONE=3
+# CONFIG_IO_DELAY_0X80 is not set
+CONFIG_IO_DELAY_0XED=y
+# CONFIG_IO_DELAY_UDELAY is not set
+# CONFIG_IO_DELAY_NONE is not set
+CONFIG_DEFAULT_IO_DELAY_TYPE=1
+# CONFIG_DEBUG_BOOT_PARAMS is not set
+# CONFIG_CPA_DEBUG is not set
+CONFIG_OPTIMIZE_INLINING=y
+# CONFIG_DEBUG_NMI_SELFTEST is not set
+
+#
+# Security options
+#
+CONFIG_KEYS=y
+# CONFIG_ENCRYPTED_KEYS is not set
+# CONFIG_KEYS_DEBUG_PROC_KEYS is not set
+# CONFIG_SECURITY_DMESG_RESTRICT is not set
+CONFIG_SECURITY=y
+# CONFIG_SECURITYFS is not set
+CONFIG_SECURITY_NETWORK=y
+# CONFIG_SECURITY_PATH is not set
+# CONFIG_SECURITY_SELINUX is not set
+# CONFIG_SECURITY_SMACK is not set
+# CONFIG_SECURITY_TOMOYO is not set
+# CONFIG_SECURITY_APPARMOR is not set
+# CONFIG_SECURITY_YAMA is not set
+# CONFIG_IMA is not set
+# CONFIG_EVM is not set
+CONFIG_DEFAULT_SECURITY_DAC=y
+CONFIG_DEFAULT_SECURITY=""
+CONFIG_XOR_BLOCKS=y
+CONFIG_ASYNC_CORE=y
+CONFIG_ASYNC_MEMCPY=y
+CONFIG_ASYNC_XOR=y
+CONFIG_ASYNC_PQ=y
+CONFIG_ASYNC_RAID6_RECOV=y
+CONFIG_CRYPTO=y
+
+#
+# Crypto core or helper
+#
+CONFIG_CRYPTO_ALGAPI=y
+CONFIG_CRYPTO_ALGAPI2=y
+CONFIG_CRYPTO_AEAD=y
+CONFIG_CRYPTO_AEAD2=y
+CONFIG_CRYPTO_BLKCIPHER=y
+CONFIG_CRYPTO_BLKCIPHER2=y
+CONFIG_CRYPTO_HASH=y
+CONFIG_CRYPTO_HASH2=y
+CONFIG_CRYPTO_RNG2=y
+CONFIG_CRYPTO_PCOMP2=y
+CONFIG_CRYPTO_MANAGER=y
+CONFIG_CRYPTO_MANAGER2=y
+# CONFIG_CRYPTO_USER is not set
+CONFIG_CRYPTO_MANAGER_DISABLE_TESTS=y
+# CONFIG_CRYPTO_GF128MUL is not set
+# CONFIG_CRYPTO_NULL is not set
+# CONFIG_CRYPTO_PCRYPT is not set
+CONFIG_CRYPTO_WORKQUEUE=y
+# CONFIG_CRYPTO_CRYPTD is not set
+CONFIG_CRYPTO_AUTHENC=y
+# CONFIG_CRYPTO_TEST is not set
+
+#
+# Authenticated Encryption with Associated Data
+#
+# CONFIG_CRYPTO_CCM is not set
+# CONFIG_CRYPTO_GCM is not set
+# CONFIG_CRYPTO_SEQIV is not set
+
+#
+# Block modes
+#
+CONFIG_CRYPTO_CBC=y
+# CONFIG_CRYPTO_CTR is not set
+# CONFIG_CRYPTO_CTS is not set
+CONFIG_CRYPTO_ECB=y
+# CONFIG_CRYPTO_LRW is not set
+# CONFIG_CRYPTO_PCBC is not set
+# CONFIG_CRYPTO_XTS is not set
+
+#
+# Hash modes
+#
+# CONFIG_CRYPTO_CMAC is not set
+CONFIG_CRYPTO_HMAC=y
+# CONFIG_CRYPTO_XCBC is not set
+# CONFIG_CRYPTO_VMAC is not set
+
+#
+# Digest
+#
+CONFIG_CRYPTO_CRC32C=y
+# CONFIG_CRYPTO_CRC32C_INTEL is not set
+# CONFIG_CRYPTO_CRC32 is not set
+# CONFIG_CRYPTO_CRC32_PCLMUL is not set
+# CONFIG_CRYPTO_GHASH is not set
+# CONFIG_CRYPTO_MD4 is not set
+CONFIG_CRYPTO_MD5=y
+# CONFIG_CRYPTO_MICHAEL_MIC is not set
+# CONFIG_CRYPTO_RMD128 is not set
+# CONFIG_CRYPTO_RMD160 is not set
+# CONFIG_CRYPTO_RMD256 is not set
+# CONFIG_CRYPTO_RMD320 is not set
+CONFIG_CRYPTO_SHA1=y
+# CONFIG_CRYPTO_SHA1_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256_SSSE3 is not set
+# CONFIG_CRYPTO_SHA512_SSSE3 is not set
+# CONFIG_CRYPTO_SHA256 is not set
+# CONFIG_CRYPTO_SHA512 is not set
+# CONFIG_CRYPTO_TGR192 is not set
+# CONFIG_CRYPTO_WP512 is not set
+# CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL is not set
+
+#
+# Ciphers
+#
+CONFIG_CRYPTO_AES=y
+# CONFIG_CRYPTO_AES_X86_64 is not set
+# CONFIG_CRYPTO_AES_NI_INTEL is not set
+# CONFIG_CRYPTO_ANUBIS is not set
+CONFIG_CRYPTO_ARC4=y
+# CONFIG_CRYPTO_BLOWFISH is not set
+# CONFIG_CRYPTO_BLOWFISH_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA is not set
+# CONFIG_CRYPTO_CAMELLIA_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_CAST5 is not set
+# CONFIG_CRYPTO_CAST5_AVX_X86_64 is not set
+# CONFIG_CRYPTO_CAST6 is not set
+# CONFIG_CRYPTO_CAST6_AVX_X86_64 is not set
+# CONFIG_CRYPTO_DES is not set
+# CONFIG_CRYPTO_FCRYPT is not set
+# CONFIG_CRYPTO_KHAZAD is not set
+# CONFIG_CRYPTO_SALSA20 is not set
+# CONFIG_CRYPTO_SALSA20_X86_64 is not set
+# CONFIG_CRYPTO_SEED is not set
+# CONFIG_CRYPTO_SERPENT is not set
+# CONFIG_CRYPTO_SERPENT_SSE2_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX_X86_64 is not set
+# CONFIG_CRYPTO_SERPENT_AVX2_X86_64 is not set
+# CONFIG_CRYPTO_TEA is not set
+# CONFIG_CRYPTO_TWOFISH is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64 is not set
+# CONFIG_CRYPTO_TWOFISH_X86_64_3WAY is not set
+# CONFIG_CRYPTO_TWOFISH_AVX_X86_64 is not set
+
+#
+# Compression
+#
+# CONFIG_CRYPTO_DEFLATE is not set
+# CONFIG_CRYPTO_ZLIB is not set
+# CONFIG_CRYPTO_LZO is not set
+
+#
+# Random Number Generation
+#
+# CONFIG_CRYPTO_ANSI_CPRNG is not set
+# CONFIG_CRYPTO_USER_API_HASH is not set
+# CONFIG_CRYPTO_USER_API_SKCIPHER is not set
+# CONFIG_CRYPTO_HW is not set
+# CONFIG_ASYMMETRIC_KEY_TYPE is not set
+CONFIG_HAVE_KVM=y
+# CONFIG_VIRTUALIZATION is not set
+CONFIG_BINARY_PRINTF=y
+
+#
+# Library routines
+#
+CONFIG_RAID6_PQ=y
+CONFIG_BITREVERSE=y
+CONFIG_GENERIC_STRNCPY_FROM_USER=y
+CONFIG_GENERIC_STRNLEN_USER=y
+CONFIG_GENERIC_FIND_FIRST_BIT=y
+CONFIG_GENERIC_PCI_IOMAP=y
+CONFIG_GENERIC_IOMAP=y
+CONFIG_GENERIC_IO=y
+# CONFIG_CRC_CCITT is not set
+CONFIG_CRC16=y
+CONFIG_CRC_T10DIF=y
+# CONFIG_CRC_ITU_T is not set
+CONFIG_CRC32=y
+# CONFIG_CRC32_SELFTEST is not set
+CONFIG_CRC32_SLICEBY8=y
+# CONFIG_CRC32_SLICEBY4 is not set
+# CONFIG_CRC32_SARWATE is not set
+# CONFIG_CRC32_BIT is not set
+CONFIG_CRC7=y
+CONFIG_LIBCRC32C=y
+# CONFIG_CRC8 is not set
+CONFIG_ZLIB_INFLATE=y
+CONFIG_LZO_COMPRESS=y
+CONFIG_LZO_DECOMPRESS=y
+CONFIG_XZ_DEC=y
+# CONFIG_XZ_DEC_X86 is not set
+# CONFIG_XZ_DEC_POWERPC is not set
+# CONFIG_XZ_DEC_IA64 is not set
+# CONFIG_XZ_DEC_ARM is not set
+# CONFIG_XZ_DEC_ARMTHUMB is not set
+# CONFIG_XZ_DEC_SPARC is not set
+# CONFIG_XZ_DEC_BCJ is not set
+# CONFIG_XZ_DEC_TEST is not set
+CONFIG_DECOMPRESS_GZIP=y
+CONFIG_DECOMPRESS_BZIP2=y
+CONFIG_DECOMPRESS_LZMA=y
+CONFIG_DECOMPRESS_XZ=y
+CONFIG_DECOMPRESS_LZO=y
+CONFIG_HAS_IOMEM=y
+CONFIG_HAS_IOPORT=y
+CONFIG_HAS_DMA=y
+CONFIG_CHECK_SIGNATURE=y
+CONFIG_CPU_RMAP=y
+CONFIG_DQL=y
+CONFIG_NLATTR=y
+CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE=y
+# CONFIG_AVERAGE is not set
+# CONFIG_CORDIC is not set
+# CONFIG_DDR is not set
+CONFIG_OID_REGISTRY=y
+CONFIG_UCS2_STRING=y
+
+#
+# BUFFALO Features
+#
+CONFIG_BUFFALO_PLATFORM=y
+CONFIG_BUFFALO_USE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT=y
+CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT=y
+# CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT is not set
+CONFIG_BUFFALO_ERRCNT=y
+CONFIG_BUFFALO_USE_UPS=y
+# CONFIG_BUFFALO_SUPPORT_UPS_RECOVER is not set
+CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN=y
+# CONFIG_BUFFALO_UBOOT_PARAMS is not set
+CONFIG_BUFFALO_IOERRS=y
+# CONFIG_BUFFALO_SKIP_RESYNC is not set
+# CONFIG_BUFFALO_IGNORE_LUN is not set
+# CONFIG_BUFFALO_SCSI_GUID is not set
+# CONFIG_BUFFALO_EXT23_EXTENSION is not set
+# CONFIG_BUFFALO_SUPPORT_WOL is not set
+# CONFIG_BUFFALO_MATSU_PLATFORM is not set
+# CONFIG_BUFFALO_KIRI_PLATFORM is not set
+CONFIG_BUFFALO_USI_PLATFORM=y
diff --git a/buffalo/arch/x86/plat-usi/Makefile b/buffalo/arch/x86/plat-usi/Makefile
new file mode 100644
index 00000000..27b1907
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/Makefile
@@ -0,0 +1,32 @@
+
+# To build modules outside of the kernel tree, we run "make"
+# in the kernel source tree; the Makefile these then includes this
+# Makefile once again.
+# This conditional selects whether we are being included from the
+# kernel Makefile or not.
+ifeq ($(KERNELRELEASE),)
+
+    # Assume the source tree is where the running kernel was built
+    # You should set KERNELDIR in the environment if it's elsewhere
+    KERNELDIR ?= /lib/modules/$(shell uname -r)/build
+    # The current directory is passed to sub-makes as argument
+    PWD := $(shell pwd)
+
+modules:
+	$(MAKE) -C $(KERNELDIR) M=$(PWD) modules
+
+modules_install:
+	$(MAKE) -C $(KERNELDIR) M=$(PWD) modules_install
+
+clean:
+	rm -rf *.o *~ core .depend .*.cmd *.ko *.mod.c .tmp_versions Module.symvers modules.order
+
+.PHONY: modules modules_install clean
+
+else
+	# called from kernel build system: just declare what our modules are
+	obj-$(CONFIG_BUFFALO_USI_PLATFORM) += sugi_platform.o
+
+endif
+
+
diff --git a/buffalo/arch/x86/plat-usi/sugi_platform.c b/buffalo/arch/x86/plat-usi/sugi_platform.c
new file mode 100644
index 00000000..1bac6a3
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/sugi_platform.c
@@ -0,0 +1,1989 @@
+/*	Sugi Platform Driver - V1.2
+ *
+ * 	Author: Gary Chen
+ *	Date  : 2012/07/11
+ */
+
+
+#include <linux/version.h>
+#include <linux/seq_file.h>
+#include <linux/slab.h>
+#include <asm/io.h>
+#include <asm/msr.h>
+#include <asm/errno.h>
+#include <linux/fs.h>
+#include <linux/irq.h>
+#include <linux/pci.h>
+#include <linux/cdev.h>
+#include <linux/init.h>
+#include <linux/poll.h>
+#include <linux/delay.h>
+#include <linux/device.h>
+#include <linux/sched.h>
+#include <linux/module.h>
+#include <linux/string.h>
+#include <linux/kernel.h>
+#include <linux/proc_fs.h>
+#include <linux/interrupt.h>
+#include "sugi_platform.h"
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 1
+ * Description: Global variabls and strctures
+ * ---------------------------------------------------------------------------------------------- */
+
+/* Define for procfs directory and file */
+#if defined(CONFIG_BUFFALO_PLATFORM)
+#include <buffalo/kernevnt.h>
+#endif
+
+
+
+/* **************** Button Driver **************** */
+
+/* declare for file and directory of procfs */
+static struct proc_dir_entry *buffalo_dir;
+static struct proc_dir_entry *gpio_dir;
+static struct proc_dir_entry *switch_dir;
+static struct proc_dir_entry *switch_file[MAX_SUPPORTED_BUTTONS];
+
+/* GPIO set3 base addr */
+static unsigned int it87_gpioset3_base_addr;
+
+/* declare timer function */
+static struct timer_list btn_timer;
+
+/* button information strcture */
+static struct button_info_st button_info[] = {
+	{"func", IT87_DEB0},
+	{"display", IT87_DEB1}
+};
+
+/* ************** Fan Control Driver ************* */
+
+/* class and device nodes */
+struct class *sugi_cls;
+struct device *fan_dev;
+dev_t sugit_fan = MKDEV(sugi_fan_major, sugi_fan_minor);
+
+/* IT8721 EC base address */
+unsigned int EC_BASE_ADDR;
+unsigned int IT87_EC_ADDR_REG;
+unsigned int IT87_EC_DATA_REG;
+
+/* core temp used */
+unsigned int tjmax[2] = {100,100};
+unsigned int eax;
+unsigned int edx;
+
+/* fan, temp information strcture */
+struct fan_info_st fan_info[] =
+{
+	{IT87_EC_FAN_TACO1, IT87_EC_FAN_TACO1_EXT, IT87_EC_FAN_SMART_PWM1, IT87_EC_FAN_PWM1, 0x1},
+	{IT87_EC_FAN_TACO2, IT87_EC_FAN_TACO2_EXT, IT87_EC_FAN_SMART_PWM2, IT87_EC_FAN_PWM2, 0x2},
+};
+
+/* 4 steps of speed */
+static unsigned char fan_stop_speed = 0;
+static unsigned char fan_slow_speed = 150;
+static unsigned char fan_fast_speed = 200;
+static unsigned char fan_full_speed = 255;
+
+/* threshold & flag */
+static unsigned int fan_threshold = 100;
+static unsigned int flag_show_speed_by_string = 1;
+
+/* ************** HDD Control Driver ************* */
+
+/* pci device */
+struct pci_dev *pdev = NULL;
+
+/* declare for file and directory of procfs */
+static struct proc_dir_entry *hotplug_dir;
+static struct proc_dir_entry *power_control_dir;
+static struct proc_dir_entry *hotplug_sata_file[MAX_SUPPORTED_DISKS];
+static struct proc_dir_entry *power_control_hdd_file[MAX_SUPPORTED_DISKS];
+
+/* GPIO base address */
+unsigned int ich10r_gpio_base_addr;
+
+/* polling timer */
+struct timer_list sata_hotplug_polling_timer;
+
+/* hotplug status information strcture */
+struct sata_hotplug_data_st sata_hotplug_data[MAX_SUPPORTED_DISKS];
+
+/* HDD information strcture */
+static struct sugi_hdd_info_st sugi_hdd_info[] = {
+	{GP_LVL,	HDD0_PRESENT_BIT,	GP_LVL,		HDD0_POWER_BIT,	HDD0_POWER_MASK},
+	{GP_LVL,	HDD1_PRESENT_BIT,	GP_LVL,		HDD1_POWER_BIT,	HDD1_POWER_MASK},
+	{GP_LVL,	HDD2_PRESENT_BIT,	GP_LVL,		HDD2_POWER_BIT,	HDD2_POWER_MASK},
+	{GP_LVL,	HDD3_PRESENT_BIT,	GP_LVL,		HDD3_POWER_BIT,	HDD3_POWER_MASK},
+	{GP_LVL,	HDD4_PRESENT_BIT,	GP_LVL2,	HDD4_POWER_BIT,	HDD4_POWER_MASK},
+	{GP_LVL,	HDD5_PRESENT_BIT,	GP_LVL2,	HDD5_POWER_BIT,	HDD5_POWER_MASK},
+	{GP_LVL,	HDD6_PRESENT_BIT,	GP_LVL2,	HDD6_POWER_BIT,	HDD6_POWER_MASK},
+	{GP_LVL,	HDD7_PRESENT_BIT,	GP_LVL2,	HDD7_POWER_BIT,	HDD7_POWER_MASK},
+};
+
+/* ***************** CMOS Driver ***************** */
+/* device nodes */
+struct device *cmos_dev;
+dev_t sugit_cmos = MKDEV(sugi_cmos_major, sugi_cmos_minor);
+
+unsigned int ich10r_pm_base_addr;
+unsigned short afterg3_en;
+
+/* Device ID offset */
+unsigned char device_id_offset[32] = {0x46, 0x47, 0x48, 0x49, 0x4a, 0x4b, 0x4c, 0x4d,
+																0x4e, 0x4f, 0x50, 0x51, 0x52, 0x53, 0x54, 0x55,
+																0x56, 0x57, 0x59, 0x5a, 0x5b, 0x5c, 0x5d, 0x5e,
+																0x5f, 0x66, 0x67, 0x68, 0x69, 0x6a, 0x6b, 0x6c};
+
+/* checksum offset */
+unsigned char checksum_offset[4] = {0x79, 0x7a, 0x7b, 0x7c};
+
+/* ASCII string to integer */																
+struct strtoint_st strtoint_info[] = {
+	{0x30, 0x0}, {0x31, 0x1}, {0x32, 0x2}, {0x33, 0x3},
+	{0x34, 0x4}, {0x35, 0x5}, {0x36, 0x6}, {0x37, 0x7},
+	{0x38, 0x8}, {0x39, 0x9}, {0x61, 0xa}, {0x62, 0xb},
+	{0x63, 0xc}, {0x64, 0xd}, {0x65, 0xe}, {0x66, 0xf},
+	{0x41, 0xa}, {0x42, 0xb}, {0x43, 0xc}, {0x44, 0xd},
+	{0x45, 0xe}, {0x46, 0xf},
+};
+
+static unsigned int bios_ver;
+
+/* *************** Boaed ID Driver *************** */
+
+struct device *boardid_dev;
+dev_t sugit_boardid = MKDEV(sugi_boardid_major, sugi_boardid_minor);
+unsigned int boardid_num;
+
+/* ************* protocol for IT8721 ************* */
+void EnterMBPnP(void)
+{
+	outb(0x87, CONFIG_ADDR_PORT);
+	outb(0x01, CONFIG_ADDR_PORT);
+	outb(0x55, CONFIG_ADDR_PORT);
+	outb(0x55, CONFIG_ADDR_PORT);
+}
+void ExitMBPnP(void)
+{
+	outb(0x02, CONFIG_ADDR_PORT);
+	outb(0x02, CONFIG_DATA_PORT);
+}
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-1
+ * Description: Implement functions of button driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ************** implement function ************* */
+
+/* ----------- get GPIO status ----------- */
+static int it87_gpio_getsts(int pin)
+{
+	int	off;
+	if(pin == BTN_DISP){
+		off = IT87_GP35_BIT5;	//pin number of DISP button
+	}else{
+		off = IT87_GP34_BIT4;	//pin number of FUNC button
+	}		
+
+	return inb(it87_gpioset3_base_addr) & off;
+}
+
+/* ------------- button timer ------------ */	
+static void timer_function(unsigned long data)
+{
+	int	pin_sts;
+
+	pin_sts=it87_gpio_getsts(data);
+	
+	if(pin_sts){
+	//Clear de-bounce ping SMI status
+		EnterMBPnP();
+		outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+		outb(IT87_DEB0DEB1 | IT87_SMI_STS2_PBD, CONFIG_DATA_PORT);		
+		ExitMBPnP();
+	//Delete timer
+		del_timer(&btn_timer);
+	}
+	else
+		mod_timer(&btn_timer, jiffies + TIMER_DELAY);
+}
+
+/* ---------- get button status ---------- */
+static void *
+sugi_button_status_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_button_status_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_button_status_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_button_status_seq_show(struct seq_file *m, void *v)
+{
+	struct button_info_st *button_info = (struct button_info_st *)m->private;
+	unsigned char smi_sts;
+
+	EnterMBPnP();
+
+	//Get SMI status of two de-bounce pin
+	outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+	smi_sts = inb(CONFIG_DATA_PORT);
+	smi_sts &= IT87_SMI_DEB_MASK;
+
+	ExitMBPnP();
+
+	//Check which button was pressed
+	if ((smi_sts & button_info->reg_stat))
+		seq_printf(m, "on\n");
+	else
+		seq_printf(m, "off\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_button_status_seq_ops = {
+	.start	= sugi_button_status_seq_start,
+	.next	= sugi_button_status_seq_next,
+	.stop	= sugi_button_status_seq_stop,
+	.show	= sugi_button_status_seq_show,
+};
+
+static int
+sugi_button_status_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct button_info_st *button_info = (struct button_info_st *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_button_status_seq_ops,
+			       sizeof(button_info));
+	if (ret) {
+		return ret;
+	}
+	m = file->private_data;
+	m->private = button_info;
+	return 0;
+}
+
+static const
+struct file_operations sugi_button_status_file_ops = {
+	.open		= sugi_button_status_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+/* ----------- interrupt handler ---------- */
+static irqreturn_t sugi_interrupt(int irq, void *dev_id)
+{
+	int	pin=0;
+	unsigned char smi_sts;
+	
+#ifdef CONFIG_BUFFALO_PLATFORM
+	char msg[32];
+	memset(msg, 0, sizeof(msg));
+#endif
+	
+	/* get SMI status of two de-bounce pin */
+	EnterMBPnP();	
+	
+	outb(IT87_REG_SMI_STS2, CONFIG_ADDR_PORT);
+	smi_sts = inb(CONFIG_DATA_PORT);
+	
+	ExitMBPnP();
+	
+	/* check if the interrupt source is PBD's IRQ */
+	if(smi_sts & IT87_SMI_STS2_PBD)
+	{
+		smi_sts &= IT87_SMI_DEB_MASK;
+		
+		/* check which button was pressed */
+		if(smi_sts == IT87_DEB0){
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				sprintf(msg, "micon_interrupts");
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			pin = BTN_FUNC;
+		}
+		else if(smi_sts == IT87_DEB1){
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				sprintf(msg, "micon_interrupts");
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			pin = BTN_DISP;
+		}
+		
+		/* setup timer for checking button GPIO status */
+ 		init_timer(&btn_timer);
+		btn_timer.expires = jiffies + TIMER_DELAY;
+		btn_timer.data = pin;
+		btn_timer.function = timer_function;
+		add_timer(&btn_timer);
+		
+		#ifdef CONFIG_BUFFALO_PLATFORM
+			if(msg[0] != '\0')
+				buffalo_kernevnt_queuein(msg);
+		#endif
+	}
+	return IRQ_HANDLED;
+}
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-2
+ * Description: Implement functions of fan control driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ************* implement functions ************* */
+
+/* ----------- get temperature ---------- */
+unsigned int get_temp(unsigned char temp_num)
+{
+	unsigned int	ret = 0;
+	
+	if(temp_num==2){
+		outb(IT87_EC_TMPIN3, IT87_EC_ADDR_REG);
+		ret = inb(IT87_EC_DATA_REG);
+		return ret;
+	}
+	
+	rdmsr_on_cpu(temp_num, MSR_IA32_THERM_STATUS, &eax, &edx);
+	ret = tjmax[temp_num] - ((eax >> 16)&0x7f);
+	
+	return ret;
+}
+
+/* ---------- get rotation speed --------- */
+unsigned int get_fan_rpm(unsigned char fan_num)
+{
+	unsigned int	read_value;
+	unsigned int	read_value_ext;
+	unsigned int	ret = 0;
+	
+	outb(fan_info[fan_num].reg, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	outb(fan_info[fan_num].reg_ext, IT87_EC_ADDR_REG);
+	read_value_ext = inb(IT87_EC_DATA_REG);
+	ret = 1350000/(read_value_ext*256+read_value)/2;
+
+	if(ret < fan_threshold)
+		ret = 0;
+	
+	return ret;
+}
+
+/* -------------- get speed -------------- */
+unsigned int get_fan_speed(unsigned char fan_num)
+{
+	unsigned int	read_value;
+
+		
+	outb(IT87_EC_FAN_MAIN_CTL, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value |= fan_info[fan_num].offset;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	outb(fan_info[fan_num].reg_smart_pwm, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+
+	return read_value;
+}
+
+/* -------------- set speed -------------- */
+unsigned int set_fan_speed(unsigned char fan_num, unsigned char set_val)
+{
+	unsigned int	write_data;
+	unsigned char	read_value;
+
+	/*if(fan_info[fan_num].reg_smart_pwm == 0 ||
+		fan_info[fan_num].reg_pwm == 0)
+	{
+		return -EINVAL;
+	}*/
+
+	outb(IT87_EC_FAN_MAIN_CTL, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value |= fan_info[fan_num].offset;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	write_data = set_val;
+	outb(fan_info[fan_num].reg_smart_pwm, IT87_EC_ADDR_REG);
+	outb(write_data, IT87_EC_DATA_REG);
+
+	outb(fan_info[fan_num].reg_pwm, IT87_EC_ADDR_REG);
+	read_value = inb(IT87_EC_DATA_REG);
+	read_value &= 0x7F;
+	outb(read_value, IT87_EC_DATA_REG);
+
+	return 0;
+}
+
+/* --------- convert string to ul -------- */
+static unsigned long fan_speed_str_to_ul(char *buf)
+{
+	int len = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len == 5) && (strncmp(buf, "stop", strlen("stop")) == 0))
+		return fan_stop_speed;
+	else if((len == 5) && (strncmp(buf, "slow", strlen("slow")) == 0))
+		return fan_slow_speed;
+	else if((len == 5) && (strncmp(buf, "fast", strlen("fast")) == 0))
+		return fan_fast_speed;
+	else if((len == 5) && (strncmp(buf, "full", strlen("full")) == 0))
+		return fan_full_speed;
+
+	return simple_strtoul(buf, NULL, 10);
+}
+
+/* --------- convert ul to string -------- */
+static unsigned long fan_speed_ul_to_str(char *buf, size_t len, unsigned long speed)
+{
+	if(speed <= fan_stop_speed)
+		snprintf(buf, len, "stop");
+	else if(speed > fan_stop_speed && speed <= fan_slow_speed)
+		snprintf(buf, len, "slow");
+	else if(speed > fan_slow_speed && speed <= fan_fast_speed)
+		snprintf(buf, len, "fast");
+	else if(speed > fan_fast_speed)
+		snprintf(buf, len, "full");
+	else
+		snprintf(buf, len, "Unknown");
+		
+	return 0;
+}
+
+/* ************** device attributes ************** */
+
+/* -------- temperature attributes ------- */
+static ssize_t show_temp1(struct device *dev, struct device_attribute *attr, char *buf)
+
+{
+	return sprintf(buf, "%d\n", get_temp(0));
+}
+
+static ssize_t show_temp2(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_temp(1));
+}
+
+static ssize_t show_temp3(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_temp(2));
+}
+
+DEVICE_ATTR(temp1, 0444, show_temp1, NULL);
+DEVICE_ATTR(temp2, 0444, show_temp2, NULL);
+DEVICE_ATTR(temp3, 0444, show_temp3, NULL);
+
+/* ------ rotation speed attributes ------ */
+static ssize_t show_fan1_rpm(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_fan_rpm(0));
+}
+
+static ssize_t show_fan2_rpm(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", get_fan_rpm(1));
+}
+
+DEVICE_ATTR(fan1_rpm, 0444, show_fan1_rpm, NULL);
+DEVICE_ATTR(fan2_rpm, 0444, show_fan2_rpm, NULL);
+
+/* fan3_rpm and fan4_rpm nodes are added to fit Buffalo's requirement. */
+DEVICE_ATTR(fan3_rpm, 0444, show_fan1_rpm, NULL);
+DEVICE_ATTR(fan4_rpm, 0444, show_fan2_rpm, NULL);
+
+/* ----------- speed attributes ---------- */
+static ssize_t show_fan1_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(0));
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else
+		return sprintf(buf, "%d\n", get_fan_speed(0));
+}
+static ssize_t store_fan1_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+
+	set_fan_speed(0, (unsigned char)(write_val & 0xff));
+
+	return count;
+}
+
+static ssize_t show_fan2_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(1));
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else
+		return sprintf(buf, "%d\n", get_fan_speed(1));
+}
+static ssize_t store_fan2_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+
+	set_fan_speed(1, (unsigned char)(write_val & 0xff));
+	return count;
+}
+
+static ssize_t show_fan3_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	unsigned int temp;
+	if(flag_show_speed_by_string == 1)
+	{
+		char szSpeed[32];
+		fan_speed_ul_to_str(szSpeed, sizeof(szSpeed), get_fan_speed(0));
+		/* get_fan_speed(1) is used to set fan4 as software control mode */
+		temp = get_fan_speed(1);
+		return sprintf(buf, "%s\n", szSpeed);
+	}
+	else{
+		/* get_fan_speed(1) is used to set fan4 as software control mode */
+		temp = get_fan_speed(1);
+		return sprintf(buf, "%d\n", get_fan_speed(0));
+	}
+}
+static ssize_t store_fan3_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long write_val = fan_speed_str_to_ul((char*) buf );
+	if(write_val > 0xff)
+		return -EINVAL;
+	
+	set_fan_speed(0, (unsigned char)(write_val & 0xff));
+	set_fan_speed(1, (unsigned char)(write_val & 0xff));
+	return count;
+}
+
+DEVICE_ATTR(fan1_speed, 0644, show_fan1_speed, store_fan1_speed);
+DEVICE_ATTR(fan2_speed, 0644, show_fan2_speed, store_fan2_speed);
+
+/* fan3_speed and fan4_speed are added to fit Buffalo's requirement,
+   and their behavior are same to Matsu. */
+DEVICE_ATTR(fan3_speed, 0644, show_fan3_speed, store_fan3_speed);
+DEVICE_ATTR(fan4_speed, 0644, show_fan2_speed, store_fan2_speed);
+
+/* ---------- 4 steps attributes --------- */
+static ssize_t show_fan_stop_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_stop_speed);
+}
+static ssize_t store_fan_stop_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_stop_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_slow_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_slow_speed);
+}
+static ssize_t store_fan_slow_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_slow_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_fast_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_fast_speed);
+}
+static ssize_t store_fan_fast_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_fast_speed = tmp_speed;
+	return count;
+}
+
+static ssize_t show_fan_full_speed(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_full_speed);
+}
+static ssize_t store_fan_full_speed(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_speed = simple_strtoul(buf, NULL, 10);
+	if(tmp_speed > 0xFF)
+		return -EINVAL;
+
+	fan_full_speed = tmp_speed;
+	return count;
+}
+
+DEVICE_ATTR(fan_stop_speed, 0644, show_fan_stop_speed, store_fan_stop_speed);
+DEVICE_ATTR(fan_slow_speed, 0644, show_fan_slow_speed, store_fan_slow_speed);
+DEVICE_ATTR(fan_fast_speed, 0644, show_fan_fast_speed, store_fan_fast_speed);
+DEVICE_ATTR(fan_full_speed, 0644, show_fan_full_speed, store_fan_full_speed);
+
+/* --------- read mode attribute --------- */
+static ssize_t show_show_speed_by_string(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", flag_show_speed_by_string);
+}
+static ssize_t store_show_speed_by_string(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long value = simple_strtoul(buf, NULL, 10);
+	
+	if(value != 0 && value != 1)
+		return -EINVAL;
+
+	flag_show_speed_by_string = value;
+
+	return count;
+}
+DEVICE_ATTR(show_speed_by_string, 0644, show_show_speed_by_string, store_show_speed_by_string);
+
+/* --------- threshold attribute --------- */
+static ssize_t show_fan_threshold(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", fan_threshold);
+}
+static ssize_t store_fan_threshold(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	unsigned long tmp_threshold = simple_strtoul(buf, NULL, 10);
+	fan_threshold = tmp_threshold;
+	return count;
+}
+DEVICE_ATTR(fan_threshold, 0644, show_fan_threshold, store_fan_threshold);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_fan_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_fan_major);
+}
+DEVICE_ATTR(sugi_fan_dev, 0444, show_sugi_fan_dev, NULL);
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-3
+ * Description: Implement functions of HDD control driver
+ * ---------------------------------------------------------------------------------------------- */
+static void *
+sugi_hotplug_status_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_hotplug_status_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_hotplug_status_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_hotplug_status_seq_show(struct seq_file *m, void *v)
+{
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)m->private;
+
+	if (inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_PRESENT_REG) & hdd_info->HDD_PRESENT_BIT)
+		seq_printf(m, "unplugged\n");
+	else
+		seq_printf(m, "plugged\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_hotplug_status_seq_ops = {
+	.start	= sugi_hotplug_status_seq_start,
+	.next	= sugi_hotplug_status_seq_next,
+	.stop	= sugi_hotplug_status_seq_stop,
+	.show	= sugi_hotplug_status_seq_show,
+};
+
+static int
+sugi_hotplug_status_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_hotplug_status_seq_ops,
+			       sizeof(hdd_info));
+	if (ret) {
+		return ret;
+	}
+	m = file->private_data;
+	m->private = hdd_info;
+	return 0;
+}
+
+static const
+struct file_operations sugi_hotplug_status_file_ops = {
+	.open		= sugi_hotplug_status_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static void *
+sugi_power_control_seq_start(struct seq_file *s, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+static void *
+sugi_power_control_seq_next(struct seq_file *s, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+static void
+sugi_power_control_seq_stop(struct seq_file *s, void *v)
+{
+}
+
+static int
+sugi_power_control_seq_show(struct seq_file *m, void *v)
+{
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)m->private;
+
+	if (inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG) & hdd_info->HDD_POWER_BIT)
+		seq_printf(m, "on\n");
+	else
+		seq_printf(m, "off\n");
+
+	return 0;
+}
+
+static const
+struct seq_operations sugi_power_control_seq_ops = {
+	.start	= sugi_power_control_seq_start,
+	.next	= sugi_power_control_seq_next,
+	.stop	= sugi_power_control_seq_stop,
+	.show	= sugi_power_control_seq_show,
+};
+
+static int
+sugi_power_control_open(struct inode *inode, struct file *file)
+{
+	int ret;
+	struct seq_file *m;
+	struct sugi_hdd_info *hdd_info = (struct sugi_hdd_info *)PDE_DATA(inode);
+
+	ret = seq_open_private(file, &sugi_power_control_seq_ops,
+			       sizeof(hdd_info));
+	if (ret) {
+		
+		return ret;
+	}
+	m = file->private_data;
+	m->private = hdd_info;
+	return 0;
+}
+
+static ssize_t
+sugi_power_control_write(struct file *file, const char __user *buffer,
+			 size_t count, loff_t *ppos)
+{
+	int tmpgpioval;
+	struct sugi_hdd_info_st *hdd_info = (struct sugi_hdd_info_st *)PDE_DATA(file_inode(file));
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = '\0';
+
+	tmpgpioval = inl(ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+
+	if (strncmp(kbuf, "off", strlen("off")) == 0) {
+		if (tmpgpioval & hdd_info->HDD_POWER_BIT) {
+			tmpgpioval &= hdd_info->HDD_POWER_MASK;
+			outl(tmpgpioval, ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+			return count;
+		}
+	}
+	
+	if(strncmp(kbuf, "on", strlen("on")) == 0){
+		if (!(tmpgpioval & hdd_info->HDD_POWER_BIT)){
+			tmpgpioval |= hdd_info->HDD_POWER_BIT;
+			outl(tmpgpioval, ich10r_gpio_base_addr + hdd_info->HDD_GPIO_POWER_REG);
+			return count;
+		}
+	}
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static const
+struct file_operations sugi_power_control_file_ops = {
+	.open		= sugi_power_control_open,
+	.read		= seq_read,
+	.write		= sugi_power_control_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+/* ----------- polling function ---------- */
+
+static void SataHotplugPollingUpdatePinstat(void)
+{
+	unsigned int i = 0;
+	
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		sata_hotplug_data[i].presentpinstat = (inl(ich10r_gpio_base_addr + sugi_hdd_info[i].HDD_GPIO_PRESENT_REG) & sugi_hdd_info[i].HDD_PRESENT_BIT)? SATA_STAT_UNPLUGGED:SATA_STAT_PLUGGED;
+	}
+}
+
+static void SataHotplugPolling(unsigned long data)
+{
+	unsigned int i = 0;
+	char buf[32];
+
+	SataHotplugPollingUpdatePinstat();
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		if(sata_hotplug_data[i].prevplugstat == sata_hotplug_data[i].presentpinstat)
+		{
+			sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+			continue;
+		}
+		--sata_hotplug_data[i].loops;
+
+		if(sata_hotplug_data[i].loops == 0)
+		{
+			if(sata_hotplug_data[i].presentpinstat == SATA_STAT_PLUGGED)
+				sprintf(buf, PLUGGED_EVENT_MSG, i);
+			else
+				sprintf(buf, UNPLUGGED_EVENT_MSG, i);
+
+			#ifdef CONFIG_BUFFALO_PLATFORM
+				buffalo_kernevnt_queuein(buf);
+			#else
+				printk("EVENT IS OCCURRED\n");
+			#endif
+			
+			sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+			sata_hotplug_data[i].prevplugstat = sata_hotplug_data[i].presentpinstat;
+		}
+	}
+	sata_hotplug_polling_timer.expires += SATA_POL_INTERVAL;
+	add_timer(&sata_hotplug_polling_timer);
+}
+
+static unsigned long SataHotplugPollingStart(void)
+{
+	unsigned int i = 0;
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++)
+	{
+		sata_hotplug_data[i].prevplugstat = SATA_STAT_UNKNOWN;
+		sata_hotplug_data[i].loops = SATA_POL_LOOPS;
+	}
+
+        init_timer(&sata_hotplug_polling_timer);
+        sata_hotplug_polling_timer.expires = jiffies + SATA_POL_INTERVAL;
+        sata_hotplug_polling_timer.function = SataHotplugPolling;
+        add_timer(&sata_hotplug_polling_timer);
+
+        return 0;
+}
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-4
+ * Description: Implement functions of CMOS driver
+ * ---------------------------------------------------------------------------------------------- */
+static unsigned char checksum_caculation(unsigned char wol, unsigned char acp, unsigned char lan)
+{
+	return (CMOS_CHANGE_CHECKSUM - wol - (acp << 1) - (lan * 6));
+}
+static int smi_write(void)
+{
+	int smi_count = 0;
+	int read_count = 0;
+	
+	for(smi_count = 0; smi_count < 3; smi_count++){
+		outb(SW_SMI_WRITE, SW_SMI_OFFSET);
+		for(read_count = 0; read_count < 10; read_count++){
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			/* return error code of write "pass" or "fail" */
+			if(inb(CMOS_DATA_PORT) == 0x40 || inb(CMOS_DATA_PORT) == 0xEF || inb(CMOS_DATA_PORT) == 0xFF)
+				return inb(CMOS_DATA_PORT);
+			mdelay(100);
+		}
+	}
+	/* return 0 after sending SMI 3 times and waiting for 0.5s delay 10 times  */
+	return 0;
+}
+
+static int smi_read(void)
+{
+	int smi_count = 0;
+	int read_count = 0;
+	
+	/* clear 73h to 0 */
+	outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+	while(inb(CMOS_DATA_PORT))
+		outb(0x00, CMOS_DATA_PORT);
+	
+	for(smi_count = 0; smi_count < 3; smi_count++){
+		outb(SW_SMI_READ, SW_SMI_OFFSET);
+		for(read_count = 0; read_count < 10; read_count++){
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			/* return error code of read "pass" or "fail" */
+			if(inb(CMOS_DATA_PORT) == 0x40 || inb(CMOS_DATA_PORT) == 0xEF)
+				return inb(CMOS_DATA_PORT);
+			mdelay(100);
+		}
+	}
+	/* return 0 after sending SMI 3 times and waiting for 0.5s delay 10 times  */
+	return 0;
+}
+
+/* -------- wake on LAN attribute -------- */
+static ssize_t show_wol_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret == 0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret == 1){
+		return sprintf(buf, "on\n");
+	}
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_wol_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len != 3) && (len != 4)){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return count;
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return count;
+			case 0x40:
+				outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+				lanboot_setting_value = inb(CMOS_DATA_PORT);
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return count;
+		}
+	}
+	
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	power_setting_value = inb(CMOS_DATA_PORT);
+		
+	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+		outb(WOL_OFFSET, CMOS_INDEX_PORT);
+		outb(WOL_ENABLE, CMOS_DATA_PORT);
+		
+		wol_setting_value = inb(CMOS_DATA_PORT);
+		if(wol_setting_value == WOL_ENABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+		outb(WOL_OFFSET, CMOS_INDEX_PORT);
+		outb(WOL_DISABLE, CMOS_DATA_PORT);
+		
+		wol_setting_value = inb(CMOS_DATA_PORT);
+		if(wol_setting_value == WOL_DISABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	if(bios_ver >=209){
+		ret = smi_write();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				break;
+			case 0xEF:
+				printk("NVRAM_CMOS_COMPARE_FAIL\n");
+				break;
+			case 0xFF:
+				printk("NVRAM_WRITE_FAIL\n");
+				break;
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				break;
+		}
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(wol_setting, 0644, show_wol_setting, store_wol_setting);
+
+/* ------- AC power loss attribute ------- */
+static ssize_t show_power_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret==0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret==1){
+		return sprintf(buf, "on\n");
+	}
+	else if(ret==2){
+		return sprintf(buf, "last state\n");
+	}
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_power_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+		
+//	if((len != 3) || (len != 4) || (len != 5)){
+//		printk("WRONG_STRING [%d]\n", len);
+//		return count;
+//	}
+		
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return count;
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return count;
+			case 0x40:
+				outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+				lanboot_setting_value = inb(CMOS_DATA_PORT);
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return count;
+		}
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	wol_setting_value = inb(CMOS_DATA_PORT);
+	
+//	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+	if(strncmp(buf, "on", strlen("on")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_POWER_ON, CMOS_DATA_PORT);
+		
+		if(bios_ver < 209){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en &=(~0x0001);
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_POWER_ON){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+//	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+	if(strncmp(buf, "off", strlen("off")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_POWER_OFF, CMOS_DATA_PORT);
+		
+		if(bios_ver < 209){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en |= 0x0001;
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_POWER_OFF){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+//	if((len == 5) && (strncmp(buf, "last", strlen("last")) == 0)){
+	if(strncmp(buf, "last", strlen("last")) == 0){
+		outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+		outb(AC_POWER_LOSS_LAST_STATE, CMOS_DATA_PORT);
+		
+		if(bios_ver){
+			ret = pci_read_config_word(pdev, GEN_PMCON_3, &afterg3_en);
+		afterg3_en &= 0xFFFE;
+			ret = pci_write_config_word(pdev, GEN_PMCON_3, afterg3_en);
+		}
+		
+		power_setting_value = inb(CMOS_DATA_PORT);
+		if(power_setting_value == AC_POWER_LOSS_LAST_STATE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	if(bios_ver >=209){
+		ret = smi_write();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				break;
+			case 0xEF:
+				printk("NVRAM_CMOS_COMPARE_FAIL\n");
+				break;
+			case 0xFF:
+				printk("NVRAM_WRITE_FAIL\n");
+				break;
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				break;
+		}
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(power_setting, 0644, show_power_setting, store_power_setting);
+
+/* -------- Gbe LAN boot attribute ------- */
+static ssize_t show_lanboot_setting(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int ret;
+	
+	if(bios_ver >= 209){
+		ret = smi_read();
+		
+		switch(ret){
+			case 0: 
+				printk("BIOS_NO_RESPONSE\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0xEF:
+				printk("NVRAM_READ_FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+			case 0x40:
+				break;
+			default:
+				printk("UNKNOWN FAIL\n");
+				return sprintf(buf, "UNKNOWN\n");
+		}
+	}
+	
+	outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+	ret = inb(CMOS_DATA_PORT);
+	
+	if(ret==0){
+		return sprintf(buf, "off\n");
+	}
+	else if(ret==1){
+		return sprintf(buf, "on\n");
+	}
+
+	return sprintf(buf, "UNKNOWN\n");
+}
+static ssize_t store_lanboot_setting(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int ret;
+	int len = 0;
+	unsigned char wol_setting_value = 0;
+	unsigned char power_setting_value = 0;
+	unsigned char lanboot_setting_value = 0;
+	unsigned char checksum_caculated = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if((len != 3) && (len != 4)){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	ret = smi_read();
+		
+	switch(ret){
+		case 0: 
+			printk("BIOS_NO_RESPONSE\n");
+			return count;
+		case 0xEF:
+			printk("NVRAM_READ_FAIL\n");
+			return count;
+		case 0x40:
+			break;
+		default:
+			printk("UNKNOWN FAIL\n");
+			return count;
+	}
+	
+	outb(WOL_OFFSET, CMOS_INDEX_PORT);
+	wol_setting_value = inb(CMOS_DATA_PORT);
+	outb(AC_POWER_LOSS_OFFSET, CMOS_INDEX_PORT);
+	power_setting_value = inb(CMOS_DATA_PORT);
+		
+	if((len == 3) && (strncmp(buf, "on", strlen("on")) == 0)){
+		outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+		outb(LANBOOT_ENABLE, CMOS_DATA_PORT);
+		
+		lanboot_setting_value = inb(CMOS_DATA_PORT);
+		if(lanboot_setting_value == LANBOOT_ENABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+	
+	if((len == 4) && (strncmp(buf, "off", strlen("off")) == 0)){
+		outb(LANBOOT_OFFSET, CMOS_INDEX_PORT);
+		outb(LANBOOT_DISABLE, CMOS_DATA_PORT);
+		
+		lanboot_setting_value = inb(CMOS_DATA_PORT);
+		if(lanboot_setting_value == LANBOOT_DISABLE){
+			checksum_caculated = checksum_caculation(wol_setting_value, power_setting_value, lanboot_setting_value);
+			outb(CMOS_CHECKSUM_OFFSET, CMOS_INDEX_PORT);
+			outb(checksum_caculated, CMOS_DATA_PORT);
+		}
+		else
+			printk("CMOS_VALUE_FAIL\n");
+	}
+
+	ret = smi_write();
+		
+	switch(ret){
+		case 0: 
+			printk("BIOS_NO_RESPONSE\n");
+			break;
+		case 0xEF:
+			printk("NVRAM_CMOS_COMPARE_FAIL\n");
+			break;
+		case 0xFF:
+			printk("NVRAM_WRITE_FAIL\n");
+			break;
+		case 0x40:
+			break;
+		default:
+			printk("UNKNOWN FAIL\n");
+			break;
+	}
+
+	return count;
+}
+
+DEVICE_ATTR(lanboot_setting, 0644, show_lanboot_setting, store_lanboot_setting);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_cmos_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_cmos_major);
+}
+DEVICE_ATTR(sugi_cmos_dev, 0444, show_sugi_cmos_dev, NULL);
+
+/* ----------- PID attribute ------------ */
+static ssize_t show_device_id(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int i=0;
+	char rv[32]; 
+	
+	for(i=0; i<=31; i++){
+		outb(device_id_offset[i], CMOS_INDEX_PORT);
+		rv[i] = inb(CMOS_DATA_PORT);
+	}
+	
+	return sprintf(buf, "%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c%c\n",
+	rv[0], rv[1], rv[2], rv[3], rv[4], rv[5], rv[6], rv[7], 
+	rv[8], rv[9], rv[10], rv[11], rv[12], rv[13], rv[14], rv[15],
+	rv[16], rv[17], rv[18], rv[19], rv[20], rv[21], rv[22], rv[23], 
+	rv[24], rv[25], rv[26], rv[27], rv[28], rv[29], rv[30], rv[31]);
+}
+
+static ssize_t store_device_id(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int i;
+	int len = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if(len != 33){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	if(len == 33){
+		for(i = 0; i <= 31; i++){
+			if((buf[i] < 32) || (buf[i] > 126)){
+				printk("WRONG_STRING\n");
+				return count;
+			}
+		}
+	
+		for(i = 0; i <= 31; i++){
+			outb(device_id_offset[i], CMOS_INDEX_PORT);
+			outb(buf[i], CMOS_DATA_PORT);
+		}
+	}
+	
+	return count;
+}
+
+DEVICE_ATTR(device_id, 0644, show_device_id, store_device_id);
+
+/* --------- checksum attribute ---------- */
+static ssize_t show_checksum(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	int i;
+	unsigned int rv = 0;
+	
+	for(i=0; i<=3; i++) {
+		outb(checksum_offset[i], CMOS_INDEX_PORT);
+		rv |= inb(CMOS_DATA_PORT) << 8*(3-i);
+	}
+	
+	return sprintf(buf, "%08x\n", rv);
+}
+
+static ssize_t store_checksum(struct device *dev, struct device_attribute *attr, const char *buf, size_t count)
+{
+	int i, j, tmp, len=0;
+	unsigned char checksum_orig[8];
+	unsigned char success_flag = 0;
+	
+	while(buf[len])
+		len++;
+	
+	if(len != 9){
+		printk("WRONG_STRING\n");
+		return count;
+	}
+	
+	else if(len == 9){
+		for(i=0; i<=7; i++) {
+			for(j=0; j<=21; j++) {
+				if(buf[i] == strtoint_info[j].strg){
+					checksum_orig[i] = strtoint_info[j].inte;
+					success_flag = 1;
+				}
+				else if (j == 21 && success_flag == 0){
+					printk("WRONG_STRING\n");
+					return count;
+				}
+			}
+			success_flag = 0;
+		}
+	
+		for(i=0; i<=3; i++) {
+			tmp = (checksum_orig[2*i] << 4) + checksum_orig[2*i+1];
+			outb(checksum_offset[i], CMOS_INDEX_PORT);
+			outb(tmp, CMOS_DATA_PORT);
+		}
+	}
+	
+	return count;
+}
+
+DEVICE_ATTR(checksum, 0644, show_checksum, store_checksum);
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2-5
+ * Description: Implement functions of board ID driver
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ---------- board ID attribute --------- */
+static ssize_t show_board_id(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	if(boardid_num==0)
+		return sprintf(buf,"2HDD\n");
+	else if(boardid_num==1)
+		return sprintf(buf,"4HDD\n");
+	else if(boardid_num==2)
+		return sprintf(buf,"6HDD\n");
+	else if(boardid_num==3)
+		return sprintf(buf,"8HDD\n");
+	else if(boardid_num==4)
+		return sprintf(buf,"1U\n");
+	
+	return sprintf(buf, "Unknown\n");
+}
+
+DEVICE_ATTR(board_id, 0444, show_board_id, NULL);
+
+/* ------- device number attribute ------- */
+static ssize_t show_sugi_boardid_dev(struct device *dev, struct device_attribute *attr, char *buf)
+{
+	return sprintf(buf, "%d\n", sugi_boardid_major);
+}
+
+DEVICE_ATTR(sugi_boardid_dev, 0444, show_sugi_boardid_dev, NULL);
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 3
+ * Description: Chipsets and file system sheeting
+ * ---------------------------------------------------------------------------------------------- */
+
+/* ------- proc file system setting ------ */
+static int init_proc_files(void)
+{
+	int i = 0;
+	char buf[32];
+	
+	/* create /proc/buffalo */
+#ifdef CONFIG_BUFFALO_PLATFORM
+	extern struct proc_dir_entry *get_proc_buffalo(void);
+	buffalo_dir = get_proc_buffalo();
+#else	/* CONFIG_BUFFALO_PLATFORM */
+	buffalo_dir = proc_mkdir(BUFFALO_DIR, NULL);
+#endif	/* CONFIG_BUFFALO_PLATFORM */
+	
+	/* create /proc/buffalo/gpio */
+	gpio_dir = proc_mkdir(GPIO_DIR, NULL);
+	
+	
+	/* button driver */
+	/* create /proc/buffalo/gpio/switch */
+	switch_dir = proc_mkdir(SWITCH_DIR, NULL);
+	
+	/* create /proc/buffalo/gpio/switch/func(display) */
+	for(i = 0; i < MAX_SUPPORTED_BUTTONS; i++){
+		switch_file[i] =
+			proc_create_data(button_info[i].name,
+					 S_IRUGO,
+					 switch_dir,
+					 &sugi_button_status_file_ops,
+					 &button_info[i]);
+	}
+
+	/* HDD control driver */
+	/* create /proc/buffalo/gpio/hotplug */
+	hotplug_dir = proc_mkdir(HOTPLUG_DIR, NULL);
+	
+	/* create /proc/buffalo/gpio/hotplug/sata# */
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "sata%d", i);
+		hotplug_sata_file[i] =
+			proc_create_data(buf, S_IRUGO,
+					 hotplug_dir,
+					 &sugi_hotplug_status_file_ops,
+					 &sugi_hdd_info[i]);
+	}
+
+	/* create /proc/buffalo/gpio/power_control */
+	power_control_dir = proc_mkdir(POWER_CONTROL_DIR, NULL);
+
+	/* create /proc/buffalo/gpio/power_control/hdd# */
+	for(i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "hdd%d", i);
+		power_control_hdd_file[i] =
+			proc_create_data(buf, S_IRUGO | S_IWUSR,
+					 power_control_dir,
+					 &sugi_power_control_file_ops,
+					 &sugi_hdd_info[i]);
+	}	
+
+	return 0;
+}
+
+
+/* ---------- sysfs file system ---------- */
+static int init_sysfs_files(void)
+{
+	int rv;
+	
+	if(sugi_cls)
+		return -EINVAL;
+
+	/* create /sys/class/sugi */
+	sugi_cls = class_create(THIS_MODULE, "sugi");
+
+
+	/* fan control driver */
+	/* create /sys/class/sugi/fan */
+	fan_dev = device_create(sugi_cls, NULL, sugit_fan, NULL, "fan");
+	
+	/* create /sys/class/sugi/fan/temp# */
+	rv = device_create_file(fan_dev, &dev_attr_temp1);
+	rv = device_create_file(fan_dev, &dev_attr_temp2);
+	rv = device_create_file(fan_dev, &dev_attr_temp3);
+	
+	/* create /sys/class/sugi/fan/fan#_rpm */
+	rv = device_create_file(fan_dev, &dev_attr_fan1_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan2_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan3_rpm);
+	rv = device_create_file(fan_dev, &dev_attr_fan4_rpm);
+	
+	/* create /sys/class/sugi/fan/fan#_speed */
+	rv = device_create_file(fan_dev, &dev_attr_fan1_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan2_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan3_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan4_speed);
+    
+	/* create /sys/class/sugi/fan/fan_pattern_speed */
+	rv = device_create_file(fan_dev, &dev_attr_fan_stop_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_slow_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_fast_speed);
+	rv = device_create_file(fan_dev, &dev_attr_fan_full_speed);
+    
+	/* create /sys/class/sugi/fan/show_speed_by string */
+	rv = device_create_file(fan_dev, &dev_attr_show_speed_by_string);
+    
+	/* create /sys/class/sugi/fan/fan_threshold */
+	rv = device_create_file(fan_dev, &dev_attr_fan_threshold);
+    
+	/* create /sys/class/sugi/fan/sugi_fan_dev */
+	rv = device_create_file(fan_dev, &dev_attr_sugi_fan_dev);
+	
+	
+	/* CMOS driver */
+	/* create /sys/class/sugi/cmos */
+	cmos_dev = device_create(sugi_cls, NULL, sugit_cmos, NULL, "cmos");
+	
+	/* create /sys/class/sugi/cmos/wol_setting */
+	rv = device_create_file(cmos_dev, &dev_attr_wol_setting);
+		
+	/* create /sys/class/sugi/cmos/power_setting */
+	rv = device_create_file(cmos_dev, &dev_attr_power_setting);
+		
+	/* create /sys/class/sugi/cmos/sugi_cmos_dev */
+	rv = device_create_file(cmos_dev, &dev_attr_sugi_cmos_dev);
+	
+		/* create /sys/class/sugi/cmos/pid */
+	rv = device_create_file(cmos_dev, &dev_attr_device_id);
+	
+	/* create /sys/class/sugi/cmos/checksum */
+	rv = device_create_file(cmos_dev, &dev_attr_checksum);
+  
+	/* create /sys/class/sugi/cmos/lanboot_setting */
+	/* this node and the related funciton will be 
+	   created if the BIOS version is newer than V209*/
+	if(bios_ver >= 209)
+		rv = device_create_file(cmos_dev, &dev_attr_lanboot_setting);
+  
+	
+	/* board ID driver */
+	/* create /sys/class/sugi/board */
+	boardid_dev = device_create(sugi_cls, NULL, sugit_boardid, NULL, "board");
+	
+	/* create /sys/class/sugi/board/board_id */
+	rv = device_create_file(boardid_dev, &dev_attr_board_id);
+		
+	/* create /sys/class/sugi/board/sugi_boardid_dev */
+	rv = device_create_file(boardid_dev, &dev_attr_sugi_boardid_dev);
+	
+	return 0;
+}
+
+/* ---------- BIOS version check --------- */
+static int bios_version_check(void)
+{
+	int i;
+	unsigned char* smbios_sm = NULL;
+	unsigned char* smbios_dmi = NULL;
+	unsigned char* smbios_eps = NULL;
+	unsigned char* smbios_base = NULL;
+	unsigned char* smbios_ver = NULL;
+	unsigned int smbios_base_addr = 0;
+
+	for(i = 0; i <= 0xFFF0; i += 0x01){
+		smbios_sm = ioremap(0x000F0000 + i, 4);
+		if(strncmp(smbios_sm, "_SM_", strlen("_SM_")) == 0){
+			smbios_dmi = ioremap(0x000F0000 + i + 0x10, 4);
+			if(strncmp(smbios_dmi, "_DMI_", strlen("_DMI_"))== 0){
+				smbios_eps = ioremap(0x000F0000 + i + 0x18, 4);
+				smbios_base_addr = ioread32(smbios_eps);
+				break;
+			}
+		}
+	}
+	
+	for(i = 0; i <= 0xFF; i += 0x01){
+		smbios_base = ioremap(smbios_base_addr + i, 1);
+		if(ioread8(smbios_base) == 0x33){
+			if(strncmp(smbios_base, "31SUG", strlen("31SUG")) == 0){
+				smbios_ver = ioremap(smbios_base_addr + i + 0x05, 1);
+				bios_ver = simple_strtoul(smbios_ver, NULL, 10);
+				iounmap(smbios_sm);
+				iounmap(smbios_dmi);
+				iounmap(smbios_eps);
+				iounmap(smbios_base);
+				iounmap(smbios_ver);
+				printk("BIOS VERSION : V%d\n",bios_ver);
+				return 0;
+			}
+		}
+	}
+
+	return 1;
+}
+/* ------------ IT8721 setting ----------- */
+	
+	/* button driver */
+void SetBTNMBPnP(void)
+{
+	unsigned int base_msb;
+	unsigned int base_lsb;
+	
+	/* select LDN 07h */	
+	outb(IT87_LDN_ADDR, CONFIG_ADDR_PORT);
+	outb(IT87_GPIO_LDN, CONFIG_DATA_PORT);
+	
+	/* find GPIO set3 base addr */
+	outb(IT87_SIMPLE_IO_BASE_MSB, CONFIG_ADDR_PORT);
+	base_msb = inb(CONFIG_DATA_PORT);
+	outb(IT87_SIMPLE_IO_BASE_LSB, CONFIG_ADDR_PORT);
+	base_lsb = inb(CONFIG_DATA_PORT);
+	it87_gpioset3_base_addr = (base_msb*256 + base_lsb) + GPIO_SET3_OFFSET;
+	
+	/* enable to generate SMI of PBD's IRQ */
+	outb(IT87_REG_SMI_CTL2, CONFIG_ADDR_PORT);
+	outb(inb(CONFIG_DATA_PORT)|0x01, CONFIG_DATA_PORT);
+	
+	/* set GPIO34/35 as de-bounce GPIO */
+	outb(IT87_REG_PNL_DBOUNCE0, CONFIG_ADDR_PORT);
+	outb(IT87_GP34_LOC | IT87_IRQEN, CONFIG_DATA_PORT);
+	
+	outb(IT87_REG_PNL_DBOUNCE1, CONFIG_ADDR_PORT);
+	outb(IT87_GP35_LOC, CONFIG_DATA_PORT);
+	
+	outb(IT87_REG_PNL_IRQ_SEL, CONFIG_ADDR_PORT);
+	outb(IT87_PNL_IRQ3, CONFIG_DATA_PORT);
+	}
+	
+/* fan control driver */
+void SetFANMBPnP(void)
+{
+	unsigned short BASE_ADDR_EXT;
+	unsigned short BASE_ADDR;
+
+	outb(IT87_LDN_ADDR, CONFIG_ADDR_PORT);
+	outb(IT87_EC_LDN, CONFIG_DATA_PORT);
+	outb(0x60,CONFIG_ADDR_PORT);
+	BASE_ADDR_EXT = inb(CONFIG_DATA_PORT)*256;
+	outb(0x61,CONFIG_ADDR_PORT);
+	BASE_ADDR = inb(CONFIG_DATA_PORT);
+  EC_BASE_ADDR = BASE_ADDR_EXT+BASE_ADDR;
+  IT87_EC_ADDR_REG = EC_BASE_ADDR+0x05;
+  IT87_EC_DATA_REG = EC_BASE_ADDR+0x06;
+}
+
+/* ------------ ich10r setting ----------- */
+static int ich10r_setting(void)
+{
+	int ret;
+	
+	pdev = pci_get_device(INTEL_ICH10R_VID, INTEL_ICH10R_DID, NULL);
+	if(!pdev)
+		return -ENODEV;
+	
+	ret = pci_read_config_dword(pdev, GPIOBASE, &ich10r_gpio_base_addr);
+	if(ret)
+		return -EINVAL;
+		
+	ret = pci_read_config_dword(pdev, PMBASE, &ich10r_pm_base_addr);
+	if(ret)
+		return -EINVAL;
+		
+	ich10r_gpio_base_addr &= 0x0000FF80;
+	
+	ich10r_pm_base_addr &= 0x0000FF80;
+	
+	/* Board ID driver */
+	/* set GPIO pin 29, 30 ,31 as GPIO function */
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL)|0xE0000000), ich10r_gpio_base_addr+GP_USE_SEL);
+	
+	/* set GPIO pin 29, 30 ,31 as input */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)|0xE0000000), ich10r_gpio_base_addr+GP_IO_SEL);
+	
+	/* get board ID relative GPIO pins status */
+	boardid_num = (inl(ich10r_gpio_base_addr+GP_LVL)&BOARD_ID_MASK) >> BOARD_ID_OFFSET;
+	
+	/* HDD control driver */
+	/* set relative GPIO pins as GPIO function */
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL)|0x0002A6FD), ich10r_gpio_base_addr+GP_USE_SEL);
+	outl((inl(ich10r_gpio_base_addr+GP_USE_SEL2)|0x01000007), ich10r_gpio_base_addr+GP_USE_SEL2);
+	
+	/* set hotplug relative GPIO pins as input */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)|0x0000A63C), ich10r_gpio_base_addr+GP_IO_SEL);
+	
+	/* set power control relative GPIO pins as outout */
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL)&0xFFFDFF3D), ich10r_gpio_base_addr+GP_IO_SEL);
+	outl((inl(ich10r_gpio_base_addr+GP_IO_SEL2)&0xFEFFFFF8), ich10r_gpio_base_addr+GP_IO_SEL2);
+	
+	return 0;
+}
+
+/* ------------ initialization ----------- */
+static int __init sugi_platform_init(void)
+{  	
+	int ret;
+	
+	/* request IRQ3 */
+	ret = request_irq(3, sugi_interrupt, IRQF_SHARED, DRVNAME, sugi_interrupt);
+	if (ret) {
+		printk("%s: REQUEST IRQ3 FAIL\n", __FUNCTION__);
+		free_irq(3, 0);
+		return -EBUSY;
+	}
+	
+	/* chipsets initilization */
+	/* ICH10R */
+	ret = ich10r_setting();
+	if (ret) {
+		printk("%s: ICH10R INITIALIZE FAIL\n", __FUNCTION__);
+		return -ENODEV;
+	}
+	/* IT8721 */	
+	EnterMBPnP();
+	SetFANMBPnP();
+	//ExitMBPnP();
+	
+	//EnterMBPnP();
+	SetBTNMBPnP();
+	ExitMBPnP();
+	
+	/* register device to system */	
+	ret = register_chrdev_region(sugit_fan, sugi_dev_count, DRVNAME);
+	ret = register_chrdev_region(sugit_cmos, sugi_dev_count, DRVNAME);
+	ret = register_chrdev_region(sugit_boardid, sugi_dev_count, DRVNAME);
+	
+	/* check BIOS verion */
+	ret = bios_version_check();
+	if (ret) {
+		printk("%s: BIOS VERSION CHECK FAIL\n", __FUNCTION__);
+		return -EINVAL;
+	}
+	
+	/* create sysfs file system */
+	ret = init_sysfs_files();
+	if (ret) {
+		printk("%s: SYSFS INITALIZE FAIL\n", __FUNCTION__);
+		return -ENOMEM;
+	}
+		
+	/* create proc file system */
+	ret = init_proc_files();
+	if (ret) {
+		printk("%s: PROCFS INITALIZE FAIL\n", __FUNCTION__);
+		return -ENOMEM;
+	}
+	
+	SataHotplugPollingStart();
+	
+	printk("SUGI_PLATFORM MODULE HAS BEEN INITIALIZED\n");
+	
+	return 0;
+}
+
+/* ----------------- exit ---------------- */
+static void __exit sugi_platform_exit(void)
+{
+	int i = 0;
+	char buf[32];
+	
+	/* delete hotplug polling timer */
+	del_timer(&sata_hotplug_polling_timer);
+	
+	/* disable and release IRQ3 */
+	disable_irq(3);
+	free_irq(3, sugi_interrupt);
+	
+	/* remove proc file system nodes */
+	for(i = 0; i < MAX_SUPPORTED_BUTTONS; i++){
+		remove_proc_entry(button_info[i].name, switch_dir);
+	}
+	
+	for (i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "hdd%d", i);
+		remove_proc_entry(buf, power_control_dir);
+	}
+	
+	for (i = 0; i < MAX_SUPPORTED_DISKS; i++){
+		sprintf(buf, "sata%d", i);
+		remove_proc_entry(buf, hotplug_dir);
+	}
+	
+	remove_proc_entry(SWITCH_DIR, NULL);
+	remove_proc_entry(HOTPLUG_DIR, NULL);
+	remove_proc_entry(POWER_CONTROL_DIR, NULL);
+	remove_proc_entry(GPIO_DIR, NULL);
+	remove_proc_entry(BUFFALO_DIR, NULL);
+	
+	/* remove sysfs file system */
+	device_remove_file(fan_dev, &dev_attr_temp1);
+	device_remove_file(fan_dev, &dev_attr_temp2);
+	device_remove_file(fan_dev, &dev_attr_temp3);
+	device_remove_file(fan_dev, &dev_attr_fan1_rpm);
+	device_remove_file(fan_dev, &dev_attr_fan2_rpm);
+	device_remove_file(fan_dev, &dev_attr_fan1_speed);
+	device_remove_file(fan_dev, &dev_attr_fan2_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_stop_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_slow_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_fast_speed);
+	device_remove_file(fan_dev, &dev_attr_fan_full_speed);
+	device_remove_file(fan_dev, &dev_attr_sugi_fan_dev);
+	device_remove_file(fan_dev, &dev_attr_fan_threshold);
+	device_remove_file(fan_dev, &dev_attr_show_speed_by_string);
+	
+	device_remove_file(cmos_dev, &dev_attr_wol_setting);
+	device_remove_file(cmos_dev, &dev_attr_power_setting);
+	device_remove_file(cmos_dev, &dev_attr_sugi_cmos_dev);
+	device_remove_file(cmos_dev, &dev_attr_device_id);
+	device_remove_file(cmos_dev, &dev_attr_checksum);
+	
+	if(bios_ver >= 209)
+		device_remove_file(cmos_dev, &dev_attr_lanboot_setting);
+	
+	device_remove_file(boardid_dev, &dev_attr_sugi_boardid_dev);
+	device_remove_file(boardid_dev, &dev_attr_board_id);
+	
+	device_destroy(sugi_cls, sugit_fan);
+	device_destroy(sugi_cls, sugit_cmos);
+	device_destroy(sugi_cls, sugit_boardid);
+	
+	class_destroy(sugi_cls);
+	
+	unregister_chrdev_region(sugit_fan, sugi_dev_count);
+	unregister_chrdev_region(sugit_cmos, sugi_dev_count);
+	unregister_chrdev_region(sugit_boardid, sugi_dev_count);
+  
+	printk("SUGI_PLATFORM MODULE HAS BEEN REMOVED\n");
+}
+
+module_init(sugi_platform_init);
+module_exit(sugi_platform_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/arch/x86/plat-usi/sugi_platform.h b/buffalo/arch/x86/plat-usi/sugi_platform.h
new file mode 100644
index 00000000..f4662fc
--- /dev/null
+++ b/buffalo/arch/x86/plat-usi/sugi_platform.h
@@ -0,0 +1,308 @@
+#if !defined __SUGI_PLATFORM_H__
+#define __SUGI_PLATFORM_H__
+
+/* common section */
+#define sugi_fan_major						125
+#define sugi_fan_minor						0
+#define sugi_cmos_major						124
+#define sugi_cmos_minor						0
+#define sugi_boardid_major				123
+#define sugi_boardid_minor				0
+#define sugi_dev_count        		1
+#define DRVNAME								"sugi_platform"
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 1
+ * Description: Definition of IT8721 registers
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ----------- Common Sections ----------- */
+ 
+/* IT8721 config section */
+#define CONFIG_ADDR_PORT	       	0x2E
+#define CONFIG_DATA_PORT	       	0x2F
+#define IT87_LDN_ADDR		       		0x07
+ 
+/* ------------ Button Driver ------------ */
+
+/* IT8721 logic device number */
+#define	IT87_GPIO_LDN							0x07
+ 
+/* panel button de-bounce mapping */
+#define IT87_REG_PNL_DBOUNCE0			0xE0
+#define IT87_REG_PNL_DBOUNCE1			0xE1
+#define IT87_GP34_LOC							0x1C
+#define IT87_GP35_LOC							0x1D
+#define	IT87_IRQEN								0x40
+
+/* panel button de-bounce interrupt level select */
+#define IT87_REG_PNL_IRQ_SEL			0x70
+#define IT87_PNL_IRQ3							0x03	
+
+/* SMI control register, bit0 is used to enable PBD's IRQ */
+#define IT87_REG_SMI_CTL2 				0xF1
+#define SMI_CTL2_EN_PBD						0x01
+
+/* SMI status register2, bit7-6 is used to detect panel button de-bounce */
+#define IT87_REG_SMI_STS2					0xF3
+#define IT87_SMI_DEB_MASK					0xC0
+
+/* SMI status register2, bit0 is PBD's IRQ */
+#define IT87_SMI_STS2_PBD					0x01
+
+/* Simple I/O base addr */
+#define IT87_SIMPLE_IO_BASE_MSB		0x62
+#define IT87_SIMPLE_IO_BASE_LSB		0x63
+#define GPIO_SET3_OFFSET					0x2
+
+
+/* ---------- Fan Control Driver --------- */
+
+/* IT8721 logic device number */
+#define	IT87_EC_LDN								0x04
+
+/* IT8721 main fan control registers */
+#define IT87_EC_FAN_MAIN_CTL	   	0x13
+#define IT87_EC_FAN_CTL		       	0x14
+
+/* IT8721 fan tachometer registers */
+#define IT87_EC_FAN_TACO1	       	0x0D // FAN1
+#define IT87_EC_FAN_TACO2	       	0x0E // FAN2
+
+#define IT87_EC_FAN_TACO1_EXT	   	0x18
+#define IT87_EC_FAN_TACO2_EXT	   	0x19
+
+/* select PWM control mode  */
+#define IT87_EC_FAN_PWM1					0x15
+#define IT87_EC_FAN_PWM2					0x16
+
+/* set the PWM value */
+#define IT87_EC_FAN_SMART_PWM1		0x63
+#define IT87_EC_FAN_SMART_PWM2		0x6B
+
+/* IT8721 temprature registers */
+#define IT87_EC_TMPIN3						0x2B // SYSTIN(TMPIN3@schematic)
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 2
+ * Description: Definition of ICH10R registers
+ * ---------------------------------------------------------------------------------------------- */ 
+ 
+/* ----------- Common Sections ----------- */
+
+/* vendor and device ID for Intel ICH10R */
+#define INTEL_ICH10R_VID					0x8086
+#define INTEL_ICH10R_DID					0x3A16
+#define GPIOBASE									0x48
+#define PMBASE										0x40
+
+/* GPIO register*/
+#define GP_USE_SEL								0x00
+#define GP_USE_SEL2								0x30
+#define GP_IO_SEL									0x04
+#define GP_IO_SEL2								0x34
+#define GP_LVL										0x0C
+#define GP_LVL2										0x38
+
+/* Power management register */
+#define PMBASE										0x40
+#define PM1_STS										0x00
+#define PM1_EN										0x02
+#define GEN_PMCON_3								0xA4
+
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 3
+ * Description: Path of proc file system
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ----------- Common Sections ----------- */
+#define BUFFALO_DIR								"buffalo"
+#define GPIO_DIR									"buffalo/gpio" 
+ 
+/* ------------ Button Driver ------------ */
+#define SWITCH_DIR								"buffalo/gpio/switch"
+#define MAX_SUPPORTED_BUTTONS 		2
+
+/* ---------- HDD Control Driver --------- */
+#define HOTPLUG_DIR								"buffalo/gpio/hotplug"
+#define POWER_CONTROL_DIR					"buffalo/gpio/power_control"
+#define MAX_SUPPORTED_DISKS				8
+
+/* ---------------------------------------------------------------------------------------------- *
+ * BLOCK 4
+ * Description: Definitions of individual drivers
+ * ---------------------------------------------------------------------------------------------- */
+ 
+/* ------------ Button Driver ------------ */
+
+/* period of timer */      
+#define TIMER_DELAY								(HZ/500)
+
+/* Buttons section */
+#define BTN_FUNC	    	   				0
+#define BTN_DISP	 	  		 				1
+
+/* select SMI status bit7-6 */
+#define IT87_DEB0									0x40	
+#define IT87_DEB1									0x80	
+#define IT87_DEB0DEB1							0xC0
+
+/* bit5-4 in GPIO set3 */
+#define IT87_GP34_BIT4						0x10
+#define IT87_GP35_BIT5						0x20
+
+/* button information structure */
+struct button_info_st
+{
+	char name[32];
+	unsigned char reg_stat;
+};
+
+/* ---------- Fan Control Driver --------- */
+
+/* fan control information */
+struct fan_info_st{
+	unsigned char reg;
+	unsigned char reg_ext;
+	unsigned char reg_smart_pwm;
+	unsigned char reg_pwm;
+	unsigned char offset;
+};
+
+/* ---------- HDD Control Driver --------- */
+
+/*
+    hotplug     |	power control
+----------------------------------
+sata0 -> GPIO2	|	hdd0 -> GPIO17
+sata1 -> GPIO3	|	hdd1 -> GPIO1
+sata2 -> GPIO4	|	hdd2 -> GPIO6
+sata3 -> GPIO5	|	hdd3 -> GPIO7
+sata4 -> GPIO15	|	hdd4 -> GPIO56
+sata5 -> GPIO9	|	hdd5 -> GPIO32
+sata6 -> GPIO13	|	hdd6 -> GPIO33
+sata7 -> GPIO10	|	hdd7 -> GPIO34
+
+*/
+
+/* GPIO pin definition */
+#define HDD0_PRESENT_BIT					0x00000004	/* GPIO2 */
+#define HDD1_PRESENT_BIT					0x00000008	/* GPIO3 */
+#define HDD2_PRESENT_BIT					0x00000010	/* GPIO4 */
+#define HDD3_PRESENT_BIT					0x00000020	/* GPIO5 */
+#define HDD4_PRESENT_BIT					0x00008000	/* GPIO15*/
+#define HDD5_PRESENT_BIT					0x00000200	/* GPIO9 */
+#define HDD6_PRESENT_BIT					0x00002000	/* GPIO13*/
+#define HDD7_PRESENT_BIT					0x00000400	/* GPIO10*/
+
+#define HDD0_POWER_BIT						0x00020000	/*GPIO17*/
+#define HDD1_POWER_BIT						0x00000002	/*GPIO1*/
+#define HDD2_POWER_BIT						0x00000040	/*GPIO6*/
+#define HDD3_POWER_BIT						0x00000080	/*GPIO7*/
+#define HDD4_POWER_BIT						0x01000000	/*GPIO56*/
+#define HDD5_POWER_BIT						0x00000001	/*GPIO32*/
+#define HDD6_POWER_BIT						0x00000002	/*GPIO33*/
+#define HDD7_POWER_BIT						0x00000004	/*GPIO34*/
+
+#define HDD0_POWER_MASK						0xFFFDFFFF
+#define HDD1_POWER_MASK						0xFFFFFFFD
+#define HDD2_POWER_MASK						0xFFFFFFBF
+#define HDD3_POWER_MASK						0xFFFFFF7F
+#define HDD4_POWER_MASK						0xFEFFFFFF
+#define HDD5_POWER_MASK						0xFFFFFFFE
+#define HDD6_POWER_MASK						0xFFFFFFFD
+#define HDD7_POWER_MASK						0xFFFFFFFB
+
+
+/* HDD information structure */
+struct sugi_hdd_info_st {
+	uint32_t HDD_GPIO_PRESENT_REG;
+	uint32_t HDD_PRESENT_BIT;
+	uint32_t HDD_GPIO_POWER_REG;
+	uint32_t HDD_POWER_BIT;
+	uint32_t HDD_POWER_MASK;
+};
+
+/* definitions of status */
+#define PLUGGED_EVENT_MSG       	"SATA %d plugged"
+#define UNPLUGGED_EVENT_MSG     	"SATA %d unplugged"
+
+/* polling timer */
+#define SATA_POL_INTERVAL       	HZ/100
+#define SATA_POL_LOOPS          	10
+
+/* hotplug ststus strcture */
+typedef enum _sata_plug_state {
+	SATA_STAT_UNKNOWN,
+	SATA_STAT_PLUGGED,
+	SATA_STAT_UNPLUGGED,
+}SATA_PLUG_STATE;
+
+/* hotplug information strcture */
+struct sata_hotplug_data_st {
+	SATA_PLUG_STATE presentpinstat;
+	SATA_PLUG_STATE prevplugstat;
+	unsigned int loops;
+};
+
+/* ------------- CMOS Driver ------------- */
+
+/* IO index */
+#define	CMOS_INDEX_PORT						0x70
+#define	CMOS_DATA_PORT						0x71
+
+/* wake on LAN setting */
+#define WOL_OFFSET								0x70
+#define WOL_DISABLE								0x00
+#define WOL_ENABLE								0x01
+
+/* AC power loss setting */
+#define	AC_POWER_LOSS_OFFSET			0x71
+#define AC_POWER_LOSS_POWER_OFF 	0x00
+#define AC_POWER_LOSS_POWER_ON  	0x01
+#define AC_POWER_LOSS_LAST_STATE	0x02
+
+/* Gbe LAN boot setting */
+#define LANBOOT_OFFSET						0x75
+#define LANBOOT_DISABLE						0x00
+#define LANBOOT_ENABLE						0x01
+
+/* CMOS setting */
+#define CMOS_CHECKSUM_OFFSET			0x73
+#define CMOS_CHANGE_CHECKSUM			0xBF
+
+
+/* ASCII string strcture */
+struct strtoint_st {
+	unsigned char strg;
+	unsigned char inte;
+};
+
+/* SW SMI setting and return code */
+#define SW_SMI_OFFSET							0xB2
+#define SW_SMI_READ								0x76
+#define SW_SMI_WRITE							0x77 
+
+/* ----------- Board ID Driver ----------- */
+ 
+/*
+     SKU   | GPIO31   GPIO30   GPIO29 
+ ----------|-------- -------- --------
+  2HDD box |   0        0        0    
+  4HDD box |   0        0        1    
+  6HDD box |   0        1        0    
+  8HDD box |   0        1        1    
+  1U       |   1        0        0    
+*/
+
+#define GPIO29										0x20000000
+#define GPIO30										0x40000000
+#define GPIO31										0x80000000
+#define BOARD_ID_MASK							(GPIO29 | GPIO30 | GPIO31)
+#define BOARD_ID_OFFSET						29
+
+
+#endif
\ No newline at end of file
diff --git a/buffalo/drivers/Makefile b/buffalo/drivers/Makefile
new file mode 100644
index 00000000..b21427e
--- /dev/null
+++ b/buffalo/drivers/Makefile
@@ -0,0 +1,20 @@
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= proc_entry.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= buffalocore.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= kernevntProc.o
+obj-$(CONFIG_BUFFALO_PLATFORM)		+= kernevnt.o
+
+obj-$(CONFIG_BUFFALO_MICON_V3)		+= micon_v3.o
+
+obj-$(CONFIG_BUFFALO_USE_UPS)		+= upsdrv.o rtc_nvram.o
+
+
+
+buffalo/drivers/buffalocore.o: buffalo/include/generated/builddate.h
+
+       chk_builddate.h = :
+ quiet_chk_builddate.h = echo '  CHK     $@'
+silent_chk_builddate.h = :
+buffalo/include/generated/builddate.h: FORCE
+	$(Q)mkdir -p buffalo/include/generated
+	@$($(quiet)chk_builddate.h)
+	$(Q)$(CONFIG_SHELL) $(srctree)/buffalo/scripts/mkbuilddate_h $@
diff --git a/buffalo/drivers/buffalocore.c b/buffalo/drivers/buffalocore.c
new file mode 100644
index 00000000..bb91fa4
--- /dev/null
+++ b/buffalo/drivers/buffalocore.c
@@ -0,0 +1,547 @@
+/*
+ *  Driver routines for BUFFALO Platform
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+
+#include <linux/version.h>
+#include <linux/kernel.h>
+#include <linux/slab.h>
+#include <linux/seq_file.h>
+#include <linux/ctype.h>
+#include <linux/string.h>
+#include <linux/module.h>
+#include <linux/proc_fs.h>
+#include <linux/init.h>
+#include <linux/device.h>
+#include <asm/uaccess.h>
+#include <linux/fs.h>
+
+#include "buffalocore.h"
+#include "kernevntProc.h"
+#include "buffalo/kernevnt.h"
+#include "proc_entry.h"
+#include "builddate.h"
+
+
+#define BUFCORE_VERSION "0.20"
+
+/* Module parameters */
+MODULE_AUTHOR("BUFFALO");
+MODULE_DESCRIPTION("Buffalo Platform Linux Driver");
+MODULE_LICENSE("GPL");
+MODULE_VERSION(BUFCORE_VERSION);
+
+//#define DEBUG
+#ifdef DEBUG
+#define FUNCTRACE(x)	x
+#else
+#define FUNCTRACE(x)	/* none */
+#endif
+
+void *
+buffalo_generic_seq_start(struct seq_file *m, loff_t *pos)
+{
+	return *pos < 1 ? SEQ_START_TOKEN : NULL;
+}
+
+void *
+buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos)
+{
+	++ *pos;
+	return NULL;
+}
+
+void
+buffalo_generic_seq_stop(struct seq_file *m, void *v)
+{
+}
+
+
+/*
+ *	/proc/buffalo/booting
+ */
+int buffalo_booting = 1;
+
+static int
+buffalo_booting_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "%d\n", buffalo_booting);
+	return 0;
+}
+
+static const struct seq_operations buffalo_booting_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_booting_show,
+};
+
+static int
+buffalo_booting_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_booting_op);
+}
+
+static ssize_t
+buffalo_booting_write(struct file *file, const char __user *buffer,
+		      size_t count, loff_t *ppos)
+{
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	if (kbuf[count - 1] == '\n') {
+		kbuf[count - 1] = '\0';
+	}
+	else {
+		kbuf[count] = '\0';
+	}
+
+	if (strncmp(kbuf, "0", 1) == 0) {
+		buffalo_booting = 0;
+	}
+	else if (strncmp(kbuf, "1", 1) == 0) {
+		buffalo_booting = 1;
+	}
+	else {
+		printk("unknown value for booting(%s)\n", kbuf);
+		count = -EINVAL;
+	}
+out:
+	kfree(kbuf);
+
+	return count;
+}
+
+static struct file_operations buffalo_booting_fops = {
+	.open		= buffalo_booting_open,
+	.read		= seq_read,
+	.write		= buffalo_booting_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_booting_entry =
+{
+	.path		= "booting",
+	.mode		= S_IRUGO|S_IWUSR,
+	.proc_fops	= &buffalo_booting_fops,
+	.data		= NULL,
+};
+
+
+/*
+ *	/proc/buffalo/cpu_status
+ */
+unsigned int bfMagicKey = MagicKeyHwPoff;
+
+static unsigned int
+bfGetMagicKey(void)
+{
+	return bfMagicKey;
+}
+
+/*
+ * define as 'weak',
+ * you can define architecture-depend bfSetMagicKey_arch()
+ */
+void (*bfSetMagicKey_arch)(unsigned int key) __attribute__((weak)) = NULL;
+
+static void
+bfSetMagicKey(unsigned int key)
+{ 
+	bfMagicKey = key;
+	if (bfSetMagicKey_arch != NULL) {
+		bfSetMagicKey_arch(key);
+	}
+}
+
+static struct buffalo_cpu_status_defs buffalo_cpu_status[] = {
+	{ MagicKeyNormalState,		"normal_state" },
+	{ MagicKeyReboot,		"reboot" },
+	{ MagicKeyWOLReadyState,	"WOLReady" },
+	{ MagicKeySwPoff,		"swpoff" },
+
+	{ MagicKeyTerminator,		NULL },
+};
+
+/*
+ * define as 'weak',
+ * you can define architecture-depend buffalo_cpu_status_arch
+ */
+struct buffalo_cpu_status_defs *buffalo_cpu_status_arch __attribute__((weak)) = NULL;
+
+
+static char *
+buffalo_find_cpu_status_str(unsigned int key,
+			    struct buffalo_cpu_status_defs *defs,
+			    struct buffalo_cpu_status_defs *defs_arch)
+{
+	int i;
+
+	for (i = 0; defs[i].stat != MagicKeyTerminator; i ++) {
+		if (defs[i].stat == key) {
+			return defs[i].str;
+		}
+	}
+
+	if (defs_arch != NULL) {
+		for (i = 0; defs_arch[i].stat != MagicKeyTerminator; i ++) {
+			if (defs_arch[i].stat == key) {
+				return defs_arch[i].str;
+			}
+		}
+	}
+
+	return NULL;
+}
+
+static unsigned int
+buffalo_find_cpu_status_id(char *stat_str,
+			   struct buffalo_cpu_status_defs *defs,
+			   struct buffalo_cpu_status_defs *defs_arch)
+{
+	int i;
+
+	for (i = 0; defs[i].stat != MagicKeyTerminator; i ++) {
+		if (strcmp(defs[i].str, stat_str) == 0) {
+			return defs[i].stat;
+		}
+	}
+
+	if (defs_arch != NULL) {
+		for (i = 0; defs_arch[i].stat != MagicKeyTerminator; i ++) {
+			if (strcmp(defs_arch[i].str, stat_str) == 0) {
+				return defs_arch[i].stat;
+			}
+		}
+	}
+
+	return MagicKeyTerminator;
+}
+
+static int
+buffalo_cpu_status_show(struct seq_file *m, void *v)
+{
+	unsigned int CpuStatus = bfGetMagicKey();
+	char *stat_str;
+
+	stat_str = buffalo_find_cpu_status_str(CpuStatus,
+					       buffalo_cpu_status,
+					       buffalo_cpu_status_arch);
+	if (stat_str != NULL) {
+		seq_printf(m, "%s\n", stat_str);
+	}
+	else {
+		seq_printf(m, "Unknown(CpuStatus=%u)\n", CpuStatus);
+	}
+
+	return 0;
+}
+
+static const struct seq_operations buffalo_cpu_status_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_cpu_status_show,
+};
+
+static int
+buffalo_cpu_status_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_cpu_status_op);
+}
+
+static ssize_t
+buffalo_cpu_status_write(struct file *file, const char __user *buffer,
+			 size_t count, loff_t *ppos)
+{
+	char *kbuf;
+	unsigned int CpuStatus;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	if (kbuf[count - 1] == '\n') {
+		kbuf[count -1] = '\0';
+	}
+	else {
+		kbuf[count] = '\0';
+	}
+
+	CpuStatus = buffalo_find_cpu_status_id(kbuf,
+					       buffalo_cpu_status,
+					       buffalo_cpu_status_arch);
+
+	if (CpuStatus != MagicKeyTerminator) {
+		bfSetMagicKey(CpuStatus);
+	}
+	else{
+		printk("unknown cpu_status(%s)\n", kbuf);
+		count = -EINVAL;
+	}
+out:
+	kfree(kbuf);
+
+	return count;
+}
+
+static struct file_operations buffalo_cpu_status_fops = {
+	.open		= buffalo_cpu_status_open,
+	.read		= seq_read,
+	.write		= buffalo_cpu_status_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_cpu_status_entry =
+{
+	.path		= "cpu_status",
+	.mode		= S_IRUGO|S_IWUSR,
+	.proc_fops	= &buffalo_cpu_status_fops,
+	.data		= NULL,
+};
+
+
+
+/*
+ *	/proc/buffalo/firmware
+ */
+char buffalo_bootver[32] = { 0 };
+char buffalo_series_name[32] = { 0 };
+char buffalo_product_name[32] = { 0 };
+char buffalo_product_id[32] = { 0 };
+
+struct {
+	char *key;
+	char *value;
+	char *default_val;
+} cmdline_opts[] = {
+	{ "BOOTVER=",		buffalo_bootver,	"Unknown" },
+	{ "SERIES=",		buffalo_series_name,	"Unknown" },
+	{ "PRODUCTNAME=",	buffalo_product_name,	"Unknown" },
+	{ "PRODUCTID=",		buffalo_product_id,	"0x00000000" },
+};
+
+static int
+buffalo_firmware_show(struct seq_file *m, void *v)
+{
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(cmdline_opts); i ++) {
+		char *p, *pe;
+
+		if (!isalpha(cmdline_opts[i].value[0])) {
+			memset(cmdline_opts[i].value, 0,
+			       sizeof(cmdline_opts[i].value));
+			p = strstr(saved_command_line, cmdline_opts[i].key);
+			if (p != NULL) {
+				p += strlen(cmdline_opts[i].key);
+				pe = strstr(p, " ");
+
+				if ((pe != NULL) &&
+				    ((pe - p) < sizeof(cmdline_opts[i].value))){
+					strncpy(cmdline_opts[i].value,
+						p, pe - p);
+				}
+				else {
+					strncpy(cmdline_opts[i].value,
+						p, sizeof(cmdline_opts[i].value));
+				}
+			}
+			else {
+				sprintf(cmdline_opts[i].value, "%s",
+					cmdline_opts[i].default_val);
+			}
+		}
+	}
+
+	seq_printf(m, "SERIES=%s\n", buffalo_series_name);
+	seq_printf(m, "PRODUCTNAME=%s\n", buffalo_product_name);
+	seq_printf(m, "VERSION=%s\n", BUFCORE_VERSION);
+	seq_printf(m, "SUBVERSION=FLASH 0.00\n");
+	seq_printf(m, "PRODUCTID=%s\n", buffalo_product_id);
+	seq_printf(m, "BUILDDATE=%s %s\n",
+		   BUFFALO_BUILD_DATE, BUFFALO_BUILD_TIME);
+	seq_printf(m, "BOOTVER=%s\n", buffalo_bootver);
+
+	return 0;
+}
+
+static const struct seq_operations buffalo_firmware_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_firmware_show,
+};
+
+static int
+buffalo_firmware_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_firmware_op);
+}
+
+static struct file_operations buffalo_firmware_fops = {
+	.open		= buffalo_firmware_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_firmware_entry =
+{
+	.path		= "firmware",
+	.mode		= S_IRUGO,
+	.proc_fops	= &buffalo_firmware_fops,
+	.data		= NULL,
+};
+
+
+/*
+ *	/proc/buffalo/micon
+ */
+#if defined(CONFIG_BUFFALO_USE_MICON) && !defined(CONFIG_BUFFALO_MICON_V3)
+static int
+buffalo_micon_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "on\n");
+	return 0;
+}
+
+static const struct seq_operations buffalo_micon_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_micon_show,
+};
+
+static int
+buffalo_micon_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_micon_op);
+}
+
+static struct file_operations buffalo_micon_fops = {
+	.open		= buffalo_micon_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_micon_entry =
+{
+	.path		= "micon",
+	.mode		= S_IRUGO,
+	.proc_fops	= &buffalo_micon_fops,
+	.data		= NULL,
+};
+
+
+/*
+ * /proc/buffalo/miconint_en
+ */
+static int
+buffalo_miconint_en_show(struct seq_file *m, void *v)
+{
+	seq_printf(m, "MiconAct\n");
+	return 0;
+}
+
+static const struct seq_operations buffalo_miconint_en_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_miconint_en_show,
+};
+
+static int
+buffalo_miconint_en_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_miconint_en_op);
+}
+
+static struct file_operations buffalo_miconint_en_fops = {
+	.open		= buffalo_miconint_en_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+static struct proc_entry_data buffalo_micon_entry =
+{
+	.path		= "miconint_en",
+	.mode		= S_IRUGO0,
+	.proc_fops	= &buffalo_miconint_en_fops,
+	.data		= NULL,
+};
+#endif	/* CONFIG_BUFFALO_USE_MICON && !CONFIG_BUFFALO_MICON_V3 */
+
+static struct proc_entry_data *ped_list[] = {
+	&buffalo_booting_entry,
+	&buffalo_cpu_status_entry,
+	&buffalo_firmware_entry,
+#if defined(CONFIG_BUFFALO_USE_MICON) && !defined(CONFIG_BUFFALO_MICON_V3)
+	&buffalo_micon_entry,
+	&buffalo_miconint_en_entry,
+#endif	/* CONFIG_BUFFALO_USE_MICON && !CONFIG_BUFFALO_MICON_V3 */
+	NULL,
+};
+
+//----------------------------------------------------------------------
+int __init
+buffaloDriver_init (void)
+{
+	int i;
+
+        FUNCTRACE(printk(">%s\n",__FUNCTION__));
+
+	for (i = 0; ped_list[i]; i ++) {
+		make_proc_entry(ped_list[i]);
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+void
+buffaloDriver_exit(void)
+{
+	int i;
+	struct proc_dir_entry *buffalo;
+
+	FUNCTRACE(printk(">%s\n",__FUNCTION__));
+
+	buffalo = get_proc_buffalo();
+	for (i = 0; ped_list[i]; i++) {
+		remove_proc_entry(ped_list[i]->path, buffalo);
+	}
+
+	remove_proc_entry ("buffalo", 0);
+}
+
+module_init(buffaloDriver_init);
+module_exit(buffaloDriver_exit);
diff --git a/buffalo/drivers/buffalocore.h b/buffalo/drivers/buffalocore.h
new file mode 100644
index 00000000..880c6cf
--- /dev/null
+++ b/buffalo/drivers/buffalocore.h
@@ -0,0 +1,27 @@
+#if !defined(_BUFFALOCORE_H_)
+#define _BUFFALOCORE_H_
+
+#ifdef CONFIG_X86
+#else // CONFIG_X86
+#if defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+#include "boardEnv/buffalo/buffalo78100BoardEnv.h"
+#include "boardEnv/mvBoardEnvSpec.h"
+#endif
+
+#endif // CONFIG_X86
+
+#if defined(CONFIG_ARCH_FEROCEON_KW) || defined(CONFIG_ARCH_ARMADA370) || defined(CONFIG_ARCH_ARMADA_XP)
+
+#include "boardEnv/mvBoardEnvLib.h"
+
+struct bf_proc_entry_tab {
+  const char *name;
+  int isDirectory;
+  read_proc_t *read_proc;
+  write_proc_t *write_proc;
+  void *data;
+  MV_BOARD_GPP_CLASS class;
+};
+#endif
+
+#endif
diff --git a/buffalo/drivers/kernevnt.c b/buffalo/drivers/kernevnt.c
new file mode 100644
index 00000000..646cc44
--- /dev/null
+++ b/buffalo/drivers/kernevnt.c
@@ -0,0 +1,348 @@
+/*
+ *  LinkStation/TeraStation Kernel Event Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/sched.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/delay.h>
+#include <linux/errno.h>
+#include <linux/init.h>
+#include <linux/fs.h>
+#include <linux/miscdevice.h>
+#ifdef CONFIG_PHYLIB
+#include <linux/netdevice.h>
+#include <linux/phy.h>
+#endif /*CONFIG_PHYLIB*/
+#include <asm/string.h>
+#include <asm/io.h>
+#include <asm/uaccess.h>
+#include <asm/serial.h>
+#include "buffalo/kernevnt.h"
+#include "kernevntProc.h"
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG
+//#define FUNCMSG
+
+#ifdef DEBUG
+#define TRACE(x)	x
+#else
+#define TRACE(x)	/* none */
+#endif
+
+#ifdef FUNCMSG
+#define FUNC_MSG(x)	x
+#else	/* FUNCMSG */
+#define FUNC_MSG(x)	/* none */
+#endif	/* FUNCMSG */
+
+static DEFINE_SPINLOCK(BuffaloMicon_event_lock);
+
+wait_queue_head_t buffalo_kernevnt_WaitQueue;
+static int initialized=0;
+static struct tag_MiconDevice {
+	struct {
+		char cmd[MAX_CMDLEN+1];
+	} cmdqueue[MAX_QUELEN];
+	int rindex,windex;
+} MiconDevice;
+
+//--------------------------------------------------------------
+void
+buffalo_kernevnt_queuein(const char *cmd)
+{
+	if (!initialized){
+		return;
+	}
+	printk(KERN_DEBUG "kernevnt: %s\n", cmd);
+	if (MiconDevice.cmdqueue[MiconDevice.windex].cmd[0] == 0) {
+		unsigned long flags;
+		spin_lock_irqsave(&BuffaloMicon_event_lock, flags);
+
+		strncpy(MiconDevice.cmdqueue[MiconDevice.windex].cmd,
+			cmd, MAX_CMDLEN - 1);
+		MiconDevice.windex ++;
+		if (MiconDevice.windex == ARRAY_SIZE(MiconDevice.cmdqueue)) {
+			MiconDevice.windex = 0;
+		}
+
+		spin_unlock_irqrestore(&BuffaloMicon_event_lock, flags);
+
+		TRACE(printk("queue in : r=%d w=%d [%s]\n",
+			     MiconDevice.rindex, MiconDevice.windex, cmd));
+	}
+	else {
+		TRACE(printk("queue full [%s]\n",cmd));
+	}
+	wake_up_interruptible(&buffalo_kernevnt_WaitQueue);
+}
+
+//--------------------------------------------------------------
+int
+buffalo_kernevnt_queueout(unsigned char *cmd, int *len)
+{
+	if (!initialized){
+		return -1;
+	}
+	if (MiconDevice.cmdqueue[MiconDevice.rindex].cmd[0] != 0){
+		int index;
+		index = MiconDevice.rindex;
+
+		TRACE(printk("queue out : r=%d w=%d [%s]\n",
+			     MiconDevice.rindex, MiconDevice.windex,
+			     MiconDevice.cmdqueue[index].cmd));
+
+		spin_lock_irq(&BuffaloMicon_event_lock);
+		
+		if (MiconDevice.cmdqueue[index].cmd[0] != 0) {
+			strncpy(cmd, MiconDevice.cmdqueue[index].cmd,
+				MAX_CMDLEN);
+			*len = strlen(cmd) + 1;  // for NULL terminate.
+			MiconDevice.cmdqueue[index].cmd[0] = 0;
+		}
+		MiconDevice.rindex ++;
+		if (MiconDevice.rindex == ARRAY_SIZE(MiconDevice.cmdqueue)) {
+			MiconDevice.rindex = 0;
+		}
+
+		spin_unlock_irq (&BuffaloMicon_event_lock);
+
+		return index;
+	}
+	else{
+		TRACE(printk("queue none\n"));
+	}
+	return -1;
+}
+
+#ifdef CONFIG_MD
+//--------------------------------------------------------------
+void
+kernevnt_RaidRecovery(int devno, int on, int isRecovery, int major, int minor)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d on=%d cnt=%d isRecovery=%d %d %d\n",
+			__FUNCTION__, devno, on, opencnt, isRecovery,
+			major, minor));
+	
+	if (on) {
+		opencnt ++;
+	}
+	else {
+		opencnt --;
+	}
+	
+	if (isRecovery) {
+		sprintf(buff,"raidrecovery %d %d %d %d %d %d",
+			devno, on, opencnt, isRecovery, major, minor);
+	}
+	else{
+		sprintf(buff,"raidresync %d %d %d %d",
+			devno, on, opencnt, isRecovery);
+	}
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidScan(int devno, int on)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d on=%d cnt=%d\n",
+			__FUNCTION__, devno, on, opencnt));
+
+	if (on) {
+		opencnt ++;
+	}
+	else {
+		opencnt --;
+	}
+
+	sprintf(buff, "raidscan %d %d %d", devno, on, opencnt);
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidDegraded(int devno, int major, int minor)
+{
+	char buff[64];
+
+	FUNC_MSG(printk(">%s:md%d %d %d\n",
+			__FUNCTION__, devno, major, minor));
+
+	sprintf(buff,"raiddegraded %d %d %d", devno, major, minor);
+	buffalo_kernevnt_queuein(buff);
+}
+//--------------------------------------------------------------
+void
+kernevnt_RaidReshape(int devno, int on)
+{
+	static int opencnt = 0;
+	char buff[64];
+
+	if (on) {
+		opencnt++;
+	}
+	else {
+		opencnt--;
+	}
+
+	sprintf(buff, "raidreshape %d %d %d", devno, on, opencnt);
+	buffalo_kernevnt_queuein(buff);
+}
+
+#endif /* CONFIG_MD */
+
+//--------------------------------------------------------------
+void
+kernevnt_FlashUpdate(int on)
+{
+	char msg[32];
+
+	FUNC_MSG(printk(">%s (%d)\n", __FUNCTION__, on));
+
+	sprintf(msg, "flashupdate %d", on);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+#ifdef CONFIG_PHYLIB
+void
+kernevnt_LanAct_phydev(void *data)
+{
+	struct phy_device *phydev = data;
+	struct net_device *netdev;
+	char msg[128];
+
+	BUG_ON(!phydev);
+	netdev = phydev->attached_dev;
+	BUG_ON(!netdev);
+	sprintf(msg, "lanact %d %s %s",
+	    phydev->link ? phydev->speed : 0,
+	    phydev->duplex ? "full" : "half",
+	    netdev->name);
+	buffalo_kernevnt_queuein(msg);
+}
+void (*kernevnt_LanAct_arch)(void *data) = kernevnt_LanAct_phydev;
+#else /*CONFIG_PHYLIB*/
+void (*kernevnt_LanAct_arch)(void *data) = NULL;
+#endif /*CONFIG_PHYLIB*/
+void
+kernevnt_LanAct(void *data)
+{
+	if (kernevnt_LanAct_arch != NULL) {
+		kernevnt_LanAct_arch(data);
+	}
+}
+
+void
+kernevnt_SwitchHubAct(const char *msg)
+{
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_IOErr(const char *kdevname, const char *dir, unsigned long long sector, unsigned int errcnt)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s(%s): I/O error, dev %s, sector %llu\n",
+			__FUNCTION__,kdevname, dir,
+			(unsigned long long)sector, errcnt));
+
+	sprintf(msg,"ioerr %s %s %llu %u",kdevname, dir,
+		(unsigned long long)sector, errcnt);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_DriveDead(const char *drvname)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s: drive %s is dead.\n",__FUNCTION__,drvname));
+
+	sprintf(msg,"drivedead %s",drvname);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_I2cErr(void)
+{
+	printk(">%s\n",__FUNCTION__);
+	buffalo_kernevnt_queuein("i2c_error");
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_MiconInt(void)
+{
+	FUNC_MSG(printk(">%s\n",__FUNCTION__));
+
+	buffalo_kernevnt_queuein("micon_interrupts");
+}
+
+//--------------------------------------------------------------
+void
+kernevnt_EnetOverload(const char *name)
+{
+	char msg[64];
+
+	FUNC_MSG(printk(">%s\n",__FUNCTION__));
+
+	sprintf(msg,"enetover %s",name);
+	buffalo_kernevnt_queuein(msg);
+}
+
+//--------------------------------------------------------------
+/*
+ * Initialize driver.
+ */
+int __init
+BuffaloMicon_init (void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("MICON ctrl (C) BUFFALO INC. V.1.00 installed.\n"); 
+	
+	// Initialize Local valiables
+	bzero(&MiconDevice, sizeof(MiconDevice));
+	init_waitqueue_head(&buffalo_kernevnt_WaitQueue);
+	initialized=1;
+	return 0;
+}
+
+//--------------------------------------------------------------
+void
+BuffaloMicon_exit(void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("MICON ctrl removed.\n");
+	initialized=0;
+
+}
+
+EXPORT_SYMBOL(buffalo_kernevnt_queuein);
+EXPORT_SYMBOL(buffalo_kernevnt_queueout);
+EXPORT_SYMBOL(buffalo_kernevnt_WaitQueue);
+
+module_init(BuffaloMicon_init);
+module_exit(BuffaloMicon_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/drivers/kernevntProc.c b/buffalo/drivers/kernevntProc.c
new file mode 100644
index 00000000..ec833ff
--- /dev/null
+++ b/buffalo/drivers/kernevntProc.c
@@ -0,0 +1,130 @@
+/*
+ *  LinkStation/TeraStation Kernel Event Proc Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/sched.h>
+#include <linux/seq_file.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/delay.h>
+#include <linux/errno.h>
+#include <linux/init.h>
+#include <linux/fs.h>
+#include <linux/proc_fs.h>
+#include <linux/string.h>
+#include <linux/uaccess.h>
+
+#include "buffalocore.h"
+#include "kernevntProc.h"
+#include "proc_entry.h"
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG
+
+#ifdef DEBUG
+ #define TRACE(x) x
+#else
+ #define TRACE(x)
+#endif
+
+extern void buffalo_kernevnt_queuein(const char *cmd);
+extern int buffalo_kernevnt_queueout(unsigned char *cmd, int *len);
+extern wait_queue_head_t  buffalo_kernevnt_WaitQueue;
+
+
+// event notice from kernel
+static int
+BuffaloKernevnt_show(struct seq_file *m, void *v)
+{
+	int len = 0;
+	char retbuff[MAX_CMDLEN + 1 + 2];
+
+	if (wait_event_interruptible(buffalo_kernevnt_WaitQueue,
+		buffalo_kernevnt_queueout(retbuff, &len) >= 0) != 0) {
+		return -EIO;	/* XXX : reasonable ? */
+	}
+	
+	seq_printf(m, "%s", retbuff);
+	return 0;
+}
+
+extern void *buffalo_generic_seq_start(struct seq_file *m, loff_t *pos);
+extern void *buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos);
+extern void buffalo_generic_seq_stop(struct seq_file *m, void *v);
+
+static const struct seq_operations buffalo_kernevnt_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= BuffaloKernevnt_show,
+};
+
+static int
+BuffaloKernevnt_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_kernevnt_op);
+}
+static ssize_t
+BuffaloKernevnt_write(struct file *file, const char __user *buf, size_t count, loff_t *ppos)
+{
+	char kbuf[MAX_CMDLEN + 1 + 2];
+
+	if (count >= sizeof(kbuf)) {
+		count = sizeof(kbuf) - 1;
+	}
+	if (copy_from_user(kbuf, buf, count)) {
+		return -EFAULT;
+	}
+	kbuf[count] = 0;
+	buffalo_kernevnt_queuein(kbuf);
+	*ppos += count;
+	return count;
+}
+
+static struct file_operations kernevnt_fops = {
+	.open		= BuffaloKernevnt_open,
+	.read		= seq_read,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+	.write		= BuffaloKernevnt_write,
+};
+
+
+/*
+ * Initialize driver.
+ */
+int
+BuffaloKernevnt_init (void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	printk("Kernel event proc (C) BUFFALO INC. V.1.00 installed.\n"); 
+
+	proc_create("kernevnt", S_IRUGO|S_IWUSR, get_proc_buffalo(), &kernevnt_fops);
+	
+	return 0;
+}
+
+void
+BuffaloKernevnt_exit(void)
+{
+	TRACE(printk(">%s\n",__FUNCTION__));
+	remove_proc_entry("kernevnt", get_proc_buffalo());
+	printk("Kernel event proc removed.\n");
+}
+
+
+module_init(BuffaloKernevnt_init);
+module_exit(BuffaloKernevnt_exit);
+
+MODULE_LICENSE("GPL");
diff --git a/buffalo/drivers/kernevntProc.h b/buffalo/drivers/kernevntProc.h
new file mode 100644
index 00000000..75570e1
--- /dev/null
+++ b/buffalo/drivers/kernevntProc.h
@@ -0,0 +1,11 @@
+#ifndef _KERNEVNTPROC_H_
+#define _KERNEVNTPROC_H_
+
+#define MAX_CMDLEN  32
+#define MAX_QUELEN  32
+
+int BuffaloKernevnt_init (void);
+void BuffaloKernevnt_exit(void);
+
+#endif
+
diff --git a/buffalo/drivers/micon_v3.c b/buffalo/drivers/micon_v3.c
new file mode 100644
index 00000000..3fcbc1d
--- /dev/null
+++ b/buffalo/drivers/micon_v3.c
@@ -0,0 +1,328 @@
+/*
+ *
+ */
+
+#include <linux/kernel.h>
+#include <linux/slab.h>
+#include <linux/tty.h>
+#include <linux/uaccess.h>
+#include <linux/syscalls.h>
+#include <linux/delay.h>
+#include <buffalo/micon_v3.h>
+
+
+#ifdef CONFIG_BUFFALO_MICON_V3_DEVTTY
+#define MICON_DEV		CONFIG_BUFFALO_MICON_V3_DEVTTY
+#else	/* CONFIG_BUFFALO_MICON_V3_DEVTTY */
+#warning "CONFIG_BUFFALO_MICON_V3_DEVTTY is not defined, use /dev/ttyS1"
+#define MICON_DEV		"/dev/ttyS1"
+#endif	/* CONFIG_BUFFALO_MICON_V3_DEVTTY */
+#define MICON_BAUD		115200
+#define MICON_BAUD_SYM		B115200
+
+#define MICON_INIT_MARK		0x1b	/* (ESC) */
+#define MICON_DELIMITER		0x0d	/* "\r" */
+
+#define MICON_CMD_POW_OFF	"POW_OFF"
+#define MICON_CMD_REBOOT	"REBOOT"
+
+#define MICON_RSP_ACK		"OK"
+#define MICON_RSP_NACK		"NG"
+
+#define MICON_RSP_MAX		256	/* XXX: reasonable ? */
+#define MICON_RETRY_MAX		3
+
+
+#define DEBUG
+#ifdef DEBUG
+#define TRACE(arg)	arg
+#else	/* DEBUG */
+#define TRACE(arg)	/* none */
+#endif	/* DEBUG */
+
+
+static int
+micon_v3_serial_io(char *indata, int inlen, char *outdata, int outlen)
+{
+	int fd;
+	int sys_val = 0;
+	struct termios termios;
+	struct termios termios_save;
+	char *cmdbuf = NULL;
+	int cmdbuflen;
+	char rspbuf[MICON_RSP_MAX];
+	int rsplen;
+	mm_segment_t oldfs;
+	int try;
+	int i;
+
+	oldfs = get_fs();
+	set_fs(KERNEL_DS);
+
+	fd = sys_open(MICON_DEV, O_RDWR | O_NDELAY, 0);
+	if (fd < 0) {
+		printk(KERN_ERR "Micon device(%s): open failed.(%d)\n",
+		       MICON_DEV, fd);
+		set_fs(oldfs);
+		return fd;
+	}
+
+	sys_val = sys_ioctl(fd, TCGETS, (long)&termios_save);
+	if (sys_val < 0) {
+		printk(KERN_ERR "Micon device(%s): ioctl(TCGETS) failed.(%d)\n",
+		       MICON_DEV, sys_val);
+		sys_close(fd);
+		set_fs(oldfs);
+		return sys_val;
+	}
+
+	memset(&termios, 0, sizeof(termios));
+	termios.c_cflag = MICON_BAUD_SYM | CS8 | CLOCAL | CREAD;
+	termios.c_iflag = IGNPAR;
+	sys_val = sys_ioctl(fd, TCSETS, (unsigned long)&termios);
+	if (sys_val < 0) {
+		printk(KERN_ERR "Micon device(%s): ioctl(TCSETS) failed.(%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+
+	/* read all data before real I/O */
+	while (1) {
+		sys_val = sys_read(fd, rspbuf, sizeof(rspbuf));
+		if (sys_val == 0) {
+			TRACE(printk(KERN_DEBUG "Micon buffer cleared.\n"));
+			break;
+		}
+		else if (sys_val < 0) {
+			printk(KERN_ERR "Micon buffer clear failed.\n");
+			goto out;
+		}
+	}
+
+	cmdbuflen = 1;	/* at least 1 byte */
+	if (inlen > cmdbuflen) {
+		cmdbuflen = inlen;
+	}
+	cmdbuflen ++;	/* for string terminator '\0' */
+	cmdbuf = kmalloc(cmdbuflen, GFP_KERNEL);
+	if (cmdbuf == NULL) {
+		printk(KERN_ERR "Micon I/O buffer allocation failed.\n");
+		return -ENOMEM;
+	}
+
+	for (try = 0; try < MICON_RETRY_MAX; try ++) {
+		/* initialize */
+		memset(cmdbuf, 0, cmdbuflen);
+		snprintf(cmdbuf, cmdbuflen, "%c", MICON_INIT_MARK);
+		sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+		TRACE(printk(KERN_DEBUG "CPU->MICON: INIT\n"));
+		if (sys_val < 0) {
+			printk(KERN_ERR "Micon device(%s): write(init) failed.\n",
+			       MICON_DEV);
+			continue;
+		}
+		else if (sys_val != strlen(cmdbuf)) {
+			printk(KERN_ERR "Micon device(%s): write(init) failed."
+			       " expect %d bytes, but %d bytes was written\n",
+			       MICON_DEV, strlen(cmdbuf), sys_val);
+			continue;
+		}
+		msleep_interruptible(10);	/* 10ms */
+		sys_val = sys_read(fd, rspbuf, sizeof(rspbuf));
+
+		/* send command */
+		memset(cmdbuf, 0, cmdbuflen);
+		snprintf(cmdbuf, cmdbuflen, "%s", indata);
+		sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+		/*
+		 * XXX:
+		 *	it might need sys_write() loop in strictly sense,
+		 *	but this driver doesn't care
+		 *	because command is enough short.
+		 */
+		if (sys_val < 0) {
+			printk(KERN_ERR "Micon device(%s): write(%s) failed.(%d)\n",
+			       MICON_DEV, cmdbuf, sys_val);
+			continue;
+		}
+		else if (sys_val != strlen(cmdbuf)) {
+			printk(KERN_ERR "Micon device(%s): write(%s) failed."
+			       "expect %d bytes, but %d bytes was written\n",
+			       MICON_DEV, cmdbuf, strlen(cmdbuf), sys_val);
+			continue;
+		}
+		TRACE(printk(KERN_DEBUG "CPU->MICON: send [%s]\n", cmdbuf));
+
+		/* check echo-back */
+		rsplen = 0;
+		memset(rspbuf, 0, sizeof(rspbuf));
+		for (i = 0; i < 10/*???*/; i++) {
+			if (rsplen >= sizeof(rspbuf)) {
+				break;
+			}
+			sys_val = sys_read(fd, rspbuf + rsplen,
+					   sizeof(rspbuf) - rsplen);
+			if (sys_val == 0) {
+				break;
+			}
+			else if (sys_val < 0) {
+				if (sys_val == -EAGAIN) {
+					msleep_interruptible(1000);/* XXX */
+					continue;
+				}
+				printk(KERN_ERR "Micon device(%s): read() failed.(%d)\n",
+				       MICON_DEV, sys_val);
+				continue;
+			}
+			else {
+				rsplen += sys_val;
+			}
+			if (rsplen == strlen(cmdbuf)) {
+				break;
+			}
+			msleep_interruptible(10);
+		}
+		TRACE(printk(KERN_DEBUG
+			     "MICON->CPU: echo-back [%s], ", rspbuf));
+		if (strncmp(rspbuf, cmdbuf, rsplen) == 0) {
+			TRACE(printk(KERN_DEBUG "OK"));
+			break;
+		}
+		else {
+			TRACE(printk(KERN_DEBUG "NG"));
+		}
+	}
+	if (try >= MICON_RETRY_MAX) {
+		printk(KERN_ERR
+		       "Micon device(%s): give up to write, can't get echo-back\n",
+		       MICON_DEV);
+		goto out;
+	}
+
+	/* send delimiter */
+	memset(cmdbuf, 0, cmdbuflen);
+	snprintf(cmdbuf, cmdbuflen, "%c", MICON_DELIMITER);
+	sys_val = sys_write(fd, cmdbuf, strlen(cmdbuf));
+	if (sys_val < 0) {
+		printk(KERN_ERR
+		       "Micon device(%s): write(delimiter) failed. (%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+	msleep_interruptible(10);
+	sys_val = sys_read(fd, rspbuf, strlen(cmdbuf));
+	if (sys_val < 0) {
+		printk(KERN_ERR
+		       "Micon device(%s): write(delimiter) failed. (%d)\n",
+		       MICON_DEV, sys_val);
+		goto out;
+	}
+	TRACE(printk(KERN_DEBUG "CPU->MICON: send delimiter\n"));
+
+	/* read response */
+	rsplen = 0;
+	memset(rspbuf, 0, sizeof(rspbuf));
+	for (i = 0; i < 10/*XXX*/; i ++) {
+		int j;
+
+		if (rsplen >= sizeof(rspbuf)) {
+			break;
+		}
+		sys_val = sys_read(fd, rspbuf + rsplen,
+				   sizeof(rspbuf) - rsplen);
+		if (sys_val == 0) {
+			break;
+		}
+		else if (sys_val < 0) {
+			if (sys_val == -EAGAIN) {
+				msleep_interruptible(10);/* XXX */
+				continue;
+			}
+			printk(KERN_ERR "Micon device(%s): read() failed.(%d)\n",
+			       MICON_DEV, sys_val);
+			continue;
+		}
+		else {
+			rsplen += sys_val;
+			for (j = 0; j < rsplen; j ++) {
+				if (rspbuf[j] == '\n') {
+					break;
+				}
+			}
+			if (rspbuf[j] == '\n') {
+				break;
+			}
+		}
+		msleep_interruptible(10);
+	}
+	TRACE(printk(KERN_DEBUG "MICON->CPU: [%s]\n", rspbuf));
+	memcpy(outdata, rspbuf, (sys_val > outlen) ? outlen : sys_val);
+
+out:
+	if (cmdbuf != NULL) {
+		kfree(cmdbuf);
+	}
+	sys_ioctl(fd, TCSETS, (long)&termios_save);
+	sys_close(fd);
+	set_fs(oldfs);
+	return sys_val;
+}
+
+
+static int
+micon_v3_send_simple_command(char *cmd, int cmdlen)
+/* expect "OK" or "NG" */
+{
+	char rspbuf[MICON_RSP_MAX];
+	int micon_ret;
+
+	memset(rspbuf, 0, sizeof(rspbuf));
+	micon_ret = micon_v3_serial_io(cmd, cmdlen, rspbuf, sizeof(rspbuf));
+	if (micon_ret < 0) {
+		return micon_ret;
+	}
+
+	if (strncmp(rspbuf, MICON_RSP_ACK, strlen(MICON_RSP_ACK)) == 0) {
+		TRACE(printk(KERN_DEBUG "Micon ACK(OK) is found\n"));
+	}
+	else if (strncmp(rspbuf, MICON_RSP_NACK, strlen(MICON_RSP_NACK)) == 0) {
+		printk(KERN_ERR "Micon NACK(NG) is found\n");
+		/* XXX: need retry ??? */
+		return -1;
+	}
+	else {
+		printk(KERN_ERR "Micon unexpected response[%s]\n", rspbuf);
+		/* XXX: need retry ??? */
+		return -1;
+	}
+
+	return 0;
+}
+
+void
+miconCntl_PowerOff(void)
+{
+	int rsp;
+
+	rsp = micon_v3_send_simple_command(MICON_CMD_POW_OFF,
+					   strlen(MICON_CMD_POW_OFF));
+	if (rsp != 0) {
+		printk(KERN_ERR "%s() failed\n", __FUNCTION__);
+	}
+
+	return;
+}
+
+void
+miconCntl_Reboot(void)
+{
+	int rsp;
+
+	rsp = micon_v3_send_simple_command(MICON_CMD_REBOOT,
+					   strlen(MICON_CMD_REBOOT));
+	if (rsp != 0) {
+		printk(KERN_ERR "%s() failed\n", __FUNCTION__);
+	}
+
+	return;
+}
diff --git a/buffalo/drivers/proc_entry.c b/buffalo/drivers/proc_entry.c
new file mode 100644
index 00000000..0ad7b2d
--- /dev/null
+++ b/buffalo/drivers/proc_entry.c
@@ -0,0 +1,38 @@
+#include <linux/string.h>
+#include "proc_entry.h"
+
+
+static struct proc_dir_entry *proc_buffalo = NULL;
+
+struct proc_dir_entry *
+get_proc_buffalo(void)
+{
+	if (proc_buffalo == NULL)
+		proc_buffalo = proc_mkdir("buffalo", NULL);
+
+	return proc_buffalo;
+}
+
+void
+make_proc_entry(struct proc_entry_data *entry)
+{
+	struct proc_dir_entry *proc_buffalo;
+	struct proc_dir_entry *pde;
+
+	proc_buffalo = get_proc_buffalo();
+	if (proc_buffalo == NULL) {
+		/* XXX */
+	}
+
+	pde = proc_create_data(entry->path, entry->mode,
+			       proc_buffalo, entry->proc_fops, entry->data);
+	if (pde == NULL) {
+		/* XXX */
+	}
+}
+
+void
+delete_proc_entry(char *path)
+{
+	remove_proc_entry(path, NULL);
+}
diff --git a/buffalo/drivers/proc_entry.h b/buffalo/drivers/proc_entry.h
new file mode 100644
index 00000000..ff4fa53e
--- /dev/null
+++ b/buffalo/drivers/proc_entry.h
@@ -0,0 +1,20 @@
+#ifndef _BUFFALO_PROC_ENTRY_H_
+#define _BUFFALO_PROC_ENTRY_H_
+
+#include <linux/version.h>
+#include <linux/proc_fs.h>
+
+
+struct proc_entry_data {
+	char			path[64];
+	umode_t			mode;
+	struct file_operations	*proc_fops;
+	void			*data;
+};
+
+struct proc_dir_entry* get_proc_buffalo(void);
+void make_proc_entry(struct proc_entry_data *entry);
+void delete_proc_entry(char *path);
+
+
+#endif	/* _BUFFALO_PROC_ENTRY_H_ */
diff --git a/buffalo/drivers/rtc_nvram.c b/buffalo/drivers/rtc_nvram.c
new file mode 100644
index 00000000..35ba102
--- /dev/null
+++ b/buffalo/drivers/rtc_nvram.c
@@ -0,0 +1,29 @@
+/*
+ *
+ */
+#include "rtc_nvram.h"
+
+void
+BuffaloRtc_UPSRecoverInit(void)
+{
+	/* XXX: TODO */
+}
+
+extern void
+BuffaloRtc_UPSRecoverEnable(int8_t TargetType)
+{
+	/* XXX: TODO */
+}
+
+extern void
+BuffaloRtc_UPSRecoverDisable(void)
+{
+	/* XXX: TODO */
+}
+
+extern int
+BuffaloRtc_UPSRecoverReadStatus(void)
+{
+	/* XXX: TODO */
+	return 0;
+}
diff --git a/buffalo/drivers/rtc_nvram.h b/buffalo/drivers/rtc_nvram.h
new file mode 100644
index 00000000..8715909
--- /dev/null
+++ b/buffalo/drivers/rtc_nvram.h
@@ -0,0 +1,16 @@
+#ifndef _RTC_NVRAM_H_
+#define _RTC_NVRAM_H_
+
+#include <linux/types.h>
+
+#define RECOVER_TARGET_UPS_APC  1
+#define RECOVER_TARGET_UPS_OMR  2
+#define RECOVER_TARGET_UPS_USB  3
+#define RECOVER_TARGET_UPS_ALL  4
+
+extern void BuffaloRtc_UPSRecoverInit(void);
+extern void BuffaloRtc_UPSRecoverEnable(int8_t TargetType);
+extern void BuffaloRtc_UPSRecoverDisable(void);
+extern int BuffaloRtc_UPSRecoverReadStatus(void);
+
+#endif	/* _RTC_NVRAM_H_ */
diff --git a/buffalo/drivers/upsdrv.c b/buffalo/drivers/upsdrv.c
new file mode 100644
index 00000000..ff76f7b
--- /dev/null
+++ b/buffalo/drivers/upsdrv.c
@@ -0,0 +1,301 @@
+/*
+ *  LinkStation/TeraStation UPS port Driver
+ *
+ *  Copyright (C)  BUFFALO INC.
+ *
+ *  This software may be used and distributed according to the terms of
+ *  the GNU General Public License (GPL), incorporated herein by reference.
+ *  Drivers based on or derived from this code fall under the GPL and must
+ *  retain the authorship, copyright and license notice.  This file is not
+ *  a complete program and may only be used when the entire operating
+ *  system is licensed under the GPL.
+ *
+ */
+#include <linux/version.h>
+#include <linux/module.h>
+#include <linux/kernel.h>
+#include <linux/proc_fs.h>
+
+#include <linux/delay.h>
+#include <linux/seq_file.h>
+#include <linux/slab.h>
+
+#include <linux/serial_reg.h>
+#include <linux/serial_core.h>
+#include <linux/serial_reg.h>
+#include "buffalocore.h"
+#include "rtc_nvram.h"
+
+
+extern void *buffalo_generic_seq_start(struct seq_file *m, loff_t *pos);
+extern void *buffalo_generic_seq_next(struct seq_file *m, void *v, loff_t *pos);
+extern void buffalo_generic_seq_stop(struct seq_file *m, void *v);
+
+
+#define bzero(p,sz) memset(p,0,sz)
+
+//#define DEBUG_UPS
+
+/* Function prototypes */
+
+
+/* variables */
+static struct proc_dir_entry *proc_buffalo_ups;
+
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+//--------------------------------------------------------------
+static void
+BuffaloUpsRecoverInit(void)
+{
+	BuffaloRtc_UPSRecoverInit();
+	printk("BUFFALO UPS Recover Function Initialized.\n");
+
+}
+
+//--------------------------------------------------------------
+static struct {
+	int	mode;
+	char	*w_str;
+	char	*r_str;
+} buffalo_ups_mode_defs[] = {
+	{ 0,	/* default */		"off",		"off"		},
+	{ RECOVER_TARGET_UPS_ALL,	"on",		"on"		},
+};
+
+static int
+buffalo_ups_recover_show(struct seq_file *m, void *v)
+{
+	int i;
+	int stat = BuffaloRtc_UPSRecoverReadStatus();
+	int found = 0;	/* default */
+
+	for (i = 1; i < ARRAY_SIZE(buffalo_ups_mode_defs); i ++) {
+		if (buffalo_ups_mode_defs[i].mode == stat) {
+			found = i;
+			break;
+		}
+	}
+
+	seq_printf(m, "%s\n", buffalo_ups_mode_defs[found].r_str);
+
+	return 0;
+}
+
+static const
+struct seq_operations buffalo_ups_recover_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_ups_recover_show,
+};
+
+static int
+buffalo_ups_recover_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_ups_recover_op);
+}
+
+static int
+buffalo_ups_recover_write(struct file *file, const char __user *buffer,
+			  size_t count, loff_t *ppos)
+{
+	int8_t OnTarget = -1;
+	char *kbuf;
+	int i;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = 0;
+
+	for (i = 0; i < ARRAY_SIZE(buffalo_ups_mode_defs); i ++) {
+		if (strncmp(kbuf, buffalo_ups_mode_defs[i].w_str,
+			    strlen(buffalo_ups_mode_defs[i].w_str)) == 0) {
+			OnTarget = buffalo_ups_mode_defs[i].mode;
+			break;
+		}
+	}
+
+	if (OnTarget > 0) {
+		BuffaloRtc_UPSRecoverEnable(OnTarget);
+	}
+	else if (OnTarget == 0) {
+		BuffaloRtc_UPSRecoverDisable();
+	}
+
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static
+struct file_operations buffalo_ups_recover_fops = {
+	.open		= buffalo_ups_recover_open,
+	.read		= seq_read,
+	.write		= buffalo_ups_recover_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+#endif /* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+static unsigned int OmronShutdownEnable = 0;
+
+static int
+buffalo_ups_omron_shutdown_enable_show(struct seq_file *m, void *v)
+{
+	if (OmronShutdownEnable) {
+		seq_printf(m, "on\n");
+	}
+	else {
+		seq_printf(m, "off\n");
+	}
+	return 0;
+}
+
+static const
+struct seq_operations buffalo_ups_omron_shutdown_enable_op = {
+	.start	= buffalo_generic_seq_start,
+	.next	= buffalo_generic_seq_next,
+	.stop	= buffalo_generic_seq_stop,
+	.show	= buffalo_ups_omron_shutdown_enable_show,
+};
+
+static int
+buffalo_ups_omron_shutdown_enable_open(struct inode *inode, struct file *file)
+{
+	return seq_open(file, &buffalo_ups_omron_shutdown_enable_op);
+}
+
+static ssize_t
+buffalo_ups_omron_shutdown_enable_write(struct file *file,
+					const char __user *buffer,
+					size_t count, loff_t *ppos)
+{
+	char *kbuf;
+
+	kbuf = kmalloc(count + 1, GFP_KERNEL);
+	if (kbuf == NULL) {
+		return -ENOMEM;
+	}
+
+	if (copy_from_user(&kbuf, buffer, count)) {
+		count = -EFAULT;
+		goto out;
+	}
+
+	kbuf[count] = '\0';
+
+	if (strncmp(kbuf, "on", 2) == 0) {
+		OmronShutdownEnable = 1;
+	}
+	else if (strncmp(kbuf, "off", 3) == 0) {
+		OmronShutdownEnable = 0;
+	}
+
+out:
+	kfree(kbuf);
+	return count;
+}
+
+static
+struct file_operations buffalo_ups_omron_shutdown_enable_fops = {
+	.open		= buffalo_ups_omron_shutdown_enable_open,
+	.read		= seq_read,
+	.write		= buffalo_ups_omron_shutdown_enable_write,
+	.llseek		= seq_lseek,
+	.release	= seq_release,
+};
+
+void
+BuffaloUps_ShutdownUps(void)
+{
+	int timeout = 15;
+	int i = 0;
+
+	if (OmronShutdownEnable == 1) {
+#if 0	/* XXX: TODO */
+		/*
+		 * sireal driver is refactored in newer kernel,
+		 * we can't access uart_ports[] structure.
+		 * need to re-implement mctrl setting procedure.
+		 */
+		unsigned int mctrl = uart_ports[UPSPORT]->ops->get_mctrl(uart_ports[UPSPORT]);
+		printk("Shuttting down OMRON ups ... \n");
+
+#if defined(CONFIG_ARCH_FEROCEON_KW) || defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+		mctrl &= ~TIOCM_DTR;	// ARMの場合は、TIOCM_DTRが論理反転していたため。
+#else //ARMADA_XPは設定側で反転
+		mctrl |= TIOCM_DTR;
+#endif
+		uart_ports[UPSPORT]->ops->set_mctrl(uart_ports[UPSPORT], mctrl);
+#endif	/* XXX */
+		while (timeout) {
+			for (i = 0; i < 1000; i++) {
+				udelay(1000);
+			}
+			timeout--;
+		}
+		if(timeout == 0)
+			printk("Failed?\n");
+	}
+}
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+//--------------------------------------------------------------
+/*
+ * Initialize driver.
+ */
+int __init
+BuffaloUpsdrv_init (void)
+{
+	printk("UPSDRV (C) BUFFALO INC. V.1.10 installed.\n"); 
+	
+	proc_buffalo_ups = proc_mkdir("buffalo/ups", 0);
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+	BuffaloUpsRecoverInit();
+	proc_create("ups_recover", S_IRUGO|S_IWUSR, proc_buffalo_ups,
+		    &buffalo_ups_recover_fops);
+#endif	/* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+	proc_create("omron_shutdown_enable", S_IRUGO|S_IWUSR, proc_buffalo_ups,
+		    &buffalo_ups_omron_shutdown_enable_fops);
+	printk("  OMRON contact type ups shutdown support enabled!\n");
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+	return 0;
+}
+
+//--------------------------------------------------------------
+void
+BuffaloUpsdrv_exit(void)
+{
+	printk("UPSDRV removed.");
+
+#ifdef CONFIG_BUFFALO_SUPPORT_UPS_RECOVER
+	remove_proc_entry("ups_recover", proc_buffalo_ups);
+	proc_buffalo_ups = NULL;
+#endif	/* CONFIG_BUFFALO_SUPPORT_UPS_RECOVER */
+
+#ifdef CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN
+	remove_proc_entry("omron_shutdown_enable", proc_buffalo_ups);
+#endif	/* CONFIG_BUFFALO_SUPPORT_OMRON_UPS_SHUTDOWN */
+
+	proc_buffalo_ups = NULL;
+	remove_proc_entry("buffalo/ups", 0);
+}
+
+module_init(BuffaloUpsdrv_init);
+module_exit(BuffaloUpsdrv_exit);
+MODULE_LICENSE("GPL");
diff --git a/buffalo/include/buffalo/kernevnt.h b/buffalo/include/buffalo/kernevnt.h
new file mode 100644
index 00000000..94803ac
--- /dev/null
+++ b/buffalo/include/buffalo/kernevnt.h
@@ -0,0 +1,74 @@
+#ifndef _KERNEVNT_H_
+#define _KERNEVNT_H_
+
+// variable definition.
+#define POWER_STATUS_REBOOTING                  1
+#define POWER_STATUS_REBOOTING_UBOOT_PASSED     2
+#define POWER_STATUS_NORMAL_STATE               3
+#define POWER_STATUS_HW_POWER_OFF               4
+#define POWER_STATUS_SW_POWER_OFF               5
+#define POWER_STATUS_SW_POFF_UBOOT_PASSED       6
+#define POWER_STATUS_FWUPDATING                 7
+#define POWER_STATUS_REBOOT_REACHED_HALT        8
+#define	POWER_STATUS_SW_POFF_REACHED_HALT       9
+#define POWER_STATUS_UPS_SHUTDOWN		10
+#define POWER_STATUS_UPS_SHUTDOWN_REACHED_HALT	11
+#define POWER_STATUS_WOL_READY_STATE		12
+#define POWER_STATUS_WOL_READY_UBOOT_PASSED	13
+
+// difinition for MagicKey.
+// DEF4CPU = (CONFIG_ARCH_FEROCEON_MV78XX0, CONFIG_ARCH_ARMADA_XP, other)
+
+#if defined(CONFIG_ARCH_FEROCEON_MV78XX0)
+#define DEF4CPU(x,y,z)  x
+#elif defined(CONFIG_ARCH_ARMADA_XP)
+#define DEF4CPU(x,y,z)  y
+#else
+#define DEF4CPU(x,y,z)  z
+#endif
+
+#define MagicKeyReboot                  0x18
+#define MagicKeyRebootUbootPassed       0x3a
+#define MagicKeyNormalState             0x71
+#define MagicKeyHwPoff                  0x43
+#define MagicKeySwPoff                  DEF4CPU(0x02,	0x41,	0x02)
+#define MagicKeySWPoffUbootPassed       0x5c
+#define MagicKeyFWUpdating              0x6f
+#define MagicKeyRebootReachedHalt       0x2b
+#define MagicKeySWPoffReachedHalt       0x7a
+#define MagicKeyUpsShutdown             DEF4CPU(0x45,   0x21,   0x21)
+#define MagicKeyUpsShutdownReachedHalt  DEF4CPU(0x16,   0x32,   0x32)
+#define MagicKeyWOLReadyState           DEF4CPU(0x75,   0x02,   0x75)
+#define MagicKeyWOLReadyUbootPasswd	0x70
+
+#define MagicKeyTerminator		0x00	/* use as terminator in defs,
+						 * it must not conflict
+						 * with meaningful values
+						 */
+
+/* routines are in buffalo/drivers/kernevnt.c */
+void kernevnt_LanAct(void *data);
+void kernevnt_SwitchHubAct(const char *msg);
+#ifdef CONFIG_MD
+void kernevnt_RaidRecovery(int devno,int on, int isRecovery, int major, int minor);
+void kernevnt_RaidScan(int devno, int on);
+void kernevnt_RaidDegraded(int devno, int major, int minor);
+void kernevnt_RaidReshape(int devno, int on);
+#endif
+
+struct buffalo_cpu_status_defs {
+	unsigned int stat;
+	char *str;
+};
+
+void kernevnt_IOErr(const char *kdevname, const char *dir, unsigned long long sector, unsigned int errcnt);
+void kernevnt_FlashUpdate(int on);
+void kernevnt_DriveDead(const char *drvname);
+void kernevnt_I2cErr(void);
+void kernevnt_MiconInt(void);
+void kernevnt_EnetOverload(const char *name);
+void buffalo_kernevnt_queuein(const char *cmd);
+
+extern void (*kernevnt_LanAct_arch)(void *data);
+
+#endif
diff --git a/buffalo/include/buffalo/micon_v3.h b/buffalo/include/buffalo/micon_v3.h
new file mode 100644
index 00000000..90f3b2e
--- /dev/null
+++ b/buffalo/include/buffalo/micon_v3.h
@@ -0,0 +1,11 @@
+/*
+ *
+ */
+
+#ifndef __BUFFALO_MICON_V3_H__
+#define __BUFFALO_MICON_V3_H__
+
+extern void miconCntl_PowerOff(void);
+extern void miconCntl_Reboot(void);
+
+#endif	/* __BUFFALO_MICON_V3_H__ */
diff --git a/buffalo/scripts/debianize.sh b/buffalo/scripts/debianize.sh
new file mode 100755
index 00000000..da46ab8
--- /dev/null
+++ b/buffalo/scripts/debianize.sh
@@ -0,0 +1,271 @@
+#!/bin/bash
+#
+export LANGUAGE=C
+export LC_ALL=C
+
+# force fixup kernel build user/host, default:"root@buffalo.jp"
+#
+: ${KBUILD_BUILD_USER:="root"}
+: ${KBUILD_BUILD_HOST:="buffalo.jp"}
+export KBUILD_BUILD_USER KBUILD_BUILD_HOST
+
+# kernel version dependent settings:
+#
+: ${KERNELVERSION:="3.10.20"}
+: ${UBUNTUCORE_NAME:="v${KERNELVERSION}-saucy"}
+: ${UBUNTUCORE_URL:="http://kernel.ubuntu.com/~kernel-ppa/mainline/${UBUNTUCORE_NAME}"}
+:
+UBUNTU_PATCHES='
+	0001-base-packaging.patch
+	0002-debian-changelog.patch
+	0003-configs-based-on-Ubuntu-3.10.0-2.10.patch
+'
+: ${UBUNTU_PATCHDIR:="buffalo/ubuntu/"}
+
+# target architecutre/machine dependent settings:
+#
+: ${ARCH:="arm"}
+: ${SRCARCH:="armhf"}
+: ${MACHINE:="buffalo_ts5010"}
+: ${DTSNAMES:="alpine_db"}
+: ${FLAVOUR:="generic-sa"}
+: ${FLAVOUR_SUPPORTED:="Generic SA"}
+: ${GCCNAME:="gcc-4.8"}
+: ${DEFCONFIG:="buffalo/arch/${ARCH}/configs/${MACHINE}_defconfig"}
+: ${PACKAGE_ARCHIVE:="kernel_armhf_with_alpine-lsp-5.0-sa"}
+: ${KERNEL_DTSDIR:="arch/${ARCH}/boot/dts/"}
+: ${EXTRA_DTSDIR:="buffalo/arch/${ARCH}/boot/dts/"}
+: ${UIMAGE_NAME:="TS5010"}
+: ${LOAD_ADDRESS:="0x00008000"}
+: ${ENTRY_ADDRESS:="0x00008000"}
+
+# mkimage command path.
+#
+: ${MKIMAGE:=$(which mkimage)}
+
+
+
+fetch_ubuntu_patch () {
+	curl --fail -OL ${UBUNTUCORE_URL}/$1 >/dev/null 2>&1 && return 0
+	cp "${UBUNTU_PATCHDIR}"$1 . >/dev/null 2>&1 && return 0
+	echo "failed to fetch Ubuntu patch" >&2
+	exit 1
+}
+
+apply_ubuntu_patch () {
+	rm -rf debian debian.master
+	for file in ${UBUNTU_PATCHES}; do
+		[ -f ${file} ] || fetch_ubuntu_patch $file
+		patch -p1 < $file || exit 1
+	done
+	chmod +x debian/rules
+	chmod -R u+x debian/scripts/*
+	fakeroot debian/rules clean
+}
+
+fixup_kernel_flavour () {
+	# create debian.master/control.d/vars.${FLAVOUR}
+	#
+	sed -e "s/^arch=.*/arch=\"${SRCARCH}\"/" \
+	    -e "s/^supported=.*/supported=\"${FLAVOUR_SUPPORTED}\"/" \
+	    debian.master/control.d/vars.$1 \
+	    > debian.master/control.d/vars.$2
+
+	# create debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+	#
+	cp debian.master/config/${SRCARCH}/config.flavour.$1 \
+	   debian.master/config/${SRCARCH}/config.flavour.$2
+
+	fakeroot debian/rules clean
+}
+
+fixup_buffalo_configs () {
+	[ -d debian.master ] || apply_ubuntu_patch
+
+	# create new flavour based on 'generic', if needed.
+	#
+	[ -f debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR} ] \
+	    || fixup_kernel_flavour generic ${FLAVOUR}
+
+	# merge machine dependent configs to flavour, except for
+	# CONFIG_LOCALVERSION setting.
+	#
+	egrep -v '^CONFIG_LOCALVERSION' ${DEFCONFIG} \
+	    >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR} \
+	    || exit 1
+
+	fixup_ubuntu_configs || exit 1
+	fixup_${SRCARCH}_configs || true
+
+	for name in ${DTSNAMES}; do
+	    dts="$(basename $name .dts).dts"
+	    if [ -f "${EXTRA_DTSDIR}${dts}" ]; then
+		rm -f "${KERNEL_DTSDIR}${dts}"
+		cat "${EXTRA_DTSDIR}${dts}" > "${KERNEL_DTSDIR}${dts}" \
+		|| exit 1
+	    fi
+	done
+}
+
+# fixup configes drived from UBUNTU.
+#
+fixup_ubuntu_configs () {
+	# Subject: UBUNTU: [Config] CONFIG_ANDROID=n
+	# Author: Tim Gardner <tim.gardner@canonical.com>
+	# Date: 2013-10-07 13:54:56 (GMT)
+	# commit: b50a787fbcd6f42e9c552b201e58953049ac4428
+	# BugLink: http://bugs.launchpad.net/bugs/1235161
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_ANDROID is not set
+EOF
+}
+
+fixup_armhf_configs () {
+	# To disable asking configs in 'make menuconfig', append default
+	# value to undefined configs.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_CPU_BIG_ENDIAN is not set
+# CONFIG_ARM_UNIPROCESSOR_IOCC is not set
+# CONFIG_ARM_ERRATA_458693 is not set
+# CONFIG_ARM_ERRATA_460075 is not set
+# CONFIG_ARM_ERRATA_742230 is not set
+# CONFIG_ARM_ERRATA_742231 is not set
+# CONFIG_ARM_ERRATA_743622 is not set
+# CONFIG_ARM_ERRATA_751472 is not set
+# CONFIG_ARM_ERRATA_798181 is not set
+# CONFIG_FUNC_REORDER is not set
+CONFIG_CMDLINE_FROM_BOOTLOADER=y
+# CONFIG_CMDLINE_EXTEND is not set
+# CONFIG_CMDLINE_FORCE is not set
+CONFIG_MTD_CFI_NOSWAP=y
+# CONFIG_MTD_CFI_BE_BYTE_SWAP is not set
+# CONFIG_MTD_CFI_LE_BYTE_SWAP is not set
+# CONFIG_MTD_CFI_GEOMETRY is not set
+# CONFIG_MTD_OTP is not set
+# CONFIG_CPU_IDLE_ALPINE is not set
+# CONFIG_NET_TEAM_MODE_RANDOM is not set
+# CONFIG_AL_ETH_ALLOC_FRAG is not set
+# CONFIG_AL_ETH_ALLOC_PAGE is not set
+CONFIG_AL_ETH_ALLOC_SKB=y
+# CONFIG_USB_DWC3_AL is not set
+# CONFIG_DEBUG_SLAB is not set
+# CONFIG_DEBUG_LL is not set
+# CONFIG_CRYPTO_FIPS is not set
+EOF
+
+	# TO avoid compile error in "drivers/dma/amba-pl08x.c" with
+	# get_signal() macro, force disable CONFIG_AMBA_PL08X.
+	# also force disable CONFIG_XEN to avoid error in
+	# "drivers/net/xen-netfront.c".
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_AMBA_PL08X is not set
+# CONFIG_XEN is not set
+EOF
+	# To enable CONFIG_PAGE_SIZE_LARGE, CONFIG_ARM_PAGE_SIZE_32KB, and
+	# CONFIG_LFS_ON_32CPU configs on 'Storage Advance' kernel,
+	# force disable CONFIG_HUGETLBFS and CONFIG_TRANSPARENT_HUGEPAGE
+	# that are dependancy of configs above.
+	# See 'depends' filed of ARM_PAGE_SIZE_LARGE entry in
+	# "arch/arm/mm/Kconfig".
+	# Becase disabling HUGETLBFS or TRANSPARENT_HUGEPAGE cause system
+	# hang-up while boot, it also need to force disable ARM_ERRATA_720789.
+	#
+	# In addtion, some CONFIG_FB_* was force disabled to avoid linker
+	# failer caused by lacking of "__aeabi_uldivmod" function.
+	#
+	# Also, some configs followed MUST be disabled on 'Storage Advance'
+	# kernel: XFRM_ALGO, XFRM_USER, NET_KEY, INET_AH, and INET_ESP,
+	# see alpine build script "scripts/al_build_defconfig".
+	# Config XFRM_ALGO MUST be disabled, but which is selected
+	# by INET_IPCOMP, INET6_AH, and INET6_ESP (there are undocumented).
+	# Note that these 3 configs are also disabled here.
+	#
+	case "${FLAVOUR}" in
+	*-sa)	# 'Storage Advance' flavor.
+		cat <<'EOF' \
+		>> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+CONFIG_HUGETLBFS=n
+CONFIG_TRANSPARENT_HUGEPAGE=n
+CONFIG_ARM_ERRATA_720789=n
+CONFIG_FB_SMSCUFX=n
+CONFIG_FB_BROADSHEET=n
+CONFIG_FB_AUO_K190X=n
+CONFIG_XFRM_ALGO=n
+CONFIG_XFRM_USER=n
+CONFIG_NET_KEY=n
+CONFIG_INET_AH=n
+CONFIG_INET_ESP=n
+CONFIG_INET_IPCOMP=n
+CONFIG_INET6_AH=n
+CONFIG_INET6_ESP=n
+CONFIG_INET6_IPCOMP=n
+EOF
+		;;
+	esac
+	# To fixup user/kernel vm-page split layout configuration
+	# from 1/3 split (ubuntu original) to 2/2 split.
+	#
+	cat <<'EOF' >> debian.master/config/${SRCARCH}/config.flavour.${FLAVOUR}
+# CONFIG_VMSPLIT_3G is not set
+CONFIG_VMSPLIT_2G=y
+# CONFIG_VMSPLIT_1G is not set
+EOF
+}
+
+
+fixup_buffalo_rules () {
+	[ -d debian.master ] || apply_ubuntu_patch
+
+	sed -e "/^flavours/s/=.*/= ${FLAVOUR}/" \
+	    -e "/^gcc/s/=.*/= ${GCCNAME}/" \
+	    -i debian.master/rules.d/${SRCARCH}.mk
+	for name in ${DTSNAMES}; do
+		dts="$(basename $name .dts)"
+		/bin/echo -e "dtb_files_${FLAVOUR}\t+= ${dts}.dtb" \
+		>> debian.master/rules.d/${SRCARCH}.mk
+	done
+}
+
+build_buffalo_packages () {
+	fakeroot debian/rules do_tools=0 no_dumpfile=1 binary-headers
+	fakeroot debian/rules clean
+	dpkg-architecture -a${SRCARCH} -c debian/rules \
+		do_extras_package=false do_tools=0 no_dumpfile=1 build-arch
+	dpkg-architecture -a${SRCARCH} -c fakeroot debian/rules \
+		do_extras_package=false do_tools=0 no_dumpfile=1 binary-debs
+}
+
+build_uimage_packeges () {
+	# ensure mkimage command was installed.
+	[ -x ${MKIMAGE} ] || return 1;
+
+	tmpdir="debian/tmpwork$$"
+	trap 'rm -rf ${tmpdir}' EXIT TERM HUP INT QUIT
+	for pkg in $(echo ../linux-image-*.deb); do
+		[ -f "$pkg" ] || continue
+		name=$(basename ${pkg} .deb)
+		image=linux-kernel-${name##linux-image-}.img
+		mkdir -p ${tmpdir}
+		dpkg -x ${pkg} ${tmpdir}
+		for file in $(echo ${tmpdir}/boot/vmlinu*); do
+			[ -f "$file" ] || continue
+			${MKIMAGE} -A ${ARCH} -O linux -T kernel -C none \
+			    -a ${LOAD_ADDRESS} -e ${ENTRY_ADDRESS} \
+			    -n ${UIMAGE_NAME} \
+			    -d ${file} ../${image}
+		done
+		rm -rf ${tmpdir}
+	done
+	rm -rf ${tmpdir}
+	trap '' EXIT TERM HUP INT QUIT
+}
+
+fixup_buffalo_configs
+fixup_buffalo_rules
+build_buffalo_packages
+build_uimage_packeges
+
+( cd ..; tar cvf ${PACKAGE_ARCHIVE}.tar linux-*.deb linux-*.img )
diff --git a/buffalo/scripts/mkbuilddate_h b/buffalo/scripts/mkbuilddate_h
new file mode 100644
index 00000000..c046309
--- /dev/null
+++ b/buffalo/scripts/mkbuilddate_h
@@ -0,0 +1,21 @@
+#!/bin/sh
+
+TARGET=$1
+
+vecho() { [ "${quiet}" = "silent_" ] || echo "$@" ; }
+
+# Do not expand names
+set -f
+
+# Fix the language to get consistent output
+LC_ALL=C
+export LC_ALL
+
+vecho "  UPD     $TARGET"
+
+( echo /\* This file is auto generated \*/
+
+  date "+#define BUFFALO_BUILD_DATE \"%Y/%m/%d\"%n#define BUFFALO_BUILD_TIME \"%T\""
+
+) > $TARGET
+
diff --git a/buffalo/ubuntu/.gitignore b/buffalo/ubuntu/.gitignore
new file mode 100644
index 00000000..69f1bf4
--- /dev/null
+++ b/buffalo/ubuntu/.gitignore
@@ -0,0 +1 @@
+!*.patch
diff --git a/buffalo/ubuntu/0001-base-packaging.patch b/buffalo/ubuntu/0001-base-packaging.patch
new file mode 100644
index 00000000..8ab6ea5
--- /dev/null
+++ b/buffalo/ubuntu/0001-base-packaging.patch
@@ -0,0 +1,104732 @@
+From b98cec0e9e28fd616b46f438347da932ce864979 Mon Sep 17 00:00:00 2001
+From: Andy Whitcroft <apw@gomeisa.buildd>
+Date: Wed, 20 Nov 2013 15:36:26 -0500
+Subject: [PATCH 1/3] base packaging
+
+---
+ debian.master/NOTES                                |    4 +
+ debian.master/abi/3.11.0-13.20/abiname             |    1 +
+ debian.master/abi/3.11.0-13.20/amd64/generic       |15575 +++++++++++++++++++
+ .../abi/3.11.0-13.20/amd64/generic.compiler        |    1 +
+ .../abi/3.11.0-13.20/amd64/generic.modules         | 3956 +++++
+ debian.master/abi/3.11.0-13.20/armhf/generic       |14794 ++++++++++++++++++
+ debian.master/abi/3.11.0-13.20/armhf/generic-lpae  |12283 +++++++++++++++
+ .../abi/3.11.0-13.20/armhf/generic-lpae.compiler   |    1 +
+ .../abi/3.11.0-13.20/armhf/generic-lpae.modules    | 2834 ++++
+ .../abi/3.11.0-13.20/armhf/generic.compiler        |    1 +
+ .../abi/3.11.0-13.20/armhf/generic.modules         | 3668 +++++
+ debian.master/abi/3.11.0-13.20/fwinfo              |  726 +
+ debian.master/abi/3.11.0-13.20/i386/generic        |15645 ++++++++++++++++++++
+ .../abi/3.11.0-13.20/i386/generic.compiler         |    1 +
+ .../abi/3.11.0-13.20/i386/generic.modules          | 4149 ++++++
+ debian.master/changelog                            |10085 +++++++++++++
+ debian.master/changelog.historical                 | 4171 ++++++
+ debian.master/config/amd64/config.common.amd64     |  117 +
+ debian.master/config/amd64/config.flavour.generic  |    3 +
+ debian.master/config/annotations                   | 1373 ++
+ debian.master/config/arm64/config.common.arm64     |    1 +
+ .../config/arm64/config.flavour.linaro-SOCFLAVOUR  |    1 +
+ debian.master/config/armhf/config.common.armhf     |   82 +
+ debian.master/config/armhf/config.flavour.generic  |   37 +
+ .../config/armhf/config.flavour.generic-lpae       |   37 +
+ debian.master/config/config.common.ports           |    3 +
+ debian.master/config/config.common.ubuntu          | 7098 +++++++++
+ debian.master/config/enforce                       |  131 +
+ debian.master/config/i386/config.common.i386       |  115 +
+ debian.master/config/i386/config.flavour.generic   |    3 +
+ debian.master/config/x32/config.common.x32         |    1 +
+ debian.master/config/x32/config.flavour.generic    |    1 +
+ debian.master/control.d/flavour-control.stub       |  119 +
+ debian.master/control.d/generic.inclusion-list     |  159 +
+ debian.master/control.d/vars.generic               |    6 +
+ debian.master/control.d/vars.generic-lpae          |    6 +
+ debian.master/control.stub.in                      |   94 +
+ debian.master/copyright                            |   29 +
+ debian.master/d-i/exclude-firmware.armhf-generic   |    2 +
+ .../d-i/exclude-firmware.armhf-generic-lpae        |    2 +
+ debian.master/d-i/exclude-modules.amd64-virtual    |   15 +
+ debian.master/d-i/exclude-modules.armhf-generic    |   10 +
+ .../d-i/exclude-modules.armhf-generic-lpae         |   10 +
+ debian.master/d-i/exclude-modules.i386-virtual     |   15 +
+ debian.master/d-i/firmware/README.txt              |    4 +
+ debian.master/d-i/firmware/kernel-image            |   11 +
+ debian.master/d-i/firmware/nic-modules             |   14 +
+ debian.master/d-i/firmware/scsi-modules            |    3 +
+ debian.master/d-i/kernel-versions.in               |   11 +
+ debian.master/d-i/modules/block-modules            |   33 +
+ debian.master/d-i/modules/crypto-modules           |   70 +
+ debian.master/d-i/modules/fat-modules              |    7 +
+ debian.master/d-i/modules/fb-modules               |    3 +
+ debian.master/d-i/modules/firewire-core-modules    |    4 +
+ debian.master/d-i/modules/floppy-modules           |    1 +
+ debian.master/d-i/modules/fs-core-modules          |    4 +
+ debian.master/d-i/modules/fs-secondary-modules     |    5 +
+ debian.master/d-i/modules/input-modules            |   23 +
+ debian.master/d-i/modules/ipmi-modules             |    5 +
+ debian.master/d-i/modules/irda-modules             |   30 +
+ debian.master/d-i/modules/kernel-image             |   24 +
+ debian.master/d-i/modules/md-modules               |   16 +
+ debian.master/d-i/modules/message-modules          |   14 +
+ debian.master/d-i/modules/mouse-modules            |    2 +
+ debian.master/d-i/modules/multipath-modules        |    2 +
+ debian.master/d-i/modules/nfs-modules              |    6 +
+ debian.master/d-i/modules/nic-modules              |  172 +
+ debian.master/d-i/modules/nic-pcmcia-modules       |   19 +
+ debian.master/d-i/modules/nic-shared-modules       |   26 +
+ debian.master/d-i/modules/nic-usb-modules          |   32 +
+ debian.master/d-i/modules/parport-modules          |    2 +
+ debian.master/d-i/modules/pata-modules             |   47 +
+ debian.master/d-i/modules/pcmcia-modules           |    8 +
+ debian.master/d-i/modules/pcmcia-storage-modules   |    6 +
+ debian.master/d-i/modules/plip-modules             |    1 +
+ debian.master/d-i/modules/ppp-modules              |    6 +
+ debian.master/d-i/modules/sata-modules             |   17 +
+ debian.master/d-i/modules/scsi-modules             |  126 +
+ debian.master/d-i/modules/serial-modules           |    3 +
+ debian.master/d-i/modules/speakup-modules          |   16 +
+ debian.master/d-i/modules/squashfs-modules         |    1 +
+ debian.master/d-i/modules/storage-core-modules     |   10 +
+ debian.master/d-i/modules/usb-modules              |   10 +
+ debian.master/d-i/modules/virtio-modules           |    9 +
+ debian.master/d-i/modules/vlan-modules             |    3 +
+ debian.master/d-i/package-list                     |  201 +
+ debian.master/etc/getabis                          |   16 +
+ debian.master/etc/kernelconfig                     |    7 +
+ debian.master/rules.d/amd64.mk                     |   16 +
+ debian.master/rules.d/arm64.mk                     |   13 +
+ debian.master/rules.d/armhf.mk                     |   31 +
+ debian.master/rules.d/i386.mk                      |   15 +
+ debian.master/rules.d/powerpc.mk                   |   12 +
+ debian.master/rules.d/ppc64el.mk                   |   13 +
+ debian.master/rules.d/x32.mk                       |   14 +
+ debian/commit-templates/bumpabi                    |    3 +
+ debian/commit-templates/config-updates             |   15 +
+ debian/commit-templates/external-driver            |   20 +
+ debian/commit-templates/missing-modules            |    3 +
+ debian/commit-templates/newrelease                 |    3 +
+ debian/commit-templates/sauce-patch                |   40 +
+ debian/commit-templates/upstream-patch             |   27 +
+ debian/compat                                      |    1 +
+ debian/control-scripts/headers-postinst            |  126 +
+ debian/control-scripts/postinst                    | 1095 ++
+ debian/control-scripts/postrm                      |  361 +
+ debian/control-scripts/preinst                     |  315 +
+ debian/control-scripts/prerm                       |  312 +
+ debian/debian.env                                  |    1 +
+ debian/docs/README.inclusion-list                  |   51 +
+ debian/rules                                       |  252 +
+ debian/rules.d/0-common-vars.mk                    |  233 +
+ debian/rules.d/1-maintainer.mk                     |  120 +
+ debian/rules.d/2-binary-arch.mk                    |  586 +
+ debian/rules.d/3-binary-indep.mk                   |  149 +
+ debian/rules.d/4-checks.mk                         |   27 +
+ debian/rules.d/5-udebs.mk                          |   67 +
+ debian/scripts/abi-check                           |    2 +
+ debian/scripts/config-check                        |    2 +
+ debian/scripts/control-create                      |   25 +
+ debian/scripts/link-headers                        |   42 +
+ debian/scripts/misc/find-obsolete-firmware         |   91 +
+ debian/scripts/misc/fw-to-ihex.sh                  |   18 +
+ debian/scripts/misc/get-firmware                   |   62 +
+ debian/scripts/misc/getabis                        |  130 +
+ debian/scripts/misc/git-ubuntu-log                 |  232 +
+ debian/scripts/misc/insert-changes.pl              |   36 +
+ debian/scripts/misc/insert-mainline-changes        |   42 +
+ debian/scripts/misc/insert-ubuntu-changes          |   58 +
+ debian/scripts/misc/kernelconfig                   |  172 +
+ debian/scripts/misc/retag                          |   34 +
+ debian/scripts/misc/splitconfig.pl                 |  107 +
+ debian/scripts/module-check                        |    2 +
+ debian/scripts/module-inclusion                    |   60 +
+ debian/scripts/sub-flavour                         |   69 +
+ debian/source/format                               |    1 +
+ debian/stamps/keep-dir                             |    1 +
+ debian/tests-build/README                          |   21 +
+ debian/tests-build/check-aliases                   |   24 +
+ debian/tests/control                               |    3 +
+ debian/tests/rebuild                               |    1 +
+ debian/tools/generic                               |   30 +
+ 142 files changed, 103581 insertions(+)
+ create mode 100644 debian.master/NOTES
+ create mode 100644 debian.master/abi/3.11.0-13.20/abiname
+ create mode 100644 debian.master/abi/3.11.0-13.20/amd64/generic
+ create mode 100644 debian.master/abi/3.11.0-13.20/amd64/generic.compiler
+ create mode 100644 debian.master/abi/3.11.0-13.20/amd64/generic.modules
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic-lpae
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic-lpae.compiler
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic-lpae.modules
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic.compiler
+ create mode 100644 debian.master/abi/3.11.0-13.20/armhf/generic.modules
+ create mode 100644 debian.master/abi/3.11.0-13.20/fwinfo
+ create mode 100644 debian.master/abi/3.11.0-13.20/i386/generic
+ create mode 100644 debian.master/abi/3.11.0-13.20/i386/generic.compiler
+ create mode 100644 debian.master/abi/3.11.0-13.20/i386/generic.modules
+ create mode 100644 debian.master/abi/perm-blacklist
+ create mode 100644 debian.master/changelog
+ create mode 100644 debian.master/changelog.historical
+ create mode 100644 debian.master/config/amd64/config.common.amd64
+ create mode 100644 debian.master/config/amd64/config.flavour.generic
+ create mode 100644 debian.master/config/annotations
+ create mode 100644 debian.master/config/arm64/config.common.arm64
+ create mode 100644 debian.master/config/arm64/config.flavour.linaro-SOCFLAVOUR
+ create mode 100644 debian.master/config/armhf/config.common.armhf
+ create mode 100644 debian.master/config/armhf/config.flavour.generic
+ create mode 100644 debian.master/config/armhf/config.flavour.generic-lpae
+ create mode 100644 debian.master/config/config.common.ports
+ create mode 100644 debian.master/config/config.common.ubuntu
+ create mode 100644 debian.master/config/enforce
+ create mode 100644 debian.master/config/i386/config.common.i386
+ create mode 100644 debian.master/config/i386/config.flavour.generic
+ create mode 100644 debian.master/config/x32/config.common.x32
+ create mode 100644 debian.master/config/x32/config.flavour.generic
+ create mode 100644 debian.master/control.d/flavour-control.stub
+ create mode 100644 debian.master/control.d/generic.inclusion-list
+ create mode 100644 debian.master/control.d/vars.generic
+ create mode 100644 debian.master/control.d/vars.generic-lpae
+ create mode 100644 debian.master/control.stub.in
+ create mode 100644 debian.master/copyright
+ create mode 100644 debian.master/d-i/exclude-firmware.armhf-generic
+ create mode 100644 debian.master/d-i/exclude-firmware.armhf-generic-lpae
+ create mode 100644 debian.master/d-i/exclude-modules.amd64-virtual
+ create mode 100644 debian.master/d-i/exclude-modules.armhf-generic
+ create mode 100644 debian.master/d-i/exclude-modules.armhf-generic-lpae
+ create mode 100644 debian.master/d-i/exclude-modules.i386-virtual
+ create mode 100644 debian.master/d-i/firmware/README.txt
+ create mode 100644 debian.master/d-i/firmware/kernel-image
+ create mode 100644 debian.master/d-i/firmware/nic-modules
+ create mode 100644 debian.master/d-i/firmware/scsi-modules
+ create mode 100644 debian.master/d-i/kernel-versions.in
+ create mode 100644 debian.master/d-i/modules/block-modules
+ create mode 100644 debian.master/d-i/modules/crypto-modules
+ create mode 100644 debian.master/d-i/modules/fat-modules
+ create mode 100644 debian.master/d-i/modules/fb-modules
+ create mode 100644 debian.master/d-i/modules/firewire-core-modules
+ create mode 100644 debian.master/d-i/modules/floppy-modules
+ create mode 100644 debian.master/d-i/modules/fs-core-modules
+ create mode 100644 debian.master/d-i/modules/fs-secondary-modules
+ create mode 100644 debian.master/d-i/modules/input-modules
+ create mode 100644 debian.master/d-i/modules/ipmi-modules
+ create mode 100644 debian.master/d-i/modules/irda-modules
+ create mode 100644 debian.master/d-i/modules/kernel-image
+ create mode 100644 debian.master/d-i/modules/md-modules
+ create mode 100644 debian.master/d-i/modules/message-modules
+ create mode 100644 debian.master/d-i/modules/mouse-modules
+ create mode 100644 debian.master/d-i/modules/multipath-modules
+ create mode 100644 debian.master/d-i/modules/nfs-modules
+ create mode 100644 debian.master/d-i/modules/nic-modules
+ create mode 100644 debian.master/d-i/modules/nic-pcmcia-modules
+ create mode 100644 debian.master/d-i/modules/nic-shared-modules
+ create mode 100644 debian.master/d-i/modules/nic-usb-modules
+ create mode 100644 debian.master/d-i/modules/parport-modules
+ create mode 100644 debian.master/d-i/modules/pata-modules
+ create mode 100644 debian.master/d-i/modules/pcmcia-modules
+ create mode 100644 debian.master/d-i/modules/pcmcia-storage-modules
+ create mode 100644 debian.master/d-i/modules/plip-modules
+ create mode 100644 debian.master/d-i/modules/ppp-modules
+ create mode 100644 debian.master/d-i/modules/sata-modules
+ create mode 100644 debian.master/d-i/modules/scsi-modules
+ create mode 100644 debian.master/d-i/modules/serial-modules
+ create mode 100644 debian.master/d-i/modules/speakup-modules
+ create mode 100644 debian.master/d-i/modules/squashfs-modules
+ create mode 100644 debian.master/d-i/modules/storage-core-modules
+ create mode 100644 debian.master/d-i/modules/usb-modules
+ create mode 100644 debian.master/d-i/modules/virtio-modules
+ create mode 100644 debian.master/d-i/modules/vlan-modules
+ create mode 100644 debian.master/d-i/package-list
+ create mode 100644 debian.master/etc/getabis
+ create mode 100644 debian.master/etc/kernelconfig
+ create mode 100644 debian.master/rules.d/amd64.mk
+ create mode 100644 debian.master/rules.d/arm64.mk
+ create mode 100644 debian.master/rules.d/armhf.mk
+ create mode 100644 debian.master/rules.d/i386.mk
+ create mode 100644 debian.master/rules.d/powerpc.mk
+ create mode 100644 debian.master/rules.d/ppc64el.mk
+ create mode 100644 debian.master/rules.d/x32.mk
+ create mode 100644 debian/commit-templates/bumpabi
+ create mode 100644 debian/commit-templates/config-updates
+ create mode 100644 debian/commit-templates/external-driver
+ create mode 100644 debian/commit-templates/missing-modules
+ create mode 100644 debian/commit-templates/newrelease
+ create mode 100644 debian/commit-templates/sauce-patch
+ create mode 100644 debian/commit-templates/upstream-patch
+ create mode 100644 debian/compat
+ create mode 100644 debian/control-scripts/headers-postinst
+ create mode 100644 debian/control-scripts/postinst
+ create mode 100644 debian/control-scripts/postrm
+ create mode 100644 debian/control-scripts/preinst
+ create mode 100644 debian/control-scripts/prerm
+ create mode 100644 debian/debian.env
+ create mode 100644 debian/docs/README.inclusion-list
+ create mode 100755 debian/rules
+ create mode 100644 debian/rules.d/0-common-vars.mk
+ create mode 100644 debian/rules.d/1-maintainer.mk
+ create mode 100644 debian/rules.d/2-binary-arch.mk
+ create mode 100644 debian/rules.d/3-binary-indep.mk
+ create mode 100644 debian/rules.d/4-checks.mk
+ create mode 100644 debian/rules.d/5-udebs.mk
+ create mode 100755 debian/scripts/abi-check
+ create mode 100755 debian/scripts/config-check
+ create mode 100755 debian/scripts/control-create
+ create mode 100755 debian/scripts/link-headers
+ create mode 100755 debian/scripts/misc/find-obsolete-firmware
+ create mode 100755 debian/scripts/misc/fw-to-ihex.sh
+ create mode 100755 debian/scripts/misc/get-firmware
+ create mode 100755 debian/scripts/misc/getabis
+ create mode 100755 debian/scripts/misc/git-ubuntu-log
+ create mode 100755 debian/scripts/misc/insert-changes.pl
+ create mode 100755 debian/scripts/misc/insert-mainline-changes
+ create mode 100755 debian/scripts/misc/insert-ubuntu-changes
+ create mode 100755 debian/scripts/misc/kernelconfig
+ create mode 100755 debian/scripts/misc/retag
+ create mode 100755 debian/scripts/misc/splitconfig.pl
+ create mode 100755 debian/scripts/module-check
+ create mode 100755 debian/scripts/module-inclusion
+ create mode 100644 debian/scripts/sub-flavour
+ create mode 100644 debian/source/format
+ create mode 100644 debian/stamps/keep-dir
+ create mode 100644 debian/tests-build/README
+ create mode 100755 debian/tests-build/check-aliases
+ create mode 100644 debian/tests/control
+ create mode 100755 debian/tests/rebuild
+ create mode 100644 debian/tools/generic
+
+diff --git a/debian.master/NOTES b/debian.master/NOTES
+new file mode 100644
+index 0000000..f65ae4a
+--- /dev/null
++++ b/debian.master/NOTES
+@@ -0,0 +1,4 @@
++eSCO patch removed. Replaced upstream with a disable_esco module parm.
++airprime: Module gone, use option driver instead
++AppArmor: Patch is all there and ported. Ooops when enabled, so default
++	off (still can be enabled apparmor=1)
+diff --git a/debian.master/abi/3.11.0-13.20/abiname b/debian.master/abi/3.11.0-13.20/abiname
+new file mode 100644
+index 0000000..b1bd38b
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/abiname
+@@ -0,0 +1 @@
++13
+diff --git a/debian.master/abi/3.11.0-13.20/amd64/generic b/debian.master/abi/3.11.0-13.20/amd64/generic
+new file mode 100644
+index 0000000..776a6c1
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/amd64/generic
+@@ -0,0 +1,15575 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x38b12930	kvm_read_guest_atomic
++EXPORT_SYMBOL arch/x86/kvm/kvm 0xb94ac8ce	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/acpi/video 0xd5715c8a	acpi_video_get_edid
++EXPORT_SYMBOL drivers/atm/suni 0x859996ba	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0xb5e5f7d1	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xfed5231c	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x0e3237cb	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x0ff8241d	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x14b79455	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x30588523	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x5790e1d2	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x59175075	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x6506d605	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x8a309c11	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0xae94befc	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0xb86d1b10	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xbb300e1c	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xdeb1b2d4	pi_write_block
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x068d6ea7	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x47dadc88	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x60f46747	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa28a2ace	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xed485c7e	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf1f0b11b	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x01a5dc4a	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x1aa8bb08	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x41c85848	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xc1573d60	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xeced6e13	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xf40001c3	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/ioat/ioatdma 0x933c2c3a	ioat_dma_setup_interrupts
++EXPORT_SYMBOL drivers/edac/edac_core 0x864b1908	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04d0f641	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x0f7d6af8	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x19f5c41e	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x1d3aebd5	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x26372b64	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2a18f239	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x394329fc	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x482cfedb	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4e4c4dc0	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x645b715f	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x767003e0	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x80dc633c	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8a1911a9	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x919abdb4	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9963ef7a	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9a1f863f	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9c3e49cc	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9c8eba83	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa079e2fb	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa0ad84ee	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb2ec9a0c	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcc35f1f4	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcec1fbd6	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcfd52595	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdbbd0ca0	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xeca1a166	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xeeb90263	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf65aad43	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf74e206f	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x01fedacc	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x0eae826e	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x40bbab6f	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x4c10795e	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0x4f887010	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x4f8a9a0c	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x7821839c	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x84e06655	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x8c7abebd	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x95c0f910	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xb20ca24b	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x01e27e86	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x025c90f5	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02e6e099	drm_mode_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03da5227	drm_mm_put_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x04465620	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x048b870f	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0584cfa1	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x065e004d	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0719997f	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x09550654	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x09ff251c	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bab51aa	drm_mm_create_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd34471	drm_core_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1029581b	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11065515	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11bdbfaf	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1274217e	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12c6276a	drm_buffer_read_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x142acc6e	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x142b8b35	drm_buffer_copy_from_user
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1549bc82	drm_core_reclaim_buffers
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17a7854e	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17bf7f2d	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x18c80efb	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a47f357	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b584c77	drm_mm_insert_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b5b324f	drm_fill_in_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21dfdea9	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2265c60a	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24059ff7	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26256356	drm_mode_equal_no_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x275a6f69	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x283412a8	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ad07661	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ae171d4	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b535a79	drm_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2bfcece7	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d7dbefe	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e44269e	drm_mm_insert_node_in_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f96e542	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2fe34629	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3074f033	drm_order
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31dd3c68	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x324453c1	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3362feca	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x344df3d0	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34e436ee	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x35261e03	drm_get_last_vbltimestamp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36d6b6a7	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3876f9e3	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x393bd174	drm_core_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3afb1ad3	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c91a8b6	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d1774a9	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e312542	drm_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ed589d7	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x42d6f133	drm_mode_connector_detach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43384bd9	drm_buffer_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43aeeec4	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43ceb90d	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x441bc692	drm_free_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44a0c113	drm_mode_height
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x462700c2	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4707036d	drm_get_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47f3fefc	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x498dcb5e	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49b102b3	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bf5763b	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4fdcad6e	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51042605	drm_platform_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51646289	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x54d9adf0	drm_mm_search_free_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x552ac517	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55a76644	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5665684c	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d47298f	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d7318dc	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eafb8e9	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60361af1	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65af0a47	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6604bf4b	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6704bf8a	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68c3da19	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69fcec9e	drm_global_mutex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a213949	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6a403b5d	drm_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b6d7375	drm_timestamp_precision
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ba1f59e	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6c92e86b	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cee2e42	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d96d7c6	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72420d06	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72e13c50	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x739628ad	drm_mode_group_init_legacy_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74ab80fb	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x759e7020	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76321daa	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76f36578	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78c16c82	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79270146	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a4e7297	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a60eead	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a6e3bd3	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b2e6a1c	drm_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b42b5d4	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c94bd5a	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7df48dcf	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80087991	drm_prime_lookup_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8172ae32	drm_mm_pre_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x866654f8	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87197f7b	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a4b6a35	drm_mm_get_block_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8b1a93a1	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c510862	drm_find_cea_extension
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ce326ae	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d0a4166	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d530396	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8dfb019d	drm_buffer_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e8c530d	drm_mode_validate_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f0af7f9	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f7df3a7	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x90135399	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x919e9dc7	drm_mm_search_free_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91e58a56	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94caee01	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9688efae	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9745d638	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x989a59a4	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98dfc292	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x997b62f7	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99de2d08	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9af9df92	drm_gem_object_handle_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d18ed97	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9e1a3e51	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9fd99d16	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9fff1630	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1eabd87	drm_mode_list_concat
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa26bf0b3	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3544c1b	drm_prime_init_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5fa05ee	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa62cfa97	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa96acfcb	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9aab36d	drm_get_platform_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xabebcc0e	drm_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xac50d585	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xadb5a434	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaeb03219	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaee4afb7	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf0c89af	drm_mm_get_block_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf3fc480	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb00b1ccc	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb0cd9c1f	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb5540008	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb567e6ce	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb6b419df	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb7811fb4	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8dd450e	drm_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb95beb55	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba2d0719	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbaad4d6d	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbaf7f721	drm_core_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbba283ab	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbd2fff25	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbdf33196	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe001c53	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe89e479	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc25a61ec	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3193742	drm_sysfs_connector_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc414c422	drm_vblank_offdelay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc443ff06	drm_unbind_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc544c55c	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6129d14	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc67849ec	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc76c2b4c	drm_put_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc87fe131	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc88e7e3c	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8dac6eb	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc97062f5	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb1beab5	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd547a92	drm_prime_destroy_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcda91c46	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdb2bd21	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce7de061	drm_compat_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf873a8b	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd125790d	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1f36be9	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2510c4d	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3261c9a	drm_mode_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd3f0878e	drm_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda5b0a05	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb86adbf	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc48c8f8	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc6d52e3	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdf746c19	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe319a5e1	drm_prime_remove_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3ed1a35	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe48e0a00	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe49b6f42	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe57e4222	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6ed13ec	drm_get_connector_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6f46e6e	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe731a1b6	drm_fasync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe77924e8	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9f06849	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb01692e	drm_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xecb9918c	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed063b19	drm_get_encoder_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee12c49a	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef31171e	drm_sysfs_connector_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xef885aa0	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xefc6ff5d	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf15dec4b	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf5280bb5	drm_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6f344ea	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf77167e3	drm_gem_object_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7e763e7	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7efe36d	drm_mode_create_dithering_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9705f6c	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9a47863	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa345305	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb482163	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb6de3d1	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd4ce422	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfea0e4c5	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff543a6a	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffe09dce	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0705423a	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e03deb2	drm_fb_helper_restore_fbdev_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x14cd11e7	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x15b4e3c5	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1d23bdf8	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x22b60963	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x259539f0	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2624cd62	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d144c43	i2c_dp_aux_add_bus
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d7a787f	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x313899ca	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x42ea7259	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5bb960df	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5caaec86	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x643bfca4	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x6f29e2f6	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f78523c	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa671adf8	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa67fb916	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa7141a7a	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb37a0603	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xbd570289	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc2f5b518	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc4282a86	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc550372c	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc58f05cc	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7fd39bb	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xce10ca3a	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd02c73c7	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd2fcb0dd	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd33f1b00	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5d8b6b8	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdb40d3ff	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdcd71baf	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe48f45e3	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe683bb74	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf67b0feb	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfee43a69	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x4085633b	drm_usb_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x6685da76	drm_get_usb_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x6b5ff009	drm_usb_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x08488482	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x08a29178	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d1180f3	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0ebbe826	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1286e1f5	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17e48a1d	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x18ebe205	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2010429e	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x22e465f0	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x26fb1361	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x28cdc1c2	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2da5874b	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2dfafdc7	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x327ebb30	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x36315343	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x38edc4a1	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x39c46bd4	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3d1f7444	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x43873df9	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x45bdb939	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x45c07a18	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4a3a21ad	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4a4e4e50	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4a6b21a0	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d1eea63	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4e8dd264	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x54ce3cd8	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x564e1aee	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6052860c	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6244e7de	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x646716ba	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x65a48e93	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6892bcfe	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6953827e	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6bb4a93e	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7319013c	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7370da94	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7503bc93	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x78c61b50	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7d356329	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x81e7545f	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x83518958	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86bdd873	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x889bb3b2	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8ff0028a	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9385b73e	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x97e01801	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9a8bd8ac	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9c66d7ba	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa333e44c	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa995c09c	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xab9685af	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xacc2feab	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xaf9091f8	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb7902d7f	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc37af7a4	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc3c29c04	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc4d4618d	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc69d45f5	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc850d617	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xca60ba80	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd169a11e	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd36436c4	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdd0edf51	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe593e0ce	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xeaa61c46	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xeeccf872	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf0f18a71	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf15f554a	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf4fa36e0	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfb675366	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x2a7ec300	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x7cbc9505	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x9a24f02d	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x53440545	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x8b645a31	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xf27c24bc	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x12d751c8	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x4016bfac	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x9a28f93d	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x3f8c9b5f	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x45337a54	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x34ceb51c	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x973289bd	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xa89d51e1	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xb9ca6f71	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xd7c2fe4c	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x0ac0d05b	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xa5d106d5	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1191b4a0	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x39264384	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4c1d1cde	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4ede5b08	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4efbfc40	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5528b00a	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5d9f87f6	st_sensors_sysfs_get_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xbe8ff15e	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xc5a8d42d	st_sensors_sysfs_set_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcdbfa400	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xcdc29753	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd6fade4a	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdc9fc610	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdd7af6c4	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe0e746b2	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x19e7036b	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xbbd747a2	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x147472dc	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x890adf77	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x2a38054e	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x3c123213	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/industrialio 0x12cade9d	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x1bcfd3a8	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x1e1c5786	iio_buffer_read_length
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x5761c00a	iio_buffer_show_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0x6a240c7b	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x7a6faa70	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x8bf91dff	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x93d850c0	iio_buffer_write_length
++EXPORT_SYMBOL drivers/iio/industrialio 0xa247eec4	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xaaeeadcc	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xb1838856	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xb3fac415	iio_sw_buffer_preenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xb6fed52f	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xb951d40a	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xbb94a604	iio_buffer_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xc95a6be1	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xd041589d	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xd497f28c	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0xd89cfec3	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xde9a696a	iio_buffer_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe691fa85	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xe6bc3cc0	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xedbeff0b	iio_buffer_store_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0xf799023e	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0x0a59fc2b	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xfd0d0fb7	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0x1c2e1c59	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0x9030ff5d	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x2d6c4db6	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xf8b3e668	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x390a6a98	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xad222cd4	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x2107de5f	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x37838b44	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x6f6ee97c	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8ef35bcc	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d1f522d	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xbe928d7e	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x11a2d3e8	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x14c041a8	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x3d362cd5	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4045342e	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4080a193	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x495da16a	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x523d12b3	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x57ddf966	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5f197fdb	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x65dc15d3	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8a5e7c19	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9419853c	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa88cb88b	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd263bd9a	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe9aa1d46	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf342e598	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xf575ab05	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00d457ee	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x018ff1d8	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x03b1aa4c	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x05131cdc	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06c82fcf	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x094ec54c	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a60f64d	ib_alloc_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a88fbb6	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0fbcf308	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x112d3f7b	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x11f0a937	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14f84918	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x171f99f1	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1fe23f81	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22f3cf93	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x268c3ff7	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x299e4fdb	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2f1d8a3d	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x322b84b5	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x357a1c56	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3a0c3224	ib_free_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3bc376b3	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49ea2b2b	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4de836ec	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4fea934d	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x535a2fa6	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5734e280	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x589cbfad	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5fad7f1f	ib_alloc_fast_reg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x60a41d2a	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x654d297d	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x67c32a86	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6adcc18f	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6cc3667c	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6f64cd43	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x751ad730	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d715c50	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d7d926e	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7df079bf	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8023a12b	ib_rereg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x815a1d1c	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x81fbaea3	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8c1d0a3a	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8e7e91fe	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x92b6612a	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9317f7d4	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x948bf406	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x94d28069	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x966fba39	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x96ce6c46	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x99179512	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9bbe5383	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9ddeac69	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa432baf6	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xada33c2c	ib_reg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xadf3acfe	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xafdf2a06	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xba356336	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbc306905	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbdb3acbf	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc1438037	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc1f7a331	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc6193f3e	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc9d38499	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcbc8034a	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcc98dc7e	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcca042b1	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd042497f	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd16e044e	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd7223860	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xde05bb6b	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe53816f6	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe59c4f80	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe7873f0f	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe791d801	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe7ea497d	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe958adc3	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xeb894d3d	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf0aaf7d5	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf9a7e9b9	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x06b6268e	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0ee282f0	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x39d3fefb	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x4cba33b7	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x56609c4a	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x808bb3e1	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x8be7cac3	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x946d5d27	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xaaae88d8	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xb994dee5	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xbde0e1fd	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd9228d87	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xfd07d6cb	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x2fd0e42f	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x30341ab9	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x521e9bfb	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x576fdbac	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x74cce1fa	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xae3e8046	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xb9c9e4f7	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc1955a3f	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xc31508f2	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xd9e0653f	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe9efd86f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf6b6444b	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x02f847bc	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x07cf5a51	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x18382f6a	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x184f3575	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x00aea8da	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x0126e906	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x16f493ba	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x59376810	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x8ef8e0e6	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xade6172c	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xbdd242a1	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xfcae1cc8	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1e27e205	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x207f0ac8	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x386e8b73	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4615a91d	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x544ec536	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x57047d5e	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5d1acaf7	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x6c6f7f55	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x745895ae	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x778cfc9e	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7d3b1207	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8dcb36f4	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x97ef81fd	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9a25d785	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa00cb719	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xabaa99d6	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xdcf1be97	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe383af5d	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xececeb44	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf8551fc3	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xfd1ebda2	rdma_notify
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x21f68fad	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x2af356ad	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x450a97a9	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x67a015dc	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x6aa8680e	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x95e159f0	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xa892375f	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xbedb6e26	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xebd8c4a7	gameport_open
++EXPORT_SYMBOL drivers/input/input-polldev 0x10a30a13	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x17e796cd	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x8458d438	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xd4ffd7af	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x7a1eba21	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x5f7abbbd	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x871ca342	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x91b559fb	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xba42e3b7	ad714x_remove
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xf07dc4b1	cma3000_init
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x0e1e314d	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x975362d1	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x9791145e	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xa220bf29	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xc5bfc72b	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xdff6c9dc	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x8bb8c3af	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x9d70d5ad	ad7879_pm_ops
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x0562fcfb	amd_iommu_set_invalidate_ctx_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x2efa2f4a	amd_iommu_free_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x40106ac0	amd_iommu_set_invalid_ppr_cb
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x5269c9b0	amd_iommu_init_device
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x68759baf	amd_iommu_bind_pasid
++EXPORT_SYMBOL drivers/iommu/amd_iommu_v2 0x6de842a5	amd_iommu_unbind_pasid
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x02777973	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x090e7ebf	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1a39ec07	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x47d3fc51	capi_info2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x526d41cb	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6377d749	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7292ab34	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x72a25a72	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7bf396cb	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x87506c4e	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb4b96cce	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc424e5ba	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe38a3f14	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed061606	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd552f7a	capi_message2str
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x211f23fb	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x308a064a	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x512442e9	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x53939a0d	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x56fae536	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7c355e29	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9841a3da	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9b9b0f7e	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xaa8533e4	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xaaba9acc	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb1e0a541	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xb6e19750	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc9e5dd5d	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xcbf148bf	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd94294e8	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x0ed6f92a	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x51ec56d7	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x6713d1f8	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x75899478	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x95720f63	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x961b9c6d	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xf51e3752	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xf82c91e8	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xfb2b5cd4	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x6dac891f	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x877c98fd	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x8d507478	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x8ec20bd0	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x9686aecb	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xa7c4cf41	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x7f29ce36	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xa1b88cea	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xe227344e	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xff2db2cf	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x5ee2af50	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x70e43b1d	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x84b0a6e1	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xd8cbeeb9	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xee7c5ba5	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x646cbb67	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x6fe11f33	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xb1f38fb3	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x23d4044a	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2af56db8	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x329a1383	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x54451388	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x557bb00c	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5aeda7e3	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x614ede30	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6a55f254	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7d521b10	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x827f4a6c	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8ad54f39	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x96309324	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x97adab00	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9b0f1b1f	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa1972d0d	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xb7a3ba8c	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbbbb3e50	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbc774d90	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbd5cd00d	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbdf72ec5	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbed03978	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc283f0b0	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc587863c	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc85cad45	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe1fa8e1c	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe87943cf	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf3cf9dfb	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/dm-log 0x0de58260	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0x37643efc	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0x805d1e2d	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0x9a427ca6	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x29905cab	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x5bff6234	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xa04c115b	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xb7b05252	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xd19b2b62	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xec9629cb	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/raid456 0x053507a2	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x284be138	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x293e76a1	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x43f2c807	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x47d38045	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x62ec6b1a	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x6c1d9395	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x854a1321	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9c8fa924	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xac6f1915	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xaedcf123	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xce1413de	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xcf52519c	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd3a1716a	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0x47d27029	btcx_riscmem_free
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0x495e4b0c	btcx_calc_skips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xad2fe38b	btcx_sort_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xc368f8e6	btcx_align
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xcda0ded2	btcx_screen_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xdb08efd7	btcx_riscmem_alloc
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5b88faf6	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x82b4c6bb	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x9efa5491	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xe1bb2e2d	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xe810dc1f	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x6af2f5fd	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x815432f9	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xa8b837df	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0c651bb2	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17523ce7	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1c8a819e	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e143732	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x231fcd18	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2dfe05d8	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x398aab01	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x39c774e8	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3b07afe6	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3faf3e6a	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4d091033	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x64d6d7a9	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6a6f70d2	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x75bede0d	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x849bb874	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x887caf4f	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8ad6c1aa	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8d0df2a1	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8f10b698	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9ab5eae0	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9cffe10a	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9d3c1511	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9eae88df	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9fa037ef	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa2a65e70	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa750d6ab	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb4dfea73	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb63310f9	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xca4965f1	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xccec4874	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcdd634b6	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd68a099e	timeval_usec_diff
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdc924427	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe15697bd	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe28c08ca	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe423c8ad	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe8b9f792	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xefcef46b	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf145275b	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/a8293 0x338ab0c0	a8293_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x69c7b18a	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9033 0x0da61f0c	af9033_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xfd019d78	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x128975b7	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x17f241b9	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x3e2ad989	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x57e7cbbc	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7fde0129	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x9b38dc4c	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa8bee5f3	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa978e953	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa9dbbba2	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x15cfd836	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x6dbc1b1b	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x555f490c	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xa07d93ad	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x1127f4e2	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x4dcc3138	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x8a358049	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xb900af70	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x207d5bc1	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x2d6f30dc	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0xe3f1e98c	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x001a35f0	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x8309528d	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf26ef66f	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf6bf01e4	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xfd4aa8dd	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x04380f8a	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0a7c40e5	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2b5be518	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x3649e96b	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x41627559	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x57be6274	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x73548b03	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7c7e5361	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x8934c9c8	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xc385db9e	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd3327ebf	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe8194ba3	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xef4fd29e	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf1caf621	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xff748ca3	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x5bba723e	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x3d6c1f4f	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x47c80d99	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x789c828b	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x960b606f	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xc8ac560b	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xe6d47e5e	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x33389875	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x45ebdea5	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x69f0b87e	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x6f5488f5	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x048b5ffc	dib7000p_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x119b8162	dib7000p_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x1872e2ef	dib7000p_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x1e0f1295	dib7000p_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3725a69d	dib7000p_get_agc_values
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3eaf1ef6	dib7000p_set_agc1_min
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x45f4d044	dib7090_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x597de4a6	dib7090_slave_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x7aa9bc7e	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x84511b75	dib7000p_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xa1cc7e58	dib7000p_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xa7a841fd	dib7090_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xbe257b35	dib7000p_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xe34c070d	dib7090_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xed3f7f53	dib7000pc_detection
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xf53591ee	dib7000p_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x1e78a0a9	dib8096p_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x217016f0	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x23b824bf	dib8000_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x44bd2447	dib8000_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x4eefca38	dib8000_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x50851c2b	dib8000_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x6ba4e89a	dib8000_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x6e69c8f0	dib8000_pwm_agc_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x73843879	dib8000_get_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x7fb703de	dib8000_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x812ccc01	dib8000_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x89fd04aa	dib8090p_get_dc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x97cd69c7	dib8000_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xc3eb8558	dib8000_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd80c0905	dib8096p_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xdb3d5e6e	dib8000_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xf34c88e1	dib8000_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xf70a44b9	dib8000_remove_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xfa7d15f4	dib8000_set_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x165db278	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x770c8a6b	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x8f71db60	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x957c2d07	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xf42112cb	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x1078cbe1	drxd_config_i2c
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x80f72f82	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x17b53ae8	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0x15780b0c	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xd32aa392	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x343b67fd	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0xe19c7072	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0xe91633fa	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0xbe0f885a	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/it913x-fe 0xff435000	it913x_fe_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xbbfef47d	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xe2851154	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0xb786ae9a	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0x118864c2	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xd9b363be	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0xbb9d2128	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xb2f9f21a	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x16eec8c7	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x86dea71b	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x6b8524bf	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0xcd2e1740	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0xebf032c0	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x873a34b0	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xf686170d	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x54e60ed4	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x2d8e0990	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x90cab2c8	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xacf4e577	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x2ae059c5	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0x9c735543	rtl2830_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xf8ad1753	rtl2830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2832 0x09a3ddd6	rtl2832_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x6b5a71fa	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x2785a5a7	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x73c12191	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xbed9395e	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0xf1dacab4	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0xc5170143	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x342ca1f1	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xacb0582a	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xd87d2689	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x265508a4	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x59e8cde1	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xc1c580e8	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x40dc4288	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x9c88b77e	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x7d86d567	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xa545f55a	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xd3c0d6a7	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x7c0586a8	stv090x_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x8e8de0b0	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x7abe468e	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xc60fd09f	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x0c15c872	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x6c313037	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xde6c6284	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x61cb0edb	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xb1a79dcf	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10071 0x39d9ed9b	tda10071_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0xfab48334	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x9767d522	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x54457e31	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0xa8b88266	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xf17740fa	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x78e89c79	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xbc4483e9	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xab4a210d	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0xaddd50f7	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x5b3d59ec	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0xdd2d6422	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x610b2b5e	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x04e0c8a3	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x3ff099ba	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x61f92bed	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x89efe29b	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x9137ec55	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x931da589	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xbb9910f4	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x63bece98	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x905c6136	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xc6cd8afa	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xe3f396d7	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x04ea9540	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xad965bed	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf484d831	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x0e7d2a33	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x2cf3989f	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x42c9d71f	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x45760379	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x527f2274	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x56ece1b4	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xb4f2e4da	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xc6c55c3b	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xdf5405d9	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0x172cd0fa	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x3b9675ae	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x50eca5b6	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x80ebb19e	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xe2a8b7d8	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xfe8409af	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x633263ac	altera_pid_feed_control
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x9247b72f	altera_hw_filt_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x97dd88a7	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xfc3b0f6b	altera_hw_filt_init
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x2fefb377	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x437246a6	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6ea23a85	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x95dec91b	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xdb239e85	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xe84af6f3	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x1e733f20	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xecd01f90	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x3aaa020f	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xa8a6a04e	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xb5ee60d8	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0xb865dd17	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x129c506e	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x1cc47e44	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x29bc7cc2	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x5e1cd025	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x70bcb027	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x8f2ce793	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x08d1ff03	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x12fbaa94	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x1709f700	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3674a99e	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3b317c06	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4c0d80e4	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5f10da60	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x76bc0699	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7750cdb6	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8c03dae1	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8ccef152	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8d67ce06	cx88_free_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9fc5d010	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa149421e	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xac0e844d	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb04f002b	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb20596f2	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xc1592543	cx88_risc_stopper
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcf877beb	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd46d55ab	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe5484f89	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe85f6eba	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0119f1f5	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x01b1996e	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x03fdc3b3	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x19c57aed	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2b86fd27	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2d745898	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x37a5799d	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x3e016132	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x50cca354	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x590d33ad	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5fd60f57	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7949d29e	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7eb1103e	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8413aaa3	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa04a8c3d	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xdf33e903	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xfd0948b0	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x138e60c6	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x28284990	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2ee8ad61	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x2fc2e4e9	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x46f5a33f	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x7120711f	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x73039031	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x8ef75d16	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa0d0f296	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa614acc5	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xae9ac9b4	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd3292d82	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xdea79fea	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x5045e553	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x1b67818d	videocodec_attach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x676bfcfd	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x9358769d	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0xb973e1b5	videocodec_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x246a9232	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x6914dacf	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x72d8ff6f	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x95b12855	soc_camera_lock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xb31f8007	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc14751fa	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xe9d0fa64	soc_camera_unlock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf1ba43f1	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xfd4db461	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x46b1be73	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xd4d5a2f0	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x0a8b2dc5	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x89d30e55	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xae291fa1	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xd5fd94d6	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x183d1a3e	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x1cbd1aef	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x6792094a	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x732c0f8a	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x98c6ff4b	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf21602f8	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf6673e60	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xfc8484b4	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x25d90a5c	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x285939bb	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/e4000 0xe5c1053d	e4000_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x562125de	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xc933b4c3	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x12495386	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x3e7d649a	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xea759e06	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc2580 0xb6de8131	fc2580_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x0d023a54	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x873fcbc8	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x2b4887a5	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x000befe1	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0x2a0463e5	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xd5ecc484	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0xc7eb4073	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18212 0x7a616d5f	tda18212_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0xdca06792	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tua9001 0x84b3722a	tua9001_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x2e14f66b	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner_it913x 0xfc7a0da4	it913x_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xdd82e239	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x452203b6	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x77fa86a6	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xc51e18fa	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0baa644b	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x1d2f7a05	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x31178bc7	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x5e794906	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x607bfb3d	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x81992db2	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x910e7016	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xd80ff7c6	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xfd74b152	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0bc6f716	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x2f6d668c	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x35b8699d	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x4fe84c92	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x965ffa31	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xaa4dcef1	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xfa05b00f	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x1ecbcaaf	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0ad6bded	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x44a61495	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x87318f56	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9495df82	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x9526744b	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa1b6afc9	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xaaa4a2e3	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xba05c0f5	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xd4b4109e	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xea38717e	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf3993a2a	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x6a587868	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x988bc20b	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x13ea373e	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2db76150	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x3181ee11	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x791defc6	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x928e6ab8	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc7bf99e0	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xd3966c33	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xfc250158	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x63b7e9fe	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xa1559bec	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xce7d7ff8	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x1c63d5b0	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x37a4d47a	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x42c8e001	v4l2_ctrl_next
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x4adaf0f3	v4l2_ctrl_query_menu_valid_items
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x53c9394f	v4l2_ctrl_query_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x5f96a661	v4l2_ctrl_check
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x2888adee	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xa0495de6	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xf7a0078b	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x2b06e563	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x61af110f	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x7a0e28d9	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x8972f496	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x8c1ba94d	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x91d8ce12	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xec381f52	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x009a3df1	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x011027dd	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0267040a	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0578780e	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x09a8c50a	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1fef0e68	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x22e60391	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x25e6d1e5	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x27e1070b	v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x29264b13	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2d8043b7	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2ee55f0b	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x30a88bc6	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x30d9ce5a	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x30e6334d	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3619121d	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f31b148	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x40d067b7	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x40e795ab	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4306a8b8	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4f3e3e33	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5f23f2e8	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x61fc81bc	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x688baf6e	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6b0d9456	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6bb9800e	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x74f37449	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7e2c94ce	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8228221a	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8476109d	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x84f0731d	v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8508b056	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8a465fc3	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8a918392	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8abd56c1	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8e1360da	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8e280391	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x917c25e6	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x988a9566	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa2ca9b1e	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa415201d	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa4cdb13a	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa6ff56e2	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xab6a6afb	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaccf296a	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xae02572f	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaf8ca449	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb6c214f7	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbac4a225	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbba1967c	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbfb62f21	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc12cf8f8	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc2af0470	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc5053946	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc52d4ef0	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xccf50493	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd01dcd4c	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd3e6fc3e	v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd7574fd7	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd7f115c0	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd9d12fd2	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe650508f	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe6fce6f2	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe8842ce8	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeaa2e6cd	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf06086bf	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf6cfa558	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x15430f57	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x1833010e	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x3fc16023	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x547a50e8	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x697522cb	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6ac2729e	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x724c68e1	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x98722dd9	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9a79e4ac	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdc07e67e	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe2583b5c	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xeffa42b5	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf044c9ef	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1322db25	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1fa61fd8	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x22dfb540	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2446dcc5	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2f622a1b	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x480f5de0	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4a01c8cd	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x530557cd	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x598a196d	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6b14424f	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6e6a0cc7	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x72e42ad1	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x7b9bb4d2	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x859f765d	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8990d75a	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8d337752	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa0a7b6cf	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb57702bf	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb5b2c8c9	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbc2daf0e	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0d4b468	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd0e1a3b2	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe5340771	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xe8101d5c	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xec85ee03	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xee2810f1	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf23ab623	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf288f7f3	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfa733097	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0bb88e91	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0fd1d3be	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x19451902	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x250f1c87	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x31432a22	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x37722abb	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4a30ed65	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4af4f0f3	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x626885a9	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x724735a4	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7fe23797	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x922755ce	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9538f3fe	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa3582443	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa6726e62	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa6d5a44f	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb17a6df1	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb4aa51a2	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc0257860	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcb61d0fb	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xdd084700	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xde825d69	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe0a3b25c	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xebfa10dd	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xee1f9e23	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xef4d593a	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf338492f	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x075062e7	i2o_status_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x08fb10fa	i2o_driver_notify_device_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x10ff074d	i2o_msg_get_wait
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x1300980f	i2o_parm_field_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x223df0da	i2o_parm_issue
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2a843bef	i2o_dump_message
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2c6e698b	i2o_driver_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2ff71f14	i2o_cntxt_list_get_ptr
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x69be2c61	i2o_driver_notify_device_remove_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x7323ea2f	i2o_find_iop
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x788f3ef6	i2o_parm_table_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x7ac981fb	i2o_msg_post_wait_mem
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x8031b06e	i2o_driver_unregister
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x8712fe8d	i2o_exec_lct_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb4c00dcf	i2o_controllers
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb6063bb8	i2o_cntxt_list_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xc5a119bb	i2o_device_claim_release
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xd0d673ec	i2o_driver_notify_controller_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xdc7374a4	i2o_event_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xde538672	i2o_iop_find_device
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xe45a288c	i2o_cntxt_list_add
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xeb9245a4	i2o_device_claim
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xf579ffb2	i2o_cntxt_list_remove
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xfe4e5d67	i2o_driver_notify_controller_remove_all
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x04f94a01	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x2cf29338	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xbce3dcd2	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xd3137d5d	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xfbf64fdc	cros_ec_prepare_tx
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x81d87820	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x839e1a6b	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x012e6b4d	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1ddb7863	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x3a94978c	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x48a31e8f	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x498a5a0b	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x74878f4b	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xbe1237c4	mc13xxx_irq_request_nounmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc024e1d9	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc0e69cdf	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xd705ccd5	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe00cb2ab	mc13xxx_irq_ack
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe64cc9d3	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf2065b52	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x1e2d9f5a	tps6105x_set
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x64f7dcf4	tps6105x_get
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xaecb73a0	tps6105x_mask_and_set
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xee44f582	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xface152a	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x1746ab2d	altera_init
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x60b58e84	ssc_free
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0xfec5ed4e	ssc_request
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x0e9755b9	pwm_channel_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5a8b82f9	pwm_channel_handler
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5d5c2951	pwm_clk_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x6a5e1f70	pwm_channel_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x73330c97	pwm_clk_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0xeb7f2c6f	__pwm_channel_onoff
++EXPORT_SYMBOL drivers/misc/c2port/core 0x9ed1420e	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xb665f5c9	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xf5884509	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xfacd3c91	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x1fff8c96	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x28028f52	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x2a440077	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x31250c44	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x4a8ae0d6	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x67386b1b	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x7a49ed70	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8b062092	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x8d8cb683	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x940a8152	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa2ac0759	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xa8c2ec46	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcc6c3a2b	tifm_eject
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x984485ab	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x3a9dc1fa	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x6e25adc1	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x93e24505	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x2a894de3	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x5a162e69	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x8b45dbf4	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xa909f19e	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xef8bb1ee	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x5cafbea5	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xd7068f12	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x08109151	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/mtd 0xfea3f953	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x2efe42cf	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x9c1844d7	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x303acd76	nand_default_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x38b0687e	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x6edfe520	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x85cf3c9e	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xd0b51211	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xeeea0c50	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xfe1569b4	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x4e0dfbf5	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x93e0e55c	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0xfdbb9240	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x4cd42977	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x612885cf	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x224c011d	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x42a975e1	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x6e669bf5	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x9ca34d32	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xdcc95acc	flexonenand_region
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x632699b8	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x64507290	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x69e69f52	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x860c8025	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x979dbb17	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa475578e	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xadf97cfc	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xd0ad36da	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xda408b97	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xee89d1b9	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x28c2afdc	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xb1a8cca5	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xb33bb29f	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x04cecf47	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x50663675	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x5d0b03d1	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x665b21ef	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8e797193	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x97b63f3c	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9d2d6681	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xcceefd02	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd02ef59a	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe71372c2	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x17496c2b	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x06beb943	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x211ee46c	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2dd60257	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3579cf87	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x3e8fa80f	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x4884390b	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x55e6245a	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x64d3d7fa	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x68f868c3	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x6d631d2a	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x76252288	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7a7e666e	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x7dcacf0e	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xbf0498a4	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xcc32fb65	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xeff53001	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0f672db2	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1005e960	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1eb9159d	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x2cdb28e0	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3099d3e5	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4d5f7673	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x58bf015a	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x655a3d23	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x67408ceb	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x68d4146b	cxgb4_enable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6d0596dd	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6dc816a7	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6e33d1d8	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x71eb2fbd	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x85162213	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x86e4c6ac	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8bd4c2db	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa4c6aa66	cxgb4_disable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xaaf789da	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb7d80a1e	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc546e94e	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xc9e8e83c	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xdf5bcc1c	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe1577c05	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xe2d5e202	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x7a457890	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xc42a5c50	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0a8d8a07	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0aa2a69f	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1e200ca9	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x213370b2	mlx4_set_stats_bitmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23817587	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48d42934	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48fdd65d	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x580d938b	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5bdb074d	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5eecb743	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x767a3b7f	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78d0d6a3	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a9faa0b	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8c0671df	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2b71ad4	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac3f13b8	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb6dfaec6	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb734dcf3	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8d1055e	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe4a61e09	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe63ee49c	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x01bd76e8	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x03444548	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x05ac3a5a	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x19cf3b33	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x219e07dc	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x21ef0f8a	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x34a98f09	mlx5_dev_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3fc90898	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x78b62cd3	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7b991ced	mlx5_dev_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7e0394cd	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x8272392c	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x87b8fad5	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x9696109d	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa1137f00	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xaf8431ed	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc267d1e6	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc4d31110	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd5b4408d	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xdd479d28	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe192fd5f	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe6bb3601	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe7e6c679	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe8f3a3fe	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xfd6ca30d	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x2f51f41f	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x38e3a535	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x45773be3	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xbad28e26	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xe45ba0c1	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1ad70e87	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2200f93b	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x6052db98	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x648f646e	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xa2773f9b	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xaaa6388f	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xb5346f2b	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xe57ab6d4	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xec6dd31c	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xff29ac72	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xb34a7575	mdio45_ethtool_spauseparam_an
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x1cbef820	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x4ccf3117	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0x8208bbbb	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x8ea986aa	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xaec8a174	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xb346ada9	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xc194e357	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xcecfc36e	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x3ec5a418	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x4459b035	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xf5743a29	pppox_ioctl
++EXPORT_SYMBOL drivers/net/sungem_phy 0xcfe07669	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x3bf300c3	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x47be9490	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x5049c6ec	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x0a10722b	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x1d635e22	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x384c83f8	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3e1f579c	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x50eb9304	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x6a8a7a0c	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xa0583b1c	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb2d86fed	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xdc3a1a0e	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe4cbfe0c	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf0a507ab	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x6055c2cf	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x271807f6	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x34e4b9ac	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xde4a1d83	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0e90a2f4	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x1e1656c8	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2803fbcc	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2c6778d3	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3316b1e1	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3e57d167	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x3f12f562	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e2481d5	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x53358ce3	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x729a0c86	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb6d0f5f5	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xf1c975e5	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0043645d	ath10k_core_target_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x1cec614f	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x505dbc70	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8246be6c	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x895f9dc2	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x998949b7	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaf096710	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xb28962bc	ath10k_core_target_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf0cb7d23	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0199ec46	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x259a333c	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x27cf1694	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2ccf5b25	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x36d010c1	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x3d87763f	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4c6ddcb4	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4e1380ee	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x6fc288a5	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7631375a	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7eb122fc	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb457dfd1	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc107b918	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xeef3e2e9	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x0d7e5763	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x0f6ff60f	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x42e1a44d	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x91fc76f5	ath9k_hw_wow_event_to_string
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1d896766	ath9k_cmn_update_ichannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x37d63e8a	ath9k_cmn_get_curchannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7069795f	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xa1d40ce4	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xcc0da16c	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x055f5b60	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07840495	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x08142591	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d978924	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x158e463b	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x177c1283	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1bb5adae	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x212cad52	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x24034653	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x324b9f6f	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3471b3b2	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37f5c1b1	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x38a90afe	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3a3178dd	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3a32157e	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3d560c85	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3d747460	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x405502c4	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x419d6071	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x46e689e2	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4d3fb7c7	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x500ddbe8	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x531005f5	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x549c2f48	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x55222f98	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5a9a3399	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x61396f58	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x63473e68	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x63937193	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x64301aa5	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x66057284	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x66835220	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x68a7acf2	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6b5324dc	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6b53c016	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6bcc6a9b	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e528c5e	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f4e87c5	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x70ec5d8e	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x713d829e	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x715cf911	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x74b2a915	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x756afc57	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7cfef3ff	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81ccae8d	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x81f90c7d	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8393e32e	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x84b1c5d5	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x859451de	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8698d327	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8acb72f4	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8f75bc2d	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x922616cd	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x92f3b231	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x955457e5	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a2f9e14	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9d490e66	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa15fc462	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5e2edf2	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa5f9b59d	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa73470f2	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa886a041	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac4219e2	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf59dce3	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb0c96227	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb1673474	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb4432f94	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb95d891a	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba19cd22	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbab9e8be	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbc36b5a9	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbe8bd99c	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbedd547e	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbfd0c72b	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1674f66	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1bc4303	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3ee0d66	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc41c35bd	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb4741c3	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcbf926f0	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd25b088a	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd75c3696	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd9a861f2	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xda5b702c	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdefd7c38	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe20ed125	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe42d22ab	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe6d27a53	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe800e80e	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe808d783	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xea678c42	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xecb7a618	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee21c587	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf0c575dd	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf428a4b3	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfb395743	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfed51162	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x10415e3b	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x1948fce7	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x5297e5ed	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0x4b8fa205	brcmf_sdio_probe
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0x8fb76ffd	brcmf_sdio_remove
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0528bd0c	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x059dd60a	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0604e42a	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0b81fb30	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2dc227f8	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2fcf966e	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x3eb00a7e	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x51fb56e5	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x5cfd39a2	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7a57a63f	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7b211e16	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbcd3c2b1	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xcbd337c4	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xde8adb13	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x11a9e2cc	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1723ac32	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1c53bb12	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x31cb3823	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x35b40a78	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x374e1b0d	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x37eacf3d	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x39db3023	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3af2d36b	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x42d3c917	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4a126a49	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6124430c	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x630f2be0	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7fae18c6	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x83d913a2	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8b6208d6	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8f5c8aeb	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9b9fa292	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9e29d83e	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc10f7041	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcbf5e80f	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcd55968b	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd47740ae	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd6464aa7	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf295b0c6	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf8d75622	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x03c0c3b0	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x14557b56	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1f4b4a41	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x33c8396e	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x3b2bceb6	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4654d1c6	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x4f9ced39	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x54225146	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x64f810ea	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x72f7c00e	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7cc1f089	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7e15d507	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x82e4166d	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x85c5050b	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x98d5418f	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa274318f	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa4651b2b	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xc0bc7e1c	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdaf7b727	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xde3bead1	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xeea04199	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x019de17f	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x04787f04	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0537f0b1	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0572a11d	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x096a51c3	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0bf57769	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x11fb607e	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x19dbbf2f	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1cd70da2	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1eeb433a	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1f5d3464	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1fe0446b	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x20513d12	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x20d12ae4	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21736086	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x21ea7ddf	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x236a0f40	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x25220508	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x272e8456	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x32dd30c2	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x32e4a5d9	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3333cbc3	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3915ce62	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3b6928b8	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x40bd3142	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4103e3b4	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x46ef50ca	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4762dc86	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4abb5448	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e82e751	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50c3fa6e	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x543074bc	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5707bb60	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x577ce110	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x58bbe662	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5a18d7e4	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5c16035b	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5cedb588	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5dd83a16	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5fb244e8	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x60291052	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x61b0a8ce	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x66bc6284	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6761abc0	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x68d25357	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6c2e5807	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6c5860ea	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6d656253	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6dd873a1	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7044f47f	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7177a43f	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7252683b	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74802201	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74b12801	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x776d2e9a	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ab16a17	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7c0fb6eb	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7cf762f7	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7eaf2359	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7fd89bd6	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x80c59306	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8438722a	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x86ecf0b2	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x88187b58	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8c8244aa	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8cd26dd1	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8f528a5c	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x90ea1309	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x966022b7	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9d81b4bd	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9def085d	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa57791ad	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa62beff7	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa7a45f7b	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa99199eb	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xab23730b	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xab2c5b16	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb07c232a	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb2c68212	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xba7960ce	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbbdf9c6d	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbf81716d	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfb8d425	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc4fedf41	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc7c40837	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcad747be	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd2a862b5	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd3efbf30	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6698179	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbdc253a	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdf6210d6	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe384246f	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe4aa398c	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xec092408	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xefb39fc8	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf3f68083	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf6bab85a	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfeb6439d	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08dd8699	__tracepoint_iwlwifi_dev_rx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x0c50fa2b	__tracepoint_iwlwifi_dev_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x1ecc5465	__tracepoint_iwlwifi_err
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x2f7b7e55	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x3b9d00d6	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x675bcb86	__tracepoint_iwlwifi_info
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x779dd6f5	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x85c1bb84	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8de37664	__tracepoint_iwlwifi_dbg
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x954eb7a7	__tracepoint_iwlwifi_crit
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x963a6f8a	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xb8f7026f	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xe2dcc8de	__tracepoint_iwlwifi_warn
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xf9ec6bdd	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x0f56eba1	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x3ddca9ee	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x64c07163	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6aaca653	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6b2cea1d	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x80365388	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x89303ce9	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x99b5a04a	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa8fd35cf	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xafa6b817	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb6edb693	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xc71ede2a	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xcfe813e5	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd28fe38d	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xda0a3432	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xdb0cbd65	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xe8ad5d1b	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x027e9c7d	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x0befd62c	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x0c440a5b	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x15de638e	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x1f12b59d	_rtl92c_phy_dbm_to_txpwr_Idx
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x243aef53	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2471cca6	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x273f8d87	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2775762e	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2983ca1d	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2d68d374	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x389b346a	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x3d81a683	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4a22aef5	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4a653e58	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4dfde4ef	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5922c2b8	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x610d690e	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x68e12217	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x690d8643	rtl92c_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6bc6865d	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6efa9dc2	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x70746b21	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x766fb040	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x892a9aa4	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x8fec6e88	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x90d8cd3d	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x96f6dcc1	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x99fa4d7c	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x9a2721fa	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x9d38ce24	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa1352f71	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa505a872	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa9252e83	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xaa28301a	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb166d97d	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xcbbfd26a	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xce02d89e	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xd69194f2	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xda4477ce	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xddf1cca4	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe26d8d5c	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x96db7dd3	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0xacd20baf	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0xc681181e	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0xf07d8a9c	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x48ee9f3f	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x86e4073b	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x98005a99	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0xc1cb45cd	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x27bc8c96	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x28b3fef5	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x37e187c1	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x39734210	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7843cdbb	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x785f50d0	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x86d0aa87	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x888d63aa	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x8c456be1	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x93d0f5d9	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xa59f7497	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xa99dc229	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xaf45b34e	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xb1440c2b	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xc38b7140	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xd43ea996	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xd6b5cc4d	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xed340734	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xf0daad62	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x17dc7214	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x3f5c4360	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x98ef917f	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xc91f4c12	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xbd5c183f	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0xc7d692cb	microread_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x36427853	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x5d9d1619	pn544_hci_probe
++EXPORT_SYMBOL drivers/parport/parport 0x030c4196	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x17b95438	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x1c7013d6	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x250c434f	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x3390a9f9	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x33b064c6	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x3b8bf4bf	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x3f14ddc6	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x408a2caf	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x47222749	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x4d064707	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x4ff0d652	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x677367ed	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x6a42c180	parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x6b4f1041	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x744e98db	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x77c593dc	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x8663d117	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x9e87b420	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xa1c0f955	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xbb809297	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xc11872e6	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xc3d55e9d	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0xdcd19dc0	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0xe59755d2	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0xe718703f	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xee2db471	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0xf6332025	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xf65609c7	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0xfc065ca3	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x593b3fca	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x9579167d	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x3bae98a4	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x4d6d8efe	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x606d324e	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x636824f3	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x64ee5b2e	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x7d6254dd	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x881926e9	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x92c66056	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x93559edb	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x94c5eed1	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x972f5bee	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x99bbb5b8	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x9c888574	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa3cb292a	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa8548372	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xb3e774c3	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xc87057c1	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf9eb477b	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xffba131d	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x080c9134	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x19c1c5bc	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x2e2adc91	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x53d024c8	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x80a0dc9a	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x8afd2b18	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb4f64e3a	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xc4a9be4c	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf4bb8d0e	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf5b3745e	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf73fe42f	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x137eb4e5	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xec13599c	pccard_static_ops
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x2b66a876	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x7cc6c5fa	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x8ccfc1d0	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0x99729ab5	pps_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x4513c740	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x7a846f0d	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x7daca8a7	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x9f72ff36	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x126e2890	pch_ch_control_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x1f456487	pch_set_station_address
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x70ab4eb7	pch_tx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x961479d6	pch_ch_event_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xb04447a1	pch_rx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xbab31a63	pch_src_uuid_lo_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xddbb80e5	pch_src_uuid_hi_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xdde286d7	pch_ch_control_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xe1068187	pch_ch_event_read
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x2eff5aae	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3e54a069	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4a07f5a4	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x9018af95	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xaf6e1c84	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb692ec29	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xb85cb2d9	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd3166b15	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xff29e4a5	rproc_boot
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0087d09f	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2b926111	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x381585c0	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x48bb3731	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4a54e168	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x66b48b71	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x70295648	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x75401e2d	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa62eac86	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xac1ec13e	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb3f324ec	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb9628da5	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x095e158e	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0c6f1ea9	fc_change_queue_depth
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0ebb1ad4	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x198ef442	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x19a71d2c	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1b737fd9	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22c5c113	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x28c89281	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2ab143e1	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2c846b16	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x31065c11	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3453163e	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3636015e	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3fdf94be	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4350c813	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4a9a29a8	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4ba77645	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4bd2b911	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4c98ec81	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4ee01db4	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x524712bf	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x551f70fa	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x561318d2	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5d510e4f	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5e7623a2	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64976847	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6514bd32	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7f6ba74c	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x803c2964	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x85df63ee	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8dfd995c	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8ea5d74f	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9a801b18	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9f27bb02	fc_change_queue_type
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa5ca8f05	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbad08534	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbb3d9ae6	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc467ea35	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc592f6bc	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd2ee5605	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd32f4801	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd3c15fcd	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdadf4bc9	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdc90b4fc	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdcbdb756	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe8882aac	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xea123fb1	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf37805a7	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf3d20f7f	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf530f0c3	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfae89b0d	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xfd7c37db	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x0fe46971	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x249a8d05	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x714e452b	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xc371b763	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2ef7eed4	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0219c94a	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x02bba40b	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0fd5c60c	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x13a285b1	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x196bb4a3	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x19eca159	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x274aef57	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x323b0443	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3594dcb8	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3f22dfb3	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4b772c02	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4fd70065	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x511db0f3	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5e89cb00	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x618d20f8	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6a063d1e	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6a899d47	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7346fb51	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x77d3df7d	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xad5d6d7b	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xae7579ec	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbcef1f0c	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc0c9d777	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc6bc92d3	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xccefe929	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcf3ffe90	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd089d6cf	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd9efb391	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdc51edb3	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe5b97328	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe7f99e93	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf01205b9	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf143dea0	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf312467e	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf5048210	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf90ae612	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1e2f4280	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x672cff82	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x975712ac	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbf2f074b	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xda9d802a	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf8596dce	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x44440651	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x47707202	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x55f14d1b	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x560b8660	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x74c25979	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x94ba1c0b	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xacaf80ea	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xb4aa8f09	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xc0ae091f	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xdb8d02bf	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xdbf147ff	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x0b3b6a4c	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1bdf2dfb	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x30144f32	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x99a3481c	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xc632bef0	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xfcdd06b3	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/raid_class 0x15f5af7c	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0x48e812f5	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0xe3787c65	raid_class_release
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2682e2d4	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2b94760e	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x35197df9	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x3a53b5ae	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x54b84f73	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x54edd7e9	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x98dd6b38	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xacd47b68	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb2e8223e	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd6c791c1	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xde8c6166	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe7a40002	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf5e070c3	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x076208c1	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x12d0b8d7	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1707ec31	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1a11a30b	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x24bb63d5	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2c581c5b	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x3e595d86	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5033dfa2	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x564d9bd1	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6c8fdd9a	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6dfdfcba	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x82427c98	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x84a0c5d3	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8aaab49c	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9e70199b	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb1375b42	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb20ac900	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc603193a	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc8a3cce6	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xcb37db3e	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd0b03a60	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd0e4e2aa	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd5390cfe	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd62a1332	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xde702552	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf0fa0539	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfbb784b0	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfcd0338a	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/ssb/ssb 0x0283d30c	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x02e91331	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x04f47343	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x07af2fc8	ssb_bus_pcibus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x07d71c12	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x07d9b849	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x1df87272	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x200c0718	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x42b56f03	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x53757a98	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x57b10734	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x58bab687	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x690b12bd	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x6a4608f0	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x78886598	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x87852a27	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x9091a7d9	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0x9229d64f	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xaf53c034	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd0f2373d	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd9046f77	ssb_device_enable
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x8ecb0704	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xfc3b2792	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x0150c76f	adt7316_remove
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x2de4fa56	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x92398813	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x94ca8a06	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x939a9569	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x4064f986	go7007_update_board
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x456b4505	go7007_snd_init
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x54c30885	go7007_read_addr
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x55aa9282	go7007_alloc
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x75f01c64	go7007_snd_remove
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x85c8359c	go7007_register_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xac7db035	go7007_read_interrupt
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xb855905b	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xcfbcfc7c	go7007_boot_encoder
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x005e9952	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x009f8039	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x03f65a96	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0519743a	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x07b4be06	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x120bf6d6	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x12de0a2d	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x20de1297	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x22f4ed83	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x265842ec	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2b89926b	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2bbeb2a3	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x312f4590	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x33f78975	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x38e5f28a	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x424a29b4	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x43158fcf	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x45c91077	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4aeea515	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4c1bcd8c	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x51cbc87a	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5245ef51	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x563aa3fa	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x66d22765	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8c3bc456	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x923225d0	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x96cb75dc	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa4034673	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xaa52d0eb	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xac230dd4	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb096940f	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb1c6e3ef	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb2d55f8f	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb4ece66e	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xba0c24fe	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbceaf661	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc1484b3f	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc5ae0e3f	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc9a26ce0	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe084ab7e	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe7bebcc0	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe8261cdf	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe8e965f8	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xeb0639a2	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf30b9d24	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf6497020	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf6aafa10	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfc8ac684	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfec73496	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xff04e1af	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x003c0679	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x013239b6	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0bd192b5	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0ecfa5ff	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0f2215e7	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1c1d890e	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1e1590c2	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2707c7db	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x274fbdcd	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x286f04bf	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2982bb43	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2cd73c97	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2d365fca	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x36804efd	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x36dec3a8	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3a1f5757	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3a482860	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x43afac6c	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x45f7df3e	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4a36714d	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x537d909f	ieee80211_send_probe_requests_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5649329b	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x580c6288	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5d11bddf	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x63230f1c	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6374702b	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6a4bf250	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6baae012	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6c13db6e	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7907276e	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8446b786	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8800caac	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8aa4c183	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8bb535b7	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8fe38e98	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x911d0d5c	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x948683fc	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9e5ecb51	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa4a2102d	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xab386404	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaec89144	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb05c785d	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb225317a	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb3b08b6e	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbe803e7e	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc1f7bae7	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc4ab833a	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd1c0fd5b	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd34e97b3	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xdcdd2429	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe218a8f2	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe22b59c0	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xea5818b2	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf2534378	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf52c34b6	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf831aa38	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0017f35f	set_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x00ea0cde	set_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x06d6f244	get_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x09df8f3e	set_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0a8d32c3	get_bypass_slave_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1936264c	set_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1d2eb8ca	get_tap_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x203af1f7	reset_bypass_wd_timer_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2070f14a	set_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x27b990ef	get_bypass_info_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2ba7cd35	get_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2c3f1c17	get_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2f59e636	get_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2fdb893a	get_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x361cf40a	get_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x45ca99c3	set_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x550a188c	set_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x5cb59e92	get_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x66b60122	set_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x675208c0	set_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x692623f2	get_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x75131ec6	set_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x76c0b7d0	set_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e872825	get_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e8d701e	get_wd_expire_time_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x86388b07	get_bp_disc_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x93ae4648	get_wd_set_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x95e42b0d	is_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9df5f807	set_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9e21f42e	set_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xa689a214	get_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xae117788	get_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xc368d30d	get_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xccab5de0	get_bypass_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd3e034b3	get_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9c1ccfc	get_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9d38d97	set_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xe640f06e	set_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xecdaa456	set_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xedcd3c1b	get_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf06d67bf	set_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf57c1671	get_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf693c3a1	bp_if_scan_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf8237882	get_bypass_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xfa59240d	get_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05af3c4c	set_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05b08a42	set_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0b0d5ce0	get_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0fc2e83c	reset_bypass_wd_timer
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x123a8133	get_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x157ec89c	get_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2440f05a	get_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2b01d1d4	set_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2c27a2f0	set_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2da97f4b	is_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2e86c67b	get_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37416370	get_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37bdab27	get_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x3da96a18	get_bypass_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4025805e	get_bypass_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4940a0cc	get_bypass_info
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4d21ff51	get_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5147360c	get_bp_disc_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x515d4df1	get_bypass_slave
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5560267e	set_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5be44d44	set_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6653590c	get_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6bda14ec	get_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x72c618ae	set_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x76d47e6f	set_bp_disc_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x794e3815	set_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x7c6cbc16	get_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x84a263dc	set_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x8a16f22c	set_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x946ff795	get_wd_set_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x94f6aff2	get_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x9d1ecf73	set_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xb1385629	set_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xbff68c45	set_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xc871c561	get_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xcee528df	set_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd202dd85	get_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd787f151	get_wd_expire_time
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xdb6a39d2	get_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xebd25ae5	get_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf1e9f8c1	set_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf224abd9	get_tap_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf5a591b2	set_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf643fd4c	get_bp_disc_pwup
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x06465d3f	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x07d0c30c	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x082166c8	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x094ab2da	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0b4619d9	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0e827499	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x133d8298	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x226d369a	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x243f5946	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x290844c4	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5df4e1e8	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7921d1fa	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8491c4bc	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8ce77fb0	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x94d298ea	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x989161f3	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x98c4c14f	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x9ab6b572	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa72726d9	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa9c5bcfe	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb79d5b47	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc285d3ec	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc86e57f7	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc89cab9a	iscsit_handle_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe31e85f0	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe36297e9	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe9cbca45	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/target_core_mod 0x009b67d9	target_fabric_configfs_free
++EXPORT_SYMBOL drivers/target/target_core_mod 0x00bbdade	transport_subsystem_release
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x07ae1c2a	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0d4c1251	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0fa39fe6	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1141f636	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12b5cbe7	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x13a5bc87	fc_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1426e552	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1a9ee283	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1b6610b0	iscsi_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x20358a39	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x25f6916c	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2c56eff0	iscsi_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x329aa03a	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3fcd2532	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x41e59c29	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0x42d60b12	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x44b588dd	sas_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x469e8bb5	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4c0eaec8	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5bfbc077	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65574d8b	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65e1556b	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x694c63ed	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6a43e030	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6d920464	sas_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7232d170	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x749b7406	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7a4ec15d	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8175144e	transport_subsystem_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x831e9811	sas_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x887e4274	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8a6175e2	target_fabric_configfs_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8dfe790d	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x94ea60f7	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97e1d56d	target_fabric_configfs_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9a581fb2	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa318bc31	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa4bc907b	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xac00515f	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb6371adc	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbbbb06f6	core_tpg_del_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbc338ad9	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbc853e7d	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc3c676e5	sbc_execute_unmap
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc43783f5	core_tpg_clear_object_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcbd2660f	fc_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd2a6a5f8	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd3c03c44	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd74e7efc	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd79e1de7	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd96945e7	fc_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdb2cd813	core_tpg_add_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xddb8c120	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xde8a60f2	iscsi_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdf9c85b6	target_fabric_configfs_init
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe77f863e	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe8c89fc4	fc_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0xea4e08c1	iscsi_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0xea754cc6	sas_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0xecf72a1b	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf378c2ef	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf411394a	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf574c681	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf94624d5	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfaaca6e1	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xfa90aee1	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x0ccb1ca7	gether_get_host_addr_u8
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x145ad95c	gether_register_netdev
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x2e2c9914	gether_get_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x4229d159	gether_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x46dc0b69	gether_set_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x4894dc28	gether_set_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x6b818660	gether_get_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x72d676ce	gether_get_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x7d124811	gether_setup_name
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x91cb5b30	gether_set_gadget
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x9d22f32d	gether_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xb78e5cfe	gether_set_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xbf43b58d	gether_get_host_addr_cdc
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xce0f4f20	gether_setup_name_default
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xf4286d80	gether_get_ifname
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x35629111	rndis_add_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3a6d4f22	rndis_free_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3ca38e3a	rndis_signal_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x4ca90996	rndis_signal_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x5d22b406	rndis_register
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x6f92e0ca	rndis_rm_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x785d494b	rndis_msg_parser
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x840dd143	rndis_deregister
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x988ad2a2	rndis_set_param_vendor
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x9acf72e4	rndis_set_param_medium
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xa90054ee	rndis_uninit
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xb971ebca	rndis_get_next_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xd2fe47b1	rndis_set_host_mac
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xe085fe98	rndis_set_param_dev
++EXPORT_SYMBOL drivers/usb/gadget/usb_f_rndis 0xe5457417	rndis_borrow_net
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x11d8a626	sl811h_driver
++EXPORT_SYMBOL drivers/usb/phy/phy-nop 0xa64a4cea	usb_nop_xceiv_unregister
++EXPORT_SYMBOL drivers/usb/phy/phy-nop 0xd0e43207	usb_nop_xceiv_register
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x150cd41a	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x24679599	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x27d53b31	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x385f33de	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6f9e4eea	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x71451a60	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb06808b8	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xbc55aa36	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xc876886d	usb_wwan_set_termios
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xcfc61a72	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xe05ef6e1	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xec676ae1	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf9ad9dcc	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x54c5a094	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xe027bf93	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0dda8c5a	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x1f063017	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x2eae4a2a	vringh_getdesc_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x36dfce73	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3b304ebb	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3eaf442a	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x3fa42e4f	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x4311cd91	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5dafbd4e	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x66af098b	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x6d0e7948	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x76bd9a5d	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x97fa07e9	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xaf8e4a0e	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xafb47dae	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc884d704	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc8bee0a4	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xda4ea4cc	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xde804bb9	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/video/backlight/generic_bl 0x366d19ef	genericbl_limit_intensity
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x0bfe2aab	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x3877d8de	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x48d9d2f6	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xef162f57	lcd_device_register
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/cyber2000fb 0xb0f9c175	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/macmodes 0x6bee0059	mac_find_mode
++EXPORT_SYMBOL drivers/video/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0x6f247984	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0xc8769445	g450_mnp2f
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0xdd1d0d12	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0x3128c0d9	matrox_mystique
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0x4df24e47	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0x8268e52c	matrox_G100
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xebb28837	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_Ti3026 0x9842a38f	matrox_millennium
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_accel 0xb0595877	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x6903d036	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0xa8895fdf	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0xb352cfbf	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0xfd9029b6	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0x07b77d0e	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0x6726914e	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x5d554a95	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x631ea008	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x68480e2e	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x71cc1ca9	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xb9848089	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/mb862xx/mb862xxfb 0xeea63f9e	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/output 0x6fe90c45	video_output_unregister
++EXPORT_SYMBOL drivers/video/output 0x8857adc9	video_output_register
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x238d3046	svga_tilecursor
++EXPORT_SYMBOL drivers/video/svgalib 0x38532373	svga_tilecopy
++EXPORT_SYMBOL drivers/video/svgalib 0x46f2a8d2	svga_tileblit
++EXPORT_SYMBOL drivers/video/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x54faf6fa	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/svgalib 0x577b32b0	svga_settile
++EXPORT_SYMBOL drivers/video/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/svgalib 0x7108a430	svga_get_caps
++EXPORT_SYMBOL drivers/video/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/svgalib 0x9d0f85fb	svga_tilefill
++EXPORT_SYMBOL drivers/video/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/syscopyarea 0x0a934253	sys_copyarea
++EXPORT_SYMBOL drivers/video/sysfillrect 0x6fb47339	sys_fillrect
++EXPORT_SYMBOL drivers/video/sysimgblt 0xad3429ed	sys_imageblit
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/vme/vme 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL drivers/vme/vme 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL drivers/vme/vme 0x0c6bdc3f	vme_master_read
++EXPORT_SYMBOL drivers/vme/vme 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL drivers/vme/vme 0x0f977f92	vme_unregister_bridge
++EXPORT_SYMBOL drivers/vme/vme 0x14acc632	vme_master_request
++EXPORT_SYMBOL drivers/vme/vme 0x156cfa9c	vme_bus_type
++EXPORT_SYMBOL drivers/vme/vme 0x189e5f0d	vme_unregister_driver
++EXPORT_SYMBOL drivers/vme/vme 0x1ab1bdf4	vme_dma_request
++EXPORT_SYMBOL drivers/vme/vme 0x1e608e6e	vme_register_bridge
++EXPORT_SYMBOL drivers/vme/vme 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x2eaa5e17	vme_new_dma_list
++EXPORT_SYMBOL drivers/vme/vme 0x2fd0d61c	vme_irq_free
++EXPORT_SYMBOL drivers/vme/vme 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL drivers/vme/vme 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL drivers/vme/vme 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL drivers/vme/vme 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL drivers/vme/vme 0x52983a4f	vme_master_write
++EXPORT_SYMBOL drivers/vme/vme 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL drivers/vme/vme 0x5c746524	vme_irq_request
++EXPORT_SYMBOL drivers/vme/vme 0x69a25048	vme_dma_list_add
++EXPORT_SYMBOL drivers/vme/vme 0x79a33f85	vme_get_size
++EXPORT_SYMBOL drivers/vme/vme 0x7cf35220	vme_master_free
++EXPORT_SYMBOL drivers/vme/vme 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL drivers/vme/vme 0x93e9e658	vme_slot_get
++EXPORT_SYMBOL drivers/vme/vme 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL drivers/vme/vme 0xa2a335bd	vme_alloc_consistent
++EXPORT_SYMBOL drivers/vme/vme 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL drivers/vme/vme 0xbfe7f815	vme_slave_request
++EXPORT_SYMBOL drivers/vme/vme 0xc69a7731	vme_register_driver
++EXPORT_SYMBOL drivers/vme/vme 0xca5ee09a	vme_free_consistent
++EXPORT_SYMBOL drivers/vme/vme 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL drivers/vme/vme 0xe07a06b5	vme_irq_handler
++EXPORT_SYMBOL drivers/vme/vme 0xe49a6c36	vme_lm_request
++EXPORT_SYMBOL drivers/vme/vme 0xe67c2839	vme_irq_generate
++EXPORT_SYMBOL drivers/vme/vme 0xe99dbe3d	vme_dma_list_exec
++EXPORT_SYMBOL drivers/vme/vme 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL drivers/vme/vme 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL drivers/vme/vme 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL drivers/vme/vme 0xfb59b3f9	vme_dma_list_free
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x0595b337	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x8f2f9da0	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xa92c32be	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xe4dd861a	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x922e05f7	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xbd734823	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x8a4579ad	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xdc620027	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x529727e6	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x7a10f240	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x9c9f390d	w1_register_family
++EXPORT_SYMBOL drivers/w1/wire 0xca3babbb	w1_add_master_device
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/btrfs/btrfs 0x27476846	ulist_reinit
++EXPORT_SYMBOL fs/btrfs/btrfs 0x41e6a9d2	ulist_init
++EXPORT_SYMBOL fs/btrfs/btrfs 0x7e2ee765	ulist_free
++EXPORT_SYMBOL fs/btrfs/btrfs 0xa2eec2e8	ulist_fini
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb1320bc8	ulist_add
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb42289d2	ulist_alloc
++EXPORT_SYMBOL fs/btrfs/btrfs 0xc2c745db	ulist_next
++EXPORT_SYMBOL fs/configfs/configfs 0x01e34f93	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x0e0e03fe	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x1b179d2b	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x23dc65b3	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x2d6769a8	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x2ea93572	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x3eda8e3a	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x6a20ee37	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xa81814a8	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0xd888e7ce	config_item_init
++EXPORT_SYMBOL fs/configfs/configfs 0xefb6c781	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0xf144b5c3	configfs_register_subsystem
++EXPORT_SYMBOL fs/exofs/libore 0x011500ad	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x159826a2	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x2851025a	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x316922f7	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x3f3b3d7a	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0x6feba123	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x737c164c	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x8eacde92	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xad568481	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xd14f2ba6	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0xe2c88e36	ore_create
++EXPORT_SYMBOL fs/fscache/fscache 0x08a723c1	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x10b74d70	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x1968806c	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x1b50c46b	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x22db41e1	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x2466cba1	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x3e6b4c81	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x44a88128	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x4b1d35cb	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x4bbc0dd5	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x50fff283	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x526d10dd	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x5433c415	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x5c1a0f41	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x6503efbb	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x6897d05f	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x72e495bd	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x760a696b	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x98085813	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x9dc1c3ad	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xa48dd877	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xa9676509	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xae380039	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xb1e00607	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xb8b09280	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0xbbd954a1	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xbc88519a	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xd6f9ec12	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xe6022bc6	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xe74bdba6	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0xece15e1a	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xeea3fb54	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xf89b2fd3	__fscache_update_cookie
++EXPORT_SYMBOL fs/nfsd/nfsd 0x040ea5a0	nfs4_acl_nfsv4_to_posix
++EXPORT_SYMBOL fs/nfsd/nfsd 0x35e33c1e	nfs4_acl_write_who
++EXPORT_SYMBOL fs/nfsd/nfsd 0x5a157ae4	nfs4_acl_get_whotype
++EXPORT_SYMBOL fs/nfsd/nfsd 0xcb152562	nfs4_acl_posix_to_nfsv4
++EXPORT_SYMBOL fs/nfsd/nfsd 0xda45bc09	nfs4_acl_new
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x150696c8	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0x2c1e8830	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x3ad28020	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x78ee65c0	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa7f8edcb	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x1a703ba1	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0x6d356209	crc_itu_t
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc7 0x6c1f6fee	crc7
++EXPORT_SYMBOL lib/crc7 0xd80c3603	crc7_syndrome_table
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd09b2cba	crc8
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0aadeff8	lc_set
++EXPORT_SYMBOL lib/lru_cache 0x2fdff88c	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0x5a715eee	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x6a7f6af5	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x6e4937ae	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x931b585c	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x95d31d89	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0x9a945ce3	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0xaf372984	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xca2cde01	lc_del
++EXPORT_SYMBOL lib/lru_cache 0xd0b9c96f	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0xe7e6d7b2	lc_get
++EXPORT_SYMBOL lib/lru_cache 0xeae82f48	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xeb0a363c	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xf09044ea	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0xf7f7e631	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0xfa63e10c	lc_put
++EXPORT_SYMBOL lib/lz4/lz4_compress 0x0c222eb5	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x682a23e0	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x315c65fd	zlib_deflateInit2
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x48034724	zlib_deflateReset
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xaf64ad0d	zlib_deflate
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xf741c793	zlib_deflateEnd
++EXPORT_SYMBOL net/802/p8022 0x0f61324b	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0x7be84ba1	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x10b24945	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x938f4148	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x88e08fff	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0x9680d349	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x0a7c3034	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x1269d56e	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x17027a48	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x1eaae911	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x21d99071	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x2d662cdc	p9_payload_gup
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3abe143e	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x3aeaa2d6	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x426d3dcd	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x4e060ed8	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4fac2c93	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5211175a	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x52a8ab69	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x53709ab7	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x55384c0b	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x5a1444eb	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x5b1fe9cf	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x6d3a5184	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x76ab22b5	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x7988658a	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x80bd8472	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x871bf74c	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x8863e3f7	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x90c6b79c	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x91c6dd89	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x973f3db3	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x977a0030	p9_nr_pages
++EXPORT_SYMBOL net/9p/9pnet 0x99819291	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x9da766ae	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xa73c8159	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xaddbb035	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0xaf5952e0	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0xb277e279	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0xbad46b11	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xbb5a5026	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xc1d47a8f	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xcd9c1a38	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xce62b295	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe893710a	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xf447a685	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf5b49bfa	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xf984fc4d	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/9p/9pnet 0xfd5bfe4f	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xfd7d3388	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xfe3050bc	p9_client_create
++EXPORT_SYMBOL net/appletalk/appletalk 0x7672e85c	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0xd2ef66a8	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xd80127c5	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xe9cf4c50	atrtr_get_dev
++EXPORT_SYMBOL net/atm/atm 0x07239981	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x16d560a1	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x2c8dc30a	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x2fe443f2	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x5d552658	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x716dfd70	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x7282ce05	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x7d4d2aa6	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x87b4d0a6	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x8c3df8b2	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x93136f41	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa52bfc00	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xbd781830	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0xc8f232a6	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x026c1368	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0x13e0d5e8	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x42d99ffc	ax25_hard_header
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x45cd9ca8	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x73f30662	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x74afe393	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x78d45b70	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xb462b316	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xc93d9ec1	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xcac69d0e	ax25_rebuild_header
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xf053fd06	ax25_linkfail_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x06d35fce	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x15e95896	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x16262dd3	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x191b9838	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x444dc8c3	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x448e6917	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4ae4ac97	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4b19c59d	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x52f03598	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x564c6162	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x59bc7f36	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6110ca7e	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x62117ead	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x678c8d13	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x75ffe8b6	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7892f694	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x798172c2	hci_recv_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x798e3c02	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c640527	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x86d81da8	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8765b68a	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x89243d9a	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8c2ac549	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8d28ee35	hci_recv_stream_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x90a764fb	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x941da02c	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x94af712c	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x97a0d889	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x9f856862	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xad116d22	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb186be3e	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb3d33bc3	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb61a0c3b	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc87c2398	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc941fd36	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe721eab6	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xeebd8d16	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf92029e8	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bridge/bridge 0xc1ff71c4	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xe7a5b67b	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xf3fdcf0a	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xf67c71fc	ebt_do_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x45fa1d20	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x4d63e1de	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9c65ca65	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xaef49b0a	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xc9d9642e	caif_connect_client
++EXPORT_SYMBOL net/can/can 0x0fc7fae7	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0x26ea51e6	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0x3fb4fc20	can_rx_register
++EXPORT_SYMBOL net/can/can 0x896accae	can_proto_register
++EXPORT_SYMBOL net/can/can 0xb14e625e	can_send
++EXPORT_SYMBOL net/can/can 0xea075715	can_ioctl
++EXPORT_SYMBOL net/ceph/libceph 0x01e9cbde	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x055bc46d	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0d61c270	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0x1475bf0d	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x16ba46ae	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0x197effcb	ceph_osdc_release_request
++EXPORT_SYMBOL net/ceph/libceph 0x1ba4d624	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x208b31f9	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x22ed12af	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x267edcbd	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x2a407e2d	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x2b10d4ba	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x2dcbe214	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x369f917d	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3df0ec7c	ceph_calc_ceph_pg
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x4205ffd7	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0x428d6b69	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x4582c498	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x4613302f	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x480fb4b5	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x48828364	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x4a283545	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x4e8886af	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x500da29b	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x52ea2525	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x570ceb67	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x64a9c40f	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x67fc6a11	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x68ec300c	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x69f67e0c	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0x69f686d5	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c5d5ac1	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x6e922dad	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x6f3e6034	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x7168baf8	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x720bea6e	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x73331a50	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x736a0d2a	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x742d764a	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x75b5df9f	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x77692acb	ceph_msg_last_put
++EXPORT_SYMBOL net/ceph/libceph 0x7803a10e	ceph_osdc_unregister_linger_request
++EXPORT_SYMBOL net/ceph/libceph 0x78a52947	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x79cd9f0e	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x7fdbda47	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x81eae1b6	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0x85b066e3	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x88d73356	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x8e9afe5e	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x98247ab0	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x98f68603	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa5c77c45	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xa62dc141	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb13a2e1d	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xb3a8c64b	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xb3b48ba8	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb582d8ad	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xc1350213	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xc18743aa	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xc3b39279	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc55de604	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0xc6d5d649	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xc8a870a5	ceph_monc_create_snapid
++EXPORT_SYMBOL net/ceph/libceph 0xc8dfc811	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcfcc2435	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xcfee749b	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd743c2c7	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0xde76c235	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0xe608fe37	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xe82c9c32	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xe8acc858	ceph_copy_page_vector_to_user
++EXPORT_SYMBOL net/ceph/libceph 0xe9818faa	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xea58ce77	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xeb7c1169	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0xed12f491	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0xed229339	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xefabdf95	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xf200baa6	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0xf5774cba	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0xf653f69f	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf8763f37	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xff698c6a	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0xa7f95e62	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x0a719051	ieee802154_nl_disassoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1363eaec	ieee802154_nl_assoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x21eadf01	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x377a67cb	ieee802154_nl_disassoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x59827d59	ieee802154_nl_scan_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x703b4ebc	ieee802154_nl_start_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x8d77cc55	ieee802154_nl_beacon_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x8f59081f	wpan_phy_alloc
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xae2e7bf4	ieee802154_nl_assoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb631a97d	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xda8eeb56	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xdf28d317	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xf1168413	wpan_phy_unregister
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x198c53ff	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x334b4322	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xbcde5da3	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x509af029	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xaa7be5ee	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xed004d0a	ipt_register_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0x661ee3d4	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0x9b9ce674	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xa8801b47	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0xc675708f	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xa67b2737	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xb5f9ac01	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xd19b5fc0	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x7dcba966	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/tunnel6 0xa879bba3	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x89e72542	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xc406b1e2	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x0e57cccf	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x1d4e08ba	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x243db6cb	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x77a58d87	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x88cb47df	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xb42ea371	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xd25c0e51	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe411f111	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x01305e3a	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x09f58a8b	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x0f6e21a0	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x1689c688	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x16e7ebef	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x1afcdbd4	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x2036ad06	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x26e6b539	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x28704b6e	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x3b6d5f65	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x3ccfd796	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x42a9904d	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x43a366b1	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4c4f4878	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x5c839df3	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0x615ee918	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x66ef7db3	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6eb89be8	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x71442a9b	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x76ef9f52	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7dabe31e	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x7fb81606	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x828b8db1	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x86b5f4ce	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x8b69b459	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x8dd879ff	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x8ef05696	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x993ad14b	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0xa0d8b28c	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xa4548c32	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0xaa89d8b7	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xad66e1db	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0xb0476610	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xb780d3f6	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc25eac67	iriap_close
++EXPORT_SYMBOL net/irda/irda 0xc2dc1bba	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xc310cf21	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xcada061c	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xd1ae6745	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xd57045a8	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf77c2dd0	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0xfa66181c	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0xfc095cbd	async_wrap_skb
++EXPORT_SYMBOL net/l2tp/l2tp_core 0xf0923ddc	l2tp_recv_common
++EXPORT_SYMBOL net/lapb/lapb 0x1f5233a4	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x213e6a4e	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x2c2d99f6	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x2ff6840a	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0x4f5a3eb3	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x5de64562	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x89efcb5f	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0xf2e7c3d7	lapb_setparms
++EXPORT_SYMBOL net/llc/llc 0x2e4a9369	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x306a0e91	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x6c6cdb31	llc_sap_list_lock
++EXPORT_SYMBOL net/llc/llc 0x972cabeb	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xa3456019	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xc03f6c85	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xc458aad3	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xe2f008c7	llc_add_pack
++EXPORT_SYMBOL net/mac80211/mac80211 0x009376f2	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x07184a3b	ieee80211_alloc_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x07cb4650	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x10a0d296	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x1d8f1c62	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x1dab2844	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x21a2ae71	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x2234122a	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x24646595	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x267ec7d4	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x2e466b29	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x314f1855	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x352ec21f	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x36864d9b	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x43175902	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x43634fd2	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d48f297	ieee80211_rx
++EXPORT_SYMBOL net/mac80211/mac80211 0x51f98208	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x545951cd	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x5c28cca5	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x626bd5ab	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x670b2e69	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x67ab28d4	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x69429d3d	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x6d295a01	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x6df0d795	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x70da19b5	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x79917120	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0x83962b8f	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x934e772a	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x96570187	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c5e6334	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x9cedf819	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x9d83d973	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1fc36c4	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xa73b1084	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa157485	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xab27d25e	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0xae24cce0	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1e9a3c5	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0xb24f072f	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xb33430a6	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xb6ee49ba	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xb93d04a5	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xbb98347e	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xc0c41bf1	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xc0d0d7d5	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0xc1f703c4	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xc7e9782e	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8c0ccc7	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xca58033a	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xcccafe99	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xd07a6169	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xd3d42dc9	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xd40eb346	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xddb47d52	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xe45ad24c	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xe663b4c2	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xe85dc963	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xea113f5c	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xeba237e4	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xec347e33	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf153fe1e	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xf395de03	ieee80211_aes_cmac_calculate_k1_k2
++EXPORT_SYMBOL net/mac80211/mac80211 0xf4999e17	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0xf70573c5	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xf7a9dfe6	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xfce77f58	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xfeca41a6	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xfeed2f68	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x5b12791f	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x9a2bcb33	ieee802154_unregister_device
++EXPORT_SYMBOL net/mac802154/mac802154 0x9b5a1bdf	ieee802154_register_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xac349e5e	ieee802154_free_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xea4c273d	ieee802154_alloc_device
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x02d97cd8	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x099a63d7	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x16948dd3	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x1e50f8c3	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2a3c0cca	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4093c096	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x50a90fa8	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x83e1a2f7	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8582899f	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb1504f97	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xbdd95cb7	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd6b3d5e3	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xe78867ff	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xff9d6663	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x06f8c46c	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x8e616652	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xebb7456f	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack_proto_gre 0xc3293510	nf_ct_gre_keymap_flush
++EXPORT_SYMBOL net/netfilter/nf_nat 0x0ebc2175	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x351ea5c9	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0x73eea1ac	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x8305f648	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xb56f33a0	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0xbac83f1d	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x08c473b7	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x205e0eed	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x253e8b44	xt_compat_init_offsets
++EXPORT_SYMBOL net/netfilter/x_tables 0x2f3e775b	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x58b81dd4	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x649e7f49	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xa8302acd	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xae1e1cd5	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xb28f5ef1	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xc3fed212	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xdd68fe29	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xdfa7c5d1	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xef95659c	xt_register_matches
++EXPORT_SYMBOL net/nfc/hci/hci 0x05c6c539	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x0a45d1d5	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x0f2fbe38	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x207e28f1	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x2df24c79	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x329baa94	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4a090445	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x565e71b8	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x6f64078e	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x808878ff	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x8de6ae09	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0x99231d1c	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xa96678cb	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xbe33032a	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xce27d79e	nfc_hci_send_response
++EXPORT_SYMBOL net/nfc/hci/hci 0xdb8196dd	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xe9e58a2e	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xfe7db989	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/nci/nci 0x909a9150	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xb8147d78	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xbf58413c	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xda7a5f05	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xe7846bd4	nci_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x0439598c	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x0d544855	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x126bede2	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x2b6d425c	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x45cd1801	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x68bf3350	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x6ade4512	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x7f5a6054	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x842a07af	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x8a6f0f71	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x8eab246f	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xa5e0933e	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xb7ffd2e2	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xd1046d13	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xd160fd87	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0xd4f139f2	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0xe173f885	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0xf92f190d	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xfd195ed2	nfc_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0x30984c6d	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x33ae9751	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x4d8d4699	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x7d335605	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x9ad8343f	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xbb278987	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xd042fe58	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xd39bfadc	phonet_proto_register
++EXPORT_SYMBOL net/rds/rds 0x7505d413	rds_str_array
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x068e8609	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x06b9346a	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0dfb520a	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1b6738bb	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1ed80701	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2aa242ab	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x4216e62a	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x59be06fb	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x897638a6	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9b90e7cc	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb17042cd	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb9a5e684	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xdd1aea1d	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe8b61dc1	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xe96c5359	key_type_rxrpc
++EXPORT_SYMBOL net/sctp/sctp 0xc9892235	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x2a3b8c90	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x439ff86a	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xfaecd892	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x3bb217b5	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x52b886bd	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xf690832e	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x016d3f1c	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x03a74288	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x0728f680	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x07e86051	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x0862031a	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x10ed4712	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x1403a39d	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x1693aac1	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1c7c3d3d	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x221394d8	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x22fcd57a	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x25229e07	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x252a8fd1	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x30a3dfed	cfg80211_del_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x3fcc90b0	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x406a8302	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x420ec784	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c3b5878	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x52021820	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x5432f995	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x56e975f2	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x5a86403d	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x5cbc6ab3	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x63bccf25	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x679b50c4	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6c5c1994	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x708d7c3d	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x725fb3aa	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x72928156	cfg80211_inform_bss_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a20fa0d	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x7a4d7997	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ca4b1cc	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x7d19c0d5	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8393ee23	cfg80211_inform_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x87d2f339	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b171f65	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x8c16a9f0	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x8e5c8b2b	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ef1f2e4	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x90d46e5e	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x90e82eb9	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x92049ebe	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x92c0c538	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa7aeec9a	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xaa4c9f99	cfg80211_testmode_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xab6c3607	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0xafe6f3d2	cfg80211_testmode_reply
++EXPORT_SYMBOL net/wireless/cfg80211 0xb1ac6ebc	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xb467ffaf	cfg80211_testmode_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6cebb4a	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7a6c1d5	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7d1afeb	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0xbdad0a12	wiphy_new
++EXPORT_SYMBOL net/wireless/cfg80211 0xbf23fd22	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xc15c8611	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xc2b285be	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xc412ff05	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0xc44d9d34	cfg80211_testmode_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xc49ae725	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xcc01df4d	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xcf618a57	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0xd1a2f134	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xd47fcfab	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xd4b2d2b1	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xd4e12b17	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0xd6ac09ca	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xd8736da9	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3167eca	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0xe6769361	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xe9a6a4d1	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xee42db3c	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0xef8440da	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xf02f5e61	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xf3957578	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xfdedfaf8	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xfef914f6	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/lib80211 0x18564150	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x2d0f99e5	print_ssid
++EXPORT_SYMBOL net/wireless/lib80211 0x5c55baa4	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x6577aebf	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x671d1f0a	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x70694682	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xe731b053	lib80211_get_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x9bb9db83	ac97_bus_type
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x291699ce	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x88f58039	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x9d8374ad	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xbcf5478d	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x3a57f235	snd_seq_autoload_unlock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xb90668b2	snd_seq_autoload_lock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xc622fb29	snd_seq_device_unregister_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xcf574a4a	snd_seq_device_register_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xedddad95	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x01b82065	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x0d2b74da	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2ceec35d	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x668570c0	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7f92860c	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb494afee	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xc7b2b6c2	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xe0a50454	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x967dd72d	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x017a37fc	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0x025c4539	snd_card_create
++EXPORT_SYMBOL sound/core/snd 0x04fd5e1d	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x07806007	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0x0b9b73ea	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0x0e12ae9e	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x269d18d9	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0x27a8439f	snd_card_proc_new
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x30712880	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0x342a2354	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3c4b48c1	snd_card_unref
++EXPORT_SYMBOL sound/core/snd 0x40009f28	snd_ctl_unregister_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4b015768	snd_iprintf
++EXPORT_SYMBOL sound/core/snd 0x4b99576b	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0x62c2836d	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x645b7e10	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0x6a6e5605	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x6c8a3446	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x71fc5ad1	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0x720c8bc1	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0x7298c8de	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x74d714b7	snd_ctl_register_ioctl_compat
++EXPORT_SYMBOL sound/core/snd 0x7afa1999	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x7c82e231	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x80e16ff6	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x99da1a40	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0a4c6ba	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa9c5aa52	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0xaf9131e9	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd 0xb1e05e48	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0xb2d12016	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb3a3e44c	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0xb40e19c8	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xc35db7c6	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0xcc0bcc67	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xcedcf22f	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0xd024ce43	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xd82169fc	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xd8c0780c	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0xd99968b2	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0xdc230254	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0xdddb737a	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0xdfd763c1	snd_add_device_sysfs_file
++EXPORT_SYMBOL sound/core/snd 0xe36ace3e	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xf0eedb9a	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0xf226e07f	snd_cards
++EXPORT_SYMBOL sound/core/snd 0xf3689107	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xf4c8e994	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xf7b66f0e	snd_register_device_for_dev
++EXPORT_SYMBOL sound/core/snd 0xfffd89db	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd-hwdep 0x6e4394ac	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x06b310c9	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x23bd6ef7	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x534bcfc3	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x5898dcba	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x6af202ee	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x6d259b40	snd_dma_get_reserved_buf
++EXPORT_SYMBOL sound/core/snd-page-alloc 0xca34c226	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-page-alloc 0xcaf3a7a2	snd_dma_reserve_buf
++EXPORT_SYMBOL sound/core/snd-pcm 0x008ba830	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x08dc4080	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x09f58435	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0x0c2c66ed	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x102b54cc	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x1a4227fe	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1cab465b	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x2127f4e8	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x287cd962	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x2af2f0c7	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x2f635766	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0x2fdff36e	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x48666de1	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0x4870665f	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x5c0d4079	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0x5c7e01be	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e4415a4	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x61a891db	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0x6439d462	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x67489230	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x6768645f	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x73472313	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x779e468b	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x7f4ef9b2	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x8096fb59	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0x834dc955	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x8694a9c6	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x95445237	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0xa02e57fe	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xa53116ba	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa9adc229	snd_pcm_link_rwlock
++EXPORT_SYMBOL sound/core/snd-pcm 0xab8dcb19	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xb13c229d	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xb226674f	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0xb34d11d0	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0xb410d9dc	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xc24c13b2	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0xc63e8fca	snd_pcm_debug_name
++EXPORT_SYMBOL sound/core/snd-pcm 0xc8480ce5	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0xc868fe6e	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0xd3a18133	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0xd960ee49	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xe4a5bb94	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xe9dba079	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xea018fc6	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0xebcae582	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xf3797152	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x199ce003	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x22ccfd01	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x2cc807d9	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3f802c0d	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x46f4066d	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4bf938d9	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x547a6caf	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x58b2d5bf	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x632354a9	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7f58bd08	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x805d1dfa	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbad7109c	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xccd0a037	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xdb4d5544	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe10e4dce	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xfd83301c	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xfe4e417d	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-timer 0x04ed0c5d	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x3d13b269	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0x3f0b40f7	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0x45bec5b8	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0x4959b35a	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0x4e5cb931	snd_timer_global_register
++EXPORT_SYMBOL sound/core/snd-timer 0x540d5a7e	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0x571e7dbd	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0xa40ae90a	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0xbe25d275	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0xc9a263fc	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0xe7661c5b	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0xe8853c7d	snd_timer_close
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x7d6bd86c	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0078bfea	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0d885d76	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x2379eec6	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5f666841	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x8dd710fc	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x9907f95a	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xa4e28b2c	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xea3e4594	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xf30af983	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x028e101c	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1c37cb1c	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x22574272	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x429884ae	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x505e3fcf	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6d53f46b	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x84a3f5fc	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb60e2088	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xb8f33286	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x017b315d	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x23351f36	amdtp_out_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3c837ad0	amdtp_out_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x493252be	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4ad773e3	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4e179ccc	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4fcc0d6a	amdtp_out_stream_set_pcm_format
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4feb8beb	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x51a43f51	amdtp_out_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x529893c1	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5cb34d2f	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5d939103	amdtp_out_stream_set_rate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6185ed78	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6e4e0fbd	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x78c52a12	amdtp_out_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x815954db	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x881379fb	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8d2a8596	amdtp_out_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9b3ba082	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa98fedc3	amdtp_out_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xab8bfbf0	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbf1f6b75	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc1ab3d3c	amdtp_out_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xcc637ca1	amdtp_out_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd03bba28	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf4e4e099	amdtp_out_stream_update
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x056327b5	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x0ed4686c	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x504d6bfa	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x57314829	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x8b4977e8	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xb3b453aa	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x7072683b	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x729a5500	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x7e8816de	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x8eebcf98	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xd001f780	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xfd8148eb	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x08682641	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x805e1d94	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x947bf8be	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xe2fed3f8	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x2be443fd	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xe41cbf69	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x172bb7d5	snd_tea575x_init
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x73e2eb7e	snd_tea575x_set_freq
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0xa25836bf	snd_tea575x_exit
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x017a68ad	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x43beafe0	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x647d409b	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x65ddf330	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x93d40a9e	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x0e22121f	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x3bad9931	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x6567c202	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x9c15ea30	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xa5e60424	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xc2ae4a36	snd_i2c_device_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x145ae68b	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x175b908a	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x19c86d2d	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x34471bfe	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x3952febf	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x3e3089a0	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x5594f8bf	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x582ca120	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc3658cb2	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xec34d800	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x011bbb9e	snd_sb16dsp_configure
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x10e5145f	snd_sb16dsp_get_pcm_ops
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xcb8d1a8e	snd_sb16dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe0b3f690	snd_sb16dsp_interrupt
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x012ce191	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x07fdd861	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x080f0a40	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1dcfaed1	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x32ccabe6	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3fb4dab4	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5511e8a6	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5900c5ff	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5efb24f6	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x644d911a	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x68c4628e	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7604c707	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x954488cf	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9a0234ed	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xac9b574e	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcf997f4d	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfd918638	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0x9a9ac0dc	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x22fe0036	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x26ee3e4f	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x431b4353	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x43a50df0	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x494ecd0b	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x5bb471bb	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xa4fae597	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xc7705b38	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xf0e0ce2d	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x12dbe6ad	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x88a2aca3	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xb0394014	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0fc2c4f3	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1dbaa84f	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x25aff627	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x41c0ee10	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x46ffe00d	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x49098b2c	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4d5effaa	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x567b7e27	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x58e19c95	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x5f701113	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x7a2f96c3	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa54b6d6a	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa7d62e21	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa845ae58	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb90917b6	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xba520353	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc438b698	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc83d26af	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xce2c771b	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xf666ab63	oxygen_write32
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x051bcec5	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x28cedf8c	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x4ad0d303	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x795bf73e	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x8b47f186	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/soundcore 0x1851b5f1	sound_class
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x15d71263	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x265be5ad	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x39e4f1c3	snd_emux_register
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x83244130	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x8bcf224f	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x94234be6	snd_emux_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x2157257d	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x21574d79	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x547dfe81	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x66745317	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xac9ee235	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xe18b93c0	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xf70a5417	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xf9b5e4fa	snd_util_mem_avail
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xfeb62a7d	snd_usbmidi_create
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x35c95b1b	dm_mem_cache_client_create
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x86e5acf9	dm_mem_cache_grow
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x920a7a41	dm_message_parse
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x9346b4af	dm_mem_cache_free
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x966d5b3b	dm_mem_cache_alloc
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xa43471b6	dm_mem_cache_shrink
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xd55b290c	dm_mem_cache_client_destroy
++EXPORT_SYMBOL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2776a3e5	lib_ring_buffer_nesting
++EXPORT_SYMBOL vmlinux 0x00000000	softirq_work_list
++EXPORT_SYMBOL vmlinux 0x0043f66d	create_syslog_header
++EXPORT_SYMBOL vmlinux 0x00560696	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x006b67bd	finish_no_open
++EXPORT_SYMBOL vmlinux 0x00801678	flush_scheduled_work
++EXPORT_SYMBOL vmlinux 0x0093a79b	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x00948ce0	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x00a54096	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x00e91cbd	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0x00fffbb3	journal_abort
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x0103d815	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x01178435	give_up_console
++EXPORT_SYMBOL vmlinux 0x01180377	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x011bce7c	set_groups
++EXPORT_SYMBOL vmlinux 0x015122fb	write_one_page
++EXPORT_SYMBOL vmlinux 0x015ddbdc	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x01783484	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x01902adf	netpoll_trap
++EXPORT_SYMBOL vmlinux 0x019fa1f2	skb_pull
++EXPORT_SYMBOL vmlinux 0x01a41905	bioset_create
++EXPORT_SYMBOL vmlinux 0x01a960d4	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x01cbbe94	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x01d19038	acpi_enable_subsystem
++EXPORT_SYMBOL vmlinux 0x01e79248	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x01fe1a8d	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02286b10	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x0232de39	journal_set_features
++EXPORT_SYMBOL vmlinux 0x0234624a	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x023e27d2	task_nice
++EXPORT_SYMBOL vmlinux 0x025241b1	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02685db0	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x029444f0	native_read_tsc
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02d2c1dc	proc_symlink
++EXPORT_SYMBOL vmlinux 0x02ec38a0	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x02fc1c0e	eth_rebuild_header
++EXPORT_SYMBOL vmlinux 0x0326a0ca	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x033506a1	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x034611d6	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x03498156	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x034d03e5	module_put
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x036c65cf	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x0377b880	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03bd889d	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x03c06156	bitmap_fold
++EXPORT_SYMBOL vmlinux 0x03c4b744	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x03d02a1d	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x03db8187	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x03ebda85	dns_query
++EXPORT_SYMBOL vmlinux 0x03f7c5cd	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x03fb0c53	__breadahead
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x040bd15c	d_invalidate
++EXPORT_SYMBOL vmlinux 0x04166788	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x0421e212	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x0430cd3b	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x044d787a	dev_get_drvdata
++EXPORT_SYMBOL vmlinux 0x0456014b	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x046c1f16	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x046c9bbd	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x046f6ab2	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x047a07f4	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x0483b314	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x04927208	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x0499badc	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x04a6223b	__idr_pre_get
++EXPORT_SYMBOL vmlinux 0x04b56ea3	journal_stop
++EXPORT_SYMBOL vmlinux 0x04bae0b5	skb_push
++EXPORT_SYMBOL vmlinux 0x04c20a81	init_net
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04ea5d10	ksize
++EXPORT_SYMBOL vmlinux 0x04ea8ff9	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x04f6ba79	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x05031f17	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x053b2cf1	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x054434d6	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x05449ff9	seq_lseek
++EXPORT_SYMBOL vmlinux 0x0547a4d5	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x05555916	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x055c8559	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x056a4ede	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x056ee730	ipv6_hash_secret
++EXPORT_SYMBOL vmlinux 0x0570f84f	amd_iommu_flush_tlb
++EXPORT_SYMBOL vmlinux 0x058b4167	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x0593a99b	init_timer_key
++EXPORT_SYMBOL vmlinux 0x05fb9350	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061f4039	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x064a5954	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x065b5cc2	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x0672cf39	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x06a365c7	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x06b08f78	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06c69f69	simple_open
++EXPORT_SYMBOL vmlinux 0x06f82474	pci_enable_ltr
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x07025cd9	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x07259c4d	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x073dfa12	generate_resume_trace
++EXPORT_SYMBOL vmlinux 0x074bf576	genl_notify
++EXPORT_SYMBOL vmlinux 0x0799aca4	local_bh_enable
++EXPORT_SYMBOL vmlinux 0x07a20375	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07b22a52	pci_enable_bridges
++EXPORT_SYMBOL vmlinux 0x07bdac92	do_sync_write
++EXPORT_SYMBOL vmlinux 0x07c02a43	sock_rfree
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07cff523	simple_write_end
++EXPORT_SYMBOL vmlinux 0x07e41b61	scsi_nonblockable_ioctl
++EXPORT_SYMBOL vmlinux 0x07e53897	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x07fa78f0	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x07fbcd75	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x082106d6	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x083424f3	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x0835d841	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x08408d85	pci_iomap
++EXPORT_SYMBOL vmlinux 0x0846f59a	cpu_info
++EXPORT_SYMBOL vmlinux 0x089061cf	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x0891e01d	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0x08932246	spi_attach_transport
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08aae601	__bforget
++EXPORT_SYMBOL vmlinux 0x08af41f5	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x08b31ce3	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x08cadf84	get_user_pages
++EXPORT_SYMBOL vmlinux 0x08f64aa4	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x08f870b5	input_release_device
++EXPORT_SYMBOL vmlinux 0x09033aa5	mutex_lock
++EXPORT_SYMBOL vmlinux 0x09088bb6	register_cdrom
++EXPORT_SYMBOL vmlinux 0x0918a232	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x0940ad67	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x095f6157	qdisc_tree_decrease_qlen
++EXPORT_SYMBOL vmlinux 0x096a5f16	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x098431ba	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0x09844c79	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x098464d8	mmc_start_req
++EXPORT_SYMBOL vmlinux 0x098b6dac	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x0992780d	efi_enabled
++EXPORT_SYMBOL vmlinux 0x099f531c	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x09be5ee6	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x09c1e96e	__vlan_find_dev_deep
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09d57c36	would_dump
++EXPORT_SYMBOL vmlinux 0x09d95cad	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x09ef5b8e	kill_fasync
++EXPORT_SYMBOL vmlinux 0x09f92e78	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x0a1e9a78	d_drop
++EXPORT_SYMBOL vmlinux 0x0a2487e0	unblock_all_signals
++EXPORT_SYMBOL vmlinux 0x0a2961b2	scsi_register
++EXPORT_SYMBOL vmlinux 0x0a2f4e6e	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x0a4c6bad	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x0a5917c8	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x0a770832	register_memory_notifier
++EXPORT_SYMBOL vmlinux 0x0a9c0460	dma_async_memcpy_buf_to_pg
++EXPORT_SYMBOL vmlinux 0x0aa94869	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x0ac7a879	__bread
++EXPORT_SYMBOL vmlinux 0x0acb1a3c	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ad0e67c	idr_replace
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b11820f	journal_start_commit
++EXPORT_SYMBOL vmlinux 0x0b14c1a1	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b202b0a	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x0b4d43d5	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x0b6689e2	bio_add_page
++EXPORT_SYMBOL vmlinux 0x0b721898	skb_copy_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b82d9d2	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bd73f9a	genphy_resume
++EXPORT_SYMBOL vmlinux 0x0bdaf457	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x0c0b5a35	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x0c266f4d	dquot_release
++EXPORT_SYMBOL vmlinux 0x0c284dbd	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x0c33662a	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x0c364eb2	cdrom_release
++EXPORT_SYMBOL vmlinux 0x0c4500f7	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c65e73c	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0x0c704106	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x0c71de93	file_update_time
++EXPORT_SYMBOL vmlinux 0x0c8c9e99	scsi_show_extd_sense
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cd6753e	genl_register_mc_group
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0ce97c16	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x0cfc481a	send_sig
++EXPORT_SYMBOL vmlinux 0x0d1e80e7	sk_common_release
++EXPORT_SYMBOL vmlinux 0x0d2891b8	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x0d31f5ea	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d7df4c6	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da38ef1	igrab
++EXPORT_SYMBOL vmlinux 0x0df26a3c	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x0e0e3c15	netpoll_rx_enable
++EXPORT_SYMBOL vmlinux 0x0e18ccbe	spi_schedule_dv_device
++EXPORT_SYMBOL vmlinux 0x0e2ef736	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x0e313b01	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e702c2d	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x0e814b7e	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x0e8a51e0	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x0e8efe46	input_flush_device
++EXPORT_SYMBOL vmlinux 0x0ea16e7d	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x0eb5fc71	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x0eb843ee	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x0ebb1639	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x0ed06f06	blk_get_backing_dev_info
++EXPORT_SYMBOL vmlinux 0x0ed8cc7b	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0x0f11e668	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x0f45aa35	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5c7911	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x0f9105a4	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x0fa1bd61	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb54b19	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x0fbf4754	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0fddaf20	fb_class
++EXPORT_SYMBOL vmlinux 0x0fedd758	tty_register_device
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x10117311	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x1016d69e	iget_failed
++EXPORT_SYMBOL vmlinux 0x1017b662	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x102268d7	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x1027be50	stop_tty
++EXPORT_SYMBOL vmlinux 0x102be8e7	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x102e4a63	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x103579e4	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x1043404c	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x10678b6e	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x106883c3	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x106fd861	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x10890464	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0x10923fd9	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x10ba8fa4	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x10be4442	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x10c7612d	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x10d18e27	keyring_search
++EXPORT_SYMBOL vmlinux 0x10d7f662	have_submounts
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x11267875	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0x113918a1	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x11602790	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x11df0384	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x11e2ec12	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x11e640da	unregister_nls
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x120d67d4	unregister_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0x120eb513	vfs_open
++EXPORT_SYMBOL vmlinux 0x1213e4f3	put_disk
++EXPORT_SYMBOL vmlinux 0x12697ca3	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x12736b33	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x127d4a0d	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x127fd425	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x12893ac7	unregister_console
++EXPORT_SYMBOL vmlinux 0x128e8f2e	d_make_root
++EXPORT_SYMBOL vmlinux 0x1298885a	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x129de341	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12dfeb12	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x1305d532	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x131e910e	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x133060fa	seq_write
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x133e25f6	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x1345f5dc	bio_pair_release
++EXPORT_SYMBOL vmlinux 0x137eb9c3	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x13b715e2	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0x13bd0eb4	journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x13c38a7c	clear_inode
++EXPORT_SYMBOL vmlinux 0x13ca95ca	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e81758	page_readlink
++EXPORT_SYMBOL vmlinux 0x13f006e0	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13fc85c4	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x1419c5fa	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x1448a9e6	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x144accaa	generic_readlink
++EXPORT_SYMBOL vmlinux 0x14765d5d	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x1476685f	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x1483340c	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x1492d2bf	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x1495b7ef	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x14977fb7	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x149e2513	bio_integrity_tag_size
++EXPORT_SYMBOL vmlinux 0x14ac7157	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x14c1dfcb	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0x14c74435	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x14de42ec	journal_errno
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x1532b2c8	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x1541d1da	xfrm_cfg_mutex
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1551dc51	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x15682d25	simple_statfs
++EXPORT_SYMBOL vmlinux 0x15692c87	param_ops_int
++EXPORT_SYMBOL vmlinux 0x159123b6	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x1598eb92	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x15a5957a	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x15b703c6	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x15cac562	vfs_rename
++EXPORT_SYMBOL vmlinux 0x15ebedde	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x15f571ec	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x160282df	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x1623441e	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1637ff0f	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0x1651e59c	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x167c5967	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x168f1082	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x1694b71d	pid_task
++EXPORT_SYMBOL vmlinux 0x1696aca7	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x16a488f1	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x16b72453	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x16cbcb01	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x16e2e398	writeback_in_progress
++EXPORT_SYMBOL vmlinux 0x16f1dc27	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x1745041e	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x176a9077	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x177c02c2	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x1790d76b	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x17947603	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x1798e36d	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x17a99a5c	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b64d09	dqstats
++EXPORT_SYMBOL vmlinux 0x17d275be	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x17daa644	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0x17e58b31	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x1829ed89	blk_bio_map_sg
++EXPORT_SYMBOL vmlinux 0x182b98b4	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x18345183	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x18372367	register_console
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x18472d5b	netdev_class_create_file
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184e6c85	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x184fc435	ip_cmsg_recv
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x1895dbd3	filp_close
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x189dd580	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x18a3a34c	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x18ac64f9	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x18b72573	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x18c4c3f2	register_gifconf
++EXPORT_SYMBOL vmlinux 0x18c6ff3b	ps2_init
++EXPORT_SYMBOL vmlinux 0x18c9177f	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x18d0ccec	file_sb_list_del
++EXPORT_SYMBOL vmlinux 0x18d780e9	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x18dc91ed	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x18de64e9	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x18e013d6	skb_pad
++EXPORT_SYMBOL vmlinux 0x19126e3d	journal_start
++EXPORT_SYMBOL vmlinux 0x193298e1	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0x19444627	memcpy_fromiovecend
++EXPORT_SYMBOL vmlinux 0x19470d47	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0x1976aa06	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x197d09a0	_dev_info
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19ba2499	__module_get
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c44d4a	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x19cb0e96	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x19f79812	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x1a0cfa76	blk_queue_merge_bvec
++EXPORT_SYMBOL vmlinux 0x1a0e6660	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x1a11a37e	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a54df29	key_unlink
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a6930b0	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x1a7e660d	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x1a8058b9	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x1a869177	pci_save_state
++EXPORT_SYMBOL vmlinux 0x1aa102c0	dm_io
++EXPORT_SYMBOL vmlinux 0x1abad0e9	kern_unmount
++EXPORT_SYMBOL vmlinux 0x1ac5d3cb	strcspn
++EXPORT_SYMBOL vmlinux 0x1ace138d	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0x1ae14ef5	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x1afc2e80	lock_may_write
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b02457d	phy_device_register
++EXPORT_SYMBOL vmlinux 0x1b038ace	udp_poll
++EXPORT_SYMBOL vmlinux 0x1b06e1f4	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x1b0b3166	ip6_route_output
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b353088	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b64d411	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x1b72e972	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x1b7d5a09	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b86077c	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b9e0ff1	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x1ba3580c	ping_prot
++EXPORT_SYMBOL vmlinux 0x1bca284e	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x1bdc26cf	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0x1bf010db	mmc_request_done
++EXPORT_SYMBOL vmlinux 0x1bf67d3a	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x1bf73cab	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x1c015911	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x1c114a6a	vm_event_states
++EXPORT_SYMBOL vmlinux 0x1c30124c	setattr_copy
++EXPORT_SYMBOL vmlinux 0x1c3057f4	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x1c4eb00d	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x1c55248b	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0x1c57eca3	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x1c5c5df4	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x1c66532a	set_binfmt
++EXPORT_SYMBOL vmlinux 0x1c784373	mount_subtree
++EXPORT_SYMBOL vmlinux 0x1c822569	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c8deb64	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x1c967f88	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x1cd38ecb	d_path
++EXPORT_SYMBOL vmlinux 0x1d1ced3b	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x1d270dd4	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x1d27673d	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x1d2a7fea	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x1d2bdd41	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x1d4b5ce0	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0x1d4ba2cd	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x1d50f76b	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x1d6d2f9b	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0x1d816f41	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x1d925f4a	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x1d970d2e	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x1d9bc05b	d_find_alias
++EXPORT_SYMBOL vmlinux 0x1da08c78	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x1da3aca8	inet_put_port
++EXPORT_SYMBOL vmlinux 0x1dad83e2	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x1db7706b	__copy_user_nocache
++EXPORT_SYMBOL vmlinux 0x1dbe4d70	loop_backing_file
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dde6f68	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x1dde839c	dump_seek
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e076829	journal_release_buffer
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e0df654	journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x1e249ba8	journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e3ff7db	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0x1e424a3a	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x1e52a9a6	skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x1e6b569b	pci_release_regions
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e6f05d5	amd_iommu_domain_clear_gcr3
++EXPORT_SYMBOL vmlinux 0x1e7597ca	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x1e8afde1	register_quota_format
++EXPORT_SYMBOL vmlinux 0x1e992f88	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ec3bed9	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0x1ec4eb34	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x1ed13793	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x1edb9cc4	seq_path
++EXPORT_SYMBOL vmlinux 0x1ef257da	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x1ef61045	find_lock_page
++EXPORT_SYMBOL vmlinux 0x1f04ff0c	phy_find_first
++EXPORT_SYMBOL vmlinux 0x1f0a1322	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x1f0d3761	follow_up
++EXPORT_SYMBOL vmlinux 0x1f183c13	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x1f37e3fd	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x1f6ce67a	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x1f7c7a41	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x1f9d6006	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x1fb27202	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff44c51	vc_cons
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x20003f28	vga_tryget
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x20092385	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0x200d7877	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x2012daa1	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x203a72cf	dev_load
++EXPORT_SYMBOL vmlinux 0x2044aea7	amd_iommu_pc_get_max_banks
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204df67c	inet6_getname
++EXPORT_SYMBOL vmlinux 0x2056a913	scsi_adjust_queue_depth
++EXPORT_SYMBOL vmlinux 0x20573f34	netlink_ack
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x207ce5d6	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x208786a0	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x20a0e2f5	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20abc15b	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0x20b065f9	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20da4e77	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x20dabb37	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x20eadeb6	ip_compute_csum
++EXPORT_SYMBOL vmlinux 0x20ecf5c1	dev_printk
++EXPORT_SYMBOL vmlinux 0x20f8b540	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x210933d1	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0x211851cb	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x21315700	param_get_bool
++EXPORT_SYMBOL vmlinux 0x21355226	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x2155bb32	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x215ebd78	bitrev16
++EXPORT_SYMBOL vmlinux 0x216ab189	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x2173179b	request_key_async
++EXPORT_SYMBOL vmlinux 0x217ad790	bio_split
++EXPORT_SYMBOL vmlinux 0x217dda13	flex_array_get
++EXPORT_SYMBOL vmlinux 0x21a9b22b	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x21bd29ae	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x21e0ea22	acpi_get_id
++EXPORT_SYMBOL vmlinux 0x21f5d0da	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x220cd71e	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x223669ac	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0x223f0a60	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x22404d1c	dquot_disable
++EXPORT_SYMBOL vmlinux 0x2250944d	simple_write_begin
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2289042b	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x22a07d0c	sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x22a4affe	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x22aa5ed3	__locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22ba5855	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x22ce28ad	con_is_bound
++EXPORT_SYMBOL vmlinux 0x22d2f451	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x22d5939c	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x22eb99f5	journal_destroy
++EXPORT_SYMBOL vmlinux 0x22f254ac	fget_raw
++EXPORT_SYMBOL vmlinux 0x22fd9ad0	sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x23027c07	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x23101797	bio_integrity_set_tag
++EXPORT_SYMBOL vmlinux 0x2314d4a2	page_put_link
++EXPORT_SYMBOL vmlinux 0x2316cadc	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x23532c4d	ftrace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x2358c2f5	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0x2363c52b	request_key
++EXPORT_SYMBOL vmlinux 0x238588c9	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b8bc0a	__dst_free
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23c9891c	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x23f77991	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x24070d3d	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x240bd54c	generic_pipe_buf_unmap
++EXPORT_SYMBOL vmlinux 0x24182c1e	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x241f50a6	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x2429a3d4	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2484adc3	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0x2485a6d9	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x24872583	compat_ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x248c273b	ida_remove
++EXPORT_SYMBOL vmlinux 0x249eb5a1	soft_cursor
++EXPORT_SYMBOL vmlinux 0x24bdc7e2	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x24d215b9	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x2511e212	mnt_unpin
++EXPORT_SYMBOL vmlinux 0x251cbdee	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x2526dc31	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x253bdb78	param_get_int
++EXPORT_SYMBOL vmlinux 0x253c0df2	mmc_cache_ctrl
++EXPORT_SYMBOL vmlinux 0x253f7d6f	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x2573c1d2	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x2575d4a1	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x259fce79	try_module_get
++EXPORT_SYMBOL vmlinux 0x25be378c	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x25c677c4	mac_pton
++EXPORT_SYMBOL vmlinux 0x25d614ab	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x25d6c348	eth_header
++EXPORT_SYMBOL vmlinux 0x25f26151	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0x25fb5c44	acpi_bus_hot_remove_device
++EXPORT_SYMBOL vmlinux 0x25ffd91d	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x260c1b2b	scsi_put_command
++EXPORT_SYMBOL vmlinux 0x263122f8	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x2665d53a	key_create_or_update
++EXPORT_SYMBOL vmlinux 0x266b975f	tty_name
++EXPORT_SYMBOL vmlinux 0x2679dd8b	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x267c61f1	vfs_link
++EXPORT_SYMBOL vmlinux 0x2685c3d7	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x2693b021	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x26948d96	copy_user_enhanced_fast_string
++EXPORT_SYMBOL vmlinux 0x26a36c52	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x26b71392	netdev_printk
++EXPORT_SYMBOL vmlinux 0x26e298e0	unregister_memory_notifier
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f0453a	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x2700522c	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x27160f7d	dqget
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x2725907d	tty_lock
++EXPORT_SYMBOL vmlinux 0x2727f53f	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x272d394e	mtrr_del
++EXPORT_SYMBOL vmlinux 0x27415fcd	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL vmlinux 0x274a4a34	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x2761b692	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x276b4d4a	pci_disable_obff
++EXPORT_SYMBOL vmlinux 0x276d4726	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x27810361	acpi_os_wait_events_complete
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x2788fd5f	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c2197f	param_set_short
++EXPORT_SYMBOL vmlinux 0x27c33efe	csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x27ca9604	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x27d30f9c	pci_enable_msi_block_auto
++EXPORT_SYMBOL vmlinux 0x27dfe615	register_key_type
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27ecd8d2	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x27fbade6	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x28086cec	tcp_poll
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x28318305	snprintf
++EXPORT_SYMBOL vmlinux 0x2840c8c2	abort_creds
++EXPORT_SYMBOL vmlinux 0x284c6d4c	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x2857ad8c	tty_port_init
++EXPORT_SYMBOL vmlinux 0x28699ca9	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x288de0bd	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28abfe6e	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x28ac5639	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x28ec61fa	amd_northbridges
++EXPORT_SYMBOL vmlinux 0x28f020e2	netdev_change_features
++EXPORT_SYMBOL vmlinux 0x291b252a	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x2924a7f8	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x2926228e	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2983f8cf	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x298532db	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x298a35dc	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0x299c1ddc	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x29dd88ea	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x29f192bd	inet_bind
++EXPORT_SYMBOL vmlinux 0x29f41ee8	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x29fb78ce	amd_iommu_device_info
++EXPORT_SYMBOL vmlinux 0x2a00799a	alloc_file
++EXPORT_SYMBOL vmlinux 0x2a13e22c	send_sig_info
++EXPORT_SYMBOL vmlinux 0x2a28c0a4	fasync_helper
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a415b1e	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x2a598a65	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x2a6671ac	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x2a6e6109	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x2a79ac13	clkdev_add
++EXPORT_SYMBOL vmlinux 0x2a7b4a83	d_instantiate
++EXPORT_SYMBOL vmlinux 0x2a89ab9d	dev_warn
++EXPORT_SYMBOL vmlinux 0x2aa3b949	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x2ab82db9	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x2add0f66	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x2add4d5f	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x2b0600ef	filp_open
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b13b489	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b400437	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x2b51837e	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x2b650850	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x2b7876ef	scsi_finish_command
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bcb471d	load_nls
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2bfeed14	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x2c0a1dfb	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2d0475	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x2c2ed1ae	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x2c33cc2c	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x2c725c9c	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x2c75c273	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x2c79aef7	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x2c8222be	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x2c86d864	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0x2c900d91	cpufreq_put_global_kobject
++EXPORT_SYMBOL vmlinux 0x2c90bd84	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x2ca10463	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x2cb9b101	blk_get_request
++EXPORT_SYMBOL vmlinux 0x2cd84056	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x2cf73cb7	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x2d015b72	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x2d01d97f	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x2d09d0bf	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d2861e3	path_put
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d48c5a6	ps2_command
++EXPORT_SYMBOL vmlinux 0x2d683f2d	tcf_generic_walker
++EXPORT_SYMBOL vmlinux 0x2d727c6e	spi_display_xfer_agreement
++EXPORT_SYMBOL vmlinux 0x2d89342a	scsi_show_sense_hdr
++EXPORT_SYMBOL vmlinux 0x2d9b4f94	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x2da12f7c	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x2db01abe	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2deda4a1	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2e043efe	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x2e072266	mmc_gpio_free_cd
++EXPORT_SYMBOL vmlinux 0x2e0d2f7f	queue_work_on
++EXPORT_SYMBOL vmlinux 0x2e14a9f7	release_sock
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e1eab01	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x2e1fd766	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0x2e245bf7	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x2e2b40d2	strncat
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e3d2801	scsi_get_command
++EXPORT_SYMBOL vmlinux 0x2e5a704c	udp_table
++EXPORT_SYMBOL vmlinux 0x2e5fbece	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x2e7cc2a1	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x2e952182	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x2ea65914	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x2eb28be7	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x2eda8d41	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x2edf720c	bio_put
++EXPORT_SYMBOL vmlinux 0x2eeceb42	sk_chk_filter
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f02f628	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f52bc11	kernel_bind
++EXPORT_SYMBOL vmlinux 0x2f54d6fd	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x2f952f83	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x2f96156d	unlazy_fpu
++EXPORT_SYMBOL vmlinux 0x2f9d39c6	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x2fab86b0	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x2fb3750c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x2fb43771	alloc_disk
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fc18e62	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x2fc37b74	d_genocide
++EXPORT_SYMBOL vmlinux 0x2fd627e5	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff063b5	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x301d3061	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x302f95a7	lock_rename
++EXPORT_SYMBOL vmlinux 0x3039e72a	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x305e0031	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0x306c5878	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3089a479	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x308c946e	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x308e74fd	i8042_check_port_owner
++EXPORT_SYMBOL vmlinux 0x309bb7c5	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30aebbe2	dev_notice
++EXPORT_SYMBOL vmlinux 0x30b09d8b	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x30c9dc33	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x30cada8f	radix_tree_next_hole
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30f32ea5	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x313d6fee	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x314deecf	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x315513e0	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x317927eb	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x318cadb1	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x319e0726	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x319f5368	dma_async_memcpy_buf_to_buf
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31b74dc7	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x31c30159	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31ed1403	bio_endio
++EXPORT_SYMBOL vmlinux 0x31f1b7f1	kfree_skb
++EXPORT_SYMBOL vmlinux 0x31feb5f8	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x3210b159	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x322f48d4	abx500_dump_all_banks
++EXPORT_SYMBOL vmlinux 0x324792f7	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x324bf870	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x324ede8f	simple_setattr
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x3274b08e	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x327e6098	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x32a945da	journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x32aa0346	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x32bb04c8	from_kqid
++EXPORT_SYMBOL vmlinux 0x32debb16	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x32e30fcf	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x32e6efb1	journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x32eeaded	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x33145044	misc_deregister
++EXPORT_SYMBOL vmlinux 0x3319973e	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x332b2e93	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0x333cb37c	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x33411bd1	alloc_pci_dev
++EXPORT_SYMBOL vmlinux 0x334c0791	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x336b2ba3	compat_mc_getsockopt
++EXPORT_SYMBOL vmlinux 0x33959bb0	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x33a6dd4d	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0x33ac417f	acpi_os_hotplug_execute
++EXPORT_SYMBOL vmlinux 0x33b84f74	copy_page
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x33fcf44a	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0x34184afe	current_kernel_time
++EXPORT_SYMBOL vmlinux 0x341cbed2	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x343b2f7a	__scsi_put_command
++EXPORT_SYMBOL vmlinux 0x343f0db5	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x344e9af4	__idr_get_new_above
++EXPORT_SYMBOL vmlinux 0x346c7121	dev_set_drvdata
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x3475ba2a	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x3494e32a	touch_atime
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34ab0ae5	dput
++EXPORT_SYMBOL vmlinux 0x34e21dc0	register_sysctl
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x35144fa7	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x35182938	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0x351ea955	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x35225ea3	down_write_trylock
++EXPORT_SYMBOL vmlinux 0x3539f11b	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x3549824f	iget_locked
++EXPORT_SYMBOL vmlinux 0x35515c6c	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x3568b743	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x35709ea4	__page_symlink
++EXPORT_SYMBOL vmlinux 0x357af0f4	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0x35b6b772	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x35c6a2a0	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x35ca823c	vfs_write
++EXPORT_SYMBOL vmlinux 0x35cce9fc	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x35defc50	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x35fde0f4	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360b8d16	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x361371a5	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x3623a347	tty_devnum
++EXPORT_SYMBOL vmlinux 0x36475ada	register_filesystem
++EXPORT_SYMBOL vmlinux 0x364b6240	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x36864668	__genl_register_family_with_ops
++EXPORT_SYMBOL vmlinux 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL vmlinux 0x368b0fa6	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0x369e1115	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x36a5eda0	__dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x36bf0ea1	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x36c5ea4f	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x36e360e3	__hw_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x36eea68c	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x36f9cd94	rcu_is_cpu_idle
++EXPORT_SYMBOL vmlinux 0x3701a196	csum_partial_copy_to_user
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x374693df	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x3749c047	tty_unlock_pair
++EXPORT_SYMBOL vmlinux 0x3768a16d	compat_sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x3769bf03	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x376e4695	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x376e5fb6	netpoll_rx_disable
++EXPORT_SYMBOL vmlinux 0x37728e7b	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x37843795	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x379ddcc5	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x379e6d21	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x37b6dd5f	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x37b777df	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37cd42c8	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37e2b67f	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x37ef710f	single_open_size
++EXPORT_SYMBOL vmlinux 0x37ff4c06	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x3804303e	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x380af2bd	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x382043a2	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x38208bae	do_splice_from
++EXPORT_SYMBOL vmlinux 0x38218972	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x383c3900	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x388125a9	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388f9128	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x389bfe0d	rtc_lock
++EXPORT_SYMBOL vmlinux 0x389e8ae1	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38b1c10a	do_splice_to
++EXPORT_SYMBOL vmlinux 0x38d285c5	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x38f33bed	dump_fpu
++EXPORT_SYMBOL vmlinux 0x38f3724f	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x38fe5ccd	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x39123e72	__lock_buffer
++EXPORT_SYMBOL vmlinux 0x3928efe9	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x3949eea2	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x3955fcf6	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x395e8620	ns_capable
++EXPORT_SYMBOL vmlinux 0x397f733a	__block_write_begin
++EXPORT_SYMBOL vmlinux 0x399ad043	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39bb372f	dq_data_lock
++EXPORT_SYMBOL vmlinux 0x39cb2a02	call_netdevice_notifiers_info
++EXPORT_SYMBOL vmlinux 0x39d24405	generic_file_buffered_write
++EXPORT_SYMBOL vmlinux 0x39f172ed	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a20ff73	__crc32c_le
++EXPORT_SYMBOL vmlinux 0x3a26c6ab	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a3f62dd	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x3a426df2	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x3a44c0f8	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x3a521152	register_nls
++EXPORT_SYMBOL vmlinux 0x3a755444	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x3a82e039	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3ac33c39	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x3ad1e5d9	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x3ad8206b	journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x3ad8f652	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0x3b2c6929	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x3b34bb70	dma_ops
++EXPORT_SYMBOL vmlinux 0x3b4ceb4a	up_write
++EXPORT_SYMBOL vmlinux 0x3b5a416a	wait_on_sync_kiocb
++EXPORT_SYMBOL vmlinux 0x3b64cf7e	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x3ba7bc4b	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x3ba7defb	kthread_bind
++EXPORT_SYMBOL vmlinux 0x3bc9cfd7	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x3bd1b1f6	msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x3bd754bf	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x3beb690b	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x3bef03b9	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x3c348b0f	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x3c3513c9	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x3c378795	flush_signals
++EXPORT_SYMBOL vmlinux 0x3c421e4e	km_state_expired
++EXPORT_SYMBOL vmlinux 0x3c57999a	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c9d1211	string_get_size
++EXPORT_SYMBOL vmlinux 0x3c9e8eaf	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x3cadff93	d_delete
++EXPORT_SYMBOL vmlinux 0x3cc0e746	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0x3cd48632	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3d21e81c	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x3d22f70a	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x3d33d4ab	compat_mc_setsockopt
++EXPORT_SYMBOL vmlinux 0x3d36475a	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x3d41c9c9	vfs_readlink
++EXPORT_SYMBOL vmlinux 0x3d5844b3	strnicmp
++EXPORT_SYMBOL vmlinux 0x3d6a92a8	check_disk_change
++EXPORT_SYMBOL vmlinux 0x3d6ab7e0	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3d9ee9f0	clear_page
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3dc501fa	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e0329b1	read_cache_page_async
++EXPORT_SYMBOL vmlinux 0x3e041763	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x3e2332be	arp_send
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e63263b	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x3e6d713f	follow_down_one
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e8a077b	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3e990c11	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x3ea0773c	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x3eae292f	param_set_byte
++EXPORT_SYMBOL vmlinux 0x3eaf291d	param_get_string
++EXPORT_SYMBOL vmlinux 0x3ec16c3b	in_group_p
++EXPORT_SYMBOL vmlinux 0x3ed63055	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0x3ed9d052	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x3ee274a9	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f26d183	arp_invalidate
++EXPORT_SYMBOL vmlinux 0x3f386fb1	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f7112ac	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x3f71faa1	mempool_create
++EXPORT_SYMBOL vmlinux 0x3f995caa	drop_nlink
++EXPORT_SYMBOL vmlinux 0x3fe2ccbe	memweight
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff62317	local_bh_disable
++EXPORT_SYMBOL vmlinux 0x3ff7b948	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x40256835	complete_all
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4037dd51	find_or_create_page
++EXPORT_SYMBOL vmlinux 0x403de1ec	clk_get
++EXPORT_SYMBOL vmlinux 0x405af52d	tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x4077baae	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x407bc0b2	set_bh_page
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a7fdb6	input_free_device
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40b4d219	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c1e77d	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x40c54b07	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40e407ea	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x40fa5176	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x411b8ac0	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x41247b1e	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x4125d762	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x41390db0	sock_i_uid
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4158d388	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0x416cb0e2	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x416d7d7f	phy_scan_fixups
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x4189b0a9	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x418ddf15	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x41a87422	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x41b57f24	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x41ebc0ac	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x41ebd2a7	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x41f128f5	journal_restart
++EXPORT_SYMBOL vmlinux 0x4211c3c1	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x422760d0	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x4260e43b	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x426729b9	netdev_alert
++EXPORT_SYMBOL vmlinux 0x4268c0df	elevator_change
++EXPORT_SYMBOL vmlinux 0x4268f303	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x4273e881	audit_log
++EXPORT_SYMBOL vmlinux 0x4275485d	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x427a25d9	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x428f24f9	posix_acl_create
++EXPORT_SYMBOL vmlinux 0x42977ad4	__hw_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42c9097b	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x42ef4059	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4310e642	empty_aops
++EXPORT_SYMBOL vmlinux 0x43111970	pm860x_page_reg_read
++EXPORT_SYMBOL vmlinux 0x4324d866	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x43261dca	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x432913f5	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x432fe55d	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x434057a6	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x43717329	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x437d822a	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43c102a7	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x43c443f7	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x43c9bde5	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x4404e411	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x4469b9d5	unregister_exec_domain
++EXPORT_SYMBOL vmlinux 0x446fc540	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x4470a79b	param_ops_long
++EXPORT_SYMBOL vmlinux 0x44752b36	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x4476e9e2	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x4489b07d	phy_detach
++EXPORT_SYMBOL vmlinux 0x448eac3e	kmemdup
++EXPORT_SYMBOL vmlinux 0x44974ad4	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x449ad0a7	memcmp
++EXPORT_SYMBOL vmlinux 0x44a81d5f	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0x44aa6f37	tcp_valid_rtt_meas
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44c2fc8d	start_tty
++EXPORT_SYMBOL vmlinux 0x44d4e3d6	sock_wfree
++EXPORT_SYMBOL vmlinux 0x44dbed2e	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x44e378fb	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x44e6ecc8	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x44e7ce7a	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x45044497	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x450935d1	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x450ace85	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x45109837	kern_path
++EXPORT_SYMBOL vmlinux 0x4510ddc9	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x4532e184	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x45379976	dev_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x455468ec	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x456c79e7	skb_unlink
++EXPORT_SYMBOL vmlinux 0x45770849	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x458aef14	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x458d3236	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x459c6076	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x45a63493	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x45a6be13	cpufreq_sysfs_remove_file
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45c2bc24	filemap_flush
++EXPORT_SYMBOL vmlinux 0x45c44a53	fib_default_rule_pref
++EXPORT_SYMBOL vmlinux 0x45c8cd86	ifla_policy
++EXPORT_SYMBOL vmlinux 0x45c92723	idr_destroy
++EXPORT_SYMBOL vmlinux 0x45e85570	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0x45f5d49e	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x45fde23e	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x4601a766	kernel_accept
++EXPORT_SYMBOL vmlinux 0x46105317	clocksource_register
++EXPORT_SYMBOL vmlinux 0x461ac773	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x461efb86	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x46313adc	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x4638087b	tty_write_room
++EXPORT_SYMBOL vmlinux 0x464fda19	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x4651d69d	sock_create
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x465e9c0f	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0x46608fa0	getnstimeofday
++EXPORT_SYMBOL vmlinux 0x4669bb79	set_security_override
++EXPORT_SYMBOL vmlinux 0x4669bddc	iput
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x46c47fb6	__node_distance
++EXPORT_SYMBOL vmlinux 0x46d73dca	icmp_send
++EXPORT_SYMBOL vmlinux 0x46daee4b	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x46ee3057	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4704af4b	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x4723a285	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x475100c2	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x4755a55d	mount_bdev
++EXPORT_SYMBOL vmlinux 0x475ef419	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x47660378	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x476d825c	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x477e6dcb	amd_iommu_pc_get_set_reg_val
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x479c9e22	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x47a0f447	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x47b0355c	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x47b3f862	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0x47b6a10f	ftrace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x47cabb96	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x47eb351d	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x4817fba3	lro_receive_frags
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x4841bdee	strnchr
++EXPORT_SYMBOL vmlinux 0x4845c423	param_array_ops
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x486926fd	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x487d5c77	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x487d9343	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x4889bf73	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x48c30b5f	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x48d50e79	amd_iommu_register_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x48d8210e	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x48de07f7	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x493dd873	input_register_handler
++EXPORT_SYMBOL vmlinux 0x494a5ec4	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x494e3393	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49b00721	read_code
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x4a162e95	bio_init
++EXPORT_SYMBOL vmlinux 0x4a358252	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x4a39e29a	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x4a6bb3b3	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x4a72c9fb	fail_migrate_page
++EXPORT_SYMBOL vmlinux 0x4a9cd35b	seq_read
++EXPORT_SYMBOL vmlinux 0x4aac9740	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x4aad52d7	mempool_free
++EXPORT_SYMBOL vmlinux 0x4ab688ec	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4ac799f5	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4ae061e3	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b06d2e7	complete
++EXPORT_SYMBOL vmlinux 0x4b070442	user_path_create
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b1b96ae	key_put
++EXPORT_SYMBOL vmlinux 0x4b29cb65	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0x4b2ce2d4	vc_resize
++EXPORT_SYMBOL vmlinux 0x4b3890d9	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x4b3c4477	dma_set_mask
++EXPORT_SYMBOL vmlinux 0x4b3df787	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b799e43	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x4baca6f2	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0x4baf6fb8	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x4bafbf70	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x4bdc1dec	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x4c1182cb	bitmap_scnprintf
++EXPORT_SYMBOL vmlinux 0x4c1ea0f1	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x4c2c5e1a	kernel_write
++EXPORT_SYMBOL vmlinux 0x4c2de2c6	compat_ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x4c4fef19	kernel_stack
++EXPORT_SYMBOL vmlinux 0x4c51ceaf	scsi_allocate_command
++EXPORT_SYMBOL vmlinux 0x4c528802	skb_copy_and_csum_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x4c5fb0d6	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x4c73b8d6	mddev_congested
++EXPORT_SYMBOL vmlinux 0x4c914292	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x4c9d28b0	phys_base
++EXPORT_SYMBOL vmlinux 0x4c9e7c1f	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x4ca00cda	release_firmware
++EXPORT_SYMBOL vmlinux 0x4ca10be8	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x4ca31ced	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x4ca9669f	scnprintf
++EXPORT_SYMBOL vmlinux 0x4cb1122a	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x4cbbd171	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x4cbd4f9a	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x4cc03be7	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cde8b09	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x4cf939db	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x4d0415c5	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x4d1023f8	mempool_resize
++EXPORT_SYMBOL vmlinux 0x4d2e1376	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x4d2f43b7	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x4d405db8	param_ops_string
++EXPORT_SYMBOL vmlinux 0x4d88e8d8	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4da89c44	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0x4daa360a	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0x4dc6c6c7	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x4dd6c59e	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df656cc	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x4df6de66	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x4df9dc65	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x4e0f2137	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0x4e1db6ff	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3ac15b	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x4e3cc45e	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x4e42ef59	scsi_free_command
++EXPORT_SYMBOL vmlinux 0x4e4a8786	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e9c7cef	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4eb39c5f	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x4ec603c4	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x4edd72f7	block_all_signals
++EXPORT_SYMBOL vmlinux 0x4eef55f5	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x4efb091e	tcp_tso_segment
++EXPORT_SYMBOL vmlinux 0x4efcef22	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f20342a	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x4f360e0e	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f3b4f48	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x4f408650	unload_nls
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f4932e0	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x4f498e95	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6b400b	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x4f72a6fe	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f8b5ddb	_copy_to_user
++EXPORT_SYMBOL vmlinux 0x4f94f1ba	idr_get_next
++EXPORT_SYMBOL vmlinux 0x4faec360	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x502b0287	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x503ba93e	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x505b7e01	tcp_syn_flood_action
++EXPORT_SYMBOL vmlinux 0x506f4cc1	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x509b0783	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x50a90e8d	bsearch
++EXPORT_SYMBOL vmlinux 0x50a9fed8	arp_find
++EXPORT_SYMBOL vmlinux 0x50b19ca3	journal_ack_err
++EXPORT_SYMBOL vmlinux 0x50d2592d	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0x50d647e4	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50e0425d	arp_create
++EXPORT_SYMBOL vmlinux 0x50e4e4ed	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x511ab427	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x51259587	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x512b7c7f	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x5143c678	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x51441aeb	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x5182420f	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x51aae676	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x51b0a0d0	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x51bb55fd	dst_discard
++EXPORT_SYMBOL vmlinux 0x51c55710	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51dce73b	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x51e42cdb	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x52006d56	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x52130046	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0x521b23a6	seq_release
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x522f166c	pnp_is_active
++EXPORT_SYMBOL vmlinux 0x52428cc8	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x527b11e4	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x5289f035	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x528dbd76	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x52a66fc0	may_umount
++EXPORT_SYMBOL vmlinux 0x52bdf743	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x52cf2dea	__lock_page
++EXPORT_SYMBOL vmlinux 0x52d42c95	set_current_groups
++EXPORT_SYMBOL vmlinux 0x52dd2f1b	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x52fa1af8	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5340e925	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x53466536	tc_classify
++EXPORT_SYMBOL vmlinux 0x5368beb1	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x536b9970	generic_permission
++EXPORT_SYMBOL vmlinux 0x5377e556	hex2bin
++EXPORT_SYMBOL vmlinux 0x5392a9a3	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x53aa0883	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x53d34b7a	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x53d4939e	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x53f14d50	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x53f6ffbc	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x53f9d27a	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x54059a2a	amd_iommu_pc_get_max_counters
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x54113402	lock_may_read
++EXPORT_SYMBOL vmlinux 0x54245b39	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0x5435ed3b	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x543ac83e	write_inode_now
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x5440e6f3	journal_forget
++EXPORT_SYMBOL vmlinux 0x5442a14c	agp_enable
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x54554948	kobject_put
++EXPORT_SYMBOL vmlinux 0x545f5f56	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x54680e1e	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54de232d	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54e9c983	compat_ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x54efb5d6	cpu_number
++EXPORT_SYMBOL vmlinux 0x54f21cff	__send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x552d90fa	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x55333d82	keyring_clear
++EXPORT_SYMBOL vmlinux 0x553d9a7d	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x55671680	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5594be03	bitmap_remap
++EXPORT_SYMBOL vmlinux 0x55ccd4d2	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x55df0724	inet_listen
++EXPORT_SYMBOL vmlinux 0x55eeb83d	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0x55f5019b	__kmalloc_node
++EXPORT_SYMBOL vmlinux 0x56060638	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x560ffb71	tcf_hash_lookup
++EXPORT_SYMBOL vmlinux 0x5612255b	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x5614b010	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x561f44f4	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x5634ea7f	genphy_update_link
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x5642793a	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x565572ec	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x56978303	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x569ee328	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56d63a2e	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x56e50eb8	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x56ef82fd	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x56fd912c	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x570a83e5	vfs_create
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x5792f848	strlcpy
++EXPORT_SYMBOL vmlinux 0x57a6ccd0	down_read
++EXPORT_SYMBOL vmlinux 0x57d14e8f	scsi_setup_blk_pc_cmnd
++EXPORT_SYMBOL vmlinux 0x57f37fc7	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x584b909c	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x5860aad4	add_wait_queue
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x586162b5	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x588fd151	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x589b632c	bmap
++EXPORT_SYMBOL vmlinux 0x58b1c3c8	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x58b518fb	mount_ns
++EXPORT_SYMBOL vmlinux 0x58c4bf53	elevator_init
++EXPORT_SYMBOL vmlinux 0x58cccde4	ip_defrag
++EXPORT_SYMBOL vmlinux 0x58ce13e7	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x58dca9ca	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x58fe4ee4	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x5916d2b7	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x593efd1b	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x5967c929	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x59759b2b	vfsmount_lock
++EXPORT_SYMBOL vmlinux 0x597b06a9	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x5982140e	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x5984af25	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x5988c1b5	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0x5991219c	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x59d40c3c	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x59d74ccc	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a521f8e	submit_bio
++EXPORT_SYMBOL vmlinux 0x5a5c87e6	console_start
++EXPORT_SYMBOL vmlinux 0x5a5d4689	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x5a7476ee	get_io_context
++EXPORT_SYMBOL vmlinux 0x5a8c9da8	acpi_video_backlight_quirks
++EXPORT_SYMBOL vmlinux 0x5a921311	strncmp
++EXPORT_SYMBOL vmlinux 0x5ac21822	irq_stat
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5ae50279	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x5aeb145f	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5b229c65	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x5b271d86	acpi_video_dmi_promote_vendor
++EXPORT_SYMBOL vmlinux 0x5b35572b	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x5b56860c	vm_munmap
++EXPORT_SYMBOL vmlinux 0x5b719eef	n_tty_compat_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x5ba02147	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x5ba53020	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x5bc10524	printk_emit
++EXPORT_SYMBOL vmlinux 0x5bd16da0	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x5be4d848	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x5bec4814	notify_change
++EXPORT_SYMBOL vmlinux 0x5c04eec2	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x5c3edd59	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x5c4431ea	twl6040_power
++EXPORT_SYMBOL vmlinux 0x5c50e246	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x5c73a45b	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x5c81578c	blk_start_request
++EXPORT_SYMBOL vmlinux 0x5c886f13	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x5c8b5ce8	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x5cae8890	bio_integrity_split
++EXPORT_SYMBOL vmlinux 0x5cdede90	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x5cefabaa	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cfa53bb	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x5d0837b4	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0x5d0b1892	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x5d1a3178	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x5d475763	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x5d5127d3	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d56314c	block_write_full_page_endio
++EXPORT_SYMBOL vmlinux 0x5d5b5a16	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x5d5d5437	splice_from_pipe_next
++EXPORT_SYMBOL vmlinux 0x5d721965	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d77eaa1	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x5d7f1585	directly_mappable_cdev_bdi
++EXPORT_SYMBOL vmlinux 0x5db86e06	dev_set_group
++EXPORT_SYMBOL vmlinux 0x5e15d54c	ida_init
++EXPORT_SYMBOL vmlinux 0x5e2ca8d8	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x5e477e49	simple_readpage
++EXPORT_SYMBOL vmlinux 0x5e4f7575	vlan_untag
++EXPORT_SYMBOL vmlinux 0x5e6df934	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x5e795e61	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ece01fc	posix_test_lock
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5eea2e20	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x5eedcb1a	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x5eff0b9d	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f0f4a4a	padata_start
++EXPORT_SYMBOL vmlinux 0x5f1eeb26	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0x5f2bfe27	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x5f2ea640	seq_printf
++EXPORT_SYMBOL vmlinux 0x5f3c8f5c	mmc_assume_removable
++EXPORT_SYMBOL vmlinux 0x5f3f0fd6	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x5f557703	acpi_evaluate_hotplug_ost
++EXPORT_SYMBOL vmlinux 0x5f58f676	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x5f5a8206	serio_close
++EXPORT_SYMBOL vmlinux 0x5f7c5ae7	skb_insert
++EXPORT_SYMBOL vmlinux 0x5f8b024d	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x5fa2e68d	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x5fb14a73	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x5fb7309e	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x5fbe1328	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x5ff42b08	acpi_video_get_capabilities
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x60230150	skb_append
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x60402af1	update_time
++EXPORT_SYMBOL vmlinux 0x6059fc21	amd_iommu_domain_set_gcr3
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x60918c2b	__d_drop
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x609f5b35	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60b4b1d6	block_write_begin
++EXPORT_SYMBOL vmlinux 0x60c5ba11	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x60f21583	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x610ff59c	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x611418e8	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x6121727d	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x612390ad	netpoll_set_trap
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x612a1abe	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x612b2b4a	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x612e55f5	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0x614383c0	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x61751fc7	aio_complete
++EXPORT_SYMBOL vmlinux 0x617643a2	param_set_long
++EXPORT_SYMBOL vmlinux 0x6188c9fb	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x618911fc	numa_node
++EXPORT_SYMBOL vmlinux 0x619cb7dd	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61d59099	md_register_thread
++EXPORT_SYMBOL vmlinux 0x61fb248a	node_states
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x623dda47	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x6256af69	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x62582314	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62748e70	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0x6277916e	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0x628121e9	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62b1425b	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x62b22819	page_symlink
++EXPORT_SYMBOL vmlinux 0x62b2c245	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x62e402ce	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x62fd6207	param_set_charp
++EXPORT_SYMBOL vmlinux 0x62fe1328	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x6301a5e4	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0x6301b9fe	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x6313b653	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x631bd687	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x63243ce9	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x63306760	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x633dd20f	no_llseek
++EXPORT_SYMBOL vmlinux 0x634bca7e	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x636bb781	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x63922bbd	vfs_stat
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63b5af54	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x63bdb040	bio_advance
++EXPORT_SYMBOL vmlinux 0x63cd0716	inet_frag_evictor
++EXPORT_SYMBOL vmlinux 0x63e35191	dev_err
++EXPORT_SYMBOL vmlinux 0x63e4b1ce	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x64005b5a	vfs_follow_link
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x640b89c6	ip_mc_rejoin_groups
++EXPORT_SYMBOL vmlinux 0x642a9cc3	bioset_free
++EXPORT_SYMBOL vmlinux 0x6449fd41	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0x6453c4a7	processors
++EXPORT_SYMBOL vmlinux 0x6459c585	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x645b4468	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x645b44b0	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x6478134c	ec_burst_enable
++EXPORT_SYMBOL vmlinux 0x647826d0	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x6485464c	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a10ddd	proto_unregister
++EXPORT_SYMBOL vmlinux 0x64bbc288	string_unescape
++EXPORT_SYMBOL vmlinux 0x64d7509a	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x64dd1392	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x64e5b0a3	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x64f85f79	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x6505d96b	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x650a6767	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x652ce9aa	nla_memcmp
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6555bdae	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0x65598d31	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x65936993	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x65b093be	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x65b0b20c	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x65c433ea	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x65d67a20	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65dd25c3	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0x65e0d6d7	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x65fbfbe7	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x6605f97f	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x6609dd56	fb_blank
++EXPORT_SYMBOL vmlinux 0x66303479	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x664b8ed6	alloc_pages_current
++EXPORT_SYMBOL vmlinux 0x666f2b40	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x6675960f	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x668da8d5	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x668e2acd	simple_link
++EXPORT_SYMBOL vmlinux 0x66a67dab	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x66c5e0f7	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x66f7be3c	scsi_execute
++EXPORT_SYMBOL vmlinux 0x66f94cc6	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x6702c81f	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x6721ec59	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x673936f7	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x674f394e	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x67602474	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x67676b93	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x67a0306a	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x67a2a048	bio_sector_offset
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67b88fbb	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x67be2dcf	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x67ca8db8	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x67d02fa4	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x67d396b0	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0x67fe0560	__napi_complete
++EXPORT_SYMBOL vmlinux 0x6825bb79	register_exec_domain
++EXPORT_SYMBOL vmlinux 0x682dbadf	sk_alloc
++EXPORT_SYMBOL vmlinux 0x68312f1a	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x685f67e7	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x68615f32	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x6866fba4	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x687692c0	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x689099e9	fd_install
++EXPORT_SYMBOL vmlinux 0x68a64354	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x68aca4ad	down
++EXPORT_SYMBOL vmlinux 0x68c65dab	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x68ca9ecd	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x68e05d57	getrawmonotonic
++EXPORT_SYMBOL vmlinux 0x691001b5	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0x6911af5b	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x6913650e	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x691578c8	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x691d5274	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x693539fe	override_creds
++EXPORT_SYMBOL vmlinux 0x69550d11	redraw_screen
++EXPORT_SYMBOL vmlinux 0x695925c7	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0x69595812	__f_setown
++EXPORT_SYMBOL vmlinux 0x695e3374	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0x6965fa79	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x699095e1	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x699847be	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69acdf38	memcpy
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69c2c8af	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x69c41aac	inet_getname
++EXPORT_SYMBOL vmlinux 0x69d38ed9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x69e27c7a	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x69f66ee1	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x69f7c773	__page_cache_alloc
++EXPORT_SYMBOL vmlinux 0x69fbc0a2	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a1fadfe	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x6a31c0d0	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x6a3872d1	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x6a5a6a0c	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5fa363	sigprocmask
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a772b12	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x6a82dea2	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x6ac8f02d	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad46edc	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6af309d0	default_llseek
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b14b8ac	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2db8ae	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b349ee5	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x6b4e7c38	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x6b640864	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6b6f18c1	pci_scan_bus_parented
++EXPORT_SYMBOL vmlinux 0x6b7589f4	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6b773baa	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x6bb32abe	__break_lease
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bd632a8	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x6bdb6b6b	pci_match_id
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6c05e8d2	input_open_device
++EXPORT_SYMBOL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL vmlinux 0x6c5101d8	percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c76e3fc	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x6c7e5ee8	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0x6c8828fb	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x6c890d05	journal_dirty_data
++EXPORT_SYMBOL vmlinux 0x6ca0a9a9	inode_init_always
++EXPORT_SYMBOL vmlinux 0x6cbc6fbe	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x6cc00ae7	release_pages
++EXPORT_SYMBOL vmlinux 0x6cda63d5	revert_creds
++EXPORT_SYMBOL vmlinux 0x6ce615ce	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x6ced6c9c	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x6cfdac26	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x6d044c26	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d0aba34	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d0f6812	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x6d1893a0	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x6d27ef64	__bitmap_empty
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d45c6e0	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x6d5f2b1e	posix_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x6d6818ff	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x6d6c4df6	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x6da40ec3	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x6dadb416	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x6dbfe9af	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x6dc33cff	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x6dd9e26c	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6e03fed4	seq_escape
++EXPORT_SYMBOL vmlinux 0x6e297a62	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x6e3fabd6	journal_create
++EXPORT_SYMBOL vmlinux 0x6e4d913e	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x6e5a513b	netdev_err
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e96b775	seq_release_private
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ea69fca	mntput
++EXPORT_SYMBOL vmlinux 0x6eafc359	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x6ebe3ed9	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x6ed5deb4	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x6ed95587	tty_port_close
++EXPORT_SYMBOL vmlinux 0x6eddd391	test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x6ef4d8a3	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x6f0c8ef5	compat_nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x6f11d1a0	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2098e1	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x6f311126	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x6f36c782	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x6f480cd3	__frontswap_test
++EXPORT_SYMBOL vmlinux 0x6f4c11f3	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x6f4c812f	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f5f11e9	proc_create_data
++EXPORT_SYMBOL vmlinux 0x6f69b8a6	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x6f6a0548	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x6f876a27	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x6f98503c	mmc_erase
++EXPORT_SYMBOL vmlinux 0x6fbe2ffa	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x6fc57bc2	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x6fc89668	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x6fc899a1	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fcf4691	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x6fcfa0a1	mount_nodev
++EXPORT_SYMBOL vmlinux 0x6fd040ec	generic_segment_checks
++EXPORT_SYMBOL vmlinux 0x6fd2f218	complete_request_key
++EXPORT_SYMBOL vmlinux 0x6fd30d04	poll_freewait
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x6ff2f673	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x6ff4cbe2	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x6ff6466e	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x7008902e	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x700aae13	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x7019deee	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x702b6c54	udplite_table
++EXPORT_SYMBOL vmlinux 0x703b4352	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x70434005	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x707dce7d	freeze_super
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70a59a25	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0x70ab869f	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x70bc17d7	inode_wait
++EXPORT_SYMBOL vmlinux 0x70d053fd	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70eb5011	amd_iommu_domain_direct_map
++EXPORT_SYMBOL vmlinux 0x70fa655c	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x70ff2f3b	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x7139bd09	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x713b30c7	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x71630664	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x716422d5	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x716f974b	phy_device_free
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71763632	mnt_pin
++EXPORT_SYMBOL vmlinux 0x717c1193	sk_release_kernel
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71b521f9	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x71e3cecb	up
++EXPORT_SYMBOL vmlinux 0x71e7036e	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x71ef13e7	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x71f59e7e	generic_file_splice_write
++EXPORT_SYMBOL vmlinux 0x72120831	path_is_under
++EXPORT_SYMBOL vmlinux 0x72a0d430	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x72a0fc05	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x72a98fdb	copy_user_generic_unrolled
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72b547de	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x72bf2140	mtrr_add
++EXPORT_SYMBOL vmlinux 0x72ddafe2	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72f3aa32	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0x7303a2b5	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x7306482e	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x73371fe7	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x734a298a	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x735906ac	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x737de5e9	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x73825145	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x7386e80d	blk_make_request
++EXPORT_SYMBOL vmlinux 0x739af39b	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x73a78bc4	downgrade_write
++EXPORT_SYMBOL vmlinux 0x73b4e2fc	generic_writepages
++EXPORT_SYMBOL vmlinux 0x73be8535	x86_hyper_xen_hvm
++EXPORT_SYMBOL vmlinux 0x73cea90d	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x73d7f84b	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x73e3561b	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x73efa7fe	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x73f6af8d	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x740509b5	sock_register
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x7469fcfe	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74d05c4c	set_device_ro
++EXPORT_SYMBOL vmlinux 0x74d0f9a8	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x750389ec	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x75057c31	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x7532588a	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x754b549b	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x754d539c	strlen
++EXPORT_SYMBOL vmlinux 0x754dac78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0x755a2ce7	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x755a3792	scsi_release_buffers
++EXPORT_SYMBOL vmlinux 0x7569fa4d	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x7582f278	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x7589c72e	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x759ac6ef	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x75a1715b	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x75b1f1fb	kobject_get
++EXPORT_SYMBOL vmlinux 0x75bbab91	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75db9e87	d_alloc
++EXPORT_SYMBOL vmlinux 0x75fbdefd	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x7628f3c7	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x762b66eb	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x763d1e29	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x763e09b0	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x765ff474	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x767dd8fd	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x76869ac8	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0x7687da15	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x7687f53d	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0x76bf656d	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x76c26f00	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0x76c8b1b7	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76d54da3	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x76e0d40b	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x76e6ed99	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x76fb08a7	amd_iommu_unregister_ppr_notifier
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x77267e5f	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x7728ff40	sk_reset_txq
++EXPORT_SYMBOL vmlinux 0x77375bf7	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x773a9c94	blk_iopoll_enabled
++EXPORT_SYMBOL vmlinux 0x773d454e	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0x773fa409	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x7768e228	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c8433e	dev_crit
++EXPORT_SYMBOL vmlinux 0x77ce93b3	qid_lt
++EXPORT_SYMBOL vmlinux 0x77d7068e	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x77d9eb20	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x77df0847	__set_personality
++EXPORT_SYMBOL vmlinux 0x77ecac9f	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x77f53abc	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x780d560e	spi_release_transport
++EXPORT_SYMBOL vmlinux 0x780eb3d5	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x7826bde3	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x78303ea1	current_task
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x7846af3e	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x786201c5	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x78764f4e	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x78826204	input_inject_event
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78b570ad	vga_put
++EXPORT_SYMBOL vmlinux 0x78bb3e24	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0x78ccbb67	generic_write_sync
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e6e112	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x78f1c705	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x78f4c262	security_path_rename
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x790f1b45	pci_set_master
++EXPORT_SYMBOL vmlinux 0x7927f1a9	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x79461485	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0x796ecb3b	dev_open
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7978d514	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x797c8fa9	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x797e841e	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x7984eefc	key_update
++EXPORT_SYMBOL vmlinux 0x798c1c9c	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x79945d9f	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x79a38e61	___ratelimit
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79ad98a2	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x79be4535	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0x79d8be26	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x79e03888	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x79e28534	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x79e83dec	inet_frags_init_net
++EXPORT_SYMBOL vmlinux 0x79fb5ff3	napi_complete
++EXPORT_SYMBOL vmlinux 0x7a11b972	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x7a188791	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x7a27c184	ewma_init
++EXPORT_SYMBOL vmlinux 0x7a3e7a60	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a49b6f4	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x7a5635d2	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x7a5f47a2	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x7a7db70b	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x7a85b46b	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x7a91726b	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x7a925833	cpufreq_get_global_kobject
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad41bf9	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x7ae3dc6f	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0x7aeb2b71	pm860x_page_set_bits
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7b03848a	verify_mem_not_deleted
++EXPORT_SYMBOL vmlinux 0x7b2aef6c	__krealloc
++EXPORT_SYMBOL vmlinux 0x7b526448	netdev_warn
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b533b40	load_nls_default
++EXPORT_SYMBOL vmlinux 0x7b784267	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x7b90b079	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x7b94b94c	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x7b953d81	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x7b9a6116	intel_agp_enabled
++EXPORT_SYMBOL vmlinux 0x7bae8f1f	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0x7bea1a1b	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c2d098f	krealloc
++EXPORT_SYMBOL vmlinux 0x7c3bb95d	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61096e	ip_fragment
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c7d90c0	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x7ca46555	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x7cac069d	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cb4943c	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0x7cbf7081	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x7cc2b8eb	secpath_dup
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf3a16b	put_cmsg
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d3420dc	single_release
++EXPORT_SYMBOL vmlinux 0x7d60bd7c	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x7d6d8c70	set_pages_nx
++EXPORT_SYMBOL vmlinux 0x7d7ad14a	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x7d914813	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x7d94f746	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7dc216d9	module_layout
++EXPORT_SYMBOL vmlinux 0x7dc77a83	inet_accept
++EXPORT_SYMBOL vmlinux 0x7dd554fc	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x7deaf425	do_SAK
++EXPORT_SYMBOL vmlinux 0x7dec2947	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df94ee4	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x7dff80ee	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x7e02bd81	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x7e0d4aeb	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x7e11e053	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x7e1e08c0	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x7e2a523a	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x7e2c402e	key_invalidate
++EXPORT_SYMBOL vmlinux 0x7e2f3089	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x7e394c4e	sysctl_local_reserved_ports
++EXPORT_SYMBOL vmlinux 0x7e3a4163	update_devfreq
++EXPORT_SYMBOL vmlinux 0x7e5026c4	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x7e548184	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x7e5ec4d9	dquot_drop
++EXPORT_SYMBOL vmlinux 0x7e645207	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x7e74f450	noop_fsync
++EXPORT_SYMBOL vmlinux 0x7e936fa0	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x7eaa36e6	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0x7eabfb25	set_pages_x
++EXPORT_SYMBOL vmlinux 0x7ebf84f7	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x7eceb93b	fget
++EXPORT_SYMBOL vmlinux 0x7ed914c9	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0x7ede287b	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x7ee5e6cb	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x7f13e5c6	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f423607	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x7f564870	scsi_calculate_bounce_limit
++EXPORT_SYMBOL vmlinux 0x7f6559f3	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x7f658e80	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0x7f69cc01	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x7f761053	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0x7f96361c	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x7fa801eb	kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x7fb41043	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x7fbb6ef8	phy_start
++EXPORT_SYMBOL vmlinux 0x7fc1601c	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe38f48	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x7fe3a60e	follow_down
++EXPORT_SYMBOL vmlinux 0x7fe4e55a	phy_print_status
++EXPORT_SYMBOL vmlinux 0x801a2039	ftrace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x801ee944	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x802d0e93	crc32_le
++EXPORT_SYMBOL vmlinux 0x8069bdb1	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x806e26e1	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x80a04718	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0x80ba6397	amd_iommu_get_v2_domain
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80cdd0a4	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80de9c39	tty_pair_get_pty
++EXPORT_SYMBOL vmlinux 0x80e19783	journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x80ef839d	bio_get_nr_vecs
++EXPORT_SYMBOL vmlinux 0x80fa8e96	request_firmware
++EXPORT_SYMBOL vmlinux 0x8112df23	iget5_locked
++EXPORT_SYMBOL vmlinux 0x811896d1	vmap
++EXPORT_SYMBOL vmlinux 0x811adb18	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814e71db	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81533963	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x817cd438	dm_get_mapinfo
++EXPORT_SYMBOL vmlinux 0x81937c9a	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x819f9a88	dump_write
++EXPORT_SYMBOL vmlinux 0x81c97ae5	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x81d10f5f	trace_seq_putc
++EXPORT_SYMBOL vmlinux 0x81d51d76	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81df2dc9	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x81fa1414	scsi_setup_fs_cmnd
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x821db5a2	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x82319223	splice_from_pipe_begin
++EXPORT_SYMBOL vmlinux 0x82477240	ida_destroy
++EXPORT_SYMBOL vmlinux 0x8251bcc3	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x8260686f	bitmap_find_next_zero_area
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x8282523d	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x829d4e08	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82d21040	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x82f49a43	proc_set_user
++EXPORT_SYMBOL vmlinux 0x82fb772a	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x8308f274	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x830d88f0	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x83226e15	journal_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x8326bbd9	kthread_stop
++EXPORT_SYMBOL vmlinux 0x83291bbe	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x833ba67d	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x833d30ce	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x83426c43	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x8346aa1f	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x83579ef2	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x835f414e	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x8373f358	dst_destroy
++EXPORT_SYMBOL vmlinux 0x83a476ce	bitmap_scnlistprintf
++EXPORT_SYMBOL vmlinux 0x83c7cde5	bdi_unregister
++EXPORT_SYMBOL vmlinux 0x83c8a355	param_set_int
++EXPORT_SYMBOL vmlinux 0x83f3cdff	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x843fc8e0	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x84450027	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x844a3c57	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x8451f377	mntget
++EXPORT_SYMBOL vmlinux 0x845b22fc	d_rehash
++EXPORT_SYMBOL vmlinux 0x8480b380	init_special_inode
++EXPORT_SYMBOL vmlinux 0x8480f1dd	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x84866a21	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x8487585f	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x8489feca	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x84a7344c	ps2_drain
++EXPORT_SYMBOL vmlinux 0x84b9f151	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x84e89bf1	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x851dbe21	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x8541a319	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x8552ab4b	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x85794fa6	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x85a86f1f	dst_alloc
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85cd72c9	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x85de16a7	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85ef1b8d	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x85fc19d4	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x86034be5	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x8609684d	tty_pair_get_tty
++EXPORT_SYMBOL vmlinux 0x8624ad71	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x86274616	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x8690f62c	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x86a40578	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0x86a65664	tty_unlock
++EXPORT_SYMBOL vmlinux 0x86b6053d	filemap_fault
++EXPORT_SYMBOL vmlinux 0x86c26f93	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x86d5255f	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x86dd7dcb	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x86ec3586	amd_iommu_enable_device_erratum
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870bf928	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x8711a3e7	km_report
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x87675a1a	inet_twsk_deschedule
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87a04330	drop_super
++EXPORT_SYMBOL vmlinux 0x87a5dd5e	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x87a8da74	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87c58a96	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x87cc4271	kern_path_create
++EXPORT_SYMBOL vmlinux 0x87dc469a	mempool_create_node
++EXPORT_SYMBOL vmlinux 0x881039d0	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x88335a3e	skb_checksum
++EXPORT_SYMBOL vmlinux 0x8834396c	mod_timer
++EXPORT_SYMBOL vmlinux 0x8834967a	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x884bc219	simple_empty
++EXPORT_SYMBOL vmlinux 0x88a7b8d7	phy_device_create
++EXPORT_SYMBOL vmlinux 0x88b04e39	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0x88c40d76	dquot_enable
++EXPORT_SYMBOL vmlinux 0x88cb4380	kill_bdev
++EXPORT_SYMBOL vmlinux 0x88e2d6b2	misc_register
++EXPORT_SYMBOL vmlinux 0x88f00d18	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0x88fbff24	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x892d92a0	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x895e8835	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x8966b1d2	generic_show_options
++EXPORT_SYMBOL vmlinux 0x897473df	mktime
++EXPORT_SYMBOL vmlinux 0x8977b226	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x8984915a	fput
++EXPORT_SYMBOL vmlinux 0x89868e87	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x898c2e12	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x89988f53	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x8998959a	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89b96639	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89d66811	build_ehash_secret
++EXPORT_SYMBOL vmlinux 0x89dc1d5f	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x89e67599	__inet6_hash
++EXPORT_SYMBOL vmlinux 0x89e7d570	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a1de370	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a6af65c	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8abf11ea	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0x8ac7af50	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x8ace8ca3	groups_alloc
++EXPORT_SYMBOL vmlinux 0x8ad7f331	pci_enable_obff
++EXPORT_SYMBOL vmlinux 0x8ad8fac0	proc_set_size
++EXPORT_SYMBOL vmlinux 0x8af0e42d	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8af4740b	tcp_close
++EXPORT_SYMBOL vmlinux 0x8afaf736	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x8b05335f	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x8b0a02e5	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x8b1a7a66	pcie_aspm_enabled
++EXPORT_SYMBOL vmlinux 0x8b226a81	acpi_video_dmi_demote_vendor
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b5f4a2e	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b6e87e6	log_wait_commit
++EXPORT_SYMBOL vmlinux 0x8b8157ad	sock_update_classid
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8bc5d49c	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x8bfe8c57	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8c0a3d93	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x8c10a96e	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x8c16f186	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c4d4174	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c94bec9	set_blocksize
++EXPORT_SYMBOL vmlinux 0x8caf7824	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cd54de5	key_task_permission
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8cea32c0	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0x8ced65de	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x8d1d13cf	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x8d4a793f	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d605c2f	__put_cred
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8d947573	get_disk
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8db32a66	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x8db7b81e	amd_iommu_complete_ppr
++EXPORT_SYMBOL vmlinux 0x8dc38134	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x8de8fa11	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x8df2bd50	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x8df92f66	memchr_inv
++EXPORT_SYMBOL vmlinux 0x8dfb48cb	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x8dfeaebc	pci_target_state
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e0eaefc	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x8e16597d	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x8e28cd42	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x8e29a20d	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x8e2c05e5	current_fs_time
++EXPORT_SYMBOL vmlinux 0x8e332829	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x8e3fd6fa	fget_light
++EXPORT_SYMBOL vmlinux 0x8e602de7	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x8e908a51	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x8e977b80	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x8ea88e6e	vm_mmap
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8f03954b	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x8f1fcfc8	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x8f252d5c	tcf_hash_destroy
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f2bce37	padata_stop
++EXPORT_SYMBOL vmlinux 0x8f52a40d	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x8f53a97e	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0x8f651f51	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x8f7014a1	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x8f772f76	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x8f7a6e87	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x8f7e29ed	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x8f7edd97	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x8f93481c	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fcba5f9	sget
++EXPORT_SYMBOL vmlinux 0x8fccf572	pfifo_fast_ops
++EXPORT_SYMBOL vmlinux 0x8fe2c889	seq_putc
++EXPORT_SYMBOL vmlinux 0x8fe48b08	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x8ff97968	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x8ffa2322	single_open
++EXPORT_SYMBOL vmlinux 0x900bfa09	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x900c6ded	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x90162f7f	bdget
++EXPORT_SYMBOL vmlinux 0x90268fa3	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x9031feba	kernel_read
++EXPORT_SYMBOL vmlinux 0x903288d0	phy_attach
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x90446e8b	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x9049d2d6	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x9052f454	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0x9066b125	skb_copy
++EXPORT_SYMBOL vmlinux 0x9078be42	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x907f77c4	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x90943038	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x9094c169	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x909c4121	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x90a02983	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x90a458b7	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x90aba6d7	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x90fffaa3	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x91392c57	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x9144a8e2	ec_burst_disable
++EXPORT_SYMBOL vmlinux 0x9144b6f8	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x9166fada	strncpy
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x91752f61	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x918d51ec	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x9197ed9e	journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x9198a40f	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0x919c56e0	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0x91a3cdf4	down_timeout
++EXPORT_SYMBOL vmlinux 0x91ac822f	vscnprintf
++EXPORT_SYMBOL vmlinux 0x91afc1e7	dqput
++EXPORT_SYMBOL vmlinux 0x91e930d4	splice_from_pipe_feed
++EXPORT_SYMBOL vmlinux 0x9205953f	send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x92229d9b	generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0x922af84d	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x923a84eb	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x9240125c	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x924236ee	cdev_add
++EXPORT_SYMBOL vmlinux 0x92445fb1	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x924ad557	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x9258ef20	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x926d96df	register_netdev
++EXPORT_SYMBOL vmlinux 0x927825b5	ata_print_version
++EXPORT_SYMBOL vmlinux 0x927ec729	ilookup
++EXPORT_SYMBOL vmlinux 0x928e0e7c	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x9291cd3b	memdup_user
++EXPORT_SYMBOL vmlinux 0x9299a8b4	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92c0384f	security_path_link
++EXPORT_SYMBOL vmlinux 0x92f15462	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x92fc5f97	register_qdisc
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x93271c28	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL vmlinux 0x9327f5ce	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x933faf01	file_remove_suid
++EXPORT_SYMBOL vmlinux 0x93448c57	screen_info
++EXPORT_SYMBOL vmlinux 0x934a2668	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x9362dafe	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x939a8fdd	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x93a6e0b2	io_schedule
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93c651be	acpi_info
++EXPORT_SYMBOL vmlinux 0x93d19e29	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0x93dc99ea	compat_sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x93f3e52b	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x94032162	__quota_error
++EXPORT_SYMBOL vmlinux 0x9406b100	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x94342ea1	thaw_super
++EXPORT_SYMBOL vmlinux 0x943bb031	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x943f17dd	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x945fb4bd	seq_bitmap
++EXPORT_SYMBOL vmlinux 0x946150e5	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x94834730	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94a85a25	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x94ba4178	journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x94cd93a3	splice_from_pipe_end
++EXPORT_SYMBOL vmlinux 0x950c168c	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x9518b623	register_shrinker
++EXPORT_SYMBOL vmlinux 0x9532f21d	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x954488a4	syncookie_secret
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x9546e8a6	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x9596f73c	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0x95a2ca58	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x95a2ebce	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x95b48205	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x95f89a33	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x96764f1c	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x968b4f1d	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x969c0f35	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x96b29254	strncasecmp
++EXPORT_SYMBOL vmlinux 0x96c03aaf	dm_put_device
++EXPORT_SYMBOL vmlinux 0x96c272eb	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x96ca90dc	iterate_dir
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x9716e801	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x9725b589	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x97360470	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976c5c1b	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x97824ea4	force_sig
++EXPORT_SYMBOL vmlinux 0x97868aef	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0x9786fa23	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x97e7ebbe	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x97e8eb89	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x97f840b1	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x982807c2	simple_getattr
++EXPORT_SYMBOL vmlinux 0x9829fc11	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0x984bfddf	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x9855264e	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x987e5ff5	input_event
++EXPORT_SYMBOL vmlinux 0x9881f948	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x98ad5c11	genl_unregister_ops
++EXPORT_SYMBOL vmlinux 0x98db5410	sk_free
++EXPORT_SYMBOL vmlinux 0x98fa21b0	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x9907f182	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x99195078	vsnprintf
++EXPORT_SYMBOL vmlinux 0x9926a346	init_buffer
++EXPORT_SYMBOL vmlinux 0x9927a9f9	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996c9c7b	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x9980aee4	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x998e085c	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99a510a5	scsi_prep_fn
++EXPORT_SYMBOL vmlinux 0x99c307ca	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d3a43c	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x99daa9bf	try_offline_node
++EXPORT_SYMBOL vmlinux 0x99e27fa3	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x99f068d5	x86_cpu_to_node_map
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a231e36	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x9a4f0dc5	netdev_crit
++EXPORT_SYMBOL vmlinux 0x9a5f38ab	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x9a5ffc64	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x9a718f02	compat_ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x9a7dcc49	scsi_prep_return
++EXPORT_SYMBOL vmlinux 0x9aae7fee	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x9ad7885d	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x9ad94b0f	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x9af89f98	memcpy_fromiovec
++EXPORT_SYMBOL vmlinux 0x9b05051a	set_nlink
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b49af01	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x9b5bce9c	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x9b75cb81	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x9b7ffd39	key_link
++EXPORT_SYMBOL vmlinux 0x9b9b2db7	dst_release
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bac0001	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x9bafae80	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9bec1965	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x9bec30a5	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x9c160874	registered_fb
++EXPORT_SYMBOL vmlinux 0x9c27862e	__block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x9c35b124	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x9c3a85e6	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c531da1	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x9c722e75	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x9c91ab83	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x9c9f6645	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9ccacbc5	path_get
++EXPORT_SYMBOL vmlinux 0x9cfd56c5	scsi_print_status
++EXPORT_SYMBOL vmlinux 0x9d01c373	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x9d05f6c4	ktime_get_clocktai
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d11785f	key_revoke
++EXPORT_SYMBOL vmlinux 0x9d1a5e3a	__memcpy
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d488178	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x9d4ac82a	elevator_exit
++EXPORT_SYMBOL vmlinux 0x9d5272cc	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x9d6dbebd	kobject_init
++EXPORT_SYMBOL vmlinux 0x9d6f6c24	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x9d743920	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x9db05710	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x9dea5d62	cdev_del
++EXPORT_SYMBOL vmlinux 0x9ded188e	kobject_del
++EXPORT_SYMBOL vmlinux 0x9dfe53ab	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x9e09c43e	inet_shutdown
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e227de4	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x9e29ef0c	led_blink_set
++EXPORT_SYMBOL vmlinux 0x9e2f13c6	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e398db6	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x9e3d198f	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e50d51c	consume_skb
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e904594	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x9e9f1714	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0x9ea0ad49	__sg_free_table
++EXPORT_SYMBOL vmlinux 0x9eb3da10	new_inode
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ec5bcf8	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x9ed53ea7	generic_setlease
++EXPORT_SYMBOL vmlinux 0x9f15395b	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x9f2bdaac	__bitmap_or
++EXPORT_SYMBOL vmlinux 0x9f3cdfb7	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x9f3f910b	__sock_create
++EXPORT_SYMBOL vmlinux 0x9f427f45	dev_alert
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f46f63f	ht_create_irq
++EXPORT_SYMBOL vmlinux 0x9f4cee7c	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x9f6aca11	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x9f6e19ab	mem_section
++EXPORT_SYMBOL vmlinux 0x9f7c91cb	genl_unregister_mc_group
++EXPORT_SYMBOL vmlinux 0x9f9074ec	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9f9af552	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x9f9b1e70	vm_stat
++EXPORT_SYMBOL vmlinux 0x9fdad6eb	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fdf8668	open_exec
++EXPORT_SYMBOL vmlinux 0x9fe55f7a	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x9fe7bcc9	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa0012dcd	md_write_start
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa033cff7	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa04ccec8	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa060bcfb	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0xa07a37f0	memchr
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa0834a47	gen_pool_free
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0bb6433	pci_disable_ltr
++EXPORT_SYMBOL vmlinux 0xa0bbfe9b	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0xa0ceef51	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xa0d6b84a	dquot_get_dqinfo
++EXPORT_SYMBOL vmlinux 0xa0e6f1ad	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0fc8291	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xa0ff74d6	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa12f5bb9	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xa14315a9	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xa143af74	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0xa14e4bea	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xa14f3d8c	ewma_add
++EXPORT_SYMBOL vmlinux 0xa15860ec	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xa174d81a	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0xa17603ef	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0xa17b2323	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xa1b6f5cd	arp_xmit
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bdd2a9	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1cceebc	__find_get_block
++EXPORT_SYMBOL vmlinux 0xa1d15b92	blk_init_tags
++EXPORT_SYMBOL vmlinux 0xa1ee56e5	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0xa202a8e5	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0xa20997b2	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0xa20ce1b8	net_msg_warn
++EXPORT_SYMBOL vmlinux 0xa20e9b6c	simple_unlink
++EXPORT_SYMBOL vmlinux 0xa22891b2	arp_tbl
++EXPORT_SYMBOL vmlinux 0xa2314a53	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0xa24a6ad1	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0xa250c838	param_get_charp
++EXPORT_SYMBOL vmlinux 0xa2513535	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0xa2580bef	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xa265fb11	generic_file_remap_pages
++EXPORT_SYMBOL vmlinux 0xa26d4e73	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0xa27461df	pci_get_class
++EXPORT_SYMBOL vmlinux 0xa276873e	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0xa27c8ff3	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xa27d4e4c	dev_activate
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa28811d8	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0xa28d018d	compat_sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xa2a5fd77	inet_ehash_secret
++EXPORT_SYMBOL vmlinux 0xa2b8886b	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL vmlinux 0xa2c8c667	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xa2d8b403	__generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0xa2ed89ce	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0xa2ef34d7	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xa2f97888	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xa30703a3	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xa32116cb	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xa33d70cc	inet_sendpage
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa35de80f	ipv4_config
++EXPORT_SYMBOL vmlinux 0xa3738e71	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xa37d252e	tty_port_put
++EXPORT_SYMBOL vmlinux 0xa396ee72	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0xa39edec9	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0xa3a77c69	down_read_trylock
++EXPORT_SYMBOL vmlinux 0xa3da5bcd	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xa3f96685	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0xa3fc3d50	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0xa400159f	crc32_be
++EXPORT_SYMBOL vmlinux 0xa415c9df	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0xa421bed1	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xa4349a14	scsi_reset_provider
++EXPORT_SYMBOL vmlinux 0xa4511467	crc16
++EXPORT_SYMBOL vmlinux 0xa4588573	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xa4596ee2	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa4b0d637	mpage_writepage
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4c3ab5c	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4d7719c	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xa4ed67a7	inode_dio_done
++EXPORT_SYMBOL vmlinux 0xa4fada1b	generic_removexattr
++EXPORT_SYMBOL vmlinux 0xa50a111e	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xa50cf9d5	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xa50d0f49	netif_rx
++EXPORT_SYMBOL vmlinux 0xa51df2b4	down_killable
++EXPORT_SYMBOL vmlinux 0xa52932fe	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xa53352d6	padata_alloc
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa577a850	param_get_short
++EXPORT_SYMBOL vmlinux 0xa57f2703	dm_register_target
++EXPORT_SYMBOL vmlinux 0xa58a3166	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xa58d8220	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0xa5902488	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xa590abd1	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa59dfc19	cdev_init
++EXPORT_SYMBOL vmlinux 0xa59fcb94	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xa5c8cad6	generic_pipe_buf_map
++EXPORT_SYMBOL vmlinux 0xa5dd45f3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xa5e4f65c	__next_cpu_nr
++EXPORT_SYMBOL vmlinux 0xa5eb06f6	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xa61a1e3e	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xa6327d27	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa6715115	do_settimeofday
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa684d9a8	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xa6dbd006	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xa6e7b937	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa72a0f5b	nr_online_nodes
++EXPORT_SYMBOL vmlinux 0xa72ed9ec	mmc_try_claim_host
++EXPORT_SYMBOL vmlinux 0xa72fb92e	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0xa730faae	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa74b12a4	do_sync_read
++EXPORT_SYMBOL vmlinux 0xa75dae5e	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0xa7d0e5f1	uart_register_driver
++EXPORT_SYMBOL vmlinux 0xa7d4f754	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0xa7e127b0	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xa7ec9bcc	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xa7f8fd6f	input_set_capability
++EXPORT_SYMBOL vmlinux 0xa8232c78	strtobool
++EXPORT_SYMBOL vmlinux 0xa8346021	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa84b15f2	unlock_rename
++EXPORT_SYMBOL vmlinux 0xa85d6421	efi
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa89c9291	journal_wipe
++EXPORT_SYMBOL vmlinux 0xa8a6f639	__check_region
++EXPORT_SYMBOL vmlinux 0xa8d68abd	acpi_warning
++EXPORT_SYMBOL vmlinux 0xa8e85fc9	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90d08e0	lookup_one_len
++EXPORT_SYMBOL vmlinux 0xa916b694	strnlen
++EXPORT_SYMBOL vmlinux 0xa91b5561	acpi_video_backlight_support
++EXPORT_SYMBOL vmlinux 0xa95d3cdb	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0xa96124a9	sock_no_accept
++EXPORT_SYMBOL vmlinux 0xa966ab1d	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0xa9745fa6	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0xa9785024	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xa981fa2d	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0xa98571eb	generic_make_request
++EXPORT_SYMBOL vmlinux 0xa9877a9a	generic_file_aio_read
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9b84580	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xa9b9b351	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0xa9bd2676	__vmalloc
++EXPORT_SYMBOL vmlinux 0xa9d8f55e	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0xa9fda855	dump_trace
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa81142d	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xaa8c4f0b	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaadc283b	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0xaadd4b2e	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xaae5f224	vm_insert_page
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaaf416ea	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xab1d6cc1	param_get_long
++EXPORT_SYMBOL vmlinux 0xab246c23	input_register_handle
++EXPORT_SYMBOL vmlinux 0xab2abddf	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0xab5b4460	skb_tx_error
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab8fc264	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xabc6dd63	cpufreq_sysfs_create_file
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd0c91c	rtc_time_to_tm
++EXPORT_SYMBOL vmlinux 0xabdbe312	compat_tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xabf04ef2	free_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac2d3d05	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xac3d20e2	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xac4a5a0e	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xac58ea5e	acpi_unload_table_id
++EXPORT_SYMBOL vmlinux 0xac59530f	set_anon_super
++EXPORT_SYMBOL vmlinux 0xac7c533e	first_ec
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacae45a5	lease_modify
++EXPORT_SYMBOL vmlinux 0xacb0373f	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xacb9f269	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xaccdf604	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad01744f	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad13c689	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xad164875	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xad2a8bd2	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xad3307e6	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xad4fc883	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xad7fa8f3	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xad80f9b9	d_add_ci
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad8bc6c8	journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xadaabe1b	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0xadb5559d	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xadff2a57	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0xae129e3e	key_validate
++EXPORT_SYMBOL vmlinux 0xae24f36b	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0xae4b10de	do_truncate
++EXPORT_SYMBOL vmlinux 0xae57bb74	pci_enable_ido
++EXPORT_SYMBOL vmlinux 0xae5bff1d	dget_parent
++EXPORT_SYMBOL vmlinux 0xae65cc88	datagram_poll
++EXPORT_SYMBOL vmlinux 0xae6abf62	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xae729e59	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0xae829410	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaeb445c0	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0xaebaa154	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xaee5fd83	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xaee92cbb	cad_pid
++EXPORT_SYMBOL vmlinux 0xaf00bb85	get_gendisk
++EXPORT_SYMBOL vmlinux 0xaf232d0b	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4ad270	__nla_reserve
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xaf6ae696	kstrndup
++EXPORT_SYMBOL vmlinux 0xaf6de6c8	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0xaf91d89f	__kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xaf977423	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0xafa4cf49	genl_register_ops
++EXPORT_SYMBOL vmlinux 0xafb8c6ff	copy_user_generic_string
++EXPORT_SYMBOL vmlinux 0xafd5ff2c	amd_iommu_v2_supported
++EXPORT_SYMBOL vmlinux 0xafd7433e	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xafd886af	vfs_writev
++EXPORT_SYMBOL vmlinux 0xafea49f8	vfs_fsync
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb0770aba	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0xb07b7cb9	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b847ac	__bitmap_full
++EXPORT_SYMBOL vmlinux 0xb0d090dd	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xb0dc6014	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e602eb	memmove
++EXPORT_SYMBOL vmlinux 0xb0ffda2f	blk_limits_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb104572b	textsearch_register
++EXPORT_SYMBOL vmlinux 0xb109758a	task_tgid_nr_ns
++EXPORT_SYMBOL vmlinux 0xb11c190b	mdiobus_register
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb1311feb	get_agp_version
++EXPORT_SYMBOL vmlinux 0xb138d0bf	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0xb14c95ad	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xb15e2a0e	account_page_writeback
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb172873c	pci_dev_put
++EXPORT_SYMBOL vmlinux 0xb174deaf	journal_clear_err
++EXPORT_SYMBOL vmlinux 0xb1853abf	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0xb1954aa1	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xb19760c3	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xb1a788ef	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0xb1b42470	idr_init
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb20ecf88	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb22e0d8a	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xb258fbfd	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xb258fe85	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0xb264f8bf	f_setown
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb26c5d71	pci_find_bus
++EXPORT_SYMBOL vmlinux 0xb2723ade	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0xb2853c20	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xb2964645	block_truncate_page
++EXPORT_SYMBOL vmlinux 0xb2a9f5ea	skb_find_text
++EXPORT_SYMBOL vmlinux 0xb2b4739b	inet6_bind
++EXPORT_SYMBOL vmlinux 0xb2b7d0d3	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c341fa	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xb2d307de	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb2dfa69d	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xb2e08e7b	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xb2edc639	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb2fe7416	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xb305bba9	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xb30f2032	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xb31bb9f1	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xb31ee4df	log_start_commit
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb348c12a	dquot_commit
++EXPORT_SYMBOL vmlinux 0xb34d4c2e	acpi_terminate
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb36378e4	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xb3aec17e	agp_bridge
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4290cf4	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xb43a5a25	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0xb4490f04	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xb44e4dc9	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0xb46c1d29	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xb4701c46	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb47189b5	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xb47ea5bd	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xb49d41a7	tcp_connect
++EXPORT_SYMBOL vmlinux 0xb4c9bc4f	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xb4c9c360	netdev_features_change
++EXPORT_SYMBOL vmlinux 0xb4d9904e	add_disk
++EXPORT_SYMBOL vmlinux 0xb4da318d	security_path_chown
++EXPORT_SYMBOL vmlinux 0xb4da7a58	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xb4e818dd	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xb4e8fed5	mdiobus_free
++EXPORT_SYMBOL vmlinux 0xb4fb616f	simple_rename
++EXPORT_SYMBOL vmlinux 0xb50df6b6	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0xb51d6df8	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xb521df2a	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xb52875fc	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb5328da7	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xb54088a3	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0xb54533f7	usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xb546ee67	tty_hangup
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb57b47a4	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xb57f2457	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xb57fdff2	proto_register
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5c37174	blk_get_queue
++EXPORT_SYMBOL vmlinux 0xb5c42021	__elv_add_request
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5dcab5b	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0xb5e9f7e0	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0xb617994e	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb62d23fd	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xb6441cb2	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6822a33	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6bbaea4	scsi_cmd_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xb6c5a973	scsi_show_result
++EXPORT_SYMBOL vmlinux 0xb6cbe886	acpi_get_node
++EXPORT_SYMBOL vmlinux 0xb6e07fb0	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0xb6e3814a	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0xb6f20933	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xb6f366e2	sk_filter
++EXPORT_SYMBOL vmlinux 0xb7164d44	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xb7316fdd	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xb7527658	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb78e5548	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0xb7a83dca	sock_release
++EXPORT_SYMBOL vmlinux 0xb7e6ad99	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0xb7f47feb	inode_sb_list_lock
++EXPORT_SYMBOL vmlinux 0xb7f9c50f	may_umount_tree
++EXPORT_SYMBOL vmlinux 0xb7fb1bc7	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0xb8097837	blk_put_queue
++EXPORT_SYMBOL vmlinux 0xb80f618a	tty_do_resize
++EXPORT_SYMBOL vmlinux 0xb822d9e4	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xb835b3e4	radix_tree_prev_hole
++EXPORT_SYMBOL vmlinux 0xb8444cf3	bdi_init
++EXPORT_SYMBOL vmlinux 0xb85e265e	kill_block_super
++EXPORT_SYMBOL vmlinux 0xb86ddb62	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xb8740cb3	qdisc_reset
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb88c88ba	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xb8c3449c	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xb8d55d7d	dev_emerg
++EXPORT_SYMBOL vmlinux 0xb8e0ea09	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8fa43c8	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xb905ff9f	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb9249d16	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xb93d85b7	pm860x_page_bulk_write
++EXPORT_SYMBOL vmlinux 0xb9466581	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xb9740ca8	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xb9829faf	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xb98847f0	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xb98a0185	rtc_tm_to_time
++EXPORT_SYMBOL vmlinux 0xb98ce15b	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0xb9972298	skb_put
++EXPORT_SYMBOL vmlinux 0xb99a6746	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0xb9a60d4b	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xb9a88eab	sock_from_file
++EXPORT_SYMBOL vmlinux 0xb9b4e181	alloc_pages_exact_nid
++EXPORT_SYMBOL vmlinux 0xb9c4a74c	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0xb9ca2afb	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0xb9fd2205	add_efi_memmap
++EXPORT_SYMBOL vmlinux 0xba1b8dd5	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0xba1e6ed2	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba3ae6bc	mmc_gpio_free_ro
++EXPORT_SYMBOL vmlinux 0xba3c93e3	register_md_personality
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba63339c	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xba89f554	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xba8b7908	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xba90d63e	__nla_put
++EXPORT_SYMBOL vmlinux 0xba962a74	get_write_access
++EXPORT_SYMBOL vmlinux 0xbaef3775	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xbaeffa05	qid_eq
++EXPORT_SYMBOL vmlinux 0xbb0d97e9	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0xbb189cad	disallow_signal
++EXPORT_SYMBOL vmlinux 0xbb2da1d2	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xbb300526	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0xbb34134a	iov_shorten
++EXPORT_SYMBOL vmlinux 0xbb3776ad	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xbb424283	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xbb4f4766	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0xbb512112	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xbb53b126	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb713e6d	sk_filter_release_rcu
++EXPORT_SYMBOL vmlinux 0xbb7b41c7	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbc6c1cb	dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xbbcc89c3	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xbbe8e0e5	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xbbef3f7d	kmem_cache_alloc_node_trace
++EXPORT_SYMBOL vmlinux 0xbbf931e1	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0xbbfcaca5	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xbc159870	kill_pid
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc2978e9	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xbc3a2381	scsi_prep_state_check
++EXPORT_SYMBOL vmlinux 0xbc499bd8	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0xbc49bda4	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0xbc5eeba8	get_super
++EXPORT_SYMBOL vmlinux 0xbc75fefe	ata_dev_acpi_handle
++EXPORT_SYMBOL vmlinux 0xbc7c974d	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xbc94e33a	led_set_brightness
++EXPORT_SYMBOL vmlinux 0xbcc01743	lock_fb_info
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcc9a6e9	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xbcdeaa4a	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0xbcdf5bbf	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0xbcf3c745	dev_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0xbcfd757c	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0xbd0462fe	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xbd100793	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xbd1a8c98	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xbd27d5f9	__lru_cache_add
++EXPORT_SYMBOL vmlinux 0xbd462b55	__kfifo_init
++EXPORT_SYMBOL vmlinux 0xbd5744b5	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xbd8444cf	nf_log_set
++EXPORT_SYMBOL vmlinux 0xbda084f3	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xbdab137c	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0xbdada5f9	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0xbdaf5b07	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0xbdfb6dbb	__fentry__
++EXPORT_SYMBOL vmlinux 0xbe18153d	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xbe22321e	d_move
++EXPORT_SYMBOL vmlinux 0xbe254e92	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xbe2ac387	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xbe2b0859	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xbe2c0274	add_timer
++EXPORT_SYMBOL vmlinux 0xbe2feaa5	flock_lock_file_wait
++EXPORT_SYMBOL vmlinux 0xbe365f42	ll_rw_block
++EXPORT_SYMBOL vmlinux 0xbe426293	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xbe56003a	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0xbe83e4ff	kset_unregister
++EXPORT_SYMBOL vmlinux 0xbe9b1732	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xbea56a76	journal_load
++EXPORT_SYMBOL vmlinux 0xbea58569	tty_check_change
++EXPORT_SYMBOL vmlinux 0xbeb2d254	mb_cache_create
++EXPORT_SYMBOL vmlinux 0xbeb59c94	prepare_creds
++EXPORT_SYMBOL vmlinux 0xbebac3cc	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbecdf052	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xbedf385b	skb_trim
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbefc8a8a	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xbf17372f	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xbf1d887b	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xbf25b958	nla_reserve
++EXPORT_SYMBOL vmlinux 0xbf31cbf6	devm_free_irq
++EXPORT_SYMBOL vmlinux 0xbf4591db	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xbf4d4bb9	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf87909b	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfc407b4	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfcfeafd	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xbfd5d2a6	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff34a1c	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0xc00d8b19	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xc01cf848	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0xc02ce5d0	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0xc02cf69b	clkdev_drop
++EXPORT_SYMBOL vmlinux 0xc02e5c99	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0xc0388d8d	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xc040d57e	nla_put
++EXPORT_SYMBOL vmlinux 0xc040fa78	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0xc055902c	framebuffer_release
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0935452	d_lookup
++EXPORT_SYMBOL vmlinux 0xc09d017f	ether_setup
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a497ec	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xc0a73432	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xc0b4e989	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0xc0ccfa09	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xc1215919	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xc1312700	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xc15467af	__skb_dst_set_noref
++EXPORT_SYMBOL vmlinux 0xc17068e9	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xc19f781f	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0xc1c2dd09	__hw_addr_flush
++EXPORT_SYMBOL vmlinux 0xc1f6f299	dev_get_by_flags_rcu
++EXPORT_SYMBOL vmlinux 0xc20aae13	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0xc20fff90	amd_iommu_flush_page
++EXPORT_SYMBOL vmlinux 0xc22a600c	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xc22b50ad	param_set_bint
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc256e762	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xc26f6c95	alloc_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0xc290e0c9	dma_async_memcpy_pg_to_pg
++EXPORT_SYMBOL vmlinux 0xc2935ca6	pci_map_rom
++EXPORT_SYMBOL vmlinux 0xc293cbf3	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xc29bf967	strspn
++EXPORT_SYMBOL vmlinux 0xc2aaf321	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0xc2ae9c3f	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0xc2b27b50	bio_map_user
++EXPORT_SYMBOL vmlinux 0xc2bfa359	replace_mount_options
++EXPORT_SYMBOL vmlinux 0xc2d6afb6	names_cachep
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2f0be1a	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xc2f9c045	timespec_to_jiffies
++EXPORT_SYMBOL vmlinux 0xc309b319	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xc310b981	strnstr
++EXPORT_SYMBOL vmlinux 0xc344643f	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0xc347de38	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xc34d91c7	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xc35e50ac	unregister_netdev
++EXPORT_SYMBOL vmlinux 0xc3662090	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xc39d47f4	bdgrab
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3b4a603	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xc3b5a3e6	dentry_unhash
++EXPORT_SYMBOL vmlinux 0xc3bd8d81	nf_log_register
++EXPORT_SYMBOL vmlinux 0xc3ddd530	blk_register_region
++EXPORT_SYMBOL vmlinux 0xc3e89e35	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xc4176cdc	skb_split
++EXPORT_SYMBOL vmlinux 0xc435db04	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc4377629	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xc44f39c3	compat_nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xc4625811	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xc47923ea	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xc47da365	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc49b2a6f	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xc49f4114	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0xc4acdda9	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xc4b5b5b5	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xc4bf5ab0	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xc4c58899	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0xc4e2b5bb	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xc4e83d44	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xc4f3a6bf	read_cache_page
++EXPORT_SYMBOL vmlinux 0xc50bab05	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0xc51808e1	bdput
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc558530d	profile_pc
++EXPORT_SYMBOL vmlinux 0xc5585be5	proc_remove
++EXPORT_SYMBOL vmlinux 0xc57e408a	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xc5806bf5	x86_hyper
++EXPORT_SYMBOL vmlinux 0xc58a6ec1	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xc58c05ed	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0xc5a1f509	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0xc5abfc89	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xc5b49dd6	register_netdevice
++EXPORT_SYMBOL vmlinux 0xc5be3859	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xc5c100c4	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5e02d03	files_lglock
++EXPORT_SYMBOL vmlinux 0xc5e0c280	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc5fe849b	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xc61a18d5	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xc61bb8ae	ata_ap_acpi_handle
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63d1667	brioctl_set
++EXPORT_SYMBOL vmlinux 0xc64484ac	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xc648ae59	sync_inode
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc666a132	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xc67f3d9b	tty_lock_pair
++EXPORT_SYMBOL vmlinux 0xc6a5f08e	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xc6a66180	rwsem_wake
++EXPORT_SYMBOL vmlinux 0xc6a67170	deactivate_super
++EXPORT_SYMBOL vmlinux 0xc6ab5cd7	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xc6bf1734	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xc6cb465a	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6f3c8fe	__inode_permission
++EXPORT_SYMBOL vmlinux 0xc6f61808	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0xc7003d8f	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xc702156b	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xc715d9e0	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc735fb95	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0xc7645806	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xc76aac6c	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0xc770d15c	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0xc772fc66	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc78381fc	xfrm_input
++EXPORT_SYMBOL vmlinux 0xc78434eb	compat_sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc78c9177	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xc791b6b4	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7cbbe00	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xc7cd370d	set_pages_wb
++EXPORT_SYMBOL vmlinux 0xc7cf7527	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0xc7d19ce3	pci_request_regions
++EXPORT_SYMBOL vmlinux 0xc7ddd7e5	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0xc7ef371a	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0xc817979e	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xc81ac68a	submit_bh
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc8623c1d	init_task
++EXPORT_SYMBOL vmlinux 0xc862e559	find_vma
++EXPORT_SYMBOL vmlinux 0xc86517ec	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xc86a5180	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0xc88c4abe	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc89d9159	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8bb035e	udp_prot
++EXPORT_SYMBOL vmlinux 0xc8dde9a3	inode_permission
++EXPORT_SYMBOL vmlinux 0xc905181d	should_remove_suid
++EXPORT_SYMBOL vmlinux 0xc91873d3	bdi_register
++EXPORT_SYMBOL vmlinux 0xc922b817	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0xc9546e56	aio_put_req
++EXPORT_SYMBOL vmlinux 0xc955cffc	seq_bitmap_list
++EXPORT_SYMBOL vmlinux 0xc9654eb6	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xc978479a	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xc98170be	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0xc98416be	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xc996d097	del_timer
++EXPORT_SYMBOL vmlinux 0xc99add7e	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0xc99c8b19	journal_extend
++EXPORT_SYMBOL vmlinux 0xc99ec303	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xc9a7e3e7	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0xc9e6cb61	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0xca138be1	user_revoke
++EXPORT_SYMBOL vmlinux 0xca1a5763	cont_write_begin
++EXPORT_SYMBOL vmlinux 0xca262050	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0xca4ca404	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xca4e194e	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0xca593167	blkdev_get
++EXPORT_SYMBOL vmlinux 0xca5dbc50	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xca6f33be	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xca86a2a4	input_register_device
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcabe548f	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0xcac48c00	compat_tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xcae01c20	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xcaef1b77	idr_remove
++EXPORT_SYMBOL vmlinux 0xcaf20a1f	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xcaf83b79	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb196465	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xcb1dfb06	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0xcb45a99a	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xcb56dfb8	blk_start_queue
++EXPORT_SYMBOL vmlinux 0xcb5c7907	vga_client_register
++EXPORT_SYMBOL vmlinux 0xcb710124	mount_pseudo
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb8c0556	wake_up_process
++EXPORT_SYMBOL vmlinux 0xcba14ce5	__idr_remove_all
++EXPORT_SYMBOL vmlinux 0xcba9cfa5	i2c_master_send
++EXPORT_SYMBOL vmlinux 0xcbab9f90	kernel_listen
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcc151d19	dma_supported
++EXPORT_SYMBOL vmlinux 0xcc173cab	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0xcc18a0b5	__bio_clone
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc37f55c	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0xcc4a8cb9	dev_get_stats
++EXPORT_SYMBOL vmlinux 0xcc4ed092	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc74e537	__scm_send
++EXPORT_SYMBOL vmlinux 0xcc76a9db	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0xcc7fa952	local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0xcc8f3bbd	agp_free_page_array
++EXPORT_SYMBOL vmlinux 0xcc93dfbf	mount_single
++EXPORT_SYMBOL vmlinux 0xcca0a1f8	kernel_connect
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccebe041	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xcd20667a	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd3bc598	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xcd4a5f87	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xcd538760	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xcd5a665b	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0xcd60205b	lro_flush_pkt
++EXPORT_SYMBOL vmlinux 0xcd77fb66	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xcd7c6b13	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xcdbc6d43	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc7f0ac	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0xcde172ac	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0xcdf446b7	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xce097b84	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xce0b1bed	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce4e47b6	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce669e54	__getblk
++EXPORT_SYMBOL vmlinux 0xce6bf945	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xce7285ff	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xce97a72d	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xcecd2ac9	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcefd9bae	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xcf1d28ab	acpi_error
++EXPORT_SYMBOL vmlinux 0xcf21d241	__wake_up
++EXPORT_SYMBOL vmlinux 0xcf2b6317	iov_iter_copy_from_user
++EXPORT_SYMBOL vmlinux 0xcf3e71ea	blkdev_put
++EXPORT_SYMBOL vmlinux 0xcf494a65	journal_flush
++EXPORT_SYMBOL vmlinux 0xcf68ce44	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf81a93e	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0xcfb0f768	bd_set_size
++EXPORT_SYMBOL vmlinux 0xcfc3ee1f	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0xcfd46922	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0xcfe740b2	sock_init_data
++EXPORT_SYMBOL vmlinux 0xcff17bd9	__pskb_copy
++EXPORT_SYMBOL vmlinux 0xd005d85b	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xd00630ea	seq_puts
++EXPORT_SYMBOL vmlinux 0xd0181f4f	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xd0248e3f	cdrom_open
++EXPORT_SYMBOL vmlinux 0xd025ea81	d_alloc_name
++EXPORT_SYMBOL vmlinux 0xd0298b8b	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xd0315710	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xd04a2b93	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0xd051902d	mmc_suspend_host
++EXPORT_SYMBOL vmlinux 0xd067fc5c	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xd06d98c1	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd08197fa	acpi_load_tables
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0ad2016	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xd0d0aa72	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0xd0d42c42	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0xd0dbb7e0	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd11c0dc1	__kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd18b6eb2	acpi_unmap_lsapic
++EXPORT_SYMBOL vmlinux 0xd18b81c5	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xd1b80dab	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xd1e28dfb	mem_cgroup_subsys
++EXPORT_SYMBOL vmlinux 0xd1e61405	clear_nlink
++EXPORT_SYMBOL vmlinux 0xd1ea8bab	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xd1f32fe7	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd21765d9	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xd21a0983	netdev_notice
++EXPORT_SYMBOL vmlinux 0xd220cf8a	jiffies_to_timespec
++EXPORT_SYMBOL vmlinux 0xd227892e	sleep_on
++EXPORT_SYMBOL vmlinux 0xd22eb8e2	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xd2314033	follow_pfn
++EXPORT_SYMBOL vmlinux 0xd2347a6b	sk_dst_check
++EXPORT_SYMBOL vmlinux 0xd23aaa3e	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xd2496d57	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd25f5ffc	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd27c6925	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xd2a3cf33	fb_set_var
++EXPORT_SYMBOL vmlinux 0xd2a7c838	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0xd2add1f1	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0xd2b09ce5	__kmalloc
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2de75eb	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0xd2e46319	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xd2ef2f25	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xd2f1b260	interruptible_sleep_on
++EXPORT_SYMBOL vmlinux 0xd2f4c095	get_task_io_context
++EXPORT_SYMBOL vmlinux 0xd2fd8a6a	free_task
++EXPORT_SYMBOL vmlinux 0xd30299f5	bio_copy_user
++EXPORT_SYMBOL vmlinux 0xd305e202	vfs_read
++EXPORT_SYMBOL vmlinux 0xd33a8a1f	nla_append
++EXPORT_SYMBOL vmlinux 0xd33f889f	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xd344e27a	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0xd35e249a	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0xd36257ba	memcpy_toiovecend
++EXPORT_SYMBOL vmlinux 0xd3668a1b	softnet_data
++EXPORT_SYMBOL vmlinux 0xd38d24af	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0xd3929277	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xd3b1e206	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xd3bdb26e	seq_open_private
++EXPORT_SYMBOL vmlinux 0xd3d3a477	posix_acl_init
++EXPORT_SYMBOL vmlinux 0xd3dcab0b	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xd3ddd0ca	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xd3fd58bb	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0xd4373768	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4a21fc9	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0xd4b08e54	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xd4df1b13	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xd4e9c928	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0xd4ea03d7	block_commit_write
++EXPORT_SYMBOL vmlinux 0xd4edeb04	cpu_core_map
++EXPORT_SYMBOL vmlinux 0xd4f0d2f0	migrate_page
++EXPORT_SYMBOL vmlinux 0xd4ffa484	acpi_initialize_subsystem
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd5273290	journal_force_commit
++EXPORT_SYMBOL vmlinux 0xd52bf1ce	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0xd54a70a2	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0xd54ba4a0	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xd55793ab	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xd58258ff	journal_update_format
++EXPORT_SYMBOL vmlinux 0xd5856d10	I_BDEV
++EXPORT_SYMBOL vmlinux 0xd59575a6	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0xd59b11e4	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xd5acfcc4	skb_clone
++EXPORT_SYMBOL vmlinux 0xd5b493d0	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xd5beb9f9	acpi_bus_generate_proc_event
++EXPORT_SYMBOL vmlinux 0xd5c82960	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xd5dad320	generic_write_end
++EXPORT_SYMBOL vmlinux 0xd5e2be6d	tty_register_driver
++EXPORT_SYMBOL vmlinux 0xd5e93360	agp_create_memory
++EXPORT_SYMBOL vmlinux 0xd5ef1c61	__brelse
++EXPORT_SYMBOL vmlinux 0xd5f2172f	del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd5f64b26	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0xd5fb9ed4	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xd611bca3	completion_done
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd6201a59	flush_old_exec
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd647f51a	file_open_root
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd65f086f	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xd660145c	pci_enable_msi_block
++EXPORT_SYMBOL vmlinux 0xd674e023	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6aef22c	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6bf3208	truncate_setsize
++EXPORT_SYMBOL vmlinux 0xd6e48772	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6f9964a	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xd71910ea	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xd71a2b67	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0xd720955c	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0xd72e6949	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xd7445f66	d_validate
++EXPORT_SYMBOL vmlinux 0xd7570911	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd77a5aa5	__bitmap_and
++EXPORT_SYMBOL vmlinux 0xd78a7982	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0xd79b5a02	allow_signal
++EXPORT_SYMBOL vmlinux 0xd7b59453	commit_creds
++EXPORT_SYMBOL vmlinux 0xd7cbddda	memcpy_toiovec
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd81685b7	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xd83eb668	padata_free
++EXPORT_SYMBOL vmlinux 0xd845706f	devm_request_and_ioremap
++EXPORT_SYMBOL vmlinux 0xd84ce383	tty_mutex
++EXPORT_SYMBOL vmlinux 0xd851b50e	serio_open
++EXPORT_SYMBOL vmlinux 0xd855184c	touch_buffer
++EXPORT_SYMBOL vmlinux 0xd866fc05	journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xd86c09db	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xd8753e98	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8c53ece	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xd8cdbc32	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xd8d24c66	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xd8dbafcc	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8eb6fa4	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xd8f74b22	blk_end_request
++EXPORT_SYMBOL vmlinux 0xd90353a2	pci_set_ltr
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd90e93ad	input_get_keycode
++EXPORT_SYMBOL vmlinux 0xd92afabe	bitmap_clear
++EXPORT_SYMBOL vmlinux 0xd92e16ba	csum_partial_copy_fromiovecend
++EXPORT_SYMBOL vmlinux 0xd94322e7	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0xd9626e8f	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0xd964d16f	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd97c43e7	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9a9bb30	getname
++EXPORT_SYMBOL vmlinux 0xd9bdd951	agp_free_memory
++EXPORT_SYMBOL vmlinux 0xd9d8baaa	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xd9db1085	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0xd9e61fcb	qid_valid
++EXPORT_SYMBOL vmlinux 0xda03ffc5	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xda0a6b0e	acpi_map_lsapic
++EXPORT_SYMBOL vmlinux 0xda176247	uart_match_port
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda62b525	ilookup5
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda7f52ac	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0xda88dcb3	__neigh_create
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xdadba9a4	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xdaea6e0d	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0xdb278770	tcp_prot
++EXPORT_SYMBOL vmlinux 0xdb279db6	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xdb289408	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xdb2aa1b5	clear_bdi_congested
++EXPORT_SYMBOL vmlinux 0xdb31b45e	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0xdb4416c3	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xdb50a5a1	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0xdb543806	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb78ef19	input_close_device
++EXPORT_SYMBOL vmlinux 0xdb7cb7ee	seq_open
++EXPORT_SYMBOL vmlinux 0xdb816d9f	dma_pool_create
++EXPORT_SYMBOL vmlinux 0xdbcd416e	sysctl_ip_nonlocal_bind
++EXPORT_SYMBOL vmlinux 0xdbcf4408	inc_nlink
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc0de782	phy_stop
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc366b7a	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc5668fe	get_fs_type
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc5a5151	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xdc6d41cf	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0xdc884ad4	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xdc8d1dde	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0xdca78030	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcc87f29	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xdce56b44	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xdcf118fe	vga_get
++EXPORT_SYMBOL vmlinux 0xdd06cec4	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0xdd437312	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xdd4a5569	param_get_byte
++EXPORT_SYMBOL vmlinux 0xdd730296	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xdda0a915	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0xdde83545	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0xddf912a1	bdget_disk
++EXPORT_SYMBOL vmlinux 0xde0234c5	pci_request_region
++EXPORT_SYMBOL vmlinux 0xde0b578b	phy_connect
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde1f6b11	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xde50e039	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0xde6151db	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0xde6556b1	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0xde66f192	neigh_update
++EXPORT_SYMBOL vmlinux 0xde6f4840	bdev_read_only
++EXPORT_SYMBOL vmlinux 0xde895926	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdebd52d0	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xdec049c8	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0xdecd1c9b	pci_get_device
++EXPORT_SYMBOL vmlinux 0xdeed5308	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0xdef122f2	dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0xdef4de0b	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0xdef74761	devm_clk_put
++EXPORT_SYMBOL vmlinux 0xdf04e773	tcp_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0xdf08d9a5	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xdf0977f3	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf1e227a	blk_put_request
++EXPORT_SYMBOL vmlinux 0xdf2aeb1a	pipe_to_file
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf35d517	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xdf478114	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xdf48a0eb	flex_array_put
++EXPORT_SYMBOL vmlinux 0xdf4f5101	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6ae038	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xdf7179d0	key_alloc
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfb2fc39	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xdfb8d17c	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfd06006	build_skb
++EXPORT_SYMBOL vmlinux 0xdfdb0eee	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xe012969d	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xe029f55f	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe06e4199	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xe06f7046	input_reset_device
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe08d5492	inode_init_once
++EXPORT_SYMBOL vmlinux 0xe08fc572	sk_run_filter
++EXPORT_SYMBOL vmlinux 0xe0a09068	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0d17460	console_stop
++EXPORT_SYMBOL vmlinux 0xe0e3fb54	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0xe0f0d3d0	ihold
++EXPORT_SYMBOL vmlinux 0xe10720f8	mmc_hw_reset_check
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe15f42bb	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0xe16fbb43	user_path_at
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1842781	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0xe18ad749	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0xe191f0c4	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xe19f33cd	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xe1c96526	dquot_operations
++EXPORT_SYMBOL vmlinux 0xe1cb70cb	sock_edemux
++EXPORT_SYMBOL vmlinux 0xe200d2d5	param_get_uint
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe202b571	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xe20f35f8	__mem_cgroup_count_vm_event
++EXPORT_SYMBOL vmlinux 0xe21516bd	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xe2236ff1	vfs_mknod
++EXPORT_SYMBOL vmlinux 0xe2259c51	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0xe22c3c0e	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xe23a094c	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24a3ce4	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe28b4b82	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xe28c5ec0	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xe29b04e9	acpi_set_firmware_waking_vector64
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe29ea9fb	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xe2be8cf0	net_dma_find_channel
++EXPORT_SYMBOL vmlinux 0xe2c1012c	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0xe2cfb038	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0xe2cfebf5	cookie_check_timestamp
++EXPORT_SYMBOL vmlinux 0xe2d444db	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2def249	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xe2e26974	netdev_info
++EXPORT_SYMBOL vmlinux 0xe3001b0f	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xe307db12	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe31a6adb	mmc_resume_host
++EXPORT_SYMBOL vmlinux 0xe34a2827	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xe35cd997	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0xe3640cd3	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xe38da622	netdev_class_remove_file
++EXPORT_SYMBOL vmlinux 0xe3a53f4c	sort
++EXPORT_SYMBOL vmlinux 0xe3bd37e8	__free_pages
++EXPORT_SYMBOL vmlinux 0xe3d6c94e	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3e12008	__first_cpu
++EXPORT_SYMBOL vmlinux 0xe3f24ede	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xe3fd8414	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xe40bb483	dev_close
++EXPORT_SYMBOL vmlinux 0xe460ef85	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xe4675aac	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xe468fd4f	skb_copy_datagram_const_iovec
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe4a9769f	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xe4b25b40	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0xe4c52b83	set_user_nice
++EXPORT_SYMBOL vmlinux 0xe4e9e595	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xe50068e0	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0xe5119d01	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xe5122890	flow_cache_genid
++EXPORT_SYMBOL vmlinux 0xe5208918	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe54e028f	netif_skb_features
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5ad9553	pci_vpd_truncate
++EXPORT_SYMBOL vmlinux 0xe5b6b339	napi_get_frags
++EXPORT_SYMBOL vmlinux 0xe5bec95c	i8253_lock
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d95985	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe60a82d9	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xe6183d07	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0xe63640e0	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0xe64b9aad	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe64d9b62	pci_release_region
++EXPORT_SYMBOL vmlinux 0xe667eed2	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0xe66c7d1b	iunique
++EXPORT_SYMBOL vmlinux 0xe672c5ea	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0xe6759edb	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0xe682e9c3	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0xe68e9286	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe69a9df4	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xe69f37ef	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xe6b2d6d9	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0xe6cf79dd	tcp_gro_receive
++EXPORT_SYMBOL vmlinux 0xe6e3b875	down_write
++EXPORT_SYMBOL vmlinux 0xe6fb675c	node_to_cpumask_map
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe7176a25	journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xe719b4c2	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0xe727d06f	d_tmpfile
++EXPORT_SYMBOL vmlinux 0xe742efbc	tty_port_open
++EXPORT_SYMBOL vmlinux 0xe7722171	flex_array_free
++EXPORT_SYMBOL vmlinux 0xe7758e0e	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xe776defa	vfs_readv
++EXPORT_SYMBOL vmlinux 0xe77f15fa	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0xe7a664c4	nf_hooks
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7ab1e34	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xe7b20896	ip_options_compile
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7ff0be8	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0xe806399b	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xe80b78c0	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0xe80ce219	sysctl_tcp_dma_copybreak
++EXPORT_SYMBOL vmlinux 0xe80f949a	module_refcount
++EXPORT_SYMBOL vmlinux 0xe866652d	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe8848286	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0xe8b2fddd	md_done_sync
++EXPORT_SYMBOL vmlinux 0xe8b63ace	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8ca41d4	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xe8d23bfe	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xe8dbafef	__next_cpu
++EXPORT_SYMBOL vmlinux 0xe8eca0ae	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe91b4639	dev_addr_init
++EXPORT_SYMBOL vmlinux 0xe91d17ad	del_gendisk
++EXPORT_SYMBOL vmlinux 0xe9252639	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0xe92f1925	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xe937c30a	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0xe9393798	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe97af1a0	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xe98fd202	kset_register
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe99dbdee	inet6_protos
++EXPORT_SYMBOL vmlinux 0xe9a3128d	km_query
++EXPORT_SYMBOL vmlinux 0xe9abc1c1	iterate_fd
++EXPORT_SYMBOL vmlinux 0xe9dff136	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea10212a	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0xea10655a	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xea1fc546	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xea3b31bf	pci_disable_ido
++EXPORT_SYMBOL vmlinux 0xea5491bf	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0xea6cdd5a	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xeaa6df3b	netpoll_setup
++EXPORT_SYMBOL vmlinux 0xeac73847	irq_regs
++EXPORT_SYMBOL vmlinux 0xead93dcb	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xeadbc9b0	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xeadd8a2f	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0xeadfffaf	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xeae2f436	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeae5a523	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xeb1206ae	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xeb192537	read_cache_pages
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb3a4d92	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xeb3fab97	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xeb44339a	free_pages_exact
++EXPORT_SYMBOL vmlinux 0xeb896527	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0xeb8be909	dentry_open
++EXPORT_SYMBOL vmlinux 0xeb97c5c8	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0xebb50b38	serio_rescan
++EXPORT_SYMBOL vmlinux 0xebbe16f0	__skb_get_rxhash
++EXPORT_SYMBOL vmlinux 0xebd3c055	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0xebdbe48c	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xebfb96c2	unlock_page
++EXPORT_SYMBOL vmlinux 0xec1a716b	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xec3b0450	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec56d3e7	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xec5e0d4a	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xec730387	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0xecb5442f	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xecde9c06	ppp_input
++EXPORT_SYMBOL vmlinux 0xece19d7d	journal_init_dev
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecfbb3ac	free_netdev
++EXPORT_SYMBOL vmlinux 0xed1326c2	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0xed49483a	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5dd28c	blk_integrity_is_initialized
++EXPORT_SYMBOL vmlinux 0xed6d7b96	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xed77f958	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0xed7eeb1a	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xed9b8fb8	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xedc4cd49	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xedd82e31	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xee0a055c	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xee18dae3	grab_cache_page_nowait
++EXPORT_SYMBOL vmlinux 0xee29f17e	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee3f855b	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0xee46885d	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xee4ddc9f	block_write_end
++EXPORT_SYMBOL vmlinux 0xee7b6db5	pipe_lock
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee95a2ed	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xeea24d64	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeb5bd3b	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0xeeec26a7	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xef200993	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0xef2560ef	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xef3aad0b	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xef408212	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0xef45f76c	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xef539521	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xef65ed7f	security_mmap_file
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xef9b6e98	security_inode_permission
++EXPORT_SYMBOL vmlinux 0xefb10eeb	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xefb6b186	interruptible_sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0xefba93e1	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf047b71f	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xf055ce08	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0619801	timekeeping_clocktai
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf067257c	register_memory_isolate_notifier
++EXPORT_SYMBOL vmlinux 0xf0829ae0	pci_iounmap
++EXPORT_SYMBOL vmlinux 0xf087137d	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0xf09914c1	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0b07886	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xf0c7c278	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xf0c7d986	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f1246c	kvasprintf
++EXPORT_SYMBOL vmlinux 0xf0fdf6cb	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xf1000f4a	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xf100416a	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xf10823d4	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0xf1089259	set_bdi_congested
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf116d4b5	copy_in_user
++EXPORT_SYMBOL vmlinux 0xf13feb57	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0xf14629f2	amd_iommu_domain_enable_v2
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf147ecb1	down_trylock
++EXPORT_SYMBOL vmlinux 0xf15effd0	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xf1700ac8	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xf1938dfa	km_state_notify
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf195f349	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0xf1a6e6d9	__netdev_pick_tx
++EXPORT_SYMBOL vmlinux 0xf1be6f8c	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xf1c4bd6b	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xf1d61328	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf202c5cb	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf20e3d3e	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0xf21a649a	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xf22449ae	down_interruptible
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf25b9ace	skb_copy_datagram_from_iovec
++EXPORT_SYMBOL vmlinux 0xf26473cb	input_allocate_device
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf2949dd8	mdiobus_write
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2a9ea3e	journal_revoke
++EXPORT_SYMBOL vmlinux 0xf2b1ac8e	__getnstimeofday
++EXPORT_SYMBOL vmlinux 0xf2f9dfe2	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf32055e7	dev_base_lock
++EXPORT_SYMBOL vmlinux 0xf329dbae	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0xf32a262a	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xf332b097	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf37260ab	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf3a446f2	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xf3bf0bce	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0xf3d39f54	bio_reset
++EXPORT_SYMBOL vmlinux 0xf3f3ca07	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0xf3f751de	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xf40d18a8	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0xf41a2255	dm_get_device
++EXPORT_SYMBOL vmlinux 0xf41b6846	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xf41c4924	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xf41e667d	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xf432dd3d	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0xf43b0c91	audit_log_start
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf45a4e52	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf460df33	nf_reinject
++EXPORT_SYMBOL vmlinux 0xf46b58c6	neigh_compat_output
++EXPORT_SYMBOL vmlinux 0xf471df82	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xf478065c	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf51bf88b	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf554053a	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xf560b31c	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xf5893abf	up_read
++EXPORT_SYMBOL vmlinux 0xf58b49b9	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0xf58c8805	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xf58fb95b	kobject_add
++EXPORT_SYMBOL vmlinux 0xf598be6a	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xf59dbdf3	elv_abort_queue
++EXPORT_SYMBOL vmlinux 0xf5a7fd6a	poll_initwait
++EXPORT_SYMBOL vmlinux 0xf5aa1331	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5b8c551	set_pages_uc
++EXPORT_SYMBOL vmlinux 0xf5ce272b	idr_for_each
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5ebcd1f	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xf62c19ad	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf640698d	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0xf653a600	__mutex_init
++EXPORT_SYMBOL vmlinux 0xf66e3e59	sg_miter_start
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf6ab8f91	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0xf6ac917b	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xf6acf520	__ps2_command
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6c3d7f2	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xf6cccd15	save_mount_options
++EXPORT_SYMBOL vmlinux 0xf6d20069	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xf6e8da50	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xf6e911ef	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6ef13bd	journal_init_inode
++EXPORT_SYMBOL vmlinux 0xf702484e	update_region
++EXPORT_SYMBOL vmlinux 0xf715f4dc	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xf721d9a0	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xf7289d14	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0xf72b7c3e	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xf73a1dbb	eth_type_trans
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf75ba7b3	generic_file_open
++EXPORT_SYMBOL vmlinux 0xf76d36cd	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xf78350da	eth_header_parse
++EXPORT_SYMBOL vmlinux 0xf79d6be8	udplite_prot
++EXPORT_SYMBOL vmlinux 0xf7adcaf3	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0xf7c27471	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xf7cb4d0d	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xf7de1ab4	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xf7f9fe51	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xf803fe39	bitmap_set
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf812cff6	memscan
++EXPORT_SYMBOL vmlinux 0xf819e075	find_get_page
++EXPORT_SYMBOL vmlinux 0xf82200c0	tc_classify_compat
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82cfd1a	proc_dostring
++EXPORT_SYMBOL vmlinux 0xf82e3d47	acpi_initialize_objects
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf838bedd	netdev_has_any_upper_dev
++EXPORT_SYMBOL vmlinux 0xf874d917	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf88e2cb1	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xf8933187	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xf8983de7	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0xf8a14e55	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xf8bcff9a	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xf8fc47c9	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xf91acda5	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xf949b5e8	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xf94b0125	get_phy_device
++EXPORT_SYMBOL vmlinux 0xf95d99ad	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xf95f0a61	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9b9b1e8	input_grab_device
++EXPORT_SYMBOL vmlinux 0xf9c0b663	strlcat
++EXPORT_SYMBOL vmlinux 0xf9f86bce	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xf9ff20e9	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xfa0f86c7	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0xfa1acafc	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xfa22361a	md_flush_request
++EXPORT_SYMBOL vmlinux 0xfa283112	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0xfa4d2286	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa5ab8f7	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xfa66f77c	finish_wait
++EXPORT_SYMBOL vmlinux 0xfa6b0fde	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0xfa75c463	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xfa7f3156	wl12xx_get_platform_data
++EXPORT_SYMBOL vmlinux 0xfa8237d3	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0xfa901198	inet_release
++EXPORT_SYMBOL vmlinux 0xfaab27bf	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xfab383b9	rename_lock
++EXPORT_SYMBOL vmlinux 0xfac44333	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfae5a862	put_io_context
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf98462	bitrev32
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb056f7c	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xfb276cb6	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0xfb299d67	put_page
++EXPORT_SYMBOL vmlinux 0xfb30ee31	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xfb54d4c3	simple_lookup
++EXPORT_SYMBOL vmlinux 0xfb578fc5	memset
++EXPORT_SYMBOL vmlinux 0xfb68c812	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb57bde	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xfbbc9790	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0xfbbd8bb7	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc1c65e7	md_error
++EXPORT_SYMBOL vmlinux 0xfc307eb3	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc3e52ff	finish_open
++EXPORT_SYMBOL vmlinux 0xfc5a5522	bio_integrity_get_tag
++EXPORT_SYMBOL vmlinux 0xfc7da69f	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfca571a8	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xfca5e76a	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xfca5efca	__napi_schedule
++EXPORT_SYMBOL vmlinux 0xfcaa04a0	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcb926cd	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc54f91	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0xfcd2b5a5	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xfce5568e	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcf0d971	elv_add_request
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0c4465	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xfd18bc82	node_data
++EXPORT_SYMBOL vmlinux 0xfd4479a5	tty_throttle
++EXPORT_SYMBOL vmlinux 0xfd610eae	bdevname
++EXPORT_SYMBOL vmlinux 0xfd6293c2	boot_tvec_bases
++EXPORT_SYMBOL vmlinux 0xfd693723	spi_dv_device
++EXPORT_SYMBOL vmlinux 0xfd7d7713	acpi_exception
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd9ce325	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0xfda0dbe8	ftrace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xfdb5d1e7	noop_llseek
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfde691da	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xfde86554	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xfdee7d42	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0xfdf72a84	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xfdfb792f	amd_iommu_pc_supported
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe0338cd	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xfe047ce6	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xfe220d95	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xfe252497	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0xfe26fc7c	nr_node_ids
++EXPORT_SYMBOL vmlinux 0xfe396ca3	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0xfe46ca02	inet6_release
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe66cde2	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfea4f320	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0xfeb3751f	md_write_end
++EXPORT_SYMBOL vmlinux 0xfed1be15	done_path_create
++EXPORT_SYMBOL vmlinux 0xfed837ed	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0xfed9cfbf	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee02b3a	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0xfeebc7c4	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0xfeef1c0b	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xfef96e23	__scsi_print_command
++EXPORT_SYMBOL vmlinux 0xfefb7ee0	dquot_resume
++EXPORT_SYMBOL vmlinux 0xff144490	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0xff154e43	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff363d2e	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xff419819	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xff64968c	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff70e0dd	set_trace_device
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff7768ec	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xff7ad342	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xff85dbb4	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffb0ac66	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xffb2921b	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xffb3c71c	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0xffba6543	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xffc4c590	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0xffc87f0b	security_file_permission
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffe5095d	groups_free
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x00673d98	ablk_encrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x077861cb	ablk_set_key
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x0c2ff594	ablk_decrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x3c381b9b	__ablk_encrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x8609b30a	ablk_init_common
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xa03ed368	ablk_exit
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xb877fc5f	ablk_init
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-x86_64 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x13a65ecf	camellia_ecb_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x17bf48dc	camellia_xts_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x1a08ded1	camellia_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x47129015	camellia_xts_enc_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7d54edc2	camellia_cbc_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x7e87ef55	camellia_ecb_dec_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x8f185793	camellia_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-aesni-avx-x86_64 0x9e8086dc	camellia_ctr_16way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x16061d06	__camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1636abdf	__camellia_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x1da0e256	camellia_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x2eff2f71	xts_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x31bbe42b	camellia_crypt_ctr_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x50dc55b6	__camellia_enc_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x749da33b	lrw_camellia_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x8b2c788f	lrw_camellia_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0x930f687f	camellia_decrypt_cbc_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xa41a5ad3	camellia_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/camellia-x86_64 0xf4521fda	camellia_dec_blk_2way
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x1cbb7b28	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x7cd881eb	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xbfb28f0e	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xc83e90f4	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xd37bbd2d	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xe1e38214	glue_ctr_crypt_final_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x016a957f	serpent_xts_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0c5a8af6	serpent_xts_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x0ff3c26d	serpent_xts_dec
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x3c0f633c	lrw_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x606a8162	serpent_cbc_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x79ff0b7a	serpent_ecb_dec_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9ae34b2f	serpent_xts_enc
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9e018632	__serpent_crypt_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0x9f99663c	serpent_ctr_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xa84ea33d	serpent_ecb_enc_8way_avx
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xb709ff99	lrw_serpent_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/serpent-avx-x86_64 0xe5edf61b	xts_serpent_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x19dc7881	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64 0x5e752773	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x1fd77fb1	twofish_dec_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x27105635	lrw_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x334fd07c	lrw_twofish_exit_tfm
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x61694b97	twofish_dec_blk_cbc_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8d75ab44	twofish_enc_blk_ctr
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0x8e856922	twofish_enc_blk_ctr_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0xf2e80e9c	__twofish_enc_blk_3way
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-x86_64-3way 0xfef2c312	xts_twofish_setkey
++EXPORT_SYMBOL_GPL arch/x86/kernel/microcode 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x023eff21	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x04046f83	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0b9b475a	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x13dc084d	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1559f1dd	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x15e9d1f1	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1cfe78d1	kvm_release_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20cb757b	gfn_to_pfn_async
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2134b782	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2161f47e	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x22494277	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x233735e5	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x24820be6	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c4e14a6	kvm_mmu_get_spte_hierarchy
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3137d6d1	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x31ce78f2	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x38c6158d	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3b5dd35e	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3de08404	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3fb783c1	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x40502a0c	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x407da715	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x477f2faf	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4bd0625f	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4c51f664	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4cf93218	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4dc93f48	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4f63706b	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4f639a33	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4f69a2f8	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x53a2a3f7	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5824404c	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x59373097	handle_mmio_page_fault_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5d445f61	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6046f4d4	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x60481ad2	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x62acbccc	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64a34f49	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x661e3054	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x670f48da	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6b8c649a	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6bd12f07	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6e29f1dd	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x70964123	kvm_set_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x709cd8cb	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7326d005	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x757d966e	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x776d3920	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x793ce70c	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x794c0ce5	kvm_get_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7ad43efb	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7c502ab9	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7cdea381	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7dbf44af	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7e6826eb	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7f2c1163	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7fc0c48b	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x816afda0	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x82975074	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x82cab0a3	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8424fe27	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x84ae932d	kvm_resched
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8a26f7b0	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ac54f4e	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8b8a4abb	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8f07b31b	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8fd7ae2a	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x91d82ccb	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x986b27df	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a2fc374	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9c4afc90	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9c8e2777	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9cdc5190	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9ee59155	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ac893c	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0c5577e	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa11e28bc	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa508e36b	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa541151d	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaa79cab5	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaafb4f05	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaf275715	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb396b7f0	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba60bae0	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba77abe0	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc0c86c68	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc24d6f79	fx_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcaa89205	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcd09d999	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcef3fec5	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd1b0a117	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd5bec944	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd8773b1c	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd9c42ec1	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdd27734a	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdd51c762	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdd95bbf8	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xde3ce06b	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdeb9e564	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe03c6396	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe1b14698	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe23965c9	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe9f91b11	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xebffdff9	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xee4da7ce	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf0d3bf83	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf17c880f	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf835a80b	kvm_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf966a3be	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf96e95f2	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xfb17aa3e	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xff58d1ff	kvm_set_memory_region
++EXPORT_SYMBOL_GPL crypto/af_alg 0x10c05084	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x19eb0b46	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0x220986cd	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x289197b2	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x4e97cd96	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x5ac6f2a6	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x65eef7f4	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x93d2273a	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xfee6727d	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0xd8003125	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x3545a7e1	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x8aaf2b30	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x58d171e4	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x79e96020	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x18ca458b	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x2a40ce0d	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x2a7641e1	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x84655f6c	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x47a9df60	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xf06d142e	async_xor_val
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x6bbf8a53	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x0e68088f	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0xb24b0f99	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/cryptd 0x04b29144	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1473312b	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1b2628b7	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x3b534d1e	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5db51243	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7f5aa21d	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x8ecf6946	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x93086fd7	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xa70d326c	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xcf468f00	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xbbcaab2e	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5c03aea9	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xed8df909	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x842f1687	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x05a99792	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x066131f5	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x07923669	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x18a9bb82	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x19c5fd40	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x220dbd9f	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x41a2c2be	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x433b6cde	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5eacba1f	ahci_interrupt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x64d82118	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x694f923e	ahci_thread_fn
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6e05c4e7	ahci_hw_interrupt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7802208a	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x960e90c0	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x9e7c9330	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xaae37cdb	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xb66c5093	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xc1d63526	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xce17ec47	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdaf3ea0e	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xee60d4b3	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf6464980	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x11c3463a	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x070328c3	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x08269c48	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0b88f824	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2de07d65	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3b3040dc	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4760756b	bcma_core_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4a59e856	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x4bc0a7c6	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x69d61270	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x733df758	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x73e3db52	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9867ffbf	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9b7e6406	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa4d7cea0	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xac888d14	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb2985382	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb8176f59	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc0603d17	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd36eb0ff	bcma_core_pci_extend_L1timer
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd663342c	bcma_find_core
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdc29ebf1	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x055a3ba5	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x1525eb94	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x33fea54c	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x3b10aa8e	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6a92fb59	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb514c2db	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xca5eb333	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdc7dc4b0	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdf1d5751	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xf8014b3e	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL drivers/cpufreq/speedstep-lib 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x01a33ab9	dca_unregister_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x15e247f0	dca_remove_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x31a2c8df	dca_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x97ab1944	dca3_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xac34ecec	dca_register_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xc27c63f7	dca_add_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xd21f6bf3	unregister_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xe3a42db9	free_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xeccd800d	register_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xfe956fd2	alloc_dca_provider
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x0b3ed634	dw_dma_resume
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x6c031f9e	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xce2a3b82	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xd385c083	dw_dma_suspend
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xd660c233	dw_dma_shutdown
++EXPORT_SYMBOL_GPL drivers/edac/amd64_edac_mod 0xf1787ed0	amd64_get_dram_hole_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x07ecf387	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x08f4513f	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x13dd1128	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x26fa71c7	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3725510a	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3e001e92	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3e8435a2	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3f24db28	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x69259f22	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6d1493a8	edac_mc_add_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x746734b6	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x93ed1205	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x96025205	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa18d8f17	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa457b4a1	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa96cbfc1	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xaecb83ed	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb08bba9b	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb9dac4d1	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc2a0e7c5	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc8ae9207	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xed9c3061	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf0c8d143	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xfdca8e99	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x21626132	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x737912b3	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x013fbdac	cs5535_gpio_set
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x93f8fe67	cs5535_gpio_set_irq
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xc0bb404a	cs5535_gpio_setup_event
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xd3bd9300	cs5535_gpio_isset
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xe07c0954	cs5535_gpio_clear
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x3c746632	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x4373c0de	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x90354233	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x983eb242	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x3f8359f3	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x6b4ab8a3	drm_vm_open_locked
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd9ca8fee	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x2b2c59ae	i915_release_power_well
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x96108893	i915_request_power_well
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x39dec690	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x550ccc83	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x7d7ef905	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0290fddb	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0adbc910	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0f8d7cf5	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x193fd437	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x19d050dd	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1c7fa2d0	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1f136285	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x28f39dc4	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2bc6cb5c	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f127822	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2f9469f1	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3400edeb	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3dd16266	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x41f594b7	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x46874c06	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4c806058	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4fe5d544	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6125c2f1	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x63b2317a	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x67695817	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6dba98da	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7e058642	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7e916a00	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7eafafa4	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x80359285	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x86ac0a2a	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x951c30bc	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xad217cfc	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb436e6ea	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc03020f9	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc9039083	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd2ac3201	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd2c7ab52	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd9ebc843	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x04f41376	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x45a57612	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x667b22bc	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xaeeec88b	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x15d02970	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x70ca8361	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa5405c17	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xab13e329	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xaf5fee62	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xf00b4dba	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x4b97d610	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xd392e6c5	usbhid_set_leds
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x0f43f4e0	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1a0e5886	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x5fad7903	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x6d6c0e55	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x736fc1f0	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x751824e4	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x93625ced	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x950f211d	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa1bb5de9	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xaa540f82	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb8c46c8b	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xce027628	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe7325bce	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x16e72aca	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x4ab84844	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x4b20de9c	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x4cc6aadc	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x60eeeb2b	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x80c35fea	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x832a2d95	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x930e1ee7	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x961c05c9	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xa6197751	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xc0ec03cf	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xf6ab89c4	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x70036650	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xa70962bb	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xc17687b5	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x235a1a5c	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x67d32e47	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7eef00d5	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8e427633	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x9a838610	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xadeb950e	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xc565b434	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe411ed41	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xe6d6337a	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xee506fc9	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf4708b65	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf9094854	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x09e16285	i2c_dw_is_enabled
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x2daacadf	i2c_dw_func
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x3745070a	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x3e3328f4	i2c_dw_xfer
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x5bb1170b	i2c_dw_isr
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x625b79d4	i2c_dw_enable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x6e88cefb	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x7179c79c	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xc5d45383	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xcc35cb9a	i2c_dw_clear_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0x6aeae3a7	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x57a407a7	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xeeac2e5a	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x38d532d0	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xb67c56e0	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x210f2485	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x34fc4520	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x598181fb	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x77133bdd	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8e5183d8	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x947b61c5	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xae9aef04	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xcac50625	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xf684bc6b	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x11f1646c	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x23d42801	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x25f93639	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2ab5c8bc	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2cb91f93	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3e281128	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x64be2ea3	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x6a5a043b	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x7acb5448	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9292a61f	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xafc18102	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xe852998c	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0ba99675	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0ff7a353	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x18d287b7	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x20928792	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x23781034	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x39dc9478	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3df8e7f8	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x458e9f43	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4c8463ce	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5bb8595b	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5cf4c42f	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x61b2b1aa	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x86dc886b	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9908b528	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa282cc0b	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa77957e4	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa834174f	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xadacb0d0	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb79bedd5	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbd92de31	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd9f5f96e	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe6dd9bf0	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf156a270	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf7e4a094	iio_scan_mask_set
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/infiniband/hw/ipath/ib_ipath 0x1514b2b2	ipath_debug
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0x7bb975cc	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xbc53f53f	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x8218a7da	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xa16651d7	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xe70a9613	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x0abeda4c	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x5a4789b0	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x67a9514d	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x00cbba6c	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xb0394d63	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x17ee97ae	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x291d8d34	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3ac13567	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3d00ebf4	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x404c1453	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x5df20909	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x71cfc899	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x91580997	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xcff8ab29	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd307093d	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf605b70c	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf611376c	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x003f9596	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2720ad07	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2b4aedaf	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x2b681e93	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x3ffd749f	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x47760d05	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xa619b157	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfc904d85	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xfd10c253	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x005e5094	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x19ac769f	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2e8c7c3d	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4f2d5686	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x524b7658	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7567fe60	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x772fd0ba	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x9841632b	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x9bc9ccd6	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3151853	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa85209e1	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb9507849	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xcf996f13	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd02edbfa	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe2cc259f	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xeca3b048	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfaca06bf	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfb9d1fa2	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x1c1567c4	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x38175bf9	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x44196e2a	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x567f79a5	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x5a26fdf9	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x768bf7a6	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7e41cdab	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8cba1363	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8e71d8c3	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9cee1933	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xbb0fb88f	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x0ec17d44	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x26062738	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x40c27b88	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4546e300	closure_trylock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4c49fc16	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x51a15737	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x52ff27f3	__closure_flush
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x616b6217	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6907ac0d	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7be42a1c	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7e532a71	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7f7b5e93	closure_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x8a4afa11	__tracepoint_bcache_alloc_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x914361f4	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9272fb0f	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x938cc2b2	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x94264614	__closure_flush_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9507b983	__closure_delay
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x9842bb88	closure_queue
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa39e3a55	closure_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa649dd21	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb157059f	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb317649e	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb493772a	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb834c124	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb8539701	closure_sub
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbb1fc0a4	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbc4fcb1e	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc1474d91	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc379085a	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc5aed8ad	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc7eda602	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xce055cbe	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe20fe821	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe24daf87	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe2ed0930	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xea2303e0	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xee7e495f	do_closure_timer_init
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xee7ebbb9	__closure_lock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xef1156ee	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfa839ac9	closure_wait
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc131205	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xa52a3ef6	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xaefd5f8e	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6a8200e	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xcb087b1c	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xcf68a5e5	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd785b483	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe6b92dc4	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xebd06eaf	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6aba7f5e	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6e5873b5	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9310ba06	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9c256008	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa1d2413a	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa448e19f	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xafbda3f3	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xcbb1bae2	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x231c3da8	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x2501ae80	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x3620ad76	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x500ed0d4	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x9eb71b5c	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xaf9498cb	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xbe391043	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x4200631d	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xf0d405d5	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x1b24f3ee	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x42c6ce96	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x4430764e	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x44878215	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x45ab972a	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x523f0a28	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x5bc5adfb	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6b46a671	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa68e1f06	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfad9d53a	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfc62ef4e	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x17c36f29	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1cac81ac	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f74609d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x371fd72c	dm_bm_flush_and_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x38c75c44	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x42dbdfc3	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x49b35849	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x55b4bd4d	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x68fae9d2	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x80c89b3d	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x827a42f4	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x85a431f1	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9f624559	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa0bbbb49	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa13861b4	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xafeda29f	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb7bad799	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd29923fb	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe44b4b9b	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf375d009	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf475af48	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf5455120	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/raid1 0x595d3686	md_raid1_congested
++EXPORT_SYMBOL_GPL drivers/md/raid10 0xdfa29e96	md_raid10_congested
++EXPORT_SYMBOL_GPL drivers/md/raid456 0x889c7383	md_raid5_congested
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x17bba7af	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x43dc6124	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x5079bc10	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x56f9a96c	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x65c6480b	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7ba618a0	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x999625a4	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xb9105005	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xef144516	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xef2a0f44	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x18235736	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x20c04c39	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x31bee8f6	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x33328287	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x66ba449c	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x8a47efa8	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x990f9949	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x04a431e6	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x115dfb3f	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x11c5db49	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x3a85207e	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x41c57cfb	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x42b7f663	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4aaed520	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x4bd842cb	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7e265e25	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x99a81ab3	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9bb2dcdc	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xba8ee677	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc48c50a2	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc93b9427	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcf66cde6	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xddc0e6b4	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe2415015	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xece2441f	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xc953e668	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x64fb791c	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0a7716aa	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0b402f6a	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x14085cc2	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x22d62c35	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x252e3952	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x343aa7da	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x3dba0179	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x629bd6f1	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x9ea8fd5f	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa49dbc2b	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa59ce1b3	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa852d34c	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa965ea8c	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xba100fb2	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe905304e	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xfc3258d3	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xfd2e1e8a	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x0e9b6c18	saa7134_queryctrl
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4beb1786	saa7134_g_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xad01ae31	saa7134_s_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xbe1c716f	saa7134_s_std_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xd35effb6	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x310d726f	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x4acdc60c	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x9e127b06	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xdbaacc74	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xdbe6282d	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xec11da6e	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xfe817db7	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x57ecdd9e	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x7ed1ef2f	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0083f0c1	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x32eada4a	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x36788a9c	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x37c071b0	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4915c9db	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5afbc314	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x61011998	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x66f899a6	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x757fe2c8	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7bcf5aab	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x81aac2bf	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xac0d2c72	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xbeb76c9c	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcf746f9c	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe9911623	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xeb1c7ef4	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfc93c460	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xf9692c39	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x5c1c192b	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0xddcaf126	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xdee3b7bf	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x255f3341	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x6bcca13a	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xb4528f02	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xcf7a294c	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x81d49ad8	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x17a62cb7	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x87244b61	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x513ed925	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xdaa67eef	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x6852006c	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x00738626	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x08f82669	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x32fdfdd6	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x39370b8e	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4afd5812	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x74d7521a	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x793a9d5b	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8dd27e8a	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8fe21b2c	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x97c7c6fa	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa007651d	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcb6aadb5	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xce5f5d29	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd5462183	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd67a3788	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe0b7ce23	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xed4a98be	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xedee8d47	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf535ef7d	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x1466aedb	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0xb20ef6ae	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x01bcef08	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x089799e3	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2dabef48	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3b27b0ce	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x4425308d	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5496bcac	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x67dbd4ba	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6ef9ae6b	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x78fc6c33	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8ae9f684	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8e44ca31	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xa21c2a8c	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbd68d377	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xd88159df	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x03a56a87	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x5c6bfd4d	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x6a31c5fd	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x85797ff9	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x14d0510e	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x53105839	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x5d9d3491	v4l_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7eaf8e7a	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xa98ac0e2	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xcf234bfe	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xde60ae91	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf00b7c2e	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf82a0adb	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x417c093a	v4l2_int_ioctl_0
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x87eac4b4	v4l2_int_ioctl_1
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xa5228b24	v4l2_int_device_try_attach_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xb3596744	v4l2_int_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xfc2cff6e	v4l2_int_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x035a88e5	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x148fd300	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2321249c	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2f9af050	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x601e14ab	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x67d0d6f2	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x888f18f7	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x9450b7e0	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x953c5a56	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa1c84d7b	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xb8cbea4b	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xbdda6f2f	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xcbd2346f	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe879a1de	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x09f0edac	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3496c223	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x349b2e82	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x383f65a4	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3a02e901	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3f54afed	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x50c93dcd	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x579da618	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6e66b8e4	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x77e3650b	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x803b6999	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8c3323f5	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8cce35d3	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x916453ef	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x96df6168	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x991cb066	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa1380104	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbd32082a	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd1d48e5c	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd2c69388	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdadfa58a	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe444414d	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe9910b33	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xf7aa3a34	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x1f919c3b	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xda3f10a3	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xf4075ad3	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x0a023ae8	videobuf_dma_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x0cb0e137	videobuf_dma_init_user
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x1f843463	videobuf_dma_init_kernel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x1fcee55d	videobuf_dma_init_overlay
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x2f3dbdfa	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x553a86d0	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x58764094	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x8ad863bc	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xbbb7019c	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xe245ad25	videobuf_dma_map
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xb493357a	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xd5331bdb	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xf3165de8	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x00aee959	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1efffabc	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2edacd23	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x329e4f17	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3cda0e18	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3d7ceddf	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x403e1873	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4277f51d	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x58666e09	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6cd497de	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x6d88ebb8	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7c2706c8	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7d762b4d	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8a96417c	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8ff695c0	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9805363b	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x991e087c	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xab37b434	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xaba1fecc	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb37058e8	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb7a82ede	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb8f81acf	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbd6a9f4e	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd0dfc9ed	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd178d31e	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd5028a1a	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd7756558	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe6152953	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xeb8b259c	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xef9f5012	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf7900e1b	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf89e5e73	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfbd34471	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfbdf6ced	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x05bdd2f0	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x3594edd5	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0xd820ae17	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x1b7fdd3d	vb2_get_contig_userptr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x3cce62d9	vb2_get_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x88f5effa	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xe039d121	vb2_put_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0xfad6df54	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x11439727	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1de9bc05	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x229b2e5b	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x284c9d32	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2ebb7fb9	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x49f25e87	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4b434089	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4d065fe5	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x51351b2d	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5a73ff4f	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6b6b3bb6	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x76a2c486	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8168c847	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x87b934d5	v4l2_compat_ioctl32
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8aa4c89b	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9305a7a1	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x975c1944	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb404563e	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdfb05f0e	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe5f3be66	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe6591aa1	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf20ac2e7	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf59be8fc	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfa93e0e7	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x2b203622	i2o_dma_free
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x2f85d2df	i2o_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x3c3aeb53	i2o_dma_realloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x4f31e21b	i2o_dma_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x7b042c2a	i2o_sg_tablesize
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xc33d339a	i2o_pool_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xd1aa343f	i2o_dma_map_single
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xd60b190f	i2o_pool_free
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x3c0f7e56	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x64dcea48	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xc8fe7501	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0e299bc4	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x1745f6f7	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x36c9e3df	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x49be10c5	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x759371fd	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x7956132e	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xa252ecce	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xc5bdd127	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x2595bdd9	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x7734ff72	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xb0314d5f	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x191f42e4	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1b904dd0	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x1d56c55f	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x3d8b20d6	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xb914967f	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xd5c90a78	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xe06442c1	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x23e0422a	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x3977e80a	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x70edc2cf	mc13xxx_common_cleanup
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xa14c9c62	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb343690a	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe1f6d742	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x04e7c647	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x05d1f564	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x36e31a69	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x4e1ba56c	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x53d9a931	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x767b7312	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8d3f832d	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x91c15597	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x9a6a6eff	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe4c22a89	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xec3cebf3	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x290a14a5	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x830c979d	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x11d20000	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x4f6d8e6e	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd35c461a	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xda2299eb	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xe2041938	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0373a2ce	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0db52ff2	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1faa4032	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x217ed26d	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x25b69465	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x3326d5e2	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4677c345	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x4dc2aa08	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x61cf9c31	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6f0f6f84	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x732e0d6f	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x8cb0767b	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9b307de3	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb6267c67	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbd03a4ee	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xc04e88cd	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xd10ad97d	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe0a4d7c1	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe8a2dc98	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe909caa2	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf665c94d	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x137899d9	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1b6f214e	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1f00da9c	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x205c0d9a	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2211cf22	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2bcdd9ff	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2bf9197f	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2d74b86c	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x339e6f4d	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4d41a6e1	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6cf081a7	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6e6d1509	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7386fc83	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7c80312d	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8e016fb7	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x906977c4	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9c295928	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xa99bbf57	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xab2e6990	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xad8848b8	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb8e17b2d	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbd983367	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbf55779e	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc01b0e23	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc3be4389	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc7853fdf	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd0183a2e	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe06d730c	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe4398b19	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe5292fab	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe99e1d52	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xed2a3d66	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf0b94ab2	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf5174807	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x4a109c4c	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x4febcbd9	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x9e14de09	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xa8f04d57	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xdd3c41e1	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x0da5b2cd	am335x_tsc_se_set
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x905f85c0	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xb0d406ac	am335x_tsc_se_update
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x136f745a	tps65217_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x901d897b	tps65217_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0xa02a4f2c	tps65217_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0xeea98854	tps65217_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xd2c54f0b	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x264b0e45	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x65e8d2fb	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x95807fb2	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xe1c6df9a	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x1be163af	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x346a4681	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x60858802	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x6d097364	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x7eb38ac5	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x8c0a88c1	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa2aa3e6a	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x22d36d28	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x3367e219	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x427249b2	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x89581095	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xacb1fca0	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xae1943b1	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb36c0918	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe2e0a44c	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x156ba8b1	mei_cl_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x1c3f001f	mei_cl_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x2bac3363	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x39ace08e	__mei_cl_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x45b5a56a	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x535d34b7	mei_cl_add_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x5e4c3d39	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x60dd90e9	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x630aabe5	mei_cl_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x79692069	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7df6a836	mei_cl_send
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x863b1d47	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x8bbd3a53	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xdae7757d	mei_cl_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xdf1a8967	mei_cl_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe05ea3bd	mei_cl_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xe947a5f0	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xefc7bdb3	mei_cl_disable_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xfa68e422	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xfb753c83	mei_cl_enable_device
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x329a1d60	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xfa818db8	st_register
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x31f6ad8f	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ba5c46b	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x53c20507	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x76f1d5c5	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x81d61eef	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcff91c6e	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe67343c1	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x204ee65b	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x287913c2	sdhci_disable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x336f9ea7	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x33bcd72e	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x5270c1ed	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x6fdf8199	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7750e584	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7c995715	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x95c1106d	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb6af69c0	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x1ec0091b	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x2e925bf2	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x52dcf9e2	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x740db0e9	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x9fee2c66	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xbcc874ff	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xf1056d0a	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x001d754d	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xc22a7533	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xfd0350db	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x6ce2ef3a	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x9f1b20bc	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xe1496b6c	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x7350a4a8	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x3f289482	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x81a13387	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xf74fe08a	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x00e026a1	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x02916be0	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x04f3edf7	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1b860ac6	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1b895f85	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1bd1d633	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x1f2b4f1b	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x2c23c267	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3616e8dc	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3c760a5c	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x429886dc	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x44ec8497	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x450b913d	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x4603bbb4	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5296fa5f	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x570a4bcf	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x71827851	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x77257917	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7a745476	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7b7dbc55	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7c6c080d	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7f586a21	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8b634eea	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9365f5d5	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9b43ec6a	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa145aa3a	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa37765e8	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa41e2387	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa7976a85	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xac69886a	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcae75f87	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcc1f5c5d	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcce60791	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd2ef77bf	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd85209eb	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdaa9666a	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xea5a1919	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xeab72d9c	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf8c9c652	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfa184d96	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xfdec3272	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x009a8df9	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x3f79bf79	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x452f29c6	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x86451575	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xf2b0dda0	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x8366c5e0	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x96d8fe30	nand_update_bbt
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xb1cce46d	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x85c83d93	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x08980bde	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x72a13d76	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x198e29ac	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2d9c25dd	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e6e007	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x68ac34e6	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7fcbf2af	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8e3d3652	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xbead47c9	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd5446ec3	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd996e483	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe0dad104	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe8824f1d	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xed1d6a64	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xfa2b2748	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x267caca2	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x377a05b3	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x52598b66	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x7a283a39	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x81a8f54e	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xc644bd8d	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x01c141d6	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x34e1ca50	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x3a9440eb	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5b28369a	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6c475071	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8956241d	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x994642f9	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x99aa5e98	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9bcca442	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb5c9af83	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbbd32f58	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xccd49886	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xceb19098	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xd175a4d3	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe649adc9	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x3463fd48	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x476a3c70	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x813d5500	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xd43d2f28	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x1042ff80	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x1d62c781	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x2a0fd48c	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xebbec254	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x2c0e4dbf	macb_ethtool_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x508aa806	macb_get_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x5f68c3d0	macb_set_rx_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x7a0a12be	macb_ioctl
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xae9e2e37	macb_mii_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xb1a244e1	macb_set_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xeb0b0ee7	macb_get_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x07e47081	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b4823ea	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f71e5fb	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x105c9cbe	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x13a76d8b	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x13ac2c37	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1872db3f	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x191e280a	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1df3bd17	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1f1993ad	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x21b86a36	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2473bfed	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x251a700a	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2a898c36	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2ce36e8a	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2dd11667	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x330bdc13	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x36952d54	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3699eeed	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3de96875	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x45d8af30	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x495a587a	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4d00234a	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f3620d4	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4ffe9449	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5380deb5	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57494173	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e5b612e	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5e6f8a74	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6123752b	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6bcbe39d	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6d8dcf56	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6e5b60f3	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x722e1394	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x73eecbf9	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x75725ceb	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x79d66f6f	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7e7ae258	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7fa9b894	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x811fb2f7	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x82f2001c	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x882a40c0	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8a675bee	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b71cd02	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8d787748	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x917f65dc	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x92a4cdd7	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9312ae88	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9373abae	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x95c0b3e4	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9ad1b4c0	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b02b10a	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9df06861	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9e431735	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2c5acd8	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa42853bf	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa460f499	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa585dadf	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa8e6ca62	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa975858b	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa99bfead	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac681572	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xaf0854d1	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0830edb	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb2accfad	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb41a0642	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb9d50ce3	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xba8f8e4e	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb550fae	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbcb7f547	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc04047ef	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc7b39af9	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcbfe01bf	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce05b4cc	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xceaca615	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcfaf56b7	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcff7a4f9	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd36e9703	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd67e41bf	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd6be040f	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8353083	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe165d116	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3e8e8fe	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6325d97	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe9b425ff	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xee7eec9a	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf2ccf9fb	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf9d4a9a6	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfbeec891	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff18ba19	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2e59ab2b	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x498f93f9	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5b97ae10	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x6b4ef393	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7babd7a5	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x7da7bbcd	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x83bd5e37	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x85edeff0	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x91f8aaa1	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x92a6283e	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x92f9592c	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xa5534351	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd067669b	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd6c4ef56	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe1ab9e13	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xe1d1c84e	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf1e45e5f	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x07cfa6ac	macvlan_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x2b03b800	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x85c8e1c1	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x8e679cb1	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x96c39b98	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xc7210cee	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x9683a89b	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xae2c9470	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xb0d9b525	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xffac40fa	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x1563589f	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x70c6246d	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x7403b672	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x7f265ca5	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xae8c03b6	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xdd932496	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x02f2837e	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x5805606a	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x816a7208	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x9621c30a	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xc3312e01	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd511fa04	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x04d48f08	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x09279fba	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0d5de41a	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x298608b9	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2f526530	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x396a6631	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3b950362	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x50b69d6c	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x51cf3708	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6010709b	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x60b8a2f3	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x671c4d62	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x68e55b50	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6c4796f8	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x780b385f	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x78d837d6	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7b0f2a76	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x843c6745	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x903cfc73	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x940dabec	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x970b2566	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9da8c618	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xae3bc720	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb597e334	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb65b3f3c	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb81ba603	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbfb88a91	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcb159114	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcda38b32	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcf1e86a8	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe56df67f	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x029b662c	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1843ca95	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x59184ff9	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5cced134	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7d1451d5	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x811375c0	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8f25fea3	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9026a9ac	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x95fdc269	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa21f028b	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa4032a68	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb1cdc99b	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe0454d2e	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe6ac41d0	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe6d41e9b	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf2714ee1	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x45d8988a	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x51e91554	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x5fe9980f	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xd2225913	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x92579292	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x1772d867	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x9d6805c1	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x9e0a23bb	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xd1c21fb2	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xf7dc4c6e	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x129e037d	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x21890380	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x23b31849	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x25b2527d	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2c3b8c6f	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x40c07971	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4233b341	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x45a1d4bf	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4bb44470	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x59f50a3f	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5d0a212e	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x61155e03	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6715334b	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x702f518e	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x71445364	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7cff80bb	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8c5d5ab3	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x91b13b89	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x95795c57	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9dec0524	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xabdf4c25	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb041ed82	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xc4ca9d7e	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcf341945	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd1db77fe	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xdd3e32a4	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf57685ce	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf7c1cca3	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x07b11bf8	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0c30fcbb	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x454b67f7	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x4fe701b6	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x543085e1	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x61dde1b2	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x646d426c	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x6bf3b7ff	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7b83beba	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7e01c26a	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x8b2b04a6	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbb6669dc	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbd14ebaf	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xcdbe9265	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe0e86a7e	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe5bb2913	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x10b9ac86	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x17c7f868	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x2405e0d0	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x3e75bffb	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x643313d6	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x99cd6534	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xb2f44c3c	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xbe43668d	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0x56634ded	if_usb_reset_device
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0xce39e6f8	if_usb_prog_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x09f9a2e3	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1a238bd3	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1ccdac61	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x1f8cbfcf	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2da6caab	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x76c106e5	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x900d151f	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xab3b2641	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbc8356ae	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc5c6da38	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xcd643506	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd0c24840	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf3c5cf26	mwifiex_deauthenticate
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf8855f11	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x08127cd1	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x25fe9067	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x279e324d	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x697993f7	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8e769de1	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x9f7cf07d	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xab60343f	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd2e396de	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe10a2d89	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x09c1f54a	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x09fc20c4	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1513364b	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x15773d71	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x197427d1	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1aba65f2	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1b50a14d	rt2800_get_tkip_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x225c7be6	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x28556a6c	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x338e4b89	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x34062046	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3617302d	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3fe216de	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x413cdcdd	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4d10cdcd	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x522803a1	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x60e55495	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6337217d	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x641681ad	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6a6355ea	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8170c8c5	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x81d2e717	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x87766819	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8835198d	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9efc9ea0	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa41ddfb0	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa5a39148	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa93dd38a	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc671562b	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcb41078a	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd50bb8c6	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd947a949	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe3a02a73	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe851ffc1	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe857f644	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf31957b3	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf7665603	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0513ab99	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0709ff79	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0a4dfc12	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0e0b1106	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1ff21537	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x20be5bb3	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2158b665	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x22b0b1af	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c3651f9	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x321f4581	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3e41b21b	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x44f5cccd	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x463db085	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x533a3444	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5e3b307f	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5f3eb43e	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x602f7200	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x612ff4bf	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x66383047	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x68f9d4d4	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x69f2ad14	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x6e53d714	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x754b45a7	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x76feac10	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7c6e08a4	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x811199a0	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x85580e4a	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x855cb61e	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8dcc7645	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x95eca630	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9ac6b89f	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9c78e319	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9dae6c26	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9eb42119	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9fec3517	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa1aabe19	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa3141d29	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa7abb6ff	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb61ea6b2	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc40c2b6c	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcffad1cd	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd41cdc84	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdc82415b	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdc8cfb29	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf559bb30	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfeceb8a2	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x17e31824	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x236d944c	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4f248e7b	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x7c0b7856	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xda6ef987	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x0f4187d6	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x4be7ecb8	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x5b0ddd4d	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x9b37d218	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x054b5dcc	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x14d0a521	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1614490e	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1a84db13	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x23994551	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2ea2a6ad	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x39794b45	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x3ab2736a	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x3f909a29	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5b4fda33	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6c096452	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x7757c696	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8fb168ba	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb392be9f	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd2c1428c	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf5163611	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb68a7a18	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x0e33f1c9	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x11a37f8e	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x16f92e77	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x35631fbf	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x3786caeb	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x519f603b	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x572c0b2d	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x5eea0838	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x6a7e16e5	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x6b4de810	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x70e2a248	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x73b25b06	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x74701fa9	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x781e384d	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xaabf6e4f	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xaadcc169	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xc3b5c943	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xc989722c	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xd2b1f48a	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x58a88bd1	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xbd41e546	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xce87c59b	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x06363f32	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0ba61913	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0c59c75f	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0e753c25	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x10c4084e	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x110e73d4	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1cde6182	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x24e45e11	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2732e388	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x319c53a7	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x33fb9b04	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x355994f7	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3625d01e	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x41042db7	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x465176ca	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x46dfe04f	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4da3b16d	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5541a5b6	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x64753579	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x65997d3c	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6f43c572	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7363391e	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7cc17f0f	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8d2f7594	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8de26726	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x914e3eb0	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa5c71497	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa9a27bec	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xae2cde43	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xae692a14	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb1c3c57c	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb3db7421	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb94fd309	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbabeeafb	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbf6bd7b1	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc1bcd256	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd316d87b	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd39bb505	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdedb3f0c	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xec768e95	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf90adcc9	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf92ac369	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x3b577068	nfc_mei_phy_disable
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x8b4e7b3b	nfc_mei_event_cb
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x9ba51237	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xc4993f08	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xd3460133	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xe82e19a5	nfc_mei_phy_enable
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x283d3737	ntb_unregister_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x30934216	ntb_transport_max_size
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x32537aca	ntb_transport_link_query
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x3d54dbfc	ntb_transport_tx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x436098aa	ntb_transport_link_down
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x4a648673	ntb_register_client
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x77ae9ef1	ntb_register_client_dev
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x82e6c13d	ntb_transport_qp_num
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0x9c992c8f	ntb_transport_link_up
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0xc270dc24	ntb_transport_free_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0xc37d9036	ntb_transport_rx_remove
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0xd40e7a02	ntb_transport_rx_enqueue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0xe269e125	ntb_transport_create_queue
++EXPORT_SYMBOL_GPL drivers/ntb/ntb 0xfe897ddd	ntb_unregister_client_dev
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x83617ce8	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x96976768	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x561c634a	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x876d29f1	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xda29f8b0	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xfb882fb7	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x3853320e	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x6199e9d6	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xaaf753d4	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x1c286983	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x58bb7d6f	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb517abd8	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x118e131d	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x8b75e5dd	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xa2d7cb79	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xd3528cc7	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xd59e806b	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xdda21ab8	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xeb80f3d6	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0835a069	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x111607a2	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1184b7fb	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x11fa08ad	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x13438873	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1989eae6	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x23a2a610	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x26c7c594	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2c6f462b	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2f8d08d5	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x313ada71	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x35c84570	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a1de38d	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4ace9edb	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4b729796	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4cb091e6	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x50dfd834	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x609d698c	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7a762081	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7b7988f7	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7c124457	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x818b1725	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x897d43f7	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x89d55d69	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8b842ffb	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8f25ad3d	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x90c86c20	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9277889e	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x92a34ea1	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x991cc18c	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa754a8ae	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa7b2364b	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xad52494d	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xae5285f2	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaf387ff2	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd48899b1	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xdd45f9a4	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe2ef939d	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe354841d	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe3dfa268	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe858a268	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe8e2ffb7	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe9337d02	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xeae8c5bd	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x55e7c483	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x593a36c2	scsi_dh_handler_exist
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x5c6c0ac9	scsi_dh_activate
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x8cfa1e42	scsi_dh_attach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x969457d8	scsi_dh_set_params
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xb85717ff	scsi_register_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xe178134c	scsi_dh_detach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xf9f01c54	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x106ad1be	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x234d0c1f	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x289fea10	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x2c78f865	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x54ab4b2f	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x6089cf4e	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x62351b34	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x688c6a95	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x6a9e41c0	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x89308165	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9796e955	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc0644c06	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xd2dd9cd9	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xdd4e8cbb	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe2ffb0fc	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xf7d44a95	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x5112b2c2	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x7a985521	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9b333f80	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xa5777cbf	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe1e1f7c3	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xf9e86c03	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x040f8c9d	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0a6f9893	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0d62b914	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x28b87395	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x28bf14f5	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2d7bed7a	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2e969fa3	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2eb88f8b	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x35b47666	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x37cd938a	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3cd09c02	iscsi_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4298254b	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x42ed93df	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x56eb3800	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5de16ba0	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6d07edf5	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7017cd22	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x718d6978	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x73c2ea0c	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x823af5db	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8279c39f	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x846c2e38	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x852c0e9b	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8acf9ad8	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8b953d25	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x921992c3	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa21d4413	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4832cf0	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa862d95f	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb2c5c142	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb2fc0370	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb32ab49d	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb9c25e3d	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc4792bb	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc13ae011	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcc8d2b01	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdc869ce0	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe6d16b77	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe7b4abc6	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeed1a84d	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf0a58b3d	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf553d558	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf60235fb	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfcd2fab4	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfee75ba3	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xff2bf578	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x336e45e5	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3ff1578c	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x576df58e	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6559c5d3	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x66aa78a6	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6b2aada5	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x7ba9120a	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x86b504b9	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8a0b547a	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa141db40	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xa639379e	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xac552f3f	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xca4bce20	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xcf00c71a	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf20581f8	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf7017add	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf8572b0c	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0c191aa2	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x119efd0a	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1d7ec791	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x22d0426b	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x232e455b	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x28bd2875	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x2c81cb73	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x31b9ffec	sas_change_queue_type
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x56d6a769	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5e9b8dfb	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6ca8db9d	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x880585cd	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8c7a09ab	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x925d91f0	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa1b9d786	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa4cf7072	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb0422a59	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbfc716af	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc67ff6a6	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc83bf509	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdb02acdf	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe36d429b	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe7618d69	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf5452b4e	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf92b7075	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x4418421f	srp_cmd_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x4488a9fd	srp_transfer_data
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x4a3c0997	srp_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xac8395d1	srp_iu_put
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xdf059ff3	srp_iu_get
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xeeda7864	srp_target_free
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x0b660e0c	scsi_tgt_it_nexus_create
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x398455fc	scsi_tgt_queue_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x5af40ca0	scsi_host_put_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x773e9a06	scsi_tgt_free_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x79fb9ad6	scsi_tgt_cmd_to_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x84fc1d56	scsi_tgt_alloc_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xb1d3c307	scsi_tgt_it_nexus_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xcc0f0511	scsi_host_get_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xf8050f20	scsi_tgt_tsk_mgmt_request
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x000e87fe	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x15a08110	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x183adde5	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1c906729	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1e4668aa	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2545d0f7	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x28169761	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x36530f0f	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x43350e7c	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x460d43ad	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x52b94c12	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x56c3202c	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5bfce0d3	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5e3ea6f7	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x674ddca7	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6cab4bc5	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7100ef35	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x74b19377	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x77d2569c	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x784317f9	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7e89f105	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x836577a7	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8a259c75	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8a9ed107	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9465c172	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x98222cab	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9f76eeb6	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa3173f01	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa90ec5dd	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xaa84b3bc	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xab5b2a91	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb1b5447f	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc133ea94	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc5b5d655	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc6c57e03	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc8528a81	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd3f9fa29	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe309d655	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xed39392d	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xeee035f6	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x6180a273	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x7d6ed5b4	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x90ea1111	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xe584f5bf	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4f84c4e4	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x5681e534	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x93f2ab77	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xf356f977	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xfe98096a	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x1890283f	ufshcd_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x6aad6ce4	ufshcd_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xbee3f9e0	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xca122fdc	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x11d5bab1	spi_bitbang_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x1e40af22	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x4809d16f	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x80917f38	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x8bc91840	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xfafaae85	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x41073062	dw_spi_xfer_done
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xa658111a	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xc4183f9b	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xe67fe94c	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xf02a439b	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x6c66b252	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x03b240cc	comedi_dev_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0aeb0f93	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x17fd9cab	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1b4c180c	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1d09b3e2	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x33994f88	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3cedc77a	comedi_buf_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3e35075e	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3f944261	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x492490ee	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4ba39574	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4e251d9a	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x53299209	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x54a25363	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x57cbf98c	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x58b72484	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x65d7eef8	comedi_buf_memcpy_from
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6a8e5588	comedi_buf_memcpy_to
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6b711a23	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x706afc52	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x74cde514	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7f6f2994	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x85f507ad	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8ad170c6	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8d1e37b2	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x90202b1d	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x95dd4b1b	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x98915374	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa08bfb14	comedi_error
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa15d96c4	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb7798962	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbcb8972b	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbd9c86f4	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbfd2bd2a	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbfdc1bd7	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc3da34cb	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc799a1c4	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc646b4c	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd278f46b	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd4c5cce2	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdde10e98	comedi_buf_get
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdf1abb09	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe950ffe6	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf17e967b	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf43c31aa	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x505f89fc	subdev_8255_init_irq
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x7cc3e16d	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0xc665492a	subdev_8255_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x97b25441	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x27369aef	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x2e91ccd6	amplc_dio200_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x4f2ab787	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x2cb80581	cfc_write_array_to_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x369f157f	cfc_read_array_from_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x9da7344c	cfc_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x60153cca	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x11baa19e	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x1f7d3793	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2ff6076c	mite_setup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3ba12d0f	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x4a3f77df	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x75db5fec	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x7b6c7436	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8091f981	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x915bf3d3	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x92bec2b6	mite_unsetup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9a3fc1d1	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9b28b8ba	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x9c288c87	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa0c370c1	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa6300d8d	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb053daf0	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xbe2ae167	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc5c70724	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd79ff4e7	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xee5f7778	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf18ed0c5	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf62e4ade	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc 0xc17e3211	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x168f83a2	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x2fe45ce5	ni_tio_rinsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x5cbc1862	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x7119dfd4	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xc34c273d	ni_tio_winsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xd02a53c0	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xde419ea2	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xdf980acb	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x0ee7bb65	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x2d35c409	ni_tio_acknowledge_and_confirm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x648dd10e	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x73880a54	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x76b24c14	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xc5353217	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x30faff84	comedi_dio_bitfield
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x4d29801f	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6988940e	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xa883f7b0	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xae4457bf	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xebd9b11e	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x2206b003	dwc2_handle_common_intr
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x38a3b8cd	dwc2_hcd_init
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x6fbac374	dwc2_hcd_remove
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0xa8514446	dwc2_set_all_params
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x5a1e3e02	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/rts5139/rts5139 0xbd5a0e51	rts5139_usb_ids
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x005c49ba	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x03d85647	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1a8012a7	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x24081073	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4bd53da3	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x6c04b535	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x892d7c77	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xcda38867	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd0913c77	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xde7ae2e8	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xdf4b212f	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xfb56156d	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x0c19c0ee	usbip_recv
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x4e706a5b	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x65ea0e08	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x934ada11	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x9501f075	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x9e33de34	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xa00e3c05	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xa80d4d62	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xbe98a027	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xc6d1e455	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xce5cf33e	sockfd_to_socket
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd7dd6dfa	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xec846603	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x10102dba	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x26cc4d58	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x942db329	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x9d8508ac	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xcdfc0649	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0x286df986	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xd9259868	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/dwc3/dwc3-omap 0x4db92025	dwc3_omap_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x03a2e7a6	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x07219868	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x1d79cbe8	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x221ab3b2	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x24fe572f	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2cf64894	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4340a8d0	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4a1849cc	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5b821c22	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x73bd4fdf	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x77774a30	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7803ba5a	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7ca2fee4	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x80f5daf2	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x83164bd2	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9f3c02e8	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9f6fd685	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa724ae9f	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xab030717	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb8757084	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc11d012d	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xc535cb43	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xec3eb5f9	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xef7d27be	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf3480a5c	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf588644c	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf977a819	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x32e4cadc	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x4054354c	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x8e27d6de	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xf1981607	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x42e65551	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x4381907e	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x678985b9	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x848fcc8d	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xa84206ef	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xb7f7ceb7	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xd61a20d9	udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xdcd18891	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xf30490ae	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x836cd76d	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xcbf4d0a5	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x042f9990	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x1e3c646c	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2dae6ab5	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x315f87cc	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x3218695f	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x6ef17963	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9d31bb5e	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbd365884	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xec78c219	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0x750c3589	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/tusb6010 0x871d8d38	tusb_get_revision
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x49cfe8c7	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0x482e3f16	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0x9401c280	omap_control_usb_phy_power
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0xca646c31	omap_get_control_dev
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0xfa6fc8be	omap_control_usb3_phy_power
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x04395195	samsung_usbphy_get_refclk_freq
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x07be04c1	samsung_usbphy_parse_dt
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x210b2700	samsung_usbphy_set_isolation_4210
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x3ddabe63	samsung_usbphy_rate_to_clksel_4x12
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x565a2e89	samsung_usbphy_set_type
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x6f898ec0	samsung_usbphy_rate_to_clksel_64xx
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x7be724f2	samsung_usbphy_cfg_sel
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x10b0dc93	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x00065b3d	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0b4c9e7d	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x19f2ca59	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x20d52b58	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x349acafa	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x35f5c19f	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x39aa0d0e	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x747604ab	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7ba031d0	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x9ae30fb9	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa837e354	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xb908ce1d	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xbdb867bf	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc1dc8ce7	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd78e99d3	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd9a3ab3e	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe2897e14	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe57f8184	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf72d9d03	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf94abc2a	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x05d7a35e	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1000723c	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1c7b731e	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1d8d43d2	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x29c7f696	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x35d2d254	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x441faa13	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x44391999	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4bbb844c	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7b791fbc	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x822c46f7	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8962f518	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8a024244	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb4d5fc06	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbf97da36	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc09a9492	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc599a3e8	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc627cb10	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc971b1a3	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd6dd8aee	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xec83b036	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf3d9c9f5	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0da5c308	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x122f15ac	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x263dc253	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x30852ced	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x94f7ccdf	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xadc509a3	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0635b907	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x079d83f3	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0842af12	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x282a9a2d	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x2a57e037	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x863421e1	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x8d83895f	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x9366dc97	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x9e9136bb	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb0fde0b6	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xba161c71	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xce60312a	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe84cac00	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf54c0c1a	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x9d297c72	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xd1230281	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xfc0e366b	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x08387a88	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x452d4c01	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4d34199a	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4da6c644	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb7d4694e	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc4176028	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc7a73674	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xe5e2fc33	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x00518a17	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x03657328	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x06bd1c65	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x08397172	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0a5f146d	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d78016e	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0fc02440	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x20f7bf1c	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3c06cb3f	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x53da8672	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x60cdf09f	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6434a889	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x67a296a8	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x69d0ba43	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6bab2f3e	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6e808c23	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x76e1d8a0	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x777e4381	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7a65bed7	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7d9c5dcf	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x816b9e92	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x823d439e	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8b7beb78	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x92c28f19	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x93f1b8c1	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xab74095a	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xac97316b	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb11ae5df	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb52af3c5	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc3ac0661	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc850fc99	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc8c7a970	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc981e6df	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xca2bea1f	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xca93d575	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcfd1d8ea	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd073cc95	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd332c354	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd916f2d7	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xde1e552d	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe17716bb	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x0b8312f4	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x005d45ef	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x3129f8b2	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x85e8ff96	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xb175bac1	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xe3e7ec02	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x02dcc90a	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x048cd13f	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x06626633	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0e146727	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0ef9920a	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1ce66a5f	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1d4a7845	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1dd30c94	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x232ad4fd	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x358d7922	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x403e033d	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4af89ac1	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4d33818c	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x50b30e29	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x53945d5b	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5b88fd45	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6207bd5d	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x643590d0	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x7d5b9667	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8897d718	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8ea27749	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8f413c8d	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9e4b0299	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa1dcbcf2	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb4cc9f29	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb51911e6	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc909efc3	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd168b942	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe4a1e8a9	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfdc25485	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x1127e873	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x40df56d4	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x45f37040	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x61188b04	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x8c5bc9aa	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xa48bb6b1	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xa8ca1547	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xa9965bdf	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xaa7719c6	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xc136b34c	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x6101d747	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x8d0ad496	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x93aea2af	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa83ca891	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xd738813a	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf2e2ed97	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xfd549bd1	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/fb_ddc 0x787722fc	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x3b5d678c	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0xb0d32de9	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0x53d90d79	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0xe892b708	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xb92ac64c	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x044cfe78	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x4c40c01c	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x667506ce	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7cc0384a	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x95d6670b	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xb761f701	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc155f80c	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc7803988	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xcc6352cd	w1_read_8
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0x9b38350b	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x28d05955	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x7dc78ae4	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x99a2d2c5	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x17ce645d	locks_end_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x1c002646	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x3d9787ab	locks_start_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x66b43d83	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x6b2ec49e	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa17dde9e	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xa4a7969d	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xce13e582	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xf7209ca8	locks_in_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xf7a3fa86	lockd_up
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x007582b3	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x012e842d	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x01d9d89e	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x045ed6be	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0ec49181	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x12183a3c	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d286d62	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e22d69e	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e35d8bb	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1f3ff0b7	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x20568582	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22c0bcc7	nfs_readhdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x234ac549	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x234d6554	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24e892fe	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25414ccf	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25de9416	nfs_generic_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x292f9441	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b319aee	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2b876814	nfs_fscache_set_inode_cookie
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f9a6f8f	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2fc5c044	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x32a3ba29	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x342cc5a8	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x38b666d6	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d77b83b	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3db880b3	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f0d75de	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4046ab16	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x436f9e0b	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45c5b2a2	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x46476d38	nfs_writedata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4800cba2	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a48e681	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e0bf0e6	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4fb2c007	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5186bee2	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x54635f5c	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x55090b95	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x577b8736	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d55f726	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e1d863a	nfs_sockaddr_match_ipaddr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e3d8eeb	nfs_setlease
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6340f855	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x65e49674	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x695b06ad	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69fed6bf	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6b595e20	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6db875c2	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6dce817c	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x729164e5	nfs_initiate_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74b7879e	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74ca9959	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78a1470d	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7951ef3f	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b6c9043	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7b8a6b9c	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c9722ba	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x80113ac9	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x84892751	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88c6a8a3	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89bc5a64	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c4ee77b	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8d676285	nfs_pageio_add_request
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8da21b5d	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8f94ac52	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9116864d	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91462d63	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a3aefb5	nfs_file_splice_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9a55ec30	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9cc07949	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9dc41b4e	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9de65e86	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e9d3497	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9ed49fb7	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa3adb7c9	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa86cc11f	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8d2d1ce	nfs_callback_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8f7df14	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaf72a9a	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0f1e8dd	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb41e220c	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb50d2203	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbbcee41f	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbeeb4e0e	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbf1043f8	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc034b669	nfs_put_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5e2e086	nfs_writehdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc69a5a46	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc8ea2d91	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc9795a52	nfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc9c0626f	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcba8a48f	nfs_file_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce046583	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xce442a13	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xceb6e92b	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf1d73f4	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd268abdc	nfs_readdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd27459d9	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd39cd89c	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4aa8470	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4b2a5ce	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd5741819	nfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd60a2e25	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd7ea3022	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd80f1a69	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbe93d87	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdcff07e4	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xde3d0b04	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe026899a	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe2af80d4	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe434a76d	nfs_generic_pagein
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe564bf18	nfs_pageio_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe5b83625	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe77c175c	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe8289796	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe910be4b	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea4d26b8	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb64de9f	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xed2f7758	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee233a70	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeeceb206	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xef8e64d9	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf0397c25	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf12140d1	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf14e74fb	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf6757280	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf69f812f	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8c5cd4e	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf9e566bd	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfaf9e500	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfd02f7cb	nfs_initiate_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0f347dc4	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x15815ef2	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x18ef706d	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1da9fd73	pnfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x219fa099	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2ddb15b6	nfs4_insert_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5b2c478e	pnfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6253883f	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x63dab704	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x657da20b	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x675c3469	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x73af0a96	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7639bc54	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7d91e21e	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x86795ae1	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8f7e5af5	nfs4_proc_getdevicelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x91ee5a4f	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x959e09aa	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9ae0adc3	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa0237907	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa4e1a203	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa570c9a0	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xaf5a6f46	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb5c6f6c8	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb6550f5d	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xba879c45	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc65db395	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc807f37e	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcc56a240	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcd7c9e04	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcf406e55	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcf89d5c8	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd1df2d8f	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd8f2ebd5	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xece31642	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfdb45244	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x5b7938fa	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xbc6b57d2	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b3d5393	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36a28a9e	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x437a6a40	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x7a5df7a8	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x7ff75a1f	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x81a17396	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x9eb10231	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa69acfc6	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf56c2017	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xfc355775	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x224d92e0	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x423dd1c7	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x47cd6a0b	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x82240276	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x9e887fd8	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xddecf803	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x025e2d69	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0562c415	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x16b2e575	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x3e670052	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x5013342e	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x5469ce31	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x7083dbd5	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x89502fe7	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xb4bd060c	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xcbd8acd2	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdc823ea4	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe2bd47db	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe417d940	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x1d0f2281	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0xae3fcddd	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x1803a6ed	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xe4b051cf	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0xfdfcb8cb	raid6_call
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL net/802/garp 0x13acf6b0	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0x427a1abe	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x85157458	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xa0006ae2	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xed735f88	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xfea9dd1b	garp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x164ea8dd	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x1b5b2384	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x2af57884	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x44776de1	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x96ccb92c	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x9b2fa03b	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/stp 0x69a520b3	stp_proto_register
++EXPORT_SYMBOL_GPL net/802/stp 0xe3257f88	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x57dd8ccc	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x9f17ff78	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xb53b4c60	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x4a2cd38e	bt_debugfs
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0d99f023	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1a322aa8	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1c7169e5	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x29281b65	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2a673a8c	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3025d600	compat_dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x328cf800	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x392033fe	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3e215deb	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3e3ce81e	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4279c66e	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4337482f	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x45594584	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5a452987	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x614144a2	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x68ddacb6	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6d6e6860	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6eec5c15	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x81a091ab	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x82a89206	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8a47c2bc	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9b740089	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9cd1ae5b	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa99b4215	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xac53f29e	compat_dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xacc7f5b3	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb40aea65	dccp_insert_option_elapsed_time
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb9a25b5d	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc17835e5	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc6c89b86	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc74a4992	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc85efd15	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xca61ccd4	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd25e4ebd	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe3691b9d	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xeb80cb85	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xee91a5ca	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf3017e21	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x01afa47d	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x2434750b	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x637a1911	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x7333150d	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x887e0888	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa68dfe22	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x294d2f2c	register_switch_driver
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x47f35f45	unregister_switch_driver
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x0619b710	gre_build_header
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x9191d75e	gre_cisco_register
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xc09a3252	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xe265ee9f	gre_handle_offloads
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xec3a8cf9	gre_cisco_unregister
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xef29aa42	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x03bbbd54	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x0e783595	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x39ac3a5f	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x86f458a0	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xb8c4a921	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xe78b47dc	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x16ddf629	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x25936b59	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2eed092e	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8655aed4	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x93fa4097	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x952fb52d	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x95ff262f	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa2cf0b6e	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb0329e88	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb646335f	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc6ef31cb	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xed28c943	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xf7268bda	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfc4c46ee	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xa7fec869	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x8d79408c	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_conntrack_ipv4 0x6d40a921	need_ipv4_conntrack
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x32b58671	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x1406af67	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x3ad7dce0	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x525dcf6e	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x5cb9462d	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x8007f4de	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x525ba777	xfrm4_mode_tunnel_input_register
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0xbd60faf7	xfrm4_mode_tunnel_input_deregister
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x30fec09f	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x6b9dd304	ip6_tnl_dst_store
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x84d209f9	ip6_tnl_dst_check
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xac4af580	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xea3c721c	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x5a54bc73	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x9d4925e2	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0359726d	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0e9a9671	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0fb63c4a	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4718e89e	l2tp_tunnel_sock_put
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4e8efa15	l2tp_tunnel_sock_lookup
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x51de1aaf	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5496e9eb	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5fa539a3	l2tp_session_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6829c95f	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x69bc783a	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6c5ab98c	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x8532c5a3	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9d8abf98	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9fd08d9c	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcee7c04e	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xf464882e	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xfa0b58b0	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0xf7b20b7f	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0aa5cb73	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x21bf7dbb	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x42252d33	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x983dcc3e	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xcd392ff5	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe9134d4a	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xea807016	ieee80211_iterate_active_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xeb1e32a6	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf08d27df	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf3aae968	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x39aae1a5	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5613f64e	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6531d01f	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6b48fbf8	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7762965e	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80ee118c	ip_set_nfnl_get
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x883d6572	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x96d19016	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xb3732577	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc12d0d78	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc3b062db	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xd769393e	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe0a39405	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe62a82d9	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xf3b4d4ae	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfda3ec7a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x1d521674	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x2c77f4d6	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x3cc66846	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x78521a1e	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x00074bbe	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x005881fe	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0c64bcbb	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0dfbbd01	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0f312aae	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1084f1e8	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x13f1c3bb	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x14208af5	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x17052fbf	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1c44165a	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1e8222fc	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x29c16465	__nf_conntrack_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2aebaa45	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2cb4407e	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x30216542	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3053ca70	nf_nat_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32f523ff	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x34d5f135	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x35e02301	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x383ae4e7	nf_ct_l3proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e32b269	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ea58f49	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3fdbdf53	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x43f1bb35	nf_ct_delete_from_lists
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x48a33f77	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4d5b08fa	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4dcc572b	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e07c268	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4face71e	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x58daeadd	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5a81cc82	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5e8e665a	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6083cce3	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x614e40e9	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x689920dd	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x70d65573	nf_ct_dying_timeout
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x723e3378	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x771bb5be	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x81757ec9	nf_conntrack_flush_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x842447c8	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x85e471ad	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8673872c	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x869a412f	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8c36ea26	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8eb3f7c8	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8f18fb1a	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9aedb5ca	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b6062e4	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9be467c6	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9e576932	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa35e2071	nf_ct_nat_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa3d36163	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaa5c845b	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaef3edf8	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb4960c58	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbd0094b8	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbd2e9998	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0240dd4	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0a0cf3e	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0cd71bf	nf_conntrack_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc4c1a5ec	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc547fcc2	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc8e08231	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc9ca4c03	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcd818446	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd2cf7333	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd9f4816b	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdab1850c	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdb93df91	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdc32ca01	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe1ffcc85	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe367f6dd	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe473a35b	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe9ab8f82	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xee2f775d	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf66cf078	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0xd70ba224	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x75fd3ae3	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x071be893	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x40a94ccc	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8c5f79c4	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x97e07039	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x9e471174	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xa3f1d123	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc1f97ca6	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc2bf2422	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc2ed90b9	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd009ac44	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd4b1a892	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x370b5f4b	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x1590214f	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x1ee853de	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x304715bf	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xc518cfa6	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x2b8ba291	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x33933a78	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x0692fee6	nf_nat_sdp_session_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x301c29ff	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x40d37782	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x58173e24	nf_nat_sip_expect_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x8f78a941	nf_nat_sdp_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa5e36421	nf_nat_sip_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb317a3b1	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb3720454	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb6c12932	nf_nat_sdp_port_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc307694b	nf_nat_sdp_media_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc526de17	nf_nat_sip_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc79a6ac7	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xfe22f8ff	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x4395720b	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xaa1a6ca4	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x00390dcd	nf_nat_tcp_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x02be1217	nf_nat_set_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x355da2fe	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x43941583	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x48cfab21	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5d43325a	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x662f64a4	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x67a6de77	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf9257fd4	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_tproxy_core 0x8f688508	nf_tproxy_assign_sock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1c9b7df4	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x72fe051a	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x9327cdbe	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa5aec943	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb1994619	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc7cc108a	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xfbf99731	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x0bcb9096	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x21f6bba6	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xa8a1c0a3	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x020ea804	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0f71a2d4	xt_compat_target_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x10c58567	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x15e86b7c	xt_compat_target_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x161d1417	xt_compat_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x2fce6355	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x49edd452	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x56ee1006	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x57b4e4d3	xt_compat_match_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5f82f1f7	xt_compat_flush_offsets
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x691a6d69	xt_compat_calc_jump
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x69e1c15e	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x78fe603f	xt_compat_match_to_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x88065960	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xacc46534	xt_compat_match_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb8488279	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc6d930a2	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc746e080	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xd20d1444	xt_compat_target_from_user
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe0b4971b	xt_compat_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe2bd9e68	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xec24fd82	xt_compat_add_offset
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xee91c363	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xff1d0baa	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x132318ac	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xd7e1b517	xt_rateest_put
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x35c5f3b7	nci_spi_register_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x41948df3	nci_spi_unregister_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x4b7ea7b7	nci_spi_free_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x835269a6	nci_spi_recv_frame
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xc66e1c89	nci_spi_allocate_device
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x013318cf	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0x02866a97	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x06aacf48	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x0bef4936	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0x1c813a6e	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x1d958484	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x2078b093	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x24222831	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x32070d09	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x3d8ab187	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x4d02a580	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x61779926	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0x7132ed78	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7bc62829	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x7c0bd6a8	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x907dfe7f	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x98e36d3c	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x990ba89c	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x9f036f2a	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xa34eca8e	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xac71f016	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc44fac3d	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xde6f52d1	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xfabdb2fd	rds_message_put
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x20bd021b	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x7bae83f3	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x1b828fe7	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x46c38bbb	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xd9c4e07c	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00792a7b	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x00fd6340	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01d59722	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x024f7754	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02f14a14	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x049742b5	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06172286	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06bc2c3d	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x081a9f92	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x08cd04f7	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a4d3eb5	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b090885	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b1e3774	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b43c188	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b60f6e9	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0be0c4de	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0e2d26de	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ecd40dd	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f20231d	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1159ba95	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x11e97879	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1769a769	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x179cc9ea	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x18da544a	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19d814d9	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a3d21e5	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1adaee65	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1f2a9970	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x208d4d37	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x221bb2e3	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2221b047	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2281d149	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2379da75	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23b1446a	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x23e2b7f5	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24677200	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2525d2f0	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x284dd4e5	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29168890	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c3b4ed7	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2c850492	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2d490884	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2fd92af7	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31243fc7	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3155f051	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31908c63	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x320b2cd9	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3293df33	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3324820e	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33a86519	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36a757a3	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x36c8cb17	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3755ae96	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x37c3379d	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3923967c	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3b78d061	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e36e44a	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e4ce071	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f305302	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x402cef9d	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40b2d9a6	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x413648de	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4144c4db	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x43f7144e	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4406714d	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x440d1c14	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x45582782	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x45e20c4d	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4761cee0	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c590a47	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c6f7378	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d3d7c07	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4dead9ef	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4fac561e	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x51f8b1a4	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52ee5e79	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x530d9433	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5532b59a	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x590031b0	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5a586dc1	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b06c602	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b7b3bcb	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c4695cc	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ca2d16b	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ccdde4b	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5d5edda4	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5dabc33c	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ea52dc2	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ff48db5	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x62eb3d53	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63e5094c	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65769ac9	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x659ab791	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x68deff65	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x696a5d71	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cb36bcb	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6cfe3d7a	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ed9d2d7	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x70c28a1a	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71adf88c	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7437d357	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x750385c6	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x76d667dd	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x76efd6c3	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79a0ff15	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a36ddbd	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e708192	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ed54d93	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7eef1953	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80b217df	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x81ac05bc	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87722fd0	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8a671747	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8c223066	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8de2e388	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8de596b3	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8fd5e8b2	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x91c44c8f	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98755f8b	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98cc9347	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99de515f	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a880f2d	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e3e56c8	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa770ebd9	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa837c415	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa6abcff	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab57eaad	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb478fb36	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb4d4ab77	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb70d1e30	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb7aa4291	xs_swapper
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb81c00f3	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8829cf9	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdb8d92b	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc00861ba	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc055d51e	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3acda27	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4a90e25	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4d322d6	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc6d9cac3	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc7cc8c61	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc92436e3	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc926af13	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb8f076f	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcba7906f	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc13c9f4	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc4d98d7	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce2adc4e	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xce9b34b4	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd0131985	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd49253a7	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd70d3f4f	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xda14774b	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddab6595	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddbbe575	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe19dd07e	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe80f30ab	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe94a5278	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb329c6e	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeb5f8df2	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xed187086	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeb19a8d	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xefd5e5b8	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf07c4e3d	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf0d07c8a	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf17e8b3e	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1f4115d	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2783503	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2924745	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf45bc564	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf476b7fe	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf5e2d80e	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf60ca04a	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf84babfd	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfa56a124	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfc3e49f9	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe015619	unix_domain_find
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0cdbf0f2	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x24e877ec	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x260b1ce0	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4a36fcd5	vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x4e4fafc1	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x59d943c8	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x6ba4903c	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x749a2cb8	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x783e95a6	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x970b77bc	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9f40d7f2	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa3750846	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb25c7ff4	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbe091347	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xdc213bb7	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x15814864	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x1f6952d2	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2a81dab1	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2acbde78	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x49d27991	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4f2ca751	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x5d75c30d	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6aa57523	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6d196cdc	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x91754eb1	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa2e97d3e	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb850acbc	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xec33ebbf	wimax_state_change
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x074c7a68	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x0b5b2cda	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x21cf42b7	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x30a1de32	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6abe4d22	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x89ce384f	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x8f25d20f	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xaf90f838	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbf1cba85	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd88072ca	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xedd44c32	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x00778770	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x056bb269	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0b9e5852	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x240f9c6e	pskb_put
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x74e1a843	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7c30b8c7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x92dbc6c1	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xbc8b0f41	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xce7a55c1	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xe122af95	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x1385f58e	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x73a95f47	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xd3825655	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf6265e9d	ipcomp_input
++EXPORT_SYMBOL_GPL sound/core/snd 0x3ca17104	__snd_printk
++EXPORT_SYMBOL_GPL sound/core/snd 0x596fb7bc	snd_kctl_jack_new
++EXPORT_SYMBOL_GPL sound/core/snd 0x8b3e049d	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0xb453c359	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0xc3d7c5e5	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0xd630828f	snd_kctl_jack_report
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x118fa46b	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x30976587	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xb4bed8b7	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x3c0df4cb	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xf5e5f57d	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x3c846c15	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x71aca83b	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x75c4389a	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x988fa21a	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xcfbffb3d	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xdacd583f	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x02237d8e	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0485f392	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04f433a8	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04f4726e	snd_hda_delete_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x056cde99	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x068bdb8d	snd_hda_jack_tbl_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x088769f6	snd_hda_parse_generic_codec
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0bb8b8cf	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0bc4a962	snd_hda_bus_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c1a1ce3	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c966fb1	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d24769e	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0d75d865	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0dfb2995	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e70a309	snd_hda_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0f5b31cf	snd_hda_codec_update_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0f69d3e1	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x135674c5	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1976d37f	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19ff28af	snd_hda_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1a5bcb08	snd_hda_sequence_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1ac2c3d4	snd_hda_queue_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1bd00a54	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1bf8646f	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2578b751	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x26b0efd0	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2e3e86d8	snd_hda_resume
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fac604b	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2fc21bf3	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x31abce86	snd_hda_is_supported_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34699908	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x34dbd363	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x36647721	snd_hda_codec_amp_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x37cb26d8	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3831e716	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x389b572c	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3a0d9c2d	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3aa901bd	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3c066579	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d755293	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3e97a0a8	snd_hda_ch_mode_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ea3e1fa	snd_hda_check_board_codec_sid_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3f46e784	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4b08b328	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4dab1f60	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4e3dd7c4	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x522ae704	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x53b8cc24	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x58974ef3	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x596621c5	snd_hda_codec_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5dec2946	snd_hda_codec_resume_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x605bcba9	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x606d9cd5	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x618d1239	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61f3a685	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x636f94c2	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66ddc12a	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x68ac051b	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x693d5473	snd_hda_query_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6947d8c7	snd_hda_codec_flush_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x699d9c75	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b06f4d6	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b769419	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6bef9e5b	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c89a280	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6df37a64	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6ff87b5c	snd_hda_bus_reboot_notify
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x725ef73e	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7753d06c	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x777fa8a0	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x77e1a0fa	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7895899f	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7b6bbf46	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7ba93069	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7fc91928	snd_hda_codec_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80a11099	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x81ac933e	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x87aff1be	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x87dcb022	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a37097e	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8ce019a6	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8d731bbb	snd_hda_ch_mode_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8daa12d0	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e3a510f	snd_hda_override_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e4c6826	snd_hda_calc_stream_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8fdda110	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x92ed3b47	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x959136c4	snd_hda_codec_resume_amp
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x970193f8	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99047d79	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99ab0b80	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a783d56	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9ae2e094	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d70200f	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9fc03b2f	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa22d915c	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2827d76	snd_hda_get_jack_location
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2cfff2b	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2f7be87	snd_hda_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa38e2a89	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa6e61406	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa80b8de0	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa996fdc2	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xabdb9bbb	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaca27d3f	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xaccc132a	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae2df9c7	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xae956d68	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb0d705e7	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb16961d3	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb4d98dfe	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb6b491ed	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9547b3f	snd_hda_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xba599078	snd_hda_check_board_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbb38191f	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbbba06b6	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbddbfbcf	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbdfe0747	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbeb29ecb	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc0478e6f	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc21f5aff	snd_hda_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc51373a4	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5841e09	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc652fd69	snd_hda_get_jack_connectivity
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc6b8ec35	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc84483e2	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb301b6e	snd_hda_get_jack_type
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcba843d4	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcbb3c71f	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcc51995b	snd_hda_codec_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf4ebf81	snd_hda_suspend
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf50357d	snd_hda_jack_detect
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0eedb45	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd268d468	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd644e515	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd6bfd808	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xde37b073	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdf84bd6f	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe0fd2313	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe369ce5d	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4c6e1af	snd_hda_gen_spec_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe6615620	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe6f6c7df	snd_hda_add_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe930d954	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea51e6ed	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xebb15ced	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xec9be378	snd_hda_ch_mode_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xedba0e6b	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xedf2ab07	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1b3672f	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf44dad54	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9ea36c6	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc081c38	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfc3893f6	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe9aa9be	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x594ecdd0	atmel_pcm_free
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xa43dc241	atmel_pcm_new
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xfbc5eb8f	atmel_pcm_mmap
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0x5faf6209	pm860x_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0xe3fec475	pm860x_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0x44fc2e3b	ab8500_audio_setup_mics
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0xd35abecd	ab8500_audio_set_ear_cmv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x0370743c	arizona_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x05ddbf0f	arizona_lhpf4_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x0bf15579	arizona_init_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x12ecde17	arizona_out_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x196694e3	arizona_ng_hold
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x1f28ceef	arizona_set_fll_refclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x206e3ddf	arizona_in_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x30ba3322	arizona_in_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3f429d4c	arizona_isrc_fsl
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x41b95c1f	arizona_in_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x4dc28647	arizona_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x547a7178	arizona_rate_val
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57e590a8	arizona_lhpf1_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x660d8a35	arizona_lhpf2_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x6a5e4cd1	arizona_hp_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x733bbfd7	arizona_out_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x7e903a70	arizona_set_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8aa00522	arizona_out_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8c821bc2	arizona_rate_text
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8dd35bf2	arizona_mixer_values
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x93ce2ac5	arizona_init_spk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xab6861be	arizona_mixer_texts
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xbf7d5b49	arizona_init_dai
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc07a8181	arizona_lhpf3_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc9c29637	arizona_mixer_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xd6382bcf	arizona_set_output_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xee9be5fe	arizona_simple_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cx20442 0xf9cddd5c	v253_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-l3 0x78c84c7e	l3_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0xbb75427d	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0xa9097a97	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max9877 0x275d5069	max9877_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x34c8a93e	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x395e89bd	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x222051a5	twl6040_get_clk_id
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x9e3f4db0	twl6040_get_trim_value
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xddf532d7	twl6040_get_dl1_gain
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xe100f584	twl6040_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xfcb427c6	twl6040_get_hs_step_size
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wl1273 0x334c81a5	wl1273_get_format
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x7497805d	wm_adsp1_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x76bbedd4	wm_adsp2_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x9c3d30b6	wm_adsp1_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xcb7b71a2	wm_adsp1_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xd0fa4f76	wm_adsp2_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xfbadb5d2	wm_adsp2_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x07257dd2	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x0d6b56ea	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x1504fef0	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x98b2aaf7	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xa16ec91c	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xbed76488	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xdabc53c0	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xff585be4	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0x7e22cb8d	wm8350_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0xf136ee8d	wm8350_hp_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0xe67986fd	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x60a79cf5	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xb67c5bbd	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xda9616ef	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8996 0xa068019a	wm8996_detect
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x00afc056	snd_soc_default_volatile_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0455bf3c	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x062c6964	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x06dceffb	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x08f3ea67	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0903beb6	dapm_mark_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ac218d1	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0cd5ca9c	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0ce87a1f	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d9c53d0	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e235d1f	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0e3bd3ed	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f919d3a	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x10757f45	snd_soc_get_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1323e571	snd_soc_info_enum_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1336cf4b	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x13fec0f5	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x14609827	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x15688932	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18270fbb	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1bfe3a68	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ce7cf31	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1d26071e	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ff943a6	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x223f454d	snd_soc_dapm_get_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x25373e5f	snd_soc_put_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x29ad98f4	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x29e29642	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2c2053c4	snd_soc_dapm_put_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2e80eb8b	snd_soc_dapm_get_enum_virt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x315c9920	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31c9a4d2	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32145da3	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x33aa0e7f	dapm_reg_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x34b603bf	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x34f9e294	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x35a0d161	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x37c5f9d4	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x39ededd7	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3bd1e678	dapm_mark_io_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3c713ed6	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3e6bbe52	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3f22c727	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x443f9d0c	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x469a266a	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x553f82a8	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x557654bc	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57281f9e	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57aa0390	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57c481bf	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x57c491cf	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5830c358	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x59ec95bc	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d65fd64	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d7c4002	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5de4b246	snd_soc_info_volsw_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5ed2d564	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x63eff5e8	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6438284d	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x65ee9979	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a228bb2	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a2d082b	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d6dc00f	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6d728242	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6f89e514	snd_soc_update_bits_locked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x714998c2	snd_soc_codec_set_cache_io
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x720a277e	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7407071f	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x77163c99	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x77d35618	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d6bad2f	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7d73dd2b	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7dca7945	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e07f545	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x84f55544	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x85b826d0	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x86e784c5	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x87d52c81	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b973c8d	snd_soc_dapm_put_enum_virt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8c908c88	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8dfdac57	snd_soc_default_readable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8fdb770d	snd_soc_put_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x90c436a1	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9478117f	snd_soc_cache_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9aa612ca	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9cc715e0	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9e4bb82e	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f33300d	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa0d1f4dd	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa51bfc9a	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa7f32dda	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa977106e	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab2c3354	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xadc349ab	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb27779d1	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb388e053	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb40a0d26	snd_soc_cache_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb4b314a7	snd_soc_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb62639f4	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb62a0752	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb9190922	snd_soc_info_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbd39de2c	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbe657e0f	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbf6e5976	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc27dc96e	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc2e5fcef	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc365888e	snd_soc_codec_readable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc58762eb	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc72a32b7	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc7398b97	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc79c227c	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc92c80c5	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcc62a9f5	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcd188a14	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcf88e898	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcfa49ead	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd4218fdf	snd_soc_get_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd4dabc2c	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd6c48721	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdc69184b	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe4304f51	snd_soc_codec_volatile_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe583cf58	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe95ade87	snd_soc_bulk_write_raw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xec542e26	snd_soc_codec_writable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xed930dde	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xef345230	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf2c596d8	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf55f65f2	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf661361d	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf6821c8c	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf79785bd	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfb32ffbb	snd_soc_cache_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfb8f79a9	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfd10c7fe	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xff41cd90	snd_soc_default_writable_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x098fa75c	vfs_lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x09ac76d0	lib_ring_buffer_move_consumer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x188d4f1f	lib_ring_buffer_switch_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1b70a30d	lib_ring_buffer_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1c18d99c	lib_ring_buffer_compat_ioctl
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1edae8e6	channel_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x230b3ab5	vfs_lib_ring_buffer_no_llseek
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x289d53f2	lib_ring_buffer_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x31aae62a	lib_ring_buffer_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x3e769ebc	lib_ring_buffer_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x426f45ae	lib_ring_buffer_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x59b07481	channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x5bf1a157	lib_ring_buffer_ioctl
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x624ca2ca	channel_create
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x698eaafa	lib_ring_buffer_put_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x69dcebc4	vfs_lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x6cf16d02	channel_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x709eedd1	channel_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x729ef0b3	lib_ring_buffer_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x72bc89f1	_lib_ring_buffer_copy_from_user_inatomic
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x87d5241a	channel_get_ring_buffer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x90dfcc4c	lib_ring_buffer_release_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9788be19	lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9a909db0	channel_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9abfedda	_lib_ring_buffer_memset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9d40d05b	channel_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9d8505db	lib_ring_buffer_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xaa9b4e50	__lib_ring_buffer_copy_to_user
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xac135917	lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xaef7de84	lib_ring_buffer_read_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xaf8528c6	lib_ring_buffer_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb4ed8d56	lib_ring_buffer_get_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb702e4d6	lib_ring_buffer_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xba28d1eb	lib_ring_buffer_poll
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc2c79efc	lib_ring_buffer_reserve_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc7211387	lib_ring_buffer_snapshot
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc9500bbf	_lib_ring_buffer_write
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xcd2b560e	lib_ring_buffer_open_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xdc366fa2	lib_ring_buffer_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe038862b	lib_ring_buffer_read_cstr
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xff25e18e	lib_ring_buffer_switch_remote
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xfffb66d2	lib_ring_buffer_read_get_page
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-statedump 0x5b7ca0c9	lttng_statedump_start
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x071cbc0f	lttng_add_vppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x0e698e4f	lttng_transport_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x1ac98182	lttng_add_ppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3469f0db	lttng_add_hostname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x34e49958	lttng_remove_context_field
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3bf4855b	lttng_add_pid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x4e6e88cf	lttng_metadata_channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x595f9972	lttng_event_put
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x70a0964b	lttng_probe_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x7ee8e124	lttng_add_vtid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x88eaa074	lttng_append_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x904b9cdc	lttng_add_vpid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x9ac2c867	lttng_add_nice_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xabb9c315	lttng_probe_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xaeef8577	lttng_add_procname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xc452a68f	lttng_find_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xca6fdb21	lttng_event_get
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd557f8a3	lttng_add_tid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd63c35f7	lttng_transport_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd8972c21	lttng_add_prio_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0x477de295	lttng_ftrace_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0xdf9658f1	lttng_ftrace_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0xf292e30d	lttng_ftrace_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x081b891f	lttng_kprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x14108334	lttng_kprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x5aee23b1	lttng_kprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xda32e24d	lttng_kretprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xf43ee93f	lttng_kretprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xf5003977	lttng_kretprobes_register
++EXPORT_SYMBOL_GPL vmlinux 0x0007d3e9	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x002102a2	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0040c8f5	inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x004483ed	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x004ab863	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x004e412a	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0067df75	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x006bc072	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0070ef14	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x007b5f66	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x008da840	sysfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x009beaf2	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x00af3afd	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x00c4dc87	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x00ff7a2b	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x01314081	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x0176d0c7	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x01b4f3f0	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x01b65ea2	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x01ba38cf	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e7f7da	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x022817f4	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x02448233	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x025ee6bf	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x0292d3e5	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x029836cc	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x029fa6f0	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x02c1a035	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x02ee134f	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x02f1a18d	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x0303fcc9	md_trim_bio
++EXPORT_SYMBOL_GPL vmlinux 0x030833ef	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x0328e3e7	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x0334ec6f	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x034478aa	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x03448e9a	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x034fcb21	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0351dcc8	sec_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x036a3ce8	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x039922e9	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x03d8ef33	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03eca9a1	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x04057ce2	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x04123d5c	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x043c2090	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x04486e88	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0459fe5d	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x04602e7c	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0485bace	pci_renumber_slot
++EXPORT_SYMBOL_GPL vmlinux 0x04a18049	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c456e5	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c9f036	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x04cad3d2	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x04d1371b	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x04df8fbc	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0x0531dcb8	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x053494cb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0551f0ce	tick_nohz_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0565b9e7	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x059b8579	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x05fee27b	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x060cb589	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x060d1064	set_memory_ro
++EXPORT_SYMBOL_GPL vmlinux 0x06248822	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x0624d197	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x062fc169	xen_hvm_resume_frames
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x065bf70f	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x06b913d8	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x06c2ecff	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x06ffd847	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x07170e6d	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x0744f983	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x0765ef06	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x07951647	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b27566	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07ba8ccf	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x07bfbf0e	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x07cf3227	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x07e259a9	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x07e93fb9	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x07f0a8e0	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x07fc478e	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x082aaca8	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x084c6e46	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x088bfa7e	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x088fddc5	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x089454a9	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x0898c3d2	xen_unmap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x08a874a7	unregister_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x08bc0870	compat_put_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x094313d7	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x09469482	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x09558080	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0x09741cbc	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0996086e	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x09c80a77	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x0a0c13bd	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0a0d2959	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x0a43de2d	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x0a638a98	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0a9ba235	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x0a9fde95	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0aa73753	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x0ab696b1	tpm_show_active
++EXPORT_SYMBOL_GPL vmlinux 0x0ae1aa24	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x0af2aba4	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b0a2e3e	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x0b19ed7c	apei_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0x0b38325b	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b7b9554	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0ba936b9	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x0baa4291	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x0bae62b1	ktime_get_monotonic_offset
++EXPORT_SYMBOL_GPL vmlinux 0x0bbe260c	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x0bc193e1	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x0bd9155b	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x0be8cb31	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0bf4edb6	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c0dc0fa	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x0c163d52	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0caaceb5	cred_to_ucred
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cd45361	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x0d30a93e	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x0d9c550a	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x0da5869e	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x0dc3fa04	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x0dc7ad0a	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0dcc625a	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0dd11f01	hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x0ddb0619	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e20bc07	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x0e6f1568	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x0e7692b3	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x0ec4b9f4	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x0ecf823a	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x0ee5a9d4	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x0ee8f60f	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL vmlinux 0x0f02d6ba	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f1dbc5e	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f6d6a01	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f81920c	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x100a6252	register_hotplug_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x100e3cc4	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10291853	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x102d3290	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x1042ce8c	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x10446a7c	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x105666a1	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x1058e0f6	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x107d0ccf	wm8994_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x107f4101	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x10978bd6	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x10cb5ade	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x10d07dea	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x10e874a8	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x110de44c	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x11354b4e	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x11438e41	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x114f1a20	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0x11659f51	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x1187437f	acpi_dev_pm_remove_dependent
++EXPORT_SYMBOL_GPL vmlinux 0x1188f2ed	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x119af014	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x11cc8c50	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0x11f447ce	__gpio_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x121ed3f3	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0x121f73bb	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0x122a88e5	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0x122b6279	scsi_unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x1231660b	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1258d9d9	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126dd288	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x127fb9a4	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x1291edb0	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x12c6ed23	__remove_pages
++EXPORT_SYMBOL_GPL vmlinux 0x12ff48ef	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x13110a7f	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x131279b6	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x1323c10a	xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x1329be1f	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x13319c9f	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x1359cd2a	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x139228b3	css_id
++EXPORT_SYMBOL_GPL vmlinux 0x13964db0	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x13ad4081	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x13bb8837	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x13c118a6	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x13ce87e8	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0x13cf2699	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x13ea8741	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x1416c8d6	put_compat_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x1433b4b4	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x144364ee	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x145c4ff8	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x145fd596	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x14610e2a	ata_sas_port_async_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1465f1e2	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x146dad97	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x147737a9	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x14a26aeb	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x14a3de87	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x14b48e52	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x14d7d881	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x14dac6e1	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x14de85e1	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x14f875ce	devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x1501bf65	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x15026a32	snmp_mib_init
++EXPORT_SYMBOL_GPL vmlinux 0x15241256	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x1547ba4e	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x1548fc43	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x154c6511	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x1553b2b8	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x1570c97f	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x1586e113	vtime_account_irq_enter
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x159f58be	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15c0241b	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x1607411f	tpm_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x1637e525	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165c2efb	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x1660de63	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x166d1edf	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x1678ba23	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x1681e788	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x16887ced	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x168f5114	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x169287a4	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x16c96e9d	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x16cde84b	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x16f58fc1	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x175e88a1	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x1793776b	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x17a6859c	cgroup_add_cftypes
++EXPORT_SYMBOL_GPL vmlinux 0x17b41986	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x17d14a7e	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x17dfafcc	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x17ecd322	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x18086720	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x1836cb4f	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x1848d7d7	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x186787e9	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x1867c0c9	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x1888b0d4	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x188dbdc5	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0x18957e23	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x18aa3007	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x18bd08fd	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x18d32b40	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x1927d1c1	xen_remap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x192ad1cf	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x193c6a8a	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x193d48e0	trace_current_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x19596753	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x1975264a	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x198c3d68	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x199c2d7d	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19fc7f60	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1a082d69	max77693_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1a323362	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1a3b97cf	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x1a3bc9dc	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x1a480500	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x1a4b8690	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x1a8070c9	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x1a98609d	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1aa4f335	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x1aabf201	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x1acae236	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x1ad83009	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x1ae04c35	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x1b01dc5e	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x1b08b126	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b30c3c5	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1b3c9291	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x1b5b0050	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x1b617d5b	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1b670663	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1b6750d5	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba720f1	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x1bbcbe9a	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x1bd06aab	cpufreq_frequency_table_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1bd0e955	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x1c236f9d	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0x1c2a7531	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0x1c559cd2	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c8521e3	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c9acd62	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1ca26371	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x1ca35cc6	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x1cb18363	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x1cba218d	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x1cc0e59a	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x1cc9a828	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x1cd97959	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x1cdb2147	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x1cfd95c1	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x1cffc4df	RSA_public_key_algorithm
++EXPORT_SYMBOL_GPL vmlinux 0x1d0522af	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1d143a7e	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x1d27192d	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d81470c	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x1d8fb3bb	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x1d9cee3e	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e314b21	regulator_use_dummy_regulator
++EXPORT_SYMBOL_GPL vmlinux 0x1e3a88fb	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e697ab4	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x1e7b6f2a	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e7f14d6	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x1e7f84aa	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x1ea4bfc9	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x1eb09199	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x1eb70efb	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ed21abd	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1ee1449c	pci_sriov_migration
++EXPORT_SYMBOL_GPL vmlinux 0x1ef39a95	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x1ef8557d	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x1f0e3e12	__inet_hash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x1f114ca3	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f54f1b4	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x1f564a42	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x1f6cca67	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x1f70ef7e	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f886e94	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x1f8d16dc	guest_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fc7bf33	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x1fcece42	inet_twdr_twcal_tick
++EXPORT_SYMBOL_GPL vmlinux 0x201c595c	balloon_mapping_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2036b1a5	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0x205e11b6	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x206f98cf	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x20bc3470	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x20ced872	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x20d7a57f	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x20eb3847	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x211d4ea9	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x21220465	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x21435db2	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x2147a8a7	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x215b57c7	dm_set_device_limits
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21b47b54	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x21d6da78	filter_current_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x21edcc6a	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x2200d038	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2221a11b	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x223fab33	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x22710ee2	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x227ca15e	platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22a80bef	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x22deb2d2	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x22ed2b03	unregister_dock_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x22f017b4	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x23075224	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x231bf420	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x23643037	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x2373352a	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0x237b9849	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2381119e	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x238e3b97	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x23bb7e2a	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x23f99771	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x23fac883	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x24011e14	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x241e712d	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x2447533c	ktime_get_real
++EXPORT_SYMBOL_GPL vmlinux 0x246a4323	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x249c0033	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24ad611f	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f2d831	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24fc46b6	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x254f5649	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x25725b4e	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x257749e9	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x25a97010	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x25b42f38	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x25cab0c5	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x25f5d1bf	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x2605de9c	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x2612947a	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x2644d0aa	xenbus_bind_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x266ac76d	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26dc2fc2	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x26f32806	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2735ef9d	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x2751c510	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27aab9b3	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x27c0c4be	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27ddb33d	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x27de6722	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x27f3756a	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x285cbd39	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x2869ebaf	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x286c5584	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x28810d56	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x288c8b4e	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x28a7ec7c	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x28a903c8	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0x28ac8818	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x28b91ac4	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x28e27baf	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x28fe5256	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2926cb40	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x2948a25b	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x2964e8eb	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x2998a1a4	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x29d93a42	blkio_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x2a05952e	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x2a4171e3	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a829bb5	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x2a83b971	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x2a912a02	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x2ad1ece4	zs_get_total_size_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2afc6992	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x2b2d1313	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2b3cd923	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2b664c5a	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2b6d2936	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a6de8	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2b86ff90	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x2b96c0d9	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x2ba4f6d4	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x2bb65833	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2bd72b76	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x2bdb982f	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x2bfc086a	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2ca4ebcd	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2cb5207f	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cf5631a	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0x2d17a0e1	cgroup_taskset_size
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d2a71fd	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d6b0518	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x2d9e95d6	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2da3a820	sync_filesystem
++EXPORT_SYMBOL_GPL vmlinux 0x2dba276a	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0x2deec523	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x2e05572e	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x2e0cdd34	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x2e1da9fb	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e27d596	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e391796	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x2e43c381	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2e45e488	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x2e5317ec	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x2e961a4e	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x2eb5e229	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ece8331	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x2edaab37	nfq_ct_nat_hook
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f857551	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0x2fa0b001	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x2fbfdab3	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fe1abad	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x2ff9f0d5	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x302e41d3	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x303efc5d	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x304990fe	cgroup_unload_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x304d6806	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x305860d2	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x308b733a	getboottime
++EXPORT_SYMBOL_GPL vmlinux 0x30a5bc36	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0x30c16ce0	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x30ec0b43	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x311c92e5	inet_csk_compat_getsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313eece7	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x315913f1	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x316ffdab	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c67f02	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31fa839a	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x31ff9731	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0x3211688a	blkg_lookup_create
++EXPORT_SYMBOL_GPL vmlinux 0x3219e25f	sec_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x321bdbb1	compat_get_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x3247eb43	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x324a20ad	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x32519f11	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x3254320b	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x325691b6	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x329bbbde	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0x32a98ed3	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x32ae2ac9	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x32b31a8c	ktime_get_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x32bded08	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32db2c0a	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x32f84983	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x32f91c65	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x32fd447a	monotonic_to_bootbased
++EXPORT_SYMBOL_GPL vmlinux 0x330d1143	apic
++EXPORT_SYMBOL_GPL vmlinux 0x3310bf11	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x331bcd5e	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x3332e3be	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x33376f00	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x333d0825	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x336ae915	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x33712103	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0x33883929	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33952290	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x33a67d4c	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x33ae158d	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33b9855a	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x33f7ab15	get_compat_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x33fcdefc	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x3406a2e5	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x3441c3d6	gpio_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x3448893c	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3465fce6	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34987dc5	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x34c11658	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x34c85653	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x34d0510d	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0x34f356d3	iommu_domain_has_cap
++EXPORT_SYMBOL_GPL vmlinux 0x34f88683	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x3515d369	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x3540fbb7	fuse_conn_kill
++EXPORT_SYMBOL_GPL vmlinux 0x354f5c7d	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x3555b233	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x355b7a00	tpm_dev_vendor_release
++EXPORT_SYMBOL_GPL vmlinux 0x357786cb	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0x359066a2	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x359a203f	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x35b3cdd5	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x35b53e55	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x35bb1cce	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x35be60ef	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x35bf39ac	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x35bf9e6c	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x35c6a037	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x35cf11dc	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x35e66306	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x35f165f1	devm_reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3617d802	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x3638b2e5	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x36395625	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x365cc1d0	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0x3662ac43	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3666cd09	acpi_dev_pm_add_dependent
++EXPORT_SYMBOL_GPL vmlinux 0x36771d89	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x368f1fea	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36cc7b8f	aead_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x36d1a668	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x36d9a465	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x36da7894	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x36f63718	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0x3700154c	pkey_hash_algo
++EXPORT_SYMBOL_GPL vmlinux 0x37040834	scsi_register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x37212230	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x37223a46	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x372c07db	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x375c049b	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0x3795d0fe	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x37a0ef94	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x37b8026f	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x37cb892f	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x37d6f7e8	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x37e8030c	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x37ef9f5c	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x37f1ffbf	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0x382560d3	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x3829804d	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x382f2919	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3832f596	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x38499eb4	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x3851cc05	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x38620e38	gnttab_grant_foreign_access_trans_ref
++EXPORT_SYMBOL_GPL vmlinux 0x386ef302	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x387f1725	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x388f8a04	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x38bb8645	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x38c99864	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x38d65e20	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x38dfedb5	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x38f23a01	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x39042e51	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x390e294f	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x391643e6	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x391924c0	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x392574aa	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x39593b9c	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x3960d84e	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x39704ef9	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x398e707f	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3997d7fb	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x39adc43d	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x39c22e08	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x39de761a	dm_requeue_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0x39e41d76	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x39e599e5	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x3a26adbd	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2abdbf	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a44056a	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x3a4a44b3	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f8083	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a54d303	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3a558cba	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x3a85bbee	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0x3aa24773	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x3acaeb96	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x3ad0e201	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x3b1ab560	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x3b4e79d3	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3b6966fe	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3ba4dbd0	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x3bc5c22c	acpi_get_gpio_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x3c0a0dac	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x3c20a753	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x3c32b1cc	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3ca0c65e	tty_prepare_flip_string_flags
++EXPORT_SYMBOL_GPL vmlinux 0x3cac21b9	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3ccf5cba	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3d0aef81	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d12fced	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d5f392d	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0x3d71235f	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3dae6404	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3db44e38	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3dc8c55e	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dce6cb3	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3df4b6af	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x3e2fa31f	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e6be64c	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e75d0a5	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x3e7fd42c	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3eba566b	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x3ebc26dd	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3efde60e	extcon_find_cable_index
++EXPORT_SYMBOL_GPL vmlinux 0x3f0b6748	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f24f412	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f88cce8	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x3f8f0b8b	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x3fa6388a	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x3fc72d3d	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3fe28533	get_device
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4035575f	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x403e833d	crypto_nivaead_type
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x405f3bbc	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x406c7df5	tpm_open
++EXPORT_SYMBOL_GPL vmlinux 0x408b8ad4	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c3202b	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x40cc31d8	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x40d1fb3a	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40e5fd79	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x411a5d5b	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x412fc7c2	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x4134737f	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x4136a917	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x417601eb	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x4194f4cf	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x41b3e4b5	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x41ce0330	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x41e1064f	acpi_get_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x41fe61fe	regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x42027bbd	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x421e50b2	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4233c71e	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x424664c6	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x427d5c68	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x427d9f5c	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42978ab4	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x4297b25f	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x429cb616	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x42d5aab9	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x42facfce	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x43050f83	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x431439e2	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x431ab286	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0x432fd7f6	__gpio_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x4337ab6a	inet_csk_compat_setsockopt
++EXPORT_SYMBOL_GPL vmlinux 0x4363a685	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x43676bd3	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x44161252	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x44404f11	kdb_register_repeat
++EXPORT_SYMBOL_GPL vmlinux 0x444bf03a	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x4455e1b3	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x44601dde	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x446128e4	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x4485cf1d	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4488df65	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x44934812	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x44a35fb7	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x44dd9018	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x450e751e	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x450ed331	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x450fb522	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x452ea35f	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x453c1ec7	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x45582612	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x455a24f0	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x4565dd4b	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x4574d1ae	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x4579ffcb	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x45853c0b	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x4588819f	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x45a4cb22	register_dock_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x45b6247a	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x45bbb75e	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x45fa1e82	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x4600f5eb	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x46074c17	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x460f7531	wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x463571f8	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0x4635d096	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x46434934	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x464a9522	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x464f1459	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4672e88b	__crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46a37692	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x46c17633	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x46cc55dd	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x46ddd866	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x46ea1e78	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x46eb78fa	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x4730df1b	regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x473672c5	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x473b04ce	task_xstate_cachep
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x477a6ec6	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x477e8bc0	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x479dba86	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47b99304	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x47ff399f	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x4810fc72	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x4819ffb9	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x482b5b58	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x484a8965	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x48508fdf	balloon_devinfo_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x48695158	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x48847e45	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x48968f4f	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x48ab5da7	pkey_algo
++EXPORT_SYMBOL_GPL vmlinux 0x48e327bc	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x48ea6226	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x48ea93a1	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x49031def	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x491df201	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x493fe14a	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x495982e4	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x495baf16	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x498d293a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x499b0751	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x49b2ee2d	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x49c774a8	tpm_register_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a5ae197	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4a90160e	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x4aa9f2d6	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x4aabd8a7	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4abf9347	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x4ac36cdd	bmp085_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4affd08b	put_compat_timespec
++EXPORT_SYMBOL_GPL vmlinux 0x4b09562c	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x4b0f274a	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x4b6068ee	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4b8b41b6	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x4ba3fbb8	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x4bc62a81	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x4bc75202	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x4bf0d6d1	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x4c1ffd56	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c869a77	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x4cbe4a08	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4cd719be	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x4ced1881	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x4cf7ab02	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x4d0a255f	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x4d2a42ee	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x4d49d2a2	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x4d4a44fe	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0x4d5592d0	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x4d5c37a0	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0x4d6af76d	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x4dc6953a	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x4dcb9447	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4de303fc	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x4df10f08	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x4df939d3	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x4e03833c	tpm_show_caps
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4e7bfa50	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x4e9a05ac	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x4ec7b8e3	tracepoint_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0x4ecdddc9	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4eecf612	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x4eeffe90	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f588d27	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x4f6d62b4	device_add
++EXPORT_SYMBOL_GPL vmlinux 0x4f74499f	task_current_syscall
++EXPORT_SYMBOL_GPL vmlinux 0x4fa5d1be	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x4fd4e89d	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x4fd5cfb9	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x500b6dd7	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x50347bac	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x505ab52d	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x506691f1	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5069e6f8	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x507de8c6	add_memory
++EXPORT_SYMBOL_GPL vmlinux 0x507ed647	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x5080f249	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50a2d905	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0x50c41962	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0x50d1f870	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50f441a9	__online_page_free
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x50ff8ecf	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x512b1d19	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x513ac9c9	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x516f6eb4	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x518e6499	netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x5191bd3c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x51b53a57	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x51e6e8bb	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x521fd17d	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x52222489	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x522578c4	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x5228219d	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x522f538b	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x5237ebf4	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x52470e03	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x525b89d5	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x5278d1f2	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5285732f	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x529c2bcb	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x52a43eaf	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x52b2eb71	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x52c15c1f	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x52de86aa	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x52df4d3f	blk_queue_bio
++EXPORT_SYMBOL_GPL vmlinux 0x52f150eb	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x5305646e	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x533c9166	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x53529322	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x536505db	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x538547b1	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x53947087	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x53a3e486	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x53fccaa6	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x54215db5	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0x542ae1aa	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x54491f8a	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54641143	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54b0d8c6	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x54da7573	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0x54e1db1d	bmp085_probe
++EXPORT_SYMBOL_GPL vmlinux 0x54e3e541	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x54e52fed	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x54f8bafa	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x5508b12c	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55436043	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x554b6a48	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x554bd571	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x556f1f68	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x5579173f	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x55a8eb1e	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x55ddcc4b	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x563d8803	sk_unattached_filter_create
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564f1dca	klist_add_after
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x5658f0d2	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56913b66	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x56d43650	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e7d899	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x56eaf36b	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x570b673c	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x57143b1b	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x575c5f94	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0x575f8cca	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x5760dca7	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x57687d15	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x577084aa	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x5782e45c	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57b3eb25	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x57c59f2b	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x57f0cfae	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x581ff65a	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x582aa470	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x58413099	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x585fa688	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x587b559d	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x5886c802	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x58893bce	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x589cbc80	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58bb658f	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0x58d8d5c9	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x590884b7	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x59242f17	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5947abbe	max77693_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x594b7802	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x5953bc45	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x595bbce2	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5960f1ea	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x596ac419	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x59897096	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0x59b2adbf	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x59e2743e	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x59e88ab7	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a0005b8	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x5a10c9c3	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a441ebd	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x5a48534a	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x5a5ce7d8	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5ac2727f	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x5ac7e249	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b178ea7	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x5b2143c0	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x5b2a33de	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x5b42b607	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x5b599a51	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5b62ad19	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5b7aa8a6	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x5bef6f22	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5c0923f8	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x5c10958a	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x5c1830af	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0x5c55e1eb	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5c9f89c5	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0x5ca93699	tracepoint_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cf8a882	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d3b0d11	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5d48a650	m2p_find_override_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x5d77952d	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d91af2e	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x5da4a81d	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x5dd18380	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5defe19f	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x5df9d581	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x5dff25e3	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x5e074b5a	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x5e411242	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x5e48074c	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x5e4ad63b	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e6b1d95	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x5ebaacf2	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5f0a01e4	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0x5f248f72	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0x5f2502f5	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x5f2aaf57	set_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5f2b7f77	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x5f2bee79	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f607c95	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x5f77080f	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5f79a98b	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0x5f8c6aec	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x5f8f9c4c	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0x5fa67f92	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x5fb7ae44	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x5fbb282a	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fc31a82	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5fc3843c	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x5fcf118b	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5fef9c1f	dm_dispatch_request
++EXPORT_SYMBOL_GPL vmlinux 0x60098c01	sysfs_schedule_callback
++EXPORT_SYMBOL_GPL vmlinux 0x601800a0	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x60192d1d	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x6038c5d3	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x604fdef3	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6078c21a	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x607eb7de	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60a6d8c2	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x60b44d02	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x60b76c95	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x60bf56f9	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x60c7d04c	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0x60c95350	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60d37c7e	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x60d4a0e0	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x60e202d4	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x61091f38	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x6114d8a4	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x612cb165	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x612ee2d7	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x614e74ea	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x615a0ef7	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x6183ff15	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0x6194ffea	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0x61c0fee4	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x61c8556a	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x61dc241d	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0x61e25af9	platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x61f6c951	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x62122c3e	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x6223d719	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622dacba	tick_nohz_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x624603d6	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x6248b5be	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x624a85d0	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0x625a4431	inet_csk_reqsk_queue_prune
++EXPORT_SYMBOL_GPL vmlinux 0x6286d9da	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x62c5002e	tpm_read
++EXPORT_SYMBOL_GPL vmlinux 0x62cf4538	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x62df2c11	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x62f11450	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x63095945	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x63205de1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x6348c699	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x637c7342	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x638fe045	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x63b52aa5	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0x63f49d55	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x642dbff0	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x646683ba	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x64df32f8	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x64fa0b41	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x65012a1f	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x6521b7cd	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x6539ee53	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x65444690	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x65454ba9	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x6546e828	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x656d51e7	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x6599f620	crypto_lookup_aead
++EXPORT_SYMBOL_GPL vmlinux 0x65a3398b	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x65a942b5	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x65b5dcf6	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ca84bd	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d4ac63	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x65d6d0f0	gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x65e8a7aa	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x65f78cf3	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x65ff2579	get_matching_microcode
++EXPORT_SYMBOL_GPL vmlinux 0x66069728	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x660f9f96	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x661d0022	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x661d4dba	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6639a57f	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x663c16d6	gnttab_grant_foreign_access_subpage_ref
++EXPORT_SYMBOL_GPL vmlinux 0x666e4ecc	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66e5386f	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x66efe180	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x66f7f60d	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x66ffc476	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x67163d1e	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x672890b6	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x673a1863	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x6740e0d7	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x675bcc2b	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x67743ab4	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67eea1e2	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x680e447a	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x683b7957	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x68ab3093	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x68f8911c	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0x6921aa34	compat_put_timeval
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x694ea3e5	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x698be398	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x69e9a2cb	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x69ed2e8a	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x69f32429	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x6a105709	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a1a464a	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6a275db8	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6a4f308c	sysfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x6a53c4dc	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x6a5c2b41	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6cafd2	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a705c2b	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a939d9b	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6a93f2d1	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6a9583a0	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x6aa10d73	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x6aacf40e	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x6ab77430	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x6ab922b2	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x6aba167a	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6abf5900	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6ad2d082	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x6afb0934	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x6afc1ea4	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b47b960	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x6b7689bd	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x6b8422cb	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x6b868f2a	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x6b93bf60	inet_twdr_twkill_work
++EXPORT_SYMBOL_GPL vmlinux 0x6bc196ff	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6bce2ede	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6bce3e5a	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x6bf629b0	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c172cd8	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x6c454071	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x6c49c4f2	clockevents_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c657ecd	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x6c824360	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x6c858db8	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d5ae8	__gpio_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x6c9127dc	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x6c9f0963	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6ce4bfba	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x6d1e3ed9	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x6d2785b5	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d42c964	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6d477219	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6d593a69	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x6d9d5de4	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x6df6427d	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x6df8f4cd	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x6e02944e	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e17e11b	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x6e1b1e9c	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x6e536842	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e6c2ea6	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e7a8e2e	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x6e7aa34a	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e8bf789	hrtimer_start
++EXPORT_SYMBOL_GPL vmlinux 0x6ea98361	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x6eaaf95d	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0x6ec9e63c	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f45f35c	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x6f4afb6a	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x6f8a9d15	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x6f9474d0	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x6faf9a0e	rtc_set_mmss
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6fe517c5	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x700d8305	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x701444d5	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0x702616b3	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x703189d7	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x70621016	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x708e75eb	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x709a2292	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x70bfba8d	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x70c71936	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d0f033	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x70da5873	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x710e3fb8	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x714131ab	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x719bea20	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x71a17e59	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x71accde8	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x71b63079	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x71bc5d28	tpm_remove_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71f131c7	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x722fcfeb	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x723caf6a	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x72510fd5	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x72561e8a	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x725a0aef	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x72606e4e	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72ac2f0b	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x72b1ab86	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x72b212ff	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x72d7700f	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x72ed01e5	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x73056d81	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x731cffef	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x732210ac	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x732b4662	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x733b8f73	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x734ada6f	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73b062b7	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x73c2554f	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0x73d3dd29	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e02114	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x73eefa32	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x741b94ad	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x74319d6b	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x743bdaeb	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x744c5ab0	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x74536084	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x74954462	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74d7391d	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x74e7f6cb	pci_configure_slot
++EXPORT_SYMBOL_GPL vmlinux 0x74e819da	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x75063daf	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x75133f6e	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0x75215d2a	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x7527398d	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x752aa9bd	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x753ac429	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x756549b1	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x7565e694	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x756c2c48	__cpufreq_driver_getavg
++EXPORT_SYMBOL_GPL vmlinux 0x75752e63	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x757b49d2	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0x758a3812	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x759caec5	blkg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x75aac4a1	efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0x75aef261	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x75ea8261	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x7600aeca	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x7649709d	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768266ad	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x7697bfaf	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x76a7121a	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x76bb1114	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x770af2d3	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7714645b	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x772fbcaf	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x774f1e07	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x776f1f65	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x7776a13d	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x77877d1e	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x77d5dd73	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x77e78218	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x77eb011b	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x77fb9762	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x784ca081	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x787c882b	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x7898e9f3	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x78aa1d01	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x78ae758c	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0x78c28b17	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x78f10261	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x78f3063e	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x78f442b9	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x792d7f09	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x7939c92d	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x7962e853	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x796f1645	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x79726bf1	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x799f78df	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x79ac1a0e	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x79c173c6	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x79e55b51	register_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x7a00a11b	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x7a079981	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a3b157b	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x7a6c69fd	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x7a6f2be1	device_schedule_callback_owner
++EXPORT_SYMBOL_GPL vmlinux 0x7a933c98	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7acaa7d6	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7acc10f1	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x7ae1ae8e	cpufreq_frequency_table_put_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7affc41f	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d1bc1	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b1f9297	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x7b292d19	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x7b34d5b5	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7b46401b	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x7b6d10fc	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x7b76f711	tpm_store_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x7b8269f5	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x7b88da59	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7b9ba8c0	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x7ba08248	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7ba0b33c	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x7bacb5c6	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x7c0a5560	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x7c0d5364	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x7c1656f1	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x7c1f04af	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x7c309fa6	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x7c327fd5	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x7c4400b9	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7c5003c6	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7c503774	sysfs_put
++EXPORT_SYMBOL_GPL vmlinux 0x7c7e20cb	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x7c948a75	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x7c99bb09	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0x7c9edfc6	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x7cc1b7fd	max77693_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cf0d679	skb_gro_receive
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d78061a	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x7d7b2be5	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x7da54064	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dc01f1e	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x7dc94247	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7e131487	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x7e4304d9	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e665876	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x7e8133ef	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7ea1a2bc	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x7eb2afa3	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x7ec22f9a	apei_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0x7ee2dccb	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x7ee58834	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x7f0a44b8	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x7f0ad9f1	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x7f179dcd	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x7f18dd02	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x7f21b40b	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x7f232be9	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x7f2b3a67	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0x7f4ed584	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x7f577c70	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x7f77864d	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x7feedb83	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x7ffc8718	gpio_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x800808d5	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8010eb17	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0x80156244	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x802386eb	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x80446b36	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x80460463	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x80509b54	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x8060cec9	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x806e502f	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x807cd7d7	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80b2846f	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0x80c7c93a	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x80d3927f	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80e2d12d	tpm_remove_ppi
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x81daa07e	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8226642f	__gpio_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x823647e6	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x82428b14	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x825b33a0	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x828e26e3	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x82939ebd	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x82a1ad65	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x82cc41a1	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x82f18069	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8308fb83	sysfs_get_dirent
++EXPORT_SYMBOL_GPL vmlinux 0x832f84cf	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x8335a41f	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x837c0c4e	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x838aeea6	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x839a1705	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x83adda70	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x83b04410	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x83cc3235	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x8414248e	cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x841a3e0d	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x8447f293	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x844e895e	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x847c2d1e	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x847c41a0	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x8484f789	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8487a2b6	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x8493074e	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x8497c607	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x84a9f9f5	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x84b8a5a6	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0x84ff161a	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x85004b35	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x85024f8e	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x850c4e1b	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x8516ebbb	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x8522d15a	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8535b7fe	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x85478a0b	inet6_hash_frag
++EXPORT_SYMBOL_GPL vmlinux 0x85515627	mmc_send_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x858319b2	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x8588e90e	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x858c29ce	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x85938cb3	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x859aea9a	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x859cd679	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0x85c10896	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85cc30be	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85fa44ee	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x86219a72	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x862f98a3	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0x864163ae	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x86473ebb	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x865a146d	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x868482fe	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86925b6b	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86b7be71	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x86ea103f	tpm_write
++EXPORT_SYMBOL_GPL vmlinux 0x86ee4af4	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fafb61	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x8702e548	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x871aafeb	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x873583e7	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x874c22ae	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x875f9124	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x876bcfcd	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x8781f9c8	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x8786849e	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x8794cd19	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x87a532d5	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x87a5df58	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x87ad3453	tpm_show_pcrs
++EXPORT_SYMBOL_GPL vmlinux 0x87c10806	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0x87c7b311	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x87d882d0	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x87e9fb83	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x8800f181	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8844b703	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8866a607	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x88804bd2	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0x88900992	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x889937fd	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88cf0c4b	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x88d6dff1	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x88dfaf2e	acpi_dev_pm_detach
++EXPORT_SYMBOL_GPL vmlinux 0x8901ba5b	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x89068f07	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x891a0d00	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x8948958f	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x89502f0c	gnttab_subpage_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x896e6845	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89e4c862	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8a0f41f7	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8a36c407	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8a42c7c6	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0x8a4b8066	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x8a5c7a80	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8a909873	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8aa674f4	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0x8ab7e2b1	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac010e6	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x8ad191be	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x8ad531b7	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x8adaf687	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x8adb1d63	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b22f677	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x8b42cf19	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x8b439c61	class_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x8b665820	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x8b66f9e0	xen_platform_pci_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x8b68ce9f	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x8b752ac1	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x8b84d34a	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x8b9200fd	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x8ba01cf8	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x8bb1c478	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x8bc3562a	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c07e80c	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x8c1842a1	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x8c488ae8	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8c51f881	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x8c98166e	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x8cbe49ac	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8ce0053f	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x8ce0bc4f	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x8cea765f	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x8cf74b87	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8cfe1f94	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x8d009248	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8d039110	bmp085_detect
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d36c088	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0x8d586104	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8d6ff7a1	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8d8476b1	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x8d94a5cf	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x8da16bd8	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x8db56573	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf28e3	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8dcd374c	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x8de49da6	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x8df61046	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x8e143bf6	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x8e428254	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x8e43f390	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8e4f8ea8	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x8e506699	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x8e6f2c9d	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x8e709efa	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x8e9357ef	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x8edfb574	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x8eebe379	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8eef6e91	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x8f18fa19	sec_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x8f589238	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f710fce	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x8f8a365c	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x8fa671a3	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x8fd134a5	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8fd49702	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8fd94d78	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x8fdbfbe9	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9003aa50	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0x90049b7d	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x900cac74	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x901628ba	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0x9022303e	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x90526b09	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x905a0f3a	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x906f560a	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x90705b7f	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9089693f	wm8994_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x908c0cd3	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90dc29df	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x9104b86e	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x9122a19c	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0x9122b079	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x916cfa78	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918e0114	guest_enter
++EXPORT_SYMBOL_GPL vmlinux 0x91ac930f	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d70984	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x91dde6fd	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x91dfa905	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x91fd7345	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x92057c8e	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x920cc389	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x9225377d	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x9225a1b0	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x9229380e	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x927ac1db	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x928da309	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x92942873	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x92be1ba3	pci_pri_status
++EXPORT_SYMBOL_GPL vmlinux 0x92ccf7c8	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x92cf9d14	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x92d31cfb	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x92f99cb1	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x9304d50a	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x930965bf	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x930b0369	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9324af20	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x9324e78e	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x9331b8fa	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x934471d9	__scsi_get_command
++EXPORT_SYMBOL_GPL vmlinux 0x93957eb2	pci_msi_off
++EXPORT_SYMBOL_GPL vmlinux 0x939bf640	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x93a21575	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x93abb1c6	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x93c1fb34	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x93d2422d	snmp_mib_free
++EXPORT_SYMBOL_GPL vmlinux 0x93d42431	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x93f74001	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x93ffb269	devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942323f1	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x949f7342	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x94a68723	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x951cc6b5	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9532e545	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x955046af	__mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x9551d172	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x9560b1e1	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x956a91ba	gpio_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x957d8068	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95a2549a	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95c54cdb	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x95c81cfa	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x95d166be	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x95e89a11	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0x95fb3cf9	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x96104781	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x96460e1e	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x96481fa3	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964d5c39	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0x964d67a8	spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x964d9ed2	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x966352a5	inet6_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x966d821c	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x96a22790	vmcore_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x96d53f8a	sysfs_rename_link
++EXPORT_SYMBOL_GPL vmlinux 0x96e051f6	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x972dc720	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x9748f1f6	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x9764bc7b	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x978aaf2b	m2p_add_override
++EXPORT_SYMBOL_GPL vmlinux 0x9792ccb8	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x979cb557	sec_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x97a0fb97	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x97cd6002	tcp_reno_min_cwnd
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97ff20e8	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x98074b77	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x98192944	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x981a0ee3	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x984bea68	pci_pri_stopped
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98c7598c	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x98cc564a	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x98f57019	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x9939076c	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x995169c5	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x996107b5	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x996a37e0	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9973934a	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a1b091d	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x9a4ba8dd	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x9a60a3a3	sysfs_notify_dirent
++EXPORT_SYMBOL_GPL vmlinux 0x9a7c1ec9	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aa04a07	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9ab16f81	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9aca444b	get_monotonic_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x9acece68	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b16fc01	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x9b279511	unregister_acpi_bus_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9b2af717	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x9b5710ed	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x9b6a7412	idle_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x9b70c693	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x9b748924	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x9b8d9503	hv_register_vmbus_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9ba2bb2b	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9bd94ed6	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9bf82eda	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9c097af1	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x9c0a7b42	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0x9c0ae39a	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9c10cf9d	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x9c22fbe0	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x9c2de449	memory_add_physaddr_to_nid
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c4c643a	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x9c65f201	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x9c6ac5a6	bmp085_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x9c70e719	regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x9c739e8d	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x9c7cecde	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x9c9cc940	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x9cbf1254	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cce9fa3	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x9cd3eb6e	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d1705a5	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x9d1add01	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d3944aa	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x9d954f1e	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x9d9e155d	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0x9e085025	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x9e2dd86d	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9e4a3b42	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x9e57fc9a	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x9e9d234e	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x9ec9b159	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0x9ed3143c	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9eeed384	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x9f0664bf	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0x9f17df81	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9f229671	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x9f4b3ed9	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x9f635977	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0x9f80fe13	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x9fb27a36	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0xa00920e8	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xa00fae07	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xa018f013	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0xa03d2821	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xa0597e3f	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0xa0634dae	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xa09b3eb5	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xa0a6f2b1	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xa0b54a9c	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL vmlinux 0xa0ca27cf	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa0caee59	__online_page_increment_counters
++EXPORT_SYMBOL_GPL vmlinux 0xa0ce1364	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0xa0cfb6c0	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0xa0d744c2	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xa0fae9ef	of_reset_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xa0fb78fb	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa11cf5ac	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa130ee7b	aead_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xa148f7ff	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xa14af079	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa187c3fd	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xa1955299	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xa228f193	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0xa22deea0	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xa2332d84	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0xa245e434	crypto_aead_type
++EXPORT_SYMBOL_GPL vmlinux 0xa25aab03	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa25eea09	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xa2665f00	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa27d2d84	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xa2883bc5	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xa2937210	devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xa298d8be	inet_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xa2992950	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xa29bfb58	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa2e29e17	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0xa2e67f08	acpi_bus_generate_proc_event4
++EXPORT_SYMBOL_GPL vmlinux 0xa3218ca3	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xa345b9e9	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa3631167	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3ae6b6f	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa3b11087	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3f0efa1	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xa3f3e1b3	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xa40c0884	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0xa413aec3	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0xa421a59f	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xa42cc217	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xa42fbc9f	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa48f8e5c	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa49c943a	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xa4ca60de	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xa4d500e3	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xa4d58669	math_state_restore
++EXPORT_SYMBOL_GPL vmlinux 0xa51890ca	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xa555cff1	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xa56ca855	tracepoint_iter_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa56d001e	default_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0xa57b3566	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0xa5ce82b7	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xa5d529a3	cgroup_rightmost_descendant
++EXPORT_SYMBOL_GPL vmlinux 0xa5e10cc4	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5f14d3a	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0xa60ee2d9	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa65da706	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa66438e8	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xa66ea443	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa676426f	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xa683a497	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xa6a0a273	max77693_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa6a75364	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6c3c586	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xa6c4b663	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6f78e37	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa720caa9	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0xa724257f	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa75312bc	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0xa754fe8e	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xa77c0a41	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xa7806879	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xa7806c69	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xa7935759	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xa796843d	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xa7b19faa	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xa7e20df3	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7e6e589	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xa7f92105	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa81e3f0b	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa8569c63	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0xa866cfbb	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xa87db02c	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xa895f774	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0xa8b82a53	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa8df65b9	sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xa8e186e7	d_materialise_unique
++EXPORT_SYMBOL_GPL vmlinux 0xa8f59416	gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xa8f6b19e	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xa8f9b7a9	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa918bcf0	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xa925e478	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0xa94ff0f0	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0xa97a6202	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xa9866ba6	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xa9a82042	gnttab_trans_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0xa9d0e3ce	bdi_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9fc3f54	gnttab_grant_foreign_access_trans
++EXPORT_SYMBOL_GPL vmlinux 0xaa26c88a	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaa7c473f	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaab3e189	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xaab41358	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab1ef0c9	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0xab1f7e4f	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xab5240b2	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xab62b44a	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0xab64db9d	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xab6a3a82	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab9a3889	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xabe21c08	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xac040b2a	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xac06a98d	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xac8bb4e8	__clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xacb11e63	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacf3be9e	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xad039c54	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0xad3b638e	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xad5a6715	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xad8fbbbf	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xada05bdf	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xada38534	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadfe1298	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0xae0912aa	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0xae0f6b4e	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xae119af4	cgroup_taskset_cur_cgroup
++EXPORT_SYMBOL_GPL vmlinux 0xae14e935	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0xae68bcec	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae69e1d0	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae7c5411	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0xae86e5b5	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0xae9aab5b	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0xaec23ad0	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xaeefb268	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0xaf1bc339	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xaf28ca38	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xaf6d794e	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xaf904248	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0xafdc5791	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0xb01b4ccf	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xb01fc3d6	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb020dc81	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb03b6960	tpm_show_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xb03f60da	ftrace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0xb060cc3f	cgroup_load_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb07248a5	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0xb0a46086	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0d1656c	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0xb0d44e89	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb0ee7cf3	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xb10d55bc	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xb13e8b8d	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb13f5f00	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb142ea17	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb159aa0b	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xb15e8716	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb17a8214	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb19f26e0	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1bedeb7	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e4b225	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb2354ac2	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0xb2359cca	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xb24018b0	tpm_show_temp_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0xb2418655	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb2c9e797	tpm_bios_log_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb31a025b	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb347bb2c	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb34a72d3	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0xb350f190	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb3559bec	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xb36c1f1c	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xb36cde24	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xb37d3225	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0xb3c57e27	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb42e1a41	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xb4322581	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xb43725dc	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xb4578d6f	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xb4759adc	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0xb478d8f8	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xb47d97ac	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xb48b170a	pci_pri_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xb49c67ef	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4c3957d	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0xb4cf97b6	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xb4d4afca	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4e22483	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4fba09a	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xb50f2dea	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb528bf1a	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xb5342dd2	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5488dff	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb57320ba	crypto_rng_type
++EXPORT_SYMBOL_GPL vmlinux 0xb579ba29	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5a5d300	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xb5b3c47a	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xb5cb8145	hrtimer_get_res
++EXPORT_SYMBOL_GPL vmlinux 0xb5efd461	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb62cdb24	ata_sas_port_async_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb63cecbc	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xb63f3c17	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0xb6580c48	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb67b2219	cm_suspend_again
++EXPORT_SYMBOL_GPL vmlinux 0xb68eea2b	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6c5f7da	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb6c635af	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb6fd3a81	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0xb709e339	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb7251f48	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb73076ce	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0xb7365937	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0xb7807e91	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb781e5a5	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0xb7aa2e42	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb7b6ab91	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7e6ddb6	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xb7ebc0d2	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xb7ece0a6	need_load_eval
++EXPORT_SYMBOL_GPL vmlinux 0xb7f3ba1e	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb80499af	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0xb831428d	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xb87cfbd2	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xb880b42f	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xb8882134	cpufreq_get_measured_perf
++EXPORT_SYMBOL_GPL vmlinux 0xb89c80bd	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb8aac964	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8b96417	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0xb8c6c06a	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0xb8cc9179	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xb8ea951f	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb91cb704	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0xb91e849f	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xb92adfd5	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xb94e4469	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xb97f25a4	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb98a730f	event_storage_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9ae1a53	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9dc74fe	dev_get_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0xb9dd5bdf	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0xb9ecdf9a	wm8994_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9edbaef	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xba18b423	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0xba2c7b88	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0xba2cb3e3	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0xba3ff080	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xba7e9a85	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xbab0edea	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0xbaf1944d	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xbaf2ecb3	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0a4ebf	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb128381	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xbb19816d	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xbb1ff9ab	dm_kill_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0xbb37d656	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0xbb521d73	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbb586b86	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xbba8a46e	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xbbab0773	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xbbb1de4c	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0xbbb38239	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbc3ed82	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbbc656df	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbbf1f633	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0xbbfa30a9	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0xbc2d3466	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0xbc8c7c54	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcaee055	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbcc9e0dd	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xbccdd9ea	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xbccfc839	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbd13b163	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xbd27d9cf	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0xbd506a46	unregister_hotplug_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd73d20b	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xbd79e89a	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0xbd939492	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbd9dfa87	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0xbda17c3f	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xbda382b8	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xbdabf04f	cgroup_taskset_first
++EXPORT_SYMBOL_GPL vmlinux 0xbdaf5686	get_compat_timeval
++EXPORT_SYMBOL_GPL vmlinux 0xbdc33829	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbdd61c14	__add_pages
++EXPORT_SYMBOL_GPL vmlinux 0xbe0f2479	devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe190c0c	free_css_id
++EXPORT_SYMBOL_GPL vmlinux 0xbe1e6aca	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xbe4c3b7b	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xbe53ca16	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xbe55763f	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xbe5d0996	idle_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe82510a	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0xbe846ece	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xbe8bfb4c	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xbe98086e	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbec34731	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbed20d9a	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbed461df	cgroup_next_sibling
++EXPORT_SYMBOL_GPL vmlinux 0xbeda6751	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf295135	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xbf41e4bb	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbf461517	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xbf82e6af	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xbf93cb0b	sk_unattached_filter_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbf95bb34	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xbfb0a21a	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfd19f49	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbffde8ec	compat_alloc_user_space
++EXPORT_SYMBOL_GPL vmlinux 0xc0292566	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc04af3ff	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc04e78b9	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0900fcf	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc0ac22a6	clockevents_unbind
++EXPORT_SYMBOL_GPL vmlinux 0xc0b0e6ec	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xc0bf6ead	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xc0bf7f3d	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xc0c501a0	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0fc7766	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xc11143b5	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xc11913d7	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0xc11bd00f	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc132a1a7	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xc1461947	cgroup_taskset_next
++EXPORT_SYMBOL_GPL vmlinux 0xc14c2824	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc16d3f2f	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc17b89b8	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc1935f33	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xc1b09c05	sec_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0xc1dc0d5d	acpi_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xc1ec1984	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc2332c9a	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc2686758	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc29cc2ab	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xc2dfa266	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0xc30fda23	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc316db3d	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0xc31ba5d7	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xc31d7504	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0xc32fa39c	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xc3418d64	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34efe27	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc37763fc	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xc3bbcee8	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc40a2cac	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc40cf8b2	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xc4177d6f	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc441f9a2	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xc447dd93	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xc46058f9	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0xc461c952	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4ab280a	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xc4ab5e76	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0xc4c06846	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc4c61824	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0xc4cb3f06	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc4e77a20	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xc506c32d	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xc51059e5	xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0xc512626a	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xc527113c	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc551fd33	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xc5687d85	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xc573eec1	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc587cd84	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc5ac5637	m2p_remove_override
++EXPORT_SYMBOL_GPL vmlinux 0xc5c3f993	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xc5e1ae9d	blkdev_aio_write
++EXPORT_SYMBOL_GPL vmlinux 0xc5ece8bf	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xc5f791c6	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xc6024f18	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xc6060bcc	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc60c39d2	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xc60dbbca	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0xc60f75ec	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc660c79a	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc684c2eb	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0xc690866c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6d7ad42	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xc6e25e99	tracepoint_iter_start
++EXPORT_SYMBOL_GPL vmlinux 0xc6ec3274	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc73851ee	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xc78d2327	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7a32f2f	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xc7af8394	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e1abbb	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7e4de26	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0xc7fce1f8	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xc81ef295	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc845ccf6	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0xc85ad4a5	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc899c0f2	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xc8a4c89d	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc911f405	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc92de37d	__clocksource_updatefreq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xc9377a36	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xc94a5755	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xc94efd94	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9641b48	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0xc964fa6e	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc9c1a83b	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xca459583	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xca480808	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0xca627962	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xca75cdc2	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xca85d8cf	tracepoint_probe_update_all
++EXPORT_SYMBOL_GPL vmlinux 0xcaab12d3	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcab7ab2a	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb3e902a	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb4bbec7	serial8250_tx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xcb4cfa1b	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0xcb9617c9	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xcbe9b49b	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbf9e5a1	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0xcc1f1c3d	inet_twdr_hangman
++EXPORT_SYMBOL_GPL vmlinux 0xcc2e8c93	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xcc36fbb1	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xcc46dc8d	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0xcc51bef4	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xcc6ab305	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0xcc770e3b	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc9c8dba	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xccaf0207	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xcce61bf0	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xcd2294a9	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xcd39fc90	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcd4ebe85	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0xcd50d655	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xcd5a3a0d	__netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xcd5b5ada	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0xcd60fe28	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xcd7ac3b3	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xcd856c42	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd93b791	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd24d6a	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xcdd6f537	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xcdffc086	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xce0b9b59	max77693_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xce0f519c	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xce0fc39d	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xce1aa2f0	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0xce24db94	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xce2dffc2	tpm_show_durations
++EXPORT_SYMBOL_GPL vmlinux 0xce46e140	ktime_get_ts
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6afa31	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xce6e1e87	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xce959802	__rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0xcea5c6cd	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xceb1f126	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcef0a3af	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcf02d385	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0xcf0a197b	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcf24460d	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf77054e	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c1b75	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xcf9db270	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0xcfa39eca	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xcfa878d0	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xcfad7286	__ip_route_output_key
++EXPORT_SYMBOL_GPL vmlinux 0xcfc62f27	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfc7af18	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xcfde5862	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xcff6971e	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd04c0bed	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0b996d8	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0d18557	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xd0d9c2b4	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xd1109007	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0xd124818a	tcp_init_congestion_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd13da64d	dma_buf_export_named
++EXPORT_SYMBOL_GPL vmlinux 0xd14bc4d9	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd161e156	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd18ba849	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0xd1b2db37	tracepoint_probe_register_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xd1e05422	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0xd1e7fc33	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd22f45a8	smpboot_register_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xd231e9a1	sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xd248099f	cgroup_is_descendant
++EXPORT_SYMBOL_GPL vmlinux 0xd24eb145	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2afe2b2	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd2b3f908	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2ea29c9	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xd3270ee6	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xd32fe193	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd355fa06	tpm_show_pubek
++EXPORT_SYMBOL_GPL vmlinux 0xd37e13b4	regulator_set_optimum_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd37e522e	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0xd3a6815f	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xd3a826cb	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xd3e11c76	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xd3ed444e	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd41a8e81	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd426dbc4	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xd4402738	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd45255b2	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd4629cf9	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0xd46bbbd2	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0xd47b857d	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xd47bc2f7	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd4ab31c8	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xd4b0f60b	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4c3f9a5	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xd4d153f4	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xd4d7370c	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xd4da4e82	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0xd50c0d9b	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0xd50edaf7	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd545ab91	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xd55a3e1a	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd55cc5fa	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd57f9e5f	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xd5aa273d	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5ea5578	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xd6011bf5	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0xd61d7c6e	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0xd63b089b	tcp_is_cwnd_limited
++EXPORT_SYMBOL_GPL vmlinux 0xd64de042	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd69967ae	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xd69cb086	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70a900c	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd730423a	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd747a966	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd78dcf4e	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xd7a431d7	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xd7b721af	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7e8bf4f	tpm_show_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xd814e82e	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8268d5d	register_acpi_bus_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd8525ea7	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xd85a6114	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd85ac634	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd881f94f	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xd884a61e	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0xd8bf3abc	cgroup_next_descendant_pre
++EXPORT_SYMBOL_GPL vmlinux 0xd8db8e2d	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd9210842	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94b5bda	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd96a2de6	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd9735ca3	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xd9ab7681	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xd9aecce4	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0xd9d7f623	pkey_id_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9e2f673	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda17aa29	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xda383dd1	user_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xda3a7ca9	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xda44cb37	setup_charger_manager
++EXPORT_SYMBOL_GPL vmlinux 0xda45fccc	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xda6b4e86	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xdab50ae7	fpu_finit
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb04cacc	tracepoint_probe_unregister_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xdb27f477	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xdb379936	tpm_release
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb9a94ab	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0xdba7c7d9	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdbd29e44	sysfs_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xdbe220b6	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xdbec834f	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdbf99f6a	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xdbfee28f	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xdc08e50a	xenbus_dev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc262632	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc4677a0	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xdc57c933	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xdc61c6f5	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc96f419	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9d958e	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca4bf67	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xdcd5ec6f	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xdce542c5	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xdce57037	apei_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0xdd226737	alloc_acpi_hp_work
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd33a17f	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3f3ee2	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0xdd452cfc	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xdd4c281d	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xdd4db8cf	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xdd647991	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xdd6618ba	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0xdd794d33	phys_wc_to_mtrr_index
++EXPORT_SYMBOL_GPL vmlinux 0xdd7ff237	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xde0ba172	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xde19e47a	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0xde463f13	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xde4e19ba	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xdea70bae	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xdee17091	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf115301	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf25675c	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xdf2a53b0	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xdf2de7b4	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xdf432029	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0xdf44cf3f	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xdf7f8b5b	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xdfb025a8	__online_page_set_limits
++EXPORT_SYMBOL_GPL vmlinux 0xdfc2cc98	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xdfc59831	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe0337b10	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0xe040fc90	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0xe0429981	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xe058126a	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xe074ee00	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe08bff47	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0xe09df326	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe10bab1c	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe14d4bcc	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xe14f3199	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0xe160594f	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xe16b0d30	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe1ba1445	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1db17e5	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xe2361792	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xe2515122	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0xe265bf06	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0xe26e46f0	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2976286	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0xe2b42d90	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0xe2d5bebe	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xe2d64920	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0xe2dd67e5	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xe2e7840d	regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe3573a06	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xe384a102	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3bd0d7b	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0xe3ca0c52	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xe3cee50f	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xe3e46ce8	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xe3e48439	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xe3e9f3b6	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xe3f102d9	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xe40b4268	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xe40e5dd0	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe427b1ec	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe4392196	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xe4655b46	tpm_show_caps_1_2
++EXPORT_SYMBOL_GPL vmlinux 0xe4ab471b	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xe4e18f97	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe4e74c37	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0xe503fd24	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xe50ec63d	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xe51701a9	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xe5327051	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xe54d87dc	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0xe5593fc2	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xe582ff3b	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5a55b33	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xe5b88967	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0xe628a094	restore_online_page_callback
++EXPORT_SYMBOL_GPL vmlinux 0xe648d95c	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe64ae449	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe6602e9f	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xe66e336d	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xe67e129d	acpi_i2c_register_devices
++EXPORT_SYMBOL_GPL vmlinux 0xe69e24b7	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6dbfaf8	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xe6dd04af	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe71be678	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe735da47	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xe7631e26	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe78322d9	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xe7a2381b	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0xe7c4da7f	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0xe7e9eaac	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xe7ef601f	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0xe7f3608a	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe826e0a0	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xe830cf43	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xe84925c6	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xe84ece8e	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe86a6a77	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe86ef8f2	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0xe8924853	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0xe89bd243	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xe8b2b6e6	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xe8c1d643	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0xe8cf21a7	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe8daf5dc	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xe8eb8b91	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe9011563	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xe90b2142	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0xe90f6e25	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe9785fc8	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe9995997	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0xe9c161cf	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea501227	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0xea628c20	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0xea79001c	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xea9b7ab3	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xea9ec4b0	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xeadf816e	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0xeaeb7601	tpm_show_owned
++EXPORT_SYMBOL_GPL vmlinux 0xeb1493a3	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xeb1c3628	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xeb1de447	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xeb1f868b	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb6db220	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xeb9cf96d	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xeba3c5b1	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0xeba745e1	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xebb8fbdd	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xebd03aa0	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xebd47db1	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0xebd55f20	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xebdab17e	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec0038c4	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec23a803	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec2dde3e	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0xec348786	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xec40dfb6	nfq_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xec4d2bf4	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xec631f34	remove_memory
++EXPORT_SYMBOL_GPL vmlinux 0xec785f15	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0xec7a64d6	user_match
++EXPORT_SYMBOL_GPL vmlinux 0xec8e53a7	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xecade2d7	init_fpu
++EXPORT_SYMBOL_GPL vmlinux 0xecba95e3	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xecc3c7d7	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xecc8bd81	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0xece2e2c9	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xecedbac7	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xecf6317f	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0xed14c4f6	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0xed3d3dae	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xed3f5844	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0xed808b55	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xed94d102	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedd3a715	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xedd49930	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0xededbe13	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xedf008bf	inet6_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xee1395bc	blk_rq_check_limits
++EXPORT_SYMBOL_GPL vmlinux 0xee13e697	set_personality_ia32
++EXPORT_SYMBOL_GPL vmlinux 0xee2095d3	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xee29f5ef	cpufreq_notify_transition
++EXPORT_SYMBOL_GPL vmlinux 0xee38317c	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xee3d9a0a	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0xee56b2a2	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee6cc7c6	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xee7add6f	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xee83cfb8	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xee9f6665	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xeeb4c33e	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef4997b0	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xef4ce860	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6d007a	sigset_from_compat
++EXPORT_SYMBOL_GPL vmlinux 0xef782b88	gnttab_grant_foreign_access_subpage
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xefa54a9d	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xefa863d9	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xefad49ac	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xefafc469	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xefb5cf6f	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xefc91531	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xeffa6b8f	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0xf03ae259	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xf0451473	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xf04632df	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf0c7f8de	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf0f72dee	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xf105b27d	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0xf131267c	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf1369484	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xf15be8dc	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0xf16d5514	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf186c82f	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1ef192a	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xf1f04fc9	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0xf1f20e99	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xf21b81fc	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf21fad1e	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0xf230af2c	devm_kzalloc
++EXPORT_SYMBOL_GPL vmlinux 0xf24e17b3	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf285f70a	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0xf2b8419c	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xf2bf1c58	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xf2d9872a	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf2df0109	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0xf2eef3ae	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf307cded	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf3150816	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf3338d3d	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xf33ceccd	tpm_bios_log_teardown
++EXPORT_SYMBOL_GPL vmlinux 0xf363ba0f	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xf388e912	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xf38f8564	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xf394db79	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xf39dbda9	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xf3a0a356	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xf3ae7649	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xf3aec308	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3be0849	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd036d	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xf3de1cb7	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xf3f18401	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xf3f93538	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf42b1801	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xf446d3e2	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4a4cec7	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xf4a86323	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xf4ab23c3	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf4b4b2f7	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xf4d11573	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0xf4f1646c	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xf4faeada	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf513151d	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf54728c8	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf54ec9a8	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf5888faf	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf59ac39d	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5c02506	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf5cbaff8	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xf5fef4e3	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf6037931	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf61356da	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xf6674893	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xf6748423	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf6c9030a	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xf6cff375	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xf6e04730	event_storage
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf73164c8	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf7322bc8	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf74656ab	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf749c5d6	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xf76591a8	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xf766a6be	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0xf778f0ec	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xf79b08b6	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xf7a14f56	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf7a16972	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xf7b42087	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xf7c72410	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xf7f69030	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf86a3a9f	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf8be9632	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf9014a89	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xf9082e86	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0xf91795c4	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xf91844db	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf9576410	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf97666a0	set_memory_rw
++EXPORT_SYMBOL_GPL vmlinux 0xf985c030	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf9924426	arch_add_memory
++EXPORT_SYMBOL_GPL vmlinux 0xf99aa323	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0xf99bd016	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a52e0f	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0xf9b6ebad	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xf9ba1cee	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d2e02c	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0xf9d44856	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xfa012fe7	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa1be8ef	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa226037	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xfa48fafa	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xfa4a647e	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xfa70a1c0	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa744482	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa901b31	compat_get_timespec
++EXPORT_SYMBOL_GPL vmlinux 0xfab4d0f9	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xfaf63864	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfafce562	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xfaffa650	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xfb17dec1	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb26a0d7	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb707ac3	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xfb7b1f1c	dm_underlying_device_busy
++EXPORT_SYMBOL_GPL vmlinux 0xfb94b645	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xfbba54cc	cgroup_next_descendant_post
++EXPORT_SYMBOL_GPL vmlinux 0xfbe5c3b5	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc201b66	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0xfc2b8a48	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc4f92dd	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xfc4fa6d7	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xfc5c0dff	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xfc8f417d	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfcbf4386	wm8994_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xfcc8d93d	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0xfcd7bc0b	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfceba9e8	tpm_add_ppi
++EXPORT_SYMBOL_GPL vmlinux 0xfcf3fb73	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xfcffecfb	serial8250_rx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xfd03cfcf	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xfd061beb	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0xfd06cbd0	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xfd19b01d	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xfd452a9e	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xfd4a1a84	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd5e5720	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xfd63772f	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd77d7d4	irq_find_host
++EXPORT_SYMBOL_GPL vmlinux 0xfdb1544c	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xfdc56fb2	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xfdcc87a9	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xfdce4c54	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0xfdd48552	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xfdd756e9	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xfe03d022	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xfe0c12b3	devres_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfe11c009	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0xfe3b69e2	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xfe446ae1	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xfe59b123	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xfe5a27b5	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xfe6b6d72	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe7dedec	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfea1d211	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0xfea8b359	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff37ce21	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff6b11c2	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xff6eb8b1	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0xff74ce57	css_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xff76ed92	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xff9f31c6	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xffbb01c7	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xffc6495b	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xffd47412	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xffdd49ee	class_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xffe06ab6	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfff7e16f	invalidate_inode_pages2_range
+diff --git a/debian.master/abi/3.11.0-13.20/amd64/generic.compiler b/debian.master/abi/3.11.0-13.20/amd64/generic.compiler
+new file mode 100644
+index 0000000..fd6ee97
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/amd64/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 4.8.1-10ubuntu8) 4.8.1
+diff --git a/debian.master/abi/3.11.0-13.20/amd64/generic.modules b/debian.master/abi/3.11.0-13.20/amd64/generic.modules
+new file mode 100644
+index 0000000..3849612
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/amd64/generic.modules
+@@ -0,0 +1,3956 @@
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8255
++8255_pci
++8390
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++88pm860x-ts
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++a100u2w
++a3d
++a8293
++aacraid
++aat2870_bl
++aat2870-regulator
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acerhdf
++acer-wmi
++acpi_ipmi
++acpi_pad
++acpiphp_ibm
++acpi_power_meter
++acquirewdt
++act200l-sir
++act_csum
++act_gact
++act_ipt
++actisys-sir
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5930
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad9850
++ad9852
++ad9910
++ad9951
++adcxx
++addi_apci_035
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520_bl
++adp5520-keys
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++ads1015
++ads7828
++ads7846
++ads7871
++ad_sigma_delta
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7180
++advansys
++advantechwdt
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aesni-intel
++aes-x86_64
++af_802154
++af9013
++af9033
++af_alg
++affs
++af_key
++af_packet_diag
++af-rxrpc
++ah4
++ah6
++aha152x_cs
++ahci
++ahci_imx
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aiptek
++aircable
++airo
++airo_cs
++ak8975
++alauda
++algif_hash
++algif_skcipher
++ali-ircc
++alim1535_wdt
++alim7101_wdt
++alphatrack
++altera-ci
++altera_jtaguart
++altera_ps2
++altera-stapl
++altera_uart
++alx
++ambassador
++amc6821
++amd5536udc
++amd64_edac_mod
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amd_iommu_v2
++amd-rng
++amilo-rfkill
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pci224
++amplc_pci230
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9802als
++apds990x
++apple_bl
++appledisplay
++apple-gmux
++applesmc
++appletalk
++appletouch
++applicom
++ar5523
++ar7part
++arc4
++arcfb
++arcmsr
++arcnet
++arc_ps2
++arc-rawmode
++arc-rimi
++arc_uart
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arptable_filter
++arp_tables
++arpt_mangle
++as3711_bl
++as3711-regulator
++as5011
++asb100
++asc7621
++asix
++ast
++asus_atk0110
++asus-laptop
++asus-nb-wmi
++asus_oled
++asus-wmi
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at86rf230
++at91_ether
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmel_pwm
++atmel-pwm-bl
++atmel-ssc
++atmtcp
++atp
++atp870u
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auo-pixcir-ts
++authenc
++authencesn
++auth_rpcgss
++autofs4
++avma1_cs
++avm_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++b1
++b1dma
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm203x
++bcm3510
++bcm5974
++bcma
++bcma-hcd
++bcm_wimax
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++blowfish-x86_64
++bluecard_cs
++bluetooth
++bma150
++bmp085-i2c
++bmp085-spi
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bonding
++bpa10x
++bpck
++bpctl_mod
++bpqether
++bq2415x_charger
++bq27x00_battery
++br2684
++brcmfmac
++brcmsmac
++brcmutil
++bridge
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btcx-risc
++btmrvl
++btmrvl_sdio
++btmtk_usb
++btrfs
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++BusLogic
++bw-qcam
++bypass
++c2port-duramar2150
++c4
++c67x00
++cachefiles
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia-aesni-avx-x86_64
++camellia_generic
++camellia-x86_64
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5-avx-x86_64
++cast5_generic
++cast6-avx-x86_64
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc770
++cc770_isa
++cc770_platform
++c_can
++c_can_pci
++c_can_platform
++cciss
++ccm
++cdc-acm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc-phonet
++cdc_subset
++cdc-wdm
++cedusb
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++chipreg
++chnl_net
++chromeos_laptop
++cifs
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clearpad_tm1217
++clip
++clk-max77686
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_cgroup
++cls_flow
++cls_fw
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobra
++coda
++com20020
++com20020_cs
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_bond
++comedi_fc
++comedi_parport
++comedi_test
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cordic
++core
++coretemp
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpqarray
++cpu5wdt
++cpuid
++cpu-notifier-error-inject
++c-qcam
++cramfs
++cr_bllcd
++crc32
++crc32-pclmul
++crc7
++crc8
++crc-ccitt
++crc-itu-t
++crct10dif-pclmul
++cros_ec
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++crvml
++cryptd
++cryptoloop
++crypto_null
++crypto_user
++crystalhd
++cs5345
++cs53l32a
++cs5535-mfd
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx8800
++cx8802
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cxt1e1
++cy8ctmg110_ts
++cyapa
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052_bl
++da9052-hwmon
++da9052_onkey
++da9052-regulator
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055_onkey
++da9055-regulator
++da9055_wdt
++DAC960
++daqboard2000
++das08
++das08_cs
++das08_pci
++db9
++dc395x
++dca
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell_rbu
++dell-wmi
++dell-wmi-aio
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgrp
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++divacapi
++divadidd
++diva_idi
++diva_mnt
++divas
++dl2k
++dlci
++dlm
++dm1105
++dm9601
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-crypt
++dm-delay
++dme1737
++dmfe
++dm-flakey
++dmi-sysfs
++dm-log
++dm-log-userspace
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-raid45
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dmx3191d
++dm-zero
++dnet
++dn_rtmsg
++docg3
++docg4
++dpt_i2o
++drbd
++drm
++drm_kms_helper
++drm_usb
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsa_core
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt3000
++dt3155v4l
++dt9812
++dtl1_cs
++dummy
++dummy-irq
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-it913x
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb_usb_v2
++dvb-usb-vp702x
++dvb-usb-vp7045
++dwc2
++dwc2_pci
++dwc2_platform
++dwc3
++dwc3-exynos
++dwc3-omap
++dwc3-pci
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e4000
++e752x_edac
++earth-pt1
++eata
++ebt_802_3
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ec100
++echo
++ec_sys
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efi-pstore
++efs
++einj
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++emc1403
++emc2103
++emc6w201
++em_canid
++em_cmp
++emi26
++emi62
++em_ipset
++em_meta
++em_nbyte
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++em_text
++emu10k1-gp
++em_u32
++enc28j60
++enclosure
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++ext2
++extcon-adc-jack
++extcon-arizona
++extcon-gpio
++extcon-max77693
++extcon-max8997
++extcon-palmas
++exynos-rng
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_ddc
++fb_sys_fops
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++flashloader
++floppy
++fm801-gp
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fm_drv
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-udc
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft1000
++ft1000_pcmcia
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++funsoft
++fusbh200-hcd
++g450_pll
++g760a
++g762
++g_acm_ms
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++g_audio
++g_cdc
++gcm
++g_dbgp
++gdmwm
++gdth
++generic
++generic-adc-battery
++generic_bl
++gen_probe
++g_ether
++gf128mul
++gf2k
++g_ffs
++gfs2
++ghash-clmulni-intel
++ghash-generic
++g_hid
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++glue_helper
++gma500_gfx
++g_mass_storage
++g_midi
++g_ncm
++g_nokia
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goldfish_battery
++goldfishfb
++gp2ap002a00f
++gpio-74x164
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-arizona
++gpio-charger
++gpio-cs5535
++gpio-da9052
++gpio-da9055
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it8761e
++gpio-janz-ttl
++gpio_keys
++gpio_keys_polled
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio_mouse
++gpio-pca953x
++gpio-pcf857x
++gpio-pch
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio_tilt_polled
++gpio-tps65912
++gpio-ts5500
++gpio-twl6040
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++g_printer
++gre
++grip
++grip_mp
++gsc_hpdi
++g_serial
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++g_webcam
++g_zero
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdlc
++hdlc_cisco
++hdlcdrv
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfcmulti
++hfcpci
++hfcsusb
++hfc_usb
++hfs
++hfsplus
++hgafb
++hid
++hid-a4tech
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-cherry
++hid-chicony
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-generic
++hid-gyration
++hid-holtekff
++hid-holtek-kbd
++hid-holtek-mouse
++hid-huion
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo-tpkbd
++hid-logitech
++hid-logitech-dj
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hidp
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-primax
++hid-prodikeys
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-magn-3d
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-wacom
++hid-waltop
++hid-wiimote
++hid-zpff
++hid-zydacron
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hmc5843
++hmc6352
++hopper
++horizon
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hp100
++hp4x
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hp-wmi
++hsi
++hsi_char
++hso
++htc-pasic3
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-dev
++i2c-diolan-u2c
++i2c-eg20t
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i2o_block
++i2o_bus
++i2o_config
++i2o_core
++i2o_proc
++i2o_scsi
++i3000_edac
++i3200_edac
++i5000_edac
++i5100_edac
++i5400_edac
++i5k_amb
++i6300esb
++i7300_edac
++i7300_idle
++i740fb
++i7core_edac
++i810
++i82092
++i82975x_edac
++i8k
++i915
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipath
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ibm_rtl
++ib_mthca
++ib_qib
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ichxrom
++icp_multi
++ics932s401
++ideapad-laptop
++idmouse
++idt77252
++ie6xx_wdt
++ieee802154
++ifb
++iforce
++igb
++igbvf
++iguanair
++iio_dummy
++iio_hwmon
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++ii_pci20kc
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++ina209
++ina2xx
++industrialio
++industrialio-triggered-buffer
++inet_diag
++inexio
++inftl
++initio
++input-polldev
++int51x1
++intelfb
++intel_ips
++intel_menlow
++intel_mid_dma
++intel_oaktrail
++intel_powerclamp
++intel-rng
++intel-rst
++intel-smartconnect
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++ioatdma
++ioc4
++io_edgeport
++io_ti
++iowarrior
++ip6_gre
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6_tables
++ip6table_security
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_MASQUERADE
++ip6t_mh
++ip6t_NPT
++ip6t_REJECT
++ip6t_rpfilter
++ip6t_rt
++ip6_tunnel
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++ipg
++ip_gre
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netport
++ip_set_list_set
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++ip_tables
++iptable_security
++ipt_ah
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_rpfilter
++ipt_ULOG
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ircomm
++ircomm-tty
++irda
++irda-usb
++ir-jvc-decoder
++ir-kbd-i2c
++irlan
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++irnet
++ir-rc5-decoder
++ir-rc5-sz-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sony-decoder
++irtty-sir
++ir-usb
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x-fe
++iTCO_vendor_support
++iTCO_wdt
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++iw_nes
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keucr
++keyspan
++keyspan_pda
++keyspan_remote
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++leds-88pm860x
++leds-adp5520
++leds-atmel-pwm
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8788
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca9633
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg2160
++lgdt3305
++lgdt330x
++lgs8gxx
++lg-vl600
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++libsrp
++lightning
++line6usb
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_igorplugusb
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533_bl
++lm3533-core
++lm3533-ctrlbank
++lm3630_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbp21
++lnbp22
++lockd
++lp
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp8755
++lp8788_bl
++lp8788-charger
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2978
++ltc4151
++ltc4215
++ltc4245
++ltc4261
++lttng-ftrace
++lttng-kprobes
++lttng-kretprobes
++lttng-lib-ring-buffer
++lttng-probe-asoc
++lttng-probe-block
++lttng-probe-btrfs
++lttng-probe-compaction
++lttng-probe-ext3
++lttng-probe-ext4
++lttng-probe-gpio
++lttng-probe-irq
++lttng-probe-jbd
++lttng-probe-jbd2
++lttng-probe-kmem
++lttng-probe-kvm
++lttng-probe-kvm-x86
++lttng-probe-kvm-x86-mmu
++lttng-probe-module
++lttng-probe-napi
++lttng-probe-net
++lttng-probe-power
++lttng-probe-printk
++lttng-probe-random
++lttng-probe-rcu
++lttng-probe-regmap
++lttng-probe-regulator
++lttng-probe-rpm
++lttng-probe-sched
++lttng-probe-scsi
++lttng-probe-signal
++lttng-probe-skb
++lttng-probe-sock
++lttng-probe-statedump
++lttng-probe-sunrpc
++lttng-probe-timer
++lttng-probe-udp
++lttng-probe-vmscan
++lttng-probe-workqueue
++lttng-probe-writeback
++lttng-ring-buffer-client-discard
++lttng-ring-buffer-client-mmap-discard
++lttng-ring-buffer-client-mmap-overwrite
++lttng-ring-buffer-client-overwrite
++lttng-ring-buffer-metadata-client
++lttng-ring-buffer-metadata-mmap-client
++lttng-statedump
++lttng-tracer
++lttng-types
++ltv350qv
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m88rs2000
++ma600-sir
++mac80211
++mac80211_hwsim
++mac802154
++macb
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac_hid
++machzwd
++mac-iceland
++mac-inuit
++macmodes
++mac-roman
++mac-romanian
++mac-turkish
++macvlan
++macvtap
++magellan
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++matrix-keymap
++matrix_keypad
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_DAC1064
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++matroxfb_Ti3026
++matrox_w1
++max1111
++max11801_ts
++max1363
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max2165
++max3100
++max34440
++max517
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8925-regulator
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mce_amd_inj
++mce-inject
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp4725
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md4
++mdc800
++mdio
++me4000
++me_daq
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei_phy
++mem2mem_testdev
++memory-notifier-error-inject
++memstick
++mena21_wdt
++metronomefb
++metro-usb
++meye
++mfd
++mga
++michael_mic
++microcode
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mma8450
++mmc_block
++mmc_spi
++mms114
++mos7720
++mos7840
++moto_modem
++moxa
++mpoa
++mpr121_touchkey
++mpt2sas
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++mrst_max3110
++msdos
++msi-laptop
++msi-wmi
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt312
++mt352
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtdblock
++mtdblock_ro
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtouch
++multipath
++musb_hdrc
++mv88e6060
++mv88e6xxx_drv
++mvmdio
++mvsas
++mv_u3d_core
++mv_udc
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxl111sf-demod
++mxl111sf-tuner
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++myri10ge
++n411
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++natsemi
++navman
++nbd
++nci
++ncpfs
++nct6775
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netprio_cgroup
++netrom
++netsc520
++nettel
++netxen_nic
++newtonkbd
++nfc
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nfcsim
++nfcwilink
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfsd
++nfs_layout_nfsv41_files
++nfsv2
++nfsv3
++nfsv4
++nftl
++nf_tproxy_core
++ngene
++n_hdlc
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++nicstar
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_cs
++ni_labpc_pci
++nilfs2
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-1
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++n_r3964
++ns558
++ns83820
++nsc-ircc
++ntb
++ntb_netdev
++ntc_thermistor
++ntfs
++n_tracerouter
++n_tracesink
++nuvoton-cir
++nvidiafb
++nvme
++nvram
++nv_tco
++nxt200x
++nxt6000
++objlayoutdriver
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stackglue
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocrdma
++ohci-pci
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++output
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlayfs
++oxu210hp-hcd
++ozwpan
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++padlock-aes
++padlock-sha
++palmas-regulator
++panasonic-laptop
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pata_acpi
++pata_ali
++pata_amd
++pata_arasan_cf
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cs5520
++pata_cs5530
++pata_cs5536
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sc1200
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pc87360
++pc87413_wdt
++pc87427
++pcap_keys
++pcap-regulator
++pcap_ts
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_can
++pch_dma
++pch_gbe
++pch_phub
++pch_uart
++pch_udc
++pci
++pci200syn
++pcips2
++pci-stub
++pcmcia
++pcmcia_core
++pcmciamtd
++pcmcia_rsrc
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++pf
++pg
++phantom
++phison
++phonet
++phram
++phy-gpio-vbus-usb
++phy-isp1301
++phy-nop
++phy-omap-control
++phy-omap-usb3
++phy-rcar-usb
++phy-samsung-usb
++phy-samsung-usb2
++phy-samsung-usb3
++physmap
++pixcir_i2c_ts
++pktcdvd
++pktgen
++pl2303
++platform_lcd
++plat_nand
++plat-ram
++plip
++plusb
++pluto2
++plx_pci
++pm2fb
++pm3fb
++pm80xx
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pm-notifier-error-inject
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poseidon
++powermate
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++pppoatm
++pppoe
++pppox
++ppp_synctty
++pps_core
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++ptp
++ptp_pch
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm_bl
++pxa27x_udc
++qcaux
++qcserial
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas408
++qmi_wwan
++qnx4
++qnx6
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quickstart
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r815x
++r8169
++r8187se
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-shark
++radio-si4713
++radio-si476x
++radio-tea5764
++radio-timb
++radio-usb-si470x
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc5t583-regulator
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv2
++rc-encore-enltv-fm53
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-tbs-nec
++rc-technisat-usb2
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++redboot
++redrat3
++reed_solomon
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rionet
++rio-scan
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rndis_host
++rndis_wlan
++rocket
++romfs
++rose
++rotary_encoder
++rp2
++rpcsec_gss_krb5
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt61pci
++rt73usb
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab3100
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-msm6242
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rtl2830
++rtl2832
++rtl8150
++rtl8180
++rtl8187
++rtl8188ee
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192se
++rtl8723ae
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtl_pci
++rtl_usb
++rtlwifi
++rts5139
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mps11
++s3fb
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20_generic
++salsa20-x86_64
++samsung-keypad
++samsung-laptop
++samsung-q10
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_rcar
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sbc60xxwdt
++sbc8360
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbe-2t3e3
++sb_edac
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc1200wdt
++sc520cdp
++sc520_wdt
++sc92031
++sca3000
++scb2_flash
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_tgt
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdhci-pxav2
++sdhci-pxav3
++sdio_uart
++sdricoh_cs
++sedlbauer_cs
++seed
++sep_driver
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent-avx-x86_64
++serpent_generic
++serpent-sse2-x86_64
++serport
++serqt_usb2
++ses
++sfc
++sha1-ssse3
++sha256-ssse3
++sha512-ssse3
++shark2
++sh_eth
++sh_mobile_ceu_camera
++sh_mobile_csi2
++shpchp
++sht15
++sht21
++sh_veu
++si21xx
++si4713-i2c
++si476x-core
++sidewinder
++siemens_mpi
++sierra
++sierra_net
++sil164
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sis-agp
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skel
++skfp
++skge
++sky2
++sl811_cs
++sl811-hcd
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm7xxfb
++smb347-charger
++smc91c92_cs
++sm_common
++sm_ftl
++smm665
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smsc-ircc2
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-als4000
++snd-asihpi
++snd-at73c213
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-compress
++snd-cs4281
++snd-cs46xx
++snd-cs5530
++snd-cs5535audio
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-lib
++snd-firewire-speakers
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxygen
++snd-oxygen-lib
++snd-page-alloc
++snd-pcm
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb16-dsp
++snd-sb-common
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-88pm860x
++snd-soc-ab8500-codec
++snd-soc-ad1836
++snd-soc-ad193x
++snd-soc-ad73311
++snd-soc-adau1373
++snd-soc-adav80x
++snd-soc-ads117x
++snd-soc-ak4104
++snd-soc-ak4535
++snd-soc-ak4641
++snd-soc-ak4642
++snd-soc-ak4671
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-alc5632
++snd-soc-arizona
++snd-soc-atmel-pcm
++snd-soc-bt-sco
++snd-soc-core
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs42l51
++snd-soc-cs42l52
++snd-soc-cs42l73
++snd-soc-cx20442
++snd-soc-da7210
++snd-soc-da7213
++snd-soc-da732x
++snd-soc-da9055
++snd-soc-hdmi-codec
++snd-soc-isabelle
++snd-soc-jz4740-codec
++snd-soc-l3
++snd-soc-lm4857
++snd-soc-lm49453
++snd-soc-max9768
++snd-soc-max98088
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max9850
++snd-soc-max9877
++snd-soc-mc13783
++snd-soc-ml26124
++snd-soc-pcm3008
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2518
++snd-soc-ssm2602
++snd-soc-sta32x
++snd-soc-sta529
++snd-soc-tas5086
++snd-soc-tlv320aic23
++snd-soc-tlv320aic26
++snd-soc-tlv320aic32x4
++snd-soc-tlv320aic3x
++snd-soc-tlv320dac33
++snd-soc-tpa6130a2
++snd-soc-twl6040
++snd-soc-uda134x
++snd-soc-uda1380
++snd-soc-wl1273
++snd-soc-wm0010
++snd-soc-wm1250-ev1
++snd-soc-wm2000
++snd-soc-wm2200
++snd-soc-wm5100
++snd-soc-wm5102
++snd-soc-wm5110
++snd-soc-wm8350
++snd-soc-wm8400
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8727
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8782
++snd-soc-wm8804
++snd-soc-wm8900
++snd-soc-wm8903
++snd-soc-wm8904
++snd-soc-wm8940
++snd-soc-wm8955
++snd-soc-wm8960
++snd-soc-wm8961
++snd-soc-wm8962
++snd-soc-wm8971
++snd-soc-wm8974
++snd-soc-wm8978
++snd-soc-wm8983
++snd-soc-wm8985
++snd-soc-wm8988
++snd-soc-wm8990
++snd-soc-wm8991
++snd-soc-wm8993
++snd-soc-wm8994
++snd-soc-wm8995
++snd-soc-wm8996
++snd-soc-wm9081
++snd-soc-wm9090
++snd-soc-wm-adsp
++snd-soc-wm-hubs
++snd-sonicvibes
++snd-tea575x-tuner
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usbmidi-lib
++snd-usb-us122l
++snd-usb-usx2y
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx222
++snd-vx-lib
++snd-vxpocket
++snd-ymfpci
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++soundcore
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedstep-lib
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spidev
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi_ks8995
++spi-lm70llp
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-topcliff-pch
++spi-xcomm
++squashfs
++ssb
++ssb-hcd
++ssfdc
++sst25l
++sstfb
++ssu100
++ssv_dnp
++st
++st1232
++st_accel
++st_accel_i2c
++st_accel_spi
++starfire
++stb0899
++stb6000
++stb6100
++st_drv
++ste_modem_rproc
++stex
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++stinger
++stir4200
++stk1160
++stkwebcam
++st_magn
++st_magn_i2c
++st_magn_spi
++stmmac
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++streamzap
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++suunto
++svcrdma
++svgalib
++sx8
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t1pci
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++tc3589x-keypad
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea5761
++tea5767
++tea6415c
++tea6420
++tef6862
++tehuti
++tekram-sir
++teles_cs
++test-kstrtox
++test_power
++test-string_helpers
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++ti-adc081c
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timb_dma
++timberdale
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++ti_usb_3410_5052
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmiofb
++tmp102
++tmp401
++tmp421
++tmscsim
++toim3232-sir
++topstar-laptop
++toshiba_acpi
++toshiba_bluetooth
++touchit213
++touchright
++touchwin
++tpci200
++tpm_atmel
++tpm_i2c_infineon
++tpm_i2c_stm_st33
++tpm_infineon
++tpm_nsc
++tpm-rng
++tpm_tis
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217
++tps65217_bl
++tps65217-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++tranzport
++tridentfb
++ts2020
++ts5500_flash
++ts_bm
++tsc2005
++tsc2007
++tsc40
++ts_fsm
++ts_kmp
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner_it913x
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tusb6010
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw9903
++tw9906
++tw9910
++twidjoy
++twl6040-vibra
++twofish-avx-x86_64
++twofish_common
++twofish_generic
++twofish-x86_64
++twofish-x86_64-3way
++typhoon
++u132-hcd
++uartlite
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++ueagle-atm
++u_ether
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_netx
++uio_pci_generic
++uio_pdrv
++uio_pdrv_genirq
++uio_sercos3
++uli526x
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unioxx5
++unix_diag
++upd64031a
++upd64083
++uPD98402
++u_rndis
++usb3503
++usb_8dev
++usb8xxx
++usbatm
++usb_debug
++usbdux
++usbduxfast
++usbduxsigma
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_gigaset
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usb-storage
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usb_wwan
++u_serial
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++ux500
++v4l2-common
++v4l2-int-device
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++vesafb
++veth
++vfio
++vfio_iommu_type1
++vfio-pci
++vga16fb
++vgastate
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via686a
++via-camera
++via-cputemp
++viafb
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via_wdt
++video
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-memops
++videobuf2-vmalloc
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videocodec
++videodev
++viperboard
++viperboard_adc
++virtio_balloon
++virtio_console
++virtio_mmio
++virtio-rng
++virtio_scsi
++virtual
++visor
++vivi
++vivopay-serial
++vlsi_ir
++vmac
++vme
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmwgfx
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmxnet3
++vp27smpx
++vpx3220
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++w1_bq27000
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1-gpio
++w1_smem
++w1_therm
++w35und
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83697hf_wdt
++w83697ug_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++w90p910_ts
++w9966
++wacom
++wacom_i2c
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wdt_pci
++whci
++whci-hcd
++whc-rc
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlags49_h25_cs
++wlags49_h2_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x_backup
++wm831x_bl
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x_power
++wm831x-ts
++wm831x_wdt
++wm8350-hwmon
++wm8350_power
++wm8350-regulator
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusbcore
++wusb-wa
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xenfs
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen_wdt
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xgmac
++xirc2ps_cs
++xircom_cb
++xo15-ebook
++xor
++xpad
++xprtrdma
++xsens_mt
++x_tables
++xt_addrtype
++xt_AUDIT
++xt_bpf
++xt_CHECKSUM
++xt_CLASSIFY
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_CONNSECMARK
++xt_conntrack
++xt_cpu
++xt_CT
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_DSCP
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_iprange
++xt_ipvs
++xtkbd
++xt_LED
++xt_length
++xt_limit
++xt_LOG
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_NETMAP
++xt_nfacct
++xt_NFLOG
++xt_NFQUEUE
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_RATEEST
++xt_realm
++xt_recent
++xt_REDIRECT
++xts
++xt_sctp
++xt_SECMARK
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_tcpudp
++xt_TEE
++xt_time
++xt_TPROXY
++xt_TRACE
++xt_u32
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++zatm
++zaurus
++zd1201
++zd1211rw
++zhenhua
++zio
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zlib_deflate
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zte_ev
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic b/debian.master/abi/3.11.0-13.20/armhf/generic
+new file mode 100644
+index 0000000..dc4a536
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic
+@@ -0,0 +1,14794 @@
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/atm/suni 0xbf7410c1	suni_init
++EXPORT_SYMBOL drivers/bcma/bcma 0xda5eb6ec	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x224540d0	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0x4b18cae3	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x5037ca40	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0x63b67546	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x81f38190	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0xa21b496f	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xb1fb8642	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xb6965dbe	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xd38e83f2	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xd53bc05a	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xdf2b54f7	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0xf142824e	paride_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1ae6dc6e	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x200b7561	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x3101615c	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x752447fd	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa28a2ace	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa4c508a8	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x04a9b8ac	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x199853f5	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x2eef58c3	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x51639f11	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x728b6012	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xf1fff0d4	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/pl330 0x74769be5	pl330_filter
++EXPORT_SYMBOL drivers/edac/edac_core 0xfb57f258	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x22b4601c	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x27219f3a	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x27c4aceb	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2a0166be	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2ab02f84	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3a3cb673	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x47e443cb	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4f7fa11b	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4fa3ab3d	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6aa70b9b	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x70fe98da	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7b18610a	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8261626a	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8aca5b94	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9eaa720d	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb38c5334	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb455cb35	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbb323103	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc4852480	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xce3232b6	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xdb372de4	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xe5228a2c	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf03e1338	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf389ed79	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xf4c4a2a1	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xfb215b81	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/fmc/fmc 0x0dbcb6b3	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x21853346	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x5c2334f0	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x61f863b9	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0x65bc6012	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x69cd3cdc	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x82f0bb47	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x9fac4212	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xab14e08a	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xbace4132	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xea560f4d	fmc_driver_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02e6e099	drm_mode_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x098d239a	drm_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a34d1d7	drm_get_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e35085d	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e85fdc0	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f2a963e	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f78aa16	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fe6c41b	drm_get_platform_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1076dd82	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11065515	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12b75085	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12c6276a	drm_buffer_read_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x133c4405	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13be2da4	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x142b8b35	drm_buffer_copy_from_user
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x15e6790a	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x163f8ab3	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x167fd723	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x16f05185	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x186ee913	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a19bd44	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c0ae7d7	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1ca51858	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d273b54	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e837252	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1f7530a1	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20320ab5	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x207811fa	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2460455f	drm_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26256356	drm_mode_equal_no_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x266b2414	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27763f17	drm_sysfs_connector_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x29be4cd2	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c1fbdf8	drm_mode_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2c7050d6	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d271c63	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d91011f	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2db7a412	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2dec35ce	drm_mode_connector_detach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e0444a7	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e429927	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ebb49da	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f010783	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2fe66f91	drm_prime_destroy_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x306b23a8	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3074f033	drm_order
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x30e5bf0e	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3119dc7e	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x31d030df	drm_core_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x32070b45	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x332a4ab4	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x34074b7f	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x364a9e78	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b877c11	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d8b5951	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3dc565d9	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x421008ac	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4318d251	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43384bd9	drm_buffer_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44760534	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44a0c113	drm_mode_height
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44b481de	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x483e738e	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48879636	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4986afcf	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x498dcb5e	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x499117b2	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49bb6ee0	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49c49ea8	drm_prime_init_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4b385b69	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bde7dbb	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d088d1f	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4fab7d55	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x519e335c	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526bece1	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x52db3f4c	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x537f0d95	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x55447a29	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5587ea04	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x560a2c0f	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57825d2f	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x580eee7e	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x581ed292	drm_mm_get_block_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5965a791	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5d5f821e	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5dbd3aaa	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e57f348	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e6f7195	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eafb8e9	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ebb2ac0	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x606ae2bc	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60a8961f	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60fa9682	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6112e563	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x622d126c	drm_fasync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x637b464e	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x63d6e6bd	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x660312ba	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6649dc13	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x66ddea01	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x67cef369	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b6d7375	drm_timestamp_precision
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cee2e42	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ddb8984	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x72b6c631	drm_sysfs_connector_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74783268	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74813d3d	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74fbf451	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x753c7b99	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x780b3052	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a042080	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a4e7297	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7aa23075	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b17923a	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b42b5d4	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b85f6f8	drm_mm_insert_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c0f2bb5	drm_mm_create_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d3c9dc0	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d5c2435	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x803a750b	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80924a9d	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82190bf9	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x837b1952	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85514efe	drm_core_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x86379de3	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x865eac64	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a2bcf26	drm_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c167bbd	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c510862	drm_find_cea_extension
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c88b4bd	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8dfb019d	drm_buffer_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8efe811b	drm_core_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f7df3a7	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f88be6a	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91236192	drm_gem_object_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x918ed706	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x923416a8	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x94407aed	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x955d725c	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9745d638	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x99337096	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9996deca	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a43ec1c	drm_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9b07466f	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9daa7bae	drm_gem_object_handle_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9db111fa	drm_put_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dd34b62	drm_mm_insert_node_in_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0f82f7d	drm_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1d93717	drm_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1eabd87	drm_mode_list_concat
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1fb703c	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa27f9220	drm_get_last_vbltimestamp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa3756a4f	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa82db9e4	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa96acfcb	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa9fb1745	drm_global_mutex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb499b71c	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8b1931f	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb95beb55	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba2d0719	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbcc7d58f	drm_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe001c53	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbec4086a	drm_mode_create_dithering_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbed92de4	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbf3b1a8f	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc25a61ec	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc414c422	drm_vblank_offdelay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc8a93d56	drm_platform_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb1beab5	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb7fb2d2	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd2b069c	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcda91c46	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcddfa8c9	drm_core_reclaim_buffers
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce30f21a	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf291902	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcf6a93a8	drm_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd004a426	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0dcdd90	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd125790d	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd16e350d	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1a02c9c	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd1d2a4d7	drm_get_connector_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd24da99b	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd675f055	drm_prime_remove_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd69acadd	drm_get_encoder_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6ceb1f9	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd735646b	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd90bc8f8	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdacddd4a	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd4200b5	drm_prime_lookup_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe10a472d	drm_mm_pre_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe16838c2	drm_mm_search_free_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe3dd4ebe	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6f46e6e	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe77924e8	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe83eba05	drm_mode_group_init_legacy_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeab6de3e	drm_fill_in_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xee2028b5	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf26ad773	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf49ec1f8	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4b2e991	drm_mm_put_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf519d64e	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf612f5e3	drm_mode_validate_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6d22890	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf92c66be	drm_mm_search_free_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa074e8e	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb8a84a4	drm_mm_get_block_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb9c228f	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc3cc5e1	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfe9c5746	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff6de437	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffb34fbc	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x00e938c3	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0e2818da	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1a241b5f	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x28b49032	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x291b40bd	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d7a787f	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3049cd2f	i2c_dp_aux_add_bus
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x38e18330	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x39aecd18	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4fc7ade4	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51557be4	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5ef4e89d	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7c4e135a	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e665768	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81003e82	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x84a16648	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8d3c9238	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9f29f290	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa0f7aa75	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa23292a9	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa2770805	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xae8b2bab	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb37a0603	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb71ed6de	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7082df8	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7fd39bb	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcc070908	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xcda554d8	drm_fb_helper_restore_fbdev_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd02c73c7	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5d8b6b8	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xdc89c970	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe3d572e2	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe6f0297c	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf55b6382	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf7699b7b	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf9789c70	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfbcb7ab7	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfee43a69	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x249c47b9	drm_get_usb_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x365bc516	drm_usb_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0xbaaa5141	drm_usb_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0083d2b4	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0b0c98d7	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d1180f3	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d63c79b	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x12ee6629	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132d9f58	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x134df76a	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x15d7b5e1	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17e48a1d	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1843400d	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x191bcb6b	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1cb0d78b	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1d378d2a	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x1ea5f9b4	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2241920b	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x28b8657e	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2c7fac9b	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2e138fe4	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x38a14830	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x46053206	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4850b69c	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4a27b07d	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d1eea63	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x52f73b19	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5559e153	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5a1fcb20	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5b5df166	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6ab6d4f0	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6ec8881b	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7c8d2926	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x806471a2	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80782255	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x865f7d73	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x86996bc9	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x954289ab	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x96c66ec9	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9914d028	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x99f3b15e	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9ebb46c2	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa095530a	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa66bfd48	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa7346593	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xae178c00	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xae8b70c2	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb3b823ea	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb72263c9	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb7902d7f	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb9dbdc30	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbc06e10e	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbd1a35b0	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc0f3b21c	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc1964459	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc42bdc8a	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc45e5355	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5973608	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc59b765c	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd2ab06fb	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd3ed041c	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xda7151f3	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xe6359cf2	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xedce7732	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf65fb491	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfa842d22	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfc4f6a1f	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfe4b950b	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/host1x/host1x 0x45da6a6c	host1x_syncpt_wait
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x53c0fe36	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x0eb33067	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x5461d90f	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x8237896b	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x0cc4de0d	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x79c2ea94	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0xf4b5da35	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x367ea9f3	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x63bf0c8d	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x13745c0b	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xbe1df4aa	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc0a5903b	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xfe4e9059	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xfeb5cd01	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x85d91d2b	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xc5ccaccf	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x0bddd70a	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x15c4dac1	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x1987679e	st_sensors_sysfs_set_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x26b9b2cb	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x26ce3ae0	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x38eab39d	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x484133a7	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x5c7083cc	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x667ac433	st_sensors_sysfs_get_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x792c0a7e	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xaa0aa243	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xaf552b30	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb9b7bbe6	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xccc4a3cf	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd75e2ee1	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0x5f3348be	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x74f7ebc1	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x161f5997	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x74ae646b	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x37ed0309	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xc4082acb	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x002708f2	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x1c072399	iio_buffer_read_length
++EXPORT_SYMBOL drivers/iio/industrialio 0x1e36ca35	iio_buffer_write_length
++EXPORT_SYMBOL drivers/iio/industrialio 0x27d4d533	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x32a2e8aa	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x59817782	iio_buffer_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x5beca1a3	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x617234c2	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x79ac649b	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x7c5ae376	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x7dc83aad	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x7e5ebd94	iio_buffer_store_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0x821242dc	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x898ed77d	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x9637d42b	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x99761b13	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x9cd3ea0a	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xb63b5418	iio_buffer_show_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0xb66f63b9	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xcb945f77	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe5b120ce	iio_buffer_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xe927ca67	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0xf5dd27ff	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xfea7feba	iio_sw_buffer_preenable
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xaf770414	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xf9ffbc1d	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0x94c4a5e8	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0xf0c35fe3	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x5d0a4a4b	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x6bf8e1ee	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x885292b1	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xfbd3000a	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x212c3664	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x37838b44	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x5347cc38	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x7df81f32	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d1f522d	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xe802975d	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x0a7a0288	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x17fabae8	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x25b7923a	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x4acbb5fb	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x52b8f52a	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x53d48d73	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x731c2c19	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x87260972	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8ad3250c	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x8d61427c	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x9b21c5b8	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa8644005	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xac808bbc	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xb7658ab5	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd3d3cb6d	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd97f86b9	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xe0e31e02	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x01ea87c3	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06c82fcf	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x075d0f5f	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c6bf6f5	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0d87c2ad	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x10aefbc1	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14f84918	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x171f99f1	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1fe23f81	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x24faa333	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x27574525	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x29d3f564	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ac8a0ce	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ba69a61	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2c49c182	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3201fb49	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x37b574d0	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x38b7aad9	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3b3033e8	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3c5cd9b0	ib_alloc_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44aec20c	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44dcfca9	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x44e16860	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x48af6d9a	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x49e89f4e	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4a31d944	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4be87559	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4c915b14	ib_reg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4cb912ca	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5e894eab	ib_alloc_fast_reg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5ecf82e7	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x609a6206	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x61b444d2	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x62aebc17	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6365b49a	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x649b6915	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x64d395f2	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x677a3a80	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x699b622c	ib_rereg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6a41c250	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6b42dce1	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7163d89d	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7385aa03	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x76a625c4	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7775f9c5	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x79ff45ad	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x813a7653	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x818a26ff	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x88000038	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x891d2222	ib_free_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8a9a6713	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8aa939d0	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8c48d8f5	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x967fa07d	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x96ce6c46	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9e2b1a63	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa1016099	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa284c924	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa61e2a9d	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaca65605	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xad8a44d6	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaf3ac393	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc19aab93	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc3b5942a	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcbcf1a4a	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcef30d8b	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcf5dfdac	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd183c359	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd1d0d4b7	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd1ec6d43	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdbf4eb6d	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc5f9a24	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdc96081a	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdf49c3f4	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xdf8289e0	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe279104e	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf16ca5d3	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf57962ad	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x05323148	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1c9638f8	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1d5eaaad	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x229aa797	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x305a13d0	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x417f50b4	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5e559127	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x66f79e39	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x68b84d9c	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x93500dfc	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x946d5d27	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xc6a42b6f	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xf18698d1	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x2f91699b	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5663c316	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x576fdbac	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x642d3d29	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x772fa465	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x7fe99b3f	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x9e7aad54	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xde9e1b2c	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe6b65f5a	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe9efd86f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf6b6444b	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xfbe97262	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x02f847bc	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x07cf5a51	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x18382f6a	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x184f3575	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x708e9e98	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x72174934	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x7955a8bc	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9d2d7685	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xa0f60bb3	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe18eedfd	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xe326dac4	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xf36fefaa	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x0f8c5293	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x125978b5	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x1322b4ee	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x318b233c	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x42ff58b2	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x452ec37f	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x47b9aadd	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5c20dc18	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5c74842f	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x61db7919	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7acccd8e	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x830b71dc	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x8cc99ad8	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa499a8b0	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xcc70df2f	rdma_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd3c52f1d	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xde2265b9	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe85e7e48	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xe8e97798	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xec108375	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xefb020ee	rdma_disconnect
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x1f9cfe30	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x207664b5	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x20a7141b	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x587d5124	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x6329a2e9	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x76060ba7	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xeb1c56b7	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xee5cf132	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xff43846f	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/input-polldev 0x56f0ffbc	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xa148f016	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xd5a8bc45	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xf8e29c4f	input_free_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x4ac696e2	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x2110f20b	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x30962158	ad714x_remove
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x42f7fbad	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x7015d972	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x286e5ce8	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x4aad138c	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x5a162b06	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x632948b6	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x994a4de9	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xd4d1216e	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xf3c2a125	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x9a9bacdf	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xb1f75e5b	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x0b9b8327	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x255b473e	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x264b7bba	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2657267a	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x42361999	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x47d3fc51	capi_info2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6f72c61a	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e3ab2a8	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc25aff88	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd593cb29	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xdbfeebb9	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed061606	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x2024a155	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x3d36c2e6	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x51617852	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x5357ad32	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x6fae8b86	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9b51e5e3	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc0874a0f	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc946bbbb	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd2b34cb4	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd3a98488	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd4494c46	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xd454c7fd	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xe9baffd6	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf9208d1d	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfe0f226f	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x06a319ef	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x3626d3a2	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x537601c1	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x74fa9000	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x866814f8	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x9b181bfb	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xbce0a1c4	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xce91471d	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xce96ff5e	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x9a3855ce	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xa3a717ac	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xb4fcce22	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xccba6cf5	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x77d2bcd1	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x7937a68e	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x7f29ce36	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xbe636768	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xe227344e	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xff2db2cf	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x343f74a8	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x37976baa	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x7643c606	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x8abf2c94	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xc425c210	isac_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x13ddcc8a	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x60531869	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xbf6741ec	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x107b1291	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x168792f1	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x26150a8c	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2a2d807e	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2ad9a902	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3b2364f2	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4151d560	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x48d31913	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4e5d1ec4	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4e6af067	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x54451388	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x614ede30	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x62951412	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x72367b7d	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x89b1f327	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8d7e5844	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8f179314	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9558ffee	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x96309324	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x9757af4c	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc43adb4d	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc7a9c30e	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd2df734f	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xdc85cc53	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe232c1f5	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe87943cf	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe9bf3cbe	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x2120c4f4	omap_mbox_enable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x223d88f5	omap_mbox_put
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x649d7ebc	omap_mbox_get
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x66726cac	omap_mbox_register
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0x8d493466	omap_mbox_restore_ctx
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xcd54f3fc	omap_mbox_msg_send
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xdbc75fe3	omap_mbox_unregister
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xea5d7248	omap_mbox_disable_irq
++EXPORT_SYMBOL drivers/mailbox/omap-mailbox 0xf64ab88c	omap_mbox_save_ctx
++EXPORT_SYMBOL drivers/md/dm-log 0x2539ac96	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0x6edbed48	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xde3cafca	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xed0ada7e	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x151d6e20	dm_snap_origin
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xae8a42a3	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbeddb554	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xd07f3b8b	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xdfeda60c	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xe5e7de9b	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/raid456 0xb8a4fe44	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x02751232	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x2c4bfe33	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x33b0aa27	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x340e37bc	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x45866e09	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x49f18e78	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4db45374	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x5bbb38d9	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8712b375	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x88cdeaea	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9d490ea4	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb3ca5265	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc9b912b6	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0x495e4b0c	btcx_calc_skips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xa06d6893	btcx_riscmem_alloc
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xad2fe38b	btcx_sort_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xc368f8e6	btcx_align
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xcda0ded2	btcx_screen_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xf0c6ffcd	btcx_riscmem_free
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5b88faf6	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x71d3999e	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x7b406db1	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xaf30cc21	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xd349fff4	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xf99cfe84	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xc6eab53a	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xf941d600	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x0a0d2079	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1196922d	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17523ce7	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x19d02ac2	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1a153af3	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x225a43fd	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x344908d4	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3656cb10	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3c6c72f9	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x414355af	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x43109573	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x44991ac3	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x49d683d8	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x51727cb9	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5b36e921	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x629f9d31	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6c06ed33	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x72180695	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x78c7a6e0	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x7f965cad	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x81490876	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x85de98aa	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8631998b	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8633f37b	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c19040b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c7d4d6c	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa8c80b71	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xae32ad58	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xaec38be8	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xafae3e14	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb8f0fefc	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd68a099e	timeval_usec_diff
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb1a8bd4	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdbd4d549	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdc094c39	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe54c23dd	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xef648737	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf48116c6	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfc09c687	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/a8293 0xc0f20411	a8293_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x7c8f4993	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9033 0x63b56a88	af9033_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xd2c6f80e	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x1c2cb2e7	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x1cd38eb9	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2dbac221	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd0a89a57	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd33c06b7	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe3866d4a	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe7d63bf3	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xfa0022bc	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xfd27fa3d	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x524ff6b2	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0x429e9140	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0x6c69c378	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xf452e31e	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0x28117e96	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xa0a4004f	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0xab3113a3	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0xe32d7b0e	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x19804071	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x44150f63	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x0af7f024	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x12d1a0a3	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x70454971	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xa6c9b734	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xde1ecb47	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xf3dd80d0	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0b6c35e1	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x12d0f837	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x13c0d824	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x2097f2a7	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x51ba3d42	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x560ffcc3	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x566e4703	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5a779f2b	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6332398d	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x649905a2	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x78530553	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x7efe362c	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xbefa1da4	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd8ad812a	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf16158eb	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0xa7ac2d1d	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x2dccc00c	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x303fd69c	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x57e46d7c	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x9c462058	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xda98f6c3	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xe98e074d	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x6b235389	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xb6dcf597	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xf1cc5669	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xfd105ee9	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x21392efb	dib7000p_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x38690d97	dib7000p_get_agc_values
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x77b783e5	dib7000p_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x7d85b7e8	dib7000p_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x85d5ce55	dib7000p_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x9b16e180	dib7090_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x9be200f4	dib7000p_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x9d205b9c	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xaf87cede	dib7090_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xb69ffcf0	dib7090_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xd8a78080	dib7000pc_detection
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xde347e55	dib7090_slave_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xeab83680	dib7000p_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xef0925bf	dib7000p_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xf9d7b5a4	dib7000p_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xfa7d1dc5	dib7000p_set_agc1_min
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x0d56cb3e	dib8090p_get_dc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x1b13ba02	dib8000_get_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x3081cf94	dib8000_remove_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x31095c0e	dib8000_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x3e37bdde	dib8000_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x4b33a077	dib8000_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x6be7d71e	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x769f9b21	dib8096p_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x76fb57dd	dib8000_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x7cbfcb29	dib8000_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x8c6a055f	dib8000_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xa8bab353	dib8000_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xb56a2d89	dib8000_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xbe63f292	dib8000_pwm_agc_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd4b4595e	dib8000_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xdf1fcdd2	dib8000_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xe2dfbfc5	dib8000_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xf2467f48	dib8000_set_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xf684ba24	dib8096p_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x4de0dea5	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x83f5b0a1	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x89ab4e29	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x9d2f0f0d	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xfee0515c	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x3eade6c9	drxd_config_i2c
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xc8216a07	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0x831a2a25	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xa85f82a3	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x83dabb65	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x86e6aa08	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0xe706c858	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0xca9fa45d	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x1f03b580	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/it913x-fe 0x6538e3f0	it913x_fe_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x4ad96e8b	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x862a3bac	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x3b98b7b2	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xe35fc9b7	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x1dce028a	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x0f544b03	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x17d74329	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x3ae3fd82	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xce6ccfd7	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0xe42204c8	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x548a274e	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x85e34744	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x1c324c91	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x24c760e8	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x2a04a363	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x21cac9c8	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x1fb26d4f	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xa0b0252f	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x42bdc1bc	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xa89c25ee	rtl2830_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xc867680c	rtl2830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2832 0x4551c5f0	rtl2832_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x7e1289e3	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x451c9855	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x77a25d00	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x8a3649f3	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x8789a62b	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x913871f0	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0x7091c591	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0xe80d3c4a	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0x53672787	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x7f0b06dc	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xf79979c3	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x6ca434eb	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0xb2072243	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x6f74bbf1	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x4d4caa38	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x958f8a05	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xa46f288f	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x3ea84649	stv090x_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x6a779f45	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0xc3dec3dd	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xaba7aa2d	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0x93f8101a	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xf5950039	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xa614a915	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x6ffee030	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xbf927324	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10071 0x28730613	tda10071_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x9e1ba9cc	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x4c400157	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0x6d73f445	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x900428f6	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0xe1891c99	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xd699285b	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0xe51a8d91	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0xcb4ad006	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x36d528d6	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0xf47be496	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x301e0b5e	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xe63a832d	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x38039e80	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x65f02493	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6efe3b10	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x7966e6aa	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xb7f3ceea	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xc11c8349	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xeb316a9e	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x363e176d	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x52060c5a	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xab3daa39	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xf07ddd28	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x7bb662b1	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf0db78ee	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xf2951ed7	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x157b0202	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x3a297fa7	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x466a07f8	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x5aa2d700	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x65a803b4	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x7a2f5667	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xdc5435aa	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xef7c019c	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xf187e9de	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0xb0183778	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x7fb090f0	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x83626d40	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xb91c278a	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xc5c693c7	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0xffcba5bd	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x0351a7f8	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x4657be0c	altera_hw_filt_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x9247b72f	altera_hw_filt_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xb9ec0f19	altera_pid_feed_control
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6883b490	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x78e0234f	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x7c69d2e2	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x9a2d5995	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xaa49b7fa	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xad176ec1	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x006e5bbc	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0xe65feb26	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x184c83aa	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x4e24a4ba	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x7778570e	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x89a8c886	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x1e022bb1	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x2dbd3966	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x566bed2f	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x5dda831d	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xabf88341	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xbe0d6473	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x11fbd905	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x14a4613b	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2abf15ff	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x2fc6152f	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x37ceca52	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x46d174aa	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5a164ab2	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x5b234872	cx88_risc_stopper
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x68d5f36a	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6a14bb84	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x71bf9bc5	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7246b184	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x74b95eda	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x91944081	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x9c29f0c7	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaf3867b3	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xba62a3f6	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xcb0a4c54	cx88_free_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xd5f27c84	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xdd2a4659	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf32b94ec	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf6a1342f	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x162d1085	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1a903495	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1bb75843	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x330b1783	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x3f10f9a2	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x49d4ca5d	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x73121ccd	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8004a482	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x844ecd25	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x8fc8541c	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xa7d604d5	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xab70505b	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xca687345	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xce0690b7	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xd4bc155e	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xdbfe5a95	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xe2cf4740	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x28e5de36	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x33c0a4be	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x41e1b5a5	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x46f9561e	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x576f6eb5	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x6216d8a0	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x73039031	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x8577b03c	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa36af344	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xa8e98e75	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xc632c3a0	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xd22021ea	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xe2f4ba95	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0x7e5ebe9d	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/platform/davinci/vpfe_capture 0xbf924a58	vpfe_register_ccdc_device
++EXPORT_SYMBOL drivers/media/platform/davinci/vpfe_capture 0xc173013f	vpfe_unregister_ccdc_device
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x088ccec9	vpss_select_ccdc_source
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x319709a6	vpss_clear_wbl_overflow
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x54146824	dm365_vpss_set_sync_pol
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x6e5b5413	vpss_enable_clock
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x72f7c8bb	vpss_set_pg_frame_size
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x749bf2c9	dm365_vpss_set_pg_frame_size
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x7517e8d7	vpss_dma_complete_interrupt
++EXPORT_SYMBOL drivers/media/platform/davinci/vpss 0x95f8c400	vpss_set_sync_pol
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x054c5a55	soc_camera_unlock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x06e351ff	soc_camera_lock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x17be543b	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x2a79cc0c	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x60078d1d	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x7ce51d87	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xa6600435	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xc088eaf1	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xce183553	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x46b1be73	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xd4d5a2f0	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x13e1d4cc	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x4b8f9642	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x7ed9b722	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x9514a8b9	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x24a58c05	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x266f0114	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x46ca5097	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x47b87c56	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4b5c137d	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x4be3df2f	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x5a35c38a	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xded76345	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x8b6d14db	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xc7746a6f	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/e4000 0x876f4b8c	e4000_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0x15d7216c	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x35a51e35	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x6bf99502	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x92d3a23b	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0xfb4f4a2e	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc2580 0xda6410f1	fc2580_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x61b8ab94	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0xcbcdd3ee	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0xe5c40b0b	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0xce87634f	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xebc1faf7	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xbdd237c8	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x062ed961	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18212 0x42ddc7cf	tda18212_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x65c0e2c1	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tua9001 0x2037cb14	tua9001_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x744bcdf7	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner_it913x 0xb4c86568	it913x_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xbf1bdfcb	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x39452d27	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x9841911c	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xff7b5ea2	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x39c10195	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x53967729	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x6cf2c7ec	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8e4f4cc9	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa35aa6cb	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xac865681	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xc82caea8	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xdd72aabc	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xf3632052	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0c5e8127	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x10fa43c8	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x3c7af29e	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x6ea66c9e	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x9e6e85e7	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xce56c34b	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xd15d5ac7	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x9d577689	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x08691f01	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x1b52d823	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x2b6c0bac	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x6939d39b	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x954bf7e4	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x971da3c8	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa4441d12	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb5d4f108	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xcb74ced0	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xeac0cfb4	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xf53ce33e	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x3a9fd7bf	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xd8195a8a	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x13a4fec9	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x208a9d7d	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x7c9fd80c	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb54b90cc	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb90d1aca	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xbc79c705	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xe321fcdb	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xf237b6fe	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x21a3b022	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x5dc87509	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xb4589b83	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x8ca2c6a0	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xa765c76a	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x42c8e001	v4l2_ctrl_next
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x4adaf0f3	v4l2_ctrl_query_menu_valid_items
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x53c9394f	v4l2_ctrl_query_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x5f96a661	v4l2_ctrl_check
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x93bd6c8c	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xeb56b127	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xf891dac4	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x0372b543	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x29e65f61	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6483e55b	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x7ed200e3	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x9546f14f	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xdf6ee78b	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xceb960b6	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x06f044d3	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x095ac640	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x097c9442	v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0cb2f623	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0d07fdac	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0e6da5f9	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x106edf65	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x140e371b	v4l2_of_get_remote_port_parent
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x18485466	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x18f8752a	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1de31607	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x21d8da23	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x233dca04	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x31970a46	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x33a003c5	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x350aa4da	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3db7f213	v4l2_of_get_remote_port
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45293fd2	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4624fd10	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x470e3053	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x484baf01	v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x49eb1a9f	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x55962555	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x560a8cb9	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5712e41e	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5acb3ef9	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5ae1135c	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5d21975e	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5d43db6b	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x667faafa	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d16d320	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x72677d58	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x73bd13d0	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7d0a6e9e	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7dc2d657	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7dd398ee	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f923f2a	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x86dd0251	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8bd8c519	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8ce55e5a	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8d815bea	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x95313c1f	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x96f8f0fa	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa0c948a5	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa5451456	v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb0529d5c	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb4aa80e2	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb90cbedf	v4l2_of_get_next_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbac4a225	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbfaf0eca	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc12cf8f8	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc9fa8a66	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcd7e5d6d	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcdf37f81	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcea3b494	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd0411535	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd0497160	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd6148a91	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd71bf125	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdfaf6c22	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xdfdd8967	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe6fce6f2	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe8842873	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf4544975	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf879dbcd	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf8b3b007	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf9e7b76c	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfafa621e	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfd100192	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfecf96fe	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xffec2951	video_device_release_empty
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x065256b7	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x1b7c50bd	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x2a191663	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4b64cdc7	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x661d6265	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6bad9301	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7d9b6538	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x8e389857	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb5e34a08	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xb6352e45	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xcc2d90d3	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf0801cef	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf4240c12	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf6d90d06	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1bce1bf5	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1c7373cb	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x21172e3c	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x25ac4c80	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x28f9cf70	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3907f7f4	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3cd053e1	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x5300ab1e	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x594bd8b6	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x647912b6	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x665bd6f7	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x6fe468dd	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8195fbc9	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8752a6a1	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8a7f6ff0	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x95658922	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xa892d7cd	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xafb77b82	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb2872382	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xba128b54	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xbe452a86	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0ecfd7c	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc33d535a	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc6be5d09	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcd744bc5	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcffa01cb	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xea05c0d3	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf687072c	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xfd9be024	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x07e8e926	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x08d6d2c1	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x09724ef6	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1c8766fc	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x2bb94475	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x37a72c76	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3a08abef	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3f6ffce3	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x3ff3dcb4	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x611dfaed	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x67f6209f	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x72085fb4	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x746ccf58	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7b498c1e	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x83a5a89b	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x85637ed6	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x88ba5a5d	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9e6470f1	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa115d414	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xa1b385e3	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb61664a0	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xc0738c60	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd383dbfe	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd667177a	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe4a399ba	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf1272552	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xfbdecc8d	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x12f95519	i2o_driver_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x144259fd	i2o_parm_field_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x1f79f741	i2o_driver_notify_device_remove_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x23e8939a	i2o_driver_unregister
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2a843bef	i2o_dump_message
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x344ecf42	i2o_msg_post_wait_mem
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x3895e5e9	i2o_msg_get_wait
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x56b7fea5	i2o_driver_notify_controller_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x673eb1a6	i2o_driver_notify_device_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x7d5471a1	i2o_device_claim
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x817a2dd2	i2o_find_iop
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xa38a25b9	i2o_iop_find_device
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xa4d72e28	i2o_event_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xa8eb3780	i2o_exec_lct_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb4c00dcf	i2o_controllers
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb8ecdb8c	i2o_parm_issue
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xc15eeb15	i2o_device_claim_release
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xcd7ec197	i2o_driver_notify_controller_remove_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xeb271e29	i2o_status_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xfae5f45e	i2o_parm_table_get
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x0cdd095b	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x540649cf	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x72a436b5	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xb19e3051	cros_ec_prepare_tx
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xca8fa172	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x0daf74ec	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xb37a7c01	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x04d13ece	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x0b282313	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x22cf7e7e	mc13xxx_irq_request_nounmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x3343bd91	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x45547373	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x4b433cad	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x67bc38b3	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x69377692	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6a88d010	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x78c7f41a	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe8582666	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xea4bfd67	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf8cdbfd7	mc13xxx_irq_ack
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x1409da5e	tps6105x_set
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x2cb2e50e	tps6105x_get
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xde46889f	tps6105x_mask_and_set
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x2569b7f3	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x4bab5e44	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x8a05ed90	altera_init
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x4884cfc0	ssc_request
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0xfe639c36	ssc_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x0e9755b9	pwm_channel_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5a8b82f9	pwm_channel_handler
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5d5c2951	pwm_clk_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x6a5e1f70	pwm_channel_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x73330c97	pwm_clk_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0xeb7f2c6f	__pwm_channel_onoff
++EXPORT_SYMBOL drivers/misc/c2port/core 0x11404b60	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0xa10e615e	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0xbbab74f0	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xe2096e1c	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x0c142b5f	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0x0dff3216	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0x12628a3f	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x18d489b8	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x3ab31d1a	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x9b5d843c	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb01e4db3	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xba96396f	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc54ac5cc	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc56775e6	tifm_map_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0xcf0f2919	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe0a49cc2	tifm_unmap_sg
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x89c3fb03	dw_mci_remove
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xabbd8cd4	dw_mci_resume
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xac492330	dw_mci_probe
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xb0fcf571	dw_mci_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x046f4d15	tmio_mmc_host_runtime_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x378f2335	tmio_mmc_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x3b170c20	tmio_mmc_host_remove
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x4ae2c7d7	tmio_mmc_host_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6d3deee9	tmio_mmc_sdcard_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6dddd9b4	tmio_mmc_host_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x7a6fd700	tmio_mmc_sdio_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xa970dea5	tmio_mmc_host_probe
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xe4d44f56	tmio_mmc_host_runtime_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xf02062dd	tmio_mmc_card_detect_irq
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x0bf1e1a9	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x3ff854fc	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xa9623524	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xc238f6dc	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x93aa1657	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x2ab528f1	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xaf3c6bfa	denali_remove
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x4b4d1455	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xc9cb5421	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xcf40eeba	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xe5a9c22f	onenand_scan_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x0647a983	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x14a2af6e	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x2385cf4f	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x486e55c1	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x516ad4ef	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x7e1b9168	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x9aaea937	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa9c4ef31	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xb3464188	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xde2ea74c	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x27b42564	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x7f2bf4f3	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xa0fb7281	com20020_found
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x3cbc3c49	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x4f07b2f9	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x5beba051	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x60b34140	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x74ba8066	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9f551700	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xcb15bfce	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe7231a07	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xee29dc99	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xf7badc8c	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xdeec3e40	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x03a5143f	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x07179d52	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x1897e2bc	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x2b71fdc1	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x36073601	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x492d263a	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x5b5ee0c6	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x656d2cc4	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x980c84fa	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x998fc25f	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xb1746836	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc0775ea2	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xd4b42bd2	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe354f82f	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe6d03a98	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf89a46ae	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x066d89fd	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0c7b42e7	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1630616d	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x31c9213c	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x40f39d41	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4292da1c	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4e401d33	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x51686e3c	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x53875689	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x5b189a4e	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x62d64f40	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x662e3238	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x681ad041	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x68c4c53f	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7014a26e	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x7d4c9131	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x8c6f90b6	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x97abe862	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa0c21417	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xac0dd45e	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcdfe0ff2	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd034a0c4	cxgb4_enable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd36b240b	cxgb4_disable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xec639b55	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf5da5b6c	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x2d01c71f	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xac3b56ae	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x083120a1	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f5a4ae2	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12fb35d2	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x26cfaf4d	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2d4728c8	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4d21b3e9	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x522e1136	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52bf88f7	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5d74446b	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x738c0bfb	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x77a717d0	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8532c378	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8818ac6c	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x989677bc	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b320680	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2e21be2	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb47ac895	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb9bf13ae	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe60994ff	mlx4_set_stats_bitmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe923d351	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8483993	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5dfbb02c	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x6edb6c85	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x9e9d52ce	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xb73651d1	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xe45ef86f	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x004c749e	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x006e65f5	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x1cb2256d	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2d9fdff8	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x2fdd4073	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x35e268ff	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9d81d669	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd10860fa	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xd7c37b5a	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xde992000	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xb34a7575	mdio45_ethtool_spauseparam_an
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x01ebe76b	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0x1f1ddfcd	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x240664c7	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x52dea30e	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0xab02fb4e	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xac6117a7	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xc4baa0f0	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0xd183451a	mii_check_media
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x1af2b6ca	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x8856f507	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xdeb204e5	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0x2df069d4	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xa2dfc635	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xcaf88cb2	usbnet_link_change
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xcd766a99	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x1e90096c	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x1fd5d08e	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x2f77998e	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x3b809505	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x9a80fc0e	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x9e27956b	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc7112fab	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd6c785ca	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xd83be940	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe27beb45	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe4fdff23	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0xf9cb92ec	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x223c567a	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e2481d5	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x53358ce3	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x6033cc2a	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x62196931	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x661e5f4b	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x708a93f7	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x9e212661	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x9e85a75a	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd84d5119	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xe8e44668	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xea15693c	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x179a8a28	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x29495a26	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x57ec50f3	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6b311558	ath10k_core_target_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x783b9342	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8246be6c	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x895f9dc2	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8bcbbed2	ath10k_core_target_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaf096710	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0199ec46	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x01c71a7e	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0e446e81	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x27cf1694	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x337b92e5	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4c6ddcb4	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4e1380ee	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7b2c02cd	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x820bbee6	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa950e9cb	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xb780cb7a	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd803738f	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe3e37cce	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf4636775	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x0a874894	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x635822f1	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x91fc76f5	ath9k_hw_wow_event_to_string
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0xdc5eac0a	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1d896766	ath9k_cmn_update_ichannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x7d5fc193	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x8c931300	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd14660c8	ath9k_cmn_get_curchannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd1752389	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x00cc331e	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x03f79a69	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05496bb5	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05ae2357	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05fa5c0a	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x063df965	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x07b30578	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x093be500	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0bd77023	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d58044a	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1416c177	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x18e9ec91	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1ad2ae2c	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1b60e94a	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1da53b1d	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x206cf428	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2484c168	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x248608d5	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2bbdad46	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2dde7dde	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2dfc3254	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x309da73a	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x30f92e84	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x348f2a74	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x34bf9484	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3630f4b3	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x38d92d19	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x450c9186	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4632db82	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x48b44e33	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4943fe79	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4f633338	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x50c81ce9	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x554da305	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x56075aab	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5664147a	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58d12d0b	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5b786c6b	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x607c3b45	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x63968d49	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x648a7d91	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6bb1780a	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6d7bbea9	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x714fbb0e	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x74744c47	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x74c55a89	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7791d838	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7a356e36	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7b0f496f	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x83c98a49	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x88ff2e54	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a7af333	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8b64bd83	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8e348a53	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9afc34e6	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa19c730b	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa52825ab	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa693f618	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaa8d0792	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xab0de73d	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb0c6f2db	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb23d89be	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb4c8e9e9	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb4dab711	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb52a5d4e	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb980da2a	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba10b341	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbac944f2	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbe438dda	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc0efbd4c	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc207d4c9	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4605473	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4a2ed72	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4a3d492	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc661730c	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc92d67c9	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcaa02641	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcb1837c7	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xccc273e4	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xce68952a	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcf878c74	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcfd3ad89	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd1f0ab8c	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xda94f477	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xde52e263	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdfe47dfc	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe2f0dec4	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe38b7a72	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe4724951	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe7dd110a	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xed4f9c38	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf922562a	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf9fb4546	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfafaf1f0	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfc49fd5a	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfdf2c1bf	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xff9d03d7	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x167f293a	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xa08b2687	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0xade58e27	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0xbcf8b96d	brcmf_sdio_probe
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0xc15135d4	brcmf_sdio_remove
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1229df6c	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2dc227f8	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x35e68910	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x4684435e	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x56832fdd	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x57734cbb	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x5fab0a8c	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x70708a3e	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x7edd41cc	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa30dd1f8	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc6487fbe	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xde383784	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xea867d35	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xf195180a	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x01c6b166	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0e33c1f9	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0e57465a	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0f6de884	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x17e72f7b	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1d4b4340	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x465dc6e7	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x50a92127	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x651cc7fb	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x688174ba	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x6fabe331	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7f76ff38	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x830c2dfe	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x8cbcd9bb	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9023f48b	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x92229d8f	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x934d3193	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa135c853	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa462d7f8	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa9ae377c	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd5e565fb	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd8462211	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdd86a9bc	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xea1541c4	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xec64a54c	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x01aba2de	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x2f91315d	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x33fc53a2	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x41c2ec53	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x43a49142	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x54f583a2	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x55c07b37	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5a64c81f	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5ba4d0d0	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x5d4d7831	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x601b0639	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x67a9d7d8	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7272fc97	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x7b45466f	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x89b78a6c	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x959c8085	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xae45271d	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb03e8da0	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xbe8a711a	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xee073390	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf284b998	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x00ad1b96	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x05a59ce9	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x083948f7	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0a735ca0	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0b8f87d8	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0dba3b93	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x102814fd	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x12dc8d74	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x139164a8	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1665c4c3	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x232a50f2	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x23a66098	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x272aa7ee	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2886dd99	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2aaab895	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2aaba353	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2f62dec2	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x339463bf	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x383bb500	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3aa4cd5b	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3adfcbbb	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3b5c504a	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4297da1f	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4487d12e	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47a40ad6	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x498ddde6	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4c3ac897	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4f76e4d6	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4ff1a0b0	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x5021fa5b	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x508e480f	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x50be3cce	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x56283faa	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x575b3aaa	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x58e457bd	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x619c566d	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6486ecac	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x672bb9b2	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6c9a505d	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6fb23559	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x706b3b75	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x728ae666	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x72c69ae5	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7342a96d	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7900ed52	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7e26ec42	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7e5010a3	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7e849f41	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7ff8e047	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x82559987	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x865887af	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x890999e9	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8c97852f	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x91adbb86	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x91c7c147	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x93aacab2	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9548d287	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x96927505	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x973a01a9	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x97a0dd97	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x988533b6	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x99e6988f	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9ae58ccb	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9c91fa89	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9d7310ce	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa1e3ff42	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa4f33a3f	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa5e77612	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa73b7be5	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaaf55fb9	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xafec2930	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xaff71801	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb162323c	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb178a599	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3b2b64f	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb6b60f96	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7fd21e0	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb8aae6a6	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb9dbb2bb	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbfd38e55	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc2bd7efb	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc8351efe	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcf76c55c	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd6deb6e4	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd73c46cc	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdaae51f5	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdbf57b4e	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xdc53a81f	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xddbfada9	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3a1b464	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe5bd9428	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe71f7326	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe9a5c061	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xebbe65b7	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xec432b58	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf07fd9af	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf1654b69	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf644d78b	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfc34ed6f	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08ee1e7d	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x0d9eb5ff	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x0e7bc05f	__tracepoint_iwlwifi_warn
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x201337b4	__tracepoint_iwlwifi_dev_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x249e4b06	__tracepoint_iwlwifi_dev_rx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x36dcef55	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4919d1a5	__tracepoint_iwlwifi_dbg
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x67381a2a	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x79e9bf26	__tracepoint_iwlwifi_crit
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x7edec07d	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8bfcc307	__tracepoint_iwlwifi_info
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a12c9c5	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xc0827b2f	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xda36f3a4	__tracepoint_iwlwifi_err
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x0cd04d03	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x0f091e61	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x4c8db081	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x51e84528	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5bfb0c47	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5e8bcfef	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x70c8f178	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x7524ada7	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x762aae3a	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x781a8974	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x7f5eef11	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x8d21eeac	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x92564615	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xa4948ebc	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xceb4f116	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf2cb786f	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xfb2b565b	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x01024e8d	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x07371b77	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x18065344	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x22e0f97a	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2a5bfefc	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2d458b11	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x31fcfaf8	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x332dcfaf	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x3c2b44e7	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x42bd0277	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x45d4d46b	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4ed6b758	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5e5f8938	rtl92c_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6590b1e0	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6618c901	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6897a523	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x78a6bb59	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x7b693c59	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x7dcfcf60	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x8364b318	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x88a0362b	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x892ee534	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x8c353356	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x90677163	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x92f73298	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x9316c8bc	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x9ab7844f	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa14b0c9d	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xab7544ea	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xac1d8e37	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb3efb284	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xbab7560c	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xcda2d79b	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xce24243c	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xd452496d	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xdc694d86	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe2e42b7f	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe6aacf1a	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xec269948	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xf2c7fe22	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xf706205d	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xfc8a55f1	_rtl92c_phy_dbm_to_txpwr_Idx
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x0c2f79e3	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x2cedec64	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x2f277651	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x53fec161	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x16c45f69	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x3514a460	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x64efc302	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0xd747e43c	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x0f0da689	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x13d09957	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x17d7bfc5	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x2698344c	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x64117d34	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7bd0960b	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7f408111	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x821f54e3	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xa47e2e1d	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xacaa5226	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xb2da1f24	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xb8065cce	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xc86f357b	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xd66a18d1	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xde6355da	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xe02b944f	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xe08e4833	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xeda8a6b8	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xee5e5df9	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x05a48b6d	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x3465617e	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x7fa460c9	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xb9b29c40	wlcore_tx_complete
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x3bb75259	microread_probe
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x72e2ce19	microread_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x03e8658c	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x2ca700a0	pn544_hci_probe
++EXPORT_SYMBOL drivers/parport/parport 0x197c90d8	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x1ccd1717	parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x20e82f00	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x259ffcd0	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x28361019	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x2d9e1535	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x2e9899c0	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x33c16e9d	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x36d8367d	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0x4753647c	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x4f1dc19a	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x5963fc55	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x5c736f57	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x66490a88	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x6fb51611	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x70380aaa	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x7fcea282	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0x82219fd9	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x82b66391	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x8366be7a	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0x8c71e672	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x93c59f45	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0x945fa216	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xacdc3547	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0xb8a5e7f7	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0xbabc814a	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xbf131379	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xcb95e6ea	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xcc4fdb19	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xee9c62c2	parport_write
++EXPORT_SYMBOL drivers/parport/parport_pc 0x7b1fd68b	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x9775492c	parport_pc_probe_port
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x3a69fb8b	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x427bdb58	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x6fa5a563	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x7e680aef	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x857536b6	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x9294bb1c	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x9906ecfa	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xbf6aa65e	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd501ef13	rproc_put
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x6aed34a3	unregister_rpmsg_driver
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x740bdf79	rpmsg_destroy_ept
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0x78a1f1bd	rpmsg_create_ept
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0xd3133d54	rpmsg_send_offchannel_raw
++EXPORT_SYMBOL drivers/rpmsg/virtio_rpmsg_bus 0xef67bacd	register_rpmsg_driver
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x02d00d09	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2975a5fe	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2b9436d9	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x2f7893d7	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x363bdece	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x38e576ba	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4407ce9d	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5ef2671b	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x81e5b6b6	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb1968792	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xcfc18d5d	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xfa626661	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x026db5cb	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x08cdc07f	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x09409c91	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0ba3bc86	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x113c4967	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x124373df	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x29b924fa	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2a8b8e5c	fc_change_queue_type
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x327ad66e	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x32933fa3	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x39cd802b	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4877c8a1	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4b0dbdc9	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4cf9d199	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4d281ca7	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4e85e8dc	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4eff2af7	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5bba8d4d	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5f167485	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6328ef90	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64b3d37d	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x69afd475	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6c94e7e9	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7a8a49a5	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7ebe62fa	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a043bf5	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a198d0b	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x953c5f22	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa00b75be	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa38edbee	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa6e0bfc8	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xaa64647d	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xab6de9ce	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb5933626	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb6367db6	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb7a2e097	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbca6bff1	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc1072bf5	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc347a9c9	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc34fe324	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc52dbb65	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc5741d92	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc7f4080c	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcaa245ef	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcaa64d7b	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd86c2f0c	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd875f023	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe4169dff	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe944d977	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf164fedb	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf683c47b	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf7912427	fc_change_queue_depth
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x244a9635	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x25fa26d3	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x378d132b	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x3dd699fb	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xb81c6413	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0307574d	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x04b66588	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x05019f1d	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1d6dce99	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x1eec8cb7	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x24886d66	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x24f51a24	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2a07d905	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3149392a	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x32dfb718	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x354e4278	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x46ee0d85	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4d27544a	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x50e44e86	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x565daafd	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5967225a	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5a3e27c0	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x61e5b2d6	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x78f0ef67	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7c72afd2	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x86e016c6	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x880fd93d	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9c098043	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa0ed9890	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xad125e39	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb2b618c2	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb64c820b	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc0b30510	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc58a54b4	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd01899b4	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd0ef755a	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdb2b322f	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe2105be7	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe75e1967	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfa3910e8	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfcbe2509	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x015b5ef6	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5e6d512d	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xd04aff4a	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xef41ac73	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xf9c1d177	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xfc14a6c6	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x03ba0ec3	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x0ec42427	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1532c59f	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x19265bea	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x5e0cfde0	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x658447dc	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x9a52163a	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xa2ebeea3	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xa83964f7	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xbb90a79d	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xe24c1af7	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/raid_class 0x1ef7cc94	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x79b40b49	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0xf15dff91	raid_class_release
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x13d6b1b7	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x21742dd7	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x26e89dad	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x50396068	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x522c40ea	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x86375afb	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x868561f5	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb95626be	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd1dc5b8e	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd39b1420	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xdb23df2f	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xdd7ccc51	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe08b7dcb	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x02658aa0	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x030f2d11	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x07652905	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1b962498	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x209c4a93	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x23f66fd9	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x31dcca3e	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4919e027	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4ab98e8b	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4f02ecdb	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x51d0631b	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6252d20c	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6c5a965e	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x78b6ca09	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89f4120b	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x91f9ad9e	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x934c598c	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x992fb376	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa0c80fae	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb15dabbd	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xcc2b2e42	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xceb70fff	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdbf5ce92	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xdd4fdb62	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe08e7603	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe633dc44	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf2c945e8	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf49be948	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x4f50cc84	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x70614314	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x8584f69c	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x96bb38c6	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xdeab3b88	spi_dv_device
++EXPORT_SYMBOL drivers/ssb/ssb 0x08a13471	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0x0bfc30b8	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x1758f05b	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x3db8a8d1	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x47731f94	ssb_bus_pcibus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x5855d210	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x5f9bdbf3	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x74cc6cf0	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x8f299a44	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x9229eb20	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x94a8e54d	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xa15ba076	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0xa26d9607	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0xaf2e40d9	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0xb128920c	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xcb29bc42	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd76cdc22	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xdc5dbfe5	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0xeabf49a2	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xf4195c70	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0xfdd70f6b	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0x4ef2c652	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xbdf3b312	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xa5136fdb	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xdd95eb6f	adt7316_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x376288df	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xfe203f82	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0x790e142b	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x01bf5807	go7007_update_board
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x1cd1f09e	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x3585b6b4	go7007_alloc
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x5feac045	go7007_register_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x96079aec	go7007_snd_remove
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xa24c1717	go7007_snd_init
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xb5aff8d5	go7007_boot_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xdf460bcd	go7007_read_interrupt
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xfbf4b47f	go7007_read_addr
++EXPORT_SYMBOL drivers/staging/nvec/nvec 0x31dfbf54	nvec_write_sync
++EXPORT_SYMBOL drivers/staging/nvec/nvec 0x5f83692f	nvec_write_async
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0181e041	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0931e249	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x18254a57	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x1bbabc6e	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x24fe7d04	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2528b6f7	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2d948fcf	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x304e91da	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3415d9e1	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x35189c0e	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x381e4e12	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3d8c7723	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3e51dce6	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x3ea506b9	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x42cde991	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4aa5fef0	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x55382b15	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x55ff6a46	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x56e4e8a7	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5acee858	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5be9292f	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x69c85c50	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6f0ed751	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x76db4ecd	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x78efda41	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7cdf97a5	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7f47abae	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x901cd576	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x97746d77	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa9f769cd	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xad0b159f	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xb55eb7f5	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbadb3ffd	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe30d622	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc005a08e	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc007ca6b	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc17eb379	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcdffda74	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xce8f7398	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xcee45895	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd06a1b67	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd2f0f42f	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd7289e99	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xde9af3df	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdee98834	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe2f01d44	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe616b596	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xed67e7c7	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfc5a88d1	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xfd8f9967	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0168fa5c	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0252c618	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x032cddb1	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0b94c877	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x0c470c83	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1ca1b1e2	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x2f8bd2d3	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3783ba8e	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3cbb989d	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x42c12e02	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4846d7a5	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4b92b919	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4d7fce5e	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4decf530	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4e57cb82	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x573dda49	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5960702e	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5a74b121	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5ce4bb9e	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5d40a83f	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x68593405	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6c32c8b5	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x71c996fd	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x76220607	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x786e9cf5	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x78c61d80	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x81fe03aa	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x83a90959	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x865be97c	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x86ce65df	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x88f78e51	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9bc91f21	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9e4dd491	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa051f38b	ieee80211_send_probe_requests_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa358fcc4	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaab28b83	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xad8eaa52	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb3a22ac7	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb6b35d3a	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb7c2f371	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbd463140	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc8432570	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc8e81418	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xccda7462	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd12f0a8	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcd6cdfa8	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcda15099	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xcdc7eec0	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd672d1e2	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd81731af	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe417bb39	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe4aa5603	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe91b4a58	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xeb43646e	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf4204608	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xff8765ad	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0017f35f	set_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x00ea0cde	set_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x06d6f244	get_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x09df8f3e	set_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0a8d32c3	get_bypass_slave_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1936264c	set_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1d2eb8ca	get_tap_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x203af1f7	reset_bypass_wd_timer_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2070f14a	set_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x27b990ef	get_bypass_info_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2ba7cd35	get_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2c3f1c17	get_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2f59e636	get_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2fdb893a	get_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x361cf40a	get_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x45ca99c3	set_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x550a188c	set_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x5cb59e92	get_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x66b60122	set_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x675208c0	set_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x692623f2	get_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x75131ec6	set_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x76c0b7d0	set_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e872825	get_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e8d701e	get_wd_expire_time_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x86388b07	get_bp_disc_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x93ae4648	get_wd_set_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x95e42b0d	is_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9df5f807	set_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9e21f42e	set_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xa689a214	get_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xae117788	get_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xc368d30d	get_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xccab5de0	get_bypass_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd3e034b3	get_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9c1ccfc	get_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9d38d97	set_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xe640f06e	set_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xecdaa456	set_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xedcd3c1b	get_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf06d67bf	set_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf57c1671	get_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf693c3a1	bp_if_scan_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf8237882	get_bypass_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xfa59240d	get_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05af3c4c	set_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05b08a42	set_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0b0d5ce0	get_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0fc2e83c	reset_bypass_wd_timer
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x123a8133	get_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x157ec89c	get_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2440f05a	get_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2b01d1d4	set_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2c27a2f0	set_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2da97f4b	is_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2e86c67b	get_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37416370	get_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37bdab27	get_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x3da96a18	get_bypass_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4025805e	get_bypass_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4940a0cc	get_bypass_info
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4d21ff51	get_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5147360c	get_bp_disc_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x515d4df1	get_bypass_slave
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5560267e	set_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5be44d44	set_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6653590c	get_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6bda14ec	get_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x72c618ae	set_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x76d47e6f	set_bp_disc_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x794e3815	set_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x7c6cbc16	get_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x84a263dc	set_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x8a16f22c	set_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x946ff795	get_wd_set_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x94f6aff2	get_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x9d1ecf73	set_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xb1385629	set_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xbff68c45	set_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xc871c561	get_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xcee528df	set_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd202dd85	get_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd787f151	get_wd_expire_time
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xdb6a39d2	get_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xebd25ae5	get_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf1e9f8c1	set_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf224abd9	get_tap_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf5a591b2	set_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf643fd4c	get_bp_disc_pwup
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0307cf46	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0dc465e0	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x1d091be7	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2b0d3777	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2cdcf892	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3184a1cf	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x34651365	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3d7f3000	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4dc78dc4	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4fd0ae04	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x503ed432	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x51675328	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6cc14430	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6f0ddd49	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8380f099	iscsit_handle_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8805ce27	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8ef2f8ef	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa1c5660c	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa5f3160c	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa6e27a79	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaa317d11	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xab97dee9	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb2b531bb	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbf0d5762	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xcae23378	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf573297d	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf5961746	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x014f193a	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x028cc520	fc_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x06a0559e	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x08cb97bf	iscsi_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0ab5234c	iscsi_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1cd5d14b	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1d1cf79f	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x23b53ec4	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x27c979b7	target_fabric_configfs_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2afe5bdc	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2de5cf2a	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2e98b0b7	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2f1c734e	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x314c57eb	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3d938b41	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3e8f3226	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3efb8280	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4559451f	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x48a1cbe7	fc_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x49d9a005	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4b7dd806	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x583058ed	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5beda4cd	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5caa4bf5	core_tpg_del_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5fbc1f88	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x610491b7	sas_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x644b8157	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6e69fc4c	core_tpg_clear_object_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x6e99dbd5	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7c5ed5f9	target_fabric_configfs_free
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x938664db	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x95093ae1	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x952bc2c5	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x95990466	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97882cef	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97e8b065	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x99c8f894	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9b78b763	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9e3db2b8	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9f54a696	sas_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9faa38c1	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa0ab1ead	transport_subsystem_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa97d5877	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xaab7b393	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xacdbd72f	fc_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xacf4963d	core_tpg_add_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb3e67190	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb742433c	transport_subsystem_release
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbbcccaa4	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbca35bf8	target_fabric_configfs_init
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc5f33c48	sbc_execute_unmap
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc6a5ee2e	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcfc976f9	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd0fdd1f2	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd2b08b89	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdbe3d63e	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe481fa53	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe6638b47	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe8b360ff	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0xeb5b29aa	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xebe88639	target_fabric_configfs_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf095a01e	sas_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf2414b4a	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf5db7ed7	iscsi_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf6b14b7f	iscsi_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf8651824	fc_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfe79bbe3	sas_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xd5517d09	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x10072887	gether_get_host_addr_cdc
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x11c84782	gether_setup_name
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x2d207e74	gether_set_gadget
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x36d74bf0	gether_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x4e5971e4	gether_get_ifname
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x630ab504	gether_register_netdev
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x76f57c87	gether_get_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x7af2504b	gether_set_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x86beaaf0	gether_set_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x9d0d11bb	gether_get_host_addr_u8
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xa2b45b7b	gether_setup_name_default
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xae719f28	gether_set_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xb637b6c9	gether_get_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xb9f895d4	gether_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xfaf29d56	gether_get_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3a6d4f22	rndis_free_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3ca38e3a	rndis_signal_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x46dcd11c	rndis_add_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x4ca90996	rndis_signal_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x5d22b406	rndis_register
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x785d494b	rndis_msg_parser
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x7d836bd5	rndis_rm_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x840dd143	rndis_deregister
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x988ad2a2	rndis_set_param_vendor
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x9acf72e4	rndis_set_param_medium
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xa90054ee	rndis_uninit
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xb971ebca	rndis_get_next_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xbf37e820	rndis_set_param_dev
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xd2fe47b1	rndis_set_host_mac
++EXPORT_SYMBOL drivers/usb/gadget/usb_f_rndis 0x33c63a26	rndis_borrow_net
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xcb699534	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0005d204	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x12dffe77	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x15ac9730	usb_wwan_set_termios
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3b74878d	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3d9e6418	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x4d6c711c	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x64d7463a	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x69016279	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x6c908a1b	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x8518c635	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x8a83de04	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9b1a6f39	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd070fa8d	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x013c432e	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xa09017bc	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0dda8c5a	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x1f063017	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x36dfce73	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3eaf442a	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x3fa42e4f	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5dafbd4e	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x66af098b	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x6d0e7948	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xaf8e4a0e	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xafb47dae	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc884d704	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc8bee0a4	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd11d2709	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xda4ea4cc	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xfc7dcad2	vringh_getdesc_user
++EXPORT_SYMBOL drivers/video/backlight/generic_bl 0x366d19ef	genericbl_limit_intensity
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x12241fcd	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x8a8b4b59	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xd50f3686	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xf7575483	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x06ba64e7	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/macmodes 0x4fa36e1b	mac_find_mode
++EXPORT_SYMBOL drivers/video/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0x4c612205	g450_mnp2f
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0x7a42b71b	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0xdc9605ff	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0x1787e91c	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0x1a85db52	matrox_mystique
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xa49c97d3	matrox_G100
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xf0fdb3b2	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_Ti3026 0xca50004e	matrox_millennium
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_accel 0xfdc09249	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x42dc659f	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x45648c7c	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x997dee09	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0xfb4d12a9	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0x96f6a9f7	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0xc3e779a0	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x03179885	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x2da9067d	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xaf61a7b9	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xb96481a6	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xf548c93e	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/mb862xx/mb862xxfb 0x631a1b2f	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/output 0x7bce0997	video_output_unregister
++EXPORT_SYMBOL drivers/video/output 0xd72e95e1	video_output_register
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/svgalib 0x13d345f6	svga_get_caps
++EXPORT_SYMBOL drivers/video/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x4bb520f5	svga_tileblit
++EXPORT_SYMBOL drivers/video/svgalib 0x655c8706	svga_tilecopy
++EXPORT_SYMBOL drivers/video/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/svgalib 0x76b05b66	svga_settile
++EXPORT_SYMBOL drivers/video/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/svgalib 0xb5cd93c9	svga_tilefill
++EXPORT_SYMBOL drivers/video/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xd8444136	svga_tilecursor
++EXPORT_SYMBOL drivers/video/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/svgalib 0xf34794ae	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/vme/vme 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL drivers/vme/vme 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL drivers/vme/vme 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL drivers/vme/vme 0x10491a8a	vme_register_bridge
++EXPORT_SYMBOL drivers/vme/vme 0x137eae89	vme_unregister_bridge
++EXPORT_SYMBOL drivers/vme/vme 0x2157965d	vme_dma_pci_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x2527a087	vme_slave_set
++EXPORT_SYMBOL drivers/vme/vme 0x2bb02815	vme_irq_request
++EXPORT_SYMBOL drivers/vme/vme 0x34c87749	vme_dma_list_add
++EXPORT_SYMBOL drivers/vme/vme 0x38214158	vme_dma_list_exec
++EXPORT_SYMBOL drivers/vme/vme 0x3d0b2cdb	vme_lm_request
++EXPORT_SYMBOL drivers/vme/vme 0x3d7eca0c	vme_irq_generate
++EXPORT_SYMBOL drivers/vme/vme 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL drivers/vme/vme 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL drivers/vme/vme 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL drivers/vme/vme 0x4c21ed76	vme_register_driver
++EXPORT_SYMBOL drivers/vme/vme 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL drivers/vme/vme 0x66227eae	vme_alloc_consistent
++EXPORT_SYMBOL drivers/vme/vme 0x6ba0de12	vme_unregister_driver
++EXPORT_SYMBOL drivers/vme/vme 0x6ff6fd64	vme_irq_free
++EXPORT_SYMBOL drivers/vme/vme 0x7cf35220	vme_master_free
++EXPORT_SYMBOL drivers/vme/vme 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL drivers/vme/vme 0x84a69fdc	vme_slave_get
++EXPORT_SYMBOL drivers/vme/vme 0x858def50	vme_dma_request
++EXPORT_SYMBOL drivers/vme/vme 0x8aaba17c	vme_dma_list_free
++EXPORT_SYMBOL drivers/vme/vme 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL drivers/vme/vme 0x94b2590f	vme_free_consistent
++EXPORT_SYMBOL drivers/vme/vme 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL drivers/vme/vme 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL drivers/vme/vme 0xb9125a56	vme_bus_type
++EXPORT_SYMBOL drivers/vme/vme 0xb9bc5bdd	vme_master_request
++EXPORT_SYMBOL drivers/vme/vme 0xbfd6a198	vme_slot_get
++EXPORT_SYMBOL drivers/vme/vme 0xcfb73abd	vme_slave_request
++EXPORT_SYMBOL drivers/vme/vme 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL drivers/vme/vme 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL drivers/vme/vme 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL drivers/vme/vme 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL drivers/vme/vme 0xf56e07c3	vme_irq_handler
++EXPORT_SYMBOL drivers/vme/vme 0xf9faded5	vme_new_dma_list
++EXPORT_SYMBOL drivers/vme/vme 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x103ca1fa	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x6ee357ab	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x76d0a397	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xd40abe8d	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x671ee5f5	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x7b7a585e	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x2396aa98	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x6efae7f1	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x1876cd21	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x3b2c1e8c	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x58cfc3c2	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x93d6914f	w1_register_family
++EXPORT_SYMBOL fs/btrfs/btrfs 0x27476846	ulist_reinit
++EXPORT_SYMBOL fs/btrfs/btrfs 0x41e6a9d2	ulist_init
++EXPORT_SYMBOL fs/btrfs/btrfs 0x7e2ee765	ulist_free
++EXPORT_SYMBOL fs/btrfs/btrfs 0xa2eec2e8	ulist_fini
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb1320bc8	ulist_add
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb42289d2	ulist_alloc
++EXPORT_SYMBOL fs/btrfs/btrfs 0xc2c745db	ulist_next
++EXPORT_SYMBOL fs/configfs/configfs 0x04170123	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x0ba92643	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x239c702f	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x2b4e86f8	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x32e5bda0	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x40625dad	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x40b29e5a	config_item_init
++EXPORT_SYMBOL fs/configfs/configfs 0x579ee1ea	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x729ff0f5	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x7aeb7fe6	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0xc644bb74	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xfdd6a3a6	config_item_init_type_name
++EXPORT_SYMBOL fs/exofs/libore 0x011500ad	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x0465d3f0	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x19e583c8	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x1ee13e8d	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x292460f0	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x5ee53a8f	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0x8f2d9618	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xc7e5a610	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0xd46ad922	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0xd5a82884	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xda56668c	ore_write
++EXPORT_SYMBOL fs/fscache/fscache 0x02088ea2	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x057af476	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x06986419	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x1441ef9d	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x1655e62a	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x1fb699a7	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x25631afd	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x349924f3	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x382d1ce1	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x49646c4f	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x52a653b4	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x570647af	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x58d73332	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x66d9553d	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x6ddf4086	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0x71547ae4	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x784fc629	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x7d65e944	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x8383c144	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x84d2cdc4	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x98edadc2	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x9936781b	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x9c882027	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xa1e03e10	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xa1f6ae55	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xa5381fa8	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0xa6ba6ad8	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xbc51de08	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xcac8eff0	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xeafdd1d6	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0xf6422b42	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xfbe2040b	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0xfe4f9760	fscache_fsdef_index
++EXPORT_SYMBOL fs/nfsd/nfsd 0x040ea5a0	nfs4_acl_nfsv4_to_posix
++EXPORT_SYMBOL fs/nfsd/nfsd 0x35e33c1e	nfs4_acl_write_who
++EXPORT_SYMBOL fs/nfsd/nfsd 0x5a157ae4	nfs4_acl_get_whotype
++EXPORT_SYMBOL fs/nfsd/nfsd 0xcb152562	nfs4_acl_posix_to_nfsv4
++EXPORT_SYMBOL fs/nfsd/nfsd 0xda45bc09	nfs4_acl_new
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x025a7d58	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x8161b24d	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa7a18680	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xcdbcfef8	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xe07daaa9	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0xa7587646	crc7
++EXPORT_SYMBOL lib/crc7 0xd80c3603	crc7_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0f135b1b	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x13f36999	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x1512741c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x1f1e1a77	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x2110282d	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x2141529e	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x22c0d0dc	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x35d7057c	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x391edfa4	lc_get
++EXPORT_SYMBOL lib/lru_cache 0x4ff71075	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0x5b69e7bc	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x69414740	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xa17de9b1	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xbd50fb72	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xc817c8aa	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xe3d5fe88	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xf59c7e96	lc_is_used
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x315c65fd	zlib_deflateInit2
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x48034724	zlib_deflateReset
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xaf64ad0d	zlib_deflate
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xf741c793	zlib_deflateEnd
++EXPORT_SYMBOL net/802/p8022 0xb7032642	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xd0a6f617	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x224d429b	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x31b93c0b	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x21d83275	register_snap_client
++EXPORT_SYMBOL net/802/psnap 0xf940acf8	unregister_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x038af9c2	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x07de80b7	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x0a1ca295	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x16be2bf2	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x188c9178	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1b3deaa8	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x239045f4	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x258648db	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x28a3e7d5	p9_payload_gup
++EXPORT_SYMBOL net/9p/9pnet 0x2b780fc6	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x2f6af4ba	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3af613d4	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x4007de5f	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x41efcba7	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x45d43fb1	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x4669a826	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x4c6eca3e	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x4e060ed8	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x50e3650e	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x5150a04f	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x5fcbda72	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x64b265c9	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x6d75a12a	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x6fb9cc44	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x7ecd37f9	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x856696c2	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x87111426	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x8beaf130	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x8d6e723b	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x9224a5a7	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x977a0030	p9_nr_pages
++EXPORT_SYMBOL net/9p/9pnet 0x9a50e476	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x9d125844	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0xad839029	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0xb753d645	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xba88245d	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xbbc7753e	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xc2021025	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0xc4385252	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd5b4fd14	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xe703c3ad	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xeefc0604	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf5b334e4	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xf876c57b	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/appletalk/appletalk 0x20206f80	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0x3f4db935	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0x65b96597	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x781c96e5	aarp_send_ddp
++EXPORT_SYMBOL net/atm/atm 0x23a75420	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x488eadcf	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x4c0b3b85	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x5485ac35	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x6390ff9b	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x683e71ab	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x7d74d682	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x7e386424	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x7ff006a8	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x859087e9	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x9a84ec31	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xbba63311	atm_charge
++EXPORT_SYMBOL net/atm/atm 0xcc2193a9	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xfac5ae25	vcc_sklist_lock
++EXPORT_SYMBOL net/ax25/ax25 0x026c1368	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0x13e0d5e8	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x1c7166d0	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x34881d76	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x49bc6a77	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x6a828b77	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x7169382d	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0x94d7febb	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x9b1d52fe	ax25_rebuild_header
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xdd214c11	ax25_hard_header
++EXPORT_SYMBOL net/ax25/ax25 0xf9733425	ax25_send_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0425fe68	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x153310c5	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2bca454f	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2cc34d1b	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3f230a9f	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x405dabdb	hci_recv_stream_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x40fdf457	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x487c817f	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4b6d9326	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x4e509741	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x535cadd4	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6792ce26	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6a55000a	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6ccca98c	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6e6c1329	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x793433b6	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c640527	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7dbe2718	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8c1f9c5b	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x95ca5054	hci_recv_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa228899d	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa5f56c1b	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa6c4d2f1	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa817ccb0	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xae129b4b	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb61a0c3b	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xca94d500	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcfac3bf7	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd5bac659	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe33b27a1	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe35cdb9c	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe9a8e77d	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xec8afed5	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xee490d6f	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf655c0e1	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf89422cd	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf93aae78	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xfa4d3b73	__hci_cmd_sync
++EXPORT_SYMBOL net/bridge/bridge 0xc02f2618	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x61f9cbde	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x8467c296	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xdfb2daab	ebt_unregister_table
++EXPORT_SYMBOL net/caif/caif 0x00cbb656	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x1a0eeb14	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x59549055	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x77035b40	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xe847dce5	caif_enroll_dev
++EXPORT_SYMBOL net/can/can 0x2938c01d	can_send
++EXPORT_SYMBOL net/can/can 0x3a555fda	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0x43176fcb	can_ioctl
++EXPORT_SYMBOL net/can/can 0x5c650f6d	can_rx_register
++EXPORT_SYMBOL net/can/can 0x727e3f80	can_proto_register
++EXPORT_SYMBOL net/can/can 0x8c795ac8	can_rx_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x030ab856	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x04dd8efe	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0x08b985c9	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x10940306	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0x1475bf0d	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x197effcb	ceph_osdc_release_request
++EXPORT_SYMBOL net/ceph/libceph 0x1d1a56c4	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x1e2579cc	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x1f784621	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x23ca184a	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x2520a906	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x255d52f5	ceph_osdc_unregister_linger_request
++EXPORT_SYMBOL net/ceph/libceph 0x258a34f7	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x29479320	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x2a3ea5f8	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x2bfcbc05	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x2cbe6e51	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x3158173e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x319c8eb9	ceph_monc_create_snapid
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3df0ec7c	ceph_calc_ceph_pg
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x415f352d	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x4205ffd7	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0x42af34ae	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x43c8d341	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x4401d20d	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x4afa272a	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x4fa5a3df	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57136cf6	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x59c5468b	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x5dcc3248	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x5fb8c0ad	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x5fe4b2fa	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x60afee6c	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x61923e0f	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x623bc057	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x62c580ee	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x6539f9f2	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x65ac551d	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x68b1a1b5	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c5d5ac1	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x6d2d06a1	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x6e2b5211	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x6ed41be2	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0x6fca0fc9	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x70da92f4	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0x7493094f	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x77692acb	ceph_msg_last_put
++EXPORT_SYMBOL net/ceph/libceph 0x7cfd9ce1	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x85fed7d2	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x88af9dd1	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x898e80a1	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x8b75a99d	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9a2f37ef	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x9ba6aed7	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa157f2a4	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xa3c70d4c	ceph_copy_page_vector_to_user
++EXPORT_SYMBOL net/ceph/libceph 0xa40bd703	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xa7caaa30	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0xa84e0fca	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0xa8c40fae	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xaaaf737a	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xab75226c	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xacccfa51	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0xae1b5f3e	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xbbc8d912	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xbe4fd263	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xc1e64754	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xc338e26d	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc55de604	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0xc5aa8f74	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0xc5c45bf9	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xca644adf	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd08fc84c	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd4b4dcd7	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xd88d660c	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xd89b5f9f	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0xde3e324b	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xe82c9c32	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xee886a4c	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xf42ec0a8	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xf48fe313	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0xff678124	ceph_messenger_init
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x0ce9b141	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x130af6b1	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x4375fa11	ieee802154_nl_disassoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x47f35a71	ieee802154_nl_disassoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x51dd2766	wpan_phy_alloc
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x59d4a4f9	ieee802154_nl_assoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x6829caf8	ieee802154_nl_start_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x735e35b1	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x840bf123	ieee802154_nl_beacon_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x85ae2f72	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x9a856717	ieee802154_nl_scan_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb6652843	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd21d8e38	ieee802154_nl_assoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd4feb91a	wpan_phy_find
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x5bd8bafd	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xd1326264	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xfc85ad25	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x47fd47ce	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x4c9d526b	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x807b660a	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0xb4529def	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xfc85f441	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x623e5fb1	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x893dd1a4	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x5a72a905	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xb93e33d5	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xef787656	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x0451daaa	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0x81cb7430	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x0b1e012d	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x3d506cd2	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x01ad5a3a	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x5d740eb7	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x628b2dde	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x726305b4	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xca1a612b	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xda397fbe	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe48adb28	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xe83fadd4	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x12141e44	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x17a491c5	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x19fb85ac	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x1a538fca	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x1bee8fc3	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x2036ad06	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x258c321b	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x2dd6cedc	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x36cad55b	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x37791344	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x42cd1bf8	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x479b952c	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x606afb17	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x6412cdb7	irlap_close
++EXPORT_SYMBOL net/irda/irda 0x6492e28c	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b76aa70	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x725dafd4	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x731cec71	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x75fbd02e	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7e67ca6e	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x8982c8d9	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x8a44dd5e	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x8a512d59	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x90ddb6bd	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x993ad14b	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x9ffda243	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0xb3c13d7f	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0xb49cbd59	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0xb535fa97	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbb622eaa	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbd50578e	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xbf7dd554	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xbfa7c08d	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xc078b933	irlap_open
++EXPORT_SYMBOL net/irda/irda 0xc1657345	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xc1763c99	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0xc477368d	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xd90a0bdd	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe0b1e094	iriap_open
++EXPORT_SYMBOL net/irda/irda 0xe695884e	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xea4570b8	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf199cba4	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0xf4188c78	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x1db835d9	l2tp_recv_common
++EXPORT_SYMBOL net/lapb/lapb 0x2ff0c357	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x4579c02f	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x48f8a77e	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x90698edc	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0xb209540d	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0xc7c5a889	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xda7a2d68	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0xe289157e	lapb_data_received
++EXPORT_SYMBOL net/llc/llc 0x10f66d0e	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x1e9e99fd	llc_sap_list_lock
++EXPORT_SYMBOL net/llc/llc 0x2b1d7329	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x34ae1289	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0xbf2f19be	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0xe3383821	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xec4e64a8	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0xeeab1e32	llc_sap_open
++EXPORT_SYMBOL net/mac80211/mac80211 0x009376f2	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x00a020f1	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x03dce042	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x0584cc1d	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x0aa8a432	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x0c763631	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x137cb220	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x1d19900b	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x21a2ae71	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x25788d33	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x2779a311	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x2e92005c	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x3072cf14	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x32a89ec2	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x36c501d3	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0x36f8cdf6	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x42f4aeb0	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x4b61eac5	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x4ff73373	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x514b2511	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x515c159d	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x526329e9	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x545951cd	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x565afb34	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x5c28cca5	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x64567425	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x6acf23be	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x6c2cc49c	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x730548f7	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x750c42f9	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x7968f58a	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x7c5340d4	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x7d711a50	ieee80211_alloc_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x8066e8fb	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0x84b59655	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x87a06b9b	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x901600cb	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x902f18c0	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0x98f96296	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c5e6334	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e9543c7	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1fc36c4	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xa4d84a31	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xa6830003	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xa9eca247	ieee80211_rx
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa157485	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xacc60869	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xade68895	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xadec6cfa	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0xb1486d08	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xb8d72762	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xbcb0d152	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe2d2d31	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xc5309585	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0xc7e9782e	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xc8f0b846	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xcb1491e2	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0xcb2c9cb1	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xcccafe99	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xd048de0e	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2177458	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xd3412566	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xddb47d52	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xde14fee8	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xe1f5b027	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xe4cde3df	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xf395de03	ieee80211_aes_cmac_calculate_k1_k2
++EXPORT_SYMBOL net/mac80211/mac80211 0xfc4ef98e	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xffad53b1	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0xffd27d30	ieee80211_queue_work
++EXPORT_SYMBOL net/mac802154/mac802154 0x2ae162aa	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x39d63baf	ieee802154_register_device
++EXPORT_SYMBOL net/mac802154/mac802154 0x5ba18d62	ieee802154_unregister_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xb9e8125f	ieee802154_alloc_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xc0e19a88	ieee802154_free_device
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x045bc6ad	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x0ca6c112	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x16562988	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x22001124	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x2aeb96bd	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x31adbbc2	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x3e930d6b	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x472ad7af	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6d3894d4	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x796d455c	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x88c54859	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x96e6a783	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9ffd5865	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xba5080d5	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x99761f31	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xdc9c3a94	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xeedd613a	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack_proto_gre 0x081da27f	nf_ct_gre_keymap_flush
++EXPORT_SYMBOL net/netfilter/nf_nat 0x17f9f7de	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x7a40516b	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xb29d06c4	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0xb6cf599c	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0xe185f059	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xffcd3350	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/x_tables 0x08c473b7	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x3149c990	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x376e9c07	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x59089037	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x7d7ed992	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x81a29901	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x94abb0a2	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x97ee9198	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xb28f5ef1	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xc3000a43	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xd1ec8abd	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xf461655e	xt_register_target
++EXPORT_SYMBOL net/nfc/hci/hci 0x0ee4a6a2	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x447919c7	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x5462a386	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x5547224b	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x5778c0dd	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x67968d8e	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x6e75fa39	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x7b413e5d	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0x7d36d875	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x96b05b52	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x99e446f8	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x9bf064da	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xa2b0c362	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xa6b236da	nfc_hci_send_response
++EXPORT_SYMBOL net/nfc/hci/hci 0xabdde67a	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xeaa5c06e	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xf35b5ea6	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xf4ac4b67	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/nci/nci 0x4517479e	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xab6e5cbb	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xc5bb2a83	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xca4bfd8e	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xd6a20544	nci_free_device
++EXPORT_SYMBOL net/nfc/nfc 0x15880ce4	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x23e0055a	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x23e205ad	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x333d7f02	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x3cee81c8	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x43c3aff8	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x4dac899a	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x5ce72a3d	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0x80a9db6f	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x972adfb5	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x989b6478	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xb2a1d7ae	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0xb631e9b2	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xc0463158	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xc4031897	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0xc5f7627e	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xcb01631f	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xd616c966	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0xd9d21c55	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/phonet/phonet 0x03860bb7	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x11d8a99a	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x7b334743	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xbcdcd62d	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xc6f4bcfa	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0xc9621e0a	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0xdbcaf7b7	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0xe9429464	phonet_header_ops
++EXPORT_SYMBOL net/rds/rds 0x5031b8c5	rds_str_array
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x032b0889	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x04275104	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x14f72e2a	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x495f1375	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x52cb54b9	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x60bc02c5	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x793e4a1f	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x7d44f817	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x874ceb10	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8f7042a4	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x97ca5ccd	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9eedb5e8	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb50d971f	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcb0fdcb7	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xea5242c0	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/sctp/sctp 0x51efff5d	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x06cf29bb	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd2479fcb	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xdf7e035e	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x88aea3a6	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x6d40a177	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x7c412eaf	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x0284f5cc	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x033334f6	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x03945943	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x05744042	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0d1eadfe	cfg80211_inform_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x0e3e1a04	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x0fe92094	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x126d6b7e	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x1747d1af	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x1a480fab	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x1aeffae0	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x1d071bc5	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x1d40186d	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x2091f71b	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x212772ca	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x23c14d92	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0x2a4a3d43	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x2c724796	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x2cb0a9eb	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x2e73b970	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x30f8ba2f	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x382670c1	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x39d44392	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x39f90857	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x3de850db	cfg80211_inform_bss_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x406a8302	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x43aab69c	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c3b5878	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4cc795bb	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x4fe7c9ff	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x52b1a66a	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x55af3048	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x5639e283	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x56ebc761	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0x62de165e	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x638c9c56	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x732da262	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x74a9480a	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x7b174d64	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x85d5676f	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x8cdd93a5	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9097b4ab	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x90eb6c97	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x92c0c538	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa309ed2f	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xa5d5225a	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xa6aba2b5	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xa8a69f20	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0xac768b5e	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0xad0314cb	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xb06dc9d2	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xb2766649	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xb490f2ac	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0xb5341976	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7de424c	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0xc15c8611	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc9b3f553	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0xcdcbe530	cfg80211_del_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xcf618a57	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0xd28a9b14	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xd78ac070	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xd7af4bdd	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xda9e6840	wiphy_new
++EXPORT_SYMBOL net/wireless/cfg80211 0xdea15f1f	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3167eca	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0xe8f13739	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xe9c1e317	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0xee42db3c	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0xee9e2a86	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xf56cc147	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xf9ac63ed	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xfa83da73	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x27dccdc7	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x2d0f99e5	print_ssid
++EXPORT_SYMBOL net/wireless/lib80211 0x5788b538	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x59bcc561	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x5ab6723b	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xb72b3ee7	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xf94d4ec8	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1045b899	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x62dc1b85	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xbde99112	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xccce5f38	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x3a57f235	snd_seq_autoload_unlock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x43311ec6	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x85ad9ebb	snd_seq_device_register_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xb90668b2	snd_seq_autoload_lock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xc622fb29	snd_seq_device_unregister_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x127b30fb	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x1cdc0812	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x59eb74ae	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x8102ed2f	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb11ba32d	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb2c7f684	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xea0e5748	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xed42580b	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x20750256	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0x64820d10	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x0880e2ec	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x43e97ad1	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x442773f0	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x62fb8705	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x66dbc8a1	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x688698f3	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x712404ff	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x7925a1a8	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8f30e36a	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xaa25e8cf	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb4c3aa29	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb53f15fc	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc9e0d3f9	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd141eebd	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xdf235a45	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf10bd443	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xfed0cd3d	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xefdd86f3	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3f14ae99	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x3fd18785	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x5872e04b	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x639cd5c9	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x71f7f311	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x76a3171a	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x84f87b0b	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xc968370a	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xcdfadf18	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x1b010ca4	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x480a44d0	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x48916a41	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x53613366	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8a013536	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xce1e9f51	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xe925e408	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xed4c715c	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xfe4b39d5	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2b872177	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3405ff3f	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3d63fb38	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4b00fcce	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5216cb96	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5a3248f7	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5a5e8c78	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5b96787c	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x5be4e473	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x627efa5b	amdtp_out_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x6a66482a	fw_iso_resources_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x746bc53d	amdtp_out_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x825b7bf1	amdtp_out_stream_set_pcm_format
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x83bd9936	amdtp_out_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x9fc8e5ce	amdtp_out_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa335ba04	amdtp_out_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa87e73f9	amdtp_out_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbbd20787	amdtp_out_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc699d52f	amdtp_out_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc7a87d80	amdtp_out_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc977c826	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xda672e00	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf50ba2b9	amdtp_out_stream_set_rate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xf65ba9a8	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xfc765743	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xff29b894	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x3b541e58	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x5d17e278	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x8949b99b	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xc86ae910	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xcc1cd88c	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xdc7effda	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x83e6c095	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x98cea80e	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xa89aca15	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xc24de98f	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x35d7bb89	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0xa430326a	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x18a3bf18	snd_tea575x_init
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0xb7b0e842	snd_tea575x_set_freq
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0xf077ea77	snd_tea575x_exit
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x181561c4	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x638469b9	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x7758b5b5	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x9cf88541	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xa8bf80e2	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x0311c0c5	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x5e21bfc9	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x612082d3	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xa1961c76	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xb6df6bfa	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xe462dd70	snd_i2c_device_create
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x12d5fe70	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1c310083	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x1d6f52c5	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x2817437e	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x318d9a22	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3328545b	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3827d5c2	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x52a3254b	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x531a7f98	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x563b0aef	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6855d02b	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7c7f3597	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x983ac73d	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xaf85a404	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe8186267	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfb250f10	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfbd6cbd7	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x193676ac	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x3038555c	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x43e565c3	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x54f85cab	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x795d18dd	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8d8f04e7	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xa54e2228	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xdcbd70ab	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xead793da	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x48ce7ec0	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x9cd8be6c	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0xc820923d	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x09e51db7	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0adb92a4	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0b60abd5	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0e64752d	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x2316b0da	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x26c6a89f	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x65cfe4c2	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x70e9794e	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x8fa579ef	oxygen_read8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x98f0cf03	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xaebb17c6	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb9b60bf8	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc3b2207d	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc412189d	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc6705cf0	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc87f78be	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd85a36e9	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xdc436fb9	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xef507bde	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xfc394280	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x122638ea	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x24baca02	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x43eafe5e	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xd2629967	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xef241fdc	snd_trident_free_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x1041d68f	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x2cdb2ee5	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x3336922e	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x354ca6a8	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xe2b29ec2	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0xf2da450d	snd_emux_register
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x3f376670	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x40520b37	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x6b4ddba0	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x9a03a41a	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x9b34e0b0	snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xbcf6cfab	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xdb7fe816	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xfeac0f4c	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x27c9f025	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x35c95b1b	dm_mem_cache_client_create
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x6543a23f	dm_mem_cache_alloc
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x86e5acf9	dm_mem_cache_grow
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x920a7a41	dm_message_parse
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xa43471b6	dm_mem_cache_shrink
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xd55b290c	dm_mem_cache_client_destroy
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xe9d6535b	dm_mem_cache_free
++EXPORT_SYMBOL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2776a3e5	lib_ring_buffer_nesting
++EXPORT_SYMBOL vmlinux 0x00000000	softirq_work_list
++EXPORT_SYMBOL vmlinux 0x001635dd	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x001ee95a	imx_ssi_fiq_base
++EXPORT_SYMBOL vmlinux 0x002a14a8	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x002e1d87	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x003b349e	input_reset_device
++EXPORT_SYMBOL vmlinux 0x003dc7fe	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x005b4bd1	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x005bc06e	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x006818a5	kobject_put
++EXPORT_SYMBOL vmlinux 0x00801678	flush_scheduled_work
++EXPORT_SYMBOL vmlinux 0x0084e86d	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x00b06bb4	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x00bec7a9	sys_imageblit
++EXPORT_SYMBOL vmlinux 0x00c3fb0b	amba_device_unregister
++EXPORT_SYMBOL vmlinux 0x00cf4a7f	of_get_parent
++EXPORT_SYMBOL vmlinux 0x00e8097b	csum_partial_copy_fromiovecend
++EXPORT_SYMBOL vmlinux 0x00ed39a4	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x01051c89	omap_dss_get_overlay
++EXPORT_SYMBOL vmlinux 0x010c66e0	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x01117d1e	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x01302b97	led_blink_set
++EXPORT_SYMBOL vmlinux 0x01424f59	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x014f1d4f	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x016db9e4	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0x016f46f6	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0x0186e2de	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x01902adf	netpoll_trap
++EXPORT_SYMBOL vmlinux 0x01935416	irq_to_desc
++EXPORT_SYMBOL vmlinux 0x01a3d310	omap_set_dma_channel_mode
++EXPORT_SYMBOL vmlinux 0x01b145f2	__scsi_put_command
++EXPORT_SYMBOL vmlinux 0x01b7fd59	dispc_read_irqstatus
++EXPORT_SYMBOL vmlinux 0x01bc6332	put_disk
++EXPORT_SYMBOL vmlinux 0x01bf8c5a	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x01d2fa66	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x01ea132e	dispc_runtime_put
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x021585f5	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x02196324	__aeabi_idiv
++EXPORT_SYMBOL vmlinux 0x024a89bf	clear_bdi_congested
++EXPORT_SYMBOL vmlinux 0x024bf88f	omap_modify_dma_chain_params
++EXPORT_SYMBOL vmlinux 0x02529fcf	page_readlink
++EXPORT_SYMBOL vmlinux 0x02554884	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x02573b36	omap_disable_dma_irq
++EXPORT_SYMBOL vmlinux 0x025c1e10	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x02628c74	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x027ad418	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x0281fe90	alloc_pci_dev
++EXPORT_SYMBOL vmlinux 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL vmlinux 0x0285ab2f	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x02872748	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x02a13a85	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02a9e655	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x02caa4da	journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x02d2cb1b	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x02d3a922	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x02e8f034	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02ef742b	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x03026722	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x031220c8	dm_get_device
++EXPORT_SYMBOL vmlinux 0x031947af	bio_copy_data
++EXPORT_SYMBOL vmlinux 0x032fd0ad	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x0334795d	icst307_s2div
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x0335ee13	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x033a65a5	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x034d0173	vfs_create
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x03635439	edma_stop
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x036c21e7	get_fs_type
++EXPORT_SYMBOL vmlinux 0x036ef4e6	wait_on_sync_kiocb
++EXPORT_SYMBOL vmlinux 0x03757c9b	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03851074	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0x0385ec94	skb_copy_and_csum_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x038c3eab	dpi_check_timings
++EXPORT_SYMBOL vmlinux 0x039a2514	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x03a1b51d	do_SAK
++EXPORT_SYMBOL vmlinux 0x03ba39b0	v7_flush_user_cache_all
++EXPORT_SYMBOL vmlinux 0x03bd889d	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x03c06156	bitmap_fold
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x041ec771	snd_timer_pause
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x046c1f16	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x0499c899	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL vmlinux 0x04cf740e	thaw_super
++EXPORT_SYMBOL vmlinux 0x04d61bbc	load_nls_default
++EXPORT_SYMBOL vmlinux 0x04e66417	inet6_getname
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04fa3324	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x04fad493	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x0501d7af	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x052ce6d9	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x054434d6	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x056ee730	ipv6_hash_secret
++EXPORT_SYMBOL vmlinux 0x05702269	journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x057ce975	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0x0593a99b	init_timer_key
++EXPORT_SYMBOL vmlinux 0x0597adad	simple_empty
++EXPORT_SYMBOL vmlinux 0x05a0c034	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x05ad2e44	journal_abort
++EXPORT_SYMBOL vmlinux 0x05ae0db8	snd_ctl_remove
++EXPORT_SYMBOL vmlinux 0x05cc2351	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0x05e9a71f	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x06048476	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x060493a5	fget_raw
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x063bd52b	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x065d09ab	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x06607f92	dss_feat_get_supported_outputs
++EXPORT_SYMBOL vmlinux 0x06718ba4	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x06783434	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x067add76	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0700c02b	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0x07039554	__free_pages
++EXPORT_SYMBOL vmlinux 0x0715769e	vga_get
++EXPORT_SYMBOL vmlinux 0x071b7eea	irq_stat
++EXPORT_SYMBOL vmlinux 0x071fcafc	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x0723cf4a	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0x0757ccaf	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x076f2229	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x07732086	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x079280dc	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x0799aca4	local_bh_enable
++EXPORT_SYMBOL vmlinux 0x079bf868	tcp_close
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07bd56f5	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07cf9099	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x07e48aba	audit_log
++EXPORT_SYMBOL vmlinux 0x080839af	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x081f3afb	complete_all
++EXPORT_SYMBOL vmlinux 0x08216276	kobject_get
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x0839687c	find_lock_page
++EXPORT_SYMBOL vmlinux 0x083c2cbe	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x0849d579	genl_unregister_mc_group
++EXPORT_SYMBOL vmlinux 0x0850a6e1	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x08750c06	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x088a8652	km_state_expired
++EXPORT_SYMBOL vmlinux 0x08923a78	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x08a89c93	__nla_put
++EXPORT_SYMBOL vmlinux 0x08c01c89	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0x08cb52ba	omapdss_default_get_recommended_bpp
++EXPORT_SYMBOL vmlinux 0x08da017d	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x08f45895	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x090fe94f	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x092e94b1	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0x0937817b	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x096a35c4	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x096e28ac	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x0971b7b0	registered_fb
++EXPORT_SYMBOL vmlinux 0x0978be30	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x09790fc7	unregister_exec_domain
++EXPORT_SYMBOL vmlinux 0x097d68e2	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0x0985b4b1	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09a33d9a	tty_lock
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cf1b46	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x09d2ed43	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09e124f6	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x09e9d2fc	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x09fff7aa	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x0a0786de	udplite_table
++EXPORT_SYMBOL vmlinux 0x0a0b585a	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0x0a2487e0	unblock_all_signals
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a64a794	mem_cgroup_subsys
++EXPORT_SYMBOL vmlinux 0x0a68d534	inet_getname
++EXPORT_SYMBOL vmlinux 0x0a741aba	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x0a85adc6	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x0a93695f	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x0a958ed4	down_write
++EXPORT_SYMBOL vmlinux 0x0aa13d05	__raw_readsw
++EXPORT_SYMBOL vmlinux 0x0aa58001	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x0ac10321	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x0acb1a3c	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0adc0883	arp_send
++EXPORT_SYMBOL vmlinux 0x0adfab73	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b56117f	of_find_node_by_path
++EXPORT_SYMBOL vmlinux 0x0b65319f	dev_crit
++EXPORT_SYMBOL vmlinux 0x0b69008a	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b75ff03	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x0b7d85a2	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bdbc994	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x0c1acf33	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0x0c20efd2	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0x0c2fd264	get_super
++EXPORT_SYMBOL vmlinux 0x0c3f4469	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c65e73c	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0x0c7289ad	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x0c8a64c4	amba_request_regions
++EXPORT_SYMBOL vmlinux 0x0c8c9e99	scsi_show_extd_sense
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca0d11d	nf_log_unset
++EXPORT_SYMBOL vmlinux 0x0ca54fee	_test_and_set_bit
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0ccf4228	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x0cd926ea	alloc_disk
++EXPORT_SYMBOL vmlinux 0x0cdd158d	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x0ce22779	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x0cfefe1e	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x0d0c7ae5	__find_get_block
++EXPORT_SYMBOL vmlinux 0x0d17a7a5	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x0d332092	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x0d3f57a2	_find_next_bit_le
++EXPORT_SYMBOL vmlinux 0x0d42aa3f	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x0d4d7a32	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d5b602d	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x0d79fbbc	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x0d890af8	blk_put_request
++EXPORT_SYMBOL vmlinux 0x0d8950dc	__neigh_create
++EXPORT_SYMBOL vmlinux 0x0d998afb	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da90784	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x0db79834	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x0dc69836	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0x0dc8cef4	snd_timer_continue
++EXPORT_SYMBOL vmlinux 0x0e0585ed	skb_insert
++EXPORT_SYMBOL vmlinux 0x0e0839d1	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x0e2ebd52	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x0e360650	contig_page_data
++EXPORT_SYMBOL vmlinux 0x0e5bc3ae	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x0e65a80f	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e973911	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x0e9b4dfb	init_buffer
++EXPORT_SYMBOL vmlinux 0x0e9e1371	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x0ea1bf8b	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x0eb04074	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x0ec5337d	do_splice_from
++EXPORT_SYMBOL vmlinux 0x0edbc486	proc_create_data
++EXPORT_SYMBOL vmlinux 0x0eeab47b	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x0ef15fe0	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x0ef5f227	blk_bio_map_sg
++EXPORT_SYMBOL vmlinux 0x0ef9e370	lease_modify
++EXPORT_SYMBOL vmlinux 0x0f125b28	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x0f1ca831	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x0f36b889	dss_mgr_start_update
++EXPORT_SYMBOL vmlinux 0x0f3a3932	path_is_under
++EXPORT_SYMBOL vmlinux 0x0f4bb3b6	get_io_context
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f566113	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x0f6659ea	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x0f7063a4	build_skb
++EXPORT_SYMBOL vmlinux 0x0fa2a45e	__memzero
++EXPORT_SYMBOL vmlinux 0x0fa2e836	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fc1c7f1	__skb_get_rxhash
++EXPORT_SYMBOL vmlinux 0x0fcbecf0	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x0ff178f6	__aeabi_idivmod
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x1000d13e	tcf_hash_lookup
++EXPORT_SYMBOL vmlinux 0x100dd491	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0x10245ae8	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x102fa771	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x103243e5	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x105596f4	vc_cons
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x106fb213	cdev_init
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x1075df39	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x107a6696	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x107dcd8f	tcp_connect
++EXPORT_SYMBOL vmlinux 0x1088ddd7	would_dump
++EXPORT_SYMBOL vmlinux 0x10bf86d8	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x10c0d82f	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x111385bd	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x11267875	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0x112748bd	omap_vrfb_adjust_size
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x11743563	bdput
++EXPORT_SYMBOL vmlinux 0x118b11bf	ata_print_version
++EXPORT_SYMBOL vmlinux 0x119b50e7	elf_check_arch
++EXPORT_SYMBOL vmlinux 0x11bb6a27	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x11c9185c	of_iomap
++EXPORT_SYMBOL vmlinux 0x11cace80	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x11e2ec12	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x11fa978f	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x122043a8	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x1223f0e7	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x122dbcbf	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x126ae742	install_exec_creds
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12aa8a3c	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0x12c135ed	i2c_transfer
++EXPORT_SYMBOL vmlinux 0x12c9e3dc	napi_complete
++EXPORT_SYMBOL vmlinux 0x12d57c6f	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12e593a2	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL vmlinux 0x12e5d30d	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x12ef63d3	pci_request_region
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x133cc9ba	setattr_copy
++EXPORT_SYMBOL vmlinux 0x1340ff85	cdev_alloc
++EXPORT_SYMBOL vmlinux 0x136f0a31	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x1388044a	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x13b715e2	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x14027b8b	bio_endio
++EXPORT_SYMBOL vmlinux 0x1403b0fe	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x14099638	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x145bd7f6	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x145decd5	account_page_writeback
++EXPORT_SYMBOL vmlinux 0x1468e29c	inet_listen
++EXPORT_SYMBOL vmlinux 0x1480c1d4	qdisc_tree_decrease_qlen
++EXPORT_SYMBOL vmlinux 0x14b9664b	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x14c507df	devm_clk_get
++EXPORT_SYMBOL vmlinux 0x14d4a9c5	_change_bit
++EXPORT_SYMBOL vmlinux 0x15017f9a	lock_may_read
++EXPORT_SYMBOL vmlinux 0x15092ba7	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x151816d2	skb_find_text
++EXPORT_SYMBOL vmlinux 0x154828c9	phy_stop
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1550ba35	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x1551dc51	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x15692c87	param_ops_int
++EXPORT_SYMBOL vmlinux 0x1590770a	scsi_put_command
++EXPORT_SYMBOL vmlinux 0x1594905a	kunmap_high
++EXPORT_SYMBOL vmlinux 0x15b9125f	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x15bfb333	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x15dfea68	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x15ef013e	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x15f571ec	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x160d8bc9	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x162849ac	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x162ccc0c	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1645ffb6	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x1648a71a	dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x1687a791	generic_file_splice_write
++EXPORT_SYMBOL vmlinux 0x168bfbef	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x16b6c574	register_nls
++EXPORT_SYMBOL vmlinux 0x16d37e2d	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x16f9b51b	generic_make_request
++EXPORT_SYMBOL vmlinux 0x170dceb3	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x17151652	pci_select_bars
++EXPORT_SYMBOL vmlinux 0x17336d5b	dss_mgr_disable
++EXPORT_SYMBOL vmlinux 0x173ba175	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x17506286	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x1757198b	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x1768dc42	sock_create_lite
++EXPORT_SYMBOL vmlinux 0x177445ef	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x17a142df	__copy_from_user
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b2bbf4	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x17b3c2e2	proto_unregister
++EXPORT_SYMBOL vmlinux 0x17d101c1	__brelse
++EXPORT_SYMBOL vmlinux 0x17d13dfe	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0x17db71b0	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x17e84236	journal_dirty_data
++EXPORT_SYMBOL vmlinux 0x18065d2f	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x1826f089	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x183d4777	snd_pcm_period_elapsed
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x18413028	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x18418798	fib_default_rule_pref
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184e6c85	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x1855ca88	pci_enable_ido
++EXPORT_SYMBOL vmlinux 0x186ff0b6	ppp_input
++EXPORT_SYMBOL vmlinux 0x18732b6d	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x188af8e2	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL vmlinux 0x188d61e4	xfrm_cfg_mutex
++EXPORT_SYMBOL vmlinux 0x188e71a9	scsi_register
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18a72b1c	scsi_prep_state_check
++EXPORT_SYMBOL vmlinux 0x18bd76a4	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x18c2227f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x18f27b9d	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x1903a77d	snd_pcm_lib_write
++EXPORT_SYMBOL vmlinux 0x191039d8	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x191797bd	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x1949b7bb	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x1957cf53	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x195a517a	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0x195c4482	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0x19610e1f	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x197623d3	follow_pfn
++EXPORT_SYMBOL vmlinux 0x1976aa06	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x197dc3b3	omap_set_dma_src_burst_mode
++EXPORT_SYMBOL vmlinux 0x198debf1	__locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a04807	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19f5809b	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x1a20c540	omap_vrfb_supported
++EXPORT_SYMBOL vmlinux 0x1a4740f6	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x1a65f4ad	__arm_ioremap_pfn
++EXPORT_SYMBOL vmlinux 0x1a6da9d4	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x1a8c96af	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0x1a92f7aa	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x1a9b6be4	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x1ac4e300	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x1ace138d	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0x1ad1f2e7	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0x1ae4ac0d	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x1ae77c2c	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x1aea6657	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x1af6a6e2	tty_register_device
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0ac272	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x1b19a7b5	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x1b5760c1	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x1b5c3012	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b6f4e46	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x1b7226eb	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b865f52	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x1b86677c	default_llseek
++EXPORT_SYMBOL vmlinux 0x1b8a47e1	snd_dma_free_pages
++EXPORT_SYMBOL vmlinux 0x1b9e0ff1	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x1ba8faab	tty_port_put
++EXPORT_SYMBOL vmlinux 0x1bb1018c	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x1bca1718	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x1bd15d11	skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x1c3d5023	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x1c5e3878	icst525_idx2s
++EXPORT_SYMBOL vmlinux 0x1c64eed0	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x1c673572	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x1ca62b8e	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x1caa793f	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x1cb5f201	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x1cbaba36	nand_scan_ident
++EXPORT_SYMBOL vmlinux 0x1cd80216	nla_reserve
++EXPORT_SYMBOL vmlinux 0x1cfb04fa	finish_wait
++EXPORT_SYMBOL vmlinux 0x1cff18a5	d_path
++EXPORT_SYMBOL vmlinux 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL vmlinux 0x1d13423f	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x1d2cc152	genl_unregister_ops
++EXPORT_SYMBOL vmlinux 0x1d3e8474	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x1d5bfa70	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x1d93619b	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0x1d947ca0	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x1db7dc40	pgprot_kernel
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc5199d	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dfaa67d	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0fb206	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e4e3708	input_close_device
++EXPORT_SYMBOL vmlinux 0x1e5912ef	scsi_device_put
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e7e073b	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0x1e91c4ae	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0x1e935440	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea06663	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0x1ea51ba2	dev_deactivate
++EXPORT_SYMBOL vmlinux 0x1ec1cf60	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x1ec3bed9	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0x1ec4eb34	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x1ee962ca	amba_find_device
++EXPORT_SYMBOL vmlinux 0x1eeb848e	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x1ef1cc32	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x1f189046	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x1f27fb19	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x1f2e0311	do_truncate
++EXPORT_SYMBOL vmlinux 0x1f46ce62	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x1f478ee2	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x1f5af939	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x1f6441c2	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x1f655905	cpu_user
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f80479b	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x1f919386	tcp_prot
++EXPORT_SYMBOL vmlinux 0x1faa7edb	snd_ctl_register_ioctl
++EXPORT_SYMBOL vmlinux 0x1fab5905	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc753cc	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0x1fcf4d4b	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fd9d1f6	omapdss_unregister_output
++EXPORT_SYMBOL vmlinux 0x1fe15c7c	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x1fe568c2	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x201ef2dc	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x2021894d	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x20421305	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x204363ca	mnt_pin
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x2056bff3	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x205ec8de	omap_dispc_register_isr
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x208540e5	tc_classify_compat
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20a86b3f	of_get_pci_address
++EXPORT_SYMBOL vmlinux 0x20adbd54	map_destroy
++EXPORT_SYMBOL vmlinux 0x20b89c00	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x20c37faa	no_llseek
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20df2681	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x20edf14d	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x211331fa	__divsi3
++EXPORT_SYMBOL vmlinux 0x21315700	param_get_bool
++EXPORT_SYMBOL vmlinux 0x215ebd78	bitrev16
++EXPORT_SYMBOL vmlinux 0x216876fa	scsi_calculate_bounce_limit
++EXPORT_SYMBOL vmlinux 0x217dda13	flex_array_get
++EXPORT_SYMBOL vmlinux 0x219ff46e	tty_name
++EXPORT_SYMBOL vmlinux 0x21bfec50	phy_attach
++EXPORT_SYMBOL vmlinux 0x21d17871	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x21d6219c	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x21da8505	noop_fsync
++EXPORT_SYMBOL vmlinux 0x21e757a1	skb_pull
++EXPORT_SYMBOL vmlinux 0x21f2dcf3	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x21fe4354	writeback_in_progress
++EXPORT_SYMBOL vmlinux 0x2208bd9a	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x2220352c	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x222fa684	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x2232a8a5	mempool_free
++EXPORT_SYMBOL vmlinux 0x223514a6	ether_setup
++EXPORT_SYMBOL vmlinux 0x223cc898	omap_vrfb_max_height
++EXPORT_SYMBOL vmlinux 0x224c011d	nand_flash_ids
++EXPORT_SYMBOL vmlinux 0x22523665	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x2256c112	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x225ae2bd	del_gendisk
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22794633	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0x2283029a	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0x22830711	edma_clear_event
++EXPORT_SYMBOL vmlinux 0x22923656	of_device_unregister
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22ba7e83	mnt_unpin
++EXPORT_SYMBOL vmlinux 0x22bbf2cf	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x22e10a4c	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x22e1ae6f	up_read
++EXPORT_SYMBOL vmlinux 0x23108b7a	bio_map_user
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232005ef	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0x23532c4d	ftrace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x235492f3	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x2363a880	snd_pcm_hw_rule_add
++EXPORT_SYMBOL vmlinux 0x236e6e3a	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x2382af35	release_pages
++EXPORT_SYMBOL vmlinux 0x2389db96	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0x2396c0cf	phy_detach
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23e9d891	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0x23f643a2	bdi_register
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x2420782c	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x243355d6	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x2433f26f	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x245205c6	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0x24574b1a	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x24869d12	ilookup5
++EXPORT_SYMBOL vmlinux 0x24a834c5	scsi_allocate_command
++EXPORT_SYMBOL vmlinux 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL vmlinux 0x24b0f90c	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0x24badbba	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x24bb9a54	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x24ceec51	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x24d7b4eb	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x24fe2f0d	security_path_mknod
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x253bdb78	param_get_int
++EXPORT_SYMBOL vmlinux 0x254b2212	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x25540332	inode_sb_list_lock
++EXPORT_SYMBOL vmlinux 0x255d4f5b	proc_symlink
++EXPORT_SYMBOL vmlinux 0x256c1d1d	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x258164ee	omapdss_unregister_display
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x258ca57c	kmap_atomic
++EXPORT_SYMBOL vmlinux 0x2598f655	generic_file_open
++EXPORT_SYMBOL vmlinux 0x25a60d6b	fput
++EXPORT_SYMBOL vmlinux 0x25c677c4	mac_pton
++EXPORT_SYMBOL vmlinux 0x25d30131	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x25dbc61a	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0x25dd29c4	mtd_concat_destroy
++EXPORT_SYMBOL vmlinux 0x25ee1678	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x25f673fc	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x260cf8f8	of_get_property
++EXPORT_SYMBOL vmlinux 0x260f0b03	save_mount_options
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x263d0751	init_special_inode
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x26637b08	__bread
++EXPORT_SYMBOL vmlinux 0x26a7c606	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x26b3d95f	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26c62923	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x26cb2ff0	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x26dd0881	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x26e73d0d	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f0453a	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x26f8c316	omapdss_sdi_set_timings
++EXPORT_SYMBOL vmlinux 0x27181125	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x2727f9a5	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0x2729cc99	snd_ctl_new1
++EXPORT_SYMBOL vmlinux 0x272bcdc7	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0x2739374c	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0x2741c4bc	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x275ef902	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c2197f	param_set_short
++EXPORT_SYMBOL vmlinux 0x27d27868	inet_twsk_deschedule
++EXPORT_SYMBOL vmlinux 0x27d9205d	netdev_info
++EXPORT_SYMBOL vmlinux 0x27e0a2c8	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x27efdd8e	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x28118cb6	__get_user_1
++EXPORT_SYMBOL vmlinux 0x28149cfd	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x2820faf6	dm_put_device
++EXPORT_SYMBOL vmlinux 0x2825e9a4	seq_bitmap
++EXPORT_SYMBOL vmlinux 0x2844c412	__page_symlink
++EXPORT_SYMBOL vmlinux 0x2850ec5e	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x28525389	set_blocksize
++EXPORT_SYMBOL vmlinux 0x287bd97e	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x28a0c867	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28abea1e	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x28bca93d	keyring_search
++EXPORT_SYMBOL vmlinux 0x28d6861d	__vmalloc
++EXPORT_SYMBOL vmlinux 0x28eb7d16	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x28ee6d36	dquot_release
++EXPORT_SYMBOL vmlinux 0x290169db	snd_dma_reserve_buf
++EXPORT_SYMBOL vmlinux 0x290f7705	security_path_rename
++EXPORT_SYMBOL vmlinux 0x29179aee	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0x291d6062	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x29554985	fsl_asoc_get_dma_channel
++EXPORT_SYMBOL vmlinux 0x295a7239	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x295c9381	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0x29663cc5	input_register_handle
++EXPORT_SYMBOL vmlinux 0x296be7dc	seq_write
++EXPORT_SYMBOL vmlinux 0x29b3d28a	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x29baff70	ida_remove
++EXPORT_SYMBOL vmlinux 0x29bbbaa2	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0x29c25d81	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x29d2a2af	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0x29ddd667	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a05a56a	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x2a07bb58	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a31f5f6	inode_permission
++EXPORT_SYMBOL vmlinux 0x2a3748c1	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x2a3aa678	_test_and_clear_bit
++EXPORT_SYMBOL vmlinux 0x2a3e8122	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x2a4fabcf	videomode_to_omap_video_timings
++EXPORT_SYMBOL vmlinux 0x2a53b268	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x2a602e1f	journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x2a6caae2	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x2a6e589e	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x2a797bf1	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x2a79ac13	clkdev_add
++EXPORT_SYMBOL vmlinux 0x2a7cac99	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aa1ad41	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x2ac6193b	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x2ad46faa	mmc_erase
++EXPORT_SYMBOL vmlinux 0x2adbe247	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b12925d	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x2b1daa76	tty_devnum
++EXPORT_SYMBOL vmlinux 0x2b2507b7	snd_timer_new
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b34980f	blkdev_get
++EXPORT_SYMBOL vmlinux 0x2b4d9de7	key_link
++EXPORT_SYMBOL vmlinux 0x2b4e956e	mempool_create
++EXPORT_SYMBOL vmlinux 0x2b690df8	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x2b9d8bee	bdi_init
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bc17cd0	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2be9b93a	scsi_prep_return
++EXPORT_SYMBOL vmlinux 0x2bfeceaa	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2b5867	unregister_nls
++EXPORT_SYMBOL vmlinux 0x2c3301a4	vc_resize
++EXPORT_SYMBOL vmlinux 0x2c4d6aab	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x2c4eeb9f	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x2c4ffb7d	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x2c51f961	__block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x2c637396	igrab
++EXPORT_SYMBOL vmlinux 0x2c70f377	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x2c7831fe	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x2c7a90a2	sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x2c7c8e9a	pcibios_min_mem
++EXPORT_SYMBOL vmlinux 0x2c81ec75	__irq_regs
++EXPORT_SYMBOL vmlinux 0x2c9732f8	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x2c988955	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x2c98f95e	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0x2cce7b27	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0x2ce135d1	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d23c0df	register_filesystem
++EXPORT_SYMBOL vmlinux 0x2d2403a5	tcf_generic_walker
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d5427db	ip_fragment
++EXPORT_SYMBOL vmlinux 0x2d6507b5	_find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0x2d770676	dispc_mgr_go
++EXPORT_SYMBOL vmlinux 0x2d874b35	vfsmount_lock
++EXPORT_SYMBOL vmlinux 0x2d89342a	scsi_show_sense_hdr
++EXPORT_SYMBOL vmlinux 0x2dae5942	dev_get_drvdata
++EXPORT_SYMBOL vmlinux 0x2dbb2a4a	pci_enable_ltr
++EXPORT_SYMBOL vmlinux 0x2dcd10ac	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x2dce29e6	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x2de8d2d4	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x2deda4a1	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0x2df91bdb	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x2dfc2e3a	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2178aa	journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x2e278faf	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e35a8d7	snd_info_free_entry
++EXPORT_SYMBOL vmlinux 0x2e46350c	netif_rx
++EXPORT_SYMBOL vmlinux 0x2e4e1948	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x2e5810c6	__aeabi_unwind_cpp_pr1
++EXPORT_SYMBOL vmlinux 0x2e6ec88d	seq_escape
++EXPORT_SYMBOL vmlinux 0x2e7be112	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2e8c5770	netdev_printk
++EXPORT_SYMBOL vmlinux 0x2e970f9a	set_anon_super
++EXPORT_SYMBOL vmlinux 0x2ebe368a	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ecc2498	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x2ed0f0ff	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x2ed8400f	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x2edce11e	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x2ee119b3	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x2eead940	ip6_route_output
++EXPORT_SYMBOL vmlinux 0x2eeceb42	sk_chk_filter
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f05d330	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x2f286dd0	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x2f3857e2	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2f5460f8	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x2f684697	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x2f6a588e	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x2f745980	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x2f76c0e6	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fc034e2	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x2fd4be6a	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x2fd86910	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x2fe07cd9	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x30142596	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0x3042f713	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x3043d9a2	get_user_pages
++EXPORT_SYMBOL vmlinux 0x30466866	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x304ec72b	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x30536657	d_rehash
++EXPORT_SYMBOL vmlinux 0x3071d548	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x307e0278	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x3082a0b3	dss_feat_get_supported_color_modes
++EXPORT_SYMBOL vmlinux 0x308aad56	omap_vrfb_min_phys_size
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30aa2c93	netdev_has_any_upper_dev
++EXPORT_SYMBOL vmlinux 0x30b601f0	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x30cada8f	radix_tree_next_hole
++EXPORT_SYMBOL vmlinux 0x30da1e5d	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x30e523a1	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30ece2e9	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x3103b804	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x310656ac	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x310a8dc2	vga_client_register
++EXPORT_SYMBOL vmlinux 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x315d6f63	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x316928ea	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x318bf121	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x318cadb1	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x318fa7c1	pcibios_fixup_bus
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31ab0e51	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31d8f0b9	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x31d90ee1	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x322f48d4	abx500_dump_all_banks
++EXPORT_SYMBOL vmlinux 0x32374ad0	revert_creds
++EXPORT_SYMBOL vmlinux 0x3255972d	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x3274b08e	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x327bf883	of_can_translate_address
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x32bb04c8	from_kqid
++EXPORT_SYMBOL vmlinux 0x32c41306	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x32c9619e	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x32cf04f0	phy_scan_fixups
++EXPORT_SYMBOL vmlinux 0x33115d12	snd_timer_resolution
++EXPORT_SYMBOL vmlinux 0x3322da16	unload_nls
++EXPORT_SYMBOL vmlinux 0x3330a47d	gen_pool_free
++EXPORT_SYMBOL vmlinux 0x33488f53	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0x3360f907	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x336f14f7	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x337cce46	put_cmsg
++EXPORT_SYMBOL vmlinux 0x339dafb5	genl_register_mc_group
++EXPORT_SYMBOL vmlinux 0x33a48d9d	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x33b2f652	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33e4b8f9	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x33e93c2e	blk_end_request
++EXPORT_SYMBOL vmlinux 0x33f5aed6	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x34030d55	file_update_time
++EXPORT_SYMBOL vmlinux 0x34044013	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x34184afe	current_kernel_time
++EXPORT_SYMBOL vmlinux 0x341dbfa3	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x34269290	omapdss_dpi_set_timings
++EXPORT_SYMBOL vmlinux 0x342a4b48	snd_card_set_id
++EXPORT_SYMBOL vmlinux 0x342fa995	neigh_update
++EXPORT_SYMBOL vmlinux 0x342fc101	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x343fae52	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b8d45c	md_write_start
++EXPORT_SYMBOL vmlinux 0x34ca9cbe	bdgrab
++EXPORT_SYMBOL vmlinux 0x34eca00d	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x35020c35	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x3507a132	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x352741a5	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL vmlinux 0x353e3fa5	__get_user_4
++EXPORT_SYMBOL vmlinux 0x354cc16c	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x3583f49b	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x35856161	give_up_console
++EXPORT_SYMBOL vmlinux 0x359600c2	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x3596e2cb	done_path_create
++EXPORT_SYMBOL vmlinux 0x35b6b772	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x35c5ae50	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x35cc3919	snd_cards
++EXPORT_SYMBOL vmlinux 0x35d8676e	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x35da4c9f	kmap
++EXPORT_SYMBOL vmlinux 0x35edef21	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x3602ee02	tcp_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360dfea3	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0x3612c10f	tmio_core_mmc_enable
++EXPORT_SYMBOL vmlinux 0x3637082b	pm860x_page_bulk_write
++EXPORT_SYMBOL vmlinux 0x3637da1b	dst_alloc
++EXPORT_SYMBOL vmlinux 0x3638a443	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x3642ca58	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0x36448a86	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x36484333	snd_dma_alloc_pages
++EXPORT_SYMBOL vmlinux 0x364ac784	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x365a320d	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0x3671328d	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x36a5bdf2	bio_put
++EXPORT_SYMBOL vmlinux 0x36b7e462	journal_start
++EXPORT_SYMBOL vmlinux 0x36d7b11a	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x36e360e3	__hw_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x36ebfe3c	__dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x36f9cd94	rcu_is_cpu_idle
++EXPORT_SYMBOL vmlinux 0x3702c013	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x371982eb	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x37277ed0	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x377de9ff	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0x3781b6e5	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x378ced6a	cdev_del
++EXPORT_SYMBOL vmlinux 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL vmlinux 0x37adf6e0	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x37b777df	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x37b85c66	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37e67901	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37f3a1e7	blk_make_request
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x381144a9	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381d250e	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0x381fac75	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x382b5111	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x382b5b67	abort_creds
++EXPORT_SYMBOL vmlinux 0x383a29f7	d_move
++EXPORT_SYMBOL vmlinux 0x3850b3bc	splice_from_pipe_feed
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388f9128	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x389612d1	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0x389acf0c	gpmc_configure
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38aaed63	phy_device_create
++EXPORT_SYMBOL vmlinux 0x38ae8b71	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x38c97d50	idr_get_next
++EXPORT_SYMBOL vmlinux 0x38cffe68	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x38dd16f3	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x38de97c6	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x39168495	inet6_protos
++EXPORT_SYMBOL vmlinux 0x3924dd56	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x3949a0de	journal_load
++EXPORT_SYMBOL vmlinux 0x394d509d	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x395db738	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x395e8620	ns_capable
++EXPORT_SYMBOL vmlinux 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL vmlinux 0x39b8f576	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL vmlinux 0x39ccb2ce	submit_bio
++EXPORT_SYMBOL vmlinux 0x39d7e144	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x39db26f0	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x3a0b9195	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x3a116425	snd_pcm_mmap_data
++EXPORT_SYMBOL vmlinux 0x3a1a3714	__genl_register_family_with_ops
++EXPORT_SYMBOL vmlinux 0x3a6a88ab	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0x3a7abebe	omapdss_find_mgr_from_display
++EXPORT_SYMBOL vmlinux 0x3a801064	dquot_disable
++EXPORT_SYMBOL vmlinux 0x3a8788df	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x3a8abfe5	omap_dss_put_device
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3abbef05	dev_get_by_flags_rcu
++EXPORT_SYMBOL vmlinux 0x3acebc12	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x3ad5a4be	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x3aead053	skb_pad
++EXPORT_SYMBOL vmlinux 0x3aeae0bf	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0x3af38fa7	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x3af6c765	of_match_device
++EXPORT_SYMBOL vmlinux 0x3af7eaae	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x3b002fed	clear_inode
++EXPORT_SYMBOL vmlinux 0x3b08e1cd	dss_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x3b3ba5e5	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x3b4ca895	snd_timer_stop
++EXPORT_SYMBOL vmlinux 0x3b543e79	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x3b7066cd	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x3b798491	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x3b917f6c	tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL vmlinux 0x3b95996e	single_open
++EXPORT_SYMBOL vmlinux 0x3bbf46ea	vga_base
++EXPORT_SYMBOL vmlinux 0x3bd1b1f6	msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x3bd1c5c0	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x3bd6becd	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x3bd79fb7	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x3bdff6f5	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x3be173ee	snd_pcm_set_ops
++EXPORT_SYMBOL vmlinux 0x3bedcb3a	vlan_untag
++EXPORT_SYMBOL vmlinux 0x3bee6ac9	send_sig_info
++EXPORT_SYMBOL vmlinux 0x3bef03b9	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x3c1fe570	datagram_poll
++EXPORT_SYMBOL vmlinux 0x3c2bb8c6	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x3c3d80b6	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x3c4ce639	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x3c6673d9	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0x3c6aa9ba	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x3c79c328	skb_unlink
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c86218e	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x3c909240	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x3c9d1211	string_get_size
++EXPORT_SYMBOL vmlinux 0x3c9de699	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x3caaec80	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x3cb41057	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x3cb48515	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x3cb688c8	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x3cbffc8d	sk_release_kernel
++EXPORT_SYMBOL vmlinux 0x3cc5092f	netpoll_rx_disable
++EXPORT_SYMBOL vmlinux 0x3cc66d09	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3d17c901	generic_write_end
++EXPORT_SYMBOL vmlinux 0x3d331c00	log_start_commit
++EXPORT_SYMBOL vmlinux 0x3d3c540f	elf_hwcap
++EXPORT_SYMBOL vmlinux 0x3d41904f	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x3d5d4d55	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x3d8abc70	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x3d9676b0	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x3da3ec39	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x3db19310	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x3dc06b27	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x3dc10581	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3df2bd9a	tcp_syn_flood_action
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3dfe8112	phy_connect
++EXPORT_SYMBOL vmlinux 0x3e05ef55	of_i2c_register_devices
++EXPORT_SYMBOL vmlinux 0x3e1777ff	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x3e1ab506	file_remove_suid
++EXPORT_SYMBOL vmlinux 0x3e5226b2	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x3e741cd2	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x3e79f90f	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x3e854b5a	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x3e884f4b	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3ea309ac	filemap_fault
++EXPORT_SYMBOL vmlinux 0x3eae292f	param_set_byte
++EXPORT_SYMBOL vmlinux 0x3eaf291d	param_get_string
++EXPORT_SYMBOL vmlinux 0x3ec16c3b	in_group_p
++EXPORT_SYMBOL vmlinux 0x3ec6a57b	nf_log_register
++EXPORT_SYMBOL vmlinux 0x3ed63055	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0x3ef6c7ee	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f466b9b	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x3f477693	dev_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x3f564ecc	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x3f5b67d5	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3f64456e	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x3f874733	seq_path
++EXPORT_SYMBOL vmlinux 0x3f9b3a85	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x3fab065e	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0x3fab3ca9	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x3fd55724	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x3fdbfc26	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL vmlinux 0x3ff2cc76	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x3ff62317	local_bh_disable
++EXPORT_SYMBOL vmlinux 0x400d24b6	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x4025c033	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x4029af5d	of_dev_get
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x40547e11	snd_card_free
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x4070b0c3	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x407136b1	__put_user_8
++EXPORT_SYMBOL vmlinux 0x407a3275	omap_start_dma
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40ca0726	free_task
++EXPORT_SYMBOL vmlinux 0x40ce485b	mempool_resize
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d29fc8	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x40e3cb19	dispc_ovl_check
++EXPORT_SYMBOL vmlinux 0x40f07981	__ashldi3
++EXPORT_SYMBOL vmlinux 0x40f120e2	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x410061f7	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x4127e367	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x412ae7f1	__lock_page
++EXPORT_SYMBOL vmlinux 0x4145945a	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x417fe4a2	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x41829485	release_firmware
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x41a8df5e	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x41bd3e4b	unlock_rename
++EXPORT_SYMBOL vmlinux 0x41bd65d1	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x41c96110	snd_ctl_find_numid
++EXPORT_SYMBOL vmlinux 0x41cdc90a	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x41d8629b	inet_ioctl
++EXPORT_SYMBOL vmlinux 0x41e29e29	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x41f4ad42	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x41f9f974	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x4211599c	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x4211c3c1	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x42231e0b	input_open_device
++EXPORT_SYMBOL vmlinux 0x423465dc	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x42395dc9	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x4253edb1	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x4280162a	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x428f24f9	posix_acl_create
++EXPORT_SYMBOL vmlinux 0x42977ad4	__hw_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x4298b775	v7_flush_kern_cache_all
++EXPORT_SYMBOL vmlinux 0x429f2cc8	nand_unlock
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42aa9963	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x42ab959c	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x42af4326	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x42b424f5	pci_iomap
++EXPORT_SYMBOL vmlinux 0x42cc068f	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0x42d5d05f	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x42e5f661	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x42e60548	d_validate
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x4310b1aa	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x4317de5d	vfs_writev
++EXPORT_SYMBOL vmlinux 0x431ae3a9	seq_puts
++EXPORT_SYMBOL vmlinux 0x43277618	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x4342d012	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43632d7d	of_find_property
++EXPORT_SYMBOL vmlinux 0x437dba7d	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x4388ad83	sget
++EXPORT_SYMBOL vmlinux 0x43a01c83	arp_create
++EXPORT_SYMBOL vmlinux 0x43a22d9f	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x43aaebc4	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x43b20e8b	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x43b51957	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x43c34d52	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x43c4c596	omap_dss_find_device
++EXPORT_SYMBOL vmlinux 0x43ca8120	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x43e2d8b3	dentry_open
++EXPORT_SYMBOL vmlinux 0x43e4fc38	pfifo_fast_ops
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x4407fe5f	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x44149575	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x44198671	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0x441ed159	omap_get_dma_src_pos
++EXPORT_SYMBOL vmlinux 0x442495c9	tmio_core_mmc_resume
++EXPORT_SYMBOL vmlinux 0x4425e68a	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x443dce28	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x44643b93	__aeabi_lmul
++EXPORT_SYMBOL vmlinux 0x44667831	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x446c959d	proc_set_size
++EXPORT_SYMBOL vmlinux 0x4470a79b	param_ops_long
++EXPORT_SYMBOL vmlinux 0x44b86c25	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x44c565c0	twl6040_power
++EXPORT_SYMBOL vmlinux 0x44d7d9b3	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x44da5d0f	__csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x44dd3d8d	completion_done
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f5e8b5	of_allnodes
++EXPORT_SYMBOL vmlinux 0x44fb6dbc	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x45118815	dev_notice
++EXPORT_SYMBOL vmlinux 0x45146d6b	d_genocide
++EXPORT_SYMBOL vmlinux 0x45335749	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x453c0d51	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL vmlinux 0x455293f6	down_read
++EXPORT_SYMBOL vmlinux 0x455e80cd	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x457cf10b	dquot_enable
++EXPORT_SYMBOL vmlinux 0x4580399f	lock_may_write
++EXPORT_SYMBOL vmlinux 0x458ddd51	udp_prot
++EXPORT_SYMBOL vmlinux 0x45bda0d5	system_serial_low
++EXPORT_SYMBOL vmlinux 0x45c61a00	filemap_flush
++EXPORT_SYMBOL vmlinux 0x45c8cd86	ifla_policy
++EXPORT_SYMBOL vmlinux 0x45d28fbb	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x45f7990c	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x4614047e	read_cache_page_async
++EXPORT_SYMBOL vmlinux 0x4623d0fb	snd_timer_global_new
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x4634772a	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x46429b7c	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x46566457	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x465757c3	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46608fa0	getnstimeofday
++EXPORT_SYMBOL vmlinux 0x46696a03	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0x467ae822	add_disk
++EXPORT_SYMBOL vmlinux 0x468d5ffc	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x46a0859b	scsi_nonblockable_ioctl
++EXPORT_SYMBOL vmlinux 0x46b9e93f	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x46d3b28c	__div0
++EXPORT_SYMBOL vmlinux 0x46d9449a	generic_pipe_buf_unmap
++EXPORT_SYMBOL vmlinux 0x46efcee5	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x47350455	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x4745bd6d	skb_copy_datagram_from_iovec
++EXPORT_SYMBOL vmlinux 0x475100c2	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x475ab9c0	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x47659262	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x478d37ad	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0x478f2405	get_gendisk
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x47944698	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x47b3f862	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0x47b6a10f	ftrace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x47bb6f91	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x47e70229	v7_flush_user_cache_range
++EXPORT_SYMBOL vmlinux 0x47f3561c	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x47f757de	elf_platform
++EXPORT_SYMBOL vmlinux 0x480c41c0	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x481ce6ce	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x48437109	snd_timer_global_register
++EXPORT_SYMBOL vmlinux 0x4845c423	param_array_ops
++EXPORT_SYMBOL vmlinux 0x484b3240	pci_choose_state
++EXPORT_SYMBOL vmlinux 0x4851a851	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x48579e29	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x485e8303	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x487921ae	dget_parent
++EXPORT_SYMBOL vmlinux 0x487d9343	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x4881d505	idr_for_each
++EXPORT_SYMBOL vmlinux 0x48853995	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x488882e7	downgrade_write
++EXPORT_SYMBOL vmlinux 0x48905c0f	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x48a5b067	__machine_arch_type
++EXPORT_SYMBOL vmlinux 0x48c6db53	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x48de34d3	splice_from_pipe_end
++EXPORT_SYMBOL vmlinux 0x48f0421a	page_put_link
++EXPORT_SYMBOL vmlinux 0x4901f3cd	bio_init
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x4955e4c4	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x495f79cc	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49910351	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0x499cb58c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x49a76cb3	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x49ae1dd7	sock_no_listen
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49dcfb27	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x49ebacbd	_clear_bit
++EXPORT_SYMBOL vmlinux 0x49edee44	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL vmlinux 0x49fc1552	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x49fedc2b	proto_register
++EXPORT_SYMBOL vmlinux 0x4a1bbae7	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x4a2b0376	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x4a30dc95	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x4a358252	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x4a39cfbe	invalidate_partition
++EXPORT_SYMBOL vmlinux 0x4a39e5a1	omap_set_dma_src_params
++EXPORT_SYMBOL vmlinux 0x4a3e4298	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL vmlinux 0x4a57b339	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x4a7fb243	percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x4a941ee0	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acbb36a	genl_notify
++EXPORT_SYMBOL vmlinux 0x4ad43ec7	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0x4ae6ad7a	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0x4aef9ca3	snd_pcm_hw_param_last
++EXPORT_SYMBOL vmlinux 0x4af3cfbe	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x4afa16b4	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b015768	snd_iprintf
++EXPORT_SYMBOL vmlinux 0x4b040f90	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0x4b04b975	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x4b16f605	elv_abort_queue
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b2f264b	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x4b34fbf5	block_all_signals
++EXPORT_SYMBOL vmlinux 0x4b3fae6d	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b7e4be5	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x4b8685ad	current_fs_time
++EXPORT_SYMBOL vmlinux 0x4b8d73d0	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x4b9efc48	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x4badd391	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x4bb4c812	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x4be7fb63	up
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4bffc1a1	vm_map_ram
++EXPORT_SYMBOL vmlinux 0x4c0745d4	neigh_compat_output
++EXPORT_SYMBOL vmlinux 0x4c1182cb	bitmap_scnprintf
++EXPORT_SYMBOL vmlinux 0x4c118436	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c33081d	omapdss_compat_uninit
++EXPORT_SYMBOL vmlinux 0x4c414405	journal_clear_err
++EXPORT_SYMBOL vmlinux 0x4c483fe4	scsi_prep_fn
++EXPORT_SYMBOL vmlinux 0x4c591bb0	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x4c6404ce	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x4c668dc9	km_state_notify
++EXPORT_SYMBOL vmlinux 0x4c7e4ed0	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x4c85237a	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x4c86184b	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4c970170	fget
++EXPORT_SYMBOL vmlinux 0x4c98fded	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x4ca9e2b2	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x4caa6dde	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x4cbbd171	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x4cc2854d	tegra114_clock_assert_dfll_dvco_reset
++EXPORT_SYMBOL vmlinux 0x4cc90da2	__module_get
++EXPORT_SYMBOL vmlinux 0x4cd93469	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x4cd9a098	snd_unregister_device
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4d0d163d	copy_page
++EXPORT_SYMBOL vmlinux 0x4d10c80f	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d405db8	param_ops_string
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d69ea5c	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x4d6ce91b	input_free_device
++EXPORT_SYMBOL vmlinux 0x4d78d54d	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x4d8a0b64	clocksource_register
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL vmlinux 0x4db0b10f	d_alloc
++EXPORT_SYMBOL vmlinux 0x4dc40263	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x4dcc6fe7	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0x4dda1812	write_one_page
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4df99e1f	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e4533ac	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x4e4e366f	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x4e506013	omap_dma_link_lch
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e830a3e	strnicmp
++EXPORT_SYMBOL vmlinux 0x4e900e14	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x4e9ce9f9	edma_link
++EXPORT_SYMBOL vmlinux 0x4ea1ddab	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x4eb0d437	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x4edf2ed6	omap_dss_get_device
++EXPORT_SYMBOL vmlinux 0x4ee0621c	genphy_resume
++EXPORT_SYMBOL vmlinux 0x4ee65e48	scsi_free_command
++EXPORT_SYMBOL vmlinux 0x4f083e54	secpath_dup
++EXPORT_SYMBOL vmlinux 0x4f08857d	block_write_full_page_endio
++EXPORT_SYMBOL vmlinux 0x4f17d6e1	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f248523	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f3b316e	dma_async_memcpy_pg_to_pg
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f4d0a0c	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL vmlinux 0x4f89c9de	gpmc_cs_free
++EXPORT_SYMBOL vmlinux 0x4f9018d4	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x4f991575	snd_pcm_new_stream
++EXPORT_SYMBOL vmlinux 0x4fca363c	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x4ff8afb9	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x500daed3	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50aded09	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x50af440e	snd_card_unref
++EXPORT_SYMBOL vmlinux 0x50b6076a	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x50bbba31	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x50becaeb	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x50ccff03	omap_dma_set_prio_lch
++EXPORT_SYMBOL vmlinux 0x50d5612e	dispc_mgr_get_sync_lost_irq
++EXPORT_SYMBOL vmlinux 0x511746c1	dump_fpu
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x511936ce	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x5143c678	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x51454bac	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0x5169161d	omap_free_dma_chain
++EXPORT_SYMBOL vmlinux 0x516eba1f	of_dev_put
++EXPORT_SYMBOL vmlinux 0x517317de	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x51749fc8	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x5175eda9	bio_advance
++EXPORT_SYMBOL vmlinux 0x5184bdb2	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x51895f3d	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x51908eb8	__raw_writesl
++EXPORT_SYMBOL vmlinux 0x51b0c028	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x51bc5d27	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0x51bef20d	arm_dma_ops
++EXPORT_SYMBOL vmlinux 0x51d559d1	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x51d730dd	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x51dce73b	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x51e77c97	pfn_valid
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x520af9c8	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x5213f8c2	posix_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x521df54a	journal_set_features
++EXPORT_SYMBOL vmlinux 0x52254641	snd_pcm_stop
++EXPORT_SYMBOL vmlinux 0x522c1026	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x5237649a	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x523cf16b	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x52428cc8	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x524316a5	nla_append
++EXPORT_SYMBOL vmlinux 0x52510205	journal_destroy
++EXPORT_SYMBOL vmlinux 0x525ba2ab	softnet_data
++EXPORT_SYMBOL vmlinux 0x5277ece1	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x527b11e4	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x5282702b	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x52d42c95	set_current_groups
++EXPORT_SYMBOL vmlinux 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL vmlinux 0x52ed8051	user_path_create
++EXPORT_SYMBOL vmlinux 0x52efd766	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x530c3d61	d_make_root
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x53399366	snd_card_file_add
++EXPORT_SYMBOL vmlinux 0x5351633b	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x5365ea02	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x537cb97f	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x53afdba8	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x53bd1648	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x53c8a6be	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x541286a9	dev_open
++EXPORT_SYMBOL vmlinux 0x5414c488	dev_alert
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x54553925	nla_put
++EXPORT_SYMBOL vmlinux 0x546305f5	blk_get_request
++EXPORT_SYMBOL vmlinux 0x547077ec	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x547ce898	dispc_read_irqenable
++EXPORT_SYMBOL vmlinux 0x547d7335	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x54a0891c	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x54a9017e	lock_rename
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f21cff	__send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x54f6830a	omapdss_get_default_display_name
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x551de1e3	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x5529825c	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x559050eb	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x5594be03	bitmap_remap
++EXPORT_SYMBOL vmlinux 0x559c9b92	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x55b6da56	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x55e4957d	udplite_prot
++EXPORT_SYMBOL vmlinux 0x55e4d7e5	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x55ef4b40	snd_ctl_add
++EXPORT_SYMBOL vmlinux 0x560147fd	edma_unlink
++EXPORT_SYMBOL vmlinux 0x560ad5a1	inet6_bind
++EXPORT_SYMBOL vmlinux 0x560eb390	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x5614b010	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x561bf2e2	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x561ccf59	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x5624dffd	skb_copy_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x5632781e	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x563df56f	generic_readlink
++EXPORT_SYMBOL vmlinux 0x563fa68a	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x5642793a	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x5666c5a9	set_page_dirty
++EXPORT_SYMBOL vmlinux 0x56789ac5	omap_set_dma_color_mode
++EXPORT_SYMBOL vmlinux 0x5684ca83	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x5689afe7	dispc_ovl_enable
++EXPORT_SYMBOL vmlinux 0x56960aba	snd_device_new
++EXPORT_SYMBOL vmlinux 0x56b94adb	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x56bc2f15	dispc_ovl_set_channel_out
++EXPORT_SYMBOL vmlinux 0x56c6aaf2	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x56c7e5c5	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56dadd30	key_unlink
++EXPORT_SYMBOL vmlinux 0x56edd136	d_lookup
++EXPORT_SYMBOL vmlinux 0x56f017d1	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x56f0896f	tegra_periph_reset_assert
++EXPORT_SYMBOL vmlinux 0x56ffc9b3	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x570305d8	serio_close
++EXPORT_SYMBOL vmlinux 0x571fedca	tc_classify
++EXPORT_SYMBOL vmlinux 0x572d0104	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x574b1001	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x574e38ec	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x576f0f93	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0x5799a29f	seq_open
++EXPORT_SYMBOL vmlinux 0x57c5b719	snd_pcm_lib_readv
++EXPORT_SYMBOL vmlinux 0x57c82849	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x57cf0adc	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x57d701f4	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0x57e21615	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0x57fe0856	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x583ecf9e	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x58516557	omap_set_dma_src_data_pack
++EXPORT_SYMBOL vmlinux 0x58534436	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x586702f8	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x588c130c	vexpress_config_func_put
++EXPORT_SYMBOL vmlinux 0x58d1070a	of_get_address
++EXPORT_SYMBOL vmlinux 0x58d5480e	tcp_tso_segment
++EXPORT_SYMBOL vmlinux 0x58dc9eaf	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x58e1a10a	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x58e75c7b	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL vmlinux 0x58fca530	mddev_congested
++EXPORT_SYMBOL vmlinux 0x591576fa	sound_class
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x594e1317	__modsi3
++EXPORT_SYMBOL vmlinux 0x5950b83b	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x596f53da	release_sock
++EXPORT_SYMBOL vmlinux 0x5977dd6f	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x598542b2	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x598aaee9	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x598cd828	udp_table
++EXPORT_SYMBOL vmlinux 0x5996b9c8	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0x59a17bfc	tegra114_clock_tune_cpu_trimmers_high
++EXPORT_SYMBOL vmlinux 0x59a88697	snd_card_register
++EXPORT_SYMBOL vmlinux 0x59af3bdf	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0x59d29dab	v7_flush_kern_dcache_area
++EXPORT_SYMBOL vmlinux 0x59d8223a	ioport_resource
++EXPORT_SYMBOL vmlinux 0x59dd0a0e	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x59e5070d	__do_div64
++EXPORT_SYMBOL vmlinux 0x5a282102	kernel_write
++EXPORT_SYMBOL vmlinux 0x5a3e380b	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x5a44c189	put_page
++EXPORT_SYMBOL vmlinux 0x5a45e25f	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x5a9872ee	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0x5aa126df	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x5ac1ab11	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x5ae5be44	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5ae716c1	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x5aead45d	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x5b020073	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x5b136679	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b1a04b8	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x5b2400ab	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x5b489960	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x5b69bd0a	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x5b70cbb2	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x5b72009f	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x5ba53020	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x5bab200f	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x5bae9caa	find_get_page
++EXPORT_SYMBOL vmlinux 0x5bb5cb76	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x5bdd2e9c	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0x5be9c443	inet_frag_evictor
++EXPORT_SYMBOL vmlinux 0x5bec319a	inode_init_once
++EXPORT_SYMBOL vmlinux 0x5bf4a1eb	sg_last
++EXPORT_SYMBOL vmlinux 0x5bf947c1	md_register_thread
++EXPORT_SYMBOL vmlinux 0x5c0091e2	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x5c511b24	nand_bch_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x5c9284a0	processor_id
++EXPORT_SYMBOL vmlinux 0x5c946ed3	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x5c971ea2	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x5ce1c024	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL vmlinux 0x5ce772a9	omap_dss_unregister_driver
++EXPORT_SYMBOL vmlinux 0x5ce8652a	kill_fasync
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cfa980c	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x5d0b1892	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x5d1213d7	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x5d48577a	nand_bch_correct_data
++EXPORT_SYMBOL vmlinux 0x5d4f8c71	omapdss_sdi_set_datapairs
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d597afc	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x5d5b5a16	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x5d66d6ca	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0x5d6f7d86	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x5d792b1c	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0x5d891a64	idr_destroy
++EXPORT_SYMBOL vmlinux 0x5da55c12	tty_port_close
++EXPORT_SYMBOL vmlinux 0x5dc05707	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x5e11b556	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x5e1d9713	snd_info_create_module_entry
++EXPORT_SYMBOL vmlinux 0x5e448c00	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x5e5f0030	snd_card_free_when_closed
++EXPORT_SYMBOL vmlinux 0x5e60eb27	omap_dma_unlink_lch
++EXPORT_SYMBOL vmlinux 0x5e7271d3	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e964a99	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x5e9daa71	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x5eaeb6ec	pipe_to_file
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5eb292bc	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x5eb9bf51	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ed0e41a	scsi_adjust_queue_depth
++EXPORT_SYMBOL vmlinux 0x5ed49f97	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f0b59f7	generic_write_sync
++EXPORT_SYMBOL vmlinux 0x5f18cc6f	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x5f1e997c	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x5f1f09b5	omapdss_register_display
++EXPORT_SYMBOL vmlinux 0x5f3c8f5c	mmc_assume_removable
++EXPORT_SYMBOL vmlinux 0x5f44d1c7	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0x5f58f676	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x5f722cb7	snd_ctl_replace
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f7e61eb	dev_set_group
++EXPORT_SYMBOL vmlinux 0x5f9d86f4	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x5faf9271	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x5fc7e4ed	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x5fc91105	mmc_gpio_free_cd
++EXPORT_SYMBOL vmlinux 0x5ff11cc3	pcibios_min_io
++EXPORT_SYMBOL vmlinux 0x60055baa	dispc_mgr_get_vsync_irq
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x60145b65	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x6021c1a6	register_key_type
++EXPORT_SYMBOL vmlinux 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x60376398	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x60458f1b	amba_driver_register
++EXPORT_SYMBOL vmlinux 0x60541702	edma_alloc_slot
++EXPORT_SYMBOL vmlinux 0x605c2219	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x607131b7	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0x607ad4c0	generic_pipe_buf_map
++EXPORT_SYMBOL vmlinux 0x6082993a	ilookup
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a06c05	snd_pcm_lib_ioctl
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60ccbac3	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x60d0ad82	ip_cmsg_recv
++EXPORT_SYMBOL vmlinux 0x60e309c9	snd_pcm_suspend_all
++EXPORT_SYMBOL vmlinux 0x60fbe773	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x60fed70e	nand_scan_bbt
++EXPORT_SYMBOL vmlinux 0x611b12ad	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x612390ad	netpoll_set_trap
++EXPORT_SYMBOL vmlinux 0x6123b5ae	snd_device_register
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x6159c2fb	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x616fccb8	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x61762016	tegra_periph_reset_deassert
++EXPORT_SYMBOL vmlinux 0x617643a2	param_set_long
++EXPORT_SYMBOL vmlinux 0x617a218d	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x618afe7d	tty_vhangup
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bc02e5	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x61c8a547	skb_push
++EXPORT_SYMBOL vmlinux 0x61e1850a	edma_write_slot
++EXPORT_SYMBOL vmlinux 0x61e9f09d	phy_print_status
++EXPORT_SYMBOL vmlinux 0x61f8db57	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x6212c2d9	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622a0c41	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x62484bb7	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x62704407	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x6273ef2e	htc_egpio_get_wakeup_irq
++EXPORT_SYMBOL vmlinux 0x62822d05	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x6283ba82	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x62926d46	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x62a0bb6b	write_inode_now
++EXPORT_SYMBOL vmlinux 0x62bf96ac	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x62c106fb	d_add_ci
++EXPORT_SYMBOL vmlinux 0x62d34ec2	kobject_del
++EXPORT_SYMBOL vmlinux 0x62e227b9	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x62e934a6	devm_ioremap
++EXPORT_SYMBOL vmlinux 0x62fd6207	param_set_charp
++EXPORT_SYMBOL vmlinux 0x63001463	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x63408d38	ihold
++EXPORT_SYMBOL vmlinux 0x63468e0a	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x6349b6b9	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x6350bf7a	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x6361d82d	sk_alloc
++EXPORT_SYMBOL vmlinux 0x636b3461	omap_dss_get_num_overlays
++EXPORT_SYMBOL vmlinux 0x6372b18b	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x63922bbd	vfs_stat
++EXPORT_SYMBOL vmlinux 0x63b42931	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63f2f774	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x63f9a415	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x6410c73c	tty_lock_pair
++EXPORT_SYMBOL vmlinux 0x641699d6	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x6433b21e	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x6439c048	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x645ca39c	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x646400f2	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x6480f2ca	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a22ff0	dispc_mgr_set_lcd_config
++EXPORT_SYMBOL vmlinux 0x64b13637	nand_scan
++EXPORT_SYMBOL vmlinux 0x64b2b185	mtd_concat_create
++EXPORT_SYMBOL vmlinux 0x64bd49c6	fail_migrate_page
++EXPORT_SYMBOL vmlinux 0x64c024dd	seq_release_private
++EXPORT_SYMBOL vmlinux 0x64d233c8	ioremap_page
++EXPORT_SYMBOL vmlinux 0x64e370b3	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x64e38db5	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x64e75914	dev_warn
++EXPORT_SYMBOL vmlinux 0x650a6767	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x65342061	arm_coherent_dma_ops
++EXPORT_SYMBOL vmlinux 0x65345ddd	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65422a94	filp_close
++EXPORT_SYMBOL vmlinux 0x65466939	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x654b4db3	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x654eb0f6	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x654f36dd	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x65721745	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x657c7014	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0x6585e310	alloc_pages_exact_nid
++EXPORT_SYMBOL vmlinux 0x65a52d19	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0x65c179d9	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL vmlinux 0x65d67a20	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x65ff2b60	__inode_permission
++EXPORT_SYMBOL vmlinux 0x66010892	nf_log_set
++EXPORT_SYMBOL vmlinux 0x6605f97f	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x662c8d06	inet_bind
++EXPORT_SYMBOL vmlinux 0x6638027b	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0x6651b1e2	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x66806011	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0x668da8d5	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x669420c4	register_md_personality
++EXPORT_SYMBOL vmlinux 0x66a67dab	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x66df0184	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x66e28d10	pci_disable_ido
++EXPORT_SYMBOL vmlinux 0x66f1a37b	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x674aa6f7	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x6766f00e	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x676bbc0f	_set_bit
++EXPORT_SYMBOL vmlinux 0x6771281c	netdev_alert
++EXPORT_SYMBOL vmlinux 0x678d06e4	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x67991c67	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x681b316d	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x6826ea1b	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x683cf3be	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x684db7d5	fb_blank
++EXPORT_SYMBOL vmlinux 0x686707db	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x68797148	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x68869bae	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL vmlinux 0x68e05d57	getrawmonotonic
++EXPORT_SYMBOL vmlinux 0x68e1f981	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0x68e787f3	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0x68ede8fc	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x68f7599f	omapdss_output_unset_device
++EXPORT_SYMBOL vmlinux 0x68fb581a	icst307_idx2s
++EXPORT_SYMBOL vmlinux 0x6915eb38	down_interruptible
++EXPORT_SYMBOL vmlinux 0x69184977	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x69209431	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x6963c03c	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0x696428b1	nand_default_bbt
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69b6f8d9	omap_set_dma_transfer_params
++EXPORT_SYMBOL vmlinux 0x69d38ed9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x69d9cd10	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x69da5c0d	directly_mappable_cdev_bdi
++EXPORT_SYMBOL vmlinux 0x69e27c7a	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x69f7d2a9	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a097b90	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0x6a1ccb1b	edma_get_position
++EXPORT_SYMBOL vmlinux 0x6a56fc1c	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a5ff522	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a80c4e7	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0x6a96cff8	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x6ab07183	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x6aba9a5e	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x6ac5eb7b	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x6af9ae7b	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x6b023af7	consume_skb
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b2974fb	mapping_tagged
++EXPORT_SYMBOL vmlinux 0x6b2db8ae	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b45dd5a	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x6b7589f4	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6b7f1739	pm860x_page_set_bits
++EXPORT_SYMBOL vmlinux 0x6b9ddbb8	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x6ba1d137	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x6bb3db13	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bd36347	omap_dss_find_output
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bf62dab	journal_revoke
++EXPORT_SYMBOL vmlinux 0x6bfe8db5	serio_open
++EXPORT_SYMBOL vmlinux 0x6c01de8a	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0x6c10e839	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c368b97	elevator_exit
++EXPORT_SYMBOL vmlinux 0x6c3bec0c	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x6c558b25	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c6cdd4d	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6ca38855	module_put
++EXPORT_SYMBOL vmlinux 0x6cb36cdd	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x6ccf7bd7	__pv_phys_offset
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6cf89f74	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x6d044c26	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d1021cf	net_dma_find_channel
++EXPORT_SYMBOL vmlinux 0x6d193c96	fb_set_var
++EXPORT_SYMBOL vmlinux 0x6d27ef64	__bitmap_empty
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d662533	_find_first_bit_le
++EXPORT_SYMBOL vmlinux 0x6d678d5a	generic_writepages
++EXPORT_SYMBOL vmlinux 0x6d8492c7	simple_lookup
++EXPORT_SYMBOL vmlinux 0x6d98a110	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x6da6b28e	lro_receive_frags
++EXPORT_SYMBOL vmlinux 0x6daa7c18	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x6db06303	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x6dd3ebe5	find_vma
++EXPORT_SYMBOL vmlinux 0x6de9c821	elevator_init
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6e2ece38	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x6e308775	bio_pair_release
++EXPORT_SYMBOL vmlinux 0x6e445779	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0x6e58b191	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x6e66ef00	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x6e6ad4e1	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x6e6e6cdf	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e88e56f	snd_pcm_link_rwlock
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6e9f43c7	sk_filter
++EXPORT_SYMBOL vmlinux 0x6eb5370c	flush_kernel_dcache_page
++EXPORT_SYMBOL vmlinux 0x6eb629b9	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0x6ec31640	dqput
++EXPORT_SYMBOL vmlinux 0x6ed7c09c	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x6ede94ef	skb_copy_datagram_const_iovec
++EXPORT_SYMBOL vmlinux 0x6ee0d967	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x6ee0f782	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x6ee19ef6	mount_single
++EXPORT_SYMBOL vmlinux 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f2397cd	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0x6f6b2f20	d_drop
++EXPORT_SYMBOL vmlinux 0x6f6e37a3	__pskb_copy
++EXPORT_SYMBOL vmlinux 0x6f9456e0	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x6fab1d37	scsi_reset_provider
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6ff5d7d8	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x700229fc	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x7009091d	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL vmlinux 0x70174cf8	scsi_release_buffers
++EXPORT_SYMBOL vmlinux 0x702c4cf7	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0x70362575	register_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0x70399443	try_module_get
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x70567257	flock_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x707bae7c	dev_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x707bbc64	ping_prot
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x70bc17d7	inode_wait
++EXPORT_SYMBOL vmlinux 0x70c2b6a3	scsi_execute
++EXPORT_SYMBOL vmlinux 0x70d053fd	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70e0ec02	seq_putc
++EXPORT_SYMBOL vmlinux 0x70e39dae	dss_uninstall_mgr_ops
++EXPORT_SYMBOL vmlinux 0x70ee8a66	nand_bch_init
++EXPORT_SYMBOL vmlinux 0x7100c46b	drop_nlink
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x71372e53	iput
++EXPORT_SYMBOL vmlinux 0x7140218e	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x7142c63c	edma_free_slot
++EXPORT_SYMBOL vmlinux 0x71658a05	dispc_ovl_setup
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71826bb3	bd_set_size
++EXPORT_SYMBOL vmlinux 0x7195ec98	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71afd84a	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0x71b7be51	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x71c14940	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71cbcbf8	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7201e73a	vfs_readlink
++EXPORT_SYMBOL vmlinux 0x72350130	___ratelimit
++EXPORT_SYMBOL vmlinux 0x7250f385	redraw_screen
++EXPORT_SYMBOL vmlinux 0x7254a4a0	ac97_bus_type
++EXPORT_SYMBOL vmlinux 0x7254c024	md_write_end
++EXPORT_SYMBOL vmlinux 0x728e27da	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x72d486e4	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72e7cf5f	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x73081798	__skb_dst_set_noref
++EXPORT_SYMBOL vmlinux 0x730ff1d8	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x731485b4	snd_device_free
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731b81f1	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x73542411	omapdss_dpi_set_data_lines
++EXPORT_SYMBOL vmlinux 0x737de5e9	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x73a1575b	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0x73ac8fa0	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x741a62aa	pci_disable_ltr
++EXPORT_SYMBOL vmlinux 0x745540a9	filp_open
++EXPORT_SYMBOL vmlinux 0x74646443	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x7469fcfe	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74c13321	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74c908db	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x74ccd20e	dm_register_target
++EXPORT_SYMBOL vmlinux 0x74ce05b8	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x74d118b6	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x74daaa09	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x74e46dac	imx_ssi_fiq_tx_buffer
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74ec22b2	register_quota_format
++EXPORT_SYMBOL vmlinux 0x74f1ff0b	page_address
++EXPORT_SYMBOL vmlinux 0x75057c31	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x7509b529	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x750e8fec	md_error
++EXPORT_SYMBOL vmlinux 0x7537ec9f	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x75404e1e	iterate_dir
++EXPORT_SYMBOL vmlinux 0x754472ef	sock_update_classid
++EXPORT_SYMBOL vmlinux 0x754dac78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0x7563e1d2	key_put
++EXPORT_SYMBOL vmlinux 0x757ae0b2	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x7598fcea	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x75a2ed05	sock_edemux
++EXPORT_SYMBOL vmlinux 0x75b33be1	iterate_fd
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75de4b4f	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x75dfc533	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x75ea3f58	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0x75ed1e80	netdev_class_create_file
++EXPORT_SYMBOL vmlinux 0x75f5cd19	inet_accept
++EXPORT_SYMBOL vmlinux 0x75f94a1f	dquot_acquire
++EXPORT_SYMBOL vmlinux 0x75fee7fd	__raw_writesb
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x763f1aff	netdev_notice
++EXPORT_SYMBOL vmlinux 0x76436d63	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x7662264e	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x7678efed	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x768d88d1	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x76a4f38d	do_map_probe
++EXPORT_SYMBOL vmlinux 0x76ae08b0	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x76bf656d	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x76cef0fc	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x76cf47f6	__aeabi_llsl
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76f660d7	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0x770059a9	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x7733f5cc	snd_pcm_hw_refine
++EXPORT_SYMBOL vmlinux 0x773a9c94	blk_iopoll_enabled
++EXPORT_SYMBOL vmlinux 0x77464315	snd_info_create_card_entry
++EXPORT_SYMBOL vmlinux 0x774afc11	__vexpress_config_func_get
++EXPORT_SYMBOL vmlinux 0x776d3bf1	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x77839ed9	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x7791193f	icst525_s2div
++EXPORT_SYMBOL vmlinux 0x779a139f	snd_pcm_debug_name
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77be4fe2	free_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0x77c4508e	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0x77ce93b3	qid_lt
++EXPORT_SYMBOL vmlinux 0x77dc0074	udp_poll
++EXPORT_SYMBOL vmlinux 0x77df0847	__set_personality
++EXPORT_SYMBOL vmlinux 0x77e104e1	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x77ecac9f	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x77f77176	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x77f7ecc2	cookie_check_timestamp
++EXPORT_SYMBOL vmlinux 0x77fe4cb2	sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x7804d1cd	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x780fc676	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x78145d9f	input_inject_event
++EXPORT_SYMBOL vmlinux 0x781a17c1	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x781b7c7c	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x781de461	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x784ff81c	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x7852c0e6	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x785fa3f3	kernel_accept
++EXPORT_SYMBOL vmlinux 0x7873a629	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x788b6e07	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x788fe103	iomem_resource
++EXPORT_SYMBOL vmlinux 0x78968589	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x78a1e649	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x78bc14c1	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x78c8a55b	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x78d32309	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x78db0e40	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x78dc76f2	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x78e82c69	of_phy_connect
++EXPORT_SYMBOL vmlinux 0x79086627	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x790e4007	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x7921ed14	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x792ad377	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x7930d225	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x795f3d06	mount_ns
++EXPORT_SYMBOL vmlinux 0x79656c5f	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x797ffc05	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x799bf72d	inet_put_port
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79c42bfa	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x79c5dcec	dma_supported
++EXPORT_SYMBOL vmlinux 0x79db448e	pci_disable_obff
++EXPORT_SYMBOL vmlinux 0x79f3205d	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0x79fa1deb	imx_ssi_fiq_rx_buffer
++EXPORT_SYMBOL vmlinux 0x7a06cddc	scsi_finish_command
++EXPORT_SYMBOL vmlinux 0x7a0afa2d	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x7a106d88	journal_wipe
++EXPORT_SYMBOL vmlinux 0x7a188791	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x7a27c184	ewma_init
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a882f90	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x7a90e81b	sock_init_data
++EXPORT_SYMBOL vmlinux 0x7a91726b	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x7a9c224d	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x7aa458e5	netdev_crit
++EXPORT_SYMBOL vmlinux 0x7aa5989b	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ac8b04c	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0x7ad41bf9	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x7ad4abe4	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x7af3e318	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7aff9b82	mount_nodev
++EXPORT_SYMBOL vmlinux 0x7b02ab61	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x7b03848a	verify_mem_not_deleted
++EXPORT_SYMBOL vmlinux 0x7b3052fc	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b64b870	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x7b6646bb	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x7b747042	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0x7b778536	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0x7b9c4cdd	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x7bb36e50	__netif_schedule
++EXPORT_SYMBOL vmlinux 0x7bc9cb67	vfs_statfs
++EXPORT_SYMBOL vmlinux 0x7bcbb11f	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0x7beb3926	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c36e9ad	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x7c3b6f63	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x7c435640	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x7c83e80d	I_BDEV
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7ca463ab	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x7cb043a8	file_sb_list_del
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cbe8095	dispc_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0x7cc035a7	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x7cdfef3f	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x7ce3b08a	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x7cfdaf4f	dump_write
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d0e3e72	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x7d113499	simple_rmdir
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d187d16	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x7d2c0224	seq_printf
++EXPORT_SYMBOL vmlinux 0x7d402bd9	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x7d4e2276	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x7d7750fc	bio_get_nr_vecs
++EXPORT_SYMBOL vmlinux 0x7d8ac45d	dqget
++EXPORT_SYMBOL vmlinux 0x7d901b35	seq_read
++EXPORT_SYMBOL vmlinux 0x7d9c11cc	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x7da8c8ff	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x7da91fe5	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x7dbada59	sock_register
++EXPORT_SYMBOL vmlinux 0x7dbd1466	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x7dbe2cfb	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x7dccc294	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7e02bb96	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x7e1f76ac	vmap
++EXPORT_SYMBOL vmlinux 0x7e27b1a0	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x7e394c4e	sysctl_local_reserved_ports
++EXPORT_SYMBOL vmlinux 0x7e399891	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0x7e613ecd	sys_copyarea
++EXPORT_SYMBOL vmlinux 0x7e67e9f4	finish_no_open
++EXPORT_SYMBOL vmlinux 0x7e81d1e4	snd_jack_report
++EXPORT_SYMBOL vmlinux 0x7e8fcd55	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x7e98d318	vexpress_config_read
++EXPORT_SYMBOL vmlinux 0x7e9efe8e	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x7ea0de35	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x7ead817c	__idr_pre_get
++EXPORT_SYMBOL vmlinux 0x7eb7c18d	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x7ef94f04	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x7efb467e	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0x7f0b6b1a	snd_seq_root
++EXPORT_SYMBOL vmlinux 0x7f171f4f	key_alloc
++EXPORT_SYMBOL vmlinux 0x7f1daffc	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x7f232e12	misc_register
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f33a63b	omap_get_dma_chain_dst_pos
++EXPORT_SYMBOL vmlinux 0x7f3cbda8	omap_dss_get_next_device
++EXPORT_SYMBOL vmlinux 0x7f554d27	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x7f616a53	rt6_lookup
++EXPORT_SYMBOL vmlinux 0x7f63b31e	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0x7f94e54a	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0x7f97f377	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x7f991024	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0x7fa2b492	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0x7fa64cca	omap_dss_pal_timings
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fed7d9e	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0x7ffbbb5a	__sock_create
++EXPORT_SYMBOL vmlinux 0x7ffdc78c	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x800a981d	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x800e4ffa	__muldi3
++EXPORT_SYMBOL vmlinux 0x801eb4e3	dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x804d8b33	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0x80669fa6	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x8068149c	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x80776808	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d14ad1	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80d81308	omap_vrfb_release_ctx
++EXPORT_SYMBOL vmlinux 0x81003ee2	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x810ac172	pcim_iomap
++EXPORT_SYMBOL vmlinux 0x810edc65	__napi_complete
++EXPORT_SYMBOL vmlinux 0x812b4368	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x81339d0b	journal_init_inode
++EXPORT_SYMBOL vmlinux 0x813c962b	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x813cb9f6	put_io_context
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x81576f25	omap_dss_get_overlay_manager
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x8184c502	init_net
++EXPORT_SYMBOL vmlinux 0x81986c06	journal_flush
++EXPORT_SYMBOL vmlinux 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL vmlinux 0x81b7107d	cdev_add
++EXPORT_SYMBOL vmlinux 0x81bfad0c	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x81d10f5f	trace_seq_putc
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820d556e	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x8213d29a	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0x82453a78	generic_file_remap_pages
++EXPORT_SYMBOL vmlinux 0x8249b2ea	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x824a4367	tmio_core_mmc_pwr
++EXPORT_SYMBOL vmlinux 0x82507c13	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x8251bcc3	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x8260686f	bitmap_find_next_zero_area
++EXPORT_SYMBOL vmlinux 0x8262dcbd	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x826a89c7	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x826cf01a	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x828526a6	snd_jack_new
++EXPORT_SYMBOL vmlinux 0x828ba44b	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x828ca1f6	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x8293eaf9	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x82ac8bec	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82bcf30d	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0x82bf585a	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x82d0ad3e	fd_install
++EXPORT_SYMBOL vmlinux 0x82d33393	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0x82fb3d82	generic_file_aio_read
++EXPORT_SYMBOL vmlinux 0x830fb011	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x8315bbfd	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x8320bea8	__umodsi3
++EXPORT_SYMBOL vmlinux 0x83211609	up_write
++EXPORT_SYMBOL vmlinux 0x835e89c9	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0x835ec25f	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x835f1d4a	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0x8371daff	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0x8380afe7	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x839541e4	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x839cdf99	edma_resume
++EXPORT_SYMBOL vmlinux 0x83a476ce	bitmap_scnlistprintf
++EXPORT_SYMBOL vmlinux 0x83c8a355	param_set_int
++EXPORT_SYMBOL vmlinux 0x83d70683	edma_start
++EXPORT_SYMBOL vmlinux 0x83d7fdbd	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x83e59a7c	netdev_warn
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x84154b40	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x841ca5ff	flush_signals
++EXPORT_SYMBOL vmlinux 0x844ad9bc	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x844b686b	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x84822f32	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84cfd662	serio_rescan
++EXPORT_SYMBOL vmlinux 0x84d84345	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x84f84824	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x84ffd43e	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85044fad	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x85061b76	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x8511f177	vm_event_states
++EXPORT_SYMBOL vmlinux 0x852d3197	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x8548771c	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x855a2b2e	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x8569cd94	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x856ede6d	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0x85737519	edma_read_slot
++EXPORT_SYMBOL vmlinux 0x85765fee	omap_enable_dma_irq
++EXPORT_SYMBOL vmlinux 0x85886dc2	finish_open
++EXPORT_SYMBOL vmlinux 0x85ab97ab	kernel_read
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85c2bf65	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e67c43	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x85e7deb2	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x85f485ef	snd_pcm_set_sync
++EXPORT_SYMBOL vmlinux 0x85f769eb	journal_start_commit
++EXPORT_SYMBOL vmlinux 0x86001bef	migrate_page
++EXPORT_SYMBOL vmlinux 0x860f94d8	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x862a6f4d	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x863c104a	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x8646fd12	scsi_cmd_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x865ccc8e	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x866202a2	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x86860195	dss_feat_get_supported_displays
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86a6cb51	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x86b2c6e5	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x86b75e08	snd_ctl_remove_id
++EXPORT_SYMBOL vmlinux 0x86c9d17d	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x86e2a980	files_lglock
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870bf928	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x8712640f	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x87275a55	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x87299a53	bdget
++EXPORT_SYMBOL vmlinux 0x873cbd96	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x8753a115	generic_read_dir
++EXPORT_SYMBOL vmlinux 0x8754dfca	complete_request_key
++EXPORT_SYMBOL vmlinux 0x8780726a	pci_vpd_truncate
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87966b9b	omapdss_get_version
++EXPORT_SYMBOL vmlinux 0x8798e453	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x87c151fd	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x87cbee69	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x87d042b5	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x880998e6	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0x881039d0	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x881fa897	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x882d7d5e	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0x8834396c	mod_timer
++EXPORT_SYMBOL vmlinux 0x886bef7f	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x888d5da7	dev_load
++EXPORT_SYMBOL vmlinux 0x88972019	call_netdevice_notifiers_info
++EXPORT_SYMBOL vmlinux 0x88af2f1c	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x88e22b2f	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0x88f2022b	snd_pcm_hw_param_first
++EXPORT_SYMBOL vmlinux 0x88fb5a73	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x89022b5b	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x890dc2ed	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x8929b630	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0x8946a3e6	aio_complete
++EXPORT_SYMBOL vmlinux 0x894f86fe	poll_initwait
++EXPORT_SYMBOL vmlinux 0x895319ff	pci_bus_put
++EXPORT_SYMBOL vmlinux 0x8953f8ff	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x89695a2c	snd_pcm_new_internal
++EXPORT_SYMBOL vmlinux 0x897473df	mktime
++EXPORT_SYMBOL vmlinux 0x899ef888	snd_timer_notify
++EXPORT_SYMBOL vmlinux 0x89a23f58	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x89a3c4f4	omap_get_dma_chain_index
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89d66811	build_ehash_secret
++EXPORT_SYMBOL vmlinux 0x89d6c40d	tty_hangup
++EXPORT_SYMBOL vmlinux 0x8a0f4230	rename_lock
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a3a376f	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0x8a4584aa	dma_async_memcpy_buf_to_buf
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a4fa83b	__aeabi_llsr
++EXPORT_SYMBOL vmlinux 0x8a532fb5	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0x8a642886	snd_timer_start
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a92aec5	dss_install_mgr_ops
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa7ae02	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x8ace8ca3	groups_alloc
++EXPORT_SYMBOL vmlinux 0x8ad75030	phy_find_first
++EXPORT_SYMBOL vmlinux 0x8ad96e09	aio_put_req
++EXPORT_SYMBOL vmlinux 0x8adf8e4c	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x8ae720fa	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x8b0a169f	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0x8b0aa812	d_invalidate
++EXPORT_SYMBOL vmlinux 0x8b0f7dee	pci_enable_obff
++EXPORT_SYMBOL vmlinux 0x8b10bdc2	send_sig
++EXPORT_SYMBOL vmlinux 0x8b1a7a66	pcie_aspm_enabled
++EXPORT_SYMBOL vmlinux 0x8b231628	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x8b3685e9	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b5cf292	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b829d5c	dev_close
++EXPORT_SYMBOL vmlinux 0x8b839525	bio_integrity_get_tag
++EXPORT_SYMBOL vmlinux 0x8baecc9b	register_cdrom
++EXPORT_SYMBOL vmlinux 0x8bcb9cfc	blk_complete_request
++EXPORT_SYMBOL vmlinux 0x8bd0a3fd	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x8bfe8c57	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8c19056e	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x8c3c4f0b	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x8c4d6523	omap_dma_chain_a_transfer
++EXPORT_SYMBOL vmlinux 0x8c5710ef	drop_super
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c705b8c	edma_clean_channel
++EXPORT_SYMBOL vmlinux 0x8c7b0ce7	of_device_register
++EXPORT_SYMBOL vmlinux 0x8c95d193	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x8ca3fad2	touch_atime
++EXPORT_SYMBOL vmlinux 0x8ca8c6e0	console_start
++EXPORT_SYMBOL vmlinux 0x8cc89b0d	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x8ccf6c0d	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x8cd8c339	omap_free_dma
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8cedce24	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x8d061264	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x8d263677	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x8d4d86f9	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d557b29	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x8d56a8a5	scsi_init_io
++EXPORT_SYMBOL vmlinux 0x8d5da109	pci_iounmap
++EXPORT_SYMBOL vmlinux 0x8d5ea79d	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x8d683678	inet_frags_init
++EXPORT_SYMBOL vmlinux 0x8d684939	sk_free
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d7b4a6a	journal_force_commit
++EXPORT_SYMBOL vmlinux 0x8d7edaf9	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0x8d8b6353	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x8d8d43a8	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x8d9ca44c	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x8dbb6ec1	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x8dcb9deb	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x8ddb9d64	blk_integrity_is_initialized
++EXPORT_SYMBOL vmlinux 0x8e0c7d48	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x8e0cfb20	xfrm_input
++EXPORT_SYMBOL vmlinux 0x8e0d66f4	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x8e28cd42	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x8e5c580a	ida_init
++EXPORT_SYMBOL vmlinux 0x8e865d3c	arm_delay_ops
++EXPORT_SYMBOL vmlinux 0x8e95c483	security_file_permission
++EXPORT_SYMBOL vmlinux 0x8e984225	dst_release
++EXPORT_SYMBOL vmlinux 0x8eaa60f4	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x8ead3637	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0x8ec40745	dm_io
++EXPORT_SYMBOL vmlinux 0x8ed523b4	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x8efbc870	stop_tty
++EXPORT_SYMBOL vmlinux 0x8f045d1c	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x8f06a649	read_code
++EXPORT_SYMBOL vmlinux 0x8f1cca0b	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x8f20796f	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x8f2f9b40	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x8f32da8e	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x8f595b11	snd_major
++EXPORT_SYMBOL vmlinux 0x8f678b07	__stack_chk_guard
++EXPORT_SYMBOL vmlinux 0x8f7014a1	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x8f7ec8a4	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x8f9bbaad	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x8fa4130a	omap_set_dma_callback
++EXPORT_SYMBOL vmlinux 0x8faa4598	of_translate_address
++EXPORT_SYMBOL vmlinux 0x8fb842d0	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x8fce9fd8	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x9010c814	start_tty
++EXPORT_SYMBOL vmlinux 0x90160cb2	km_query
++EXPORT_SYMBOL vmlinux 0x903766ec	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x903c7f92	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x9048982c	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0x90565f74	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x906a5e12	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x9080311e	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x908cd8a7	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x90903a01	input_register_handler
++EXPORT_SYMBOL vmlinux 0x9091c1c8	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0x90a8a982	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x90ac3102	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x90b471ab	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0x90b67b1e	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90c79b9b	blk_register_region
++EXPORT_SYMBOL vmlinux 0x90dd6f40	mmc_hw_reset_check
++EXPORT_SYMBOL vmlinux 0x90fb8f50	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0x90ffd167	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0x9108c132	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x911cf37b	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x911d13fd	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x911d42f7	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x91299df4	snd_pcm_new
++EXPORT_SYMBOL vmlinux 0x912d6fb9	mmc_cache_ctrl
++EXPORT_SYMBOL vmlinux 0x9138226a	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x9152875f	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x91621d6a	allocate_resource
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x917324de	skb_queue_head
++EXPORT_SYMBOL vmlinux 0x917ac2a0	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x919029aa	__readwrite_bug
++EXPORT_SYMBOL vmlinux 0x91aec064	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x91b6b420	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x91bcdbb3	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x91c0980e	icst_hz
++EXPORT_SYMBOL vmlinux 0x91f9812e	elm_decode_bch_error_page
++EXPORT_SYMBOL vmlinux 0x9205953f	send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x920eb90c	interruptible_sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x922df7f7	journal_errno
++EXPORT_SYMBOL vmlinux 0x923758c2	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x923a64f0	tty_mutex
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x924d2dd2	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x9267b24c	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x9276ce28	edma_set_dest
++EXPORT_SYMBOL vmlinux 0x929627ea	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x92a342d4	journal_extend
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92bb5cc7	sock_rfree
++EXPORT_SYMBOL vmlinux 0x92c2f37b	scsi_setup_fs_cmnd
++EXPORT_SYMBOL vmlinux 0x92c77177	bdi_unregister
++EXPORT_SYMBOL vmlinux 0x92ca2536	test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x92ca9945	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x92cc59ed	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x92d5121f	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x92ec5d1b	dispc_mgr_enable
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x9332527c	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x93640af7	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x938bd8aa	generic_show_options
++EXPORT_SYMBOL vmlinux 0x93942aef	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x93963a85	dss_feat_get_num_mgrs
++EXPORT_SYMBOL vmlinux 0x93a6e0b2	io_schedule
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93be954d	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x93fdae54	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x940199da	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x9401b417	set_device_ro
++EXPORT_SYMBOL vmlinux 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL vmlinux 0x943d57f7	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x94407703	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x944df3eb	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x94757766	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x9475cb64	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x94869320	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94c11107	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x94c19840	snd_pcm_open_substream
++EXPORT_SYMBOL vmlinux 0x94d3da68	rtc_lock
++EXPORT_SYMBOL vmlinux 0x94fc016c	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x9501fb9d	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x9504d95d	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x95187fc0	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x95276a73	arp_tbl
++EXPORT_SYMBOL vmlinux 0x9529f7ed	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x954488a4	syncookie_secret
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x9554b64e	set_security_override
++EXPORT_SYMBOL vmlinux 0x955aa495	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x95622f41	down_timeout
++EXPORT_SYMBOL vmlinux 0x9568e65a	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x9582aa13	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x9596699d	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL vmlinux 0x959b5b35	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x95b37398	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x95cb929c	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x95d40a04	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x95dbe078	__get_user_2
++EXPORT_SYMBOL vmlinux 0x95e5846c	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x95e6e500	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x95f88784	touch_buffer
++EXPORT_SYMBOL vmlinux 0x9600f629	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0x9613509a	idr_replace
++EXPORT_SYMBOL vmlinux 0x9615c731	_dev_info
++EXPORT_SYMBOL vmlinux 0x962f56e8	__break_lease
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x968e1ab3	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x9697206b	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x96b39b6e	omap_start_dma_chain_transfers
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x9711d94c	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x971aaccb	lro_flush_pkt
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x972f520e	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x973acb82	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x9754d878	input_set_capability
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e700f	down_trylock
++EXPORT_SYMBOL vmlinux 0x9772d316	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0x97734471	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x978f7812	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x9793c93a	dispc_mgr_setup
++EXPORT_SYMBOL vmlinux 0x9798e8ba	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97b4500c	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x97c6782c	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x97ff288e	__put_cred
++EXPORT_SYMBOL vmlinux 0x98082893	__copy_to_user
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x984b079d	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x984edb18	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x98720204	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0x987fb8e2	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x98973054	mutex_lock
++EXPORT_SYMBOL vmlinux 0x989ed9dd	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x98b86fe6	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x98c041dd	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x98fa21b0	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x9958c377	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x995b3f83	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0x996c4d30	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x997fa975	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999c3148	__raw_readsb
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d88665	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0x99d9ae1d	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x99f58330	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x99f90abf	follow_down_one
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a6e183a	__idr_remove_all
++EXPORT_SYMBOL vmlinux 0x9a8318ef	v7_coherent_kern_range
++EXPORT_SYMBOL vmlinux 0x9a885df0	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0x9a8dea11	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x9a9b95ca	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x9aa9c93b	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x9ab316f7	seq_lseek
++EXPORT_SYMBOL vmlinux 0x9abab5c4	request_firmware
++EXPORT_SYMBOL vmlinux 0x9ac23f5c	PDE_DATA
++EXPORT_SYMBOL vmlinux 0x9ad9e2d6	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x9b015f67	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x9b178184	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b603efe	journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b794393	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x9b8d7e09	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x9b92f1ab	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bbfdced	single_open_size
++EXPORT_SYMBOL vmlinux 0x9bc56611	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0x9bce482f	__release_region
++EXPORT_SYMBOL vmlinux 0x9bd42570	icmp_send
++EXPORT_SYMBOL vmlinux 0x9bda4bb4	edma_set_src
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c0bd51f	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x9c3737fc	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x9c4658e1	elevator_change
++EXPORT_SYMBOL vmlinux 0x9c745cbf	ptp_clock_index
++EXPORT_SYMBOL vmlinux 0x9c97082e	edma_pause
++EXPORT_SYMBOL vmlinux 0x9c98ddd1	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x9c9ec2a0	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cb569ca	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x9cd60539	sg_free_table
++EXPORT_SYMBOL vmlinux 0x9cd627c9	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x9ceb163c	memcpy_toiovec
++EXPORT_SYMBOL vmlinux 0x9cf1fb85	page_symlink
++EXPORT_SYMBOL vmlinux 0x9cf5afeb	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x9cfd56c5	scsi_print_status
++EXPORT_SYMBOL vmlinux 0x9d009e3d	block_commit_write
++EXPORT_SYMBOL vmlinux 0x9d05f6c4	ktime_get_clocktai
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d2d1170	bio_integrity_tag_size
++EXPORT_SYMBOL vmlinux 0x9d32931f	dump_seek
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d60599d	dss_mgr_unregister_framedone_handler
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d97fca7	force_sig
++EXPORT_SYMBOL vmlinux 0x9d9b2d45	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x9d9c6984	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x9d9f2525	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0x9da5eb5b	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x9dfbad91	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2000a7	memcpy_toiovecend
++EXPORT_SYMBOL vmlinux 0x9e26c662	kern_path_create
++EXPORT_SYMBOL vmlinux 0x9e428c6e	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x9e44b9b7	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL vmlinux 0x9e78c2b4	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x9e9f1714	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0x9eaf7798	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL vmlinux 0x9ec9e394	kthread_stop
++EXPORT_SYMBOL vmlinux 0x9ecc6a7a	interruptible_sleep_on
++EXPORT_SYMBOL vmlinux 0x9ecd4a79	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0x9ecf414e	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x9ed685ee	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x9edaec7d	block_write_end
++EXPORT_SYMBOL vmlinux 0x9effaf17	padata_start
++EXPORT_SYMBOL vmlinux 0x9f226a74	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x9f2bdaac	__bitmap_or
++EXPORT_SYMBOL vmlinux 0x9f3741f6	vfs_write
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f491e5d	ftrace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x9f6123b5	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x9f823cea	dispc_mgr_is_enabled
++EXPORT_SYMBOL vmlinux 0x9f8acaaf	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x9f8efc49	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x9f9115e3	set_user_nice
++EXPORT_SYMBOL vmlinux 0x9f95e7aa	omap_dss_register_driver
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fa4a965	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x9fb3dd30	memcpy_fromiovec
++EXPORT_SYMBOL vmlinux 0x9fbd9991	mmc_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x9fce4c44	sock_from_file
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe08376	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0x9fff448c	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xa01a4185	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0xa026af42	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xa02d6d6b	kernel_bind
++EXPORT_SYMBOL vmlinux 0xa038ba2c	ip_mc_rejoin_groups
++EXPORT_SYMBOL vmlinux 0xa03b3f85	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xa0421337	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xa045a3ed	ftrace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa0576437	tegra_ahb_enable_smmu
++EXPORT_SYMBOL vmlinux 0xa058a06a	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa068f283	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa0aae687	imx_ssi_fiq_end
++EXPORT_SYMBOL vmlinux 0xa0ab60be	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0bc2305	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0xa0c1c1ed	get_write_access
++EXPORT_SYMBOL vmlinux 0xa0c93489	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xa0ce17f5	phy_driver_register
++EXPORT_SYMBOL vmlinux 0xa0ceef51	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xa0fa204c	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa109119f	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xa10aef27	alloc_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa13589ed	request_key_async
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa1484ed2	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0xa14f3d8c	ewma_add
++EXPORT_SYMBOL vmlinux 0xa14f534a	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xa153e0d8	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0xa16ddc53	snd_pcm_lib_read
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c33c83	dquot_resume
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1cd0013	__mutex_init
++EXPORT_SYMBOL vmlinux 0xa1d55e90	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xa1d820bf	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0xa1eb0dda	unlock_page
++EXPORT_SYMBOL vmlinux 0xa1ed7f34	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xa1f0ebea	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xa1f9ddae	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0xa20ce1b8	net_msg_warn
++EXPORT_SYMBOL vmlinux 0xa22aac33	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xa23722af	dev_addr_init
++EXPORT_SYMBOL vmlinux 0xa250c838	param_get_charp
++EXPORT_SYMBOL vmlinux 0xa2814405	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa286c34a	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xa29a957a	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xa2a5fd77	inet_ehash_secret
++EXPORT_SYMBOL vmlinux 0xa2b17305	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0xa2d8793a	inet_shutdown
++EXPORT_SYMBOL vmlinux 0xa2df6c66	set_nlink
++EXPORT_SYMBOL vmlinux 0xa2ef34d7	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xa2fa436b	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0xa2fd64b4	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xa30cdce7	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0xa316c599	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0xa31e44ba	edma_free_channel
++EXPORT_SYMBOL vmlinux 0xa31fd68b	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xa333a52a	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL vmlinux 0xa33ed52d	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xa34da209	genphy_update_link
++EXPORT_SYMBOL vmlinux 0xa34f1ef5	crc32_le
++EXPORT_SYMBOL vmlinux 0xa35444e4	dispc_write_irqenable
++EXPORT_SYMBOL vmlinux 0xa35de80f	ipv4_config
++EXPORT_SYMBOL vmlinux 0xa35f9912	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0xa3712d4f	simple_rename
++EXPORT_SYMBOL vmlinux 0xa378208a	mmc_resume_host
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa38e31bd	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xa3f35bf5	rwsem_is_locked
++EXPORT_SYMBOL vmlinux 0xa402aaa2	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xa403c2ba	grab_cache_page_nowait
++EXPORT_SYMBOL vmlinux 0xa40d2280	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xa414882d	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xa41adb2d	vga_tryget
++EXPORT_SYMBOL vmlinux 0xa4201ee9	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xa42b216f	sock_i_ino
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa43b9539	memcpy_fromiovecend
++EXPORT_SYMBOL vmlinux 0xa43e9030	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0xa452ec0a	omap_video_timings_to_videomode
++EXPORT_SYMBOL vmlinux 0xa4555ba8	elm_config
++EXPORT_SYMBOL vmlinux 0xa4592203	iget_failed
++EXPORT_SYMBOL vmlinux 0xa4610bc6	omap_rev
++EXPORT_SYMBOL vmlinux 0xa46c0a33	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa48d1e44	sock_no_bind
++EXPORT_SYMBOL vmlinux 0xa48f5b09	omap_dma_set_global_params
++EXPORT_SYMBOL vmlinux 0xa49e0838	snd_timer_close
++EXPORT_SYMBOL vmlinux 0xa4b42c55	omap_set_dma_priority
++EXPORT_SYMBOL vmlinux 0xa4c43d7d	posix_lock_file
++EXPORT_SYMBOL vmlinux 0xa4dbb9d3	journal_get_create_access
++EXPORT_SYMBOL vmlinux 0xa506f3bb	bdevname
++EXPORT_SYMBOL vmlinux 0xa5080ae0	arp_find
++EXPORT_SYMBOL vmlinux 0xa50a111e	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xa5233101	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa5569b36	inet_del_offload
++EXPORT_SYMBOL vmlinux 0xa560ddca	netdev_err
++EXPORT_SYMBOL vmlinux 0xa5642ffc	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xa577a850	param_get_short
++EXPORT_SYMBOL vmlinux 0xa57f4965	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0xa58fea9d	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xa597d9d7	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa598f6a7	dm_get_mapinfo
++EXPORT_SYMBOL vmlinux 0xa5cef8ad	release_resource
++EXPORT_SYMBOL vmlinux 0xa5d31df2	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xa5d7b20f	dquot_commit
++EXPORT_SYMBOL vmlinux 0xa5dd45f3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xa5f7f3db	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xa609a707	cad_pid
++EXPORT_SYMBOL vmlinux 0xa61a1e3e	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL vmlinux 0xa61e4362	omap_request_dma
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa64a4cea	usb_nop_xceiv_unregister
++EXPORT_SYMBOL vmlinux 0xa6715115	do_settimeofday
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa684f58a	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0xa6882fbc	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa6a31e73	may_umount
++EXPORT_SYMBOL vmlinux 0xa6bab23d	dqstats
++EXPORT_SYMBOL vmlinux 0xa6c2fa79	eth_header
++EXPORT_SYMBOL vmlinux 0xa6c81774	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xa6eb9f44	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xa6fb66d5	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xa7006534	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xa70423db	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xa72820ec	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xa7282c18	__d_drop
++EXPORT_SYMBOL vmlinux 0xa72a4303	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xa72e2b4b	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xa734a3e9	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa73fc98f	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xa77992c3	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xa77a369d	idr_init
++EXPORT_SYMBOL vmlinux 0xa77e168b	___pskb_trim
++EXPORT_SYMBOL vmlinux 0xa77ef61c	skb_put
++EXPORT_SYMBOL vmlinux 0xa7aecab9	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0xa7e07183	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0xa7e420ff	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xa808bcb8	vexpress_config_wait
++EXPORT_SYMBOL vmlinux 0xa80db0d5	generic_file_buffered_write
++EXPORT_SYMBOL vmlinux 0xa8232c78	strtobool
++EXPORT_SYMBOL vmlinux 0xa83c7af1	bio_integrity_set_tag
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa852f656	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0xa85eafa5	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xa865e033	tty_write_room
++EXPORT_SYMBOL vmlinux 0xa86c1e76	dev_emerg
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa89b53ca	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xa8b8da4a	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xa8bd26f1	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xa8be236d	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0xa8be3aac	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0xa8db52aa	file_ns_capable
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa9165097	dst_destroy
++EXPORT_SYMBOL vmlinux 0xa92b19db	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0xa95d8d34	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xa964dd13	gpmc_cs_request
++EXPORT_SYMBOL vmlinux 0xa9685d96	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0xa97b545d	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xa98b51fc	dss_mgr_enable
++EXPORT_SYMBOL vmlinux 0xa999f9e5	simple_link
++EXPORT_SYMBOL vmlinux 0xa9cee019	block_write_begin
++EXPORT_SYMBOL vmlinux 0xa9d182e7	kill_bdev
++EXPORT_SYMBOL vmlinux 0xa9effda5	__first_cpu
++EXPORT_SYMBOL vmlinux 0xaa1e9785	dquot_get_dqinfo
++EXPORT_SYMBOL vmlinux 0xaa2c71c7	names_cachep
++EXPORT_SYMBOL vmlinux 0xaa3d2602	snd_ctl_rename_id
++EXPORT_SYMBOL vmlinux 0xaa5927f9	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0xaa656040	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6dc6ff	amba_release_regions
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa72c798	__frontswap_load
++EXPORT_SYMBOL vmlinux 0xaa83fd05	__f_setown
++EXPORT_SYMBOL vmlinux 0xaa9a5a3d	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0xaa9c6172	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xaab2644e	dss_mgr_connect
++EXPORT_SYMBOL vmlinux 0xaab2dfc6	tty_check_change
++EXPORT_SYMBOL vmlinux 0xaac643c3	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xab01504b	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xab1d6cc1	param_get_long
++EXPORT_SYMBOL vmlinux 0xab20d18a	edma_filter_fn
++EXPORT_SYMBOL vmlinux 0xab536a45	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xab554bbc	omapdss_output_set_device
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab677d10	journal_update_format
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab72f759	omap_dss_find_output_by_node
++EXPORT_SYMBOL vmlinux 0xab7603e7	imx_ssi_fiq_start
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab82d419	vfs_open
++EXPORT_SYMBOL vmlinux 0xab88751b	snd_dma_get_reserved_buf
++EXPORT_SYMBOL vmlinux 0xab9d8cd8	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xabb93c59	blk_free_tags
++EXPORT_SYMBOL vmlinux 0xabba2932	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd0c91c	rtc_time_to_tm
++EXPORT_SYMBOL vmlinux 0xabdd57c3	wireless_send_event
++EXPORT_SYMBOL vmlinux 0xabe1e7ee	bmap
++EXPORT_SYMBOL vmlinux 0xabee4648	vfs_follow_link
++EXPORT_SYMBOL vmlinux 0xabf41485	register_exec_domain
++EXPORT_SYMBOL vmlinux 0xabf99f56	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac22a66a	nand_lock
++EXPORT_SYMBOL vmlinux 0xac3860b4	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xac5cd1dd	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0xac7a93f3	fget_light
++EXPORT_SYMBOL vmlinux 0xac8bcfb3	mntput
++EXPORT_SYMBOL vmlinux 0xac8d05e2	dss_mgr_disconnect
++EXPORT_SYMBOL vmlinux 0xac8f37b2	outer_cache
++EXPORT_SYMBOL vmlinux 0xac9edabd	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacddf7b3	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0xace3c463	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad46dec2	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xad6d815e	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad92dafd	sk_reset_txq
++EXPORT_SYMBOL vmlinux 0xada4b084	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0xadb5559d	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xadb6ec8a	__bforget
++EXPORT_SYMBOL vmlinux 0xadb86db7	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0xadc2458c	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0xadd7f351	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0xade0347f	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL vmlinux 0xadf42bd5	__request_region
++EXPORT_SYMBOL vmlinux 0xadff1fe9	proc_set_user
++EXPORT_SYMBOL vmlinux 0xae208cbe	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0xae46be28	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0xae5a5a19	set_groups
++EXPORT_SYMBOL vmlinux 0xae729e59	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0xae8505d5	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xae89646b	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0xae8d7f76	pps_lookup_dev
++EXPORT_SYMBOL vmlinux 0xae9f70c1	netlink_set_err
++EXPORT_SYMBOL vmlinux 0xaeaa1d9e	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xaebb75a3	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xaec46144	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaeefbeed	kset_unregister
++EXPORT_SYMBOL vmlinux 0xaef7858c	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xaefd4ee6	security_path_chown
++EXPORT_SYMBOL vmlinux 0xaf05b91b	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xaf308e86	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0xaf3b511c	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf46e799	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xaf50e76d	elf_set_personality
++EXPORT_SYMBOL vmlinux 0xaf5f7994	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xaf67d0fd	snd_pcm_lib_writev
++EXPORT_SYMBOL vmlinux 0xaf8aa518	system_rev
++EXPORT_SYMBOL vmlinux 0xaf911adb	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0xaf91d89f	__kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xaf926625	sk_common_release
++EXPORT_SYMBOL vmlinux 0xafaf0572	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL vmlinux 0xafb3481d	simple_statfs
++EXPORT_SYMBOL vmlinux 0xafbce463	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xafc5f5eb	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xafdb9836	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xafea1d3f	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0xb00fc365	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xb01235e0	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xb0399ba0	register_gifconf
++EXPORT_SYMBOL vmlinux 0xb04cf0fe	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xb05a0358	snd_timer_interrupt
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb061d59f	scsi_print_command
++EXPORT_SYMBOL vmlinux 0xb065b320	snd_jack_set_parent
++EXPORT_SYMBOL vmlinux 0xb08a3333	nf_register_hook
++EXPORT_SYMBOL vmlinux 0xb09138fe	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b847ac	__bitmap_full
++EXPORT_SYMBOL vmlinux 0xb0bab6d8	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0e90ecf	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xb0ffda2f	blk_limits_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb1279463	phy_device_register
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb1656234	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0xb16fb67a	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xb19538bc	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xb19760c3	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d9aabd	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xb237c716	snd_info_register
++EXPORT_SYMBOL vmlinux 0xb245be14	vga_put
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb288c675	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xb29cc80f	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xb2a6df7c	proc_remove
++EXPORT_SYMBOL vmlinux 0xb2b94674	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2cdbd75	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xb2d307de	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2e39b69	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL vmlinux 0xb302363d	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xb310c92a	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0xb31efd6c	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xb3421be4	__netdev_pick_tx
++EXPORT_SYMBOL vmlinux 0xb367c984	mxc_set_irq_fiq
++EXPORT_SYMBOL vmlinux 0xb37f5d8f	tcp_valid_rtt_meas
++EXPORT_SYMBOL vmlinux 0xb39e9a2d	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xb3a5538a	ip6_xmit
++EXPORT_SYMBOL vmlinux 0xb3cfd25a	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3fba461	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0xb40bd486	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xb414799e	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0xb418473c	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4392ec0	bio_reset
++EXPORT_SYMBOL vmlinux 0xb44c4c30	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xb44cf460	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0xb45023fd	journal_restart
++EXPORT_SYMBOL vmlinux 0xb45f6807	pci_get_device
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb472697e	bioset_free
++EXPORT_SYMBOL vmlinux 0xb4850c86	nf_reinject
++EXPORT_SYMBOL vmlinux 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL vmlinux 0xb4c8f38a	omap_dma_chain_status
++EXPORT_SYMBOL vmlinux 0xb4dc53de	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0xb5188d60	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xb51ec336	deactivate_super
++EXPORT_SYMBOL vmlinux 0xb52e336c	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xb532ee58	mmc_start_req
++EXPORT_SYMBOL vmlinux 0xb537ffd7	inet6_release
++EXPORT_SYMBOL vmlinux 0xb53d5e14	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0xb54088a3	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0xb54533f7	usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xb5524265	omap_dss_get_output
++EXPORT_SYMBOL vmlinux 0xb5582f6b	override_creds
++EXPORT_SYMBOL vmlinux 0xb55a1b10	init_task
++EXPORT_SYMBOL vmlinux 0xb562d247	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb5792723	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5be1bac	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5cd1691	vexpress_config_complete
++EXPORT_SYMBOL vmlinux 0xb5d83b0f	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb5e28a76	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0xb5ff279d	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xb608c2e8	task_nice
++EXPORT_SYMBOL vmlinux 0xb614aa3c	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xb63d3192	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0xb64a5ee3	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xb6652413	omapdss_sdi_display_disable
++EXPORT_SYMBOL vmlinux 0xb67390cb	tty_unlock_pair
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb67b03c8	__lru_cache_add
++EXPORT_SYMBOL vmlinux 0xb6822a33	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb68f8894	nf_afinfo
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a660d0	follow_up
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6c5a973	scsi_show_result
++EXPORT_SYMBOL vmlinux 0xb70c1482	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xb70ef994	bioset_create
++EXPORT_SYMBOL vmlinux 0xb7132188	blk_queue_merge_bvec
++EXPORT_SYMBOL vmlinux 0xb71fb74f	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xb72f8a87	tty_port_open
++EXPORT_SYMBOL vmlinux 0xb73117ff	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0xb74ca282	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xb78a37d4	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xb791e119	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xb79fd068	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xb7a7241b	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xb7b61546	crc32_be
++EXPORT_SYMBOL vmlinux 0xb7ba76c7	__aeabi_unwind_cpp_pr2
++EXPORT_SYMBOL vmlinux 0xb7bec291	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xb7c1cdb9	seq_open_private
++EXPORT_SYMBOL vmlinux 0xb80eb552	misc_deregister
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb82f8f41	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xb835b3e4	radix_tree_prev_hole
++EXPORT_SYMBOL vmlinux 0xb86ad4b1	pci_scan_bus_parented
++EXPORT_SYMBOL vmlinux 0xb86df9a9	bdget_disk
++EXPORT_SYMBOL vmlinux 0xb8722bcb	snd_pci_quirk_lookup
++EXPORT_SYMBOL vmlinux 0xb87262c0	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb89a0739	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xb8a00d0a	amba_driver_unregister
++EXPORT_SYMBOL vmlinux 0xb8a668c9	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xb8aa2342	__check_region
++EXPORT_SYMBOL vmlinux 0xb8aecf0f	generic_setlease
++EXPORT_SYMBOL vmlinux 0xb8b1e71f	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xb8b248a3	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xb8e0ed1c	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8ef7a43	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0xb8f513f0	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0xb8f89e5b	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0xb916e533	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0xb9215138	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0xb922f454	tc6393xb_lcd_mode
++EXPORT_SYMBOL vmlinux 0xb92e22fa	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xb93e7f67	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xb946850f	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL vmlinux 0xb95f98d6	_memset_io
++EXPORT_SYMBOL vmlinux 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL vmlinux 0xb97f1a0b	proc_mkdir
++EXPORT_SYMBOL vmlinux 0xb98a0185	rtc_tm_to_time
++EXPORT_SYMBOL vmlinux 0xb99d1b2c	__elv_add_request
++EXPORT_SYMBOL vmlinux 0xb9a8f03b	omap_stop_dma
++EXPORT_SYMBOL vmlinux 0xb9acd3d9	__put_user_2
++EXPORT_SYMBOL vmlinux 0xb9b34653	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xb9c1164e	padata_stop
++EXPORT_SYMBOL vmlinux 0xb9cd8e82	udp_proc_register
++EXPORT_SYMBOL vmlinux 0xb9e815ce	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xb9fee36a	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xba02cd27	ps2_init
++EXPORT_SYMBOL vmlinux 0xba1f662d	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xba2ecee7	generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0xba3bbd38	pid_task
++EXPORT_SYMBOL vmlinux 0xba459030	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba5aff57	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xba6ed31f	mem_map
++EXPORT_SYMBOL vmlinux 0xba7d870a	__mxc_cpu_type
++EXPORT_SYMBOL vmlinux 0xba8b18f9	blk_init_queue
++EXPORT_SYMBOL vmlinux 0xba8e8a24	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xba9e9e5c	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0xbaac427c	get_mem_type
++EXPORT_SYMBOL vmlinux 0xbaeffa05	qid_eq
++EXPORT_SYMBOL vmlinux 0xbafeee36	dispc_runtime_get
++EXPORT_SYMBOL vmlinux 0xbb03fb85	pps_event
++EXPORT_SYMBOL vmlinux 0xbb0448f6	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xbb0924bc	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xbb120d42	unregister_console
++EXPORT_SYMBOL vmlinux 0xbb189cad	disallow_signal
++EXPORT_SYMBOL vmlinux 0xbb1aad45	follow_down
++EXPORT_SYMBOL vmlinux 0xbb1f8718	mount_subtree
++EXPORT_SYMBOL vmlinux 0xbb3fb56b	dev_err
++EXPORT_SYMBOL vmlinux 0xbb49400c	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb713e6d	sk_filter_release_rcu
++EXPORT_SYMBOL vmlinux 0xbb72d4fe	__put_user_1
++EXPORT_SYMBOL vmlinux 0xbb753617	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xbb85fa5a	pci_save_state
++EXPORT_SYMBOL vmlinux 0xbb8ca00a	module_refcount
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbf9b239	generic_permission
++EXPORT_SYMBOL vmlinux 0xbc10dd97	__put_user_4
++EXPORT_SYMBOL vmlinux 0xbc1a3dbf	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0xbc2edcdb	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0xbc6bf286	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xbc89ede4	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcc4ceb7	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0xbcdedba7	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xbce0b817	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0xbd12a578	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xbd197ba4	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xbd468435	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0xbd957fea	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xbd96c85a	vexpress_config_write
++EXPORT_SYMBOL vmlinux 0xbdba9828	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xbdbbe68f	single_release
++EXPORT_SYMBOL vmlinux 0xbdd17b24	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0xbdec97c2	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xbded5a92	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xbdf2580d	__raw_readsl
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe254e92	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xbe2c0274	add_timer
++EXPORT_SYMBOL vmlinux 0xbe334969	create_syslog_header
++EXPORT_SYMBOL vmlinux 0xbe520209	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0xbe63ee40	request_resource
++EXPORT_SYMBOL vmlinux 0xbe6f9037	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xbe8860a8	dispc_mgr_go_busy
++EXPORT_SYMBOL vmlinux 0xbe8fb90c	dispc_mgr_get_framedone_irq
++EXPORT_SYMBOL vmlinux 0xbea25545	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0xbeaa8d2f	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xbebb697d	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0xbec04a79	check_disk_change
++EXPORT_SYMBOL vmlinux 0xbec2094b	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0xbec25473	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0xbed4c302	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0xbee401f8	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xbee8bf26	key_validate
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf0100f2	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xbf20389c	blk_run_queue
++EXPORT_SYMBOL vmlinux 0xbf32b624	simple_readpage
++EXPORT_SYMBOL vmlinux 0xbf35cb67	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xbf366914	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0xbf75ea6c	tegra114_clock_tune_cpu_trimmers_low
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfb71709	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0xbfbda65e	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xbfc407b4	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfcbc0d2	stmp_reset_block
++EXPORT_SYMBOL vmlinux 0xbfdfb54f	kset_register
++EXPORT_SYMBOL vmlinux 0xbfe57487	do_sync_write
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xbff92581	notify_change
++EXPORT_SYMBOL vmlinux 0xc019a8ea	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0xc0204698	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xc02cf69b	clkdev_drop
++EXPORT_SYMBOL vmlinux 0xc04584e2	genlmsg_put
++EXPORT_SYMBOL vmlinux 0xc05482bc	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xc05f08b7	d_delete
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc0a6a8c5	omap_set_dma_dest_burst_mode
++EXPORT_SYMBOL vmlinux 0xc0a98385	profile_pc
++EXPORT_SYMBOL vmlinux 0xc0b28abf	kdb_current_task
++EXPORT_SYMBOL vmlinux 0xc0b8a323	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0xc0cf95f9	omap_vrfb_request_ctx
++EXPORT_SYMBOL vmlinux 0xc0d4a421	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xc0fcab8e	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xc10c0019	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc12ec3a6	dns_query
++EXPORT_SYMBOL vmlinux 0xc133d8fd	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xc15b9796	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xc178ebea	blk_start_request
++EXPORT_SYMBOL vmlinux 0xc182dacb	__kfree_skb
++EXPORT_SYMBOL vmlinux 0xc19e1210	snd_power_wait
++EXPORT_SYMBOL vmlinux 0xc1a0cc80	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xc1c2dd09	__hw_addr_flush
++EXPORT_SYMBOL vmlinux 0xc1cf6de1	dquot_drop
++EXPORT_SYMBOL vmlinux 0xc1f1ff8c	tty_pair_get_tty
++EXPORT_SYMBOL vmlinux 0xc1f582a5	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xc2020d2d	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0xc2073aa5	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xc2081a83	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0xc20f2038	__generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0xc2165d85	__arm_iounmap
++EXPORT_SYMBOL vmlinux 0xc221078a	prepare_creds
++EXPORT_SYMBOL vmlinux 0xc22b50ad	param_set_bint
++EXPORT_SYMBOL vmlinux 0xc2404532	kern_unmount
++EXPORT_SYMBOL vmlinux 0xc24deb94	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0xc25113cf	iterate_mounts
++EXPORT_SYMBOL vmlinux 0xc256e762	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xc29eca1f	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xc2a0bb8e	log_wait_commit
++EXPORT_SYMBOL vmlinux 0xc2ae712e	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xc2b8e5bd	journal_forget
++EXPORT_SYMBOL vmlinux 0xc2be9bdf	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xc2d3a3c6	audit_log_start
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2d7abec	dev_activate
++EXPORT_SYMBOL vmlinux 0xc2dfc128	mdiobus_free
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2ed7514	mdiobus_register
++EXPORT_SYMBOL vmlinux 0xc2f9c045	timespec_to_jiffies
++EXPORT_SYMBOL vmlinux 0xc3071da7	simple_unlink
++EXPORT_SYMBOL vmlinux 0xc30def7b	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xc31d8d36	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xc359fb65	abort
++EXPORT_SYMBOL vmlinux 0xc3666d4d	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xc369b750	phy_device_free
++EXPORT_SYMBOL vmlinux 0xc36a3f8c	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0xc38223cd	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xc382d9d4	pci_match_id
++EXPORT_SYMBOL vmlinux 0xc3a98926	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0xc3c2b8db	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xc3c6e5ed	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0xc3d1fa4d	edma_alloc_cont_slots
++EXPORT_SYMBOL vmlinux 0xc3f0a1f1	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xc3f6ef57	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xc3ff776f	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xc411a841	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0xc413bac5	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc42aef2f	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xc438d5c3	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4b75ed8	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0xc4b97d88	netdev_emerg
++EXPORT_SYMBOL vmlinux 0xc4c17147	dst_discard
++EXPORT_SYMBOL vmlinux 0xc4d1446b	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xc4f12911	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xc4f21506	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0xc50e2d5a	dquot_operations
++EXPORT_SYMBOL vmlinux 0xc52da066	omap_set_dma_dest_params
++EXPORT_SYMBOL vmlinux 0xc5539a96	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0xc57c309e	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xc5bc71a1	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0xc5dd5ad4	pci_bus_type
++EXPORT_SYMBOL vmlinux 0xc5f20c6d	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xc5fcf5c0	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc6037a71	of_device_alloc
++EXPORT_SYMBOL vmlinux 0xc607aa6b	simple_open
++EXPORT_SYMBOL vmlinux 0xc62b32b2	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc665d6d7	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xc673bee7	devm_request_and_ioremap
++EXPORT_SYMBOL vmlinux 0xc6ab1ee0	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0xc6c501ec	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6f1a7d3	__mem_cgroup_count_vm_event
++EXPORT_SYMBOL vmlinux 0xc702156b	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xc717160a	vexpress_config_bridge_register
++EXPORT_SYMBOL vmlinux 0xc71ab977	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc7260bf8	tty_pair_get_pty
++EXPORT_SYMBOL vmlinux 0xc72c6abf	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0xc749941b	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xc74c85e8	do_splice_to
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7ae743b	kfree_skb
++EXPORT_SYMBOL vmlinux 0xc7bcbc8d	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xc7c43c5d	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xc7df707f	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc805981e	snd_timer_open
++EXPORT_SYMBOL vmlinux 0xc80743b0	simple_map_init
++EXPORT_SYMBOL vmlinux 0xc81f1ea7	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0xc823ef70	update_region
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc847120b	key_invalidate
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc84ecaff	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0xc84f8bf0	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xc8511c75	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xc869fa4a	da903x_query_status
++EXPORT_SYMBOL vmlinux 0xc86ae106	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xc8901e33	iget5_locked
++EXPORT_SYMBOL vmlinux 0xc8a0517d	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8bdea3d	genphy_read_status
++EXPORT_SYMBOL vmlinux 0xc8ddcf85	md_done_sync
++EXPORT_SYMBOL vmlinux 0xc8e0e7d2	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL vmlinux 0xc8f36b20	kobject_init
++EXPORT_SYMBOL vmlinux 0xc92cd3bf	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0xc93066e0	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0xc93a2f4d	edma_free_cont_slots
++EXPORT_SYMBOL vmlinux 0xc9687c93	clear_nlink
++EXPORT_SYMBOL vmlinux 0xc970a889	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0xc996d097	del_timer
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9bceb35	alloc_file
++EXPORT_SYMBOL vmlinux 0xc9db8ea3	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0xc9dd9c24	pci_set_ltr
++EXPORT_SYMBOL vmlinux 0xc9f0dc29	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0xca3d83d4	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xca5967e3	vm_stat
++EXPORT_SYMBOL vmlinux 0xca5dbc50	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xca6ce8ba	omap_dss_ntsc_timings
++EXPORT_SYMBOL vmlinux 0xca711dd7	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0xca71dd92	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xca7ee34e	__blk_end_request
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcaa94a28	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0xcaaed157	km_report
++EXPORT_SYMBOL vmlinux 0xcac96fd4	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0xcad50ab8	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xcaddbd7e	edma_set_dest_index
++EXPORT_SYMBOL vmlinux 0xcae91017	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb17d95a	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0xcb2557ea	kobject_add
++EXPORT_SYMBOL vmlinux 0xcb466063	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xcb478556	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0xcb5c9712	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xcb6c6b04	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xcb7d0b78	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0xcbbbcd5b	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcc1b21cf	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc37f55c	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0xcc4b84da	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc7fa952	local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0xcc93efdc	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0xccab113f	inet_add_offload
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xccd71f0a	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xccecf37c	set_bdi_congested
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd30b95a	tmio_core_mmc_clk_div
++EXPORT_SYMBOL vmlinux 0xcd38e328	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0xcd3cb1de	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xcd4e8ba6	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0xcd569b20	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xcd63c845	__aeabi_lasr
++EXPORT_SYMBOL vmlinux 0xcd674538	register_netdevice
++EXPORT_SYMBOL vmlinux 0xcd93e60e	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0xcd944973	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0xcdbfe8ca	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcddac067	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xcddf1c13	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xcde172ac	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0xcdfc5e52	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0xce1fae57	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce5d9cdf	empty_aops
++EXPORT_SYMBOL vmlinux 0xcea5366f	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0xcea605b0	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xcea63214	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xcea79bd6	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0xcee513c0	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0xcef3e9b5	omapdss_default_get_resolution
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf1c4155	tegra_powergate_sequence_power_up
++EXPORT_SYMBOL vmlinux 0xcf44cb25	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xcf49417a	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0xcf5da930	tcp_gro_receive
++EXPORT_SYMBOL vmlinux 0xcf6d88ec	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0xcf87d133	_snd_ctl_add_slave
++EXPORT_SYMBOL vmlinux 0xcf88625f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xcfc74809	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xcfcab3ce	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xcfd20f43	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xcfe7bd7c	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0xcfe95b43	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xcfea66ff	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xcff6b676	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0xcffabc4d	security_path_link
++EXPORT_SYMBOL vmlinux 0xd01616e4	dev_addr_del
++EXPORT_SYMBOL vmlinux 0xd0181f4f	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xd01c7629	genl_register_ops
++EXPORT_SYMBOL vmlinux 0xd038668d	scsi_setup_blk_pc_cmnd
++EXPORT_SYMBOL vmlinux 0xd0493846	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd0a0370f	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0xd0a34964	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0b5d3c1	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xd0cb4b57	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL vmlinux 0xd0d42c42	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0xd0e1fa3f	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xd0e43207	usb_nop_xceiv_register
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f1864d	seq_release
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fdd00e	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xd1067ba7	dispc_ovl_enabled
++EXPORT_SYMBOL vmlinux 0xd1157735	release_and_free_resource
++EXPORT_SYMBOL vmlinux 0xd11c0dc1	__kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xd123a3b7	netlink_ack
++EXPORT_SYMBOL vmlinux 0xd131d71f	path_get
++EXPORT_SYMBOL vmlinux 0xd13bfec2	nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0xd13c51ea	journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xd13d47cf	noop_llseek
++EXPORT_SYMBOL vmlinux 0xd152890e	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0xd16c93f8	register_qdisc
++EXPORT_SYMBOL vmlinux 0xd17c01b7	task_tgid_nr_ns
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd18c681f	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1e083bb	snd_add_device_sysfs_file
++EXPORT_SYMBOL vmlinux 0xd1e73396	pipe_lock
++EXPORT_SYMBOL vmlinux 0xd1ea43f4	journal_init_dev
++EXPORT_SYMBOL vmlinux 0xd21af53e	amba_device_register
++EXPORT_SYMBOL vmlinux 0xd220cf8a	jiffies_to_timespec
++EXPORT_SYMBOL vmlinux 0xd2337e76	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd2693c21	omapdss_default_get_timings
++EXPORT_SYMBOL vmlinux 0xd270c1e3	bio_copy_user
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd286000a	__inet6_hash
++EXPORT_SYMBOL vmlinux 0xd2adf463	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2b73f94	journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xd2d1a5ac	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2eef359	open_exec
++EXPORT_SYMBOL vmlinux 0xd30bc6fc	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd3241425	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0xd328ab44	free_netdev
++EXPORT_SYMBOL vmlinux 0xd32cf003	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0xd32f7e48	account_page_redirty
++EXPORT_SYMBOL vmlinux 0xd343fa5d	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0xd344232f	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xd38622ec	ptp_clock_event
++EXPORT_SYMBOL vmlinux 0xd3983caf	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0xd3ad90aa	blk_get_backing_dev_info
++EXPORT_SYMBOL vmlinux 0xd3b86e75	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xd3d3a477	posix_acl_init
++EXPORT_SYMBOL vmlinux 0xd3dbfbc4	_find_first_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xd3dcab0b	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xd3e6f60d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xd3e7515e	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xd3e90395	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0xd3f4df0d	file_open_root
++EXPORT_SYMBOL vmlinux 0xd418e1c0	adjust_resource
++EXPORT_SYMBOL vmlinux 0xd41db421	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0xd41fe818	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd432c2e8	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xd434526f	snd_pcm_release_substream
++EXPORT_SYMBOL vmlinux 0xd456425d	kobject_set_name
++EXPORT_SYMBOL vmlinux 0xd459c1dd	pm860x_page_reg_read
++EXPORT_SYMBOL vmlinux 0xd4669fad	complete
++EXPORT_SYMBOL vmlinux 0xd4e67a67	wake_up_process
++EXPORT_SYMBOL vmlinux 0xd4ebf7a4	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0xd5152710	sg_next
++EXPORT_SYMBOL vmlinux 0xd5416103	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0xd54a70a2	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0xd54d6835	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0xd564e434	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xd56e9485	omap_set_dma_dest_index
++EXPORT_SYMBOL vmlinux 0xd579366f	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0xd5913715	skb_checksum
++EXPORT_SYMBOL vmlinux 0xd5b1376d	register_shrinker
++EXPORT_SYMBOL vmlinux 0xd5bb0b67	tc6393xb_lcd_set_power
++EXPORT_SYMBOL vmlinux 0xd5c5ff75	inet_frags_init_net
++EXPORT_SYMBOL vmlinux 0xd5ce7646	kunmap
++EXPORT_SYMBOL vmlinux 0xd5cf15e7	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xd5eb46a8	input_event
++EXPORT_SYMBOL vmlinux 0xd5f2172f	del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd61347c6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd613bfa3	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd6583ead	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd69b9f5b	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xd6c2f97b	key_revoke
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd70eaa42	__sb_start_write
++EXPORT_SYMBOL vmlinux 0xd72dc202	nand_scan_tail
++EXPORT_SYMBOL vmlinux 0xd74289f9	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd75f17c4	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0xd77a5aa5	__bitmap_and
++EXPORT_SYMBOL vmlinux 0xd78025ae	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xd79b5a02	allow_signal
++EXPORT_SYMBOL vmlinux 0xd7ae2361	vexpress_config_bridge_unregister
++EXPORT_SYMBOL vmlinux 0xd7affc47	sg_miter_start
++EXPORT_SYMBOL vmlinux 0xd7b4599b	__idr_get_new_above
++EXPORT_SYMBOL vmlinux 0xd7d10dae	km_new_mapping
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7edd710	ps2_command
++EXPORT_SYMBOL vmlinux 0xd7f08cae	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xd7f93a8f	netdev_class_remove_file
++EXPORT_SYMBOL vmlinux 0xd82ef3af	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0xd850882c	vfs_rename
++EXPORT_SYMBOL vmlinux 0xd8553509	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0xd85cd67e	__wake_up
++EXPORT_SYMBOL vmlinux 0xd8aa2502	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0xd8c2a006	sys_fillrect
++EXPORT_SYMBOL vmlinux 0xd8dbf8f5	tty_throttle
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd8e8bb03	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0xd8fa2b35	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xd9005dbe	snd_register_device_for_dev
++EXPORT_SYMBOL vmlinux 0xd90f25fe	skb_copy
++EXPORT_SYMBOL vmlinux 0xd91db562	snd_ctl_make_virtual_master
++EXPORT_SYMBOL vmlinux 0xd92afabe	bitmap_clear
++EXPORT_SYMBOL vmlinux 0xd955d2b7	omap_set_dma_dest_data_pack
++EXPORT_SYMBOL vmlinux 0xd958cc31	snd_ctl_notify
++EXPORT_SYMBOL vmlinux 0xd95d94cb	new_inode
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd9924047	snd_pcm_notify
++EXPORT_SYMBOL vmlinux 0xd99241b1	__dst_free
++EXPORT_SYMBOL vmlinux 0xd9928dcc	simple_getattr
++EXPORT_SYMBOL vmlinux 0xd993267b	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xd9a9bb30	getname
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9df8f1f	update_devfreq
++EXPORT_SYMBOL vmlinux 0xd9e1fa2d	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0xd9e61fcb	qid_valid
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda6441fa	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8652a8	__vlan_find_dev_deep
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8b54bb	module_layout
++EXPORT_SYMBOL vmlinux 0xda9ed42a	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0xdaa00886	vfs_link
++EXPORT_SYMBOL vmlinux 0xdaa16b82	of_clk_get
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaafc807	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xdab7bdc2	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0xdabe8f48	serio_interrupt
++EXPORT_SYMBOL vmlinux 0xdad0aba9	fb_class
++EXPORT_SYMBOL vmlinux 0xdad95e90	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xdadc197c	tcp_poll
++EXPORT_SYMBOL vmlinux 0xdadd4960	kill_block_super
++EXPORT_SYMBOL vmlinux 0xdb2178c7	__sg_free_table
++EXPORT_SYMBOL vmlinux 0xdb23d02c	journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xdb4292e4	omap_set_dma_params
++EXPORT_SYMBOL vmlinux 0xdb5c8d78	dss_mgr_set_timings
++EXPORT_SYMBOL vmlinux 0xdb634553	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb81afc0	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xdb93b838	dispc_free_irq
++EXPORT_SYMBOL vmlinux 0xdb95efd0	poll_freewait
++EXPORT_SYMBOL vmlinux 0xdbcd416e	sysctl_ip_nonlocal_bind
++EXPORT_SYMBOL vmlinux 0xdbec2478	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc15cabc	elv_rb_del
++EXPORT_SYMBOL vmlinux 0xdc19cbbb	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xdc3f4bdd	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc417d18	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0xdc438da7	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xdc440098	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0xdc69ab08	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xdc6d41cf	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0xdc729d30	padata_alloc
++EXPORT_SYMBOL vmlinux 0xdc77264e	nand_correct_data
++EXPORT_SYMBOL vmlinux 0xdc942659	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdcc0c495	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xdcc74e08	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL vmlinux 0xdcd9f5f3	journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xdcf5d7ff	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd196bef	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xdd22107f	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd3916ac	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xdd4a5569	param_get_byte
++EXPORT_SYMBOL vmlinux 0xdd68f45f	mount_bdev
++EXPORT_SYMBOL vmlinux 0xdd9cc10e	dma_async_memcpy_buf_to_pg
++EXPORT_SYMBOL vmlinux 0xdda58c77	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0xddeee955	sk_run_filter
++EXPORT_SYMBOL vmlinux 0xde15c042	omap_set_dma_src_index
++EXPORT_SYMBOL vmlinux 0xde1b44e7	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0xde211cd9	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0xde4a9385	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0xde56cfbe	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0xde692d94	omap_get_dma_chain_src_pos
++EXPORT_SYMBOL vmlinux 0xde713137	simple_write_end
++EXPORT_SYMBOL vmlinux 0xde7343ab	freeze_super
++EXPORT_SYMBOL vmlinux 0xde8c763d	cpu_v7_set_pte_ext
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xdeb5831f	commit_creds
++EXPORT_SYMBOL vmlinux 0xdee89625	kill_pid
++EXPORT_SYMBOL vmlinux 0xdefad134	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0xdf08d163	arp_invalidate
++EXPORT_SYMBOL vmlinux 0xdf1a7e82	sock_release
++EXPORT_SYMBOL vmlinux 0xdf2253b9	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf399da4	user_path_at
++EXPORT_SYMBOL vmlinux 0xdf401846	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf48a0eb	flex_array_put
++EXPORT_SYMBOL vmlinux 0xdf4f5b47	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf6c866f	snd_jack_set_key
++EXPORT_SYMBOL vmlinux 0xdf7f2991	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xdf8b3282	dcb_setapp
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfb01a80	cpu_v7_dcache_clean_area
++EXPORT_SYMBOL vmlinux 0xdfb45655	mpage_writepage
++EXPORT_SYMBOL vmlinux 0xdfbdbaf0	fasync_helper
++EXPORT_SYMBOL vmlinux 0xdfc1dc95	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfcf95e5	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xdfd19a05	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0xdfd5b38f	get_phy_device
++EXPORT_SYMBOL vmlinux 0xdfd91ce9	omap_type
++EXPORT_SYMBOL vmlinux 0xdffc4bc7	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xdffc8d6d	snd_card_proc_new
++EXPORT_SYMBOL vmlinux 0xe014ecb6	put_tty_driver
++EXPORT_SYMBOL vmlinux 0xe0382961	journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xe043bbf7	pci_set_master
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe050bc8b	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe0686234	vm_insert_page
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe0a959d9	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0bef318	icst_hz_to_vco
++EXPORT_SYMBOL vmlinux 0xe0c8d6ea	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xe0d99bdb	clk_get
++EXPORT_SYMBOL vmlinux 0xe0e1d61f	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0xe0f99a2f	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe11f3cbc	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0xe127fb18	down_killable
++EXPORT_SYMBOL vmlinux 0xe12a1799	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xe1457293	journal_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xe173477b	noop_qdisc
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1888b25	mmc_put_card
++EXPORT_SYMBOL vmlinux 0xe18ac446	skb_make_writable
++EXPORT_SYMBOL vmlinux 0xe1928246	vfs_readv
++EXPORT_SYMBOL vmlinux 0xe1b8bb3b	pci_release_region
++EXPORT_SYMBOL vmlinux 0xe1d87574	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0xe1eb7fef	__quota_error
++EXPORT_SYMBOL vmlinux 0xe1ee6ed3	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xe200d2d5	param_get_uint
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe217daf8	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xe21db409	of_phy_connect_fixed_link
++EXPORT_SYMBOL vmlinux 0xe22c5512	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe2549ec1	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xe271f162	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xe27ae307	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0xe292fb9f	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2b9cf46	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d7cb60	register_console
++EXPORT_SYMBOL vmlinux 0xe2db22f0	sk_wait_data
++EXPORT_SYMBOL vmlinux 0xe2e0d03e	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0xe2e355cc	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2e9bee0	path_put
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe2fe32cf	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xe31b8b7f	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xe31ee066	vm_mmap
++EXPORT_SYMBOL vmlinux 0xe325b56b	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0xe34855d9	update_time
++EXPORT_SYMBOL vmlinux 0xe34e6b5f	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xe35c5285	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0xe37d10ae	omap_dispc_unregister_isr
++EXPORT_SYMBOL vmlinux 0xe37e4dd3	key_task_permission
++EXPORT_SYMBOL vmlinux 0xe3842d3d	generic_write_checks
++EXPORT_SYMBOL vmlinux 0xe3a33676	bio_add_page
++EXPORT_SYMBOL vmlinux 0xe3b23d50	textsearch_register
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3d7c77f	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0xe3e5874a	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xe430264b	scsi_get_command
++EXPORT_SYMBOL vmlinux 0xe43274bc	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xe44d6f99	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0xe4b5c091	snd_ctl_free_one
++EXPORT_SYMBOL vmlinux 0xe4bc2ad3	omapdss_sdi_display_enable
++EXPORT_SYMBOL vmlinux 0xe4c80097	cacheid
++EXPORT_SYMBOL vmlinux 0xe4ccdd22	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xe4cf9ee1	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0xe4d5df9f	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xe4d5e947	phy_start
++EXPORT_SYMBOL vmlinux 0xe4df66c1	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0xe4f7e323	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xe4faace8	phy_init_eee
++EXPORT_SYMBOL vmlinux 0xe5122890	flow_cache_genid
++EXPORT_SYMBOL vmlinux 0xe5125e83	ip_defrag
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe52900aa	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0xe53d1faa	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0xe5445af6	omap_get_dma_dst_pos
++EXPORT_SYMBOL vmlinux 0xe551f637	mmc_try_claim_host
++EXPORT_SYMBOL vmlinux 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe59bd68b	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xe5b0e13e	snd_ctl_find_id
++EXPORT_SYMBOL vmlinux 0xe5bd296f	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5ca4f38	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xe5d95985	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6225d27	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0xe63d9dc5	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xe64f4753	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xe6564c05	omapdss_find_output_from_display
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe6744a89	omap_clear_dma
++EXPORT_SYMBOL vmlinux 0xe68b1ee2	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6ab3817	kmap_to_page
++EXPORT_SYMBOL vmlinux 0xe6be9523	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0xe6c3ebb0	__raw_writesw
++EXPORT_SYMBOL vmlinux 0xe6c90be4	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0xe6d66069	vfs_read
++EXPORT_SYMBOL vmlinux 0xe6df8b85	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0xe6e014f6	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe707d823	__aeabi_uidiv
++EXPORT_SYMBOL vmlinux 0xe70a7238	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0xe7119fc6	km_policy_notify
++EXPORT_SYMBOL vmlinux 0xe73d0b0d	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xe745d63b	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xe7722171	flex_array_free
++EXPORT_SYMBOL vmlinux 0xe775bef5	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0xe77afbd3	cpu_tlb
++EXPORT_SYMBOL vmlinux 0xe7800017	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xe7833a44	input_grab_device
++EXPORT_SYMBOL vmlinux 0xe7a61b08	sock_wfree
++EXPORT_SYMBOL vmlinux 0xe7a664c4	nf_hooks
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7cd3bd8	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7dca1e5	__breadahead
++EXPORT_SYMBOL vmlinux 0xe7df6c2c	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xe7e15910	dispc_clear_irqstatus
++EXPORT_SYMBOL vmlinux 0xe7e6bd6f	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xe80b0b2f	pps_unregister_source
++EXPORT_SYMBOL vmlinux 0xe80ce219	sysctl_tcp_dma_copybreak
++EXPORT_SYMBOL vmlinux 0xe81828e7	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0xe82c8afb	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xe83f5fc5	inode_init_always
++EXPORT_SYMBOL vmlinux 0xe8439337	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xe851bb05	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe862144e	cdrom_release
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe8958fe1	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xe89c1f4f	kernel_connect
++EXPORT_SYMBOL vmlinux 0xe8a6ccd7	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xe8b4e29a	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xe8b53ecc	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xe8b63ace	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8cfce09	tegra114_clock_deassert_dfll_dvco_reset
++EXPORT_SYMBOL vmlinux 0xe8d09dc4	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0xe8d64509	pps_register_source
++EXPORT_SYMBOL vmlinux 0xe8d87e62	d_instantiate
++EXPORT_SYMBOL vmlinux 0xe8e5263f	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xe8f03f1d	try_to_release_page
++EXPORT_SYMBOL vmlinux 0xe8f517c0	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xe8f5a3ea	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xe8faa982	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0xe912da6b	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe9156cb2	ata_port_printk
++EXPORT_SYMBOL vmlinux 0xe929ce46	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xe93633f8	input_register_device
++EXPORT_SYMBOL vmlinux 0xe9487b2d	__getblk
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe9572c06	__bio_clone
++EXPORT_SYMBOL vmlinux 0xe9596512	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL vmlinux 0xe95e367e	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xe989a17e	bio_split
++EXPORT_SYMBOL vmlinux 0xe9adc65b	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xe9b61c3f	may_umount_tree
++EXPORT_SYMBOL vmlinux 0xe9c51795	cdrom_open
++EXPORT_SYMBOL vmlinux 0xe9efbfc3	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xe9fc7502	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea10212a	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0xea10655a	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xea6e3003	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea846683	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xea869778	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0xeaa02e5a	brioctl_set
++EXPORT_SYMBOL vmlinux 0xeaa3b745	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0xeadbe6f4	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0xeb1b120e	omap_set_dma_write_mode
++EXPORT_SYMBOL vmlinux 0xeb35257f	pci_enable_bridges
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb3f2235	omapdss_dpi_display_enable
++EXPORT_SYMBOL vmlinux 0xeb4ed6b5	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb68c065	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0xeb89e80e	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0xeb99697a	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xeb9e7cdd	ida_destroy
++EXPORT_SYMBOL vmlinux 0xeba4ee0a	pci_get_class
++EXPORT_SYMBOL vmlinux 0xebc8e871	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0xebd2fae7	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xebdb3d23	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0xebdbe48c	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xebee227d	omapdss_register_output
++EXPORT_SYMBOL vmlinux 0xebfdcbdf	system_serial_high
++EXPORT_SYMBOL vmlinux 0xec0250bb	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0xec1775f9	read_cache_page
++EXPORT_SYMBOL vmlinux 0xec17ebb0	of_match_node
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec59093c	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xec8fc21e	get_disk
++EXPORT_SYMBOL vmlinux 0xec94022f	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xec96bf4a	keyring_clear
++EXPORT_SYMBOL vmlinux 0xec9e301b	kernel_listen
++EXPORT_SYMBOL vmlinux 0xecac6282	kern_path
++EXPORT_SYMBOL vmlinux 0xecaf1924	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0xecb0aafa	mmc_suspend_host
++EXPORT_SYMBOL vmlinux 0xeccab0c2	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xed066882	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0xed232c72	__scm_send
++EXPORT_SYMBOL vmlinux 0xed466515	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5c317e	ptp_clock_register
++EXPORT_SYMBOL vmlinux 0xed6c88d6	mmc_free_host
++EXPORT_SYMBOL vmlinux 0xed854dac	omap_stop_dma_chain_transfers
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed969975	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xed9e5040	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc7f4ec	dq_data_lock
++EXPORT_SYMBOL vmlinux 0xedd25edc	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0xedd9106d	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xee004647	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0xee108f30	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0xee15c7ed	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0xee2bc2d0	omapdss_is_initialized
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee30ef7a	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0xee3496c3	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0xee3ce648	have_submounts
++EXPORT_SYMBOL vmlinux 0xee49a6dc	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0xee4c7fd3	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0xee5c41f1	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0xee715ef8	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xee76907a	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0xee7a17fc	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xee95a2ed	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xeea66c20	simple_setattr
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeabc3a4	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0xeebdd7e5	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0xeed3635b	proc_dostring
++EXPORT_SYMBOL vmlinux 0xeed943c7	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0xeedddd14	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xeee036b0	dss_mgr_register_framedone_handler
++EXPORT_SYMBOL vmlinux 0xeef31f99	iunique
++EXPORT_SYMBOL vmlinux 0xef10ac81	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0xef230439	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xef491263	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0xef5da2bd	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0xef6669c4	journal_stop
++EXPORT_SYMBOL vmlinux 0xef6913e9	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0xef6c2a87	__ps2_command
++EXPORT_SYMBOL vmlinux 0xef9083f5	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xef964f6b	__serio_register_port
++EXPORT_SYMBOL vmlinux 0xefa8e41e	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xefb14472	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xefb57938	md_flush_request
++EXPORT_SYMBOL vmlinux 0xefb66a95	omap_request_dma_chain
++EXPORT_SYMBOL vmlinux 0xefcf19bb	snd_component_add
++EXPORT_SYMBOL vmlinux 0xefcf3143	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xefd6cf06	__aeabi_unwind_cpp_pr0
++EXPORT_SYMBOL vmlinux 0xefdd2345	sg_init_one
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefec312f	omap_get_dma_active_status
++EXPORT_SYMBOL vmlinux 0xeff198d3	mntget
++EXPORT_SYMBOL vmlinux 0xefffee65	dev_printk
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf041d957	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0619801	timekeeping_clocktai
++EXPORT_SYMBOL vmlinux 0xf0776e8d	dput
++EXPORT_SYMBOL vmlinux 0xf08309dc	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0xf086341d	generic_listxattr
++EXPORT_SYMBOL vmlinux 0xf086fa06	snd_card_disconnect
++EXPORT_SYMBOL vmlinux 0xf087137d	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0xf09612b7	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0b60b54	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xf0b64e71	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0xf0b763c5	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL vmlinux 0xf0d68ed6	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xf0e5304c	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f1246c	kvasprintf
++EXPORT_SYMBOL vmlinux 0xf0fdf6cb	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xf139d0f2	netpoll_rx_enable
++EXPORT_SYMBOL vmlinux 0xf13e713c	inc_nlink
++EXPORT_SYMBOL vmlinux 0xf13feb57	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf1745795	mount_pseudo
++EXPORT_SYMBOL vmlinux 0xf1806da9	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0xf1832472	tty_unlock
++EXPORT_SYMBOL vmlinux 0xf18c2a74	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf19e9355	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xf1a4842f	padata_do_serial
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e0b260	edma_set_transfer_params
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ff1d15	snd_timer_global_free
++EXPORT_SYMBOL vmlinux 0xf202c5cb	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf233e40e	dev_set_drvdata
++EXPORT_SYMBOL vmlinux 0xf2392efa	mutex_trylock
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf24cf625	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0xf2580df3	input_flush_device
++EXPORT_SYMBOL vmlinux 0xf268c2de	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0xf28baf80	tcf_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf2981f95	kill_anon_super
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf29a9b22	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0xf2ab8531	skb_clone
++EXPORT_SYMBOL vmlinux 0xf2b1ac8e	__getnstimeofday
++EXPORT_SYMBOL vmlinux 0xf2bdd554	bio_sector_offset
++EXPORT_SYMBOL vmlinux 0xf2f68caf	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0xf2f7cb7b	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf31c5cea	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xf32b23d5	dev_add_offload
++EXPORT_SYMBOL vmlinux 0xf3312afc	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33def12	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf34f3fb2	ll_rw_block
++EXPORT_SYMBOL vmlinux 0xf3518ada	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf35ef6f3	seq_bitmap_list
++EXPORT_SYMBOL vmlinux 0xf3797152	snd_interval_ratnum
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf398e99e	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0xf3bf0bce	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0xf3eb454d	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xf3f02443	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xf40019c0	tegra114_clock_tune_cpu_trimmers_init
++EXPORT_SYMBOL vmlinux 0xf406debe	get_tz_trend
++EXPORT_SYMBOL vmlinux 0xf40742bb	sock_create
++EXPORT_SYMBOL vmlinux 0xf41b9c0b	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xf427bb00	set_bh_page
++EXPORT_SYMBOL vmlinux 0xf438111d	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xf44e140d	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xf45a4e52	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf473ffaf	down
++EXPORT_SYMBOL vmlinux 0xf477a2a6	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xf483c2a0	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xf4842a7a	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xf4891bac	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0xf4a68fe6	vfs_mknod
++EXPORT_SYMBOL vmlinux 0xf4a7fc6d	omapdss_compat_init
++EXPORT_SYMBOL vmlinux 0xf4b69153	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0xf4bd1c64	journal_ack_err
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4cdab64	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xf4d2a284	submit_bh
++EXPORT_SYMBOL vmlinux 0xf4daf567	mmc_gpio_free_ro
++EXPORT_SYMBOL vmlinux 0xf4e343fa	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xf4eaa133	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f71fc3	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xf502717b	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0xf513ef4f	do_sync_read
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf53f0b9f	eth_rebuild_header
++EXPORT_SYMBOL vmlinux 0xf54c51a2	dma_pool_free
++EXPORT_SYMBOL vmlinux 0xf559c091	devm_iounmap
++EXPORT_SYMBOL vmlinux 0xf5639897	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0xf564412a	__aeabi_ulcmp
++EXPORT_SYMBOL vmlinux 0xf5b9bf07	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xf5c05914	generic_segment_checks
++EXPORT_SYMBOL vmlinux 0xf5e18540	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5f16f9d	padata_free
++EXPORT_SYMBOL vmlinux 0xf5f21c2f	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xf6032e1c	kthread_bind
++EXPORT_SYMBOL vmlinux 0xf61a60a7	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xf6294e1d	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf642ddc5	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xf66c747c	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf6851d5f	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xf6b4f564	__scm_destroy
++EXPORT_SYMBOL vmlinux 0xf6b5b765	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6bcdc7a	uart_match_port
++EXPORT_SYMBOL vmlinux 0xf6bfecde	ps2_drain
++EXPORT_SYMBOL vmlinux 0xf6c2fae0	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xf6c85e31	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xf6e7c7bd	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6f3cef6	omap_vrfb_setup
++EXPORT_SYMBOL vmlinux 0xf7271948	edma_set_src_index
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf75ece94	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xf762104f	load_nls
++EXPORT_SYMBOL vmlinux 0xf772e084	pci_target_state
++EXPORT_SYMBOL vmlinux 0xf7756645	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xf7802486	__aeabi_uidivmod
++EXPORT_SYMBOL vmlinux 0xf78c7ed9	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0xf793fa79	bio_integrity_split
++EXPORT_SYMBOL vmlinux 0xf7a2dcc9	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0xf7b12aee	__next_cpu
++EXPORT_SYMBOL vmlinux 0xf7b5e846	skb_trim
++EXPORT_SYMBOL vmlinux 0xf7cd2002	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0xf7e09e72	inet_release
++EXPORT_SYMBOL vmlinux 0xf7eec892	arp_xmit
++EXPORT_SYMBOL vmlinux 0xf803fe39	bitmap_set
++EXPORT_SYMBOL vmlinux 0xf80d1e94	inode_dio_done
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf853bbca	omap_vrfb_map_angle
++EXPORT_SYMBOL vmlinux 0xf875a8b3	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0xf88a2578	sync_inode
++EXPORT_SYMBOL vmlinux 0xf88c3301	sg_init_table
++EXPORT_SYMBOL vmlinux 0xf8953696	blkdev_put
++EXPORT_SYMBOL vmlinux 0xf8974922	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xf8a43469	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0xf8bdcd4a	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xf8c4c7eb	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0xf8fa693b	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xf8fb0cf3	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0xf8fbb4f0	__bad_xchg
++EXPORT_SYMBOL vmlinux 0xf923b9f1	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0xf92642ac	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0xf92a5677	skb_split
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf938cc80	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xf9427374	dispc_request_irq
++EXPORT_SYMBOL vmlinux 0xf95f3624	snd_card_file_remove
++EXPORT_SYMBOL vmlinux 0xf9659464	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xf96abae5	blk_put_queue
++EXPORT_SYMBOL vmlinux 0xf96eb2e3	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0xf96eb988	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0xf99d5521	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xf9a2a6b9	journal_release_buffer
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9b2d57e	skb_append
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9f42bc8	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xfa0e606f	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xfa50611d	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0xfa53d0ae	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa6b9c23	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xfa7ce485	find_or_create_page
++EXPORT_SYMBOL vmlinux 0xfa7d4405	iget_locked
++EXPORT_SYMBOL vmlinux 0xfa7eb2e6	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xfa7f3156	wl12xx_get_platform_data
++EXPORT_SYMBOL vmlinux 0xfa8c610b	soft_cursor
++EXPORT_SYMBOL vmlinux 0xfa9523b1	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xfaa0de2c	set_binfmt
++EXPORT_SYMBOL vmlinux 0xfac339b8	journal_create
++EXPORT_SYMBOL vmlinux 0xfac68eba	arm_elf_read_implies_exec
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfacd2e14	pgprot_user
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf98462	bitrev32
++EXPORT_SYMBOL vmlinux 0xfaf9995e	sleep_on
++EXPORT_SYMBOL vmlinux 0xfafa75ce	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xfb0a3b50	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xfb24a6dc	journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0xfb4b865d	dev_mc_init
++EXPORT_SYMBOL vmlinux 0xfb55dcf7	user_revoke
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb79a3ad	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0xfb7d9c45	__udivsi3
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfb961d14	__arm_ioremap
++EXPORT_SYMBOL vmlinux 0xfb98f1de	kmap_high
++EXPORT_SYMBOL vmlinux 0xfba70dd2	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbb91ee8	d_find_alias
++EXPORT_SYMBOL vmlinux 0xfbc6ce30	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xfbf0979f	register_netdev
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc08f923	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xfc0adce9	f_setown
++EXPORT_SYMBOL vmlinux 0xfc1f04fb	serio_reconnect
++EXPORT_SYMBOL vmlinux 0xfc2e69f7	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfca502e0	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0xfcaa04a0	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xfcadadb6	request_key
++EXPORT_SYMBOL vmlinux 0xfcb9556e	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcc6c254	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0xfce67c94	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcef30e1	snd_pcm_lib_free_pages
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0ea740	splice_from_pipe_begin
++EXPORT_SYMBOL vmlinux 0xfd1e0b67	elv_add_request
++EXPORT_SYMBOL vmlinux 0xfd305341	walk_stackframe
++EXPORT_SYMBOL vmlinux 0xfd3218b5	simple_write_begin
++EXPORT_SYMBOL vmlinux 0xfd35b5d2	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0xfd5683b9	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0xfd6293c2	boot_tvec_bases
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda0dbe8	ftrace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xfda33b53	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xfdce239b	tegra_chip_uid
++EXPORT_SYMBOL vmlinux 0xfddf9cbf	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0xfdf4e123	snd_pcm_suspend
++EXPORT_SYMBOL vmlinux 0xfdfa88eb	con_is_bound
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe027755	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe19144f	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xfe216d82	ptp_clock_unregister
++EXPORT_SYMBOL vmlinux 0xfe326c91	nf_log_packet
++EXPORT_SYMBOL vmlinux 0xfe33c6c3	sg_nents
++EXPORT_SYMBOL vmlinux 0xfe40bf95	dss_feat_get_num_ovls
++EXPORT_SYMBOL vmlinux 0xfe4cda39	input_release_device
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfec1f260	console_stop
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee2f355	iov_iter_copy_from_user
++EXPORT_SYMBOL vmlinux 0xfee5d663	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xfef96e23	__scsi_print_command
++EXPORT_SYMBOL vmlinux 0xfefb6077	edma_alloc_channel
++EXPORT_SYMBOL vmlinux 0xff0364a1	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xff03e056	omapdss_dpi_display_disable
++EXPORT_SYMBOL vmlinux 0xff064fee	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2f1814	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0xff39113f	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xff4f77a2	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xff57239b	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL vmlinux 0xff62c364	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xff67b37f	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff6f1a83	tty_port_init
++EXPORT_SYMBOL vmlinux 0xff86d7b4	unregister_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffa3ab61	snd_card_create
++EXPORT_SYMBOL vmlinux 0xffa51605	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xffb94ef0	_test_and_change_bit
++EXPORT_SYMBOL vmlinux 0xffd2cf99	omap_dss_get_num_overlay_managers
++EXPORT_SYMBOL vmlinux 0xffd2fcaf	splice_from_pipe_next
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffdd82ae	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xffe5095d	groups_free
++EXPORT_SYMBOL vmlinux 0xffe5abc8	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0xfff62ab9	i2c_del_adapter
++EXPORT_SYMBOL_GPL crypto/af_alg 0x0ad880ce	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x667e43ce	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x93957c0c	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9d12cb0d	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0xb92c1212	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd954ef95	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0xda3d4c6e	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe5aa29d5	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xe5c6d763	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0xb3e47963	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x09dbe866	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xdca14894	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x6c624966	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x97658a8c	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x597f81ee	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x9b2e16a2	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xbafc43e1	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xca0365ba	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x06d30e57	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x7f3562d3	async_xor
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x68f66673	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x32ca2b0b	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x91c1f4fe	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/cryptd 0x00eb8705	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x2802cbe4	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x2ea9f4f7	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x396d7839	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x55ada3dd	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x59ede6d8	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x63289cb1	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x8a2d8aed	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x8c4cd151	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd57bcc65	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0x7f2e8fa2	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xb80ca8c8	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xda1f2c31	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x571100e9	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x4e2f75c6	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x00a80e62	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x11e094a6	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x1cd1d6ba	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x25980c0c	bcma_find_core
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x284ea34f	bcma_core_pci_extend_L1timer
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x302d1403	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x498f78d9	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x52bb94d6	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6bd5099c	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x7818260e	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9a26d3d2	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xafc174d0	bcma_core_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb388813d	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xbc6468df	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xbf94cb58	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xc97beaed	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcc1645f0	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcd70b006	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdc011eb1	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xef7bfbc1	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf55f8ed1	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x0a8a91ea	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2498ced6	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x4d94fb4e	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x6baed499	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x720a0145	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x729b8e20	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x7ed4cc8e	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb81111fc	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcb4f2ebc	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcb5cd5f7	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x2bbc0c61	dw_dma_suspend
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x416083f9	dw_dma_resume
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x65becbf8	dw_dma_shutdown
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x82481be4	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xaef2e1ac	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0a4e75d8	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x10d6eb49	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x26787010	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2b1a24ab	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2e42a1e8	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3d53086f	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4bce3170	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x52a37110	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5ee5b413	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x69259f22	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6ba023a7	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6c7b015c	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x796252f8	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x7a444ff1	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9fe6d1a0	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb477c767	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc6551f9d	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xcb11a980	edac_mc_add_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xcbdbde5c	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xcc861a7c	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd3e3d4dc	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdbd7fc02	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe4eef99f	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe9fb5220	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x2188f152	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x5b8f2ee2	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1adc5e59	drm_gem_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x30aa3341	drm_gem_cma_dumb_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x3c93624f	drm_vm_open_locked
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x56bd8ce3	drm_gem_cma_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x67ef1d04	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x770f0d95	drm_display_mode_from_videomode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x78256451	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x78b4ecc2	drm_gem_cma_prime_get_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa33ec413	drm_gem_cma_prime_vmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa55983c3	drm_gem_cma_vm_ops
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xabc27f66	drm_gem_cma_dumb_map_offset
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xb1edb47f	drm_gem_cma_free_object
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xccb1ba6b	of_get_drm_display_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd284f28e	drm_gem_cma_prime_vunmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xda7a89ef	drm_gem_cma_prime_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xdb273164	drm_gem_cma_dumb_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xee0c6102	drm_gem_cma_describe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xf9d13f34	drm_gem_cma_prime_import_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x1148b623	drm_fbdev_cma_fini
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x2148c34e	drm_fb_cma_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x47f2ef19	drm_fbdev_cma_init
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x73704fdc	drm_fb_cma_debugfs_show
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xb2c912af	drm_fbdev_cma_hotplug_event
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xcc337fd5	drm_fbdev_cma_restore_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xe615dcdf	drm_fb_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xe808d7e4	drm_fb_cma_describe
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x11d6096e	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x12973dca	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x19d9635c	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1cf85a5e	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x29d3b3f4	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x38443692	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3fe49f8f	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x41913e67	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x48567ef9	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4c094064	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x548429a3	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x64166a5b	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x65579ee2	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x65cf6795	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x73a0db6d	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8e2df739	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9074c0d4	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x93429f82	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa36bc060	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa6d4139a	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xab241d76	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb8d7206d	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xcfa8964c	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd31ff167	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd5b72a0f	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd661da15	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe4b8aea6	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe76f7ca7	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe9e08163	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf056ea81	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf28a5b1d	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf3c0d4d6	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfab16070	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfdf14d20	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2760bd91	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x3ceee43a	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x81584a1c	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xef6125f6	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1dee4513	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x538d9f9c	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x8bc7aa93	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x93ab8cce	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa90b9e37	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xe4265856	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x0df8590f	usbhid_set_leds
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x147e6e6d	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1b58a140	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x39f5b408	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x3bb62683	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4d924f89	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x8890ac8b	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x99d80602	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x9b3a0e5c	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa49bfa5a	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa741c36a	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb38c9271	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc83ea41d	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xdce61c42	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe93aab44	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x6cc939d7	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x9fb00bc9	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xa60c8c37	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x11f230dc	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x53d1fec0	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x590c5f5e	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5db38c2f	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x74652e36	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x7cf31b57	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8576af3d	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x8e725cd9	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb1b95db2	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xec2b0b3d	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf6e2e773	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf80ee47d	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x1190277e	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x320ea345	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x400c029e	i2c_dw_enable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x48f7c065	i2c_dw_func
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x4d7e6ec9	i2c_dw_clear_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x4f7e8c7c	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x5bb1170b	i2c_dw_isr
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x6746e26a	i2c_dw_is_enabled
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xac8268e0	i2c_dw_xfer
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xc7d5a771	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x75c36435	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x82d16877	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x01f07e67	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x7fd21c1e	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x0226b831	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3239ded1	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3a333446	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x3ae8fe22	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x46bf97c3	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x56b6cc3f	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x707787c6	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x89e5cc42	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xfa64d51d	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x0fb92817	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x15ebba03	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1923675a	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x34096a20	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x382e8b3f	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x4a91393e	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x5dfb37f1	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8e35d5cd	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x940ccef6	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xba41aaea	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xd01316c3	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xe8b0c6ae	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x03ee6205	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2565e9c5	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a29b029	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x40b9f376	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x49d07f87	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x61a4024f	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6330d475	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x78e62f23	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x912f4d44	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa4e076fa	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xaa6a5231	iio_scan_mask_set
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xac0d1120	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xadb585e4	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xaf2c3f5b	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb5edf386	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc138c4ad	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc666385e	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xd5ff34f4	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xdcd74798	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xdf6a924e	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe37715be	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe9186f16	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe977c15b	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeb5bd985	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xb103e2f5	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xc1412a3b	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x68a245d9	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x3d6583f1	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xa0ca2bcf	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xd6ea7778	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x0419e87f	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xd01ca300	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xed39133a	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x75a2f86a	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x9a884783	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x0b4d2d48	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x16f33012	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x19798b12	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x4070e45d	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x4f5e01b1	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa1c202cf	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa226113f	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xca1d332c	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xcb4bee90	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xd4f2f458	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xda59308c	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xf9173ffa	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1db8351f	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x212b0b9a	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4ba0de0d	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x88c32e5e	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb1cc1e69	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xbbda330a	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xe8983ca6	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xea746c85	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xf485baf5	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x0dc9b939	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x32b4414c	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x554c4154	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5768f812	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x59fba037	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7a461650	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7aabeac1	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8b73bce8	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8bfa56d4	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x932da708	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x9a292cdc	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xce4ebdf9	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd9484546	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xf133fa99	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfa21f99b	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfa6aac75	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfb311479	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0576d04d	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x46b042d4	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x473a2b09	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6aa09343	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x8bf5c8f1	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x98ee6c23	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9ac6f86e	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb3a8e2a7	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xb4cff2ce	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xc4e72407	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xf41d1537	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e06e97	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x155ea9c7	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1822fd23	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1f2ba9ac	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x260d47cf	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x27831e89	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2dec45e0	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x347aebe1	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x377b4a17	closure_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x3ccfe458	closure_trylock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x41c861f0	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x4652a53c	closure_sub
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x49856e5a	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x50e8c39f	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5132a7a8	__closure_flush
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x574ba881	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x5a939f1f	__closure_delay
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x628eb712	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6770a402	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x67bf69be	do_closure_timer_init
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x698ed07c	__closure_lock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x71262459	closure_wait
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x785cfc9f	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7b488fb1	__tracepoint_bcache_alloc_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f2af34	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x97c885d6	closure_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa09069a3	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa0bf2436	__closure_flush_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa591c5d6	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa6890b59	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xab9881e7	closure_queue
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf60c34b	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb950d2ae	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbd4b89b6	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xce0e6218	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd40fba32	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xdc5ea5a5	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf58ce244	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf5bcbdc7	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc1d5275	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcdf28c9	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xffc308e4	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x10be5b31	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1e818676	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x42c7f276	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x7f43df96	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x899823d9	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb27c29f1	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xebd06eaf	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xf350bd07	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xbc7aca2e	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x0ac362c6	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x1dc059d6	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x4fba97f8	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xb5e09d64	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xb75c31c2	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xd613581c	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xfb2f2cf8	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x5980036d	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xbaef4257	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x1f3c083a	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3c4aeed6	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xae15e369	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xb358d592	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc6b250a1	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xdd7dfc20	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0abee463	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1cac81ac	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f74609d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x371fd72c	dm_bm_flush_and_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x38c75c44	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x68fae9d2	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x80c89b3d	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa0bbbb49	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa13861b4	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb7bad799	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe44b4b9b	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf475af48	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/raid1 0xd16a456d	md_raid1_congested
++EXPORT_SYMBOL_GPL drivers/md/raid10 0x9be67b6b	md_raid10_congested
++EXPORT_SYMBOL_GPL drivers/md/raid456 0xf224abf5	md_raid5_congested
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3970439a	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3d91ab2d	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x75215371	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x8490124a	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x91db18d8	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xa50a42a9	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe387d3aa	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xeb2a87d6	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xec354e23	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xfb5f2290	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x40eeca55	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x7cc23793	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x83778e7a	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x859ea09c	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xd977abdc	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe65fb3d9	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe931783a	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x02614385	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0758bfaa	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0cf223d8	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2942f9d7	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x3aeeef08	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x588337d9	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5a8d0b23	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x5eb88a3b	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x85d34313	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8869b0c9	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8a176886	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9a731b1f	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xaeb7f56c	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xba390809	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xc9afcdaf	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcf8a1e9f	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xeac59f13	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0x5bc9da9b	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0x5a835351	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x0e659c89	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1d22beb6	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x31a5328c	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x37a37bfa	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x3e9e130b	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x64c2c8b5	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6966b299	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x6e0e8d3e	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8e66dce5	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x96994a34	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xa7cb8eb5	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xafa280f4	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd913f91e	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe6180403	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xeb062837	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xef793c37	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xfc3e1e08	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x15e0dbaa	saa7134_queryctrl
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x794a47c4	saa7134_s_std_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xa70f2eba	saa7134_g_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xb80dabd8	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xc8ea7005	saa7134_s_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x42ce6254	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x81c30a4b	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x8280eb50	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x836a2b26	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xa88516d3	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd205f724	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xdbc802ea	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x090b7ab2	omap_vout_default_crop
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x3f08714d	omap_vout_try_window
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0x87006df4	omap_vout_new_window
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0xd5aa61c6	omap_vout_new_format
++EXPORT_SYMBOL_GPL drivers/media/platform/omap/omap-vout 0xe168e379	omap_vout_new_crop
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x0550fc29	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x41f39242	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x39e13bfd	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4f6471c9	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x7a68b1dc	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x80054539	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x85fff5a2	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x88c29ad4	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9a098b24	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9c045cf3	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9d376238	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xad482d74	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xba3adb1f	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc71af715	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcd752e39	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xd8d7c4cc	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xda9ee99b	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xea4727f1	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf2e468b4	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0xb59b341f	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x029bbe2b	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x33a232c6	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0x1804a186	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xd0f1aa32	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x49cf48f6	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x9a57e40a	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xd3675fcd	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x1d452a12	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x6a17241d	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xd7ceac1f	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x37951193	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x9e281171	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x99c6e39a	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x08047d47	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x152a2411	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2ceef139	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x35cc4a8d	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x4dc4c799	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x668152c4	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x82ba143a	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8ac2924b	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8b439d6d	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8e4d0200	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8eca40bd	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x92b1bc53	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x98974139	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb291b988	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb2b2da4d	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc28d26cf	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdffb6699	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xebea349d	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xfc97c330	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xec7ffaaa	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x509c7259	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1b5eff5f	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2c43cf25	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x52c96a7b	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x558b3f6f	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x61c1a3ed	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8cba7488	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xac99f7c8	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xad8c3bc6	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbd9af7a0	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc4038196	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xc5cad810	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xde3fb900	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xf1e5fffa	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xfb18cd40	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x0b8b1fc1	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x481882a6	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xd28185ef	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdd12a0e3	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x12ea4a7a	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x53105839	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x5d9d3491	v4l_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x61127b1c	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7a7b216a	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7b4ef343	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7eaf8e7a	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x9604d1df	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xe68ba4ec	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x03040e7a	v4l2_int_ioctl_0
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x10bbd7b3	v4l2_int_ioctl_1
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x526a39e1	v4l2_int_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xa5228b24	v4l2_int_device_try_attach_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xf07fad82	v4l2_int_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x26f1c153	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3859894a	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3bc23c00	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x462283a1	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x638b1e87	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x8391e244	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x871ddc32	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x88408415	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa032f9d7	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xa984a727	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xacfb8880	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe0b0f1ce	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xea19aca5	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xeda5df58	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x06f8998c	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x083375e7	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0a6bf5aa	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x14c8f4e7	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x1cf21088	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x251af5ce	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4a83e21f	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4ccc83f4	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x53ebe7ab	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x595fcc2f	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5d0f91a9	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6098fa8b	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x79812dbb	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8b8b1f47	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x9b6ecfe5	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa32a2136	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb7d9d5aa	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbdfc5d38	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd1990ce3	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xdf5d575c	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe6307b38	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xedf81ee6	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfb229c06	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfb26a55f	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x30728157	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x7addd7d8	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x8942e408	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x18f2bd82	videobuf_dma_init_kernel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x378a7889	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x641dcfa3	videobuf_dma_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x7adae750	videobuf_dma_init_user
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xb5f99200	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xc7035af6	videobuf_dma_map
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xcbbd1af4	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xe837d1ba	videobuf_dma_init_overlay
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xe99d2957	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x6672e693	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xcd7093c2	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xffae2986	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x04871655	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0c2129eb	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0e801935	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0ec9d768	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x10058bdf	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x11f5697e	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x18235071	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1dc95ae1	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1fc0f143	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x265446f7	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3d146126	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3e27f196	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x48627747	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x488edfef	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x50673a8f	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x52d36d1e	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5a509d40	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x5b46bd4e	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x646bf85a	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8ef1a080	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9d8fcb20	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbfa82150	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc3d0e1c0	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xc91106c1	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd30e0118	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd7a81c83	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdd5d2306	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdf832fdc	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe005d372	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe546f788	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe5f3d5e8	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe6117c1c	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xebc660c7	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf7fd2a33	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x077a0ad4	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xbb581015	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x528e0ef7	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x11a29f17	vb2_get_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x45b6f866	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x7d2cbb60	vb2_put_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xc7959363	vb2_get_contig_userptr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x5a56938c	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x02b10034	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x07961049	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0b419a14	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x14542202	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x1b119f5e	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x268c9abb	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x29b67ad1	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x342d2b01	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x45f24351	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x4a7781b1	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x57418570	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5ef7a926	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x68ecbf26	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7150ab75	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x877b9e08	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x90fdff92	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9f9a7eac	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xc66c26e5	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xcdef5878	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdc5afa04	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe25a5170	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf8fc569d	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xff088188	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x0d0f8aa1	i2o_dma_map_single
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x57aea99d	i2o_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x7317260f	i2o_dma_free
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xb3465075	i2o_dma_realloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xc134b2ee	i2o_pool_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xc7cfbb79	i2o_pool_free
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xcfa0a542	i2o_dma_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xd95897f7	i2o_sg_tablesize
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x8f00dc75	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xbe1fc55f	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xccd5893d	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0c2feb12	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x25c22400	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x38f1a692	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x76903dba	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x7bffd589	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xcbd22eb8	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xdc0adda6	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xee816f25	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x54999237	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x7ba14450	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x9ec9aa64	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x120701bb	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x3c7d5106	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x56b70a9e	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x84c9713a	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x84e8aff8	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x91f7c458	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x9913fb5d	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x6a6a2692	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x813aa012	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x9335557a	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xc180eb32	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xee8d2b6a	mc13xxx_common_cleanup
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xf972bf61	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x33ed8182	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x37089732	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x71157c8b	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x85153d9c	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8b45d482	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8d0acd99	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc2e4c535	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xc9281458	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xce3575af	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xd86075e2	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xf5bd229b	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x532734fe	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xc7b454fd	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x2e9a2d09	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x8e854644	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x9cdf43d4	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xada9fe35	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xf78e1a4d	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0f028d3d	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x132eb967	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x14cccd4c	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1947c752	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1c37ccdf	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x47ed544b	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5478b00e	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x5961dd9b	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x64ae9126	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6e4da030	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7ace191a	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x89645862	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x9bda935d	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xaac9f3df	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbea80f80	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe0f21912	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe181731c	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe7aafeae	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf5f61d79	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xf8c2e973	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfb2ea944	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x04e0896b	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x061b902e	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0783d3c3	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x14d12367	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x191c58c0	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1c5b5080	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x20f6528e	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x24f51624	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x25e0dfea	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2a73f2e0	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2eb73591	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x365cba97	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x36efa6e8	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4126eace	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x45d7d449	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5b2a8189	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5c9648cd	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x680f6c73	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x77137409	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7734e1cb	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8840d70e	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8f88d40a	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb29d4096	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb70b50a7	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbe0559a9	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcb6ab7c4	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdc0b3f9e	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdc88626f	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe2c4b9e9	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe351a41b	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe38e06cc	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xeab310e9	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf2720a13	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfc558ad2	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x026ec98f	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x3e2774f9	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x4bc696d1	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x86048fdc	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x8f87b7a0	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x79bd282b	am335x_tsc_se_update
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xa471395e	am335x_tsc_se_set
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0xfb6b008b	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x0fd18e66	tps65217_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x2904f7a8	tps65217_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x5fdbed99	tps65217_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x70a83be5	tps65217_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/twl4030-madc 0x9effbf1a	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xaa819090	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x2d086022	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x2d5da2ef	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x4679db06	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x712b02ca	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x14ff402a	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x6177be44	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x85251bab	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x97e894cd	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa479dba7	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xd01c98bf	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf7127c27	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x1a52c131	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x3208ce4a	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x5d18593d	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x65a2f88d	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7a04d157	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9574cd6e	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9c40426d	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xdd1b6bbd	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x9dcdd96e	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xe573fed8	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x21b8bf79	dw_mci_pltfm_remove
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x36599cde	dw_mci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xf9debf40	dw_mci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x784de928	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x8553ccbe	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xba7ae956	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x0235ee15	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x7c67a5c5	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x8f9e6a43	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x0b0038cd	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x55543383	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x8f0036eb	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xda5843fe	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0x2702e2de	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x7441bb4c	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x98d19579	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3bdddec8	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x7e76394d	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8d8a160f	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8da0da81	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x8fd08a3a	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x90719bfb	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xaa46d377	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xbb654aa2	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xd05555cf	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe51d85cb	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xeab72e2b	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf926bc35	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf966e41b	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x0e2afaec	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x3dd765ee	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x7d435f5e	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x9282fcbd	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xdc389528	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xf3bb51c9	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x4e20d254	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x602236a4	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x64f84a47	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x6662e40b	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x71874893	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xab357ae8	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb77fa681	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xba96621e	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbbe62125	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xd7a52c10	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xda8583ff	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe384b2ba	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe687439e	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xeec890d9	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xf5e981a4	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x220fbc1b	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x92f6d8cb	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xc3676250	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xceb7da27	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x2ffeec99	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x5d1864ec	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x8a3a35c6	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x9108365f	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x026afaa1	macb_set_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x1b0e76b7	macb_set_rx_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x2e4b07ed	macb_ioctl
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x34b0e440	macb_get_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x42182761	macb_mii_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x471c0493	macb_ethtool_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x8b04521a	macb_get_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0195c2bd	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x062302e4	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x08386b35	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0b52ab00	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e3d896a	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0e4deb35	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f2f379e	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x108caaa8	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x125d17ce	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x144c99a4	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x159c17f9	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x17c4e579	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x244d81a9	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x25c0f743	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x265c7de1	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x283fa3b1	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x290ee62b	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f415c33	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x317a5879	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3311d61a	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3be19a8f	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3e77729c	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x405c8d55	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x40b1891c	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x41f0954b	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4296dc69	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x42c22fb0	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x42cabe72	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x435a6e5b	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x438f5c47	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4430111f	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x462edb56	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47a2ec55	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x496c6d4c	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4f4a9792	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x52745e83	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x56c3bfe8	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b075859	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5b18f3f4	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5c4b7b77	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x60ff8201	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x64df6f6d	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x742a0ad2	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x816b13aa	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85a310c5	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x88559e0a	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8b6b8c90	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8cb9b1be	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94a44cbf	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94ab89a6	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x99416934	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9b8d8fb1	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9d67a728	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa0119d7f	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa5e8532a	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa66e8840	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6871b76	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xad9770d5	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb0aac06f	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb38dc0c0	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb6f178f	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbfb3b360	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc087a78a	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc0987c30	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc247d187	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4e4685b	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc75275af	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc9d2bed6	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7ee1875	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd895d9c4	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd93a8ba0	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd97173cd	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdae60951	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdbd0e68f	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xdc159fbb	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xded5b8ea	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe10625b2	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe2596707	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe61e6c17	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6674ff6	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe8e1a91d	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe8f15550	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe911c65f	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xeb05d5c5	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf6fd371f	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf8db5295	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfafdb530	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfcdf2e03	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff408f50	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xffacbdb4	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x018edcce	cpdma_ctlr_dump
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x03979f1c	cpdma_ctlr_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x0ff9af09	cpdma_ctlr_int_ctrl
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x5a8f213c	cpdma_ctlr_eoi
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x5c2fe4a5	cpdma_chan_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x68e47b2c	cpdma_ctlr_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x764928a2	cpdma_chan_create
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x949334db	cpdma_ctlr_start
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0x9cdc9867	cpdma_ctlr_stop
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xb125ceb2	cpdma_control_set
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xb77cb0a8	cpdma_chan_submit
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xc5d5513e	cpdma_chan_process
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xc685c037	cpdma_check_free_tx_desc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xe4c22565	cpdma_chan_destroy
++EXPORT_SYMBOL_GPL drivers/net/ethernet/ti/davinci_cpdma 0xee8d7539	cpdma_chan_start
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x0b715c7c	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x48c88e64	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x5d4c1af0	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x6d833411	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xd3c90047	macvlan_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x49a1de91	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xa7e1ce11	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xb3e53517	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xd7b2c5ed	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xe9e7eb25	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x13a19afa	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x4808a538	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x56edab39	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x696c526e	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x9477dcea	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc2a2a024	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7ad4ba7b	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x93508fd9	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xa473eee6	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xa4bf5210	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xc05245e1	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xc4a39112	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1632f9b9	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1664bffd	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x194e17af	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x28bb863d	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x363156c2	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3deefbbe	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x413a7b82	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x463c11e6	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6bb8603c	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6fe3d795	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x71eb1dd5	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7dbf19fe	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x89bbd2bf	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8ce307bb	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa9ae8e06	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xaa1540f0	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb0340f20	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb294ab69	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb574eeb9	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb62839af	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc014c3f5	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc05360e3	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc4e55f55	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc881a20d	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc8b70e10	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc8e08ec9	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xd2b20fda	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe6bfa4c3	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf0c51fc5	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf4d1817c	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xfe987875	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x07237a54	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x515baa05	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5aa22c42	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5e6435b5	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x6d460873	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8a8b05cf	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8a92d966	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8fd4d043	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x9fc34414	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa4de56a1	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd182847d	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe2cf3951	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe42492bc	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xe652a5b8	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xec678058	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf46dc980	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x73c1b481	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x99166585	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xd3bd2da9	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0xe5b441df	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0xd62476df	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x17a2fb0a	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x28b16232	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x49f58c56	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xb400eed5	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xb432ac6b	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0418ffaf	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x19309081	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x194202ee	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x2239962f	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x32d6c835	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x39f7aefc	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3f0b9a6d	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x406c5cc3	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a10d898	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5d0a212e	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x769fbc5c	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8c5d5ab3	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9005d244	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x92e64568	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9bf008f8	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x9ec63dc7	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa5558b61	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xb0342c46	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd5402ae7	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xde6f4ba7	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xdfde1a41	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe11f9eaa	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe698cde2	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xeaca064b	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xeb07398f	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xef280d18	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf371a595	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf5032a20	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1a9c0553	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x1c3e729f	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x25dcb10b	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x384c72e1	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x43820570	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5c41d1f6	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x8ec292f4	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa302897a	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa8a277f7	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xaac9ee99	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xae07ae1f	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc0792322	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc09329ca	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xc2f22bee	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd74a5b82	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xdc5cc5b0	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x1356402b	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x29e70bf9	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4f24a5c4	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x9b34ce8e	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc245ff95	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xd8d2618e	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xf3cb6178	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xff808d2a	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0x822a087c	if_usb_prog_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0xc233b694	if_usb_reset_device
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x0b539ea0	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x145b6aa7	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x2ca0ba98	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x468199b5	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x787775b2	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x82a2e179	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8eb08394	mwifiex_deauthenticate
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x922cd0a9	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xa83d8c9e	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xaaf06404	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xb9127c90	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbbea8af9	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbfbda81a	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd30db99c	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x46a46917	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x63f63869	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x6974aa40	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x9c169f68	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xbe64e542	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xc8fcf9b2	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xec0ddb82	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xedbe7a8a	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xf6997d5b	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x03739b9c	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0842907b	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0f1235c6	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1466338b	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x154ce8e4	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1cfcbb7e	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1d341ef7	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x20bbc224	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x25f074a7	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2c2c7d5c	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x35dda6db	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x391fa6c1	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x43f4dc78	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x49bd9fab	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5928ed24	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x71995056	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7a9dfd19	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7b098a81	rt2800_rt2x00debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7d8358ff	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x871aabe2	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8ca16839	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8cc746d3	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9d23070a	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xad1e0dd6	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb9d063fb	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc146b1c6	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc40f23e5	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xc8f723eb	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xca65b706	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcb6de6be	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xcea54aa5	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd597ee7c	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xdac5b1c1	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe7ab9460	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xed9ba3b4	rt2800_get_tkip_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xef3a4856	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf5a549f5	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf7255f09	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x05bb32de	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x105a1468	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1c997a01	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x296def4d	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c5015f7	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2e6c8428	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x35bdbcd3	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3a026bdd	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3abbde71	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x42a30101	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4610a4cc	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4a519524	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4dcaae04	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x60235c1e	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x68e9d712	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x69b63694	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x72a31fc5	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x78f24e3c	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7b1314b2	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7ba3c7d4	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7c446d61	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7e436071	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x83d33112	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x864a0ef9	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x935ec01c	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x96b67e96	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x97ed7d01	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9b25167d	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9f3b328b	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa5ac310f	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xab39342e	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xac174ad6	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb117b088	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb214706f	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb27a65b0	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc49ea86d	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc7c616f6	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcc563258	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xddf640c9	rt2x00debug_dump_frame
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xde460fda	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe110955b	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe4c5cf3a	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe5a204d2	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe7805bec	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe9bca94b	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xebc2e6aa	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf3a2a47e	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4a9e488e	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x80dddc65	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xb916be5e	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xbef70e5a	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xfc97353f	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x38657961	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x96b7befa	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xb16f2864	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xd9389469	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x020010c0	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x08c827ab	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x47e08935	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x675727e4	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6e945049	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x72a8bc38	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x834f9f79	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8d5718b1	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x8e35e8ce	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9918f3f8	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9cad1e99	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbc0744c2	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xbe866d94	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc5972bcc	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xc75ec951	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd9c1187f	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xbb40babe	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x049c201a	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x0d909181	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x13d9d21b	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x1c118f03	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x27c36bdd	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x2d882d91	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x4a066035	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x59cf03cf	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x79817bb5	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x7a162d10	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x7c25862a	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x88639dc3	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x94e8048a	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xb6115acb	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xbc66f2eb	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xc0323104	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xd0f4bd77	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xf92cb894	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x296cfe3e	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x72e1f529	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x93b27d17	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x00d650d2	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x05294fba	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x06009f0a	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0bb210b4	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x12042a31	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1630401d	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1824c8f4	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x184c2a36	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1bc9f7da	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1e15ad55	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x21054e71	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x29b61c16	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2bed0efe	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x31ad085e	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x33bbe42f	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x372d02ed	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3df872ba	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4eb624b4	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x513e93ea	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x52df3743	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5c352d58	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x650b0792	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6dcc2d46	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6edb2a93	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7e960b3a	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x7f475501	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x80afafe1	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x810d60ff	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9808a4dd	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x99e00784	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa18f0342	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xaf974994	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb5b74195	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbb0d0233	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbe135c1f	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xcc0babb6	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd6be7923	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdd290244	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe46c05fa	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe6cef7e6	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfaf96e5f	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfb202e45	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x9888fa0d	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x9cd2ae19	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xb5c900c8	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x2943239d	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x46e55dec	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb62456ca	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xddbc973c	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xe9d7109b	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x754ca541	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x80cfff64	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x84dba40e	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x90362543	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xccafb080	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xe4e405f0	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xa979a73e	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0ded05b5	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1630d733	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1b323eae	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2278cc44	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x25a750bd	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x34864f1f	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x34b23fc6	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x35838d83	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a7d7a34	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4515ecdb	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4a145ec4	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4cbfec10	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4cfe83ed	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5940af53	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5a2f9717	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5ec1c8ed	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7a7c473d	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7d2d2239	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fea6782	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x806aa9f0	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8adcd930	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x940dd031	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x94bde7e1	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9c81cd2a	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9e542269	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa96b7b7c	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xaae5d9cd	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xae39e777	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb323d3c5	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb9befd71	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xb9d65c71	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc6a0788b	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xcb7aaeaa	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd3598f0f	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd5f9f7b4	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd7e9f189	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xde0da917	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xde469927	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe6190499	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe7577300	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe99cb57e	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf1fea80d	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xf9a01e74	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xfde61da3	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x10f69ab8	scsi_dh_activate
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x3ce2c1d3	scsi_dh_detach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x593a36c2	scsi_dh_handler_exist
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x839d5e80	scsi_dh_set_params
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x871cdfb3	scsi_dh_attach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xa910209f	scsi_register_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xcfbe6640	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xebfca1a6	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x22aa49a0	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x553d357b	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x57f30142	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x6eb060e3	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7a7719e5	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7cf6ee12	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x891bfb1c	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8c7c90d2	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x99e87a57	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x9c85ce4a	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xbec6fd95	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc9b360a2	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xcda088e1	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xeb25df12	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xeceb42bc	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xfc36f0a7	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x032fb243	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1070b933	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x329ad5e6	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9631489d	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xa5dede7b	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xff40299a	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x09918024	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0c9b6425	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x109e8882	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x188efcf4	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1ed61604	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x22388268	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x282ff6f9	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2a902d4d	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2e01ccc1	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2eb88f8b	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3efdf4fc	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4298254b	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x45b06c08	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4d271163	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4fb345ef	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5478e1fb	iscsi_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5656d6fc	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5f8522f0	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6391c6de	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x72409562	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x799a5393	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7de8f529	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8698d551	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x87d14e30	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x8d288426	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x917ab875	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9180e55e	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x99455e48	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9aa4db01	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa155ff9f	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa40e1d10	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4832cf0	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xaace2d69	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbe310729	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc0adeb1b	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc0f80e6e	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc82b3393	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc850ff07	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xcbb2685a	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd2bb52be	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd49416ac	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd97284d3	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe7667045	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe77a467d	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe8fa61a5	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfce91d5c	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x130201f0	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1b21d715	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2b06e897	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2e505138	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x32e00117	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3ec8de84	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3fe5e668	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6a64e1f9	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x8a907b70	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x90ee9013	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x93635deb	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x94da42dd	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x99dadae3	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xaabbfcdc	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xbc24a5bd	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xdb104ab6	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf96f8116	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x018d55d2	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0ac06347	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1bacda42	sas_change_queue_type
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1bf23389	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1f140ad9	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1fa3fee3	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x28201961	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3b2ff2b6	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x4a206db9	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x4ef2963d	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x55e33070	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x692a554c	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x7c2fb1a6	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x87020cf7	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9d79e07f	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb7929cde	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xbfec791a	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xc50bbbd9	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd07d3c9b	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd6b03aff	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdde498f3	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe7f95bef	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf64fac1f	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf64fc94c	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfb75e7ee	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x3df69a57	srp_transfer_data
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x7a8e16db	srp_iu_put
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x8ee60fc8	srp_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xa03fec1b	srp_cmd_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xb285a801	srp_target_free
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xcc006af8	srp_iu_get
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x1b41e600	scsi_tgt_alloc_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x2b0cd1e9	scsi_tgt_free_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x671b9497	scsi_tgt_tsk_mgmt_request
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xa8d1180b	scsi_host_get_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xba624a84	scsi_host_put_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xca48f7e2	scsi_tgt_cmd_to_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xd99714a4	scsi_tgt_it_nexus_create
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xda9cb2e5	scsi_tgt_queue_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xe5585b07	scsi_tgt_it_nexus_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x03add7af	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0ebe5587	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x17de3fb1	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1cdcdff9	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1f40069e	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x25075c4e	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x261ebb51	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x27a4e06b	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2a872f29	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2b801a3e	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2d745839	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x30458655	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3049268c	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x48f53969	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x49180442	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x65e5173e	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x66c20bb0	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x72eb24dc	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x739eb0e3	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x772ec52d	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x779ace4f	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x79e68000	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x79ffd8d6	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7b1ed2ea	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8bd9aa39	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8cef9c67	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x8e612747	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x97477360	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xab793244	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb051d7c2	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb0912981	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb6c507fe	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc33d8ebd	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc4d4321b	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc7abb463	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd5cc899c	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd8e4df7f	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe21abca5	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe8ef8bb6	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xeddcd558	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x56b2bf1f	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x651f2e29	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x75cdd7ba	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x7fdfa43f	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x404bac87	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xac44e42a	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xaeafb8ba	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xbf982f69	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xe053630b	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x0a69e8b2	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb99c6485	ufshcd_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xf003cc88	ufshcd_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xf23fab3e	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x29f53291	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x3ccbb470	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xcac3eda7	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xd08bb001	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xd5d2f2c7	spi_bitbang_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xe60003fb	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x42219c0d	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x45c7acc2	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x528d3a96	dw_spi_xfer_done
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x5e4e5a66	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xfc95112b	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x70bae09c	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x01d8b972	comedi_buf_memcpy_to
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0222541f	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x03779fb5	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0ec3e34a	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x168c44df	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1af8975c	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x1ecc47b1	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x223dd46a	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x24c4750e	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x25791114	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2c39edf3	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2e6933fd	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f732fee	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2fb05f13	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x40e05f80	comedi_error
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x49114ced	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5eba0ae4	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6547b480	comedi_buf_get
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6c9cdbe5	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x72ed7efa	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7a062ec5	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x80f86ee3	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8332ef1c	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8589b20d	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8c5a9b8a	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x95e72dd4	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x98310d38	comedi_buf_memcpy_from
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa00cbc06	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa1fc1c35	comedi_dev_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa20912f1	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xae8d0c2d	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb94ba846	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc1a5f3e0	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd82259d5	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe30ade25	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf12a2304	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfb959c66	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfc46ee64	comedi_buf_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x01c3e978	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x71c0a3a5	subdev_8255_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0xc4e21c22	subdev_8255_init_irq
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xe6b83e9d	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x02ffd392	amplc_dio200_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x32b8ca98	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0xedda9e51	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x3656c100	cfc_write_array_to_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x67bb7766	cfc_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0xb047bb0e	cfc_read_array_from_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x24325c6e	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x0c2e4fb8	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x1614c3d8	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x24d2920c	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2e6c6b16	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x30d98f7f	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x36cdf2b4	mite_unsetup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x39e9f8f4	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x4c2103b0	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x56780317	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x5dd77c76	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x65a2c665	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x74ec3d97	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x788f812a	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x80d8fbe9	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x810c81eb	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x8848ea84	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x97f31588	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xa137ef64	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xaab25875	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xb2ad48cd	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe17cf506	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe924d410	mite_setup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc 0x47301497	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x1a7c2187	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x25debbf0	ni_tio_winsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x56849daa	ni_tio_rinsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x75701b06	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa80d868d	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb5420053	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb89a6651	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xd7324042	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x1308278f	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x2c6d988f	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x309833f3	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x51305305	ni_tio_acknowledge_and_confirm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xcecb7f48	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xef36a07d	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x232519e4	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x2521f222	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x276fdb83	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x2b25ae94	comedi_dio_bitfield
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xb1a06918	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xc74e65ee	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x4119da0b	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0x0bbe6be7	nvec_msg_free
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0x28c64b7d	nvec_unregister_notifier
++EXPORT_SYMBOL_GPL drivers/staging/nvec/nvec 0xf6d78841	nvec_register_notifier
++EXPORT_SYMBOL_GPL drivers/staging/rts5139/rts5139 0xbd5a0e51	rts5139_usb_ids
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0fcf9560	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x21c13a21	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x22107c82	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x251be66f	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5b02675a	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x7e532ea1	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x86442336	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x917a1270	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xaf5d671c	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb2978dbc	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd23a71d7	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf97ee65e	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x033d1b95	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x13b6afb0	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x30397f01	sockfd_to_socket
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x44acb158	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x5498bf9b	usbip_recv
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x590e9332	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x599e80c1	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xa06a7082	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xa0c3b787	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xa0e9804a	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xab8a38fb	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xb58345cf	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe8f5136d	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x425f2b2a	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x51c281ca	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x88f17abf	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x407bd6bf	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x55c3ec4b	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/dwc3/dwc3-omap 0x4db92025	dwc3_omap_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0d270eee	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x0f4fa3a8	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x24b41327	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2804efb2	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2df5b02f	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3e8d65b3	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x536ca890	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5c558419	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5ce99e0b	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5e88b309	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5ed2935b	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6479d987	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x675042a4	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6d068c47	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6f87dafe	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x72bd83bf	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x793ef927	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x83664d7b	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x84af0f97	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x87041a39	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8f4c6771	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa21750f9	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xade61cad	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xafb41928	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb37ba7e8	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb92f2e3f	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2666b45	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x0ffc09d0	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x799d5e08	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x9c2581cc	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xd3883d7c	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x42dcdd5e	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xb0614620	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x17c45b3f	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x2fb6cce6	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x393bd770	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x764c2625	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9f6e0608	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xaeab4969	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xbeccceb9	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe12b7151	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf45a8dc6	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/musb/omap2430 0x6fb55e1f	omap_musb_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0xe58c2067	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x31141600	samsung_usbphy_parse_dt
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x3234fbc5	samsung_usbphy_rate_to_clksel_64xx
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x5517f819	samsung_usbphy_cfg_sel
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xce8db7ce	samsung_usbphy_set_isolation_4210
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xf42d6a4a	samsung_usbphy_get_refclk_freq
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xfbbcf7c1	samsung_usbphy_set_type
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xfef151e9	samsung_usbphy_rate_to_clksel_4x12
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x376cc123	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x02386f95	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x0513134b	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2a6a2396	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2b70b648	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2ce40f36	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4429fac1	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x49c15a4f	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x569a0725	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x72374936	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x72c07d62	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x75bf6468	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x8cccdc2d	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x94c4e0a5	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa7bdf9a8	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xbd6673eb	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc2479f47	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc26c20f1	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe6d005c3	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xea967e1b	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf54a2e39	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0689fab5	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x14b8d221	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x29ca3cf7	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3bf3296c	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4b76eb3d	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x4d24131d	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x693813e7	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6d097e94	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7170effd	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x870693c7	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8b365ea1	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x91745e83	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa28a9301	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xabaa5b6e	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xba286223	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc6caf624	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc8c8a962	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcfb4861c	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd0fe2619	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd2588124	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe01f128f	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe8c07771	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x0dd3fc46	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x28288988	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x41a3aa82	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x848bdb16	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xfd8d0d55	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1d4e69e7	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x1d69e3d4	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x29a81076	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x417dea0c	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x5a92b534	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6782dba1	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x74f14201	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x772e0702	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7ca68bbd	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x919c6c5e	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xd3680aff	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xde966f3d	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe04d2306	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe19494c6	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x7ee70e1f	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x8d78d2fa	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xa59d6c78	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x1e2e5a67	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x4b5ce058	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x7ce237af	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x8108f921	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x9e23f8eb	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xa348d732	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xc0a73143	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xefd1128d	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0d618f68	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1509890d	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1ba62bd0	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x1da59ac1	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x23511f4e	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x249b6bce	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x25b7f353	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x360d848a	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3708bc28	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x381eefb4	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x393fba4d	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3b85c7a5	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x59d460d2	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5a5ca84b	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x64acad45	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x72ac7e1a	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7452d0b8	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x78ec4443	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7de50768	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x88dc178c	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x8ceb8ac5	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x919a9a32	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x92b9ba6d	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x932c529b	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x97306ca3	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x984fd17f	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9a61a08d	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9b5e355a	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa24eb4b0	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb5a204fc	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc36482d2	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc8d3e481	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcadbc79b	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xcc07d61c	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xea3b3748	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xeebc2ef9	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xfc6e07b1	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x2a6b8978	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x05ab02ad	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x47dac68a	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x54a555b2	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xd77314d9	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xdd9b8df4	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x00f43361	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x02637d96	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0a13573a	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x16c5354b	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x23c19cdb	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x23c6ec2a	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x32bcc5e8	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3a0b271a	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x506b0565	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x51b2563e	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x57697998	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x59bfe129	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5c78f620	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x60c0259b	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x62b73d8c	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x655613d6	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x735a6a49	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x83d49e02	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8817a6c0	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8d8dddc6	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8e61738c	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x96406948	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9b1adc0f	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9e83aaf5	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbaeb3e7c	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xbd1793ed	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc60cd595	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc8f5b642	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdf2232dd	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe0d9af73	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x2936dfbb	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x4448c8f2	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x60d5ce69	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x6dbf48c0	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x770508fe	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x7fdd3357	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x9ca94165	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xaabb8626	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xb83995e1	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xf3090f6b	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x2337761e	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x53b8435f	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x8c613611	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb21d05ed	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xc52ecb30	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xe5d6b53b	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf12fe9d9	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/fb_ddc 0x30aa9f5f	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x25b3b646	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0xfb8c9b10	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0xb84e8c7b	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0xbfbed73a	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x12e853e6	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x25109c37	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3c58f3be	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x41f28d13	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x4cca8204	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x54fd325a	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x793ea9d8	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x939c4b51	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf4145b8c	w1_write_8
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0xe071aa68	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x040e2282	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x16f695c7	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x498aa549	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x0d516701	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x17ce645d	locks_end_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x183e5093	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x23f7b66e	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x2b9fc213	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x61ca5ea4	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x6bad0428	locks_in_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x81fd3452	locks_start_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xac8fda38	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xe856ce60	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0515ced5	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0580933e	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x083caaec	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0875736f	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x14ce47eb	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x19b7d1ed	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x19f98588	nfs_readdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b268643	nfs_readhdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x22d7bca5	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24ea37d0	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x266a1c99	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2a6b89b2	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d32f69b	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d523aa9	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2e744384	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f731e9e	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x303d10a7	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x30f85a8b	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x31b4a222	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x328a4d7b	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x35d26b23	nfs_generic_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x373cad5c	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x38f1931d	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3982c172	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3d64a261	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e0709f3	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3e0e7199	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ffe0d19	nfs_initiate_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x41012c0b	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45b3ac01	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x467db5ff	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x486f6810	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a6fc7b7	nfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4e99dca3	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5341c3c2	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x56a375c6	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x576d1cf2	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x58e0dacd	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ca3b876	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d84e626	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e1d863a	nfs_sockaddr_match_ipaddr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x60bbfb50	nfs_fscache_set_inode_cookie
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6194a827	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x61e30997	nfs_initiate_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6322d2e9	nfs_writedata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x64062e27	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x64357c00	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x663b840b	nfs_pageio_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x69a2c81c	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6ace0cc4	nfs_put_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6db875c2	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6ff9ebfc	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x70db939e	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x732564cc	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x789fa2ed	nfs_setlease
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7cbe5e89	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7e9c1ff3	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ebe2269	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x845b2570	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89bc5a64	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89d16a49	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c35135b	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c641287	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c76011e	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a00f5a	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91786c56	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9465ce5f	nfs_file_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x947926a2	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x948f6f9b	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x976ecd70	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x97b70883	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x984ed228	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x99a03da3	nfs_pageio_add_request
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9d64e597	nfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa0041dd1	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8d2d1ce	nfs_callback_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xac6fdd4d	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaca364d5	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaf24a388	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaf9b77ce	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb03dfd05	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb06d10d4	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb0b84728	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb559fa3f	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb8863104	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb9037ba2	nfs_generic_pagein
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbb1a9737	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbc2b7fb6	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbc361051	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbdb72e5b	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbf36a039	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc01519bb	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc1ef40dc	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc4d1421f	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5868388	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5fd2177	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc944a2e6	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcd176a62	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf12ebeb	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd078b147	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd0b40155	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd14ed47e	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd22e5975	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd2f797fa	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd425ab50	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd45f7d9c	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd47b49a8	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd67ac192	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd82da9c9	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd93a2b36	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdcabce8c	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd0928c4	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xde59ed52	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe44c8c50	nfs_writehdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe58b28a1	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe5a68619	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe7e1b13a	nfs_file_splice_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe860697b	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xebef26e7	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeea02a61	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeebc1837	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeeceb206	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf2de963b	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf59758c9	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf5feba21	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf6018933	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf9a7e2b2	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfce1ca76	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfed3120b	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfee23e3e	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xff6fe39e	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x014cd53b	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0d8f260b	pnfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0f1be938	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x11f4fb49	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x130ecf2b	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1b37e1d2	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2110c4f7	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2afba96b	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x501938be	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x58d9845d	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5c708d89	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5efe302c	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69185869	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8110ae0b	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x824def4f	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x87ee6f61	nfs4_insert_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8f0974d8	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9242e96a	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x94c4d143	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x965e7e41	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa051912d	nfs4_proc_getdevicelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa1562ebc	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa16ef5b3	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa1ce2006	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa4df167f	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa62ba54b	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xad9ab6a6	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xaf3d0da3	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc378c25d	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc51e207b	pnfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc751c0fe	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcb8402e9	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xcd34568e	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdaee2cd4	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe22ff818	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfa0ee5ba	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x82525d08	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xdba91107	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x0a5a1ec4	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x109b42b4	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x3a46a1e0	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x501ef369	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xcd55c83d	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xeaa9abc1	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xeae08e11	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x23e7cecb	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x47440c99	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x4c27089e	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x69d59764	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xdaaca630	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfab4938a	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x025e2d69	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0562c415	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x16b2e575	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x377b647f	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x5469ce31	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x7083dbd5	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x89502fe7	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xb4bd060c	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd46e714e	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdc823ea4	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe2bd47db	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe417d940	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xf119b2cb	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x2ef544ca	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x63820d7c	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x05513b71	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL net/802/garp 0x079e2218	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x1e6e5d40	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x4e066641	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x9f2365ac	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xb7197d1b	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0xf0205ea1	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x082eca35	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0x1f7aa057	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x61f6aa4d	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x8331481e	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xc5707c0b	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xfebc4e97	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/stp 0x411ec1f5	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xa53c485c	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x2454a3fd	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xa81f340b	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xcdb0e1ad	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0xc1a7daf7	bt_debugfs
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x006c3a24	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09a123b7	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x17df31b7	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x267f3e07	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x28cc0333	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2a8183ce	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x39078676	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x394d5f59	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3c2a70c5	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x412ed8fb	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x44f5f27a	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4b0e1b79	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x528a78d0	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x590b6d19	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5fd2cc87	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x60ff6650	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x733f798b	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x73a91e42	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x765ee749	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8b2df695	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9a20aeef	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9c49d8f7	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa00f9fbc	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa6c7f417	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xab70cdbd	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbbd37d1d	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc7715ca1	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd45f3d10	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd4abc784	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd9d25302	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd9d9edd6	dccp_insert_option_elapsed_time
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xeb469e06	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf198b3bb	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf1f33200	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf3017e21	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfc7ea7b8	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x0b8c17e7	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x10bdfb23	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x3e8686d9	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb8323a7a	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xc01713f3	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xe3ed2048	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x3cc59323	unregister_switch_driver
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x53d26c31	register_switch_driver
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x24b240eb	gre_handle_offloads
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x74f0f1b5	gre_build_header
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x7a661870	gre_cisco_unregister
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x83f068a8	gre_cisco_register
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa1cdf139	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xb562e0a6	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x124e592f	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x237da114	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xa8959f33	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xaea838ef	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xd1aa4edc	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xf7298a2f	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x14741479	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1e50a6f3	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x390c6cf3	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x51b583a7	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x635916a9	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x7168d826	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9aee698d	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa0fd2eec	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xab60657d	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc4e231e6	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xcf0e6f16	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xcff959fd	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xe61d2716	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xfb26aa02	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xaff22e16	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x9998e05c	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_conntrack_ipv4 0x6d40a921	need_ipv4_conntrack
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xb336e0bf	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x031d5f1b	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x398733d9	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x6113ced9	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x9d4edb7b	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xca20759b	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x178335cd	xfrm4_mode_tunnel_input_register
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x299adbe1	xfrm4_mode_tunnel_input_deregister
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x0c3f3ba6	ip6_tnl_dst_check
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x3163efa7	ip6_tnl_dst_store
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5fb9ad7d	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x67985fc8	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xe97070b7	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x2c6fc443	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x9a3307b2	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x26292093	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x288855bb	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3c101f5f	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x54ef2058	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5811a4d3	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5fa20b29	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6e070e76	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6fe149c3	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x79fc53e2	l2tp_tunnel_sock_put
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x91c3192e	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xa7b0b145	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb9cec3e5	l2tp_session_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc67f0e87	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc6eda217	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd05f6d6c	l2tp_tunnel_sock_lookup
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xfce43cce	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xff9365c1	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x54dafe7f	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x0add00f1	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x4425d078	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x7ba3dd7c	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x9f18eb90	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa024ffbf	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xac2081a0	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xca140dfa	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xebe1ed24	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xee9a548b	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xf0e3df63	ieee80211_iterate_active_interfaces
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x226c3c30	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x2f9e51bc	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3aae5431	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3dfc2207	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4e75110a	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4ef21ce1	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x57cf4986	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7762965e	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80ee118c	ip_set_nfnl_get
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x883d6572	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa130e3d7	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xac8a0c3e	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xaefe5d32	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc3b062db	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfda3ec7a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x5aa65fb1	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x7700e4b0	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xcaf7fba2	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xdfc30dec	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x036d8512	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x099676d5	__nf_conntrack_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x09e11ded	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0b24d3d8	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0df2e0dc	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0f67ba7a	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x179a406f	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1972ae2d	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x25665f9f	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x257e20b3	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x275ec90c	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x27bfb1b8	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32135d5b	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x361786f3	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x367f054f	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x39deea4e	nf_ct_l3proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3bbdc49e	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3c9c6a5a	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e5cb42d	nf_ct_dying_timeout
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4203f502	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x43eb58b2	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4755bfc7	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4a0613aa	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x575313c3	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5c6de248	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x64a00d64	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x659b3f34	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6ad04392	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7248f172	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x774f1aa8	nf_ct_nat_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x784f8137	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7967352e	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x824a442d	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x88f8190e	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8b4da116	nf_nat_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8fe4fbb8	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ff0cc1c	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x912e3e73	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x945eace2	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9752491f	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b5a0487	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9efd0c15	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa13d0711	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa4e42309	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa6c0d469	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa6ca9f2b	nf_ct_delete_from_lists
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa9db5a05	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab465acd	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad4d3ced	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb041465b	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb23f3373	nf_conntrack_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb5cf5af1	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbdc6ae9e	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbee58cc2	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0240dd4	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc99e4445	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xca417bf8	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcab68018	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcbb6edbf	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcc542800	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcf3155d8	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd1fe5b74	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd2c639ce	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xdec0eced	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe1e93c02	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe679db20	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe7719974	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe867f5d5	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe892332c	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe8b56ee0	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xedcae565	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xef9254ce	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf3c7b9e7	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf481a8cb	nf_conntrack_flush_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf8fc3827	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfd07375a	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x40cdea5e	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x93e6aadf	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x9ae30daf	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x01a7bc6c	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x3e335001	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x58eb71e2	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x94526eae	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xb308b718	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xb5ee22e9	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc5c53d70	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xcf404ad4	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xe0c643d2	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xed751df4	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xf2a22a86	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x43afa168	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x8eb2adc1	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xa236ffb2	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xfaf03a97	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x68975c67	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x87ecd883	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x1050f729	nf_nat_sdp_session_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x167de43f	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x23b5f467	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x327c4303	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x47590e2b	nf_nat_sip_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x58090eff	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x614e3608	nf_nat_sdp_media_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa247e343	nf_nat_sdp_port_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc6ae95c0	nf_nat_sip_expect_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xcd87b1b1	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd7add726	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xef60887d	nf_nat_sip_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf6baac04	nf_nat_sdp_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0x464bba91	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xeb04362f	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x00efa557	nf_nat_set_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x59c62e80	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x8b8185c2	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x93f225ca	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x9b65af59	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xa2387bf7	nf_nat_tcp_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc64b38f1	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe26180b2	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xe6566dad	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tproxy_core 0x0be5b37e	nf_tproxy_assign_sock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1841308b	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x2591a2bf	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa118ba10	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xa3c4cfb7	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xde8dcf56	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdfb0beda	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xf2943366	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x1121137d	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x21f6bba6	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xc6aa581e	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x09e6713a	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x373c10be	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4de8c897	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5fb2114e	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6a00bb04	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x74b82ffe	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x75bcd905	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x85d817be	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8fc6df9d	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xa9210de1	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb1d67bab	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xcaf9a601	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xe371d493	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x57909dc1	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xd0f26ea3	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x01854248	nci_spi_free_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x8ad9415a	nci_spi_allocate_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xa992bb42	nci_spi_register_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xea687af5	nci_spi_unregister_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xf052b0be	nci_spi_recv_frame
++EXPORT_SYMBOL_GPL net/rds/rds 0x00813c70	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x0efe2fc3	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0x13841b73	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x17457b90	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x32d645bd	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x3a921f10	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b844310	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x40a77efb	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0x41187b69	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x4c4411d5	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x54e278d6	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x61ed1841	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x6494b260	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x71154ae8	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7ffc832c	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x953cfe22	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x99665b65	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0xa76c67c5	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xb5f79ced	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc313655f	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc642cc2c	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xd3c5084a	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0xeffc7670	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0xfbccb9cf	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xa3e2f921	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xac2bfdae	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x60d37ef2	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xc9d59602	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xd28f8dbf	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0149b9ce	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0169d916	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01e11318	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05d9422e	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07266acb	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07d80073	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x08e081c5	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0b24536f	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c32f40f	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0dd705b5	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x105c0507	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x10c31665	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x116a153a	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12c586c5	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14e69720	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x156703f0	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15974bf4	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19612179	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1963542d	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x19e70f26	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a2ac49d	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ad746bd	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b9269f9	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c5fab82	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cb447f3	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ea5c2b6	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x223be6a0	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2296a105	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x238299cb	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x267b781d	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x26eabd5e	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2732820b	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2750ed01	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27c2db1e	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x284c0c33	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f5427f	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x299e4f04	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2a1bbfcc	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3034a83d	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x326668df	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3387e6e1	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x34e5d9a5	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x351bd7d9	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x353f3f30	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x369d47e3	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x379674b4	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3c1d991a	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3cc422a7	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40b87077	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41591d9c	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x41b7dab2	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x43d1de74	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x443a4e9a	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48b8392b	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x491e17d4	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4ad337d7	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4b0c5af5	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4bb7beb5	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4c6d564e	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d14200b	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d3d7c07	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x50eb1624	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53113204	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53365fc9	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5908695b	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59c9c6b8	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5ac7d831	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5af62ff3	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b0e2ef0	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b1602b8	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c41c77d	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5f9cb4fe	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x632cd3db	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x665c01fd	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66c66afd	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6776c56f	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6781624b	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67daec3e	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x686eac94	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6add74b0	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6aeb5b3a	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6bcd4dd2	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6beb8338	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6d79a975	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6fb6d49a	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x70aec067	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71245072	xs_swapper
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71bc5b8c	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78599060	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x79e72619	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7a8dca80	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b97eef6	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80a8fb9a	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80e51550	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x831190c9	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x853a0800	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x872d6e16	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8762b567	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88395129	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x88884b95	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8b2e03d6	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8b3bc73f	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8da6e10d	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8eefead1	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x90c32dc7	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9341d576	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9447df1e	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x968230ba	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a929179	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9adf7da5	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9b3c0d20	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cc33cee	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ccecd13	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9e7a4961	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f50c3d4	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f9b6e72	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9fcb2337	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3289fdb	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa55fd81a	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa9042468	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa565ee9	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa9eccc0	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab3f2ff6	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab61b7c5	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xab92ef94	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaca874a0	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0060cd8	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb2623646	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb3be940c	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb599630f	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5f77b8e	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb87a6eeb	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9279960	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb96e6a46	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbdac9161	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc020a556	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3752a0c	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc481d3d3	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc544e62f	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8df4bd7	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcb067be7	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcba9e012	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd4b55cb	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcf1f9b0d	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcf8e2237	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd309df42	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd787905d	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7911849	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd89afba6	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdaba98d8	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc1d7e98	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdea400c7	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdee96d17	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf9c9ec9	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe187f296	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe24a05e8	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2a9b905	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe376b32a	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe569420d	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe6b8312f	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf02655d2	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf036bfaf	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf0763c30	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1860cf8	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf1897d31	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2d55d89	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf2e439a2	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf36ebbea	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf693fd5b	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf7154dc8	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9400065	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9c88af9	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfaad03ce	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd348a32	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfdad33be	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xff51d383	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x16d5adb4	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x1b4eeb2e	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x66881138	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x85aeb8e6	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa08d6aa9	vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa66a222c	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa823843a	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xab9ae9d4	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb2c86cb0	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xc605a202	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xda139353	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf6a38a0c	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xfe31ba82	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x329a419a	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x6aaf6ac6	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x73dedaba	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x7e7e46d5	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8242ff98	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8dfe19ce	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x8f535567	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xad6fe0fe	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xc1e22fd3	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xc9e9d88c	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xda08bf96	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xde07f8ac	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xe6b7e21b	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x04758bd7	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x32db21a7	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x3d818b30	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x4141410b	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x5c5848c1	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x98f75f45	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xad98a4b4	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb7cee1ec	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbbd67a4e	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xdd696f72	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe840114e	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x00778770	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x056bb269	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0b9e5852	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x58e86480	pskb_put
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x74e1a843	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7c30b8c7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x92dbc6c1	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xbc8b0f41	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xce7a55c1	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xe122af95	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x06b391da	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x179b2b14	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf21511ce	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf4f89718	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x0c896ff2	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x0f6a5fbb	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x21fdf497	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x751c6654	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xac6b1eb1	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xce9f86f7	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x006eb9ac	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01dbd370	snd_hda_sequence_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x01fcd99b	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x027dbfe4	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x069bb369	snd_hda_codec_update_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x06fe869a	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07e8c946	snd_hda_bus_reboot_notify
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x08267662	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e194e85	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e5f58ae	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0ee5cd0a	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1117e0d4	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x113c407e	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1269cff8	snd_hda_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x13fda501	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x144d5533	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x145b2f12	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x16ed9334	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x182fa1f9	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x188cfb0f	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x192abfb6	snd_hda_is_supported_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x19b6e599	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1c0d6279	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d57154f	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1dce8fa9	snd_hda_ch_mode_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x229a1f28	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x240a4c2d	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x241153bb	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x27cd763f	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2951e62c	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2a52ca55	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2b005a61	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2bbf9ed5	snd_hda_ch_mode_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2e16eab4	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2f04f4fc	snd_hda_check_board_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x32a1eeb5	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x33d89359	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x362402c3	snd_hda_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3ad5b707	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3b3d3a6f	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3cf6becb	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x40b9de81	snd_hda_add_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44282c27	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46bfd705	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4994782f	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4dab1f60	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4fd384ac	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x50146dd1	snd_hda_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x501a076d	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x537170c0	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5397d1c8	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56b6d530	snd_hda_jack_tbl_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56c71ee4	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5957d96a	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5b85b672	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5edbdbea	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5fc51495	snd_hda_codec_resume_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x600ae002	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61bf33a2	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6232e5f3	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x62a933a9	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6323d8df	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66fdbf33	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x66fe2438	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67e1d3dc	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6a89c79a	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b1694e0	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b40fe78	snd_hda_suspend
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b96728e	snd_hda_queue_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6bf32908	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6c5c3561	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6cd69e5d	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6cd716fd	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6d1bff62	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6edeb480	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6f61983f	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6fc95559	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x71dfe0ef	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7302cffb	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7a6600ac	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7c52f2a8	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x814907dd	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x861242f6	snd_hda_gen_spec_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8a19fa5c	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8ad83c77	snd_hda_codec_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8bb5b6c8	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e4c6826	snd_hda_calc_stream_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e6330b7	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x91342531	snd_hda_codec_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x93c1a755	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x93c25211	snd_hda_delete_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x94544085	snd_hda_codec_amp_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9503b8e9	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9532f661	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x963811f8	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x97b95f3d	snd_hda_resume
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x99a98b3d	snd_hda_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9b1e66c5	snd_hda_query_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c0528ad	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c6ac5a4	snd_hda_codec_resume_amp
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9cd0ee80	snd_hda_ch_mode_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9d1a802d	snd_hda_parse_generic_codec
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2827d76	snd_hda_get_jack_location
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa3b938c5	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa7834bc3	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa8652759	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xabc6b753	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadeaba13	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xadf06339	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xafacb230	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb0c00e43	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb33891c3	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb4340e70	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb44b511a	snd_hda_check_board_codec_sid_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb6081dff	snd_hda_jack_detect
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb6ebad44	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xba5d0253	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbad8d42e	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbce3a24a	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbd1c4441	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbfabefcc	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc06f30f4	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc136cdca	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc323c81f	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5a1fd27	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc652fd69	snd_hda_get_jack_connectivity
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc78c8918	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc85a4d8d	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9252f09	snd_hda_override_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xca3158bb	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb301b6e	snd_hda_get_jack_type
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xce9921a0	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2c69db8	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd345eb92	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd695a041	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7882c9d	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd7a8655e	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdfa8e5f1	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe0932c2d	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe1ec196d	snd_hda_bus_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe495f217	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4a37333	snd_hda_codec_flush_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea247469	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xecf4f890	snd_hda_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xed97901c	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeeb6f60b	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf045e9a8	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf13b02ff	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf69b5d5a	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf945c7ee	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9557f6a	snd_hda_codec_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9cffdad	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfcd27c6f	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfdf5703e	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe2da0d5	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x04fcfc0b	atmel_pcm_new
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xee45597f	atmel_pcm_mmap
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xfe44b505	atmel_pcm_free
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0x19828827	pm860x_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0x395cf533	pm860x_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0xeddc94ad	ab8500_audio_set_ear_cmv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0xf8532cfd	ab8500_audio_setup_mics
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x033fb1b0	arizona_init_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x05ddbf0f	arizona_lhpf4_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x12ecde17	arizona_out_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x196694e3	arizona_ng_hold
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x206e3ddf	arizona_in_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3f429d4c	arizona_isrc_fsl
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x41b95c1f	arizona_in_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x4f857e02	arizona_set_fll_refclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x547a7178	arizona_rate_val
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57a7b97b	arizona_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57e590a8	arizona_lhpf1_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57ebef21	arizona_in_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x5892a12c	arizona_set_output_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x5c270695	arizona_init_spk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x660d8a35	arizona_lhpf2_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x6cefa2b3	arizona_init_dai
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x733bbfd7	arizona_out_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x78b9584e	arizona_hp_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x78d8489a	arizona_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x7a03c87e	arizona_set_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8c821bc2	arizona_rate_text
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8dd35bf2	arizona_mixer_values
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xab6861be	arizona_mixer_texts
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xbdfb98df	arizona_simple_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc07a8181	arizona_lhpf3_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc9c29637	arizona_mixer_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xfe0151d5	arizona_out_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cx20442 0x1642157a	v253_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-l3 0x78c84c7e	l3_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x84de40fe	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0xd6344577	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max9877 0x2ebe2ec8	max9877_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x30d9205b	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xfaca7c45	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wl1273 0x66bd6083	wl1273_get_format
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x2bda6afd	wm_adsp1_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x2f747441	wm_adsp1_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x3aab3a63	wm_adsp2_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x5acd1ae5	wm_adsp1_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xb04bc787	wm_adsp2_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xf453f2b8	wm_adsp2_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x04cd9987	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x3b054d4e	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x3d11fa6c	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x715922e2	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x75789687	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xd39ebefd	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xd8d24272	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xfb2d6ff9	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0x0bf3bf5a	wm8350_hp_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0x0df7b71f	wm8350_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x6e9cb2bb	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x6adee406	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0x568d98cf	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xf0319262	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8996 0x6d620568	wm8996_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm9713 0x0593ebbf	wm9713_reset
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-pcm 0x4b72e705	tegra_pcm_platform_register
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-pcm 0x678280be	tegra_pcm_platform_unregister
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x0901cc47	tegra_asoc_utils_set_rate
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x3f75eab6	tegra_asoc_utils_init
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x5fe07781	tegra_asoc_utils_set_ac97_rate
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra-utils 0x659e7515	tegra_asoc_utils_fini
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0x0d54c9b9	tegra20_das_connect_dap_to_dac
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0xb52cfca4	tegra20_das_connect_dac_to_dap
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra20-das 0xbced7431	tegra20_das_connect_dap_to_dap
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x33e6f259	tegra30_ahub_allocate_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x55a40206	tegra30_ahub_disable_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x5cf6f91f	tegra30_ahub_allocate_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0x6fe20143	tegra30_ahub_set_rx_cif_source
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb419329b	tegra30_ahub_disable_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb4a9367d	tegra30_ahub_enable_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xb81bca9d	tegra30_ahub_free_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xc78c7125	tegra30_ahub_free_tx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xccc98372	tegra30_ahub_enable_rx_fifo
++EXPORT_SYMBOL_GPL sound/soc/tegra/snd-soc-tegra30-ahub 0xe549513a	tegra30_ahub_unset_rx_cif_source
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x03b5ac62	lib_ring_buffer_poll
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x11e5cc84	channel_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x147a3c77	lib_ring_buffer_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x180c4ddb	lib_ring_buffer_read_get_page
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x18d9ddfc	vfs_lib_ring_buffer_no_llseek
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1f1703a8	lib_ring_buffer_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2057c637	lib_ring_buffer_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2671941a	lib_ring_buffer_put_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x29de5f5b	lib_ring_buffer_switch_remote
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2a9510af	lib_ring_buffer_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x3157aa21	lib_ring_buffer_get_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x378368fe	lib_ring_buffer_move_consumer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x424c9863	lib_ring_buffer_read_cstr
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4880cd1c	channel_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4e150b52	vfs_lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x5c2a881e	_lib_ring_buffer_copy_from_user_inatomic
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x6482075c	lib_ring_buffer_snapshot
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x6d4765d1	lib_ring_buffer_reserve_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x71a8a907	channel_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x7d93bf34	lib_ring_buffer_open_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x805f377d	channel_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x890e13e2	lib_ring_buffer_release_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x89134549	lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x99f07961	channel_create
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xa63792d0	lib_ring_buffer_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xa99e4656	channel_get_ring_buffer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xafb3666d	channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb231eb90	vfs_lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb2ae7f8f	lib_ring_buffer_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb2fee4b6	lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xb3d3244c	lib_ring_buffer_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xbed224f8	lib_ring_buffer_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc78ca086	__lib_ring_buffer_copy_to_user
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd035278e	lib_ring_buffer_read_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd0621654	lib_ring_buffer_ioctl
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd98ba90f	lib_ring_buffer_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe834a67f	_lib_ring_buffer_memset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xed3610a9	lib_ring_buffer_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xeef34040	_lib_ring_buffer_write
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xf087f119	channel_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xffee3cbb	lib_ring_buffer_switch_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-statedump 0x09e2fdcc	lttng_statedump_start
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x02a9f75e	lttng_add_vppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x2bb318f5	lttng_add_vtid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3195a4e9	lttng_event_put
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3849cf38	lttng_add_procname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3b0e134e	lttng_add_prio_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x4079b139	lttng_probe_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x471079be	lttng_add_hostname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x4ece833a	lttng_add_nice_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x57ea4e27	lttng_metadata_channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x5f31e0c6	lttng_transport_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x63db8054	lttng_add_ppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x6e8731e3	lttng_probe_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x6f962a28	lttng_add_vpid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x710d0181	lttng_find_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x85588035	lttng_append_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x8734a71a	lttng_transport_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xa752579e	lttng_remove_context_field
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xb8e0c306	lttng_add_pid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd9bda6a8	lttng_event_get
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xfcc5f1db	lttng_add_tid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x162f5a05	lttng_kprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0xc3314a16	lttng_kprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0xd5574403	lttng_kprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xa035af07	lttng_kretprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xd9f647bf	lttng_kretprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xe25f1935	lttng_kretprobes_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0005016b	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x000eea63	cgroup_next_descendant_post
++EXPORT_SYMBOL_GPL vmlinux 0x00111d1a	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x00187567	pin_is_valid
++EXPORT_SYMBOL_GPL vmlinux 0x002957b2	blkg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0037aae5	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x00391aad	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x0056e49b	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x005c29ad	ahci_shost_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x0065b619	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x0067df75	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00831f3b	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0088c896	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0090764e	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x00b1db0c	ahci_set_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0x00b70232	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x00c3eddc	__netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x00c4dc87	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x00cbbe31	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x00d48f33	omap_usb2_set_comparator
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x010d3400	snd_dmaengine_pcm_open
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x01474187	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x0148adb6	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x01727ce9	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x01a0fe04	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x01a8bea8	omap_dm_timer_set_match
++EXPORT_SYMBOL_GPL vmlinux 0x01b4e67a	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x01c6cb0c	cpu_cluster_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x01d4b8bf	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x01e64cfa	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x02049993	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0215d6d2	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x02203a03	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x025c3456	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x0276e7d5	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x02c625b8	cred_to_ucred
++EXPORT_SYMBOL_GPL vmlinux 0x02f88ae1	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x032832b9	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x034caa04	opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x036d391b	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x037862fa	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x03902b32	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x03b15cc1	omap_dm_timer_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x03b53546	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x03b738bb	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x03cace44	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x03cfb1db	omap_dm_timer_set_load
++EXPORT_SYMBOL_GPL vmlinux 0x03d66cfa	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x03da4823	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x03f5e4b1	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x0422c121	snd_soc_add_platform
++EXPORT_SYMBOL_GPL vmlinux 0x04266035	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x043c9806	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x0442fb72	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x04486e88	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x04538212	__mtd_next_device
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x0472caae	of_pci_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x0475f346	twl6040_hs_jack_detect
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x048e71b8	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04c511d2	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x04d7ce9b	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x04f4048d	tpm_show_pubek
++EXPORT_SYMBOL_GPL vmlinux 0x0531dcb8	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0551f0ce	tick_nohz_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x05720ec9	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05978d40	omap_iommu_save_ctx
++EXPORT_SYMBOL_GPL vmlinux 0x05e150e8	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x05edfbca	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x06011577	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x060f82ea	gpiochip_remove_pin_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x062fc169	xen_hvm_resume_frames
++EXPORT_SYMBOL_GPL vmlinux 0x06438115	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x064a7d91	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x0654e0f0	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x0665ccd8	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0x067e982a	mtd_panic_write
++EXPORT_SYMBOL_GPL vmlinux 0x06853c69	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x06a7a947	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x06d17a7e	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x06d549e6	pinctrl_free_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x06dceffb	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL vmlinux 0x070eb509	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x0713cfdf	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x07455fa9	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x07564002	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x076e5ec3	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x076ef8c3	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x079155a8	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b291d1	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07cf3227	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x07ed48c3	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x07ff0fa7	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x081a5701	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x083ff62c	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x0870a6fc	__mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0899f091	hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x08f1c04f	smpboot_register_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x090f08de	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x091db4df	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x092fe016	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x09469482	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x0952af60	fb_videomode_from_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x0985ffb8	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x09a80c9b	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x09c09d88	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x09ce8349	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x09ed36de	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x09f31128	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x0a3e1a65	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x0a7dee83	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a808aaa	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x0a8f10f4	tegra_pinctrl_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0aa2344a	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0ac6f373	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x0ad87a08	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0ae2e1d9	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x0af556aa	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b374325	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x0b44ea31	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x0b59390b	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0b63e1c6	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x0b78c98a	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x0b98210b	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x0b9a681b	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0x0ba8374b	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0ba994f0	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x0bae62b1	ktime_get_monotonic_offset
++EXPORT_SYMBOL_GPL vmlinux 0x0bbae511	return_address
++EXPORT_SYMBOL_GPL vmlinux 0x0be17af8	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0x0bee0812	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c15105d	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0c1c35f3	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c4db728	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0c90b18e	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0ca54de4	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cdbfd3a	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0x0d0528f6	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x0d2260e3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d33fc38	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0x0d847d87	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x0d9dad36	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL vmlinux 0x0dbd0e20	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x0de7021e	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0de83aa8	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x0df1c70a	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x0df53f2f	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x0dfc6217	__rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x0e2ac8ea	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x0e372cb1	opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0e3d1d7b	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x0e3e8bf7	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0e698b05	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL vmlinux 0x0ec9893a	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0ecdbeeb	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x0ed36b2f	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x0f15c129	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x0f25e779	snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0x0f2a03e9	md_trim_bio
++EXPORT_SYMBOL_GPL vmlinux 0x0f30c42a	usbmisc_unset_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f858414	omap_iommu_restore_ctx
++EXPORT_SYMBOL_GPL vmlinux 0x0f9d32ae	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x0fadee30	omap_dm_timer_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fc3bd35	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x0fd254bf	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x0fe112dc	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x0fe65e8c	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x101206a6	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x1020b822	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x1021cd46	snd_soc_cache_write
++EXPORT_SYMBOL_GPL vmlinux 0x1026c1d9	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x10291853	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x102c294c	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x10553d52	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x106d29ed	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1107c0db	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x110cd33b	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x112f6b63	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x1154e13f	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x1179b7cd	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x119be264	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x11f2ef5a	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0x11f447ce	__gpio_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1203731c	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x120e0b30	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x120e6d0d	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x120f39de	udc_attach_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1215cd89	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x121ccbe9	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x121cd964	of_pci_range_parser_one
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x121ed3f3	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0x122a3634	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x123cc747	snd_soc_cache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x124e3f6b	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x12570963	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x1258d9d9	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1263b5c2	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126afcd8	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x127b9210	amba_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x127e585d	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x12bcf8b9	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x12cd2439	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x12e5c3d9	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x13288d6e	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x133155b1	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x1334a6df	sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x133e7428	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x13543319	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x1357bd95	cgroup_taskset_next
++EXPORT_SYMBOL_GPL vmlinux 0x1376dd2d	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x13882a78	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13a195de	snd_dmaengine_pcm_prepare_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x13b89dee	pinctrl_request_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x13c69f23	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x1402f778	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x140c90d4	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x1423dc43	omap_dm_timer_request
++EXPORT_SYMBOL_GPL vmlinux 0x142a8be4	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0x14659aa6	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0x146b8606	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x14889798	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0x149d9e28	blk_queue_bio
++EXPORT_SYMBOL_GPL vmlinux 0x14b23d0f	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x14cba27b	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x14cfe5d3	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x14e07c63	ata_sas_port_async_resume
++EXPORT_SYMBOL_GPL vmlinux 0x14f2863f	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x14f875ce	devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x1506901a	class_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x1512ea2d	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x15255936	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x1525f36d	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x1549d6fb	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x157035cc	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x15722800	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0x157aba32	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x157f8bc7	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL vmlinux 0x15854ced	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15aacf9f	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x15e6a852	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x15ee2233	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x160fd95d	wm8994_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x16188b20	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x1657254b	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x165c2efb	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x1664a9e1	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x167f6224	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0x1685e235	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x16aa8e60	usb_gadget_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x16b5c401	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x16c1078a	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x16de848b	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x170017c8	dev_get_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0x170c7c0f	mtd_writev
++EXPORT_SYMBOL_GPL vmlinux 0x1716d3cc	__put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17893c8b	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x179a6809	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x17db2891	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL vmlinux 0x1819ce4c	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x1842afa5	balloon_devinfo_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1846a04c	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x18840c04	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x18a27f34	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0x18b549b7	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x1900dd6c	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0x1907c976	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x190f9a04	of_irq_map_pci
++EXPORT_SYMBOL_GPL vmlinux 0x193d48e0	trace_current_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x194693c3	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x19796853	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19a8b7ba	unregister_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0x19bbd686	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x19c6f1b5	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x19fc7f60	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1a01433c	omap_dm_timer_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1a082d69	max77693_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1a0c8b66	tegra_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x1a1767e0	iommu_domain_has_cap
++EXPORT_SYMBOL_GPL vmlinux 0x1a1c257b	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x1a2b00a8	crypto_rng_type
++EXPORT_SYMBOL_GPL vmlinux 0x1a323362	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1a4e405c	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x1a65920b	omap_iommu_arch_version
++EXPORT_SYMBOL_GPL vmlinux 0x1ac27698	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x1ad83009	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x1ae18336	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x1ae3142c	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x1ae4cd2d	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x1afc5d49	bmp085_detect
++EXPORT_SYMBOL_GPL vmlinux 0x1b10bd05	mtd_block_markbad
++EXPORT_SYMBOL_GPL vmlinux 0x1b3193ff	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x1b3261e0	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1b478b95	snd_soc_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b5ab1b8	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x1b617d13	snd_soc_get_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0x1b7926d0	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x1b8822d8	pinctrl_gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bab2646	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x1bab6862	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x1bb5fc26	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1bb6b2fa	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x1bc4ad31	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x1bc5eebe	pinctrl_gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x1bd47a54	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1c0b9251	regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x1c1aeda7	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x1c2092af	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0x1c21b0b4	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x1c2a01cc	tpm_write
++EXPORT_SYMBOL_GPL vmlinux 0x1c3a550d	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x1c430031	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c6e6cf0	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1ca45ccd	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x1cd37c4d	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x1cd6679b	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x1cf42ffb	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0x1cffc4df	RSA_public_key_algorithm
++EXPORT_SYMBOL_GPL vmlinux 0x1d27235a	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x1d2e1b1d	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0x1d3fc0ae	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d7188df	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c3072	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x1d94d896	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1da79a4b	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x1dc79a14	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL vmlinux 0x1de054d5	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x1e314b21	regulator_use_dummy_regulator
++EXPORT_SYMBOL_GPL vmlinux 0x1e3a88fb	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x1e57cdc3	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e5c7731	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e83fee6	HYPERVISOR_physdev_op
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ec4bf7e	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x1ec59936	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x1f1a8060	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x1f2ef654	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x1f37286e	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x1f54f1b4	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8d5a7d	snd_soc_put_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fcece42	inet_twdr_twcal_tick
++EXPORT_SYMBOL_GPL vmlinux 0x1feafa4d	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x20236d59	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x2045565c	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x205b072f	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x20a18fa6	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x20b3b0d0	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0x20bc3470	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x20f86a43	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21bbd26a	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2205b8f4	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x22112b60	snd_dmaengine_pcm_close_release_chan
++EXPORT_SYMBOL_GPL vmlinux 0x2232443b	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x2263d436	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x226a674d	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x22811e3c	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x2289beca	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x22915133	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2291bf37	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22978952	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x22ad9d06	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x22b7b711	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x22c16ecb	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x22cbf016	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x23216299	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x234df1f9	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x23679939	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0x236904e2	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x2373352a	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x238bacd1	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x23910e62	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x2392bc6e	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x23965d4b	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x23a517b2	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x23a59991	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x23e58900	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x23f8fab9	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x240580a9	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0x24131469	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x24419969	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x2447533c	ktime_get_real
++EXPORT_SYMBOL_GPL vmlinux 0x246c837a	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d3ece4	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f2d831	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24fc46b6	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x2528c385	register_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0x252d2d17	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x254d97f3	user_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x258a5ff2	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x25a3e78b	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x25ca1a6e	snd_soc_codec_writable_register
++EXPORT_SYMBOL_GPL vmlinux 0x25cf3644	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL vmlinux 0x25e4540f	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x25e4fa8c	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2603231f	ahci_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2612202d	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265b32a5	mtd_erase
++EXPORT_SYMBOL_GPL vmlinux 0x265ccbe5	tpm_show_caps_1_2
++EXPORT_SYMBOL_GPL vmlinux 0x266275e2	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x268fe926	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x268fec43	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x26adb815	thread_notify_head
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c6f0e6	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x2766de42	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x276bbf3c	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x27735399	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x27853e19	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278c6220	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x27902b87	dapm_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x27a1a469	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27d8123b	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x280acd71	snd_soc_register_codec
++EXPORT_SYMBOL_GPL vmlinux 0x280f5a27	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x2821a59f	sec_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x282ab391	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x2849924b	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x28689a8d	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x2869ebaf	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x28762fc1	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x288920ec	xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x28a7487f	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x28a82da4	snmp_mib_init
++EXPORT_SYMBOL_GPL vmlinux 0x28a903c8	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0x28de0820	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x28ed72b0	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x28fec97a	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x29047f1a	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x29123f43	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0x29571f23	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x295a9cb6	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x29895ba1	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x29bff6d5	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL vmlinux 0x29cc1bba	sdhci_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x2a0d6633	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0x2a2ef23b	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x2a350c3f	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x2a3e8030	snd_compress_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x2a4e14a6	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x2a504ad2	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x2a666e52	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a6f6305	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x2a80efca	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x2ab7c6b2	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x2ad1ece4	zs_get_total_size_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2ad289cd	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x2ad64625	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0x2ad9d326	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2b0d3a54	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x2b348ad7	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x2b373124	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x2b54da0c	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b5f4d1a	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x2b724a7f	omap_dm_timer_get_fclk
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a6de8	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2b865cb5	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2b90ad28	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x2b9c34d9	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x2ba0c0fe	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x2babe81f	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x2bdf2bcd	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2c06b69b	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x2c0be75e	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c2322b3	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x2c3ffe31	xen_unmap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x2c4c59cb	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c810b66	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x2c836306	dapm_clock_event
++EXPORT_SYMBOL_GPL vmlinux 0x2c998402	snd_soc_write
++EXPORT_SYMBOL_GPL vmlinux 0x2ca4ebcd	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2cb73405	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x2ce70eef	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cfa7a30	snd_dmaengine_pcm_register
++EXPORT_SYMBOL_GPL vmlinux 0x2d172905	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x2d17a0e1	cgroup_taskset_size
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d28f36f	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x2d367fe4	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d639a25	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x2d79695e	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x2d7f55b3	wm8994_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2d8f3385	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x2da6f48e	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x2dbf1a8f	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL vmlinux 0x2dd12593	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2dda2206	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x2e278f88	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e454f4f	omap_dma_filter_fn
++EXPORT_SYMBOL_GPL vmlinux 0x2e45e488	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x2e724408	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x2e9670c0	pl320_ipc_transmit
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2edd78d5	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x2ee12f68	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0x2ee470ea	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0x2ef6b5bf	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f4fe3d6	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x2f7c64e0	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL vmlinux 0x2f874043	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x2fa3c201	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x2fabf024	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x2fd2e3c6	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x3006b6f5	of_pci_get_devfn
++EXPORT_SYMBOL_GPL vmlinux 0x3015ca6d	sdhci_add_host
++EXPORT_SYMBOL_GPL vmlinux 0x304b2a30	blk_rq_check_limits
++EXPORT_SYMBOL_GPL vmlinux 0x3053726d	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x30693bb7	imx_audmux_v1_configure_port
++EXPORT_SYMBOL_GPL vmlinux 0x306a942b	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x307e2926	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x308039b2	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x308b733a	getboottime
++EXPORT_SYMBOL_GPL vmlinux 0x30929d5e	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30dfe902	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0x30ecdfd0	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x3101f3f1	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x31335ad6	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x31392a09	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0x31587761	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x315e3419	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x31879ff3	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x3189bb44	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x31a820ed	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x31b1649a	sk_unattached_filter_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x31b9cb9d	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0x31be35d5	of_get_named_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31e89c51	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x3266607c	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x32973967	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x32974d71	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x329bbbde	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0x329d0f8d	tpm_read
++EXPORT_SYMBOL_GPL vmlinux 0x32a26e07	ftrace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x32b31a8c	ktime_get_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x32b34817	snd_dmaengine_pcm_close
++EXPORT_SYMBOL_GPL vmlinux 0x32b4a793	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32f16325	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x32fd447a	monotonic_to_bootbased
++EXPORT_SYMBOL_GPL vmlinux 0x3300c4c1	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x330d351e	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x331a16ae	snd_soc_default_writable_register
++EXPORT_SYMBOL_GPL vmlinux 0x3321885f	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x334ef3d7	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x3366c475	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x33883929	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33abca4e	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x33b3a97d	bgpio_init
++EXPORT_SYMBOL_GPL vmlinux 0x33c6fa70	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x33d2c5a6	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x33d76835	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x33e4f538	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x33e7a423	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x33fee6d4	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3402cb11	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x341643ba	omap_dm_timer_modify_idlect_mask
++EXPORT_SYMBOL_GPL vmlinux 0x343b4ada	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x3441c3d6	gpio_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x344d3f03	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL vmlinux 0x344db0ee	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x345ce2cc	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0x346c6209	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x3487ba26	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x34a884d8	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34cefa4a	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x3508d032	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x3511ea11	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x35614c42	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x357e12b9	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x3580ba93	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x359650d6	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x35a9cf6f	omap_control_usb_phy_power
++EXPORT_SYMBOL_GPL vmlinux 0x35b5afb5	ahci_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x35bbcbd4	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x35bdd540	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x35bf47e9	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x35f165f1	devm_reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x361ba899	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x36585128	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x365f0a07	pinctrl_pm_select_sleep_state
++EXPORT_SYMBOL_GPL vmlinux 0x366307db	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36a31979	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x36e372a3	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0x36e88e43	sec_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x36f15994	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x36fff2fa	snd_soc_cnew
++EXPORT_SYMBOL_GPL vmlinux 0x3700154c	pkey_hash_algo
++EXPORT_SYMBOL_GPL vmlinux 0x375e921c	mdio_mux_init
++EXPORT_SYMBOL_GPL vmlinux 0x377f2e8a	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x37984972	omap_mcpdm_configure_dn_offsets
++EXPORT_SYMBOL_GPL vmlinux 0x37aa380a	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x37aeda84	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x37c122ae	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x37f1e9d2	snd_soc_update_bits_locked
++EXPORT_SYMBOL_GPL vmlinux 0x37f4564e	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x38620e38	gnttab_grant_foreign_access_trans_ref
++EXPORT_SYMBOL_GPL vmlinux 0x387b3583	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x38a0b1fd	sec_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38abc000	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x38cd6211	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x38f6516f	ahci_reset_controller
++EXPORT_SYMBOL_GPL vmlinux 0x3905b22e	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x39174e23	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x396c4a96	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3970c835	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x397b9a07	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x39ce5aa5	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x39d9ae7d	snd_soc_codec_set_cache_io
++EXPORT_SYMBOL_GPL vmlinux 0x3a051de8	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x3a2055fd	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x3a260ef4	dma_buf_export_named
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2abdbf	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3a4c6000	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3ac4d6b8	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x3ac75973	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3acf7d80	aead_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x3ad82802	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0x3ad8dfdb	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x3ae1d0e5	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x3afa577e	ahci_print_info
++EXPORT_SYMBOL_GPL vmlinux 0x3b1209d5	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3b2551d7	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x3b4e8490	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x3b5a84dd	pci_renumber_slot
++EXPORT_SYMBOL_GPL vmlinux 0x3b5aa1ec	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3b76523a	nand_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x3ba15a81	device_schedule_callback_owner
++EXPORT_SYMBOL_GPL vmlinux 0x3bc7b6be	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3bc876b2	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x3be2e994	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x3bea7c38	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x3bf1648c	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x3c132691	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x3c14275b	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x3c15c5ec	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x3c1bf01b	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x3c3cdf99	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL vmlinux 0x3c631f42	platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x3c831441	arm_check_condition
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3c9fb117	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3ca17104	__snd_printk
++EXPORT_SYMBOL_GPL vmlinux 0x3cac21b9	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cda4279	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0x3cdcad09	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d3a3a33	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x3d4f52a0	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x3d638c77	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d87bd47	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x3db0cc98	amba_ahb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0x3db677fb	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3db91586	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dca1c07	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3e0a89d4	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x3e16fb4f	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x3e2aea29	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x3e2fa31f	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e452a00	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x3e66d1f3	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e8ae333	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x3e8de215	inet6_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x3ede668c	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL vmlinux 0x3ee03aec	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3eef41a8	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f0b6748	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f553508	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x3f5f9f9c	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x3f620a84	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3f69c73a	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3f6a02c7	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x3f7567ea	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x3f7a6aae	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x3f7ea9f8	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f9311bd	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3fba2b89	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x3fed777c	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3ff65f5e	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x402c88de	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x4031ad0f	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x403b8608	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x40892701	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x408a497c	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c3202b	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40f4bc4e	pinctrl_pm_select_idle_state
++EXPORT_SYMBOL_GPL vmlinux 0x40f7e3ea	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x40fc78f1	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x414261f2	__get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x416180a5	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x4181cc49	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x41db7ca0	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL vmlinux 0x41fa6487	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x4201a01d	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x420ff368	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x424e6efb	__inet_hash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x4255c960	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x425b1322	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42d01a5a	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x42f10bc1	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x430e5257	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x430ee275	ata_sas_port_async_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x432fd7f6	__gpio_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x433b1bef	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x433d5a3c	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x4349a396	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x43a1793f	xen_dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x43a5293d	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43cae469	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x43e59623	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x442e0796	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4436585e	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x44404f11	kdb_register_repeat
++EXPORT_SYMBOL_GPL vmlinux 0x444f1735	cpu_pm_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4455e1b3	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x446187bb	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x446e8e15	musb_dma_completion
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x448dc824	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x448ec5ce	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0x4494e530	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x44a793ab	HYPERVISOR_grant_table_op
++EXPORT_SYMBOL_GPL vmlinux 0x44ed2bf3	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x4504dc5d	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0x450665f7	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x4563c9ba	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x45708c5b	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x457b77ca	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x45897366	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x459585c0	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x45ba1367	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45f1e912	mtd_point
++EXPORT_SYMBOL_GPL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL_GPL vmlinux 0x46074c17	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x460ef264	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x460f7531	wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x461423af	inet_csk_reqsk_queue_prune
++EXPORT_SYMBOL_GPL vmlinux 0x461bedce	sdhci_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x461f55d7	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x463f5f4c	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x4643d49a	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x4672e88b	__crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x46740a67	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x467c6fbd	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x46f512a5	snd_kctl_jack_new
++EXPORT_SYMBOL_GPL vmlinux 0x46fcb374	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x474c1832	opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4769e6a2	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x476f77d7	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x477564e3	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4776dc52	sdhci_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x479e9671	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x47ad3e64	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x47c3cdac	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x47d693a3	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x47fe5166	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x47ff399f	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x48198dbe	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x482e91ac	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x483624ef	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x48377a61	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x485baf54	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x48ab5da7	pkey_algo
++EXPORT_SYMBOL_GPL vmlinux 0x48ca8947	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x490021c2	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x490a08c4	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x49348758	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x49365a62	default_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x4946da71	omap_iotlb_cr_to_e
++EXPORT_SYMBOL_GPL vmlinux 0x496dde9b	sk_unattached_filter_create
++EXPORT_SYMBOL_GPL vmlinux 0x496fa379	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x498d293a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x4992c765	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x49bae788	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x49dfb5c8	pinctrl_find_and_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x4a2d0250	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4a369e55	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x4a37c66a	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x4a47abce	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x4a60eb02	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0x4a7b7615	omap_dm_timer_request_specific
++EXPORT_SYMBOL_GPL vmlinux 0x4a813715	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x4a8bcc94	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0x4a96d164	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x4a9cb082	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x4aa63900	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4aab7e0b	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x4aad979e	pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ad7237a	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x4b024f97	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x4b17b645	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x4b20627f	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x4b45d975	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x4b725b13	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4bafcdd8	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x4bc62a81	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x4c3ccdac	extcon_find_cable_index
++EXPORT_SYMBOL_GPL vmlinux 0x4c44cd11	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x4c47ec15	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x4c543107	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c68fa22	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c82b8c4	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x4cc4e170	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x4cda0381	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x4cdd09f7	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x4ce8db8a	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4d1ca0c0	dm_kill_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0x4d248926	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x4d2bd6fe	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x4d2e522b	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4d32c6d1	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x4d60c5f8	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x4d73cc05	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4d9286a7	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x4daaea28	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x4db47a98	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x4dc9c192	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4df92723	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4dfffd31	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x4e01ba0d	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e1ec2f4	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2c5aad	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4e5f8bbf	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x4e7913a6	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x4e941fb4	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e99b1ca	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0x4edafff5	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f102d18	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x4f1d8b19	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x4f5006a4	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4f59db14	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4f603b1c	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x4f6172ff	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x4f6cb143	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4f8736a9	snd_soc_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x4f8c7c6b	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4f98d766	cpu_pm_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4f99838b	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x4f9dacbf	pinctrl_pm_select_default_state
++EXPORT_SYMBOL_GPL vmlinux 0x4fa09a3d	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4fa5cadd	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x4fb64845	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0x4fd4e89d	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x4fd91c46	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4ff4fc92	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x4ff71442	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x4ffb419e	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x500c89e4	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x50514735	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x5053e2a6	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x505ab52d	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x505d885c	tty_prepare_flip_string_flags
++EXPORT_SYMBOL_GPL vmlinux 0x50601122	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x506130da	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x506691f1	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x506cc085	tracepoint_iter_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5089644c	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x509e64c2	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50e491ab	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50eb1032	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0x50f7ce81	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x510e2b2c	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x51139aa5	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0x512cf16c	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x512e19cd	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x5134a46f	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x514729e5	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x51553f28	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x515e7ae8	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x5162f1a2	omap_control_usb3_phy_power
++EXPORT_SYMBOL_GPL vmlinux 0x51706a1d	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x519d4097	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x51be0893	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0x51e37365	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x51e6dabc	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x51f28692	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52120583	of_get_display_timings
++EXPORT_SYMBOL_GPL vmlinux 0x52212010	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x5291b985	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x52c61690	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x52ccf3aa	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0x52e93ace	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x5318b77c	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x532242e2	mtd_device_parse_register
++EXPORT_SYMBOL_GPL vmlinux 0x53386bbb	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL vmlinux 0x5349ddd1	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x538aaabe	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x538acc74	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x539833fa	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x53a3e486	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x53ab1104	sdhci_get_of_property
++EXPORT_SYMBOL_GPL vmlinux 0x53deab2f	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x540bcab7	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x543b0daa	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x544aab61	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5460f155	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54a5a157	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x54cbaf8e	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x54d010d7	twl6040_get_hs_step_size
++EXPORT_SYMBOL_GPL vmlinux 0x54d3158c	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL vmlinux 0x54f9944e	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x54f9a668	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x54fda785	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x550b5ac7	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x552a6cee	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x552e3952	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55937735	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0x55a5245b	cgroup_taskset_cur_cgroup
++EXPORT_SYMBOL_GPL vmlinux 0x55bdfe93	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL vmlinux 0x55c6df9c	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x55cd9612	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x55cdd58c	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x55efc115	skb_gro_receive
++EXPORT_SYMBOL_GPL vmlinux 0x55f04c21	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x56017b56	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x561e4b77	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x562921d8	tcp_reno_min_cwnd
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564f1dca	klist_add_after
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x567290b1	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x568fe1ac	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x569cc913	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x56a069fe	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x56a3c9a0	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56c118a1	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x56c1a638	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x56d1924d	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56db5e1c	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x56dc5a15	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e9103b	cpu_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x56ee480a	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57382a68	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57f144ff	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x5811d695	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x5819c8aa	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0x581c77b0	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x582be91b	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x5835fda1	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x58413099	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x5846504b	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0x584b15e5	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x584e917b	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x58631dab	imx_audmux_v2_configure_port
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58bc259b	pinctrl_remove_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0x58d7c952	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x58e14f15	HYPERVISOR_event_channel_op
++EXPORT_SYMBOL_GPL vmlinux 0x590e0c63	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x591e8aa3	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5927a793	bdi_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x592bb5a0	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x5947abbe	max77693_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x59497f93	__scsi_get_command
++EXPORT_SYMBOL_GPL vmlinux 0x595c37e9	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x599d0cb6	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0x59a7cdc5	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x59badfba	devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x59d0eaf4	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x59de4107	put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x59e2743e	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a18c774	tpm_show_durations
++EXPORT_SYMBOL_GPL vmlinux 0x5a225a7e	mtd_is_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a3892bb	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x5a3c2afd	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x5a446332	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x5a47437d	xenbus_dev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x5a48534a	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x5a4fe414	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL vmlinux 0x5a7474d2	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5acf6567	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5af1a284	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x5afb47fc	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x5b1cfbcd	of_get_fb_videomode
++EXPORT_SYMBOL_GPL vmlinux 0x5b2ce35c	mtd_table_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x5b3093ac	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL vmlinux 0x5b3fdb98	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0x5b4e379c	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x5b8090f7	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x5b927257	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x5b949baf	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x5ba4b791	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x5bc0f667	dm_underlying_device_busy
++EXPORT_SYMBOL_GPL vmlinux 0x5bd165ed	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x5be36630	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x5bf2ea5d	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x5bff2985	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x5c1dc81d	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x5c29bcce	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x5c2bc140	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x5c3729d2	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x5c924222	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x5c9ab448	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0x5ca47b3e	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5ccc2845	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x5cfabdb2	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5d0e1d0b	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5d1098c6	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d1c1bac	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d25b8b3	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d3abf82	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x5d4bf171	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x5d8ef510	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0x5da27a45	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x5dc15311	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0x5dd18380	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5dd8928a	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x5df58ca2	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x5dfedcca	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x5e05a33d	dm_requeue_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0x5e19ecd7	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x5e38022b	amba_apb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0x5e4ec9ab	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5e81fd33	pinctrl_dev_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x5e8471a8	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0x5ea42541	unregister_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x5eacba1f	ahci_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x5eb3ee4d	sec_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x5f127cff	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x5f248f72	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0x5f443a53	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x5f4ac581	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x5f6ab9c7	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x5f8158de	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x5f9291ea	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x5fe41a2a	vchan_tx_submit
++EXPORT_SYMBOL_GPL vmlinux 0x600b0939	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x600d0df8	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x600e551c	omap_dm_timer_set_prescaler
++EXPORT_SYMBOL_GPL vmlinux 0x601010c3	devm_pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0x6010688e	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x60247879	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x604c9bfb	bgpio_remove
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x606abce2	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x6075d0c7	omap_tll_init
++EXPORT_SYMBOL_GPL vmlinux 0x6091175d	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x609780be	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x609d333d	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60cf4c4a	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x60d8511c	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6114d8a4	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x61343ebe	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x6137b72b	tegra_usb_phy_preresume
++EXPORT_SYMBOL_GPL vmlinux 0x615f1cd8	bmp085_probe
++EXPORT_SYMBOL_GPL vmlinux 0x6162fdc8	omap_dm_timer_request_by_cap
++EXPORT_SYMBOL_GPL vmlinux 0x61c0448f	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x61c98f85	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x6211cc9f	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x621ed252	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x622b0b6b	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622dacba	tick_nohz_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x6248b5be	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x624a6406	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x6253c300	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0x627566d3	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x627e61a9	omap_install_iommu_arch
++EXPORT_SYMBOL_GPL vmlinux 0x62969aed	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0x629e7ce5	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x62a222a8	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x62b9ab37	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL vmlinux 0x62beabb4	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x62f8b386	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x630a8479	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x63205de1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x632a3663	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x632a57e8	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x634e9b91	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x636a4a87	amba_apb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x6371d584	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x6390efda	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x63b1e7a7	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x63e27718	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL vmlinux 0x63f48085	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x63f8590a	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6400a4ee	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x6411bfbe	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x641236d1	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x6418113b	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x641991a6	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x64283095	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x644e2f98	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x646ce2f0	of_get_display_timing
++EXPORT_SYMBOL_GPL vmlinux 0x647537f3	pl320_ipc_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6488b70f	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x6496893c	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x64a69552	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x64a99f2e	snd_soc_dapm_get_enum_virt
++EXPORT_SYMBOL_GPL vmlinux 0x64ffc708	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x651a427a	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x652263fb	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x654f544d	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x6558b811	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x6560f213	mtd_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6587cdd0	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x659d2f95	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x65a8bb50	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x65b3e83c	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d6d0f0	gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x65db354f	bmp085_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x660c7fc8	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6639c8a9	tpm_show_caps
++EXPORT_SYMBOL_GPL vmlinux 0x663c16d6	gnttab_grant_foreign_access_subpage_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6678c138	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x6682cfc8	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66b38c37	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66d888ea	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0x66e11ade	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x66e9e970	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x66f7f60d	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x67128609	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x672373d5	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x67246a2a	snd_soc_info_enum_ext
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x67489fc8	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x675924df	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x67643d26	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x67673496	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x676ed4b8	ahci_check_ready
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x67a122e6	mtd_block_isbad
++EXPORT_SYMBOL_GPL vmlinux 0x67be4f47	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0x67caf096	wm8994_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x67e986cf	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x67edebb0	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x67fa4f6f	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0x67fe72af	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x67fecd59	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x680a90ae	omap_dm_timer_set_load_start
++EXPORT_SYMBOL_GPL vmlinux 0x68118712	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6812cf8d	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x6859343e	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x687fa8e4	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x68aedddc	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x68f21450	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x691203ea	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x691a19a9	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x691a4345	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x693b1f23	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694be42a	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x694f923e	ahci_thread_fn
++EXPORT_SYMBOL_GPL vmlinux 0x696c5647	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x698be398	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x699e0164	input_class
++EXPORT_SYMBOL_GPL vmlinux 0x69cc0f10	sec_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x69e9a2cb	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x69fdfbe7	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a544f5f	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a5f92ac	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a7f158c	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a9fe2cd	class_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x6aa7ff87	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x6ab34e52	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x6ab77430	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x6ab922b2	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x6aba167a	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6ada9baf	xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0x6ae956fb	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6aece502	omap_uninstall_iommu_arch
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b2ef020	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x6b2f169e	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x6b8819bd	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6b94a42e	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x6bae4caa	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0x6bb47950	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x6bc767d6	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x6c185883	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x6c195a4f	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x6c301390	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x6c49c4f2	clockevents_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c5928a6	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0x6c5b0c14	aead_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x6c5b3467	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6c749afe	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x6c7d31f3	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d5ae8	__gpio_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x6c96ab29	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x6ca48035	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6cb1320d	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x6cc78c5c	set_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x6cc8713d	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x6cc9014d	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x6cdc7f55	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x6d00e338	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d31e93b	tracepoint_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x6d3238b6	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x6d323c07	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x6d73b191	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x6d74f842	spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6db82785	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6dfae0b5	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e05c4e7	ahci_hw_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6e183c0b	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x6e3ae363	snd_soc_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e61ad17	snd_dmaengine_pcm_pointer
++EXPORT_SYMBOL_GPL vmlinux 0x6e74834b	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6e8ea089	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x6ec135bb	pinctrl_find_gpio_range_from_pin
++EXPORT_SYMBOL_GPL vmlinux 0x6ec8de35	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6ef9e395	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6f06ce09	vchan_find_desc
++EXPORT_SYMBOL_GPL vmlinux 0x6f0df624	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ded04	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f25977c	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x6f2d285c	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x6f2e6060	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x6f51b8ef	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0x6f587483	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x6f8d181b	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x6fc4d626	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x6fc8bc85	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x6fd70c1d	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x6fd9446f	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6feeb626	inet_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x701e0c61	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x703189d7	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x705e13b4	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x706b0533	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0x7072f713	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x707f57d9	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70916ace	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x709cef8e	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x70b44a03	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x70b7a54f	css_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x70bb651d	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d85f89	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x70ee9dcf	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x70f3113c	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x71008581	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x710d8d03	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x71930ed3	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x719cfea4	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x71a27198	xen_remap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x71d6c308	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x71dad235	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x72593c88	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x7267db00	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x726f9f67	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x727bfec8	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x7291019b	__cci_control_port_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x72a130b5	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x72b212ff	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x72ced114	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x73056d81	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x730bd0c7	asic3_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x7325695d	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x7327bcc9	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x73692023	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73c6a2ef	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x73cbecd3	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x73ce588f	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73f50e1b	register_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x741fdfa3	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL vmlinux 0x7437ff12	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x744b2cd6	irq_find_host
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7469efa5	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x7472d966	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x7483eba4	ahci_kick_engine
++EXPORT_SYMBOL_GPL vmlinux 0x74954462	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74f7f932	usbmisc_get_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x750999be	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x75215f74	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x7536036d	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x753d2638	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x756bbfae	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x757b9604	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75c8a11c	inet_twdr_twkill_work
++EXPORT_SYMBOL_GPL vmlinux 0x7600bfb4	pinctrl_select_state
++EXPORT_SYMBOL_GPL vmlinux 0x760afa04	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0x761e0aca	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x767f4c50	omap_dm_timer_set_source
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x76997388	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x76b54a07	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x76b563a6	sysfs_get
++EXPORT_SYMBOL_GPL vmlinux 0x76cef8f2	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0x76ec6485	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x77214cea	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x77327e0f	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x7769eb13	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x77af47fc	snd_soc_codec_volatile_register
++EXPORT_SYMBOL_GPL vmlinux 0x77bf8a52	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x77d08524	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x77e2be63	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x77e78218	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x77f4c4af	pinctrl_dev_get_devname
++EXPORT_SYMBOL_GPL vmlinux 0x77fcdfb4	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x7803559a	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x7839af0a	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x783fea3f	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0x7840b42c	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x78410782	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x78585fb0	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0x785dd0b1	event_storage_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x785f9ab7	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x787c1cf2	nand_update_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x78859f72	tpm_show_pcrs
++EXPORT_SYMBOL_GPL vmlinux 0x78a5d9ed	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x78cf4589	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x78e5655f	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0x790e990a	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0x792a9f83	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x7944bd7b	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x794578be	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x798173e1	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x79968c15	regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x79b7d8d8	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x79ba264a	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x79c2b855	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x79ca9e25	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x79e6968d	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x79eeffda	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x7a2254c9	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7a330669	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7a3b1b60	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x7a5541fa	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x7a5cf681	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7a6e847e	css_id
++EXPORT_SYMBOL_GPL vmlinux 0x7a933c98	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ac57cfa	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7acb48c0	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x7aee42ad	mtd_read_oob
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b204780	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x7b2163bd	HYPERVISOR_tmem_op
++EXPORT_SYMBOL_GPL vmlinux 0x7b4038ad	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x7b4ea526	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x7b6e0952	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x7b7e12f3	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7b89df37	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7ba99a7a	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7bb494e8	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0x7bf3b5c3	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x7c0ca98d	regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x7c6a49ce	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c79cbb9	pci_msi_off
++EXPORT_SYMBOL_GPL vmlinux 0x7c7e4751	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x7c9ad2eb	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x7ca7446b	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x7cadd9e1	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7cc1b7fd	max77693_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x7cc3a46c	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7cccb1b3	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7cd88e68	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x7ce3c07f	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7d444e55	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7d5383b1	snd_soc_resume
++EXPORT_SYMBOL_GPL vmlinux 0x7d559c2d	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d8f4864	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7e2ca8d6	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x7e2f4717	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL vmlinux 0x7e4ecd10	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0x7e5f9208	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e786aed	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7e7f8820	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x7e8a5394	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x7e8f8848	__ip_route_output_key
++EXPORT_SYMBOL_GPL vmlinux 0x7eb0c030	tegra_ehci_phy_restore_start
++EXPORT_SYMBOL_GPL vmlinux 0x7eb7b3f8	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0x7eca3bac	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x7ed68941	asic3_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x7ef4c66e	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x7f08dbf6	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x7f0f20c8	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x7f24e2a9	omap_dm_timer_request_by_node
++EXPORT_SYMBOL_GPL vmlinux 0x7f2f053b	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x7f3dd4e0	register_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0x7f4bd2cb	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x7f60e837	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x7f81117a	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x7f86c172	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x7f99b5d8	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x7fa1a670	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x7fa26685	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7fab5350	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7fb21c4d	platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0x7fe9f667	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7ff2e154	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x7ffb4304	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x7ffc8718	gpio_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x8002753a	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x800808d5	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8013e76b	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x80231a03	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x80266f3e	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x8043eb8c	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x80482765	sysfs_get_dirent
++EXPORT_SYMBOL_GPL vmlinux 0x806c7aaf	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x807628cd	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x807a5c0a	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80904814	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x80a65392	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x80a8f85b	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x80b616c7	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x80c81a88	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80dd831a	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x80eade72	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x81070d7d	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x8117184c	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x8119198c	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x81534c66	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8177296f	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x81941eeb	tpm_show_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x81af93d1	pinctrl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x81b88d1c	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0x81c22eba	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x81c9ea70	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x81f9f445	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x8209c0cc	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x820b2b80	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x820d8548	omap_dm_timer_read_counter
++EXPORT_SYMBOL_GPL vmlinux 0x8226642f	__gpio_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x823699ed	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x8257225c	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x82939ebd	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x82bcb070	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0x82c2e31e	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82eaad8e	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x82ee6a8e	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x82fec260	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x8315d422	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x83286841	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x832f4587	crypto_nivaead_type
++EXPORT_SYMBOL_GPL vmlinux 0x83305bff	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x83332dc2	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x83341063	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x83593448	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0x837c7f6e	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83a5ae2e	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x83b16ac2	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x83b360df	tpm_show_temp_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0x83c7d7c5	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x83d108cc	tegra_pinctrl_probe
++EXPORT_SYMBOL_GPL vmlinux 0x83df4f20	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x83ff39dd	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x84106e42	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8410efae	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x8428c081	snd_soc_read
++EXPORT_SYMBOL_GPL vmlinux 0x843433d8	xen_dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0x84502ab2	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x8468747e	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x846beeba	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x84c0c054	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x84cdb78d	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x84e2704e	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x8521e752	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x852e568d	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x852e783a	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x852f3e32	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x85478a0b	inet6_hash_frag
++EXPORT_SYMBOL_GPL vmlinux 0x85608a60	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x856629e7	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x85903e06	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x85b0cc98	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x85c10896	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x8609c5c1	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x861359ed	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x862b9816	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x869b039a	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86b2eb68	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x86e9a182	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86fdc413	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x86ffbf0b	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x870498f3	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x870e34d3	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x8727ebac	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x8748d7ea	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x874c2a9b	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8769de55	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x87850fc6	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x878b9861	mtd_write
++EXPORT_SYMBOL_GPL vmlinux 0x87984b16	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x87b3696e	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x87ba8758	__cci_control_port_by_device
++EXPORT_SYMBOL_GPL vmlinux 0x87bb4e32	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x87cdb39b	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x87f38bf3	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8817255c	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x88477747	twl6040_get_trim_value
++EXPORT_SYMBOL_GPL vmlinux 0x8879a557	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x88a45a32	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88ac566c	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88c257ac	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0x88d6dff1	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x88eeb0c4	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x89003849	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x890e5711	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x89106c10	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x8927b1e8	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0x89321306	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89502f0c	gnttab_subpage_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0x8996feca	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x89988057	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89c1a840	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x89c401a9	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x89e07797	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0x89e839cd	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x8a04b9fe	tracepoint_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8a087a7e	snd_dmaengine_pcm_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x8a22c02a	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x8a45fa79	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x8a5c7a80	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8a5d8ba7	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a816875	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x8a8b90f1	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL vmlinux 0x8ab72781	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ac5bdaa	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x8ad0403d	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL vmlinux 0x8ad21f0f	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x8ae152b5	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b3cfb08	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x8b5b2bad	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x8b66d6a5	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x8b66f9e0	xen_platform_pci_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x8b73cf2d	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x8b752ac1	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x8b775d3a	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8b86852f	tegra_usb_phy_postresume
++EXPORT_SYMBOL_GPL vmlinux 0x8ba5afe9	HYPERVISOR_memory_op
++EXPORT_SYMBOL_GPL vmlinux 0x8bba5d91	ahci_save_initial_config
++EXPORT_SYMBOL_GPL vmlinux 0x8bbff712	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8bc44fc4	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x8be024ba	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0x8be41789	mount_mtd
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c488ae8	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8c4a7d95	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x8c5664d8	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x8cc9fd61	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x8cd43c07	snd_soc_codec_readable_register
++EXPORT_SYMBOL_GPL vmlinux 0x8d032b77	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8d079c3d	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x8d111a47	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x8d12dd36	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x8d195ae6	cgroup_rightmost_descendant
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d272cab	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL vmlinux 0x8d615f1c	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d63ea94	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8d6ca298	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x8d8c7011	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x8da11d63	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8db7b3fa	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf7aaa	privcmd_call
++EXPORT_SYMBOL_GPL vmlinux 0x8dc8e433	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8dde3020	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x8df6fc97	omap_mcbsp_st_add_controls
++EXPORT_SYMBOL_GPL vmlinux 0x8e1e5349	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x8e2b25c2	videomode_from_timings
++EXPORT_SYMBOL_GPL vmlinux 0x8e3a2f8c	inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0x8e5e2040	wm8994_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x8e71f787	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x8e7894bd	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8e96b623	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x8ea1f635	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x8eb1f650	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x8eca25d7	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8ee5a1b5	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8ee7914c	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8eedb3c8	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x8eff6f28	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x8effebd3	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x8f01625e	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x8f2111d8	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8f2fd100	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x8f5525fc	opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8fd134a5	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8feb6b9b	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x9036c728	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x90574050	cci_ace_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x906d46c1	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x90705b7f	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x90737873	get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0x9082d068	kprobe_decode_arm_table
++EXPORT_SYMBOL_GPL vmlinux 0x9099b708	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90ae2b52	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x90b763f1	HYPERVISOR_console_io
++EXPORT_SYMBOL_GPL vmlinux 0x90c01bfa	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x90cb40f5	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x90decc84	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0x90e66d47	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x90e9daa3	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x913ff86b	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x914ec6a1	mtd_add_partition
++EXPORT_SYMBOL_GPL vmlinux 0x915f3cd7	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x9190c9ff	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9195c392	get_mtd_device_nm
++EXPORT_SYMBOL_GPL vmlinux 0x919ee9a0	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x91dda801	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0x91fa94c9	sysfs_schedule_callback
++EXPORT_SYMBOL_GPL vmlinux 0x9203f98b	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0x920aacca	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x922073ce	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x9224f3d8	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x9264b702	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x928ea532	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92d31cfb	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x930a6701	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x930b0350	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x930ed9b9	of_usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x931750b0	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x931f45be	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x93205f6e	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x93429e30	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x936909e5	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x939534ad	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x93af0ba3	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x93c43bba	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x93d2422d	snmp_mib_free
++EXPORT_SYMBOL_GPL vmlinux 0x93d26ce7	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x93fca903	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x94024853	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x940a1a30	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x9413ab84	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0x9419706d	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL vmlinux 0x946ad253	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x946d581f	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x948baaf7	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x94a68723	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x94a6ae12	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94b81b88	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x94c0e0c0	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x94c785d5	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x94e1823c	hrtimer_start
++EXPORT_SYMBOL_GPL vmlinux 0x94fc76c0	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x9521600d	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x9529f022	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956a91ba	gpio_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x9572918d	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x957408a3	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x95762345	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x957e6976	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x959726ac	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL vmlinux 0x95b3419b	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95c578a0	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x95f61804	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x95f6ee15	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x96342bbd	usb_gadget_map_request
++EXPORT_SYMBOL_GPL vmlinux 0x9635c1b6	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x9643cd49	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9677c716	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x96887995	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x968bc592	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x968decc8	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9696048f	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x96a22790	vmcore_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x96bf1572	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x96bf2552	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x96d88ab5	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9700e6bd	musb_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x971e0c7c	clockevents_unbind
++EXPORT_SYMBOL_GPL vmlinux 0x9745c52a	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x9759d938	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x97689337	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x97704c40	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x97822d7a	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x97a1f7d5	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x97a3ec56	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x97b452d3	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x97b71123	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97f1b938	usbmisc_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x98080942	kill_mtd_super
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98883d31	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x989136c1	snd_soc_default_readable_register
++EXPORT_SYMBOL_GPL vmlinux 0x98b20ba8	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x98c9f584	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x98cc564a	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x98dd33c8	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x98e67754	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x990a0355	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x991484c4	of_property_count_strings
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x992e2d00	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x996b22b8	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x9983efe7	omap_dm_timer_set_int_disable
++EXPORT_SYMBOL_GPL vmlinux 0x99b1cb8b	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a1f05de	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x9a2889ca	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x9a419a40	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x9a48b27a	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL vmlinux 0x9a4d71bb	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9a7cea06	snd_soc_dapm_put_enum_virt
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9aa95c4f	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x9ab22255	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9aca444b	get_monotonic_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b308ec9	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9b3512fe	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x9b541ec5	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9b5ec0c4	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x9ba28bf4	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x9ba341b8	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x9be3ff53	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x9be49b29	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c10977d	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e0ce6	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9c4ec9d1	register_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0x9c6dae1b	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x9c7dce72	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x9c86ede0	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x9c8e00d1	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x9c9d3c82	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x9caebf91	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x9cb0abf6	tpm_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cd42c3e	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9cf0aa0d	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0x9cf32b66	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x9cf69dac	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d0dbc0e	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d2a9002	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d598a11	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0x9d6017df	pci_pri_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d99150e	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x9dcab565	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e776496	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0x9e863ce4	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x9ea556f8	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9ebbc24c	amba_ahb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x9ec3a6b1	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ed5b0af	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x9f0664bf	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0x9f258b63	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x9f3f98e1	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x9f4b548c	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9f517986	HYPERVISOR_hvm_op
++EXPORT_SYMBOL_GPL vmlinux 0x9f829d48	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x9fa8594d	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fd74f67	cgroup_load_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ff4929b	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xa006454d	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0xa064f393	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xa09caf0b	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0xa0b4915b	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa0c80c45	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa0d54d73	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa0d69b43	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0xa0d97704	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xa0db5b3f	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0xa0f103b6	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa1247e74	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xa1653ab7	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xa178737f	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0xa186e83f	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0xa190c368	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xa1b8ab18	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0xa1bd7822	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa1d462c1	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0xa1f0c76f	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xa1f97aad	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xa20a30ad	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xa21e3b2d	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xa23d4e6c	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa284c225	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL vmlinux 0xa2932476	pinctrl_force_default
++EXPORT_SYMBOL_GPL vmlinux 0xa2a969de	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa2cf2045	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xa2dba1ca	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xa2dee7f6	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0xa2e76288	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xa2e935ad	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0xa308caec	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xa32a65d5	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa342ac2c	devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3a98f68	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa3bdb61d	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xa3c395a5	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xa3d190dd	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa420ef51	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0xa425b180	tpm_show_active
++EXPORT_SYMBOL_GPL vmlinux 0xa43cf2a5	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa467ce14	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa49714f9	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xa4999d6c	mtd_del_partition
++EXPORT_SYMBOL_GPL vmlinux 0xa4ea04ee	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0xa52eb82d	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa566215a	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa5950162	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xa59e424b	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0xa5ace281	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xa5bb09ed	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xa5c33af5	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL vmlinux 0xa5cfdc25	soc_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa5d0d9ac	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa61b1477	tracepoint_iter_start
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa63485af	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xa63f6cc2	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xa665b9a9	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0xa69b13bf	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0xa6a0a273	max77693_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa6a609f3	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6b684ed	crypto_aead_type
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6f884ce	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0xa7014aaf	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xa724257f	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa7246b2c	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xa738d56b	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xa73e7e1c	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xa75312bc	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0xa784509d	free_css_id
++EXPORT_SYMBOL_GPL vmlinux 0xa786398e	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xa789bdd1	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xa7bb7b74	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0xa7dc6d76	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xa7e20df3	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7eb4e26	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL vmlinux 0xa7f92105	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0xa81a1f51	inet6_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xa833d633	snd_soc_platform_read
++EXPORT_SYMBOL_GPL vmlinux 0xa8406b02	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa87ccbe0	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0xa8852615	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xa8cd1698	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xa8da94a1	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa8e98132	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xa8f59416	gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xa928b496	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0xa9695c55	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xa991f3b1	sdhci_disable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xa99fb071	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa9a82042	gnttab_trans_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0xa9ac50b5	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa9b7df25	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e5e4ae	snd_soc_bulk_write_raw
++EXPORT_SYMBOL_GPL vmlinux 0xa9fc3f54	gnttab_grant_foreign_access_trans
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa2ab215	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0xaa2ecd32	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0xaa44acff	omap_tll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xaa516096	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xaa5bf88b	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xaa5e7501	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0xaa616924	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xaa843dd1	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaab45034	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab18e6bd	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0xab4a40c1	omap_dm_timer_stop
++EXPORT_SYMBOL_GPL vmlinux 0xab593d75	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab88fe34	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xab8ceced	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0xab9b5fc6	tpm_release
++EXPORT_SYMBOL_GPL vmlinux 0xabe051b4	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0xabe91afd	tegra_ehci_phy_restore_end
++EXPORT_SYMBOL_GPL vmlinux 0xac0d156f	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xac1b1ef4	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL vmlinux 0xac21ffb3	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xaca6ab6e	omap_dm_timer_write_counter
++EXPORT_SYMBOL_GPL vmlinux 0xacbd7d60	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL vmlinux 0xacbf2c3a	snd_soc_info_volsw_ext
++EXPORT_SYMBOL_GPL vmlinux 0xacc6337f	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace70c55	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xad19c687	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xad2ab7a0	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0xad33c8a7	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xad41e4d0	fuse_conn_kill
++EXPORT_SYMBOL_GPL vmlinux 0xad4d61bd	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xad5a6715	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xad62d12b	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL vmlinux 0xad7700f5	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0xad851934	blkg_lookup_create
++EXPORT_SYMBOL_GPL vmlinux 0xad8bc023	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0xada38534	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd178fc	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae0f6b4e	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xae143bac	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xae34d7da	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xae3641b3	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0xae390fd6	sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xae3951e7	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xae51a1f0	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6ddb7d	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xae73d452	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae928fda	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xaebdf584	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0xaeddfccc	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xaeecf09b	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0xaf02291f	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xaf0e3d85	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0xaf1f46fc	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xaf348da7	cpu_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaf3feee5	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xaf473d56	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0xaf5d5b81	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xaf8c005f	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL vmlinux 0xaf8d37c5	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0xafb44a57	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xafd4fd14	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0xafded7ef	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xb015fa75	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xb0263ae3	snd_compress_register
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb079f52f	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xb0a1314d	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0ce6068	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xb0e7f678	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0xb10d55bc	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb149b4df	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb193b50c	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xb1995540	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c4a88e	omap_dm_timer_free
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb220f7eb	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb232a2bd	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb2cb4d90	blkdev_aio_write
++EXPORT_SYMBOL_GPL vmlinux 0xb2d46f08	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb3018d3a	snd_dmaengine_pcm_set_config_from_dai_data
++EXPORT_SYMBOL_GPL vmlinux 0xb33598a0	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb350f190	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb369e6ef	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xb3bee4a9	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0xb3d0713f	crypto_lookup_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb43fd35b	pinctrl_get
++EXPORT_SYMBOL_GPL vmlinux 0xb459887a	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0xb47e5170	omap_dm_timer_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb49ca52c	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xb49ed85e	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4cf0322	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb4d5c4ab	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4e5fc05	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xb4e85c2b	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb4f703c7	pci_sriov_migration
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb52af5fe	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0xb5339313	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb5405d6e	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xb54460c7	ahci_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb5484b76	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb549a413	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xb55c0ce9	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb58e4664	__clocksource_updatefreq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xb5a049ab	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5cb8145	hrtimer_get_res
++EXPORT_SYMBOL_GPL vmlinux 0xb5d8e605	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb624b43f	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb64e1c1d	tcp_is_cwnd_limited
++EXPORT_SYMBOL_GPL vmlinux 0xb669f507	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb67b2219	cm_suspend_again
++EXPORT_SYMBOL_GPL vmlinux 0xb67c64fd	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb68cf3d4	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6c635af	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb6c718ed	omap_dm_timer_write_status
++EXPORT_SYMBOL_GPL vmlinux 0xb6d026f7	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb70f8bae	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xb72c6118	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0xb734f5a0	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xb73e9366	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0xb740108d	dapm_reg_event
++EXPORT_SYMBOL_GPL vmlinux 0xb75d000b	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0xb76c43f4	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xb771631e	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb78a0fbd	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xb790fd6e	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xb7d05bf8	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb7f46ff5	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77c50	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xb82566eb	omap_tll_enable
++EXPORT_SYMBOL_GPL vmlinux 0xb8315b1c	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xb83549d5	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0xb8369ebd	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xb83ab0da	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xb84df0e3	cgroup_next_descendant_pre
++EXPORT_SYMBOL_GPL vmlinux 0xb85a8206	snd_soc_default_volatile_register
++EXPORT_SYMBOL_GPL vmlinux 0xb85bb390	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0xb85bf5af	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb8694ef2	imx_pcm_dma_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb86a8159	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb8864f8b	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xb89e891d	tcp_init_congestion_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb8debe18	devm_kzalloc
++EXPORT_SYMBOL_GPL vmlinux 0xb8e8fb3f	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xb8f53436	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xb905ea11	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb935ef81	snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0xb9595c6d	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb95a05da	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b5fb21	devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9cf63d6	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9d6b1ca	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xb9da2997	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0xba11bd37	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xba1950a8	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0xba2e6866	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL vmlinux 0xba3784d1	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xba41b153	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xba457d62	pinctrl_register
++EXPORT_SYMBOL_GPL vmlinux 0xba4ad11c	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xba714e04	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0xba80838c	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL vmlinux 0xbab20442	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xbac819ca	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xbad5880b	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0d0576	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ecc05	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xbb11cfba	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbb12c06b	omap_dm_timer_start
++EXPORT_SYMBOL_GPL vmlinux 0xbb19b638	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0xbb2ba5b6	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xbbb35fcd	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xbbccb3cf	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xbbcdbb53	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xbbf32fb0	sysfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xbc00bb3f	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xbc0bf7c0	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xbc15a1c0	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xbc41a635	netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xbc51333f	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc624c48	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcaf3971	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xbcb4cb68	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xbcbaa80a	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcf89ab6	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbd050b6b	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0xbd18bd3e	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0xbd3c2f1c	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL vmlinux 0xbd4c7d8b	pci_ioremap_io
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbdc288b4	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL vmlinux 0xbe14b5bc	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe224d1c	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xbe3a65df	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xbe672e84	split_page
++EXPORT_SYMBOL_GPL vmlinux 0xbe912ef9	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0xbe98086e	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbeae5776	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0xbebd5da6	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xbebdf621	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xbecd33bf	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xbefa591f	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xbf03522c	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xbf03d587	rtc_set_mmss
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf1d0256	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xbf37b920	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xbf630dc9	pinctrl_lookup_state
++EXPORT_SYMBOL_GPL vmlinux 0xbf63e9f0	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0xbf9b9449	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xbf9f1111	opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0xbf9fccdb	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfe3c99a	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc0042322	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xc014cbda	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0xc01fc4bb	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xc031b831	omap_dm_timer_set_pwm
++EXPORT_SYMBOL_GPL vmlinux 0xc04745c2	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xc0795c5d	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0912f1e	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0xc091612b	tpm_store_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xc0b78727	serial8250_tx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc0bf6ead	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f53083	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc10b2e80	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xc11b4470	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0xc11bd00f	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc126b385	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xc159e7c5	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18456bd	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc196dd74	opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0xc1a4362c	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xc1a8a7c5	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0xc1aa9983	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xc1df5ed5	nand_release
++EXPORT_SYMBOL_GPL vmlinux 0xc1fdce3b	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xc2037bf7	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0xc2056aa1	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0xc20aae1d	snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23ccd5b	sync_filesystem
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc26e266c	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2b0c3ef	omap_dm_timer_set_int_enable
++EXPORT_SYMBOL_GPL vmlinux 0xc2f61bf8	snd_soc_cache_read
++EXPORT_SYMBOL_GPL vmlinux 0xc311d449	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc32cec23	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34efe27	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0xc35a9470	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL_GPL vmlinux 0xc3a0b7b0	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0xc3b93bba	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xc4054f60	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xc41e0178	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc4315afe	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0xc443c92c	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc46325f4	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc488827a	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc537db4c	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc543a371	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xc5496a8d	snd_soc_platform_write
++EXPORT_SYMBOL_GPL vmlinux 0xc55176d1	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xc553442c	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xc57350b0	omap_dm_timer_read_status
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc58d976c	nfq_ct_nat_hook
++EXPORT_SYMBOL_GPL vmlinux 0xc5be4656	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0xc5d37180	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xc5f1b964	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0xc60f75ec	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc63c94aa	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc6464fd6	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0xc64ae20f	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xc654460a	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc663be3e	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xc6647ac3	snd_dmaengine_pcm_trigger
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa090	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0xc690866c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a9f932	omap_get_control_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc6b995cb	of_reset_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc72d733d	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc760786d	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xc769b61a	opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xc78bbc44	serial8250_rx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7bcfc0c	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xc7c2fbaf	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7d40085	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc7e2885c	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc813b1b7	cgroup_is_descendant
++EXPORT_SYMBOL_GPL vmlinux 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0xc827cef8	user_match
++EXPORT_SYMBOL_GPL vmlinux 0xc848da72	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc8588263	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc87acfe6	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc892f417	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xc8957ba6	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8da50b8	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xc8eb3e4f	otg_ulpi_create
++EXPORT_SYMBOL_GPL vmlinux 0xc8fc8959	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc900237d	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xc90eeabf	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc914ad30	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xc918e88e	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xc9291dc4	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc952d6a8	amba_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc97f70db	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0xc9c64943	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0xc9cb529f	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xc9cecdf3	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xc9cfa97f	of_pci_range_parser_init
++EXPORT_SYMBOL_GPL vmlinux 0xc9d86032	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xc9daa0b6	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc9e5c02e	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec9678	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0xc9fa7d64	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0xca13b43d	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xca1f881f	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xca3651c1	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0xca5ff768	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xca649136	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xca7d23c0	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xca83f60f	imx_pcm_dma_init
++EXPORT_SYMBOL_GPL vmlinux 0xca85d8cf	tracepoint_probe_update_all
++EXPORT_SYMBOL_GPL vmlinux 0xca89a299	mtd_erase_callback
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcad631b5	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xcadd8964	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0xcae9b669	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xcaed1937	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xcb0b5e8e	of_display_timings_exist
++EXPORT_SYMBOL_GPL vmlinux 0xcb13d7db	dm_dispatch_request
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb27d7db	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0xcb356577	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xcb428668	pci_pri_status
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb9ad7c2	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0xcbd6dfa6	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xcbdaea32	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc1f1c3d	inet_twdr_hangman
++EXPORT_SYMBOL_GPL vmlinux 0xcc25c8c9	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xcc378721	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0xcc504ef1	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xcc5838ba	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc8865f6	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xcc90ecd7	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xccb54178	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xccbfe1a2	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd89a30	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xcd008561	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0xcd2a4e2a	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcd330808	snd_hwparams_to_dma_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0xcd53eeab	ahci_start_engine
++EXPORT_SYMBOL_GPL vmlinux 0xcd55cfd3	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0xcd722bb5	mtd_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcd7d9530	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcda4a5d3	dapm_mark_io_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xcdc0594e	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd15087	of_irq_map_one
++EXPORT_SYMBOL_GPL vmlinux 0xcdea0601	find_module
++EXPORT_SYMBOL_GPL vmlinux 0xcdebaf5f	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0xce070132	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0xce0b2f01	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xce0b9b59	max77693_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xce200f48	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xce21b60e	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xce346aa5	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xce4427a5	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xce46e140	ktime_get_ts
++EXPORT_SYMBOL_GPL vmlinux 0xce596e6f	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce8e31ba	__clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xcea0bf88	snd_soc_put_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xced74a8f	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcee30e69	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0xcef113b0	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xcf0a7f44	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf7823f5	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c1b75	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xcf81c2a1	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xcf9089f2	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0xcf99b17c	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0xcfc60593	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfd84ef1	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0xcffaa8bc	opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0xd00d68c0	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd01bfc67	ahci_do_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xd026d518	HYPERVISOR_vcpu_op
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd04ade73	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd08a7967	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0e1a150	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd0e40169	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd0fcfaf6	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd13bf72f	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xd13e87b5	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xd14bc4d9	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xd14c5c47	mtd_is_partition
++EXPORT_SYMBOL_GPL vmlinux 0xd159900d	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1772d28	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd19f16f9	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xd1a2eb59	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0xd1b2db37	tracepoint_probe_register_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2416775	snd_soc_dapm_put_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd273b330	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xd27c6048	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xd28b29df	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xd28c0aca	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xd28cd9f6	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xd2901f3c	device_add
++EXPORT_SYMBOL_GPL vmlinux 0xd291e2af	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL vmlinux 0xd294ea88	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2acd591	sdhci_alloc_host
++EXPORT_SYMBOL_GPL vmlinux 0xd2af06db	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xd2c45ea4	of_pci_find_child_device
++EXPORT_SYMBOL_GPL vmlinux 0xd2f56c89	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0xd3119507	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xd325ec88	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0xd32d37e1	filter_current_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xd32dc38f	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0xd32fe193	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd3325e92	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xd332996a	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xd33ada8b	cci_probed
++EXPORT_SYMBOL_GPL vmlinux 0xd35356d9	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0xd37e13b4	regulator_set_optimum_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd391d302	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xd39e0999	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xd3b49dee	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0xd3c4b401	snd_soc_info_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0xd3f8386c	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xd3ffee99	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd408084b	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd42161de	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xd43839f5	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd43a27c6	snd_dmaengine_pcm_get_chan
++EXPORT_SYMBOL_GPL vmlinux 0xd4409f0c	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0xd444c95b	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44c2f38	cci_disable_port_by_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd45690a9	cgroup_next_sibling
++EXPORT_SYMBOL_GPL vmlinux 0xd4595b58	task_current_syscall
++EXPORT_SYMBOL_GPL vmlinux 0xd47a0fea	snd_soc_jack_new
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd53da4e3	omap_dm_timers_active
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd56902f4	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xd5a45213	cgroup_taskset_first
++EXPORT_SYMBOL_GPL vmlinux 0xd5ae17d8	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xd5b5d851	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5d7a0ae	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xd5dab7e4	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0xd5fe2865	snd_dmaengine_pcm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd616341c	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0xd62f3bae	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xd62f64b6	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd65ac65f	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd6991328	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd6b4a836	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0xd6b501d7	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0xd6c2e04b	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd7051ace	ahci_reset_em
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd70880c4	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xd71f092d	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xd72b3953	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd73be3ce	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd75c55e9	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0xd7682ec0	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd76e5629	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd788742d	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xd793f4be	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7dd1bf3	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xd7e57269	pinconf_generic_dump_config
++EXPORT_SYMBOL_GPL vmlinux 0xd7eba346	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0xd80f3fc9	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd81ffcd3	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd839efd2	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xd8525ea7	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xd85273ef	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xd85a6476	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xd85ac634	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xd861bb89	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xd863e510	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd8824087	tpm_show_owned
++EXPORT_SYMBOL_GPL vmlinux 0xd88a21c2	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xd898cd9c	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xd8af38e9	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd8bde545	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0xd8f33204	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0xd8fa2a4b	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xd90a182c	sysfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xd917ed59	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd91d9589	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94aa457	display_timings_release
++EXPORT_SYMBOL_GPL vmlinux 0xd9574e4e	dm_set_device_limits
++EXPORT_SYMBOL_GPL vmlinux 0xd9699e52	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd97b79d2	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xd9c541c8	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xd9d7f623	pkey_id_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9eaeefa	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda137858	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0xda1d3dc3	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xda3a7ca9	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xda44cb37	setup_charger_manager
++EXPORT_SYMBOL_GPL vmlinux 0xda5077fc	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xda8db65c	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0xda8f4a38	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xdabdd85c	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xdabf65d1	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xdac11bae	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xdacd26c5	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xdae715e0	videomode_from_timing
++EXPORT_SYMBOL_GPL vmlinux 0xdae8c9ee	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb04cacc	tracepoint_probe_unregister_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xdb0b98c3	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xdb160b84	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0xdb196d1a	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xdb68b14c	mtd_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb97c6e6	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xdb98d7c6	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0xdba4ad93	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xdba80fc1	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0xdbc70479	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0xdbd0718b	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0xdbdfafa6	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xdbf2adc9	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc016eda	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdc10d1dd	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc289d9b	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xdc395b57	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0xdc461430	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xdc542793	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc943c12	devres_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9a574d	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca28d7f	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xdcb83c11	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xdceacce2	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0xdcecc39f	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xdcedb2ce	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xdd11cb87	tpm_remove_hardware
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd3b407c	sysfs_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xdd4e9338	snd_dmaengine_pcm_pointer_no_residue
++EXPORT_SYMBOL_GPL vmlinux 0xdd7f5f4f	gpiochip_add_pin_range
++EXPORT_SYMBOL_GPL vmlinux 0xddb0e9c5	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0xddb3b08f	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xde09de4d	amba_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xde2c5a6e	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xde34bebf	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xde4e0ef6	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0xdea76698	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdeedb4cb	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf25e37a	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xdf4ba7ab	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL vmlinux 0xdf51985a	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0xdf6dceca	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL vmlinux 0xdf7c1bfc	pinctrl_force_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xdf8af570	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xdf965016	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL vmlinux 0xdf994623	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xdff40801	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xdff7c9ce	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe0010a60	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe006bf35	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe0201023	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xe022ebd2	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe03525ac	of_irq_map_raw
++EXPORT_SYMBOL_GPL vmlinux 0xe03c24ff	ahci_init_controller
++EXPORT_SYMBOL_GPL vmlinux 0xe054cb91	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xe068483f	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe07ca631	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe089c18c	vchan_init
++EXPORT_SYMBOL_GPL vmlinux 0xe0a6efee	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xe0b83542	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0xe0c4bbc6	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xe0c9fb6d	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe0d0e37b	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xe0d74694	tpm_dev_vendor_release
++EXPORT_SYMBOL_GPL vmlinux 0xe0e3147c	HYPERVISOR_sched_op
++EXPORT_SYMBOL_GPL vmlinux 0xe16591ab	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0xe16cba17	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xe176ccbb	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0xe184e01b	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xe18ad461	tpm_open
++EXPORT_SYMBOL_GPL vmlinux 0xe1a1ec9e	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xe1af5c07	sysfs_notify_dirent
++EXPORT_SYMBOL_GPL vmlinux 0xe1caefcb	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xe1d24956	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xe1f269f2	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0xe2213c71	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xe2488e66	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xe26962b6	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xe29fbc55	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xe2a85d23	d_materialise_unique
++EXPORT_SYMBOL_GPL vmlinux 0xe2b36286	tpm_register_hardware
++EXPORT_SYMBOL_GPL vmlinux 0xe2c64f1e	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xe2ce6927	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xe2dd67e5	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xe2e7840d	regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xe2f17212	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe3397a7d	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xe3707528	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xe3731733	pinctrl_dev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xe384a102	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0xe3b5bb1e	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xe3bcca54	cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xe3c5c734	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xe3ec7137	dapm_regulator_event
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe42e1f70	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe45f4751	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0xe4710f83	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xe4780a8b	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0xe4803c91	of_get_videomode
++EXPORT_SYMBOL_GPL vmlinux 0xe4857f26	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0xe48b7960	devm_pinctrl_put
++EXPORT_SYMBOL_GPL vmlinux 0xe4fef0c5	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe503c73b	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xe50e65bf	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5244e64	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL vmlinux 0xe5524eab	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0xe5529de7	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58b957f	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xe58e7acc	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5968701	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xe5a53cff	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xe5ac5550	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xe5c3b58e	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe5c4b900	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xe5eaa15d	pinctrl_add_gpio_ranges
++EXPORT_SYMBOL_GPL vmlinux 0xe60693b0	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xe6329cdd	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xe63fdf6a	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0xe64bccab	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe658902b	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xe68c33c3	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xe6987dea	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xe69afc54	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0xe6a425c7	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6dd04af	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe6e9dd53	sdhci_free_host
++EXPORT_SYMBOL_GPL vmlinux 0xe7136155	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0xe7321175	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xe738e704	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xe73d3292	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xe746018e	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe748a857	omap_iopgtable_store_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe7574f52	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe75bf548	pci_pri_stopped
++EXPORT_SYMBOL_GPL vmlinux 0xe75f46a5	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xe764488a	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xe768b975	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe78c7e72	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xe7baf604	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe7c92ac6	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0xe7df64e6	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0xe7f71950	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80e35a4	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe82b9904	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0xe82efd2b	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0xe8400441	of_property_read_string_index
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85a9fd3	cpu_cluster_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe86a6a77	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe8ea303f	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xe9014430	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0xe9297333	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xe9340c92	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe956a75c	pl320_ipc_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe96945dd	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe997a768	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0xe9c6a372	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xe9d289a8	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xea032bbe	twl6040_get_dl1_gain
++EXPORT_SYMBOL_GPL vmlinux 0xea0d1e03	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea324821	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea43355b	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL vmlinux 0xea518a48	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xea76eeb0	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xea90cdb3	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xeacdf45d	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xead9c3c0	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xeae1b368	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xeaf577ad	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xeb1c3628	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xeb3ef01d	arm_pm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL vmlinux 0xeb7f500a	pinctrl_add_gpio_range
++EXPORT_SYMBOL_GPL vmlinux 0xeb90f697	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xebb80bf8	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xec0dbf39	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xec121b4d	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec2ff70b	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xec60feb7	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0xec9b1f52	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xecaa3bee	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xecaeddf6	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xed06b916	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xed0e91f1	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0xed446cb8	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xed5a822c	tpm_show_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xed695a2d	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xed80ddfa	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xed8d6841	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0xeda63db3	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedd49930	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0xedecc519	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xee404398	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xee436c8f	cgroup_add_cftypes
++EXPORT_SYMBOL_GPL vmlinux 0xee4f3181	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xee55281f	deregister_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee7259a2	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0xee92bbf6	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xeeb8ecb3	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xeec5098b	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xeeeaa4ef	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0xef267bc1	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0xef2bdb19	xenbus_bind_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef4cd70e	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef6ee619	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0xef782b88	gnttab_grant_foreign_access_subpage
++EXPORT_SYMBOL_GPL vmlinux 0xef8dd296	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xef9c853a	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xefad9cf0	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0xefc91531	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xefdbc109	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xeff5ec2d	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xeffee949	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xf00d58f7	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xf019674a	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0xf0313ad6	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xf03733c8	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0xf04a83cd	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0xf0b35027	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xf0bf2a3a	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf0f030f0	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf0f72dee	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xf0ff40e6	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0xf129d601	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0xf140a5f3	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xf14bc919	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf155ef0f	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0xf17b071a	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xf184b9a8	snd_kctl_jack_report
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf18ffda2	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xf19adc86	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1c37c1a	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0xf1dfd3e6	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xf1ee1794	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xf215e75e	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf222f80f	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xf240f7e6	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0xf267add9	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xf277bc5a	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf27d8e1d	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xf28fae87	nfq_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xf2fc7f6e	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf2fedca8	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf318ed3f	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xf319ff7b	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf328a284	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf32e6b47	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf3489322	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf34d3402	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xf362e24e	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xf37582ba	snd_soc_dapm_get_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xf39e04cd	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xf3a2db4d	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3c286d4	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0xf3c87bf7	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xf3ced323	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd036d	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xf489c4ad	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf49163aa	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf496cd89	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4a8975d	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf4ae5770	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf4c8e54e	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xf4d0c64d	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf50c2a39	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL vmlinux 0xf5318aea	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf55f3c42	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf59d4b8b	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5ce7d98	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xf5f9c637	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xf5fef4e3	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf60d1625	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf6230084	snd_soc_get_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xf631e2f0	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xf63a45d0	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf6464980	ahci_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0xf6797dad	mtd_get_device_size
++EXPORT_SYMBOL_GPL vmlinux 0xf6c5d823	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xf6e04730	event_storage
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf7125c62	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0xf72615c2	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0xf736c070	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0xf73a0adc	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xf74656ab	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf74dae0f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf761c488	snd_dmaengine_pcm_open_request_chan
++EXPORT_SYMBOL_GPL vmlinux 0xf762f192	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL vmlinux 0xf76b0a59	read_current_timer
++EXPORT_SYMBOL_GPL vmlinux 0xf772a18d	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0xf772cf55	ahci_stop_engine
++EXPORT_SYMBOL_GPL vmlinux 0xf7773ea1	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xf778ce97	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf78fb4bb	mmc_send_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0xf7b652aa	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xf7c49324	of_pci_parse_bus_range
++EXPORT_SYMBOL_GPL vmlinux 0xf7d6a7b7	ulpi_viewport_access_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf7e19dbc	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xf7f78d49	snd_compress_new
++EXPORT_SYMBOL_GPL vmlinux 0xf81613ba	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf839a7a5	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0xf846506f	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf86205d9	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0xf86a3a9f	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf8d68722	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf93a7d62	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL vmlinux 0xf9532e89	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0xf955b28d	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL vmlinux 0xf967422b	HYPERVISOR_xen_version
++EXPORT_SYMBOL_GPL vmlinux 0xf9857838	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0xf9903bb5	of_init_opp_table
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a8a0aa	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xf9c1b1bc	mtd_read
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9de08d9	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xf9e14084	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfa012fe7	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa1413bf	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa3ef3d6	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xfa47b9a6	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xfaa6eb20	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0xfadc789b	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xfaf36efc	twl6040_get_clk_id
++EXPORT_SYMBOL_GPL vmlinux 0xfaf534bf	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfb082d03	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfb0a246b	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb3a47cd	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xfb46058f	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL vmlinux 0xfb57bfee	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0xfb68448c	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb6f52fd	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xfbbedefd	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xfbc80c30	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xfbe5aaae	snd_soc_jack_report
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc2eb7f2	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xfc755c93	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xfc7f2bd7	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0xfc8f9de2	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0xfcb59257	cgroup_unload_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xfcbcb3ee	snd_soc_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xfcbebdc2	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xfcc572b9	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xfcc69b78	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xfccfea1f	bmp085_remove
++EXPORT_SYMBOL_GPL vmlinux 0xfcd16e24	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xfcd7bc0b	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfcdb4034	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xfceefb97	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0xfd1fba8b	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xfd41c7ce	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd8f1817	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0xfd980079	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfdc7f587	sysfs_rename_link
++EXPORT_SYMBOL_GPL vmlinux 0xfdcf015d	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xfdd7bd25	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xfdecf726	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfe61bd42	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0xfe866d69	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xfe8d9864	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfebbf6bb	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xfec4f163	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xfec657fd	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfecdec11	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xfeced756	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfeda4e1c	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0xfef34ecd	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0xfef5c596	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfefc7af1	blkio_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff398d54	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xff4eb2d7	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5cda7c	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xff605b31	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xff65c0e5	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xff7dca5b	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0xff8974eb	mtd_unpoint
++EXPORT_SYMBOL_GPL vmlinux 0xffece114	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0xfff15ef0	arizona_free_irq
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic-lpae b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae
+new file mode 100644
+index 0000000..8e7f168
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae
+@@ -0,0 +1,12283 @@
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/bcma/bcma 0x2963d897	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x01f0b6e9	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x0f8d8f27	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x2ea6c112	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x3e758834	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x6c80fdf2	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0x766f83b3	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xa7d96ff6	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xd166f07b	paride_register
++EXPORT_SYMBOL drivers/block/paride/paride 0xd860a0e1	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0xe036fffe	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xe4b69b87	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xebbd4a07	pi_write_regr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0da34b33	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x2e0d16de	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x89131fce	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa28a2ace	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xbbac5ba0	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xcf5b2dac	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x2b501482	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x57f7187f	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x75d48b36	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x86a1787e	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x8a46397e	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xd94c2b92	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/pl330 0x880dbc4d	pl330_filter
++EXPORT_SYMBOL drivers/edac/edac_core 0x21f80f7e	edac_mc_find
++EXPORT_SYMBOL drivers/fmc/fmc 0x17440beb	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x468f2003	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x65a5b26d	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x7973b2b6	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xa43dc718	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xc978bf23	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xcf4c712e	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xd06741df	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xe697e1d6	fmc_reprogram
++EXPORT_SYMBOL drivers/fmc/fmc 0xf98520e3	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xfbfc5765	fmc_device_register
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x014eaef8	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02e6e099	drm_mode_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x033efaa1	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0405839a	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x086b4da7	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bcbc952	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0cb4924f	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d3b924e	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0f2a963e	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11065515	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12c6276a	drm_buffer_read_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x13da269f	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x142b8b35	drm_buffer_copy_from_user
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1511820d	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x167fd723	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1b339c1b	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c0ae7d7	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1c62d7b9	drm_get_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1e837252	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2171bdfb	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21a4d2d5	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x21c207e5	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x22a36ddc	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x240c6587	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2445374d	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24836ad5	drm_mode_group_init_legacy_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x24d6e185	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2576cf97	drm_platform_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26256356	drm_mode_equal_no_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27baf82d	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x28d89535	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b21c127	drm_core_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b487472	drm_gem_object_handle_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b706ced	drm_get_platform_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d816e75	drm_core_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e9542bc	drm_mode_connector_detach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f7fc078	drm_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x306b23a8	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3074f033	drm_order
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x341e850b	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3704a8e0	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3706cd4e	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38410037	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac92333	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b31fb60	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c17944b	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d622cf2	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3dc565d9	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3e371ef8	drm_prime_remove_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3f5e034f	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3fda6fbc	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43384bd9	drm_buffer_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43582e9d	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44a0c113	drm_mode_height
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x474d2afb	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x47539e54	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48076537	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x498dcb5e	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a04a3b2	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4a7bd820	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4bbf0e2c	drm_mode_validate_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4d088d1f	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ddee1d5	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x51c27b80	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5203dc86	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57876a1d	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x57d82c3a	drm_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x581ed292	drm_mm_get_block_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x58a21970	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5b4680e3	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eafb8e9	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x606ae2bc	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6637473d	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6640d8eb	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x66fac91f	drm_prime_destroy_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6889360b	drm_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x68fb0cf7	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b6d7375	drm_timestamp_precision
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cee2e42	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e93ebf6	drm_get_encoder_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fed1307	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7100d27f	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74e0d57d	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x74fbf451	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x779bd6cb	drm_sysfs_connector_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a4e7297	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b1ee8b1	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b42b5d4	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b85f6f8	drm_mm_insert_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7bd0a7d2	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c0f2bb5	drm_mm_create_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c12b0af	drm_gem_object_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d11a16e	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7d159c24	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f0faed0	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f3fdb00	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x80dd436e	drm_sysfs_connector_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x82d5c4b6	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84048c32	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x84542300	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x85543e44	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8772c613	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x87ceb313	drm_prime_init_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8a636dea	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8b3f04b4	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c510862	drm_find_cea_extension
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8d613009	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8dfb019d	drm_buffer_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8e49f1ef	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f7df3a7	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x910dca59	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91797155	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x953e4e53	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x955d725c	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9745d638	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x98f3d8b6	drm_mode_create_dithering_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a92ba75	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9ad4c5a4	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c646aa1	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9d67db17	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9dd34b62	drm_mm_insert_node_in_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa07aa567	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa0b8b646	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1eabd87	drm_mode_list_concat
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1fb703c	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa508410d	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa66fd45a	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa735caef	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa96acfcb	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad2cb02a	drm_core_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad893bc3	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad89424c	drm_put_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf1fb6df	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaf7a26c7	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb1793cf8	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb8e5c44f	drm_core_reclaim_buffers
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb95beb55	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb9b09896	drm_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba2d0719	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba96254b	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbab69be7	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb4f492e	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbc0de18b	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbde4d203	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe001c53	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe18dba4	drm_get_last_vbltimestamp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe563f47	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc25a61ec	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2735609	drm_mode_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc3150c80	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc414c422	drm_vblank_offdelay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4ac8d62	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4ff743c	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca42b7f5	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb1beab5	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb59345a	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb9de2d0	drm_get_connector_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcc132086	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcda91c46	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcdeff753	drm_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce5bbde9	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0dcdd90	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd125790d	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4b3b1d0	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4f40c41	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd664dbfd	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd727955e	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd76aa2b5	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7b661cb	drm_fasync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd9ca1a72	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xda1aca64	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc46814b	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdc98d646	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd1b18e4	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdeb003cb	drm_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe10a472d	drm_mm_pre_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe16838c2	drm_mm_search_free_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2901312	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe2d4e8ac	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe4a9a4cb	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6f46e6e	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe77924e8	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xead1b319	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb506cb6	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeb8ff842	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeba8287e	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xebbd8111	drm_prime_lookup_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xec216264	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf0dcad97	drm_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf2ec6892	drm_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf36699bf	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf3ab04ad	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf4b2e991	drm_mm_put_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf56cb032	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf817b5b1	drm_global_mutex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf82e31ae	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf8cd79a3	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf92c66be	drm_mm_search_free_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfa1fbf44	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb24fa5a	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb5241ba	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfb8a84a4	drm_mm_get_block_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc41a3c3	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfd55962d	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfdca429c	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff03348d	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff0343bf	drm_fill_in_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff47a034	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x10e02fc9	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x1c4fb457	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2b978484	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d7a787f	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3117f343	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x32eed681	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x352a3698	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3b67d0ef	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x40bc9c65	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4491abb0	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x46e50b17	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4eb1457d	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x50bf64ed	i2c_dp_aux_add_bus
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x51eb7188	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x55bf1b41	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x5cb3c3ea	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8129337b	drm_fb_helper_restore_fbdev_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x81e9b1c3	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x85e30521	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x8e4340be	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x90cec218	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x936ca2ca	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x94d9b5b9	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa2195d1d	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa5c664f0	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa65195d1	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa75e8be7	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb06816da	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb2654159	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb37a0603	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc44a9a76	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7fd39bb	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd02c73c7	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0a30c77	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5d8b6b8	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf2bf5174	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf93b31d0	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfee43a69	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x1a086089	drm_usb_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x55c5aa03	drm_usb_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0xac39762d	drm_get_usb_dev
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xeb7b286d	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x09178389	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x48f49bef	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x89cc413c	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x7c829ef0	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x7f6602cb	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x5cb5d84f	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0x8ffd4eff	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x5bd12740	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x72766bb8	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x8ef73751	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x9b2dc533	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0xc115dc72	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0x6f005cf2	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xd5128761	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x2941b9a7	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x32c6dc80	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x35096410	st_sensors_sysfs_get_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x4ff35167	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6ee2ae5d	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x872bcfa6	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x8887a09e	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x9dd28ef8	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa3576a96	st_sensors_sysfs_set_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa9352069	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb77d3010	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb96b93b0	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xbc1ff8ca	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd47095f4	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe0c62bea	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xc62e40b7	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0x92cff3b0	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x6b19df73	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x75ad56da	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x6c227d4e	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0x933b7d2e	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/industrialio 0x044c761f	iio_buffer_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x04f6d173	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0x216694fd	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x2c4b0406	iio_sw_buffer_preenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x38b748a3	iio_buffer_show_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0x546edc46	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x57fe4f40	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x64de8305	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x7556ee15	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x80bc4e5f	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x81cd980a	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0x8ef2efe8	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0x937c27cf	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0x96615e88	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0x985b7730	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0x9b15f989	iio_buffer_read_length
++EXPORT_SYMBOL drivers/iio/industrialio 0xb61bf043	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0xbcc8de88	iio_buffer_store_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0xbe04c9fe	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xbfe6d7c6	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0xc15a6247	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe15aec1b	iio_buffer_register
++EXPORT_SYMBOL drivers/iio/industrialio 0xf0168efd	iio_buffer_write_length
++EXPORT_SYMBOL drivers/iio/industrialio 0xfa8fc908	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xd14f13b6	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xf0b615d3	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0xd861e3af	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0xeb322ca2	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xd554fd26	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0xdfb298ef	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x59ad0434	st_press_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0xda5cfbef	st_press_common_probe
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x1b184332	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x21a728d1	gameport_close
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x23c850a0	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x24b1cbae	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc4e28579	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfa626cc8	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfb684339	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfcbfcae0	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xfee2d53b	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/input-polldev 0x0539a00c	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x0688c3ae	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x9a8d7063	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xe218de44	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0x2241b0c7	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x2d042955	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x8db1d8b4	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xb33fb04e	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xbd0b7b1a	ad714x_remove
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xc3a18e7f	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x382d9a90	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x65a21849	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x8a2548ea	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xb54c5679	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xe9b3decf	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xfd50dbad	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x27925bad	ad7879_pm_ops
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xb7535e6b	ad7879_probe
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x0f1dfa84	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1000b392	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x10057401	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x1a3bc3a4	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x47d3fc51	capi_info2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6cfb27ad	capi20_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x955dc8ee	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xab5e55d8	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xd3e77c73	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed061606	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xefe91f42	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd7bfb49	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x7f29ce36	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xcb0237b2	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xe227344e	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xff2db2cf	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x20388f98	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x9a19f932	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xdc8a8132	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x009cab6f	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x03ee8462	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x09515126	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0d88787b	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x222d9e19	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x24dae5a0	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x26801ef8	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x29450bf2	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2f25ce5f	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x46190e01	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x54451388	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x614ede30	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x63c0d128	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x7193f76c	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x73953b35	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x781d5efb	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x92b6ea0c	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x96309324	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xa56c7b1a	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xaf62af20	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xbd43b1ff	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc652ab16	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xcea09058	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd972b13e	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe6b0bfa5	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe87943cf	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xfe42360f	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/dm-log 0x82945a42	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xaf6ba6af	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-log 0xd5811100	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xf2529edc	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x1bed69c1	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x1e8b3d22	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x9f1a5104	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xb2ba915d	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xcf257580	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xfbe87849	dm_snap_origin
++EXPORT_SYMBOL drivers/md/raid456 0x169fb7bd	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x03180b34	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x080f0dda	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x1dd2c182	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x6fa023b2	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7146af24	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x88793646	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x9f9c9b0c	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xa745463b	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xbe30cbf0	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc1e86f5d	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd9b03a2b	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xe44ae73c	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xff7c8d13	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5b88faf6	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5e3a273c	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x7533c912	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x9f6323a0	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xd5906107	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0xade54165	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x7fa4b553	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xadfe75ab	tveeprom_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x14cc2a7e	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17523ce7	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x217e3cb5	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x29432dbd	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2ad7486b	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x344908d4	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3656cb10	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3acd6a14	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x45baa1de	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x47ccec64	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x524fc05e	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5de003d2	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x629f9d31	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6883daad	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x712cf31e	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x72180695	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8189f812	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x8633f37b	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x949ecfd9	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9c19040b	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9cf2a3ba	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa59837a8	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xa90e4a37	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xaef0a423	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb24d606e	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb8d65b93	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbaae995f	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbe340587	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc4102bc2	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcbe2fddf	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd68a099e	timeval_usec_diff
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xda94cdc8	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdb1a8bd4	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdc094c39	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe0a2cb2b	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xea40a594	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf25a7aa3	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf48116c6	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf6d1ea37	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-frontends/a8293 0xe41331f3	a8293_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x4950ed57	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9033 0x431ae97f	af9033_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xeade2faa	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x01a97468	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x2d34c079	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x7b389f13	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xa5a8bc02	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xd3bb1e1a	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xdc546b84	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe568678d	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xf01e2905	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xfc3882e3	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0x3e029ecf	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xa2481c60	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0xcea992b2	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x3f53a142	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x7e41246a	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x44e07c6c	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x1ec5bbd4	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0xb11e5e62	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0x8dfed4fb	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x31da0837	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x5b873c48	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xb5155df0	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xe6778bfd	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xec419cbd	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x08d1719b	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0ec08851	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x20398ab1	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x24228fea	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x285cbaa8	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x368f1493	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x436edb24	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x92cb8930	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x93530550	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x9caca04c	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd800c8d6	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe5c45c50	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xe9ccbe8c	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xebf9585e	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf773c97b	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x339c7aec	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x03ba0991	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x18d018f1	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x512e995f	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x573d2c0f	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xc23b6fd9	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xdc44ab2c	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x278a1eeb	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x83cedc83	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x93475145	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xc2007514	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x01b3b768	dib7000p_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x1da4fd79	dib7000p_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x26346163	dib7000p_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x379a3bcc	dib7000p_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3b3aa08c	dib7000p_set_agc1_min
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3d2503d9	dib7090_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x41262171	dib7000p_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x427f6ff2	dib7000p_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x565141c9	dib7000p_get_agc_values
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x59836452	dib7000pc_detection
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x7d49fa9d	dib7000p_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xa10ee969	dib7090_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xc42eb423	dib7090_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xcd8ebd1b	dib7090_slave_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xf9900ada	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xfb921412	dib7000p_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x1dd47ab6	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x2ef4d823	dib8000_pwm_agc_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x3185b5c4	dib8000_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x563e6676	dib8000_set_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x6308b787	dib8096p_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x699b6efb	dib8000_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x70786c67	dib8000_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xa6336e49	dib8090p_get_dc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xa97d8e06	dib8000_remove_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xae16168e	dib8000_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xb9047023	dib8096p_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xc768c4cd	dib8000_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xcc800763	dib8000_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xcd773377	dib8000_get_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xcf8af823	dib8000_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd42072f4	dib8000_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xe6370fba	dib8000_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xeca69051	dib8000_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xf5c53818	dib8000_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x05b9571f	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x168430b7	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x3e2c590e	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x897b2261	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xf7aeafed	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x4c5306ea	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xe5dbf817	drxd_config_i2c
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xc1dcb852	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xec2003fc	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0xfec9d1b9	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0x2e1d1ac2	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x458729c8	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x494c1939	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/it913x-fe 0x1e94cf9c	it913x_fe_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0x04f90cea	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0xd8e828e4	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xbd93f85d	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0x8f2c19b3	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x423f21a0	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0xce5b56bc	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x390c18ce	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0xa657d243	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x3c27f9d3	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0x7e1b7b68	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0xff40a4ca	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0xd3596d4f	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0xfe35f6d5	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x7db65e89	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0x3c8b0dee	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0x2e2b7888	rtl2830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xafd9de4b	rtl2830_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2832 0xb90b3f64	rtl2832_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x4bcd2d27	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x4581174e	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x8d73b256	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xda64d6f2	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0xe110a2ef	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0xabc3005c	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xd473acbe	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0x98deda29	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0xbc8c3092	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0x92d38610	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x7dfa67f8	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0x085159bd	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0xfed4182f	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x40eeae0d	stv090x_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xc7c55ee7	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x840ee1eb	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0xc2eb360e	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0xdf045c1f	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0x85408356	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x6e16e913	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xbe7a7a07	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10071 0xdcbb83c3	tda10071_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0xc0d9ba84	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x55f489e5	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0x9d8c610a	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0x5deff950	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0x516aa585	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xf3749438	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x17c071b4	soc_camera_lock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x17d2b89f	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x1cdd79af	soc_camera_unlock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x2209c64d	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x2a566e43	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x4f506b8a	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x6eb19f78	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8637ed0a	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x967fa372	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x46b1be73	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xd4d5a2f0	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x4d148841	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x542e1cf2	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x60d040e5	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xadacdde8	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x0d478462	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x0e77f890	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x224549fc	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x2dc599a1	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xae06fa08	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xd9fec3b9	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xde34636e	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xebb3eecb	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/rc-core 0x342e0beb	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xf41478a4	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/tuners/e4000 0x7dc18445	e4000_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0xd9fee671	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0x0e2be870	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x6dd1ca0a	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x7c466ef1	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x9c736463	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc2580 0xcb875979	fc2580_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x705be21c	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x3797297a	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x9bea8017	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xbe57be04	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0xf82335d7	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x53b89d92	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18212 0x352ffc08	tda18212_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x2210c0f7	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tua9001 0xb35517a3	tua9001_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x32b92278	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner_it913x 0xdcf378fc	it913x_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xbf8650d0	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x28dd4af1	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0x5507b070	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xa660e068	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x0442892e	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x21bbc799	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x3c1c7af8	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x70b0783b	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x76eb21ea	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xa863a3e7	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xac66df55	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xda119ea3	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xdc961366	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x0e977b44	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x12c1fb60	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x8a547e87	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xa290cd80	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xad9c2567	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xc980fddf	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xef44517d	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x9a33d237	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x17e29a55	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x402f7af3	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x608cfd43	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa2d9293c	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa9fa76ea	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb463c72f	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xc86725f9	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xc9ffa1f2	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe051a274	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xe138c399	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xeb59b6f3	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xdb6dac2f	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xdbdc8bea	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x16dc63c8	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x2d1a71b2	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x6257e352	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x97faf120	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc04d5297	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc2f99534	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xc583834b	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xe058e7fc	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x469f5490	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x98a1d615	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xc9d1d1a8	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x42c8e001	v4l2_ctrl_next
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x4adaf0f3	v4l2_ctrl_query_menu_valid_items
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x53c9394f	v4l2_ctrl_query_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x5f96a661	v4l2_ctrl_check
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x90c3bb42	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x920e0698	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xa132f065	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x6774f931	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x69f6ca63	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x8c93fd34	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x9ad6f650	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x9d1bac50	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa00d5943	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0xa835155a	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x05cc413a	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x06b502de	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x08e8dcfd	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x09d6173e	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0caec282	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0e04db8c	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123a5db8	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x13c2eea1	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x140e371b	v4l2_of_get_remote_port_parent
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1a20fa43	v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2174aca7	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35384f94	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x35485eae	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x39ebe191	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c732121	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3d4001a9	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3db7f213	v4l2_of_get_remote_port
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3f85c9e7	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x409ef8fd	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x40e33598	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45363117	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x45e1b47f	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4ddce9aa	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5239e310	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5241a2f6	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5360e6c1	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x60beea97	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6289b7a4	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x62e1ddb9	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x661f6eb4	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6a16eb51	v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6b9ee25d	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6d482106	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x72bbbae1	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x77583bb8	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7f923f2a	v4l2_of_parse_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x832554e4	v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8420ae97	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87d22858	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87ee2c7b	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x87f8140a	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x894e65fa	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x98890406	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9c77d036	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa31f6288	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa69649e7	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xad92458e	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xaea1bfcf	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb343241a	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb3afa640	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb44b7412	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb71481a3	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb90cbedf	v4l2_of_get_next_endpoint
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb938be38	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbac4a225	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbe47ddf9	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbfebeb92	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc12cf8f8	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc24935b5	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc256ab25	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc75bd551	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcf73d9e3	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd2bdccbd	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe28bc339	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe6fce6f2	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe979af84	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xea8218d7	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xeaa7e027	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf58b561f	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfbdcfc30	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xfe9ba7ac	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x06c955e6	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0cafa30b	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0f65fc81	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x4a6dee49	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x57782b9d	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6a25caa3	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6eb6b199	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x7bb704b7	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x983469e7	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa803b780	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xc8257eec	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xd0b24903	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xdf51fae5	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe2ab6a6e	memstick_suspend_host
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x3727ceb8	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x7f5ebcb4	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xc1a18977	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xdb94d8d4	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xef69a770	cros_ec_prepare_tx
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x7d11d5da	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xf07fc7a5	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x11667fb9	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x1571acb4	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x2add8564	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x69472517	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x6eda8060	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7de809de	mc13xxx_irq_ack
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x84d21cc0	mc13xxx_irq_request_nounmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9d67ed8a	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9f95e638	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xaab39238	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc5b212ee	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xc635ff66	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xf1915a9d	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xb60b9c1d	tps6105x_get
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xcceef334	tps6105x_set
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xd550aa56	tps6105x_mask_and_set
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x442cd10a	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xce763add	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x8a05ed90	altera_init
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x20d9c7f3	ssc_free
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x3676686b	ssc_request
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x0e9755b9	pwm_channel_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5a8b82f9	pwm_channel_handler
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5d5c2951	pwm_clk_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x6a5e1f70	pwm_channel_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x73330c97	pwm_clk_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0xeb7f2c6f	__pwm_channel_onoff
++EXPORT_SYMBOL drivers/misc/c2port/core 0x7acb4cb6	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0x9064534a	c2port_device_register
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x19f6edd8	dw_mci_suspend
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x2d1fb81a	dw_mci_resume
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0x95be2c69	dw_mci_probe
++EXPORT_SYMBOL drivers/mmc/host/dw_mmc 0xbb7ed125	dw_mci_remove
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x05edd90a	tmio_mmc_host_runtime_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x0a790e26	tmio_mmc_host_runtime_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x378f2335	tmio_mmc_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6401e9f9	tmio_mmc_host_remove
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x6d3deee9	tmio_mmc_sdcard_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x7a6fd700	tmio_mmc_sdio_irq
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0x87fe31e3	tmio_mmc_host_probe
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xdff53426	tmio_mmc_host_suspend
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xe9963d28	tmio_mmc_host_resume
++EXPORT_SYMBOL drivers/mmc/host/tmio_mmc_core 0xf02062dd	tmio_mmc_card_detect_irq
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x0a56af9e	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x1b97b363	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x8bc44168	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0x89a211d3	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x27f82716	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x9ca89be7	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0xf6095b1a	denali_remove
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x499187fe	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x4f1051ea	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x550f7346	onenand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xaf4df9e5	onenand_default_bbt
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x48ec618c	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x5ffa7b33	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x8148b529	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xa37cb6a1	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0xa6233041	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x0fa75204	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x100fd08d	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x7a818578	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x948719b1	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x97d18809	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x9d09f215	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xbac45a51	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xce3fa515	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xcfd01ab6	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xf4365f4c	irda_register_dongle
++EXPORT_SYMBOL drivers/net/mii 0x1b4de6f7	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0x3753e305	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x59a48aee	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0x76680096	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0xa60ae6c0	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xb09782c1	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/mii 0xca56d994	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xcd4ad3f0	mii_nway_restart
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x38c071a7	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xb80309d9	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xc96206ee	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x0bb76508	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xc3a90a41	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xf006ce3e	usbnet_link_change
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x194b593c	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x28533d39	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x4d2476d1	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x55d86511	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x5fb4832a	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xac4dddac	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xb3118290	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc999c98d	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xcabccd50	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe03c4591	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe937a30a	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x815cd1e6	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x0c41516c	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4ceaaa15	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e18a66b	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e2481d5	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x53358ce3	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7a8c8158	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb2936de5	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb7c24671	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xb93fdc1e	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xbea50e09	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xd8175412	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xef5935ae	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x300e5249	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3415cef2	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x3d30d00f	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x71802b41	ath10k_core_target_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8246be6c	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x895f9dc2	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x98c44aa7	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaf096710	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xf57239ea	ath10k_core_target_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0199ec46	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x22b9aae4	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x27cf1694	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x3cb7ff8d	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4c6ddcb4	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4e1380ee	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7fabb4d2	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8054f676	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x8d4bc720	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x9629f0df	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xa3f92075	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xc9e5a090	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xe9a03add	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xf52b6280	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x0f3c6c00	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x91fc76f5	ath9k_hw_wow_event_to_string
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0xa2b7c203	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0xf4458ad7	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1d896766	ath9k_cmn_update_ichannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x20483edb	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x76339a0e	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf49aa4b3	ath9k_cmn_get_curchannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xf5b44b7b	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04433af0	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05f96666	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x08bdfb01	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0f82a67c	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x19ff07c6	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1e77299a	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1f079e7d	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x1fee31f2	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x25b9d59a	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2a9059cb	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2be1ce20	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2c90418f	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2d13cd03	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2edbf809	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x2fc83f08	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3189d4cb	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x34bfa68c	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x36511793	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37d607dd	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3837bd80	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x38eb7a8f	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3abecca6	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3c3cc67f	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3cbad34b	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x46af29ae	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x484ce3ee	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4a5af24b	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4ed15b2d	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x532852e8	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x53c1e802	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5576dd2b	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5b9cf1b2	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5bd85259	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5dbf0eeb	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x616de297	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x65b5ffc8	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x65fda10c	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x667db57f	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ae348fc	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6b757a8b	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e724942	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x788136de	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7e3cd976	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7fd275bb	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x82974bf0	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x85f7aed3	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x87598893	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8a6a5f93	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8c696086	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x900775cd	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x938c63f8	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x94ab9142	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x97956650	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x98eef192	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9a8b0069	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9bafb0f3	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9fcd73aa	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa1e70eff	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa41a20ac	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa54b16cc	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa9ea5c4f	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xabb30821	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf286ff1	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb932d8c4	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba616075	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xba6e7fe3	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbac21d8c	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbb6a5789	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbbb40ff9	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbf8dbc51	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbf93e152	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc31f26a4	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3a17c99	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc3c8556f	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4c5c268	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc531fa62	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcad54c6f	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcc46fdfc	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcfa2af62	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcfda2b24	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd051c4df	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd45f39e1	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd5ce8a00	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd6998a99	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc50f499	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdc605ab7	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdebaf1ae	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe127a8cf	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe17f05dd	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe36b2ea7	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe4cc5382	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe5e618dd	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe7c3becc	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe92187e5	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xea7062c9	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf40c34cc	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfbf14289	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0x7da5e2ac	brcmf_sdio_remove
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0xebf0805b	brcmf_sdio_probe
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1628d543	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x16302540	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x189640b7	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2dc227f8	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x31046d7b	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x5b7340f4	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x80d02dcc	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x868a984a	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x92e1dd0d	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xa7514efd	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xcbcb07f3	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xdb2e4520	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xf0707ef6	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xff85aaf5	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x03d7c9f4	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x135c73f9	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x21b33bcb	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x2205107f	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x236ad7a2	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x30a35726	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x337c2d94	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3dd66e64	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x59d2dc0b	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x7ec9a8a9	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x832ea83f	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9093656d	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x94e56e24	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9b8b27d1	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x9de9a0bb	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xace1dd50	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xaed878ec	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc05c6239	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc854744d	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xc99aec81	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd202214f	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xdbe4ab76	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe75be825	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xefed0926	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf0f214ae	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x05a806c3	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x05aa7149	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x0801b482	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x0f40c185	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x1309d990	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x14ab5998	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x15052c6f	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x16f7fd43	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x1d7692ee	_rtl92c_phy_dbm_to_txpwr_Idx
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2480e432	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x264eb2d4	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x274beb42	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2faa454a	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x3bfe947a	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x3cd6de6b	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4a109e5f	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4a80e28b	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4b586326	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5421c1c0	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x54a47797	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5bae5dba	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5c3b2680	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x67192880	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6f67a5bd	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x78f0044f	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x7c250c16	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x7de5e1ac	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x8f09a7f8	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x99c39de2	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa79c481b	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa919fd67	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xab1e9cf0	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xad960aa1	rtl92c_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb6b90586	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb7a04305	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xbecee38c	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xc100d62c	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xc4a95865	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xd3ad62ea	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xdf2c201f	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe55192b6	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xfc5e0fb9	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x26185c6d	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x5a63cca9	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0xabb1212b	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0xe37eff57	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x17232c24	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x178a1a5f	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x19c46846	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x275cab6d	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x39db32e7	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x66809569	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x70345886	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7197aa0b	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x731e4c73	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x79feedd3	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7ad6bca6	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x8537a8b4	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x89738fbd	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x91af38cf	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xa0f46e96	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xacca4609	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xb3baa4ba	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xea545380	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xf2d2f373	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x10e29d65	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x24642319	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x5737353d	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x96310ee9	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x6fa0a0d7	microread_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x8d5e6684	microread_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x2adb0e0b	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x9daa0fa4	pn544_hci_probe
++EXPORT_SYMBOL drivers/parport/parport 0x00bb369d	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x0e567b08	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x0eb5ef7a	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0x1205bc3c	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0x1d826913	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x1ee06701	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x25fedb2b	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x2623f7b9	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x3aaf303b	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x4aa11ae7	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x565ba62e	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x60f6b9f4	parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0x6105e54a	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0x63b468b8	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x80e82513	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0x80f9eb6b	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0x886def0c	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x943b10e1	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0xbd7d9c38	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0xc2afdd65	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0xca9d4a5e	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0xcc1ad87d	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xd2eed040	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xd99cb426	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0xeba06fb2	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0xed90e468	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0xefb7974c	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xf1ecc6d0	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0xf6aba129	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0xf797cf34	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport_pc 0xe8b86f3d	parport_pc_probe_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0xf2a24185	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x0697f6e3	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x15b02816	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4e92849a	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x7ff3b18d	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xa7f9db86	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xcea58108	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xd8ab73cd	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xf18a67c1	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xf2a25978	rproc_alloc
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x03604c3c	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x077d3068	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x0967764c	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x18da4eed	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x326d9ebc	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x4d04147c	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xb794ad4e	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xbcd144ee	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xcbe54290	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd36537b9	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xda122ad7	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf901ee59	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x026db5cb	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x06cbdba2	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x134d5319	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x192d02e3	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1ac9601f	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2508d0fa	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x314569de	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4418b659	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x45f0a9fc	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4eff2af7	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x50b7fd05	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x56f1a110	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x58dc5aad	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x63ba7f17	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64b3d37d	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x69b3931a	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6b56242c	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x75a1af25	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x765c289c	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7f317b26	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7f484283	fc_change_queue_depth
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x805b0ed9	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x82c01d5d	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8399913d	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8a33133b	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x923ed721	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x978ac719	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x98fe2b85	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x9ef83e37	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb6367db6	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb96e3375	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbbcbdb0c	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xbc98adfe	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc52dbb65	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc5741d92	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc619774d	fc_change_queue_type
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcb7508f3	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xccf4fed2	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd1e0face	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe2d1274a	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe3debf3b	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe4169dff	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe5f2e162	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe6cb9b4b	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe7f05dc0	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xebaa314c	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xefa2fb73	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf0dac055	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf164fedb	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf5896908	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf6a95a4b	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf7c074e2	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x67efce05	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x9863d6cf	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xb34a7f1f	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xb756543e	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0702f575	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0f01bb1b	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x12c8ef93	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x19df455f	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x27e6ef09	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x354e265a	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3d38c1a5	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3effb4ba	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x40d41e60	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x46216719	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x486e3eb8	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4f46eb90	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5ba166ea	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5ef43c0b	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x635d3b1a	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6aaf0b96	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x7478e147	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x77381423	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x79d21fdc	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x87076727	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x89eb77f1	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x96e129eb	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x9b53859a	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xaab9ef4e	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xad93e597	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb4c25392	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xba9fc970	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbe558c3a	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcbee4e40	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xcc82dce9	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd3b02302	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xe6bc066d	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf4c11a3c	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf93d83d8	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xf9b2bf4f	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xfaeb4cc5	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x0c520e0b	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x6738becd	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x720e5efd	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x804ed4de	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xbee77c1d	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xc479d5a9	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/raid_class 0x16db5d5b	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/raid_class 0x5d7d536c	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0xad8df6d6	raid_component_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1403330f	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1d91852c	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x2396c2c5	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x3172e259	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x4e7cdce5	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x518396b6	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x57c9bec8	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x57cfdd15	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x713576a4	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x76a29ba6	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8d5b75f8	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8df28f98	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb7f95a60	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x23c4aade	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x402e6023	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x41db9099	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x43103c0a	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x43fa42bb	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4b93b616	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x5ffb3a1c	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6218d4c0	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6406a996	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x68c99f8f	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x69c384b9	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x6cbeaf54	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x70a676f0	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7616ed36	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x7ce5b016	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x8323bed4	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89ebb101	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x932c6174	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9470cae7	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x991532b7	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa7dd124e	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb1443a3a	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xbac7d0a6	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc23cac71	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xda8a92e3	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe8145e16	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xee20176c	sas_phy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xf3b6a971	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x525ac38e	spi_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0x65a7233e	spi_schedule_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa2f4323e	spi_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xa4c0d255	spi_dv_device
++EXPORT_SYMBOL drivers/scsi/scsi_transport_spi 0xc40b97dd	spi_display_xfer_agreement
++EXPORT_SYMBOL drivers/ssb/ssb 0x09729e05	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x0a53f73d	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x1ca67c0a	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0x2b402d7b	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0x36e235db	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x46f06c8f	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x49dd6445	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0x647e3b8e	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x82d98f3f	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x83a744f2	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x99d442a4	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/ssb/ssb 0xbb438176	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd7c70b14	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xda52e43d	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0xe8d601ff	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0xebebe447	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xf0e3926b	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xff543ef7	ssb_bus_suspend
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x7bb98e66	adt7316_remove
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0xd5859d08	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x2dd7fa96	ade7854_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0xe8fe33de	ade7854_remove
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x08c5acba	go7007_update_board
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x418adb4e	go7007_read_interrupt
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x6b1cefe7	go7007_snd_remove
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x6db1514a	go7007_snd_init
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x71df108d	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x9c4ff4e5	go7007_read_addr
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xa46eb5f6	go7007_boot_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xb489986b	go7007_register_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xb4e1f6cc	go7007_alloc
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x009c03e6	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x05f52d2f	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x12599792	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x194f6306	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x23805b69	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2dbf8b2d	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x2dd709b6	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x43a687b8	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x51696e21	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x54bda78d	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x63f40734	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x695835bc	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x70fe0fdf	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x76019f11	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x7fa7424b	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x85d199f7	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa4bef834	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa5307e18	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xabad3630	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xabd90617	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbaf37b2f	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbca3928d	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xc7c5a731	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xcc06c4b1	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd85ecc8d	iscsit_handle_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe1273363	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf6ccb3ec	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0d079145	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x13487edf	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x137ee15f	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x14cc7050	target_fabric_configfs_free
++EXPORT_SYMBOL drivers/target/target_core_mod 0x18e699ba	fc_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1ec17e0b	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2038641c	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2946c712	transport_subsystem_release
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2ad3dadf	core_tpg_del_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2c710c4b	sas_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2fd7efb2	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3594f637	core_tpg_clear_object_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x38058dac	core_tpg_add_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3a86b8e2	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3cb24646	target_fabric_configfs_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3d74dd65	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3ed715c9	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x44182fa1	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x45980170	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x491558e4	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4a1807b9	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4fb56c58	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x534a55fa	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x59a78b78	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0x62033efc	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65359410	sas_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x66e17c18	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7170f0a4	iscsi_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x74019f9b	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x745cad12	fc_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x754a3d64	sas_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7beec10f	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x816d6020	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x82459ba1	target_fabric_configfs_init
++EXPORT_SYMBOL drivers/target/target_core_mod 0x82be2895	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x82c3f252	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x842dd53d	sbc_execute_unmap
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x87a4ea20	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x8df26ec3	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x97add18e	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9be4dee3	fc_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x9f51de2c	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa902bf90	sas_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xae43d871	iscsi_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb0d0788f	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb3f3f526	iscsi_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbcc58447	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbd643d68	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbe2adbf9	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc42be1b8	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcb4b6224	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd2f651d5	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd33f7cdf	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd624bf93	fc_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0xd638b6cb	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xda67af19	target_fabric_configfs_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xded61c42	transport_subsystem_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe038a8b6	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe102e896	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe4e53aa5	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe9707d48	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0xebd12c8e	iscsi_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf4febb9d	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf9bfa95b	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfa7c54b7	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfce0123b	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0xfecd7926	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0x1df0ed0e	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x19cb18d4	gether_set_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x1c3a1452	gether_get_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x34c0cda0	gether_set_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x39ba910f	gether_setup_name_default
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x4962917c	gether_setup_name
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x67a92a82	gether_get_ifname
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x6d101295	gether_get_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x80cc68f2	gether_set_gadget
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x85af2489	gether_get_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x9f33dbaa	gether_register_netdev
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xa0b09d11	gether_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xacabbf6e	gether_set_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xdd594c9c	gether_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xe1bace82	gether_get_host_addr_cdc
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xf0d5785c	gether_get_host_addr_u8
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3a6d4f22	rndis_free_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3ca38e3a	rndis_signal_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x4ca90996	rndis_signal_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x5d22b406	rndis_register
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x785d494b	rndis_msg_parser
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x840dd143	rndis_deregister
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x8d9854b2	rndis_set_param_dev
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x988ad2a2	rndis_set_param_vendor
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x9acf72e4	rndis_set_param_medium
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xa90054ee	rndis_uninit
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xaf1773bc	rndis_rm_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xb971ebca	rndis_get_next_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xd2fe47b1	rndis_set_host_mac
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xe555efc8	rndis_add_hdr
++EXPORT_SYMBOL drivers/usb/gadget/usb_f_rndis 0x5b7b3fda	rndis_borrow_net
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0xcdb75431	sl811h_driver
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x02716547	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0c205df0	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x10724522	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x1903cfc2	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x232fcb73	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x338466d6	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5af3cd00	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x66a0bbbc	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9554281f	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xad507713	usb_wwan_set_termios
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xafc15974	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xb289841b	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd28ead2a	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x5671baae	usb_serial_suspend
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0xa19baa11	usb_serial_resume
++EXPORT_SYMBOL drivers/vhost/vringh 0x0dda8c5a	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x1f063017	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x36dfce73	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3eaf442a	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x3fa42e4f	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5dafbd4e	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x66af098b	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x6d0e7948	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xaf8e4a0e	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xafb47dae	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc884d704	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc8bee0a4	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd11d2709	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xda4ea4cc	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xfc7dcad2	vringh_getdesc_user
++EXPORT_SYMBOL drivers/video/backlight/generic_bl 0x366d19ef	genericbl_limit_intensity
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x5f7f9611	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x966c1432	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xdb516b22	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xdba111f1	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/output 0x9291ed8e	video_output_unregister
++EXPORT_SYMBOL drivers/video/output 0xcd71e9a3	video_output_register
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x261f9d9c	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xaf179440	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xbe4437aa	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xcd4ce229	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x7c884beb	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0xc9b52bbf	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xe70fb1d4	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xe7a4150b	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x6e0cb716	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0x7f50af0d	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0x8d617ec0	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xf3ac91d4	w1_register_family
++EXPORT_SYMBOL fs/btrfs/btrfs 0x27476846	ulist_reinit
++EXPORT_SYMBOL fs/btrfs/btrfs 0x41e6a9d2	ulist_init
++EXPORT_SYMBOL fs/btrfs/btrfs 0x7e2ee765	ulist_free
++EXPORT_SYMBOL fs/btrfs/btrfs 0xa2eec2e8	ulist_fini
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb1320bc8	ulist_add
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb42289d2	ulist_alloc
++EXPORT_SYMBOL fs/btrfs/btrfs 0xc2c745db	ulist_next
++EXPORT_SYMBOL fs/configfs/configfs 0x04170123	config_item_put
++EXPORT_SYMBOL fs/configfs/configfs 0x0ba92643	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x239c702f	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x2b4e86f8	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x32e5bda0	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x40625dad	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x40b29e5a	config_item_init
++EXPORT_SYMBOL fs/configfs/configfs 0x579ee1ea	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0x729ff0f5	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x7aeb7fe6	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0xc644bb74	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xfdd6a3a6	config_item_init_type_name
++EXPORT_SYMBOL fs/exofs/libore 0x011500ad	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x04372611	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x0e953439	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0x1cc70abd	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x31fd7e38	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x4c51c428	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x70cafbad	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x88ffe8ec	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0x92a26966	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xaa68f8f0	ore_check_io
++EXPORT_SYMBOL fs/exofs/libore 0xdbe707f9	ore_remove
++EXPORT_SYMBOL fs/fscache/fscache 0x0709b045	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x098ad4bf	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x116df34e	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x1c93a7c2	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x1feb821d	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x25631afd	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x2a986904	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x302b51bb	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x348374ca	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0x3c4843fa	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0x65402c02	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x6a0ec39f	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x6cd6a0ba	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x71dc8f6e	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x7b0b98d6	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x85c3f906	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0x8739a99d	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0x88e5041e	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0x935e7f96	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x9819d0ec	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x99bf4baa	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x9aa86fae	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x9ae943eb	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xa1769776	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0xa223a0fe	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xa562dd2e	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0xa707adcb	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xb4355a29	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xcdb9a1dc	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0xd27392f6	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xd5cf5962	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0xe9cedf1c	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xf3516858	fscache_object_init
++EXPORT_SYMBOL fs/nfsd/nfsd 0x040ea5a0	nfs4_acl_nfsv4_to_posix
++EXPORT_SYMBOL fs/nfsd/nfsd 0x35e33c1e	nfs4_acl_write_who
++EXPORT_SYMBOL fs/nfsd/nfsd 0x5a157ae4	nfs4_acl_get_whotype
++EXPORT_SYMBOL fs/nfsd/nfsd 0xcb152562	nfs4_acl_posix_to_nfsv4
++EXPORT_SYMBOL fs/nfsd/nfsd 0xda45bc09	nfs4_acl_new
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x025a7d58	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x8161b24d	qtree_write_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xa7a18680	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xcdbcfef8	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xe07daaa9	qtree_read_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0xa7587646	crc7
++EXPORT_SYMBOL lib/crc7 0xd80c3603	crc7_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x0f135b1b	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x13f36999	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x1512741c	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x1f1e1a77	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0x2110282d	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0x2141529e	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x22c0d0dc	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x35d7057c	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x391edfa4	lc_get
++EXPORT_SYMBOL lib/lru_cache 0x4ff71075	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0x5b69e7bc	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x69414740	lc_set
++EXPORT_SYMBOL lib/lru_cache 0xa17de9b1	lc_find
++EXPORT_SYMBOL lib/lru_cache 0xbd50fb72	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0xc817c8aa	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xe3d5fe88	lc_create
++EXPORT_SYMBOL lib/lru_cache 0xf59c7e96	lc_is_used
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x315c65fd	zlib_deflateInit2
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x48034724	zlib_deflateReset
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xaf64ad0d	zlib_deflate
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xf741c793	zlib_deflateEnd
++EXPORT_SYMBOL net/802/p8022 0xb859879d	unregister_8022_client
++EXPORT_SYMBOL net/802/p8022 0xcc960242	register_8022_client
++EXPORT_SYMBOL net/802/p8023 0x361c5717	destroy_8023_client
++EXPORT_SYMBOL net/802/p8023 0xb7a60e88	make_8023_client
++EXPORT_SYMBOL net/802/psnap 0x42b9a1cf	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0xd98379d4	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x023179dd	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0x07369be8	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0x09c2f3b3	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x155b88a1	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1c6d0e01	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x1de5624a	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x1ebd467e	p9_client_readlink
++EXPORT_SYMBOL net/9p/9pnet 0x22c7c29a	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x23df2914	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x28a3e7d5	p9_payload_gup
++EXPORT_SYMBOL net/9p/9pnet 0x29c62388	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x31997723	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3af613d4	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x435cf969	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x4938f4b4	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0x4e060ed8	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x4ee0fa40	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x4fdcb3ee	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0x5bc5e89c	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x5cf0f036	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x62d6a923	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0x675d584a	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x685ce029	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x7722091a	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0x7ea83924	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x856696c2	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0x872ed773	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x977a0030	p9_nr_pages
++EXPORT_SYMBOL net/9p/9pnet 0xac1b3ee7	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0xb62d9146	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xb9afd58a	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0xbbc7753e	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xbc0c3bf5	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xc073dcc8	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc961c80a	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0xcd277dd8	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0xd6708792	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xdbee25da	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xde660e90	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0xe1949ee4	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf4f47089	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0xf56c55c0	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfb45463d	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/9p/9pnet 0xffc6abc7	p9_client_create_dotl
++EXPORT_SYMBOL net/appletalk/appletalk 0x244f5152	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xa7c4a819	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0xb7bfd5d0	atrtr_get_dev
++EXPORT_SYMBOL net/appletalk/appletalk 0xbb953928	aarp_send_ddp
++EXPORT_SYMBOL net/atm/atm 0x20867d45	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0x29784d7b	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x360a728c	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x70fddaef	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xa17c9a7d	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xae3574d6	atm_charge
++EXPORT_SYMBOL net/atm/atm 0xc4a424c3	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xc5e0ec3b	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0xc90acfee	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0xcdc6c5d5	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0xdd5fb216	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0xe42bddba	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/atm/atm 0xf6d4431f	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0xfac5ae25	vcc_sklist_lock
++EXPORT_SYMBOL net/ax25/ax25 0x00e9f9a1	ax25_rebuild_header
++EXPORT_SYMBOL net/ax25/ax25 0x026c1368	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0x13e0d5e8	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x27d92797	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x31ffba75	ax25_linkfail_register
++EXPORT_SYMBOL net/ax25/ax25 0x3269cc32	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x45153b8d	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x68be7ad3	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x8359d232	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0x8cb4c07f	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xcf363f93	ax25_hard_header
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x03e85cb2	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x0cb60a67	hci_recv_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x104c5bcc	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1073d81e	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x119e7134	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x18a6eb89	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x24529101	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x28670023	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x42ceea2a	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x43c72b4c	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x568132bc	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x59ecae44	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x63292115	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x668777d1	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6ab86876	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7275c818	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c640527	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c8a182b	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7ddf7422	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x823c0ed5	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x86ca485e	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91b9d28d	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x976bb8b1	hci_recv_frame
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa9c94bbe	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xadf3afee	hci_recv_stream_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xaf3f6b8c	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb61a0c3b	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xc8b14cf4	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcaf46c80	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd338394b	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd3d82381	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd4b5ce72	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe7cd6308	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe95767a4	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xec03bc05	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xed421f76	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf3554a16	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf5df2166	hci_suspend_dev
++EXPORT_SYMBOL net/bridge/bridge 0x05abc8c5	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x21bb6383	ebt_register_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x4b443ac7	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x4d64cb28	ebt_unregister_table
++EXPORT_SYMBOL net/caif/caif 0x068d3f1d	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x21577f21	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x3f19b1ad	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x7beddfcb	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xc3b606bc	caif_disconnect_client
++EXPORT_SYMBOL net/can/can 0x19629209	can_rx_register
++EXPORT_SYMBOL net/can/can 0x25449f96	can_proto_register
++EXPORT_SYMBOL net/can/can 0x533d55f5	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0x54af9af6	can_send
++EXPORT_SYMBOL net/can/can 0x5db53a1c	can_ioctl
++EXPORT_SYMBOL net/can/can 0xa60bd509	can_proto_unregister
++EXPORT_SYMBOL net/ceph/libceph 0x019df31a	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x0465ef9d	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x04da5800	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x062ef076	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x06ee847e	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x0f675c8b	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x0ff2b343	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x10940306	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0x1475bf0d	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x197effcb	ceph_osdc_release_request
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x20e664a4	ceph_osdc_unregister_linger_request
++EXPORT_SYMBOL net/ceph/libceph 0x24f24b42	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0x264b4606	ceph_copy_page_vector_to_user
++EXPORT_SYMBOL net/ceph/libceph 0x2658e775	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x2e3440d7	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x3158173e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x38d90d4a	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3bef94b5	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x3c80fadb	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0x3df0ec7c	ceph_calc_ceph_pg
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x4205ffd7	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0x424cb631	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x43c8d341	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x44ad5d41	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x49c993f1	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x4aea4697	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x4cac2343	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x57f1585f	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x5aed6485	ceph_monc_create_snapid
++EXPORT_SYMBOL net/ceph/libceph 0x5bf2ad40	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x5e9cf575	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0x5fe4b2fa	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x60b9fb86	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x61460921	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x631651e4	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x63c88ffa	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x648575ec	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x663e6707	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6c5d5ac1	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x6d2d06a1	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x6ed41be2	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0x6ed8a589	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x6fb1e584	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x71eed841	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x727d87f2	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x77692acb	ceph_msg_last_put
++EXPORT_SYMBOL net/ceph/libceph 0x7a413be0	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x7a7ae1dc	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0x7f55ad10	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x80e7aa35	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0x84f0348e	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x8556b201	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0x85c7f3d0	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x85ecae08	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0x8676a496	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0x870455ff	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x97b59121	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x9874ed78	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9a75d825	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0x9bd27baf	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa40bd703	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xa805288d	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xa97aeec3	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb1b81ca0	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb805e228	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0xb942452f	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xbbe06875	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xc2aa2381	ceph_osdc_sync
++EXPORT_SYMBOL net/ceph/libceph 0xc3bd87ec	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc55de604	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xcc170cca	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xcc28b7e4	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd2f6a896	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xd7aa7bba	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0xdc4ba325	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0xe4766b23	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0xe765b429	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0xe82c9c32	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xec792f6e	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0xf3a3b0ee	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0xfaacc8af	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0xff678124	ceph_messenger_init
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x5ab1480f	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x052da8dd	ieee802154_nl_disassoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1b81dcd4	ieee802154_nl_assoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x38239b0d	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x3f8936e9	ieee802154_nl_disassoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x7108cfd4	wpan_phy_alloc
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x7ff625ab	ieee802154_nl_scan_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x856d298a	ieee802154_nl_start_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xa929dd1d	ieee802154_nl_beacon_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb3f458c0	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xb98dac50	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xc34a8107	ieee802154_nl_assoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xf79e6e01	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xf8156194	wpan_phy_for_each
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x7e5080d2	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x861e81ad	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x976e8bcd	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x1614b97e	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x65a46461	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x8b1e9adc	ipt_register_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0xc8a54c97	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv4/tunnel4 0xec165ab4	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x960394a0	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x9c2cb6a0	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x18eee51c	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xd995c801	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0xf2a40d87	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x2b455878	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xf200ad72	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x4f51a5e5	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x6df071d2	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x045dcadb	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x063585b9	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x1720ee04	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x29fd943a	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x548c1398	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x5ac1da7d	ircomm_open
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x9b69be23	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xc4cf2f3c	ircomm_close
++EXPORT_SYMBOL net/irda/irda 0x03676e57	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x0454a18c	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0x052aeb47	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0fe7d525	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0x17a491c5	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x2036ad06	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x22842cc1	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x26975e11	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x32dfc621	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x36cad55b	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x37791344	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x3d71176f	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x4a622b47	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x4b0935d7	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x5511257d	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x6492e28c	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x6b76aa70	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x731cec71	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x773b8189	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x79dce598	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x7e67ca6e	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x83be0aac	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x845e4b09	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x875db376	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x8982c8d9	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x8a44dd5e	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0x8fcd313f	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x90ddb6bd	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x9536838a	irlap_open
++EXPORT_SYMBOL net/irda/irda 0x993ad14b	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x9ffda243	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0xaa8d74a6	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0xadddc9ee	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0xb22fd9e5	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0xb3c13d7f	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0xb60b764a	irttp_close_tsap
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xbf7dd554	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xbfa7c08d	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0xc477368d	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0xcde1c314	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xd2fd02c1	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xd310e005	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xf199cba4	irias_insert_object
++EXPORT_SYMBOL net/l2tp/l2tp_core 0x02b05e0c	l2tp_recv_common
++EXPORT_SYMBOL net/lapb/lapb 0x0ecec5ee	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x2edd9471	lapb_data_received
++EXPORT_SYMBOL net/lapb/lapb 0x32dbcef5	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x390edc2e	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x45d3f49b	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x5636dc98	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xa2766d78	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0xb54200a2	lapb_disconnect_request
++EXPORT_SYMBOL net/llc/llc 0x1e9e99fd	llc_sap_list_lock
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x427e1e88	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x5509e289	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0x776bf59c	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0xbbb92a60	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0xcd1661a9	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0xdc993462	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0xfd121995	llc_add_pack
++EXPORT_SYMBOL net/mac80211/mac80211 0x009376f2	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x027fa8af	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x090cf72a	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x09c19ef7	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x0f3579e9	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x0f460055	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x100a0154	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x1ec0ff01	ieee80211_alloc_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x20113caa	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x21a2ae71	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x26a5fa0a	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x313a2c6c	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x31d2ee7d	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x37acafe2	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x3b92746e	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0x4c611759	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x4d3e3bb7	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x4f5b5bfc	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x545951cd	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x561ab8a8	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x5c28cca5	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x5d2fd982	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x5d91c741	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x5db8fa9a	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x614ea16a	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x62201d06	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x66341e0f	ieee80211_rx
++EXPORT_SYMBOL net/mac80211/mac80211 0x68173502	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x68aa2209	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x68dbd850	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x69747869	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0x6f0134c9	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x74380b62	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x75064bfa	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x75097d2c	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x7ce0a88f	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x7ff30abb	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0x913e869c	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x965150a4	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c5e6334	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x9dae3fc3	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x9ebefe67	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0x9eeb830c	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1fc36c4	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xa9833dcd	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa157485	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xac0dc607	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xaf9ee250	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xb5485faa	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xbbbc7128	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xbbe4a5ca	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0xc08abf85	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xc36c4a8d	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0xc47d9477	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xc7e9782e	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xc88695cd	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xc92ce5e8	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0xc9859582	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xcb5df1df	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xcccafe99	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xcda61d51	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0xd2b72e14	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0xd8540a32	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xddb47d52	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xe3ee32ed	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xf1823da0	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0xf32eab86	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xf395de03	ieee80211_aes_cmac_calculate_k1_k2
++EXPORT_SYMBOL net/mac80211/mac80211 0xfb7b4c8a	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xfb923dc0	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x22e24bb1	ieee802154_register_device
++EXPORT_SYMBOL net/mac802154/mac802154 0x73f63d7f	ieee802154_free_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xb2d303d7	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0xc9cc8010	ieee802154_unregister_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xdef0a59b	ieee802154_alloc_device
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x06aa69f2	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x09468d41	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x4ed97094	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6641a4ef	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6ddf2487	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x896e2c7c	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x8f1583a3	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x922454e7	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xad98bec1	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb64c66f5	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc6a1eefb	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd78a42e7	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xde401e74	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xf47558d9	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x71f1919c	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x8978b68f	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xbf0f534c	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack_proto_gre 0x4e0a333e	nf_ct_gre_keymap_flush
++EXPORT_SYMBOL net/netfilter/nf_nat 0x0b8f7acb	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x32a0bb68	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0x95df5fe3	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0x9a0cfc70	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0xa1121198	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xbcaadf25	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/x_tables 0x08c473b7	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x208da174	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x36d78754	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x3c2b818b	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x80a2c653	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x8da406d3	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xb28f5ef1	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xb53e37af	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0xc190b8df	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xc726f6a0	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0xfc975b68	xt_register_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0xff175f74	xt_register_target
++EXPORT_SYMBOL net/nfc/hci/hci 0x1884feb9	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x31482dc2	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x58e96daf	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x5b5be3e0	nfc_hci_send_response
++EXPORT_SYMBOL net/nfc/hci/hci 0x62953c61	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x6b7f2630	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x6ecf5a85	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x88ebcaf5	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0x9ac9bfbd	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xa47d7bb5	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xc99b3956	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xccf95cd9	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xcd36bc71	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xce6e609c	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0xe8fd9820	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0xecbdcd73	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xf6d93e0a	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xfd06145a	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/nci/nci 0x07509839	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x21de1e0a	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x7633f425	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nci/nci 0xdab4fd87	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xea4d018c	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x02de267c	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x1b1f39ea	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x254252fa	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x2b1f1002	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x3219ab61	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0x4209282e	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0x435e0b5d	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0x44f95e61	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0x48c30e76	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0x595303d3	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0x68b535ee	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0x6aed3f7e	nfc_allocate_device
++EXPORT_SYMBOL net/nfc/nfc 0x76db8e3f	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x7fb4157e	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0x8d33d583	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x96060c4e	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0x98e791e4	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0xcd2c1039	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xfa24cd9f	nfc_class
++EXPORT_SYMBOL net/phonet/phonet 0x045dba40	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x068692a9	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0x1d18c33b	pn_skb_send
++EXPORT_SYMBOL net/phonet/phonet 0x1d8ff244	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x350e91b8	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0x395faf79	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0xaa315780	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0xbbfb34d5	phonet_stream_ops
++EXPORT_SYMBOL net/rds/rds 0x5031b8c5	rds_str_array
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x0aed1dbc	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x193832b6	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1f928669	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2c362439	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x3f292c3e	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x84a62e95	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x85d19427	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x8c9fd5eb	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x9038f164	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xa17a1b2f	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xbefab5c0	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xddc76a3f	rxrpc_get_null_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xdf8cc60a	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xea41a9ca	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf6079e6f	key_type_rxrpc
++EXPORT_SYMBOL net/sctp/sctp 0x02e0ce33	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x98ca4db2	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xd2a4e3db	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xe1ed8055	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x43d2fa3a	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0x23c7239d	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0x3e356372	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x017649b3	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0x036d7ae2	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x06660386	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x07d44595	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x1047ad02	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x10bc719e	cfg80211_inform_bss_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x1222b88a	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x125b2baa	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x2759e3b2	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x287d6114	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x2ac0982c	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x2ff6fc2c	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x31b8a77f	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x37233152	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0x3870b0fe	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x404700a6	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x406a8302	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x43c3c2f5	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x43d4ff2a	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x452db0b0	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0x46db6bc7	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c3b5878	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4df60550	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x4fd0230e	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x50cdf7b7	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x52b35903	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x5cae3fb9	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x6296bd68	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x634dfdd9	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x67ea8c89	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6caabe9f	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x72b6ba39	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x732fdef0	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x76a51d99	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x7e7ed3c6	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8345c112	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x850fef07	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x8976ba21	cfg80211_del_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x912e6ee7	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x92c0c538	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x942d8696	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x9842edde	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0x9902ad00	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0x9a2404d1	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9cd7e6cc	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0x9eca6f3b	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1f71781	cfg80211_inform_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xa3ba7dc6	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0xa88c690a	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0xa997eb58	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0xae831a7b	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xb540ddf9	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xb60ef50d	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0xb82eba68	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xb85c0cd0	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xc15c8611	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xc43bebe1	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xca7cfb33	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xcb343012	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xce113b95	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xcf618a57	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0xcf96fcf9	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xd0b0d36e	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xd53a45fa	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3167eca	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0xee42db3c	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0xf1035633	wiphy_new
++EXPORT_SYMBOL net/wireless/cfg80211 0xf223a6d1	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xf443e9e1	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xf5e89fdf	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0xfb0ceaf5	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xfea3805b	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/lib80211 0x115efa61	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0x2d0f99e5	print_ssid
++EXPORT_SYMBOL net/wireless/lib80211 0x7db0b983	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0x8c1b2115	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xaf93df5a	lib80211_register_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xddd61fca	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0xe2181a0e	lib80211_get_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0xb69fd202	ac97_bus_type
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x170ece22	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x94fe356c	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb4d029a6	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xea19f260	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x0983a8a4	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x3a57f235	snd_seq_autoload_unlock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x4be18ccc	snd_seq_device_register_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xb90668b2	snd_seq_autoload_lock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xc622fb29	snd_seq_device_unregister_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x127b30fb	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x1cdc0812	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x59eb74ae	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x8102ed2f	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb11ba32d	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xb2c7f684	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xea0e5748	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xed42580b	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x679589d2	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd-hwdep 0x0f387add	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x13d05928	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3c804fb7	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3d126ae2	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x459d6954	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x531ace8b	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x5865fd6c	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8cfc26ba	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8e9f590f	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb1630440	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb67a11dc	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbcf6997a	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc3fef086	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xccbad658	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xd3d054f4	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe04a99f9	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf4dcf82e	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xf61d79f4	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x1db281d4	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x01548c4e	snd_tea575x_set_freq
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x76c576fb	snd_tea575x_exit
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x93954817	snd_tea575x_init
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x036723b6	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x187b5da1	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x241917a9	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x30f6616b	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3da6c622	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x49c330ac	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x55c98e87	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5cb6c14b	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5cfca21f	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5d1908ab	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x6c8fbbb7	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x9fdcae77	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xa854197f	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc0eff50b	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xd7c41248	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xe3c1780f	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xf24c42dc	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x07cffb2b	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x35c95b1b	dm_mem_cache_client_create
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x68640b1b	dm_mem_cache_alloc
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x86e5acf9	dm_mem_cache_grow
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x920a7a41	dm_message_parse
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xa43471b6	dm_mem_cache_shrink
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xd55b290c	dm_mem_cache_client_destroy
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xfd0b67f1	dm_mem_cache_free
++EXPORT_SYMBOL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2776a3e5	lib_ring_buffer_nesting
++EXPORT_SYMBOL vmlinux 0x00000000	softirq_work_list
++EXPORT_SYMBOL vmlinux 0x0022bde3	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x002e1d87	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0x006818a5	kobject_put
++EXPORT_SYMBOL vmlinux 0x00801678	flush_scheduled_work
++EXPORT_SYMBOL vmlinux 0x0084e86d	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x00a0c058	register_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0x00a7edb8	dev_uc_init
++EXPORT_SYMBOL vmlinux 0x00c51797	register_quota_format
++EXPORT_SYMBOL vmlinux 0x00cf4a7f	of_get_parent
++EXPORT_SYMBOL vmlinux 0x00deecfb	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x00e76383	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x00e8097b	csum_partial_copy_fromiovecend
++EXPORT_SYMBOL vmlinux 0x01000e51	schedule
++EXPORT_SYMBOL vmlinux 0x010caa83	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x01524c30	tty_mutex
++EXPORT_SYMBOL vmlinux 0x0179e529	elevator_change
++EXPORT_SYMBOL vmlinux 0x017d3601	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0x017ed86b	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x0186e2de	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x01902adf	netpoll_trap
++EXPORT_SYMBOL vmlinux 0x0197365f	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0x019d63cc	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x01d768ee	tty_register_driver
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x02196324	__aeabi_idiv
++EXPORT_SYMBOL vmlinux 0x021d648e	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x02733e67	__dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL vmlinux 0x02872748	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x029a88a5	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02c5085f	unregister_mtd_chip_driver
++EXPORT_SYMBOL vmlinux 0x02cbaf97	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x02e3ce18	fasync_helper
++EXPORT_SYMBOL vmlinux 0x02eba601	inet6_protos
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x02ef742b	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x02f3b61f	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0x02f4ce54	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x02fa5979	con_is_bound
++EXPORT_SYMBOL vmlinux 0x02fd3a10	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x03026722	mempool_alloc
++EXPORT_SYMBOL vmlinux 0x030b1ec6	softnet_data
++EXPORT_SYMBOL vmlinux 0x0321900b	__vlan_find_dev_deep
++EXPORT_SYMBOL vmlinux 0x032a828b	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x0332a91d	clocksource_register
++EXPORT_SYMBOL vmlinux 0x0334795d	icst307_s2div
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x034b20eb	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x03757c9b	of_get_named_gpio_flags
++EXPORT_SYMBOL vmlinux 0x0376b279	set_nlink
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x037ae713	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x03815afe	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x038a1702	blk_get_queue
++EXPORT_SYMBOL vmlinux 0x039bef81	snd_timer_resolution
++EXPORT_SYMBOL vmlinux 0x03a6689d	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x03ba39b0	v7_flush_user_cache_all
++EXPORT_SYMBOL vmlinux 0x03bd889d	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x03c06156	bitmap_fold
++EXPORT_SYMBOL vmlinux 0x03d22852	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0404fc89	dma_supported
++EXPORT_SYMBOL vmlinux 0x04066d5b	__netdev_pick_tx
++EXPORT_SYMBOL vmlinux 0x040951b9	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0x0422c982	__d_drop
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x04454e66	complete_request_key
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x045bae3e	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0x046c1f16	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x048361c8	bio_advance
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x0493ff17	netdev_crit
++EXPORT_SYMBOL vmlinux 0x04a33d9c	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0x04cb9160	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL vmlinux 0x04cf8901	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x04d11e73	pps_lookup_dev
++EXPORT_SYMBOL vmlinux 0x04d61bbc	load_nls_default
++EXPORT_SYMBOL vmlinux 0x04e508a0	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x054434d6	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x0547fb7c	blk_register_region
++EXPORT_SYMBOL vmlinux 0x0555e2d9	phy_detach
++EXPORT_SYMBOL vmlinux 0x056ee730	ipv6_hash_secret
++EXPORT_SYMBOL vmlinux 0x057ce975	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0x0593a99b	init_timer_key
++EXPORT_SYMBOL vmlinux 0x059da60c	__devm_release_region
++EXPORT_SYMBOL vmlinux 0x05b0b273	iget_locked
++EXPORT_SYMBOL vmlinux 0x05b89d82	task_tgid_nr_ns
++EXPORT_SYMBOL vmlinux 0x05c11cb4	arm_dma_ops
++EXPORT_SYMBOL vmlinux 0x05e2843b	of_phy_connect_fixed_link
++EXPORT_SYMBOL vmlinux 0x05eee3ef	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x05f37a45	snd_pcm_hw_param_last
++EXPORT_SYMBOL vmlinux 0x05ff35bd	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x05ff568c	security_path_rename
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061a5203	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x062e4ee3	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x062ea3b0	writeback_in_progress
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x06640e3b	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0x066c1ed2	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x068ae9b5	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x06a677d2	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x06b7aa2b	lookup_bdev
++EXPORT_SYMBOL vmlinux 0x06b984ee	default_llseek
++EXPORT_SYMBOL vmlinux 0x06c08838	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0x06cce272	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x06d62d7b	update_devfreq
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x071b7eea	irq_stat
++EXPORT_SYMBOL vmlinux 0x0736332c	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0x07392259	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x073ad136	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x0767cf55	bdi_register
++EXPORT_SYMBOL vmlinux 0x077dbf56	journal_force_commit
++EXPORT_SYMBOL vmlinux 0x07869553	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0x078ef60d	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x079280dc	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x0795410e	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x07981be0	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x0799aca4	local_bh_enable
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07b21f9c	sock_register
++EXPORT_SYMBOL vmlinux 0x07c727a9	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07cf9099	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0x081f3afb	complete_all
++EXPORT_SYMBOL vmlinux 0x08216276	kobject_get
++EXPORT_SYMBOL vmlinux 0x083916d7	journal_errno
++EXPORT_SYMBOL vmlinux 0x083c2cbe	of_get_next_parent
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x086bb641	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x088f259e	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x08988b91	sock_init_data
++EXPORT_SYMBOL vmlinux 0x089d19d9	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x08a24750	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0x08c41cbe	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0x08ca1182	sock_update_classid
++EXPORT_SYMBOL vmlinux 0x08dcb096	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x08fbbe9c	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x090f9b30	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0x0943a1e2	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x09470061	release_sock
++EXPORT_SYMBOL vmlinux 0x097d174a	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x0986e135	scsi_put_command
++EXPORT_SYMBOL vmlinux 0x0988c6c1	generic_fillattr
++EXPORT_SYMBOL vmlinux 0x098b617e	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x09b7cef4	simple_lookup
++EXPORT_SYMBOL vmlinux 0x09b974cc	phy_device_register
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09cf1b46	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09df848c	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x09f6614c	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x0a068143	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x0a0786de	udplite_table
++EXPORT_SYMBOL vmlinux 0x0a2487e0	unblock_all_signals
++EXPORT_SYMBOL vmlinux 0x0a267ed0	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0x0a2df6c8	journal_create
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a36e86f	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a6b9070	bdget_disk
++EXPORT_SYMBOL vmlinux 0x0a958ed4	down_write
++EXPORT_SYMBOL vmlinux 0x0aa13d05	__raw_readsw
++EXPORT_SYMBOL vmlinux 0x0ab178ea	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0x0abda572	genl_unregister_ops
++EXPORT_SYMBOL vmlinux 0x0acb1a3c	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0adb00e8	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x0adfab73	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x0af9251c	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b0fac43	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x0b19bee7	dst_alloc
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b2366a6	inode_permission
++EXPORT_SYMBOL vmlinux 0x0b261686	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL vmlinux 0x0b2c864b	grab_cache_page_nowait
++EXPORT_SYMBOL vmlinux 0x0b3719c7	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b56117f	of_find_node_by_path
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b971c08	backlight_force_update
++EXPORT_SYMBOL vmlinux 0x0bb7341d	map_destroy
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bbed3bc	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0c0fa656	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0x0c389a7c	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0x0c3aa5fe	inode_change_ok
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c65e73c	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0x0c68c5cf	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0x0c75dac1	tty_name
++EXPORT_SYMBOL vmlinux 0x0c8c9e99	scsi_show_extd_sense
++EXPORT_SYMBOL vmlinux 0x0c93d0d4	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0x0ca0c882	twl6030_interrupt_mask
++EXPORT_SYMBOL vmlinux 0x0ca54fee	_test_and_set_bit
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cbde1d4	padata_alloc
++EXPORT_SYMBOL vmlinux 0x0cd5fcda	register_cdrom
++EXPORT_SYMBOL vmlinux 0x0cdc6ff4	kmap_atomic
++EXPORT_SYMBOL vmlinux 0x0cfefe1e	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x0d3f57a2	_find_next_bit_le
++EXPORT_SYMBOL vmlinux 0x0d4d7a32	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d609dc8	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x0d94e5c4	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0db232b6	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x0db867e6	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x0dffe67a	alloc_file
++EXPORT_SYMBOL vmlinux 0x0e079a38	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x0e1355ab	ata_print_version
++EXPORT_SYMBOL vmlinux 0x0e1e7dd8	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x0e4fe5b3	elv_rb_add
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e9b50d3	bd_set_size
++EXPORT_SYMBOL vmlinux 0x0e9d037e	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x0ee12959	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0x0f11478d	ps2_drain
++EXPORT_SYMBOL vmlinux 0x0f157947	cpu_v7_set_pte_ext
++EXPORT_SYMBOL vmlinux 0x0f31c986	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x0f32afd2	sock_from_file
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f4efc13	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x0f6be4ad	init_net
++EXPORT_SYMBOL vmlinux 0x0f806980	genl_unregister_mc_group
++EXPORT_SYMBOL vmlinux 0x0fa2a45e	__memzero
++EXPORT_SYMBOL vmlinux 0x0faddacd	dev_addr_del
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fd4e3d2	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x0ff178f6	__aeabi_idivmod
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x10000b1b	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x1000d13e	tcf_hash_lookup
++EXPORT_SYMBOL vmlinux 0x1007b6a8	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x1010f76d	security_path_symlink
++EXPORT_SYMBOL vmlinux 0x10200d58	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x1030cf94	input_register_device
++EXPORT_SYMBOL vmlinux 0x103167ee	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x103451a0	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x10589e62	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x106e082f	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x1072a394	csum_partial_copy_from_user
++EXPORT_SYMBOL vmlinux 0x109ec22b	sock_create
++EXPORT_SYMBOL vmlinux 0x10b18581	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x10d8ccdf	dma_async_memcpy_buf_to_pg
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x110e73c4	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x110f2499	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x11267875	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0x1142fb11	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x116f5510	notify_change
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x11714c55	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x117338e8	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x1190cce6	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x119b50e7	elf_check_arch
++EXPORT_SYMBOL vmlinux 0x11a88d76	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x11b4445b	snd_ctl_register_ioctl
++EXPORT_SYMBOL vmlinux 0x11b579a6	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x11c9185c	of_iomap
++EXPORT_SYMBOL vmlinux 0x11db73d8	journal_destroy
++EXPORT_SYMBOL vmlinux 0x11dfec25	input_event
++EXPORT_SYMBOL vmlinux 0x11e2ec12	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x11e3e1cb	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x122043a8	of_find_node_with_property
++EXPORT_SYMBOL vmlinux 0x124f86e1	padata_start
++EXPORT_SYMBOL vmlinux 0x12561309	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x125cf0f9	module_layout
++EXPORT_SYMBOL vmlinux 0x1269610e	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x1275122c	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x128f2ba7	genlmsg_put
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12b84e2d	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12e146a0	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x12e751e2	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x1303682a	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x133bc0ee	pps_register_source
++EXPORT_SYMBOL vmlinux 0x13731c56	genphy_suspend
++EXPORT_SYMBOL vmlinux 0x1391457a	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x139884bb	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x13a44520	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x13b715e2	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0x13bcf75a	__scm_send
++EXPORT_SYMBOL vmlinux 0x13c469ee	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0x13cc744c	kill_block_super
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e8ab73	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0x13e9aa38	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x13fdf297	snd_ctl_remove
++EXPORT_SYMBOL vmlinux 0x140841a5	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x140bb198	generic_getxattr
++EXPORT_SYMBOL vmlinux 0x14187c70	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x1434dd82	clk_get
++EXPORT_SYMBOL vmlinux 0x144f6e7a	sg_free_table
++EXPORT_SYMBOL vmlinux 0x1461dc02	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL vmlinux 0x14acd3ec	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0x14ce2bda	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x14d4a9c5	_change_bit
++EXPORT_SYMBOL vmlinux 0x14dcde42	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0x14f0cb9c	__neigh_create
++EXPORT_SYMBOL vmlinux 0x14f37374	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1551dc51	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x1559d260	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x155ceb9c	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x15692c87	param_ops_int
++EXPORT_SYMBOL vmlinux 0x15b8e2be	_snd_ctl_add_slave
++EXPORT_SYMBOL vmlinux 0x15b9125f	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x15bd9a8c	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x15c753ad	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0x15ce4dbf	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x15deca45	snd_timer_stop
++EXPORT_SYMBOL vmlinux 0x15e65d90	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0x15f571ec	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x160498e7	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x16146085	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x162ccc0c	lg_local_lock
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1639fb19	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x164b0fb3	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x164e0da9	snd_timer_start
++EXPORT_SYMBOL vmlinux 0x16766435	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x169e47df	snd_pcm_debug_name
++EXPORT_SYMBOL vmlinux 0x16b6c574	register_nls
++EXPORT_SYMBOL vmlinux 0x16c488b2	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x16d1e64c	free_task
++EXPORT_SYMBOL vmlinux 0x1711fbfb	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0x1713e799	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x1731cefb	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x1769024f	snd_pcm_notify
++EXPORT_SYMBOL vmlinux 0x178f7f0d	update_time
++EXPORT_SYMBOL vmlinux 0x17a142df	__copy_from_user
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b2f07e	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0x17e100b3	simple_setattr
++EXPORT_SYMBOL vmlinux 0x17e6d361	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x17f8849e	kernel_write
++EXPORT_SYMBOL vmlinux 0x18063c89	eth_type_trans
++EXPORT_SYMBOL vmlinux 0x1806b4a9	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0x1816a814	thaw_bdev
++EXPORT_SYMBOL vmlinux 0x181d65f2	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x1826f089	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x183aa27d	snd_ctl_make_virtual_master
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184e6c85	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x1856901d	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x1889545f	iterate_dir
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x18bd76a4	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x18c2227f	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x18cf445d	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x18d18241	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x18fd2e9f	noop_qdisc
++EXPORT_SYMBOL vmlinux 0x190709c2	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0x190c107b	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x190c7146	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x190feb17	blkdev_get
++EXPORT_SYMBOL vmlinux 0x1918e371	scsi_prep_return
++EXPORT_SYMBOL vmlinux 0x191c29fb	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x19610e1f	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0x1973a8a1	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x1976aa06	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x1989420c	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19c21bd7	bdi_destroy
++EXPORT_SYMBOL vmlinux 0x19ea6024	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0x19f5809b	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x1a21cc9a	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x1a22a9df	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x1a40930c	mutex_trylock
++EXPORT_SYMBOL vmlinux 0x1a4d616a	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x1a530670	file_remove_suid
++EXPORT_SYMBOL vmlinux 0x1a65f4ad	__arm_ioremap_pfn
++EXPORT_SYMBOL vmlinux 0x1a7c5ec0	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x1a99cb86	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x1ab1c355	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x1ab261fe	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x1ace138d	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0x1ad0b98c	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x1ad1f2e7	_memcpy_fromio
++EXPORT_SYMBOL vmlinux 0x1addab55	vfs_create
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0ac272	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x1b0f6dd8	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0x1b0f80a3	input_grab_device
++EXPORT_SYMBOL vmlinux 0x1b19a7b5	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x1b3760f5	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x1b37d548	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0x1b433aef	dev_uc_add
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b741af1	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b863380	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x1b8e7b09	register_gifconf
++EXPORT_SYMBOL vmlinux 0x1b8ec9e8	input_set_keycode
++EXPORT_SYMBOL vmlinux 0x1b9e0ff1	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x1bb0068c	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0x1bb1755b	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0x1bb6917e	skb_dequeue
++EXPORT_SYMBOL vmlinux 0x1bd86bf0	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x1bfc778c	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x1c1de81c	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x1c26c3eb	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x1c2fb226	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0x1c55b030	scsi_get_command
++EXPORT_SYMBOL vmlinux 0x1c5e3878	icst525_idx2s
++EXPORT_SYMBOL vmlinux 0x1c66f14c	vfs_setpos
++EXPORT_SYMBOL vmlinux 0x1c7a2267	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x1c886486	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x1c921b8d	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0x1c94dabb	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x1cc93e07	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x1cce8c05	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0x1ce2ee86	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x1cec5e45	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x1cf60b1e	drop_super
++EXPORT_SYMBOL vmlinux 0x1cf6a1f2	phy_device_free
++EXPORT_SYMBOL vmlinux 0x1cf6cf7e	wait_on_sync_kiocb
++EXPORT_SYMBOL vmlinux 0x1cfb04fa	finish_wait
++EXPORT_SYMBOL vmlinux 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL vmlinux 0x1d075f48	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x1d1726c3	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0x1d1eb7b8	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x1d307d4f	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0x1d4d30ba	__locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x1d5d49f4	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0x1d682258	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x1d6cf11e	pipe_lock
++EXPORT_SYMBOL vmlinux 0x1d71ae5f	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x1d742e87	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x1d87078c	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x1db44d7d	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x1db5a578	d_alloc
++EXPORT_SYMBOL vmlinux 0x1dbdf5e4	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dc7a8c7	blk_make_request
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1dd7c58a	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL vmlinux 0x1dd86295	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x1de6f19f	bio_integrity_get_tag
++EXPORT_SYMBOL vmlinux 0x1de71bda	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0aa962	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x1e1211bb	arp_find
++EXPORT_SYMBOL vmlinux 0x1e1804d4	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e344cc5	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x1e45615e	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0x1e46866b	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x1e501d36	flush_signals
++EXPORT_SYMBOL vmlinux 0x1e5bba61	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e7c2635	register_netdevice
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1ea061b5	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x1ea06663	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0x1ec3bed9	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0x1ec4eb34	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x1ed75e56	tty_port_init
++EXPORT_SYMBOL vmlinux 0x1ee1d67e	snd_dma_get_reserved_buf
++EXPORT_SYMBOL vmlinux 0x1eeb848e	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0x1eee8d4b	proc_set_user
++EXPORT_SYMBOL vmlinux 0x1efe2c25	iterate_fd
++EXPORT_SYMBOL vmlinux 0x1f042756	skb_checksum
++EXPORT_SYMBOL vmlinux 0x1f31d2a0	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0x1f46cb7b	noop_fsync
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1f7f9c6e	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x1f907855	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x1fab5905	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fcefe47	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x1fcf4d4b	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe595aa	empty_aops
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1feabe9c	mntget
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2004cf6f	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x203db3b9	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x20421305	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x204c7903	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x205afca7	dev_change_flags
++EXPORT_SYMBOL vmlinux 0x206b9fb9	amba_device_register
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20779cc8	journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0x20834bb0	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x20a3603b	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20df2681	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x20edaa28	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x20fe1136	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x211331fa	__divsi3
++EXPORT_SYMBOL vmlinux 0x21218299	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x21315700	param_get_bool
++EXPORT_SYMBOL vmlinux 0x21403ab2	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x215a9582	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0x215ebd78	bitrev16
++EXPORT_SYMBOL vmlinux 0x21761760	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x217dda13	flex_array_get
++EXPORT_SYMBOL vmlinux 0x21a33a22	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x21abc754	security_path_link
++EXPORT_SYMBOL vmlinux 0x21ad0d74	led_blink_set
++EXPORT_SYMBOL vmlinux 0x21b4d459	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x21d15319	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0x21e94f8c	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x220d33a6	d_find_alias
++EXPORT_SYMBOL vmlinux 0x2219b972	of_find_backlight_by_node
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x222fa684	lg_global_lock
++EXPORT_SYMBOL vmlinux 0x2232a8a5	mempool_free
++EXPORT_SYMBOL vmlinux 0x224c011d	nand_flash_ids
++EXPORT_SYMBOL vmlinux 0x224db4ee	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x226be09e	datagram_poll
++EXPORT_SYMBOL vmlinux 0x2272832e	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x2283b0fb	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x22ac0dac	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22b89ab6	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0x22c41981	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x22cb18ca	dst_discard
++EXPORT_SYMBOL vmlinux 0x22e14cc3	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x22e1ae6f	up_read
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x232c8c8f	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x2334c823	sg_init_table
++EXPORT_SYMBOL vmlinux 0x233ddab8	snd_jack_new
++EXPORT_SYMBOL vmlinux 0x23532c4d	ftrace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x236c65a7	force_sig
++EXPORT_SYMBOL vmlinux 0x23729581	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x23838785	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x238e85f9	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x2390396a	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240729b4	blk_bio_map_sg
++EXPORT_SYMBOL vmlinux 0x2411ebd0	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x2426cbc0	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL vmlinux 0x24285fc5	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x24287f98	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x242bfb19	snd_ctl_add
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2448bbf8	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0x2451fafa	__bread
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x2462c850	journal_start_commit
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x248593a6	dquot_destroy
++EXPORT_SYMBOL vmlinux 0x24873a1d	blk_end_request
++EXPORT_SYMBOL vmlinux 0x249f1b1e	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL vmlinux 0x24b03bfe	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x24b0f90c	of_clk_get_by_name
++EXPORT_SYMBOL vmlinux 0x24d7b4eb	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x24f2b9aa	test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x25283c07	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0x253bdb78	param_get_int
++EXPORT_SYMBOL vmlinux 0x254c2097	vfs_rename
++EXPORT_SYMBOL vmlinux 0x25540332	inode_sb_list_lock
++EXPORT_SYMBOL vmlinux 0x255db26a	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x258e8a87	md_register_thread
++EXPORT_SYMBOL vmlinux 0x259522d4	qdisc_tree_decrease_qlen
++EXPORT_SYMBOL vmlinux 0x25a06b25	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0x25c677c4	mac_pton
++EXPORT_SYMBOL vmlinux 0x25cb73c4	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x25d9a624	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x25db8ffe	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x25e789df	simple_rename
++EXPORT_SYMBOL vmlinux 0x25f673fc	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0x2609c347	snd_timer_pause
++EXPORT_SYMBOL vmlinux 0x260cf8f8	of_get_property
++EXPORT_SYMBOL vmlinux 0x261980d2	read_cache_page
++EXPORT_SYMBOL vmlinux 0x261c53d0	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x264076de	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x267fa9eb	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26bfd628	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0x26ce72d2	fsync_bdev
++EXPORT_SYMBOL vmlinux 0x26d15b94	journal_check_used_features
++EXPORT_SYMBOL vmlinux 0x26dc68c6	tty_write_room
++EXPORT_SYMBOL vmlinux 0x26dc6b87	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26f0453a	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x26f4c929	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x26f7b38a	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0x27274556	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x2733afc9	journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x275c4952	ftrace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x275ef902	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x276779bf	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0x2776d453	phy_connect
++EXPORT_SYMBOL vmlinux 0x277d513a	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x278095d8	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x2783b64f	elv_add_request
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x2797c627	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0x27a6b862	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0x27ad76f2	of_device_register
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c2197f	param_set_short
++EXPORT_SYMBOL vmlinux 0x27e1a049	printk
++EXPORT_SYMBOL vmlinux 0x28010028	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x28118cb6	__get_user_1
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x2825e9a4	seq_bitmap
++EXPORT_SYMBOL vmlinux 0x283b00ff	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0x28463bb0	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0x288041c5	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28fc3f09	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x291f0adf	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0x2929baf3	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x29300066	__genl_register_family_with_ops
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x296be7dc	seq_write
++EXPORT_SYMBOL vmlinux 0x2982ba79	vfs_readv
++EXPORT_SYMBOL vmlinux 0x29ac7257	__elv_add_request
++EXPORT_SYMBOL vmlinux 0x29b9d3a8	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x29baff70	ida_remove
++EXPORT_SYMBOL vmlinux 0x29cc21ba	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x29dbbcf6	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x29e6b180	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a07778c	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0x2a15abfb	input_flush_device
++EXPORT_SYMBOL vmlinux 0x2a282745	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a3aa678	_test_and_clear_bit
++EXPORT_SYMBOL vmlinux 0x2a689749	request_key
++EXPORT_SYMBOL vmlinux 0x2a79ac13	clkdev_add
++EXPORT_SYMBOL vmlinux 0x2a850949	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x2a866839	iget5_locked
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2aa1ad41	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x2ac61281	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL vmlinux 0x2ad0052f	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b12925d	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x2b1c8fda	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0x2b1d65ba	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b491e4f	snd_timer_global_register
++EXPORT_SYMBOL vmlinux 0x2b4e956e	mempool_create
++EXPORT_SYMBOL vmlinux 0x2b8b2507	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bc17cd0	seq_vprintf
++EXPORT_SYMBOL vmlinux 0x2bc7a13f	directly_mappable_cdev_bdi
++EXPORT_SYMBOL vmlinux 0x2be0f12d	dql_completed
++EXPORT_SYMBOL vmlinux 0x2bff3087	dev_alert
++EXPORT_SYMBOL vmlinux 0x2c03c30e	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c1bcc4a	splice_from_pipe_begin
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c2b5867	unregister_nls
++EXPORT_SYMBOL vmlinux 0x2c2f9f8f	page_put_link
++EXPORT_SYMBOL vmlinux 0x2c34f976	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x2c3fbcab	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x2c5249af	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x2c583dcf	dev_addr_add
++EXPORT_SYMBOL vmlinux 0x2c6d26ee	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x2c81ec75	__irq_regs
++EXPORT_SYMBOL vmlinux 0x2c8c684e	arp_tbl
++EXPORT_SYMBOL vmlinux 0x2c9732f8	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x2c988955	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0x2ca0af13	skb_copy_and_csum_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x2ca52716	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d28c6f2	mmc_suspend_host
++EXPORT_SYMBOL vmlinux 0x2d31228e	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d3598f5	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0x2d35dd02	km_policy_expired
++EXPORT_SYMBOL vmlinux 0x2d46431b	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0x2d594ff6	nobh_writepage
++EXPORT_SYMBOL vmlinux 0x2d6507b5	_find_next_zero_bit_le
++EXPORT_SYMBOL vmlinux 0x2d874b35	vfsmount_lock
++EXPORT_SYMBOL vmlinux 0x2d89342a	scsi_show_sense_hdr
++EXPORT_SYMBOL vmlinux 0x2d97a7f3	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x2d97eaf0	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0x2da6f62e	input_register_handler
++EXPORT_SYMBOL vmlinux 0x2dc30404	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x2dd88bc4	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x2deda4a1	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0x2e0239da	I_BDEV
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e29d39e	do_SAK
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e41584a	skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0x2e5810c6	__aeabi_unwind_cpp_pr1
++EXPORT_SYMBOL vmlinux 0x2e6ec88d	seq_escape
++EXPORT_SYMBOL vmlinux 0x2e7be112	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2e7edac9	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x2e82a804	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x2eb3edc9	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x2eb5c571	fs_bio_set
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2ed4008c	vfs_writev
++EXPORT_SYMBOL vmlinux 0x2ee52686	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x2eeceb42	sk_chk_filter
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f0286ad	blk_queue_merge_bvec
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f3857e2	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x2f3fe8b2	inode_dio_done
++EXPORT_SYMBOL vmlinux 0x2f4e3bb5	generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0x2f533596	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x2f7ef815	journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x2fac2bcb	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x2ff27c3e	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x2ff95e07	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x3009de15	lock_rename
++EXPORT_SYMBOL vmlinux 0x3013fb3a	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x30241fe6	sg_next
++EXPORT_SYMBOL vmlinux 0x302542de	i2c_release_client
++EXPORT_SYMBOL vmlinux 0x302988e9	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0x303b3227	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0x304ec72b	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x306ae61d	snd_pcm_new_stream
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x3095820e	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30c200a5	mmc_hw_reset_check
++EXPORT_SYMBOL vmlinux 0x30c2acfc	of_mdiobus_register
++EXPORT_SYMBOL vmlinux 0x30c965bd	cdrom_release
++EXPORT_SYMBOL vmlinux 0x30cada8f	radix_tree_next_hole
++EXPORT_SYMBOL vmlinux 0x30d4bf22	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x312bce5d	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x31377593	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0x31389b8b	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0x313a3128	d_path
++EXPORT_SYMBOL vmlinux 0x3145aff2	kern_path_create
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x31491b73	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x31592908	netlink_ack
++EXPORT_SYMBOL vmlinux 0x3166bcc9	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x316a7d01	of_phy_find_device
++EXPORT_SYMBOL vmlinux 0x316a82f3	pps_event
++EXPORT_SYMBOL vmlinux 0x317baf88	d_make_root
++EXPORT_SYMBOL vmlinux 0x3181b395	simple_empty
++EXPORT_SYMBOL vmlinux 0x31899291	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0x318b4fe6	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0x318cadb1	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31977516	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x31b31f5c	csum_partial_copy_nocheck
++EXPORT_SYMBOL vmlinux 0x31be69e8	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x322f0e96	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x322f48d4	abx500_dump_all_banks
++EXPORT_SYMBOL vmlinux 0x323106f2	generic_pipe_buf_map
++EXPORT_SYMBOL vmlinux 0x32374ad0	revert_creds
++EXPORT_SYMBOL vmlinux 0x3255972d	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x326d9c5a	mmc_release_host
++EXPORT_SYMBOL vmlinux 0x3274b08e	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x327bf883	of_can_translate_address
++EXPORT_SYMBOL vmlinux 0x328389a0	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x328a05f1	strncpy
++EXPORT_SYMBOL vmlinux 0x329d67c6	dst_release
++EXPORT_SYMBOL vmlinux 0x32a1d512	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0x32bb04c8	from_kqid
++EXPORT_SYMBOL vmlinux 0x32c69070	cpu_user
++EXPORT_SYMBOL vmlinux 0x32d71ea2	bmap
++EXPORT_SYMBOL vmlinux 0x32da96f4	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x32dde034	flock_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x32e278ec	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x33096f5b	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0x33160a8b	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x3316ab1a	vfs_unlink
++EXPORT_SYMBOL vmlinux 0x3322da16	unload_nls
++EXPORT_SYMBOL vmlinux 0x3330a47d	gen_pool_free
++EXPORT_SYMBOL vmlinux 0x33421180	__page_symlink
++EXPORT_SYMBOL vmlinux 0x334f085a	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x337cce46	put_cmsg
++EXPORT_SYMBOL vmlinux 0x33c13388	tc_classify_compat
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x3400bce4	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0x34184afe	current_kernel_time
++EXPORT_SYMBOL vmlinux 0x341dbfa3	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x34304c15	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x3496fd4e	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b231c4	snd_pcm_period_elapsed
++EXPORT_SYMBOL vmlinux 0x34c3c121	mnt_pin
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3507a132	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x353e3fa5	__get_user_4
++EXPORT_SYMBOL vmlinux 0x35618ec0	snd_ctl_new1
++EXPORT_SYMBOL vmlinux 0x35b6b772	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x35cb45b6	md_write_end
++EXPORT_SYMBOL vmlinux 0x35cdeba5	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x3600f5c4	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x3612c10f	tmio_core_mmc_enable
++EXPORT_SYMBOL vmlinux 0x3621d1d4	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x362a4c62	snd_info_register
++EXPORT_SYMBOL vmlinux 0x362c4777	of_mm_gpiochip_add
++EXPORT_SYMBOL vmlinux 0x363efea8	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x364e6e03	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x36565bd8	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x365a6b39	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x366a773b	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x3682e94a	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x369a6bd5	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0x36aa1f34	ip_fragment
++EXPORT_SYMBOL vmlinux 0x36b1c7dc	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x36bc2098	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x36d7b11a	of_find_matching_node_and_match
++EXPORT_SYMBOL vmlinux 0x36e360e3	__hw_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x36eb42a0	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0x36f9cd94	rcu_is_cpu_idle
++EXPORT_SYMBOL vmlinux 0x36fdba8d	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x372c4740	dev_err
++EXPORT_SYMBOL vmlinux 0x373350de	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x374ae6bd	key_invalidate
++EXPORT_SYMBOL vmlinux 0x375ce5a0	touch_atime
++EXPORT_SYMBOL vmlinux 0x37686356	input_register_handle
++EXPORT_SYMBOL vmlinux 0x376fadd0	input_release_device
++EXPORT_SYMBOL vmlinux 0x3786a5f0	of_dev_get
++EXPORT_SYMBOL vmlinux 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL vmlinux 0x37b777df	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x37b951d5	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37dbe123	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x38007f4f	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0x381144a9	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x382b5b67	abort_creds
++EXPORT_SYMBOL vmlinux 0x38347eee	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0x3866853e	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388f9128	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x38acab20	tty_devnum
++EXPORT_SYMBOL vmlinux 0x38c97d50	idr_get_next
++EXPORT_SYMBOL vmlinux 0x38e03d8b	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x38e7f8b4	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0x39172f7c	nand_scan
++EXPORT_SYMBOL vmlinux 0x39226dba	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x3924dd56	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x395e8620	ns_capable
++EXPORT_SYMBOL vmlinux 0x396c7e67	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL vmlinux 0x397cfecd	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x3997c605	simple_getattr
++EXPORT_SYMBOL vmlinux 0x39ab1be6	find_lock_page
++EXPORT_SYMBOL vmlinux 0x39b15d96	cdev_add
++EXPORT_SYMBOL vmlinux 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL vmlinux 0x39f273cc	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x3a17462f	netif_napi_add
++EXPORT_SYMBOL vmlinux 0x3a26492f	create_syslog_header
++EXPORT_SYMBOL vmlinux 0x3a55ac80	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x3a7e8c0f	bio_add_page
++EXPORT_SYMBOL vmlinux 0x3a847103	security_path_chown
++EXPORT_SYMBOL vmlinux 0x3a8c1b8b	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3aa0087e	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x3ae7134c	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0x3b148d53	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0x3b261c05	vfs_readlink
++EXPORT_SYMBOL vmlinux 0x3b2e3e06	elv_rb_find
++EXPORT_SYMBOL vmlinux 0x3b30120c	current_fs_time
++EXPORT_SYMBOL vmlinux 0x3b3ea145	snd_card_disconnect
++EXPORT_SYMBOL vmlinux 0x3b401714	netdev_class_create_file
++EXPORT_SYMBOL vmlinux 0x3b65afa9	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x3b88ad76	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x3b8e2241	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x3b917f6c	tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL vmlinux 0x3b95996e	single_open
++EXPORT_SYMBOL vmlinux 0x3b99531f	ip_mc_rejoin_groups
++EXPORT_SYMBOL vmlinux 0x3b99e9b6	get_disk
++EXPORT_SYMBOL vmlinux 0x3bbf46ea	vga_base
++EXPORT_SYMBOL vmlinux 0x3bd1b1f6	msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x3be7ec9f	neigh_for_each
++EXPORT_SYMBOL vmlinux 0x3bef03b9	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x3bfac894	generic_permission
++EXPORT_SYMBOL vmlinux 0x3c20efe4	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0x3c2af469	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x3c303880	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3c7d019b	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x3c7d75fa	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c8c2706	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x3c93bd72	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0x3c9d1211	string_get_size
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3ce51a28	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0x3cf59ac3	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x3d14ea39	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x3d1ce947	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0x3d24e4d5	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x3d309cb5	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x3d3c540f	elf_hwcap
++EXPORT_SYMBOL vmlinux 0x3d41904f	of_get_next_child
++EXPORT_SYMBOL vmlinux 0x3d6f5299	scsi_finish_command
++EXPORT_SYMBOL vmlinux 0x3d71d00f	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3dd5d463	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x3dd8f186	__arm_ioremap
++EXPORT_SYMBOL vmlinux 0x3de8f45e	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x3dea1c82	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e082b33	amba_device_unregister
++EXPORT_SYMBOL vmlinux 0x3e2319ab	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0x3e4e184e	phy_attach
++EXPORT_SYMBOL vmlinux 0x3e581679	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x3e5ec1e9	kern_unmount
++EXPORT_SYMBOL vmlinux 0x3e780e46	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x3e840cf4	snd_timer_global_new
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3eae292f	param_set_byte
++EXPORT_SYMBOL vmlinux 0x3eaf291d	param_get_string
++EXPORT_SYMBOL vmlinux 0x3ec16c3b	in_group_p
++EXPORT_SYMBOL vmlinux 0x3ec3fa78	bioset_create
++EXPORT_SYMBOL vmlinux 0x3ed63055	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0x3f181e2c	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0x3f3517a8	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x3f3c9bbc	mem_cgroup_subsys
++EXPORT_SYMBOL vmlinux 0x3f3fe5cb	unlock_page
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f455332	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x3f4a684a	dev_get_by_flags_rcu
++EXPORT_SYMBOL vmlinux 0x3f4aa526	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x3f5b67d5	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x3f609675	pm860x_page_reg_read
++EXPORT_SYMBOL vmlinux 0x3f874733	seq_path
++EXPORT_SYMBOL vmlinux 0x3f952d47	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x3fab3ca9	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x3fbecd72	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0x3fc61011	get_super_thawed
++EXPORT_SYMBOL vmlinux 0x3fcee150	file_sb_list_del
++EXPORT_SYMBOL vmlinux 0x3fd55724	of_n_size_cells
++EXPORT_SYMBOL vmlinux 0x3ff62317	local_bh_disable
++EXPORT_SYMBOL vmlinux 0x40298ead	tty_lock_pair
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x4039138f	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x4043c351	phys_mem_access_prot
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x407136b1	__put_user_8
++EXPORT_SYMBOL vmlinux 0x4078083b	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x409af60a	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40be6614	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40ce485b	mempool_resize
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40d4f256	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x40f07981	__ashldi3
++EXPORT_SYMBOL vmlinux 0x40f40cf3	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x4110a313	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x41473fb7	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x41f57a1e	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x420a54b9	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x420b515d	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x420bacf2	scsi_reset_provider
++EXPORT_SYMBOL vmlinux 0x4211c3c1	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x423636b1	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0x423f8599	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0x4250eed0	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x4261b606	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x426f3496	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x428f24f9	posix_acl_create
++EXPORT_SYMBOL vmlinux 0x42977ad4	__hw_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x4298b775	v7_flush_kern_cache_all
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42aedd93	clear_nlink
++EXPORT_SYMBOL vmlinux 0x42aefe59	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x42f8a2de	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x431158ac	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x431914f4	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0x431ae3a9	seq_puts
++EXPORT_SYMBOL vmlinux 0x4346b752	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x43492ffe	simple_map_init
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x43632d7d	of_find_property
++EXPORT_SYMBOL vmlinux 0x4363a98d	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x437e2ded	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x43850017	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43992c36	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x43b3ba4e	nf_reinject
++EXPORT_SYMBOL vmlinux 0x43bf177e	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0x43c61355	scsi_add_device
++EXPORT_SYMBOL vmlinux 0x43d357ef	bdi_init
++EXPORT_SYMBOL vmlinux 0x43ea3da5	snd_pcm_mmap_data
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x44091e18	sync_inode
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x442495c9	tmio_core_mmc_resume
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x44620d67	vfs_read
++EXPORT_SYMBOL vmlinux 0x44643b93	__aeabi_lmul
++EXPORT_SYMBOL vmlinux 0x4470a79b	param_ops_long
++EXPORT_SYMBOL vmlinux 0x44727343	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x449af4ba	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0x44da5d0f	__csum_ipv6_magic
++EXPORT_SYMBOL vmlinux 0x44dd3d8d	completion_done
++EXPORT_SYMBOL vmlinux 0x44e2034c	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44f5e8b5	of_allnodes
++EXPORT_SYMBOL vmlinux 0x455293f6	down_read
++EXPORT_SYMBOL vmlinux 0x4558e3a9	get_fs_type
++EXPORT_SYMBOL vmlinux 0x456f3176	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x45b6ba3c	dev_load
++EXPORT_SYMBOL vmlinux 0x45b6dd6e	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0x45bc58a7	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x45bda0d5	system_serial_low
++EXPORT_SYMBOL vmlinux 0x45c0a4b8	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x45c8cd86	ifla_policy
++EXPORT_SYMBOL vmlinux 0x45cc755b	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0x45eac0dd	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0x45f68981	dev_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x46343f64	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0x4639be44	bio_get_nr_vecs
++EXPORT_SYMBOL vmlinux 0x465757c3	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x465e3ef2	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x46608fa0	getnstimeofday
++EXPORT_SYMBOL vmlinux 0x466ec2cd	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x4690ca7d	write_cache_pages
++EXPORT_SYMBOL vmlinux 0x46b8d786	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL vmlinux 0x46d3b28c	__div0
++EXPORT_SYMBOL vmlinux 0x46f0b4b4	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0x46f4b88c	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x470a36dc	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47478b70	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x475100c2	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x4794c1dd	scsi_print_result
++EXPORT_SYMBOL vmlinux 0x47b3f862	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0x47b6a10f	ftrace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x47e70229	v7_flush_user_cache_range
++EXPORT_SYMBOL vmlinux 0x47edb69b	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x47f757de	elf_platform
++EXPORT_SYMBOL vmlinux 0x47fc8620	ip_cmsg_recv
++EXPORT_SYMBOL vmlinux 0x481cab01	of_i2c_register_devices
++EXPORT_SYMBOL vmlinux 0x481ce6ce	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x482d1a18	noop_llseek
++EXPORT_SYMBOL vmlinux 0x4845c423	param_array_ops
++EXPORT_SYMBOL vmlinux 0x48467036	mpage_readpages
++EXPORT_SYMBOL vmlinux 0x48539a67	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x486785e8	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x487d9343	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x4881d505	idr_for_each
++EXPORT_SYMBOL vmlinux 0x488882e7	downgrade_write
++EXPORT_SYMBOL vmlinux 0x488ff3ed	inet6_release
++EXPORT_SYMBOL vmlinux 0x48905c0f	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0x48945b34	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x48a5b067	__machine_arch_type
++EXPORT_SYMBOL vmlinux 0x48c6db53	of_get_child_by_name
++EXPORT_SYMBOL vmlinux 0x48d64a2b	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0x48dbd028	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL vmlinux 0x48de487c	simple_open
++EXPORT_SYMBOL vmlinux 0x48dfe768	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x4903cd88	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x4923114f	rtnl_notify
++EXPORT_SYMBOL vmlinux 0x49261753	input_open_device
++EXPORT_SYMBOL vmlinux 0x493dbbc1	migrate_page
++EXPORT_SYMBOL vmlinux 0x493de9d7	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0x49455a4f	padata_stop
++EXPORT_SYMBOL vmlinux 0x4956f7be	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x499cb58c	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b77420	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x49c33eb7	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x49d113f9	do_splice_to
++EXPORT_SYMBOL vmlinux 0x49ebacbd	_clear_bit
++EXPORT_SYMBOL vmlinux 0x49efcfae	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0x4a09887a	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x4a112df8	sg_init_one
++EXPORT_SYMBOL vmlinux 0x4a358252	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL vmlinux 0x4a4a81f5	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x4a57b339	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x4a796b8a	cdev_init
++EXPORT_SYMBOL vmlinux 0x4a7fb243	percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4abfef24	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4add903c	put_io_context
++EXPORT_SYMBOL vmlinux 0x4aecb5df	bio_split
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b015768	snd_iprintf
++EXPORT_SYMBOL vmlinux 0x4b0defba	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0x4b1d0577	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b34fbf5	block_all_signals
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b693518	mmc_try_claim_host
++EXPORT_SYMBOL vmlinux 0x4b6ca107	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x4b82841e	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x4b88ca77	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x4b9864f9	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0x4ba72965	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x4bc78ff5	input_unregister_device
++EXPORT_SYMBOL vmlinux 0x4bcc588a	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x4bdcafcb	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x4be7fb63	up
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4be9d968	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0x4bff5c0c	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0x4c1182cb	bitmap_scnprintf
++EXPORT_SYMBOL vmlinux 0x4c1c079a	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x4c1d6044	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c3c3b43	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x4c63fd8e	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0x4c671a2c	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x4c69a31b	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x4c6a926b	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0x4c86184b	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x4cb87266	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x4cbbd171	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cea2c55	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x4d0d163d	copy_page
++EXPORT_SYMBOL vmlinux 0x4d264427	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x4d27617b	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x4d2f198e	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0x4d3b62de	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d405db8	param_ops_string
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d4b8867	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x4d60b3d1	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL vmlinux 0x4da2f1ed	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x4da6a9f0	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x4dd4e6f4	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x4dda3f51	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4dec6038	memscan
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e0d469d	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x4e114b39	get_io_context
++EXPORT_SYMBOL vmlinux 0x4e1c8edc	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x4e2ae7cb	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x4e2ffcfd	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e35c58c	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e830a3e	strnicmp
++EXPORT_SYMBOL vmlinux 0x4e8564ee	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x4e8adc00	__lock_page
++EXPORT_SYMBOL vmlinux 0x4e9db993	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x4ea63695	get_write_access
++EXPORT_SYMBOL vmlinux 0x4ec64efc	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0x4ec7ef0f	scsi_setup_fs_cmnd
++EXPORT_SYMBOL vmlinux 0x4edd2e80	inode_init_once
++EXPORT_SYMBOL vmlinux 0x4ee6a904	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x4f01caab	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f248523	of_find_node_by_name
++EXPORT_SYMBOL vmlinux 0x4f29ac03	fb_pan_display
++EXPORT_SYMBOL vmlinux 0x4f36ab41	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f40739a	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x4f4555fe	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f644e29	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f758686	nand_scan_bbt
++EXPORT_SYMBOL vmlinux 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL vmlinux 0x4f872dd4	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x4f99d705	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0x4fa842cb	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x4fcdbf9e	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x4fd67e4e	inet_frag_evictor
++EXPORT_SYMBOL vmlinux 0x4fe4094b	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x4fe90a43	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x4fee0767	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0x4fee546c	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x5004a3a1	put_page
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x504d7a8c	neigh_destroy
++EXPORT_SYMBOL vmlinux 0x50613d87	__pskb_copy
++EXPORT_SYMBOL vmlinux 0x5072b256	blk_get_request
++EXPORT_SYMBOL vmlinux 0x507846b9	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0x508048e0	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x509817cf	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x50a9e78a	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x50b95330	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x50bc0b91	elv_register_queue
++EXPORT_SYMBOL vmlinux 0x511746c1	dump_fpu
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5143c678	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x517394ea	simple_readpage
++EXPORT_SYMBOL vmlinux 0x51749fc8	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0x51908eb8	__raw_writesl
++EXPORT_SYMBOL vmlinux 0x51a4ff78	__ps2_command
++EXPORT_SYMBOL vmlinux 0x51bb51ef	input_reset_device
++EXPORT_SYMBOL vmlinux 0x51d559d1	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x51dce73b	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x51e34f9f	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0x51e77c97	pfn_valid
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x5209297d	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x52428cc8	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x524cc031	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x524e73a0	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x52599436	set_disk_ro
++EXPORT_SYMBOL vmlinux 0x527b11e4	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x528fea94	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x52d42c95	set_current_groups
++EXPORT_SYMBOL vmlinux 0x52d8e7d8	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x52dd2da2	scsi_cmd_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x532e8cd0	request_firmware
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x5334d28d	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x533a2657	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0x534f1649	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x5385ea45	cad_pid
++EXPORT_SYMBOL vmlinux 0x53994be5	write_inode_now
++EXPORT_SYMBOL vmlinux 0x539a39d3	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x53eb971f	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0x53f2d195	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x53f53b9c	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x541979b8	inc_nlink
++EXPORT_SYMBOL vmlinux 0x5427d9b6	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x5427dfd2	__nla_reserve
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544539d5	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0x544a32e7	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x547077ec	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x54752324	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x547a21ff	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x548a3429	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x549be3cf	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54cef51d	journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54f21cff	__send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x550fd2fd	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5546d754	netdev_has_any_upper_dev
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x5568ec9d	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL vmlinux 0x556c435f	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x5587a353	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x558b6d66	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x5594be03	bitmap_remap
++EXPORT_SYMBOL vmlinux 0x55999f45	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x55b9de36	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x55bc8147	kernel_listen
++EXPORT_SYMBOL vmlinux 0x55c591d4	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x5614b010	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x561fe2b9	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x56239611	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x562939c3	of_gpio_simple_xlate
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x5642793a	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x564ec501	dev_notice
++EXPORT_SYMBOL vmlinux 0x56695f2b	ptp_clock_unregister
++EXPORT_SYMBOL vmlinux 0x566df6de	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x5697e7d9	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x5699b0fb	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x56a09268	sock_no_getname
++EXPORT_SYMBOL vmlinux 0x56bb0528	get_tz_trend
++EXPORT_SYMBOL vmlinux 0x56c325ab	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56e81207	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0x571d3247	_dev_info
++EXPORT_SYMBOL vmlinux 0x57221537	journal_wipe
++EXPORT_SYMBOL vmlinux 0x5724eb34	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x5725f6ee	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0x572d0104	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x57381d0c	sock_no_poll
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x57629bbf	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x5799a29f	seq_open
++EXPORT_SYMBOL vmlinux 0x57b1452c	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0x57baad6f	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0x57d855ae	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x57e7d08a	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x57e8a80a	scsi_nonblockable_ioctl
++EXPORT_SYMBOL vmlinux 0x57f756d7	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x57fc06bc	brioctl_set
++EXPORT_SYMBOL vmlinux 0x581c49a1	ps2_command
++EXPORT_SYMBOL vmlinux 0x58330d7d	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x5833a6f8	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x584b84b5	scsi_release_buffers
++EXPORT_SYMBOL vmlinux 0x58545ede	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x5857b7cd	pgprot_kernel
++EXPORT_SYMBOL vmlinux 0x58617f6c	__sb_end_write
++EXPORT_SYMBOL vmlinux 0x5882780c	proc_set_size
++EXPORT_SYMBOL vmlinux 0x58829406	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x588748ee	tcp_poll
++EXPORT_SYMBOL vmlinux 0x588c130c	vexpress_config_func_put
++EXPORT_SYMBOL vmlinux 0x58a901cd	__find_get_block
++EXPORT_SYMBOL vmlinux 0x58b5a97c	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0x58bfe69b	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x58d1070a	of_get_address
++EXPORT_SYMBOL vmlinux 0x58dbcff3	mutex_lock
++EXPORT_SYMBOL vmlinux 0x59256547	release_pages
++EXPORT_SYMBOL vmlinux 0x594b0267	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x594e1317	__modsi3
++EXPORT_SYMBOL vmlinux 0x5951f14d	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x5967a3e2	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0x596fb905	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x596fffcd	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x598542b2	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x598cd828	udp_table
++EXPORT_SYMBOL vmlinux 0x59b597f5	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x59bb036e	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x59bd62f4	nand_bch_init
++EXPORT_SYMBOL vmlinux 0x59d29dab	v7_flush_kern_dcache_area
++EXPORT_SYMBOL vmlinux 0x59e5070d	__do_div64
++EXPORT_SYMBOL vmlinux 0x5a024903	___pskb_trim
++EXPORT_SYMBOL vmlinux 0x5a0cd1b8	free_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0x5a11eaf1	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x5a297533	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x5a7e8fb8	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x5a9395f6	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x5ad007e2	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0x5ad2ab2f	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0x5ad3d8b8	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x5ae5be44	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x5afb2fd6	start_tty
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b3c8c88	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL vmlinux 0x5b4338f7	uart_match_port
++EXPORT_SYMBOL vmlinux 0x5b56cddb	sys_imageblit
++EXPORT_SYMBOL vmlinux 0x5b72009f	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x5ba4301f	scsi_host_put
++EXPORT_SYMBOL vmlinux 0x5ba53020	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x5bce252a	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x5c25a655	file_open_root
++EXPORT_SYMBOL vmlinux 0x5c58199d	kmap_high
++EXPORT_SYMBOL vmlinux 0x5c61f140	new_inode
++EXPORT_SYMBOL vmlinux 0x5c9284a0	processor_id
++EXPORT_SYMBOL vmlinux 0x5cb1b43f	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0x5cc5be0e	follow_pfn
++EXPORT_SYMBOL vmlinux 0x5ccfb396	__block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5d0b1892	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x5d30f7ff	fb_get_mode
++EXPORT_SYMBOL vmlinux 0x5d3ae9fd	tcp_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x5d43a31f	bio_endio
++EXPORT_SYMBOL vmlinux 0x5d4cc554	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x5d4ecde7	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d554e21	find_vma
++EXPORT_SYMBOL vmlinux 0x5d5b5a16	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x5d693169	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x5d76aa04	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x5d7c2a89	skb_store_bits
++EXPORT_SYMBOL vmlinux 0x5d891a64	idr_destroy
++EXPORT_SYMBOL vmlinux 0x5d8b35fb	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x5db6e6ea	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0x5dc66e0e	dma_async_memcpy_pg_to_pg
++EXPORT_SYMBOL vmlinux 0x5dc835df	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x5e0576cf	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0x5e431e1a	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0x5e56b581	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x5e5d010d	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0x5e5ecb3a	tcp_close
++EXPORT_SYMBOL vmlinux 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL vmlinux 0x5e8d2eb0	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5ea772c8	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ec1dae6	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0x5ec67f9e	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5ede26d0	of_mdio_find_bus
++EXPORT_SYMBOL vmlinux 0x5ee48195	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL vmlinux 0x5eebfb7d	of_match_device
++EXPORT_SYMBOL vmlinux 0x5ef57707	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f3c8f5c	mmc_assume_removable
++EXPORT_SYMBOL vmlinux 0x5f487c30	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x5f58f676	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x5f6675e2	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x5f72fcf4	bio_reset
++EXPORT_SYMBOL vmlinux 0x5f754e5a	memset
++EXPORT_SYMBOL vmlinux 0x5f9bb16b	skb_put
++EXPORT_SYMBOL vmlinux 0x5fa5f0c7	md_check_recovery
++EXPORT_SYMBOL vmlinux 0x5fd4a369	clear_inode
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602c02cc	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL vmlinux 0x602fc53c	skb_unlink
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x6045b3de	vfs_write
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60ba81ac	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x60dc6357	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x6108297a	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0x6115ba2e	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x6118a404	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0x611a37ac	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0x611e64be	htc_egpio_get_wakeup_irq
++EXPORT_SYMBOL vmlinux 0x612390ad	netpoll_set_trap
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x61296b64	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0x612aa479	tty_port_open
++EXPORT_SYMBOL vmlinux 0x6170371e	skb_find_text
++EXPORT_SYMBOL vmlinux 0x617643a2	param_set_long
++EXPORT_SYMBOL vmlinux 0x617a218d	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x617b38b5	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x61813a38	sk_reset_txq
++EXPORT_SYMBOL vmlinux 0x61ad743d	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61bc86b8	__nla_put
++EXPORT_SYMBOL vmlinux 0x6201df6a	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0x62071273	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0x62145469	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x62430a60	mmc_cleanup_queue
++EXPORT_SYMBOL vmlinux 0x6251a1f9	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0x626df122	km_query
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62822d05	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x628e330b	net_dma_find_channel
++EXPORT_SYMBOL vmlinux 0x62a2f33b	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x62b02b12	account_page_writeback
++EXPORT_SYMBOL vmlinux 0x62be44ee	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x62bf1729	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0x62d2716a	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x62d32747	tcp_tso_segment
++EXPORT_SYMBOL vmlinux 0x62d34ec2	kobject_del
++EXPORT_SYMBOL vmlinux 0x62e4319b	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x62e7ecb5	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x62fd6207	param_set_charp
++EXPORT_SYMBOL vmlinux 0x631647bc	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x6340ca91	skb_trim
++EXPORT_SYMBOL vmlinux 0x63922bbd	vfs_stat
++EXPORT_SYMBOL vmlinux 0x639d0698	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x63c6fb56	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x63d073a7	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6402e743	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x64130335	lease_modify
++EXPORT_SYMBOL vmlinux 0x645cc2ba	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0x6461897d	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL vmlinux 0x646399a1	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0x64663dd2	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a62ff1	sock_release
++EXPORT_SYMBOL vmlinux 0x64af6419	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x64b3b47f	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x64c024dd	seq_release_private
++EXPORT_SYMBOL vmlinux 0x64d233c9	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x64e197b6	mmc_cache_ctrl
++EXPORT_SYMBOL vmlinux 0x64f3958a	vfs_getattr
++EXPORT_SYMBOL vmlinux 0x64f9e81a	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0x6505feea	input_close_device
++EXPORT_SYMBOL vmlinux 0x650a6767	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x653a2381	i2c_master_send
++EXPORT_SYMBOL vmlinux 0x654017ff	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x6540232f	vfs_open
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x65466939	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x6585e310	alloc_pages_exact_nid
++EXPORT_SYMBOL vmlinux 0x658765fa	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x65a39985	arp_send
++EXPORT_SYMBOL vmlinux 0x65c6d300	block_read_full_page
++EXPORT_SYMBOL vmlinux 0x65d67a20	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65e2f81b	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x65f8573e	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x6605f97f	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x663f84cf	vmap
++EXPORT_SYMBOL vmlinux 0x666ca558	phy_print_status
++EXPORT_SYMBOL vmlinux 0x668da8d5	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x66955f79	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x669ed373	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0x66a67dab	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x66aa18e1	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x66cad000	__sg_free_table
++EXPORT_SYMBOL vmlinux 0x66dd9dad	nla_put
++EXPORT_SYMBOL vmlinux 0x66fb6af0	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0x6752db3b	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x675c2c5f	snd_card_free
++EXPORT_SYMBOL vmlinux 0x676bbc0f	_set_bit
++EXPORT_SYMBOL vmlinux 0x6780eb64	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x6793674e	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x67991c67	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b643f1	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67bb0253	dqput
++EXPORT_SYMBOL vmlinux 0x67c772f1	eth_rebuild_header
++EXPORT_SYMBOL vmlinux 0x67e3276e	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x67f0fd4e	skb_append
++EXPORT_SYMBOL vmlinux 0x6802332c	log_start_commit
++EXPORT_SYMBOL vmlinux 0x6804af84	snd_pcm_suspend_all
++EXPORT_SYMBOL vmlinux 0x68128574	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x681436e6	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0x68398d4c	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0x68472135	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0x685ff801	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0x686707db	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x686e3b38	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x68735957	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x687c8539	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x688297d1	vc_cons
++EXPORT_SYMBOL vmlinux 0x68869bae	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0x688aabbb	snd_pcm_lib_ioctl
++EXPORT_SYMBOL vmlinux 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL vmlinux 0x68ab656c	journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0x68d3ce6a	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0x68e05d57	getrawmonotonic
++EXPORT_SYMBOL vmlinux 0x68fb581a	icst307_idx2s
++EXPORT_SYMBOL vmlinux 0x6915eb38	down_interruptible
++EXPORT_SYMBOL vmlinux 0x693a88d6	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x695fb0a0	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6976085d	snd_pcm_lib_free_pages
++EXPORT_SYMBOL vmlinux 0x697f7853	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x69958af9	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0x699895e1	page_address
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69d33db8	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x69d38ed9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x69e27c7a	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a2cb028	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0x6a401e55	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a77df5d	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x6a8655da	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x6a918eb8	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x6aa8b3d8	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x6ae5bf1c	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0x6ae8502f	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x6af61901	dev_mc_add
++EXPORT_SYMBOL vmlinux 0x6af75486	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b22cc21	__module_get
++EXPORT_SYMBOL vmlinux 0x6b27f121	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x6b2db8ae	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b489559	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x6b558a79	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0x6b71d895	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0x6b7589f4	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6b8d00bc	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0x6b90cdba	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x6b951ea7	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x6bbf0416	of_find_i2c_device_by_node
++EXPORT_SYMBOL vmlinux 0x6bbf2454	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x6bc25819	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bc9d5d2	splice_from_pipe_next
++EXPORT_SYMBOL vmlinux 0x6bce652c	snd_card_register
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6be24427	kmap
++EXPORT_SYMBOL vmlinux 0x6c0eca4b	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c564610	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c6cdd4d	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c7e9ed4	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x6ccf7bd7	__pv_phys_offset
++EXPORT_SYMBOL vmlinux 0x6cd7dc2c	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6d044c26	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d05efdb	dqget
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d14937e	snd_unregister_device
++EXPORT_SYMBOL vmlinux 0x6d27ef64	__bitmap_empty
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d3b3ecb	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x6d44ab9f	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x6d5fc726	bio_sector_offset
++EXPORT_SYMBOL vmlinux 0x6d662533	_find_first_bit_le
++EXPORT_SYMBOL vmlinux 0x6d98a110	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x6db33dc8	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x6db55d71	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x6dc3547f	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x6dd798d4	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0x6dde8761	mmc_gpio_free_ro
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6e0e825b	log_wait_commit
++EXPORT_SYMBOL vmlinux 0x6e0eba2b	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0x6e384bd0	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x6e3d3b88	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0x6e4acb31	genl_register_mc_group
++EXPORT_SYMBOL vmlinux 0x6e4e30f4	bdgrab
++EXPORT_SYMBOL vmlinux 0x6e4f882e	vfs_follow_link
++EXPORT_SYMBOL vmlinux 0x6e581f46	dm_get_mapinfo
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e749452	generic_writepages
++EXPORT_SYMBOL vmlinux 0x6e88e56f	snd_pcm_link_rwlock
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6ece6983	simple_statfs
++EXPORT_SYMBOL vmlinux 0x6edb52ca	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x6ee97046	journal_extend
++EXPORT_SYMBOL vmlinux 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL vmlinux 0x6f1680b0	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x6f1bfce2	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x6f1f0e06	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f262588	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x6f4b329b	scsi_prep_fn
++EXPORT_SYMBOL vmlinux 0x6f8f7c87	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x6f958ca3	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6fcf8e0f	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x6fd4bd86	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0x6fed4f98	kthread_stop
++EXPORT_SYMBOL vmlinux 0x6fef762b	mntput
++EXPORT_SYMBOL vmlinux 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL vmlinux 0x7011f8eb	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0x7020c900	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0x70257857	scsi_execute
++EXPORT_SYMBOL vmlinux 0x70379e99	locks_init_lock
++EXPORT_SYMBOL vmlinux 0x70386317	flush_dcache_page
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x705a606b	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x705e5c52	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0x706dea48	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x7088cad0	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0x7094494b	bdput
++EXPORT_SYMBOL vmlinux 0x70a2a21b	journal_stop
++EXPORT_SYMBOL vmlinux 0x70b29803	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x70b8564c	lro_flush_pkt
++EXPORT_SYMBOL vmlinux 0x70bb69f7	dev_emerg
++EXPORT_SYMBOL vmlinux 0x70bc17d7	inode_wait
++EXPORT_SYMBOL vmlinux 0x70d053fd	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70d6a2c1	key_type_keyring
++EXPORT_SYMBOL vmlinux 0x70e0ec02	seq_putc
++EXPORT_SYMBOL vmlinux 0x70ebadc0	snd_add_device_sysfs_file
++EXPORT_SYMBOL vmlinux 0x71240bb1	mmc_get_card
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x7137ac98	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x71726650	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x71769810	alloc_disk
++EXPORT_SYMBOL vmlinux 0x718efd3b	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71bd21f1	iput
++EXPORT_SYMBOL vmlinux 0x71c90087	memcmp
++EXPORT_SYMBOL vmlinux 0x71d86b32	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7205a7fd	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x720c72f0	snd_card_free_when_closed
++EXPORT_SYMBOL vmlinux 0x721d3914	fb_set_var
++EXPORT_SYMBOL vmlinux 0x72350130	___ratelimit
++EXPORT_SYMBOL vmlinux 0x729b62a4	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x72c159b3	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72dac3e8	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x72e54959	sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x730cd976	km_state_notify
++EXPORT_SYMBOL vmlinux 0x7315a4e9	twl6030_mmc_card_detect_config
++EXPORT_SYMBOL vmlinux 0x731b81f1	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x73750370	neigh_update
++EXPORT_SYMBOL vmlinux 0x737de5e9	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x737f9ae2	key_task_permission
++EXPORT_SYMBOL vmlinux 0x7382d113	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x7388fe8f	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x738eb500	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0x7390566f	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x73add281	alloc_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0x73b3133a	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x73cac51e	sys_copyarea
++EXPORT_SYMBOL vmlinux 0x73cb7a2d	mmc_resume_host
++EXPORT_SYMBOL vmlinux 0x73d53e2d	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x73d77995	scsi_setup_blk_pc_cmnd
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x73e52ab9	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x73fd93bd	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x746962cb	dquot_release
++EXPORT_SYMBOL vmlinux 0x7469fcfe	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x748dcc92	phy_start
++EXPORT_SYMBOL vmlinux 0x7494cbb3	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74ce05b8	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x74e01e88	genl_notify
++EXPORT_SYMBOL vmlinux 0x74e05323	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x75057c31	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x754dac78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0x755d5049	__bforget
++EXPORT_SYMBOL vmlinux 0x75617e6b	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0x75682678	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0x756fd216	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0x758336d8	deactivate_super
++EXPORT_SYMBOL vmlinux 0x75850d01	__vmalloc
++EXPORT_SYMBOL vmlinux 0x758e73ed	xfrm_cfg_mutex
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75a07ac3	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0x75af32ba	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75fee7fd	__raw_writesb
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x761ffd56	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x7627464b	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x765b7a67	dquot_commit
++EXPORT_SYMBOL vmlinux 0x76798119	dev_warn
++EXPORT_SYMBOL vmlinux 0x7687cdfe	key_unlink
++EXPORT_SYMBOL vmlinux 0x76ab7f8c	misc_deregister
++EXPORT_SYMBOL vmlinux 0x76ae08b0	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x76bf656d	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x76cf47f6	__aeabi_llsl
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x76e0e974	fget_raw
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x7722d141	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x773a9c94	blk_iopoll_enabled
++EXPORT_SYMBOL vmlinux 0x77523c26	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x7787b3be	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x7791193f	icst525_s2div
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77a50702	snd_timer_close
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77ce69eb	request_key_async
++EXPORT_SYMBOL vmlinux 0x77ce93b3	qid_lt
++EXPORT_SYMBOL vmlinux 0x77d7c218	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0x77df0847	__set_personality
++EXPORT_SYMBOL vmlinux 0x77e1429d	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x77ecac9f	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x77fe4cb2	sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x7832c53a	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x7833deb2	pgprot_user
++EXPORT_SYMBOL vmlinux 0x78378abb	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x784a9765	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0x785acbac	dev_set_drvdata
++EXPORT_SYMBOL vmlinux 0x7874d8e7	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x78876d90	pfifo_fast_ops
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x789e0d87	read_code
++EXPORT_SYMBOL vmlinux 0x78bcda7d	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0x78bff910	journal_restart
++EXPORT_SYMBOL vmlinux 0x78d7dd40	registered_fb
++EXPORT_SYMBOL vmlinux 0x78df3102	snd_pcm_lib_readv
++EXPORT_SYMBOL vmlinux 0x7930d225	of_device_is_compatible
++EXPORT_SYMBOL vmlinux 0x7943b7d5	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x79563c01	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x7975fc6c	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x79768c45	dquot_disable
++EXPORT_SYMBOL vmlinux 0x79812692	kthread_bind
++EXPORT_SYMBOL vmlinux 0x799148d7	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79ac065e	generic_show_options
++EXPORT_SYMBOL vmlinux 0x79c94c7d	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0x79d1194f	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0x79f881e1	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x79fd1485	inet_put_port
++EXPORT_SYMBOL vmlinux 0x7a188791	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x7a27c184	ewma_init
++EXPORT_SYMBOL vmlinux 0x7a324673	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a60f3b1	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x7a91726b	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x7aa46090	__f_setown
++EXPORT_SYMBOL vmlinux 0x7aac75fb	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad41bf9	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x7aeb2f5f	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7b03848a	verify_mem_not_deleted
++EXPORT_SYMBOL vmlinux 0x7b0985bc	twl6040_power
++EXPORT_SYMBOL vmlinux 0x7b19c202	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x7b29cca4	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0x7b38281c	snd_register_device_for_dev
++EXPORT_SYMBOL vmlinux 0x7b523377	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b6646bb	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0x7b8ff9d9	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x7b938ba8	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0x7ba1ffba	snd_seq_root
++EXPORT_SYMBOL vmlinux 0x7bc265c0	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x7bc28742	mount_ns
++EXPORT_SYMBOL vmlinux 0x7bfa2fcd	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c16a407	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0x7c2aff08	snd_ctl_remove_id
++EXPORT_SYMBOL vmlinux 0x7c2d59c9	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x7c44a1ba	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0x7c44ea19	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x7c5b5166	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c73c9d2	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x7c7bffe0	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x7c7ce791	block_write_full_page
++EXPORT_SYMBOL vmlinux 0x7c8ef928	bioset_free
++EXPORT_SYMBOL vmlinux 0x7c98845d	twl_i2c_read
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cc035a7	__ucmpdi2
++EXPORT_SYMBOL vmlinux 0x7cc3e819	nand_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x7cc9db69	module_put
++EXPORT_SYMBOL vmlinux 0x7cef9564	twl6030_mmc_card_detect
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d0dd7ad	dma_async_memcpy_buf_to_buf
++EXPORT_SYMBOL vmlinux 0x7d0e3e72	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d1ea59b	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x7d228c47	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x7d2c0224	seq_printf
++EXPORT_SYMBOL vmlinux 0x7d4e2276	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x7d5354df	snd_pcm_open_substream
++EXPORT_SYMBOL vmlinux 0x7d582c23	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0x7d699caa	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x7d901b35	seq_read
++EXPORT_SYMBOL vmlinux 0x7dccc294	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x7de878b1	pm860x_page_bulk_write
++EXPORT_SYMBOL vmlinux 0x7de95769	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7df45195	nonseekable_open
++EXPORT_SYMBOL vmlinux 0x7e0a87c3	__breadahead
++EXPORT_SYMBOL vmlinux 0x7e394c4e	sysctl_local_reserved_ports
++EXPORT_SYMBOL vmlinux 0x7e6e878e	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x7e98d318	vexpress_config_read
++EXPORT_SYMBOL vmlinux 0x7e9efe8e	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x7eaba722	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x7ead817c	__idr_pre_get
++EXPORT_SYMBOL vmlinux 0x7eb22fe2	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0x7ec463d5	snd_pcm_stop
++EXPORT_SYMBOL vmlinux 0x7ef1c6d3	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x7f126ff4	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x7f1dba9b	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0x7f21c57c	d_delete
++EXPORT_SYMBOL vmlinux 0x7f24590c	cpu_tlb
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f5900f7	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x7f63b31e	_memcpy_toio
++EXPORT_SYMBOL vmlinux 0x7f684ff3	dquot_operations
++EXPORT_SYMBOL vmlinux 0x7fa93d9d	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x7fe7b95d	d_rehash
++EXPORT_SYMBOL vmlinux 0x7fed1395	key_alloc
++EXPORT_SYMBOL vmlinux 0x7ff0adf7	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0x800e4ffa	__muldi3
++EXPORT_SYMBOL vmlinux 0x800f6790	key_link
++EXPORT_SYMBOL vmlinux 0x801ffe46	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x8034b6e8	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x80608ef0	nf_log_set
++EXPORT_SYMBOL vmlinux 0x807f9e09	snd_ctl_free_one
++EXPORT_SYMBOL vmlinux 0x80900ec5	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x80a1810f	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x80a5eb61	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0x80ac1d83	build_skb
++EXPORT_SYMBOL vmlinux 0x80bde2a7	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x80f26e6d	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x810b08cc	vfs_mknod
++EXPORT_SYMBOL vmlinux 0x81188b25	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0x813621af	dm_put_device
++EXPORT_SYMBOL vmlinux 0x813755c3	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x81a11e1d	add_disk
++EXPORT_SYMBOL vmlinux 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL vmlinux 0x81b6fcfd	kernel_read
++EXPORT_SYMBOL vmlinux 0x81b71367	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0x81d0f3f9	find_or_create_page
++EXPORT_SYMBOL vmlinux 0x81d10f5f	trace_seq_putc
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e144ca	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x81f91997	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x82002b5d	netdev_info
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x820aac54	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x821886c6	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0x823916e7	dquot_get_dqinfo
++EXPORT_SYMBOL vmlinux 0x824a4367	tmio_core_mmc_pwr
++EXPORT_SYMBOL vmlinux 0x8251bcc3	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x8260686f	bitmap_find_next_zero_area
++EXPORT_SYMBOL vmlinux 0x826a89c7	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0x8271ac64	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0x82741ea9	proc_create_data
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82a9ccd5	free_netdev
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82aedceb	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0x82b424c0	skb_copy_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x82eb6085	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0x82f82aa4	aio_put_req
++EXPORT_SYMBOL vmlinux 0x82fa66df	release_firmware
++EXPORT_SYMBOL vmlinux 0x8320bea8	__umodsi3
++EXPORT_SYMBOL vmlinux 0x83211609	up_write
++EXPORT_SYMBOL vmlinux 0x8343a2d4	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0x83a476ce	bitmap_scnlistprintf
++EXPORT_SYMBOL vmlinux 0x83b1fa8d	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x83ba3714	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x83c8a355	param_set_int
++EXPORT_SYMBOL vmlinux 0x83d13859	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x83e00559	snd_pcm_release_substream
++EXPORT_SYMBOL vmlinux 0x83e8cdb2	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x840e77e6	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x841d9d34	misc_register
++EXPORT_SYMBOL vmlinux 0x8432c579	vlan_untag
++EXPORT_SYMBOL vmlinux 0x843cd3d3	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0x843e3a7b	contig_page_data
++EXPORT_SYMBOL vmlinux 0x8469cfa0	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x846ee685	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0x8479eeba	journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x847e05af	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0x8484a7b5	simple_link
++EXPORT_SYMBOL vmlinux 0x84b183ae	strncmp
++EXPORT_SYMBOL vmlinux 0x84c7d716	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x84d84345	is_bad_inode
++EXPORT_SYMBOL vmlinux 0x84e6bf3b	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x84f8155e	fb_blank
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x85061b76	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x8515a905	nand_bch_correct_data
++EXPORT_SYMBOL vmlinux 0x85219820	__skb_get_rxhash
++EXPORT_SYMBOL vmlinux 0x852e643d	__free_pages
++EXPORT_SYMBOL vmlinux 0x8533c06c	filemap_flush
++EXPORT_SYMBOL vmlinux 0x8549af16	bio_put
++EXPORT_SYMBOL vmlinux 0x855ffe6e	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x8587b1a3	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85c17d3e	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e7deb2	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x860601db	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x86269eed	dev_crit
++EXPORT_SYMBOL vmlinux 0x862d32a0	d_validate
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8675d82e	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x867b7e78	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x86a41001	netdev_printk
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86aa77b0	key_validate
++EXPORT_SYMBOL vmlinux 0x86e2a980	files_lglock
++EXPORT_SYMBOL vmlinux 0x86ead5bf	__destroy_inode
++EXPORT_SYMBOL vmlinux 0x86f2ce88	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0x86f307d3	inet_listen
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x8708ebea	netdev_class_remove_file
++EXPORT_SYMBOL vmlinux 0x870bf928	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x871b308a	give_up_console
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x8746ca9e	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0x8773b0f2	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x877b01b3	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x877bd30c	nand_bch_calculate_ecc
++EXPORT_SYMBOL vmlinux 0x877f5e3a	kunmap_high
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x87936f14	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0x8798e453	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x87b2fdc9	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0x87d42b14	tcp_connect
++EXPORT_SYMBOL vmlinux 0x87f27f28	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x880ce1aa	md_done_sync
++EXPORT_SYMBOL vmlinux 0x881039d0	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x8812d079	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x881f7fc3	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0x8824deba	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x8828e763	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x88322407	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0x8834396c	mod_timer
++EXPORT_SYMBOL vmlinux 0x884596fa	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0x8857c5d0	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0x889ce91d	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x88c30ff3	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x88e4f4b8	nand_lock
++EXPORT_SYMBOL vmlinux 0x88feb57d	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x890dc2ed	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x891b04c1	md_integrity_register
++EXPORT_SYMBOL vmlinux 0x8942ccbe	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0x894c55f3	__sb_start_write
++EXPORT_SYMBOL vmlinux 0x8953eff3	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x8953f8ff	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x8966d0ef	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x897473df	mktime
++EXPORT_SYMBOL vmlinux 0x8986ee63	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x8998c6f9	path_get
++EXPORT_SYMBOL vmlinux 0x89b0bf09	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0x89c16a82	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0x89cb4765	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89d66811	build_ehash_secret
++EXPORT_SYMBOL vmlinux 0x89d993e5	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x89dede07	tty_check_change
++EXPORT_SYMBOL vmlinux 0x89fac49f	set_bh_page
++EXPORT_SYMBOL vmlinux 0x8a00a60d	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0x8a0764e4	__brelse
++EXPORT_SYMBOL vmlinux 0x8a0f4230	rename_lock
++EXPORT_SYMBOL vmlinux 0x8a147a04	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x8a15ce5b	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a3c6a94	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a4fa83b	__aeabi_llsr
++EXPORT_SYMBOL vmlinux 0x8a54d35a	kernel_accept
++EXPORT_SYMBOL vmlinux 0x8a6692e3	of_get_ddr_timings
++EXPORT_SYMBOL vmlinux 0x8a742b95	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a802c89	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x8a819d0c	dentry_open
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8a9bd1e4	mnt_unpin
++EXPORT_SYMBOL vmlinux 0x8aa5d68d	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x8ace8ca3	groups_alloc
++EXPORT_SYMBOL vmlinux 0x8aec5217	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x8b07939d	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x8b1ce2a7	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x8b2c7ce7	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x8b337180	pps_unregister_source
++EXPORT_SYMBOL vmlinux 0x8b38959f	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b4865e7	__generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8ba055a5	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x8ba63968	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x8ba66904	audit_log
++EXPORT_SYMBOL vmlinux 0x8bd0a3fd	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x8bfe8c57	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8c06dd54	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x8c144f08	__lru_cache_add
++EXPORT_SYMBOL vmlinux 0x8c2850ce	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0x8c34c021	end_page_writeback
++EXPORT_SYMBOL vmlinux 0x8c52400d	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c8f0a02	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x8cc36f34	check_disk_change
++EXPORT_SYMBOL vmlinux 0x8cc81325	done_path_create
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8ce4f064	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0x8ce67df1	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0x8cffb17b	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0x8d1ad280	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0x8d1c2f8c	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x8d2f410c	dput
++EXPORT_SYMBOL vmlinux 0x8d3a5300	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0x8d3e0273	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d578600	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x8d5a156f	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x8d5e2111	pid_task
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d7d340b	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x8d7f12b7	set_bdi_congested
++EXPORT_SYMBOL vmlinux 0x8d8b6353	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0x8daa6886	finish_open
++EXPORT_SYMBOL vmlinux 0x8dd0729c	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x8dd4c356	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8dd8443f	__dst_free
++EXPORT_SYMBOL vmlinux 0x8de9cdba	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x8df25cc3	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0x8e022dc6	get_super
++EXPORT_SYMBOL vmlinux 0x8e0d66f4	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x8e18bff1	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x8e1e4fe6	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x8e28cd42	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x8e2b826c	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x8e409e35	snd_ctl_find_id
++EXPORT_SYMBOL vmlinux 0x8e553ef6	kfree_skb
++EXPORT_SYMBOL vmlinux 0x8e56dfeb	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x8e5c580a	ida_init
++EXPORT_SYMBOL vmlinux 0x8e5ca006	task_nice
++EXPORT_SYMBOL vmlinux 0x8e865d3c	arm_delay_ops
++EXPORT_SYMBOL vmlinux 0x8e8bf0be	__napi_complete
++EXPORT_SYMBOL vmlinux 0x8e9b8b43	tty_lock
++EXPORT_SYMBOL vmlinux 0x8f045d1c	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x8f0ce7ab	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x8f3eec5e	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x8f4fc5dd	iunique
++EXPORT_SYMBOL vmlinux 0x8f595b11	snd_major
++EXPORT_SYMBOL vmlinux 0x8f628b94	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0x8f678b07	__stack_chk_guard
++EXPORT_SYMBOL vmlinux 0x8f693523	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0x8f7014a1	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x8f7bfd7f	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL vmlinux 0x8f9acc23	blk_put_request
++EXPORT_SYMBOL vmlinux 0x8faa4598	of_translate_address
++EXPORT_SYMBOL vmlinux 0x8fce51f6	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x8fd4c8a4	tcp_syn_flood_action
++EXPORT_SYMBOL vmlinux 0x8ff931e4	km_report
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x901b6926	snd_ctl_find_numid
++EXPORT_SYMBOL vmlinux 0x901cc2b0	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x902be503	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0x902c75eb	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x9030bb00	of_platform_bus_probe
++EXPORT_SYMBOL vmlinux 0x906f749f	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL vmlinux 0x90a33a6f	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0x90ac3102	dev_base_lock
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90f6d905	generic_write_sync
++EXPORT_SYMBOL vmlinux 0x90fc34a7	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x9101c347	inet6_getname
++EXPORT_SYMBOL vmlinux 0x9135f508	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0x91402bca	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x914060ea	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x9152875f	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x916bfdc0	set_user_nice
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x918c7b5e	phy_find_first
++EXPORT_SYMBOL vmlinux 0x918ec380	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0x919029aa	__readwrite_bug
++EXPORT_SYMBOL vmlinux 0x91aec064	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x91c06510	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x91c0980e	icst_hz
++EXPORT_SYMBOL vmlinux 0x91cd0ce0	dget_parent
++EXPORT_SYMBOL vmlinux 0x91d3ee66	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x91edddd7	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0x9205953f	send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x920eb90c	interruptible_sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x9221f3bc	dquot_enable
++EXPORT_SYMBOL vmlinux 0x92224a15	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x9227ddc1	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x924922d1	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x92498021	snd_timer_continue
++EXPORT_SYMBOL vmlinux 0x92562c25	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x925f9ed1	inet6_bind
++EXPORT_SYMBOL vmlinux 0x92725671	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0x9277030b	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x92982e9a	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x929dedcf	amba_find_device
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92b74677	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x92b8ad9c	kill_fasync
++EXPORT_SYMBOL vmlinux 0x92c60ef7	netdev_alert
++EXPORT_SYMBOL vmlinux 0x92d6c57f	fget_light
++EXPORT_SYMBOL vmlinux 0x92e92d1d	snd_power_wait
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x93236a67	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x9329fe04	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x9335b2bc	journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x9361e2d9	netpoll_rx_disable
++EXPORT_SYMBOL vmlinux 0x93a11725	phy_device_create
++EXPORT_SYMBOL vmlinux 0x93a6e0b2	io_schedule
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93b5dead	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x93c28ebf	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x93d70857	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x93d78c45	skb_split
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x94054687	tty_free_termios
++EXPORT_SYMBOL vmlinux 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL vmlinux 0x942f8d09	simple_write_end
++EXPORT_SYMBOL vmlinux 0x943021d4	input_free_device
++EXPORT_SYMBOL vmlinux 0x9431383d	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x944e8d79	fb_class
++EXPORT_SYMBOL vmlinux 0x947cd3ed	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x94988490	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x94c5fbf6	fget
++EXPORT_SYMBOL vmlinux 0x94c99a7d	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x94d3da68	rtc_lock
++EXPORT_SYMBOL vmlinux 0x94fffbd4	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x95102cad	d_genocide
++EXPORT_SYMBOL vmlinux 0x954488a4	syncookie_secret
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x9554b64e	set_security_override
++EXPORT_SYMBOL vmlinux 0x9555d31b	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0x95622f41	down_timeout
++EXPORT_SYMBOL vmlinux 0x9576c892	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x9580dc1c	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x9586c1b0	put_disk
++EXPORT_SYMBOL vmlinux 0x959b5b35	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x95a5d746	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x95cb929c	of_find_all_nodes
++EXPORT_SYMBOL vmlinux 0x95dbe078	__get_user_2
++EXPORT_SYMBOL vmlinux 0x95e1f29c	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0x95e6e500	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x95ef80e4	snd_info_create_module_entry
++EXPORT_SYMBOL vmlinux 0x95f10fe0	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x9613509a	idr_replace
++EXPORT_SYMBOL vmlinux 0x9622a135	journal_clear_err
++EXPORT_SYMBOL vmlinux 0x9641548f	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x9686d981	proc_remove
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x969d7e7c	snd_pcm_set_sync
++EXPORT_SYMBOL vmlinux 0x96a3f76a	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x96c54adf	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96fdeac2	set_blocksize
++EXPORT_SYMBOL vmlinux 0x9705a413	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x97255bdf	strlen
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x976e700f	down_trylock
++EXPORT_SYMBOL vmlinux 0x976fb6a4	snd_ctl_replace
++EXPORT_SYMBOL vmlinux 0x9782dba8	secpath_dup
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x97b4500c	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x97ba26ca	user_path_at
++EXPORT_SYMBOL vmlinux 0x97d08592	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0x97fe2e3c	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL vmlinux 0x97ff288e	__put_cred
++EXPORT_SYMBOL vmlinux 0x98082893	__copy_to_user
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x9828f799	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0x983d072c	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x98481ef8	lro_receive_frags
++EXPORT_SYMBOL vmlinux 0x98622756	module_refcount
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x98774534	bdi_unregister
++EXPORT_SYMBOL vmlinux 0x988aefd8	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0x988cb182	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x98a6517f	keyring_search
++EXPORT_SYMBOL vmlinux 0x98bd36c4	__mem_cgroup_count_vm_event
++EXPORT_SYMBOL vmlinux 0x98bfbf21	mount_single
++EXPORT_SYMBOL vmlinux 0x98cb498a	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x98d0931f	dump_seek
++EXPORT_SYMBOL vmlinux 0x98f557a5	snd_card_unref
++EXPORT_SYMBOL vmlinux 0x98fa21b0	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x991b93f4	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x993abb01	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x994223c2	igrab
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x9958555f	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x996c4d30	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999a3c49	cookie_check_timestamp
++EXPORT_SYMBOL vmlinux 0x999c3148	__raw_readsb
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99b3b101	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x99bb8806	memmove
++EXPORT_SYMBOL vmlinux 0x99caf6f6	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x99cb920c	eth_header
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x99d5a4e3	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0x99f58330	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x99fc143d	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x9a0f8208	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x9a13f18c	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL vmlinux 0x9a1568f6	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a2cdcb0	set_device_ro
++EXPORT_SYMBOL vmlinux 0x9a3e1414	send_sig
++EXPORT_SYMBOL vmlinux 0x9a459b11	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0x9a6293fe	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x9a656198	input_inject_event
++EXPORT_SYMBOL vmlinux 0x9a6e183a	__idr_remove_all
++EXPORT_SYMBOL vmlinux 0x9a8318ef	v7_coherent_kern_range
++EXPORT_SYMBOL vmlinux 0x9a924376	nand_scan_ident
++EXPORT_SYMBOL vmlinux 0x9a968bd7	arm_coherent_dma_ops
++EXPORT_SYMBOL vmlinux 0x9ab316f7	seq_lseek
++EXPORT_SYMBOL vmlinux 0x9abb1900	tty_pair_get_tty
++EXPORT_SYMBOL vmlinux 0x9ac547d7	dquot_resume
++EXPORT_SYMBOL vmlinux 0x9ace3498	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x9afb0d76	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b61dd91	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b8f01fe	bio_map_user
++EXPORT_SYMBOL vmlinux 0x9b9c7bfa	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9bacdf7b	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x9bb53033	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x9bbfdced	single_open_size
++EXPORT_SYMBOL vmlinux 0x9bc7a5c3	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x9bdd110a	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c082934	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x9c0bd51f	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x9c2481f0	__bio_clone
++EXPORT_SYMBOL vmlinux 0x9c251420	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x9c2fcec9	md_write_start
++EXPORT_SYMBOL vmlinux 0x9c3737fc	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x9c4b5092	dma_find_channel
++EXPORT_SYMBOL vmlinux 0x9c54b401	generic_pipe_buf_unmap
++EXPORT_SYMBOL vmlinux 0x9c589423	stop_tty
++EXPORT_SYMBOL vmlinux 0x9c6ced74	tty_pair_get_pty
++EXPORT_SYMBOL vmlinux 0x9c837591	snd_device_register
++EXPORT_SYMBOL vmlinux 0x9c9ec2a0	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0x9c9f1a7d	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9cb491bf	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x9cbafd27	filp_close
++EXPORT_SYMBOL vmlinux 0x9cc7b9a2	dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x9cd0a750	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0x9ce106ae	tc6393xb_lcd_mode
++EXPORT_SYMBOL vmlinux 0x9ce9dd3f	sock_edemux
++EXPORT_SYMBOL vmlinux 0x9ceb163c	memcpy_toiovec
++EXPORT_SYMBOL vmlinux 0x9cfd56c5	scsi_print_status
++EXPORT_SYMBOL vmlinux 0x9d003ea6	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x9d05f6c4	ktime_get_clocktai
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d4fb6e2	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x9d669763	memcpy
++EXPORT_SYMBOL vmlinux 0x9d7aeab6	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x9da191e6	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x9da6f6a9	journal_forget
++EXPORT_SYMBOL vmlinux 0x9db24f26	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x9db48840	may_umount
++EXPORT_SYMBOL vmlinux 0x9dd7d1c1	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x9debce74	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0x9df81757	mount_nodev
++EXPORT_SYMBOL vmlinux 0x9e012831	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x9e08b6e3	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e2000a7	memcpy_toiovecend
++EXPORT_SYMBOL vmlinux 0x9e23ac3e	scsi_free_command
++EXPORT_SYMBOL vmlinux 0x9e3374ba	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x9e44b2b8	generic_setxattr
++EXPORT_SYMBOL vmlinux 0x9e44b9b7	of_get_next_available_child
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e6b3c8b	led_set_brightness
++EXPORT_SYMBOL vmlinux 0x9e6bf625	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL vmlinux 0x9e7d0239	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x9e80c677	snd_card_proc_new
++EXPORT_SYMBOL vmlinux 0x9e9f1714	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0x9eb6a45c	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0x9eb9288b	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ecb21b0	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x9ecc6a7a	interruptible_sleep_on
++EXPORT_SYMBOL vmlinux 0x9ece870c	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x9ed685ee	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x9ef0e9cf	kernel_bind
++EXPORT_SYMBOL vmlinux 0x9f2bdaac	__bitmap_or
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f491e5d	ftrace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x9f4bde7f	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x9f4ff6fa	keyring_clear
++EXPORT_SYMBOL vmlinux 0x9f6104b5	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0x9f8efc49	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x9f939127	skb_copy_datagram_const_iovec
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fa40519	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x9fb3dd30	memcpy_fromiovec
++EXPORT_SYMBOL vmlinux 0x9fd4e28b	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x9fdc6546	block_commit_write
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9fe47ac5	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa01fe263	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0xa021f29f	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xa03e6c0a	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa067d91e	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0c93489	__seq_open_private
++EXPORT_SYMBOL vmlinux 0xa0ceef51	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xa0da3dbc	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xa0dfdeac	mdiobus_register
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa10f0e06	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa13e5c71	neigh_lookup
++EXPORT_SYMBOL vmlinux 0xa1415618	twl6030_interrupt_unmask
++EXPORT_SYMBOL vmlinux 0xa14f3d8c	ewma_add
++EXPORT_SYMBOL vmlinux 0xa161ccab	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xa1804bdf	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1d55e90	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xa1e4d1b1	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0xa1f0ebea	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0xa1f9bc5c	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xa20845d1	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0xa2099e8a	skb_push
++EXPORT_SYMBOL vmlinux 0xa20ce1b8	net_msg_warn
++EXPORT_SYMBOL vmlinux 0xa2383749	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xa239731b	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0xa2506271	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0xa250c838	param_get_charp
++EXPORT_SYMBOL vmlinux 0xa267841b	address_space_init_once
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa294a917	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xa2a5fd77	inet_ehash_secret
++EXPORT_SYMBOL vmlinux 0xa2a90b71	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xa2b18e47	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0xa2bfc5f2	d_instantiate
++EXPORT_SYMBOL vmlinux 0xa2ce2bd9	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0xa2da0b56	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xa2ef34d7	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xa32caef8	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xa32db7ce	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL vmlinux 0xa33a7b99	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xa34f1ef5	crc32_le
++EXPORT_SYMBOL vmlinux 0xa35de80f	ipv4_config
++EXPORT_SYMBOL vmlinux 0xa37afa9b	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0xa381944f	dql_reset
++EXPORT_SYMBOL vmlinux 0xa3820900	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0xa382b8e8	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0xa38345de	sg_last
++EXPORT_SYMBOL vmlinux 0xa392c1e7	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0xa3b6aa21	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xa3dd3254	bio_copy_user
++EXPORT_SYMBOL vmlinux 0xa3f35bf5	rwsem_is_locked
++EXPORT_SYMBOL vmlinux 0xa40a2d36	sock_no_connect
++EXPORT_SYMBOL vmlinux 0xa414882d	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0xa42891ad	netdev_state_change
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa43b9539	memcpy_fromiovecend
++EXPORT_SYMBOL vmlinux 0xa447ccef	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0xa44c2429	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0xa4592203	iget_failed
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa487e42f	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0xa49e49b7	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0xa4a2b4d7	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xa4cb0e1c	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0xa4d8775f	arp_create
++EXPORT_SYMBOL vmlinux 0xa4e22d4c	ata_link_printk
++EXPORT_SYMBOL vmlinux 0xa4f6b037	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xa50a111e	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xa5114d74	simple_release_fs
++EXPORT_SYMBOL vmlinux 0xa511c540	udp_disconnect
++EXPORT_SYMBOL vmlinux 0xa545b6fe	d_set_d_op
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa55afd63	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0xa5722c7a	block_write_full_page_endio
++EXPORT_SYMBOL vmlinux 0xa577a850	param_get_short
++EXPORT_SYMBOL vmlinux 0xa57e22f9	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0xa58f8599	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0xa58fea9d	mempool_destroy
++EXPORT_SYMBOL vmlinux 0xa594e469	snd_pcm_new_internal
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa59d3091	dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0xa5b106ef	sys_fillrect
++EXPORT_SYMBOL vmlinux 0xa5b23fa2	generic_file_aio_read
++EXPORT_SYMBOL vmlinux 0xa5b55830	sget
++EXPORT_SYMBOL vmlinux 0xa5c401c4	get_user_pages
++EXPORT_SYMBOL vmlinux 0xa5c9a890	__get_page_tail
++EXPORT_SYMBOL vmlinux 0xa5ca59e7	follow_down
++EXPORT_SYMBOL vmlinux 0xa5cbe549	aio_complete
++EXPORT_SYMBOL vmlinux 0xa5cd43b7	blk_peek_request
++EXPORT_SYMBOL vmlinux 0xa5cda490	blkdev_put
++EXPORT_SYMBOL vmlinux 0xa5d5b8df	dev_get_drvdata
++EXPORT_SYMBOL vmlinux 0xa5dcdeb2	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0xa5dd45f3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xa5f16e13	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL vmlinux 0xa5fd3f58	genphy_update_link
++EXPORT_SYMBOL vmlinux 0xa61a1e3e	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL vmlinux 0xa61eb459	snd_timer_new
++EXPORT_SYMBOL vmlinux 0xa62359ba	nand_scan_tail
++EXPORT_SYMBOL vmlinux 0xa636aa99	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa64a4cea	usb_nop_xceiv_unregister
++EXPORT_SYMBOL vmlinux 0xa66e1513	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xa6715115	do_settimeofday
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa68584e1	bio_map_kern
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa69f145f	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0xa6acd6ae	__alloc_skb
++EXPORT_SYMBOL vmlinux 0xa6ae5793	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xa6bab23d	dqstats
++EXPORT_SYMBOL vmlinux 0xa6cc1fa3	snd_pcm_hw_param_first
++EXPORT_SYMBOL vmlinux 0xa6f3053f	mddev_congested
++EXPORT_SYMBOL vmlinux 0xa6f66335	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xa6ff555d	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0xa734a3e9	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa73cd1a1	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xa73fc98f	of_n_addr_cells
++EXPORT_SYMBOL vmlinux 0xa753e904	find_get_page
++EXPORT_SYMBOL vmlinux 0xa760555f	generic_listxattr
++EXPORT_SYMBOL vmlinux 0xa76217f2	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xa7681b1a	thaw_super
++EXPORT_SYMBOL vmlinux 0xa768f8fc	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0xa77a369d	idr_init
++EXPORT_SYMBOL vmlinux 0xa7a009c8	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0xa7bc406a	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xa7c1728f	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0xa7cf9e69	__genl_register_family
++EXPORT_SYMBOL vmlinux 0xa7ec8dfd	unregister_exec_domain
++EXPORT_SYMBOL vmlinux 0xa808bcb8	vexpress_config_wait
++EXPORT_SYMBOL vmlinux 0xa80fe4f4	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0xa8232c78	strtobool
++EXPORT_SYMBOL vmlinux 0xa8275a70	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0xa8315fb0	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa85c76ad	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa880c620	ilookup
++EXPORT_SYMBOL vmlinux 0xa8856e29	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xa888cfb7	f_setown
++EXPORT_SYMBOL vmlinux 0xa88a5b92	lock_may_read
++EXPORT_SYMBOL vmlinux 0xa8a6f639	__check_region
++EXPORT_SYMBOL vmlinux 0xa8bba0ee	journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xa8c54f05	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0xa8c55b23	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0xa8fc0f5f	snd_ctl_rename_id
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa90e3e65	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0xa9268d8c	mmc_gpio_free_cd
++EXPORT_SYMBOL vmlinux 0xa980e64d	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xa981a9e8	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0xa994c642	padata_free
++EXPORT_SYMBOL vmlinux 0xa9af6497	mpage_readpage
++EXPORT_SYMBOL vmlinux 0xa9b0977f	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0xa9d7217a	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0xa9e7c3f4	kill_bdev
++EXPORT_SYMBOL vmlinux 0xa9ecab8a	do_map_probe
++EXPORT_SYMBOL vmlinux 0xa9effda5	__first_cpu
++EXPORT_SYMBOL vmlinux 0xa9f68808	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xaa095f29	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xaa0f437e	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0xaa251de3	console_stop
++EXPORT_SYMBOL vmlinux 0xaa2941ef	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0xaa30beec	ioremap_page
++EXPORT_SYMBOL vmlinux 0xaa473c78	generic_setlease
++EXPORT_SYMBOL vmlinux 0xaa52c98c	clear_bdi_congested
++EXPORT_SYMBOL vmlinux 0xaa5e2a0d	vm_event_states
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa79b824	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0xaa9f822d	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xaab4078a	serio_close
++EXPORT_SYMBOL vmlinux 0xaacc26ff	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaad9c35a	snd_pcm_suspend
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xab068e64	scsi_register
++EXPORT_SYMBOL vmlinux 0xab1d6cc1	param_get_long
++EXPORT_SYMBOL vmlinux 0xab22b304	sock_create_kern
++EXPORT_SYMBOL vmlinux 0xab247535	snd_timer_interrupt
++EXPORT_SYMBOL vmlinux 0xab2616a7	pipe_to_file
++EXPORT_SYMBOL vmlinux 0xab5b115b	init_task
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab682ac4	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab74087e	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xab97295c	tty_register_device
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd0c91c	rtc_time_to_tm
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1b0790	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xac3c095e	sg_nents
++EXPORT_SYMBOL vmlinux 0xac4e9416	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0xac67ef93	page_symlink
++EXPORT_SYMBOL vmlinux 0xac792f3e	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xac80717d	flush_kernel_dcache_page
++EXPORT_SYMBOL vmlinux 0xac8f37b2	outer_cache
++EXPORT_SYMBOL vmlinux 0xac99d00d	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacad21c7	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0xacb55e0a	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0xacc8eefd	bio_flush_dcache_pages
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacf87ed1	iov_iter_copy_from_user
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad06f045	ihold
++EXPORT_SYMBOL vmlinux 0xad07923d	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xad0e276d	snd_device_free
++EXPORT_SYMBOL vmlinux 0xad18912a	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0xad384735	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xad3ae637	__skb_dst_set_noref
++EXPORT_SYMBOL vmlinux 0xad46dec2	of_count_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xad8edefa	tty_kref_put
++EXPORT_SYMBOL vmlinux 0xad9d6e19	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0xadb5559d	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xadca6c3f	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0xadcf74fd	submit_bh
++EXPORT_SYMBOL vmlinux 0xadd2b333	inet_release
++EXPORT_SYMBOL vmlinux 0xadddeaa0	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xade28bd0	of_phy_connect
++EXPORT_SYMBOL vmlinux 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL vmlinux 0xadfbf1dd	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xae3eb2e0	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xae5a5a19	set_groups
++EXPORT_SYMBOL vmlinux 0xae729e59	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0xae8dc3b6	snd_pcm_hw_refine
++EXPORT_SYMBOL vmlinux 0xae9bbc54	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaeefbeed	kset_unregister
++EXPORT_SYMBOL vmlinux 0xaf05b91b	of_device_is_available
++EXPORT_SYMBOL vmlinux 0xaf13611c	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf50e76d	elf_set_personality
++EXPORT_SYMBOL vmlinux 0xaf5dd8d5	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xaf8aa518	system_rev
++EXPORT_SYMBOL vmlinux 0xaf91d89f	__kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xafb185b8	journal_init_inode
++EXPORT_SYMBOL vmlinux 0xaff866c1	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xb01b298e	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0xb047bb09	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0xb04cf0fe	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb063c46b	tcp_valid_rtt_meas
++EXPORT_SYMBOL vmlinux 0xb082dd88	register_exec_domain
++EXPORT_SYMBOL vmlinux 0xb09133fb	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0xb094691b	get_gendisk
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b3a7fb	security_file_permission
++EXPORT_SYMBOL vmlinux 0xb0b847ac	__bitmap_full
++EXPORT_SYMBOL vmlinux 0xb0bca0b8	journal_abort
++EXPORT_SYMBOL vmlinux 0xb0c37e22	journal_update_format
++EXPORT_SYMBOL vmlinux 0xb0c818d0	sk_filter
++EXPORT_SYMBOL vmlinux 0xb0c9659e	security_path_chmod
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ffda2f	blk_limits_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb104acf9	bdevname
++EXPORT_SYMBOL vmlinux 0xb1198567	dentry_unhash
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb130ce56	snd_timer_notify
++EXPORT_SYMBOL vmlinux 0xb137cf83	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0xb143c3d1	tty_unlock
++EXPORT_SYMBOL vmlinux 0xb154ea94	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xb156809f	bio_integrity_split
++EXPORT_SYMBOL vmlinux 0xb162ddeb	skb_pad
++EXPORT_SYMBOL vmlinux 0xb19760c3	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xb19810b5	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0xb1b0b39f	uart_register_driver
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1c67418	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1d9aabd	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xb1e6e49d	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xb1f172f4	udp_prot
++EXPORT_SYMBOL vmlinux 0xb241aa25	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL vmlinux 0xb25dc3ce	kunmap
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb2891dce	scsi_calculate_bounce_limit
++EXPORT_SYMBOL vmlinux 0xb28b7484	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0xb292e059	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0xb2a58d9b	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0xb2afaf37	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xb2b94674	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c1727e	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xb2d307de	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2d4b1a8	arm_dma_zone_size
++EXPORT_SYMBOL vmlinux 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL vmlinux 0xb3317859	generic_readlink
++EXPORT_SYMBOL vmlinux 0xb34863cd	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xb35117ea	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0xb35505b1	have_submounts
++EXPORT_SYMBOL vmlinux 0xb3c33ac0	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0xb3c561fc	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0xb3dcb9e9	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0xb3dcf8b6	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0xb3e0bb21	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb3fba461	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0xb4199a3b	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0xb419bae8	blk_free_tags
++EXPORT_SYMBOL vmlinux 0xb4207748	dcache_readdir
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb4586a2c	genphy_resume
++EXPORT_SYMBOL vmlinux 0xb45c6659	serio_open
++EXPORT_SYMBOL vmlinux 0xb469f5a1	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0xb46a24ab	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xb46c92a6	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4881555	md_flush_request
++EXPORT_SYMBOL vmlinux 0xb49b152c	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL vmlinux 0xb4fd8db9	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0xb510bf34	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0xb531f29f	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0xb534c001	nand_default_bbt
++EXPORT_SYMBOL vmlinux 0xb54088a3	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0xb54533f7	usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xb54a0e67	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xb5582f6b	override_creds
++EXPORT_SYMBOL vmlinux 0xb55f56e7	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0xb5614e9c	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5cd1691	vexpress_config_complete
++EXPORT_SYMBOL vmlinux 0xb5d9454c	printk_emit
++EXPORT_SYMBOL vmlinux 0xb5f13730	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0xb601048a	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0xb61325bd	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0xb641549c	freeze_super
++EXPORT_SYMBOL vmlinux 0xb6677295	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xb66adf37	dev_activate
++EXPORT_SYMBOL vmlinux 0xb67566b0	tc6393xb_lcd_set_power
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6822a33	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb68ebde2	snd_info_free_entry
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a1e6b6	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6b2b5d9	ping_prot
++EXPORT_SYMBOL vmlinux 0xb6c5a973	scsi_show_result
++EXPORT_SYMBOL vmlinux 0xb6df5b50	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0xb6f79a91	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xb7052ccf	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0xb71fb74f	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0xb7647bd8	snd_timer_open
++EXPORT_SYMBOL vmlinux 0xb768c712	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xb76b6620	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0xb76de85a	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0xb78fe862	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xb79b30e0	setup_new_exec
++EXPORT_SYMBOL vmlinux 0xb7a5f016	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xb7b61546	crc32_be
++EXPORT_SYMBOL vmlinux 0xb7ba76c7	__aeabi_unwind_cpp_pr2
++EXPORT_SYMBOL vmlinux 0xb7c1cdb9	seq_open_private
++EXPORT_SYMBOL vmlinux 0xb7d2b53b	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0xb7faf62d	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0xb803bef1	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb834c403	__inode_permission
++EXPORT_SYMBOL vmlinux 0xb835b3e4	radix_tree_prev_hole
++EXPORT_SYMBOL vmlinux 0xb838060b	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0xb84753fb	d_add_ci
++EXPORT_SYMBOL vmlinux 0xb84bdf26	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0xb85d0b28	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb8799ad1	journal_init_dev
++EXPORT_SYMBOL vmlinux 0xb881d5f4	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0xb888fbd3	splice_from_pipe_feed
++EXPORT_SYMBOL vmlinux 0xb8897694	genl_register_ops
++EXPORT_SYMBOL vmlinux 0xb8b4b11d	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xb8b7b9aa	dst_destroy
++EXPORT_SYMBOL vmlinux 0xb8b8948d	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0xb8b8b22c	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0xb8ce60e7	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8f4c88d	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xb8fc3115	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0xb90b1f18	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0xb91a6d8a	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xb928c2fb	finish_no_open
++EXPORT_SYMBOL vmlinux 0xb93dc165	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xb95f98d6	_memset_io
++EXPORT_SYMBOL vmlinux 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL vmlinux 0xb979a3a3	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xb98a0185	rtc_tm_to_time
++EXPORT_SYMBOL vmlinux 0xb9933bf5	ptp_clock_index
++EXPORT_SYMBOL vmlinux 0xb9a99551	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0xb9acd3d9	__put_user_2
++EXPORT_SYMBOL vmlinux 0xb9af6c51	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xb9dcf5f6	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0xb9f8ab9e	scsi_adjust_queue_depth
++EXPORT_SYMBOL vmlinux 0xb9fa557b	mtd_concat_create
++EXPORT_SYMBOL vmlinux 0xba2bfa89	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4b03e2	generic_file_open
++EXPORT_SYMBOL vmlinux 0xba502c18	__sock_create
++EXPORT_SYMBOL vmlinux 0xba59cd7c	generic_write_end
++EXPORT_SYMBOL vmlinux 0xba8d1b43	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0xbaa03e79	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xbaeffa05	qid_eq
++EXPORT_SYMBOL vmlinux 0xbaf9da9c	__getblk
++EXPORT_SYMBOL vmlinux 0xbb103629	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0xbb10cd18	tcp_gro_receive
++EXPORT_SYMBOL vmlinux 0xbb189cad	disallow_signal
++EXPORT_SYMBOL vmlinux 0xbb3068b0	snd_ctl_notify
++EXPORT_SYMBOL vmlinux 0xbb4a91bf	unlock_rename
++EXPORT_SYMBOL vmlinux 0xbb556d40	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb713e6d	sk_filter_release_rcu
++EXPORT_SYMBOL vmlinux 0xbb72b937	km_state_expired
++EXPORT_SYMBOL vmlinux 0xbb72d4fe	__put_user_1
++EXPORT_SYMBOL vmlinux 0xbb85367a	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbae00ab	__get_user_pages
++EXPORT_SYMBOL vmlinux 0xbbbc7088	bio_integrity_tag_size
++EXPORT_SYMBOL vmlinux 0xbbdebcf4	tty_vhangup
++EXPORT_SYMBOL vmlinux 0xbc10dd97	__put_user_4
++EXPORT_SYMBOL vmlinux 0xbc13c92e	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xbc144eb4	md_error
++EXPORT_SYMBOL vmlinux 0xbc253648	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xbc39c2e5	skb_insert
++EXPORT_SYMBOL vmlinux 0xbc8800ff	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xbcab0bd7	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xbcb454e2	snd_info_create_card_entry
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbcd3a605	of_platform_device_create
++EXPORT_SYMBOL vmlinux 0xbcdedba7	of_get_mac_address
++EXPORT_SYMBOL vmlinux 0xbce6bb39	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0xbce6e680	dm_io
++EXPORT_SYMBOL vmlinux 0xbd167943	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0xbd2ca129	snd_timer_global_free
++EXPORT_SYMBOL vmlinux 0xbd46570f	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xbd5b4061	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xbd63cbbd	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0xbd96c85a	vexpress_config_write
++EXPORT_SYMBOL vmlinux 0xbdba9828	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xbdbbe68f	single_release
++EXPORT_SYMBOL vmlinux 0xbdc8f5d4	phy_scan_fixups
++EXPORT_SYMBOL vmlinux 0xbdf2580d	__raw_readsl
++EXPORT_SYMBOL vmlinux 0xbdf57d0a	mount_bdev
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe238ec5	register_qdisc
++EXPORT_SYMBOL vmlinux 0xbe254e92	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xbe2c0274	add_timer
++EXPORT_SYMBOL vmlinux 0xbe517038	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xbe788e2c	fail_migrate_page
++EXPORT_SYMBOL vmlinux 0xbe7c4025	snd_jack_set_key
++EXPORT_SYMBOL vmlinux 0xbe9ee512	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xbec25473	of_parse_phandle
++EXPORT_SYMBOL vmlinux 0xbec593f1	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf105dfa	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xbf1300cf	mb_cache_create
++EXPORT_SYMBOL vmlinux 0xbf18cdf9	netif_rx
++EXPORT_SYMBOL vmlinux 0xbf215158	skb_seq_read
++EXPORT_SYMBOL vmlinux 0xbf3e6e15	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0xbf5e5fae	journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xbf668950	dm_get_device
++EXPORT_SYMBOL vmlinux 0xbf77f703	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0xbf7ba49e	vfs_link
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8666f2	bio_integrity_set_tag
++EXPORT_SYMBOL vmlinux 0xbf8ba54a	vprintk
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfbda65e	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xbfc407b4	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfc95463	key_put
++EXPORT_SYMBOL vmlinux 0xbfcfefe2	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0xbfdcd71c	snd_card_create
++EXPORT_SYMBOL vmlinux 0xbfdfb54f	kset_register
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc0010120	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0xc0110661	generic_file_remap_pages
++EXPORT_SYMBOL vmlinux 0xc02921be	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0xc02cf69b	clkdev_drop
++EXPORT_SYMBOL vmlinux 0xc03054a8	scsi_unregister
++EXPORT_SYMBOL vmlinux 0xc03ed63c	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0xc06278d6	__invalidate_device
++EXPORT_SYMBOL vmlinux 0xc066ec72	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc0823e4c	twl_i2c_write
++EXPORT_SYMBOL vmlinux 0xc082469a	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0xc0a11ed0	skb_copy
++EXPORT_SYMBOL vmlinux 0xc0a98385	profile_pc
++EXPORT_SYMBOL vmlinux 0xc0c6b548	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xc0e1e7ef	do_sync_write
++EXPORT_SYMBOL vmlinux 0xc0f6eef2	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0xc0ff98b6	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0xc1004a16	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc129285b	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xc12ec3a6	dns_query
++EXPORT_SYMBOL vmlinux 0xc14e7262	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xc191a4ad	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0xc1953c49	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xc1b1c938	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0xc1baa94d	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xc1c2dd09	__hw_addr_flush
++EXPORT_SYMBOL vmlinux 0xc1ea93f6	devm_clk_get
++EXPORT_SYMBOL vmlinux 0xc21435d1	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0xc2165d85	__arm_iounmap
++EXPORT_SYMBOL vmlinux 0xc221078a	prepare_creds
++EXPORT_SYMBOL vmlinux 0xc22b50ad	param_set_bint
++EXPORT_SYMBOL vmlinux 0xc256e762	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xc2790961	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0xc2888d4d	skb_copy_datagram_from_iovec
++EXPORT_SYMBOL vmlinux 0xc2940f64	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xc2a27303	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0xc2a5149e	of_device_alloc
++EXPORT_SYMBOL vmlinux 0xc2baccf8	inet_bind
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2e7ec2b	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xc2f9c045	timespec_to_jiffies
++EXPORT_SYMBOL vmlinux 0xc3134ef7	nobh_write_end
++EXPORT_SYMBOL vmlinux 0xc359fb65	abort
++EXPORT_SYMBOL vmlinux 0xc35d29ee	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0xc36d24c5	blk_get_backing_dev_info
++EXPORT_SYMBOL vmlinux 0xc392ea2d	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0xc39302f0	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xc411cf1a	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0xc41599a3	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc4401950	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xc4683aee	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0xc4941c81	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4e3f35a	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xc52c713d	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0xc571656a	__inet6_hash
++EXPORT_SYMBOL vmlinux 0xc5a54a7b	fd_install
++EXPORT_SYMBOL vmlinux 0xc5a78f31	proto_register
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc6014e58	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc64e5b9a	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xc6568943	amba_driver_unregister
++EXPORT_SYMBOL vmlinux 0xc665d6d7	of_parse_phandle_with_args
++EXPORT_SYMBOL vmlinux 0xc6897819	skb_pull
++EXPORT_SYMBOL vmlinux 0xc68df1a3	netdev_err
++EXPORT_SYMBOL vmlinux 0xc6adf857	lock_may_write
++EXPORT_SYMBOL vmlinux 0xc6b23ae8	get_phy_device
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6d16cab	dm_register_target
++EXPORT_SYMBOL vmlinux 0xc6eff169	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0xc70213fd	register_md_personality
++EXPORT_SYMBOL vmlinux 0xc702156b	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xc70e01fd	elv_abort_queue
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc748f823	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc78333d3	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79abfe6	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc7a48279	try_module_get
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7bcbc8d	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xc7d3ccab	of_find_i2c_adapter_by_node
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc7ee7689	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0xc7f749a5	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0xc7f8b0c2	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0xc80f4af2	ppp_input
++EXPORT_SYMBOL vmlinux 0xc816cf0f	snd_card_file_add
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc83652a7	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xc83ecc80	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc84b87e8	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0xc84fdc7d	dquot_alloc
++EXPORT_SYMBOL vmlinux 0xc8793956	journal_dirty_data
++EXPORT_SYMBOL vmlinux 0xc87c9e2a	journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xc8847468	amba_release_regions
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8cfc985	tcf_generic_walker
++EXPORT_SYMBOL vmlinux 0xc8d90398	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0xc8e52538	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0xc8f36b20	kobject_init
++EXPORT_SYMBOL vmlinux 0xc93ad41f	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0xc95a6e39	snd_jack_set_parent
++EXPORT_SYMBOL vmlinux 0xc9785652	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xc9795799	snd_cards
++EXPORT_SYMBOL vmlinux 0xc98adf6e	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0xc996d097	del_timer
++EXPORT_SYMBOL vmlinux 0xc99e2a55	twl_rev
++EXPORT_SYMBOL vmlinux 0xc9bb2bf9	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xc9be3b55	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xc9c092d4	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xc9c3d05e	__register_chrdev
++EXPORT_SYMBOL vmlinux 0xc9c714e9	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xc9dfb144	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0xca4bd57a	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0xca5967e3	vm_stat
++EXPORT_SYMBOL vmlinux 0xca5dbc50	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xca687237	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xca80ebf2	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcac908ee	del_gendisk
++EXPORT_SYMBOL vmlinux 0xcae78415	scsi_allocate_command
++EXPORT_SYMBOL vmlinux 0xcae86324	simple_write_begin
++EXPORT_SYMBOL vmlinux 0xcaf943a5	scsi_device_put
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb0a8254	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0xcb2557ea	kobject_add
++EXPORT_SYMBOL vmlinux 0xcb3c5f06	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xcb4416b2	tty_hangup
++EXPORT_SYMBOL vmlinux 0xcb466063	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xcb46d416	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbd4d6f9	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0xcbf79e31	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0xcc0c6e2b	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0xcc22ae94	revalidate_disk
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc339d93	tty_unlock_pair
++EXPORT_SYMBOL vmlinux 0xcc37f55c	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0xcc451faa	simple_unlink
++EXPORT_SYMBOL vmlinux 0xcc4b84da	of_find_node_by_type
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc5e506e	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0xcc7316a7	sk_alloc
++EXPORT_SYMBOL vmlinux 0xcc7d8b53	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0xcc7fa952	local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0xcc87f33a	path_put
++EXPORT_SYMBOL vmlinux 0xcc8c3002	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xcc91f0a3	__register_binfmt
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd30b95a	tmio_core_mmc_clk_div
++EXPORT_SYMBOL vmlinux 0xcd359c88	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xcd604212	dev_printk
++EXPORT_SYMBOL vmlinux 0xcd63c845	__aeabi_lasr
++EXPORT_SYMBOL vmlinux 0xcd7d9747	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0xcd852fee	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0xcd853834	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xcd8621e2	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xcd8c14b4	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xcda9c283	ps2_init
++EXPORT_SYMBOL vmlinux 0xcdba7a11	xfrm_input
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcde172ac	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0xce1035a1	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0xce26d328	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0xce27dee4	tcp_prot
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce3b309c	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL vmlinux 0xce3e485e	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0xce47a21a	kvm_read_guest_atomic
++EXPORT_SYMBOL vmlinux 0xce4a27d3	generic_make_request
++EXPORT_SYMBOL vmlinux 0xce4bd608	may_umount_tree
++EXPORT_SYMBOL vmlinux 0xce5129e2	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce747f11	poll_freewait
++EXPORT_SYMBOL vmlinux 0xce822f50	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0xce973e1f	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xceb284bc	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xcecabc23	keyring_alloc
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf08965b	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0xcf6b9d86	register_framebuffer
++EXPORT_SYMBOL vmlinux 0xcf88625f	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xcf90532f	nf_log_register
++EXPORT_SYMBOL vmlinux 0xcfac20f2	neigh_compat_output
++EXPORT_SYMBOL vmlinux 0xcfd46210	snd_pcm_new
++EXPORT_SYMBOL vmlinux 0xcfd5adb6	security_path_unlink
++EXPORT_SYMBOL vmlinux 0xcff2c021	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0xcff6b676	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0xd003a7a4	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0xd00fa297	submit_bio
++EXPORT_SYMBOL vmlinux 0xd0181f4f	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xd0322d8b	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd07d204e	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0xd08c89d2	dev_set_group
++EXPORT_SYMBOL vmlinux 0xd0969031	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0b63be5	tty_port_put
++EXPORT_SYMBOL vmlinux 0xd0c0b8b3	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0xd0c7027d	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xd0d42c42	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0xd0db566c	inode_init_owner
++EXPORT_SYMBOL vmlinux 0xd0dc8887	generic_file_buffered_write
++EXPORT_SYMBOL vmlinux 0xd0e43207	usb_nop_xceiv_register
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f1864d	seq_release
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd112211a	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0xd11c0dc1	__kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xd122186a	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xd13f0d98	proto_unregister
++EXPORT_SYMBOL vmlinux 0xd1484659	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1b2b543	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL vmlinux 0xd1c8d7a1	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xd1d39898	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0xd1db74eb	dev_close
++EXPORT_SYMBOL vmlinux 0xd220cf8a	jiffies_to_timespec
++EXPORT_SYMBOL vmlinux 0xd22cc9d2	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0xd2301319	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2552f29	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd260436f	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xd264f42b	journal_set_features
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd27c1f47	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2c0ddaf	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2fee009	page_readlink
++EXPORT_SYMBOL vmlinux 0xd3115303	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xd31ccb06	of_machine_is_compatible
++EXPORT_SYMBOL vmlinux 0xd35cc844	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0xd3818a66	of_device_unregister
++EXPORT_SYMBOL vmlinux 0xd3c1b7b7	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0xd3d1f036	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xd3d3a477	posix_acl_init
++EXPORT_SYMBOL vmlinux 0xd3d622cf	of_dev_put
++EXPORT_SYMBOL vmlinux 0xd3dbfbc4	_find_first_zero_bit_le
++EXPORT_SYMBOL vmlinux 0xd3dcab0b	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xd3deb7be	netif_device_attach
++EXPORT_SYMBOL vmlinux 0xd3e16a1f	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xd3e6f60d	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0xd41fe818	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xd42a7d06	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0xd43028cb	udp_poll
++EXPORT_SYMBOL vmlinux 0xd433fbc5	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0xd456425d	kobject_set_name
++EXPORT_SYMBOL vmlinux 0xd4669fad	complete
++EXPORT_SYMBOL vmlinux 0xd48ce26e	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xd4e46c08	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0xd50acf4a	ptp_clock_register
++EXPORT_SYMBOL vmlinux 0xd51e3b4e	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xd51f6b29	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0xd5385a91	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xd54a70a2	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0xd58c16b9	vc_resize
++EXPORT_SYMBOL vmlinux 0xd59d6f52	eth_header_cache
++EXPORT_SYMBOL vmlinux 0xd5b1376d	register_shrinker
++EXPORT_SYMBOL vmlinux 0xd5c5ff75	inet_frags_init_net
++EXPORT_SYMBOL vmlinux 0xd5d72a40	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xd5de2461	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0xd5e7dde9	napi_complete
++EXPORT_SYMBOL vmlinux 0xd5f2172f	del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd60db692	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xd61347c6	register_sysctl
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd627480b	strncat
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd632e6b6	open_exec
++EXPORT_SYMBOL vmlinux 0xd636c540	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0xd6370563	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0xd63743ca	skb_queue_head
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd65b9471	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0xd65c2a30	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0xd67c7ce0	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd69974a4	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0xd6c86f1b	sock_wfree
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6f87643	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0xd7011df7	arp_invalidate
++EXPORT_SYMBOL vmlinux 0xd70d7c07	snd_dma_free_pages
++EXPORT_SYMBOL vmlinux 0xd70dfdbe	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0xd7321c6a	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0xd74289f9	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0xd74c4a03	read_cache_page_async
++EXPORT_SYMBOL vmlinux 0xd7513511	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd76e30e3	sock_rfree
++EXPORT_SYMBOL vmlinux 0xd77a5aa5	__bitmap_and
++EXPORT_SYMBOL vmlinux 0xd77ff1ca	d_move
++EXPORT_SYMBOL vmlinux 0xd78025ae	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xd78e7796	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xd79b5a02	allow_signal
++EXPORT_SYMBOL vmlinux 0xd7abbd8c	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0xd7ac63a7	init_special_inode
++EXPORT_SYMBOL vmlinux 0xd7ae2361	vexpress_config_bridge_unregister
++EXPORT_SYMBOL vmlinux 0xd7b4599b	__idr_get_new_above
++EXPORT_SYMBOL vmlinux 0xd7b7c298	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd7ecacc2	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0xd83962c9	bdget
++EXPORT_SYMBOL vmlinux 0xd8405c6d	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL vmlinux 0xd85cd67e	__wake_up
++EXPORT_SYMBOL vmlinux 0xd87a3662	journal_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xd88cd2fe	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xd88ed469	would_dump
++EXPORT_SYMBOL vmlinux 0xd89639e1	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xd8e0ce26	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd923d4e3	mount_subtree
++EXPORT_SYMBOL vmlinux 0xd92afabe	bitmap_clear
++EXPORT_SYMBOL vmlinux 0xd93bab96	blk_rq_init
++EXPORT_SYMBOL vmlinux 0xd95d2498	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0xd96979b6	key_revoke
++EXPORT_SYMBOL vmlinux 0xd9760fdb	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd98ef647	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xd99fde03	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0xd9a9bb30	getname
++EXPORT_SYMBOL vmlinux 0xd9c2d7e1	generic_file_splice_write
++EXPORT_SYMBOL vmlinux 0xd9cae267	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0xd9ce8f0c	strnlen
++EXPORT_SYMBOL vmlinux 0xd9e61fcb	qid_valid
++EXPORT_SYMBOL vmlinux 0xd9eee4ce	sk_release_kernel
++EXPORT_SYMBOL vmlinux 0xda0a53e6	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0xda0c6930	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0xda3b3cbf	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda57eb19	snd_dma_reserve_buf
++EXPORT_SYMBOL vmlinux 0xda6410eb	redraw_screen
++EXPORT_SYMBOL vmlinux 0xda7465a7	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0xda757554	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xdaa16b82	of_clk_get
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdaafc807	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0xdab1989a	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0xdae84f88	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0xdaf546dc	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0xdb052c92	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xdb0af2f9	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xdb11320f	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0xdb3ab32c	kill_pid
++EXPORT_SYMBOL vmlinux 0xdb42d2ad	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb77d055	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0xdbc9c85f	nand_unlock
++EXPORT_SYMBOL vmlinux 0xdbcd416e	sysctl_ip_nonlocal_bind
++EXPORT_SYMBOL vmlinux 0xdc035702	no_llseek
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc0988e7	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0xdc2c44f5	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xdc38e889	nand_correct_data
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc438da7	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0xdc5bcbac	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xdc6cbccc	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xdc6d41cf	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0xdc7923de	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0xdca8f503	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0xdcac7248	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xdcb0349b	sys_close
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd27fa87	memchr
++EXPORT_SYMBOL vmlinux 0xdd34df3b	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xdd3916ac	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0xdd4a5569	param_get_byte
++EXPORT_SYMBOL vmlinux 0xdd8d5f3b	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xddbd3fe8	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xddbf6eb6	update_region
++EXPORT_SYMBOL vmlinux 0xdde401fc	follow_down_one
++EXPORT_SYMBOL vmlinux 0xdde77e54	setattr_copy
++EXPORT_SYMBOL vmlinux 0xddf2b3a3	blk_integrity_is_initialized
++EXPORT_SYMBOL vmlinux 0xde295fbf	__vexpress_config_func_get
++EXPORT_SYMBOL vmlinux 0xde2e0273	inet_getname
++EXPORT_SYMBOL vmlinux 0xde4b6db0	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xde52eca6	kern_path
++EXPORT_SYMBOL vmlinux 0xde53e4be	consume_skb
++EXPORT_SYMBOL vmlinux 0xde6026b2	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0xde8e7da9	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xdea84905	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0xdeb5831f	commit_creds
++EXPORT_SYMBOL vmlinux 0xdec44e82	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf401846	idr_remove
++EXPORT_SYMBOL vmlinux 0xdf48a0eb	flex_array_put
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdf9472b6	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0xdfa93b52	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xdfb01a80	cpu_v7_dcache_clean_area
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xdfcaafe2	ilookup5
++EXPORT_SYMBOL vmlinux 0xdfe5af46	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xe01b9f9a	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0xe023e980	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0xe03803ac	dquot_drop
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe054931c	scsi_host_get
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe07338dd	neigh_table_init
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe07693e5	follow_up
++EXPORT_SYMBOL vmlinux 0xe07fbafd	mpage_writepage
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0b446b7	path_is_under
++EXPORT_SYMBOL vmlinux 0xe0ba63ca	fput
++EXPORT_SYMBOL vmlinux 0xe0bef318	icst_hz_to_vco
++EXPORT_SYMBOL vmlinux 0xe0e3bb42	snd_pcm_lib_write
++EXPORT_SYMBOL vmlinux 0xe0e82c33	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xe0f1ab58	d_drop
++EXPORT_SYMBOL vmlinux 0xe0f99a2f	ida_pre_get
++EXPORT_SYMBOL vmlinux 0xe0ff85c0	ether_setup
++EXPORT_SYMBOL vmlinux 0xe1093ded	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0xe113bbbc	csum_partial
++EXPORT_SYMBOL vmlinux 0xe11f3cbc	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0xe127fb18	down_killable
++EXPORT_SYMBOL vmlinux 0xe13cacb8	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xe15f3eb4	fb_find_mode
++EXPORT_SYMBOL vmlinux 0xe170db29	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe17bdead	register_key_type
++EXPORT_SYMBOL vmlinux 0xe189872c	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xe1971b6a	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0xe1afe839	journal_flush
++EXPORT_SYMBOL vmlinux 0xe1b54ee3	input_set_capability
++EXPORT_SYMBOL vmlinux 0xe200d2d5	param_get_uint
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe2112ffb	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0xe2113b50	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0xe22f72a2	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0xe234b1bb	send_sig_info
++EXPORT_SYMBOL vmlinux 0xe237c2d8	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0xe2384e03	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe271f162	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xe2740087	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe2b0c946	dev_open
++EXPORT_SYMBOL vmlinux 0xe2b50d44	mdiobus_read
++EXPORT_SYMBOL vmlinux 0xe2bde56e	mmc_erase
++EXPORT_SYMBOL vmlinux 0xe2be3b6d	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xe2ce9bcc	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2e94c4e	block_write_begin
++EXPORT_SYMBOL vmlinux 0xe2ed45cc	inet_twsk_deschedule
++EXPORT_SYMBOL vmlinux 0xe2f53a63	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0xe2f90c74	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe3294d5a	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xe32c026c	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0xe32c7fa8	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0xe35c5285	of_find_node_by_phandle
++EXPORT_SYMBOL vmlinux 0xe37a947e	pm860x_page_set_bits
++EXPORT_SYMBOL vmlinux 0xe392da8f	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0xe3b23d50	textsearch_register
++EXPORT_SYMBOL vmlinux 0xe3b6c595	save_mount_options
++EXPORT_SYMBOL vmlinux 0xe3c073f3	sync_blockdev
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3d77527	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0xe3f6670e	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0xe4287b15	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xe43274bc	proc_dointvec
++EXPORT_SYMBOL vmlinux 0xe44af385	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0xe44fab76	register_filesystem
++EXPORT_SYMBOL vmlinux 0xe4613d72	scsi_prep_state_check
++EXPORT_SYMBOL vmlinux 0xe4684f1b	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xe47d15e7	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0xe488ffcc	d_lookup
++EXPORT_SYMBOL vmlinux 0xe4c80097	cacheid
++EXPORT_SYMBOL vmlinux 0xe4d039aa	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xe4d48ff1	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0xe4e0df6e	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0xe4e305ab	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0xe4edf095	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0xe4f92903	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0xe5026ed0	netdev_notice
++EXPORT_SYMBOL vmlinux 0xe5122890	flow_cache_genid
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe529c236	tc_classify
++EXPORT_SYMBOL vmlinux 0xe5314560	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0xe53d1faa	of_translate_dma_address
++EXPORT_SYMBOL vmlinux 0xe55a3e15	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xe55d203e	snd_pcm_lib_writev
++EXPORT_SYMBOL vmlinux 0xe565364d	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe5b00f28	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0xe5c19138	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5d95985	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe6106e42	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0xe64713b0	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xe66452ab	dql_init
++EXPORT_SYMBOL vmlinux 0xe684c86c	__scsi_put_command
++EXPORT_SYMBOL vmlinux 0xe6913a15	phy_stop
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6bef801	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0xe6c3ebb0	__raw_writesw
++EXPORT_SYMBOL vmlinux 0xe6c92cb1	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0xe6d063ba	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0xe6e4d20b	elevator_init
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe707d823	__aeabi_uidiv
++EXPORT_SYMBOL vmlinux 0xe7380cf0	mtd_concat_destroy
++EXPORT_SYMBOL vmlinux 0xe73d3555	set_anon_super
++EXPORT_SYMBOL vmlinux 0xe7410089	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0xe7566d70	snd_pcm_set_ops
++EXPORT_SYMBOL vmlinux 0xe7661851	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0xe7722171	flex_array_free
++EXPORT_SYMBOL vmlinux 0xe77ab1a7	register_console
++EXPORT_SYMBOL vmlinux 0xe78299f0	sound_class
++EXPORT_SYMBOL vmlinux 0xe78927f0	arp_xmit
++EXPORT_SYMBOL vmlinux 0xe78a5dcd	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xe7a664c4	nf_hooks
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7c84182	nla_reserve
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe80ce219	sysctl_tcp_dma_copybreak
++EXPORT_SYMBOL vmlinux 0xe81064a2	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0xe841225a	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0xe851bb05	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe853ea4c	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xe869bcc2	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe88911e0	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xe8b53ecc	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xe8b63ace	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8dc31b7	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0xe8ed1b5c	snd_pcm_lib_read
++EXPORT_SYMBOL vmlinux 0xe90f2538	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0xe912da6b	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe93dafbf	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xe93e9cca	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0xe94710b0	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0xe94aa47f	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xe952976e	filp_open
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe95f0ae2	mount_pseudo
++EXPORT_SYMBOL vmlinux 0xe9625225	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0xe9a4cc7b	sk_common_release
++EXPORT_SYMBOL vmlinux 0xe9a7f243	serio_rescan
++EXPORT_SYMBOL vmlinux 0xe9acc9e1	snd_device_new
++EXPORT_SYMBOL vmlinux 0xe9b3d069	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0xe9b92d33	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0xe9c79896	cdev_del
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea05a229	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0xea10212a	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0xea10655a	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xea346938	poll_initwait
++EXPORT_SYMBOL vmlinux 0xea3932fc	vm_mmap
++EXPORT_SYMBOL vmlinux 0xea4b9f29	amba_request_regions
++EXPORT_SYMBOL vmlinux 0xea54c964	set_create_files_as
++EXPORT_SYMBOL vmlinux 0xea6e3003	of_find_compatible_node
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xeaad8e68	devm_request_and_ioremap
++EXPORT_SYMBOL vmlinux 0xeaafc5f4	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xeab7c1ee	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0xeae338b3	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xeae7f333	do_truncate
++EXPORT_SYMBOL vmlinux 0xeb00f135	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xeb040fbe	drop_nlink
++EXPORT_SYMBOL vmlinux 0xeb2034d8	amba_driver_register
++EXPORT_SYMBOL vmlinux 0xeb31879b	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb7b6c6f	dev_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0xeb7c5e82	mmc_put_card
++EXPORT_SYMBOL vmlinux 0xeb9003fd	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xeb9e7cdd	ida_destroy
++EXPORT_SYMBOL vmlinux 0xebdbe48c	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xebdcec0d	udplite_prot
++EXPORT_SYMBOL vmlinux 0xebdd1ed5	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xebfc6c24	bio_init
++EXPORT_SYMBOL vmlinux 0xebfdcbdf	system_serial_high
++EXPORT_SYMBOL vmlinux 0xec06d779	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0xec120c81	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xec17ebb0	of_match_node
++EXPORT_SYMBOL vmlinux 0xec3bc724	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0xec4bc179	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec60fdab	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xec6293fc	nla_append
++EXPORT_SYMBOL vmlinux 0xec668b5c	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xecf25eb3	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xed116445	read_dev_sector
++EXPORT_SYMBOL vmlinux 0xed3e68c9	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed641fe4	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xed646e7b	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0xed6bcb69	kill_litter_super
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed99ecac	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xed9ba7eb	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0xed9f25c5	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc227ef	vexpress_config_bridge_register
++EXPORT_SYMBOL vmlinux 0xedc7f4ec	dq_data_lock
++EXPORT_SYMBOL vmlinux 0xedd9106d	__ashrdi3
++EXPORT_SYMBOL vmlinux 0xedf3e9b3	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0xee078a3d	dquot_file_open
++EXPORT_SYMBOL vmlinux 0xee13d0ce	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0xee255ac6	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee39ea4e	icmp_send
++EXPORT_SYMBOL vmlinux 0xee4c7fd3	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0xee559bdf	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL vmlinux 0xee5a57cc	snd_component_add
++EXPORT_SYMBOL vmlinux 0xee715ef8	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xee7d0cfa	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0xee95a2ed	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeeca46bd	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0xeed3635b	proc_dostring
++EXPORT_SYMBOL vmlinux 0xeedddd14	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0xeeff80bb	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0xef1b9638	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0xef3b1996	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0xef4d4aaf	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xef4e2214	soft_cursor
++EXPORT_SYMBOL vmlinux 0xef4fb226	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0xef6f19cf	fb_show_logo
++EXPORT_SYMBOL vmlinux 0xef6fe66e	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xefba75d7	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0xefcc6ef7	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xefcf3143	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0xefd6cf06	__aeabi_unwind_cpp_pr0
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf00e0401	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xf02b3071	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xf02cda57	bio_pair_release
++EXPORT_SYMBOL vmlinux 0xf03a03f7	netpoll_rx_enable
++EXPORT_SYMBOL vmlinux 0xf04d5c61	console_start
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0619801	timekeeping_clocktai
++EXPORT_SYMBOL vmlinux 0xf06991d7	elevator_exit
++EXPORT_SYMBOL vmlinux 0xf06e28d3	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xf087137d	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0xf088c15a	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xf097cdd5	bh_submit_read
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0d68ed6	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xf0dd905e	dump_write
++EXPORT_SYMBOL vmlinux 0xf0e84b88	file_update_time
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f1246c	kvasprintf
++EXPORT_SYMBOL vmlinux 0xf0fdf6cb	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xf100416a	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xf1072cd4	journal_revoke
++EXPORT_SYMBOL vmlinux 0xf10e8b8b	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0xf1185043	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0xf1372833	unregister_key_type
++EXPORT_SYMBOL vmlinux 0xf1389594	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0xf13feb57	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0xf142ad53	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf15eee8c	ip6_route_output
++EXPORT_SYMBOL vmlinux 0xf1701f5c	skb_clone
++EXPORT_SYMBOL vmlinux 0xf1806da9	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0xf184a0a4	of_find_device_by_node
++EXPORT_SYMBOL vmlinux 0xf193db2e	register_netdev
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf19e9355	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0xf1ca4341	do_splice_from
++EXPORT_SYMBOL vmlinux 0xf1ce1b54	inode_init_always
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1ff86a3	__pagevec_release
++EXPORT_SYMBOL vmlinux 0xf202c5cb	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0xf208deda	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf219595c	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xf219f9a6	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0xf21afa20	pipe_unlock
++EXPORT_SYMBOL vmlinux 0xf21eac86	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xf22e9610	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xf22f7a91	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0xf23aea1d	d_invalidate
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2595a25	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xf28baf80	tcf_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf29b09f8	__mutex_init
++EXPORT_SYMBOL vmlinux 0xf2a6fabd	fib_default_rule_pref
++EXPORT_SYMBOL vmlinux 0xf2b1ac8e	__getnstimeofday
++EXPORT_SYMBOL vmlinux 0xf2ba6702	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xf2c59c9b	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0xf2ce63c0	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xf2d8c861	journal_start
++EXPORT_SYMBOL vmlinux 0xf301fa6d	mem_map
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf32e0886	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf3445513	call_netdevice_notifiers_info
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf35ef6f3	seq_bitmap_list
++EXPORT_SYMBOL vmlinux 0xf3797152	snd_interval_ratnum
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf39c38fd	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xf39f8ac3	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xf3b98c0c	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xf3bbd8ba	posix_lock_file_wait
++EXPORT_SYMBOL vmlinux 0xf3bf0bce	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0xf3e9624b	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xf401a3ba	kernel_connect
++EXPORT_SYMBOL vmlinux 0xf4039944	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xf41d5c76	nf_log_packet
++EXPORT_SYMBOL vmlinux 0xf42f3ba1	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xf443bbfe	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xf450cb35	ptp_clock_event
++EXPORT_SYMBOL vmlinux 0xf45a4e52	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf473ffaf	down
++EXPORT_SYMBOL vmlinux 0xf4899c2e	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0xf4a3f266	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0xf4b88733	__break_lease
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4beb2fe	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f1e1f2	names_cachep
++EXPORT_SYMBOL vmlinux 0xf4f71fc3	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0xf506f924	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0xf5280394	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf543b433	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0xf547a8cf	wake_up_process
++EXPORT_SYMBOL vmlinux 0xf54cace1	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xf551217b	filemap_fault
++EXPORT_SYMBOL vmlinux 0xf557b8e1	inet_accept
++EXPORT_SYMBOL vmlinux 0xf564412a	__aeabi_ulcmp
++EXPORT_SYMBOL vmlinux 0xf57605e3	do_sync_read
++EXPORT_SYMBOL vmlinux 0xf5bd2750	tty_port_close
++EXPORT_SYMBOL vmlinux 0xf5c05914	generic_segment_checks
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf62353c5	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xf62bbe76	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63e1b27	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xf65eb495	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf6851d5f	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0xf69a0ba8	__quota_error
++EXPORT_SYMBOL vmlinux 0xf6b53086	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xf6b87bf9	security_path_truncate
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6c5136f	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0xf6e53917	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf6fbd9d8	inet_shutdown
++EXPORT_SYMBOL vmlinux 0xf70cf6b7	snd_jack_report
++EXPORT_SYMBOL vmlinux 0xf70fa575	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL vmlinux 0xf72eb478	netdev_update_features
++EXPORT_SYMBOL vmlinux 0xf742e625	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0xf7485521	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf762104f	load_nls
++EXPORT_SYMBOL vmlinux 0xf7802486	__aeabi_uidivmod
++EXPORT_SYMBOL vmlinux 0xf7a5f40f	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xf7b12aee	__next_cpu
++EXPORT_SYMBOL vmlinux 0xf8031b39	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xf803fe39	bitmap_set
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf8675bb2	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0xf8b8030e	prepare_binprm
++EXPORT_SYMBOL vmlinux 0xf8dfd9fc	of_get_min_tck
++EXPORT_SYMBOL vmlinux 0xf8ebe930	audit_log_start
++EXPORT_SYMBOL vmlinux 0xf8fbb4f0	__bad_xchg
++EXPORT_SYMBOL vmlinux 0xf9125b97	blk_start_request
++EXPORT_SYMBOL vmlinux 0xf91e12b7	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xf92c7a68	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf9358bbc	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xf93aee4e	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xf94abd1f	ppp_input_error
++EXPORT_SYMBOL vmlinux 0xf964f5f3	ip_defrag
++EXPORT_SYMBOL vmlinux 0xf964fe3a	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0xf9670840	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0xf989512d	proc_symlink
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9afb0d7	tty_throttle
++EXPORT_SYMBOL vmlinux 0xf9bafcc0	simple_fill_super
++EXPORT_SYMBOL vmlinux 0xf9d290aa	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xfa0eeaa4	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xfa1cec46	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xfa219f19	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa61f7ec	write_one_page
++EXPORT_SYMBOL vmlinux 0xfa7f3156	wl12xx_get_platform_data
++EXPORT_SYMBOL vmlinux 0xfa915ac2	snd_dma_alloc_pages
++EXPORT_SYMBOL vmlinux 0xfaa2d1fc	cdrom_open
++EXPORT_SYMBOL vmlinux 0xfaac814a	netdev_warn
++EXPORT_SYMBOL vmlinux 0xfaae85fe	journal_ack_err
++EXPORT_SYMBOL vmlinux 0xfab5b3f8	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xfac68eba	arm_elf_read_implies_exec
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfadc9f7b	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0xfadea80f	user_revoke
++EXPORT_SYMBOL vmlinux 0xfae4f27e	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf98462	bitrev32
++EXPORT_SYMBOL vmlinux 0xfaf9995e	sleep_on
++EXPORT_SYMBOL vmlinux 0xfaff937f	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0xfb0246b7	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0xfb241124	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xfb2c6a3a	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xfb2dd264	touch_buffer
++EXPORT_SYMBOL vmlinux 0xfb358450	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0xfb6253df	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb6f2e1f	journal_load
++EXPORT_SYMBOL vmlinux 0xfb7d9c45	__udivsi3
++EXPORT_SYMBOL vmlinux 0xfb8d27d4	netif_napi_del
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfba9633b	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc280ec	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xfbe98d1a	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0xfbecff1c	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc0c0fbe	snd_card_set_id
++EXPORT_SYMBOL vmlinux 0xfc183766	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xfc26fb05	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0xfc300b56	mmc_start_req
++EXPORT_SYMBOL vmlinux 0xfc30171f	freeze_bdev
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc47f808	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfcaa04a0	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcd70e15	block_write_end
++EXPORT_SYMBOL vmlinux 0xfce5b8ea	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd0f704d	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0xfd0fa57d	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0xfd1b1b34	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0xfd305341	walk_stackframe
++EXPORT_SYMBOL vmlinux 0xfd3c6510	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0xfd5683b9	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0xfd58849d	journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0xfd6293c2	boot_tvec_bases
++EXPORT_SYMBOL vmlinux 0xfd640ecf	journal_release_buffer
++EXPORT_SYMBOL vmlinux 0xfd7bf876	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0xfd8ee9c1	user_path_create
++EXPORT_SYMBOL vmlinux 0xfd93d226	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfda0dbe8	ftrace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xfdc09d97	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0xfde07533	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0xfdf6a637	ll_rw_block
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe17b940	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe77ece4	init_buffer
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe9b3007	unregister_console
++EXPORT_SYMBOL vmlinux 0xfeca1b63	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfee6a51b	sk_free
++EXPORT_SYMBOL vmlinux 0xfef14816	set_binfmt
++EXPORT_SYMBOL vmlinux 0xfef96e23	__scsi_print_command
++EXPORT_SYMBOL vmlinux 0xfefe9bfb	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xff00f8fc	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xff01b6ec	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0xff04665e	sk_run_filter
++EXPORT_SYMBOL vmlinux 0xff064fee	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2d9d80	get_mem_type
++EXPORT_SYMBOL vmlinux 0xff44bc04	splice_from_pipe_end
++EXPORT_SYMBOL vmlinux 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL vmlinux 0xff66a8a1	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xff67b37f	__lshrdi3
++EXPORT_SYMBOL vmlinux 0xff67ef68	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7047c7	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff82372b	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffb62a75	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xffb94ef0	_test_and_change_bit
++EXPORT_SYMBOL vmlinux 0xffb99bd8	snd_card_file_remove
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffd73a8c	snd_pcm_hw_rule_add
++EXPORT_SYMBOL vmlinux 0xffdca32d	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xffe5095d	groups_free
++EXPORT_SYMBOL_GPL crypto/af_alg 0x19e9837d	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x21bb9305	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x53751b7c	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x93957c0c	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x95d7e96c	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9ce37938	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd954ef95	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf838d99e	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0xfb3660b9	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x2ce58a07	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x5ada6a3b	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0xa7b9cfe9	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x2f23b20d	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x9bc61898	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x36d0910c	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x3a2766b7	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xac6d2176	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0xb8c07908	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x6c0de209	async_xor_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xa4435397	async_xor
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0x3e356e77	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x32ca2b0b	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x91c1f4fe	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1ba47131	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x1e9c61ef	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x297f3d18	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x46da75a6	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x7ffc2983	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9969bfef	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x9ae15995	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd1648c10	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd574bd3b	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xf2ce610a	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/lrw 0x2dda1740	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0xb80ca8c8	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0xda1f2c31	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x1186a5b0	xts_crypt
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0xe8dd8f1a	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x0dd64cc3	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x259f4470	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2680977f	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x292d81b0	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x336fb896	bcma_find_core
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x3e2f0ee7	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x43280394	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x5930ef53	bcma_core_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x634fd486	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9546d356	bcma_core_pci_extend_L1timer
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x97a0e60b	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xaee692f1	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb9b74971	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb9f6f79a	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xbfcfcb01	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xcefe0488	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xdce16612	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe9000bf2	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf703530a	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf93ceb8a	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfcd46a79	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x0efd15da	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x4248569f	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x4f0e97a3	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x73f6c89f	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x77803c96	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9a4f1b04	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x9ca06064	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xb4a9a7bc	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xd4ea0ce4	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xee5983d0	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x257ce808	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x4312f3f2	dw_dma_suspend
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x6889d5df	dw_dma_shutdown
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc8e2419f	dw_dma_resume
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xc9ad29de	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x199d5a0f	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x2c90ebb8	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x39e2baec	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x50022983	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x536efd83	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x56f7c838	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x69259f22	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xa495d1da	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc3da5e8c	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd3ddb302	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd51b1ee2	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xdb6ba5ed	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe3fd9089	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe5a31580	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf379d578	edac_mc_add_mc
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x812f33e1	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x98e170c1	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x5eadb24a	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x9a6e1ad8	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x065ddc91	drm_gem_cma_dumb_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1d630c00	drm_gem_cma_prime_vunmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1e69b9e9	drm_gem_cma_prime_get_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x1ef2b12f	drm_gem_cma_vm_ops
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x2445c1e5	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x2515f19c	drm_gem_cma_prime_vmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x3ee5a781	drm_gem_cma_dumb_map_offset
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x6c285e19	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x7c91844c	drm_gem_cma_describe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x843c4c5a	drm_gem_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x8e8fa49a	drm_vm_open_locked
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x906fa2d8	drm_gem_cma_prime_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xa738477e	drm_gem_cma_dumb_destroy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xc8b2bfb8	drm_gem_cma_prime_import_sg_table
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xd7249fd6	drm_gem_cma_free_object
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xec3d4834	drm_gem_cma_mmap
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x0b15da00	drm_fbdev_cma_init
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x10e1574e	drm_fb_cma_create
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x1148b623	drm_fbdev_cma_fini
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0x93fde991	drm_fb_cma_describe
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xa5d69e38	drm_fb_cma_debugfs_show
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xb2c912af	drm_fbdev_cma_hotplug_event
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xcc337fd5	drm_fbdev_cma_restore_mode
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm_kms_helper 0xf8194baa	drm_fb_cma_get_gem_obj
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x08a42c2c	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x158009bc	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x1be3719f	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2a02d3af	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2cb62981	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2d4d2f08	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4020e0bb	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x56f48ff0	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5f504158	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x630f9c54	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x66d1efab	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6d90daa0	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x700a3306	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x718d4385	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x773e166c	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x8e2dea0c	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa06fd31c	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa6737307	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb4078d73	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbb538d29	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbfd2e64b	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc419ea23	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xcaf28cb2	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd4a421d7	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd8a1fe16	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd99b85d7	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe0263005	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe0b93253	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe6f3555d	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe9f62a08	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xed87ff41	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf205b812	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf4f45404	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xfeca9cb9	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x25bf9434	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x0dcf63e1	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x72901524	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x79869a7f	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x14d84989	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x29e57ebf	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x3c59d4cd	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x6358e3b4	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc3104a91	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xc8693e3e	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xc6764544	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xc6d391af	usbhid_set_leds
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x1e845e0c	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x5f0ad547	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x8674d2bc	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x87815c56	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x9b4d9ac8	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa829a8ab	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xaefaa060	hsi_async
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xb0eacf12	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xc1f0af4f	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xd55133aa	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe1696f5a	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe198ee10	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe648e3fd	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x5a0f091b	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x5c9cafa4	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xb7cb7f76	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1ba05ab5	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x4a74f448	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x55d905bd	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x5c1e29c5	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x68439088	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x83c782bf	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x85ab4fb7	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x977f2122	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa4d6e476	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xb8e27f6d	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xee99bed8	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf68db111	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x0ebedf23	i2c_dw_clear_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x3b94bf1c	i2c_dw_func
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x5bb1170b	i2c_dw_isr
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x6470d163	i2c_dw_xfer
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x843c5b17	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xb11427a2	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xb2baf96d	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xd28eaa87	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xe62ad1e7	i2c_dw_is_enabled
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xedb2e459	i2c_dw_enable
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x21ec2453	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0xbd6925b1	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x7cf56c9e	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xcc31e837	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x007fa42d	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x0b24d2d8	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x13acc6d6	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x7098b7a9	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x7e0061cd	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x80a67c30	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xa8d38c06	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe1bcd940	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe3b34b88	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x051a2fe4	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x191a7889	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1b89121f	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x1cc46a0d	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x251eeec1	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x36dd54ac	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x60a3e93e	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x63f968b8	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x99699563	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x9aba6140	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xaf92d356	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xd81cf033	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0186e789	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x24c3a22e	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a2eeccf	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2c49ea10	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2f1c6c36	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3e2b11c2	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x43e8a4f9	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x580d5628	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5f4f0fa6	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67d23afb	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x6faa3287	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x70274d90	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x81b0be72	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x8cda20a2	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xa33dc75e	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xaaf86c62	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb169be1a	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbab4b6ec	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xbd7a859c	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc7797ebb	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc90e6fac	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xce5fce48	iio_scan_mask_set
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe0b82814	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xeb18046f	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0xf3993922	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/matrix-keymap 0xa1ce6686	matrix_keypad_parse_of_params
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe901a6f0	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x08f017d1	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x5b426c47	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x82a24554	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x45293ea3	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x74dba0e3	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x7a769c87	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x5c5a5398	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0xb2c661dc	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x14c136d4	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1537a1dc	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3a00e8e5	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x60e6bb43	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x74323146	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x7d58a619	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xac4cbbdd	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb0dfb74a	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xb85bd55e	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xc9b1bdf6	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xdb9dfac8	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xfd3d1d14	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x0555c6cf	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x1c741e5b	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x406065ff	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x5ee64638	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xb3e4be42	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xcbf7a5d4	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xe833de53	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xf5d85ecf	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xf8603b09	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x0657dc1a	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x12b7ba44	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1df861f0	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x38390065	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x385c999d	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5f56a490	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x83c599c4	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x931f39fa	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa0763534	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa3d6ebfb	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa5ca03d5	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xa77b2bf0	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xb362a396	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd47fb593	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd6bc7ffa	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xe4857ae1	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xfd850e38	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x11ad7ccf	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x141e3e15	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2667db71	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x3a729198	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x497f65bf	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x4a809548	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x58de46be	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x7732c909	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xabc5bd37	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xae75075d	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xdd78ece5	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x041b4145	closure_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10c931f2	__closure_flush_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e06e97	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x155ea9c7	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1822fd23	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1f2ba9ac	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x260d47cf	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x26572dfa	closure_wait
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x27831e89	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2dec45e0	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x303563a5	closure_sub
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x347aebe1	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x41c861f0	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x49856e5a	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x50e8c39f	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x574762e8	__closure_lock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x574ba881	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x628eb712	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6770a402	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6af8a9e1	closure_trylock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x785cfc9f	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x79783247	closure_queue
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7b488fb1	__tracepoint_bcache_alloc_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91473bf2	__closure_flush
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f2af34	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x93c4f8b9	closure_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa09069a3	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa591c5d6	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa6890b59	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf60c34b	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb950d2ae	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbd4b89b6	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xce0e6218	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd40fba32	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xdc5ea5a5	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe8f89e62	__closure_delay
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf58ce244	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf5bcbdc7	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfb90a920	do_closure_timer_init
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc1d5275	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcdf28c9	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xffc308e4	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17d0e20e	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1ffa53e1	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x42c98902	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x55a32038	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x614c788b	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x761fae56	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xd3f34db8	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xebd06eaf	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x012aea12	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x11471e27	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x30fcbb24	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x582768cc	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7c20af0a	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xa2b929eb	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xf8edc509	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xfd28d2e4	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x69ff7848	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0xb2f9a103	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x2d34b464	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x80405a84	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x9ea6f502	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcae953b9	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xe4b5add7	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xedb8d989	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1cac81ac	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x240986fe	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f74609d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x371fd72c	dm_bm_flush_and_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x38c75c44	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x68fae9d2	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x80c89b3d	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa0bbbb49	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa13861b4	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb7bad799	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe44b4b9b	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf475af48	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/raid1 0x87ffe2f9	md_raid1_congested
++EXPORT_SYMBOL_GPL drivers/md/raid10 0x121ecbd4	md_raid10_congested
++EXPORT_SYMBOL_GPL drivers/md/raid456 0x44ac893d	md_raid5_congested
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0984c8a6	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x150f1ad2	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2c6db08f	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x417d24dc	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x55970e60	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x57730a4f	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x655ff2cc	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x711f5fc1	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x782706d6	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7da93caa	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x8fdebb15	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xb4a48971	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcd8ba841	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xcea83c9b	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe1629c5c	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xec0b8fe4	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xff42bf85	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xacc3b6db	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x7ebf5fe5	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x7fa842c8	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x024d5b9c	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x02e633f8	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x0ec9fe89	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x21a6f57e	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x250510de	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x4f6471c9	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5beca3c0	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5cede4d7	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x675997ad	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x88c29ad4	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x917e0d63	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x9d376238	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb2573356	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc2db6b0c	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc7d99dfc	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xcc3b232a	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xe8a37861	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x49c1ce8b	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0xcfab6d64	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x6289368f	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xdc557e77	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0x1e7f3cb3	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0x1af5f7ed	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x3da95515	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0x8718ed52	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x4c3160ad	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x07e6d613	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0xe8d28dff	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x5a64e39d	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xf4de6c96	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0x4bfeab61	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1cac6795	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x2ca4435f	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x3659f2bb	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x43880252	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x459ed54c	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x56460285	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x56f03f7b	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x605548b6	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6194384c	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x6c4a66ae	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x7809f3e3	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8df542a7	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xadc1f32e	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbab9e3fa	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xca616671	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd49bd1b2	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd9d6dcd3	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdcce8ac1	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xedc8fd05	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0xfcd35f33	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x7ad0012e	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1ac7b9b5	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1acf1b92	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x1c0ecade	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2ea8e86d	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x31492daf	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3dfa855e	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x3eaa1d49	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x4aca72eb	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x6e93f6ce	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x70d61366	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x9be27c6e	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xb6cfcab7	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xbf17d1e0	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xff600f66	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2012b445	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x36ea34c0	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xce8a9ecd	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xd2f8bc43	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x06344ef5	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x277d0b58	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x412418bc	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x53105839	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x5d9d3491	v4l_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x649acc64	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7eaf8e7a	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xa9b4f888	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xdefb0cd3	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x286b08ad	v4l2_int_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x36031326	v4l2_int_ioctl_0
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x9cb8427b	v4l2_int_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xa5228b24	v4l2_int_device_try_attach_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xbd0f0a50	v4l2_int_ioctl_1
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x085254d3	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2193250e	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x34095be8	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3f88b816	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x426aaf48	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x49593f5a	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x4a166e1a	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6262f36f	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x6d1ae9db	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x84334c71	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd4834a9d	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd9a13547	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf071e913	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xf3a46868	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x02cfc5d7	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x037745d3	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x11e5afa6	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x25491604	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x25b74e67	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x25c7a21c	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x29d21e26	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2a0b4322	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x38fa7e6f	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3ef920d2	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x511b3db0	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x5762fb3c	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x592a9744	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x6346b7c7	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x7c59821f	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa7531e3b	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xa8b3d2c9	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xab1bfd63	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb0571cc3	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xbfb45d34	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe377069b	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xed0cab16	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xee3f57ab	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xfc1bdfd9	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xb9053581	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xcb58031b	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xe4f5eab3	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x221f964f	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x3f27e2fa	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x47687cee	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x056f5d70	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0abef7a6	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0ba86333	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x0d62702a	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x101a7a8c	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1c3d923b	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2123dfbe	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x23a9047b	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x30a252fe	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x32437268	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x3299874b	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x37865b00	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x40117091	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4457b838	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x4d4ab034	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x672b8db9	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x680f46ee	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x72a51686	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x731fa77c	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7c7d3ce6	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x84e30d19	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8951882a	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8bf34064	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8fe497ee	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa5527ee2	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xb34b609d	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbbed309f	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd25fc6d8	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xde80fed4	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xf90dd669	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfc3bc007	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xff90ff2d	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xffd96543	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfff07be5	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x763b9006	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xafd5641c	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x5e05a71e	vb2_get_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xa05e4402	vb2_put_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xb87b9d16	vb2_get_contig_userptr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0xcc524112	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0x482c5916	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x045d6067	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x136fc9fc	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x275308ea	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2af23255	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x325f945a	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x333d01e2	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x5dea5bba	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x61ae7dd2	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6886dbc6	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8653b6a6	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x89c7a060	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x92142dc8	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9b026355	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x9f8ebf7a	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xa6b5521c	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xda1af007	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xda204483	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xdd3b7a53	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xee818760	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf2f4099e	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xf9129ce7	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfccfea65	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xfd4b6598	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x610bbb13	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x6f8e6ff1	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xa2f9be1a	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x2329f49c	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x281c548f	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x73f43bf8	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x82132d1b	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xadf52641	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xd75b9161	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe2f32036	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfb24bde1	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x40c371bb	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xa0e66cb5	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xaca37360	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x04030776	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x3639b43f	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x3930af27	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x89d85db5	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x908a7625	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xc5f79019	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xfa5acd49	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x1f92089a	mc13xxx_common_cleanup
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x77f4abb6	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xa4f2bd45	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xb6fd482d	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xde683e9f	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe448f665	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x016acfdc	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x14276d35	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x3608107b	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x36e16cc1	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x6438a759	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x65f15591	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x78644bfe	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x79371e21	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xcba39b4d	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe0716fb9	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfb13a081	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xc5abf363	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xf23dd989	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x405b28f1	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x48496659	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xd88cf359	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xef6bab8d	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xfa70ea70	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x218f8b51	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x30be46e4	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x32ef6a15	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3467a4b9	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3b4db463	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x3bd7ce18	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x463401d5	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x468ffd9a	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4a939e22	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4f0b3c15	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x515db45a	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5b380354	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5c574a1a	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x666a3631	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x684bc766	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6a0c4065	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6ab52ef3	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x6c97c624	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x72d9f4fb	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x797cfadf	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x840c1d14	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x86004909	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x99af9e99	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbdeec870	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcaad5916	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xcc49487f	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd26dfbff	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xd4a1ba4a	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xda8f828d	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdfa76290	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe46bb2d1	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xe566a6fb	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf4ed192c	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfbb151af	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x014e3107	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x532e1e6e	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x68cefb28	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x6c7dee70	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xbaf4a4b4	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x108df072	am335x_tsc_se_update
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x229ceb66	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x6447b61e	am335x_tsc_se_set
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x47aa56d0	tps65217_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x54009290	tps65217_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x87eebc67	tps65217_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0xe2976d2b	tps65217_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/twl4030-madc 0x4362dc66	twl4030_get_madc_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/twl4030-madc 0x9effbf1a	twl4030_madc_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0x77cc406e	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x00400e4e	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x029e4f9d	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x208b3ea9	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x313839b1	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x7cfa2468	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xa35181bb	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xc3ea3ac7	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x0a87785a	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x55598219	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x714452e5	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7fded527	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xb6886dbd	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xc8b5bf96	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xc94ea31e	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xfd4b776b	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x9dcdd96e	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xe573fed8	st_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0x1b790f86	dw_mci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xc7cb1ceb	dw_mci_pltfm_remove
++EXPORT_SYMBOL_GPL drivers/mmc/host/dw_mmc-pltfm 0xd384f30c	dw_mci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x0fe5040c	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x30cc21e4	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xcdd20472	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x7596043f	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x866fcbb9	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xf83d8069	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0xbe9fd597	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x03be532d	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x87335d50	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0xd84bee10	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x226c898d	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0x7c40fab7	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x0fbcad55	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x39cbcdc5	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3b4fb284	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3b5c8d11	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3c4c0989	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x422007cc	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x45d23c09	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x53256135	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x69e55dcb	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x99157a91	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe08d53eb	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xe50ce0a0	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xef74e895	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x3a80c5b1	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x3d9696eb	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xbf8d9187	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xc57c96d0	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xe89cb173	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xeb9a60e2	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0c6f030c	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x2d96d0ab	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x31d0a0fa	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x37e2d34a	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x59e3cab0	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x679c75e8	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x874fbb02	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8cb716b1	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xaa1faa71	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xad753b13	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc7d71a70	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xcf37776f	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe1efdfa5	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xe3700aea	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xfba4e659	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x37bc86e9	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x4e29579d	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x508b1545	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x5fd868bb	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x23674b18	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x99e06c3d	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xd1ddffea	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xec58d3d5	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x2314ec5e	macb_get_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x8a229e7f	macb_ethtool_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x90daec93	macb_ioctl
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x990b749e	macb_get_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xa72a6cc8	macb_set_rx_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xb2b51c91	macb_set_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xfd531fe8	macb_mii_init
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x3da758e4	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x419cac57	macvlan_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xdcf7797f	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xf40ba739	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xf4a215cd	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0xe954159b	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x52979ed0	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x7bf4b3a2	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x9b6ebb86	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x9d860f6e	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x488a27e0	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x4bd2dfd4	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x8141aed7	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xac5a6aae	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xd4d04449	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xfc703ce2	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x23d0ca0b	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x7a66cf29	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xab67eb00	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xb56c745c	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd3ce5213	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xf0309a85	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x056c83a1	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0d72f01c	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x1c4d3b85	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x37f5dd1f	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x45178200	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x480d7d18	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x6581852b	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x76a70097	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x86be8f13	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x87423f47	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x8e72f914	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x926b14e4	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x93e7434d	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9593ac3a	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9d974e71	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xa346873a	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb3ef9752	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb62ac86a	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb6da4a1a	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xba572f85	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbc000cdb	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc02d3549	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc5ac6207	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc7945e96	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcd4d40ac	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe081dc02	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe4a29947	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xe56a83bd	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xebdff87d	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xef7b8149	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf2d45300	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x0d21affa	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x1efe854f	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x65ff69f8	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x750fd958	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x75e32d3a	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7ed61187	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x7fe9b6d4	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x895368ad	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x8ee326b2	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x90bff05a	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x97a1da01	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa5c9fbd2	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc3e3b652	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xcd2650ae	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd2d764fa	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xf1db5203	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x1e796d71	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x322d3466	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x43ced188	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x80799f39	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x014978bb	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2db9b866	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x2f467e02	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x43e236a8	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x54e19ade	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x9f4a5dd2	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xae664ad6	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbe0dc2d7	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbf5158c3	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xcbd6b95b	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xd65df09e	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xdaa6b057	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xdef88db8	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe0dab907	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe76b95ed	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xea0d46f5	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x07c0932d	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x0881507f	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x3aab89ea	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x4e2ebdd7	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x5400ac2f	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x5a8254d1	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x6a12024f	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xda604a21	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0x0fdc1958	if_usb_prog_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0x1e4f2b5b	if_usb_reset_device
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x30160cfb	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x3c9014bb	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4a334b42	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x4d354192	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x811cc982	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x85cc7fa2	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x8aa5cccc	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x95700a79	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xa489833a	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xab1c1485	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc5b0a095	mwifiex_deauthenticate
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xc89e4ad6	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd102554a	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xd8dd2a59	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x025a9cb4	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x02e17d42	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x12e10717	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x35b7ebe0	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5dda97f9	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x61f416ee	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xcf1a8485	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xe715f10c	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xfb1654a9	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0b90c2fd	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1710126d	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2200fb6d	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x34027ed6	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3466c23d	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x34aa90ba	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x37969a9a	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3b144d3e	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x48d64c11	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4a870e40	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4c47967f	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4e9e3ace	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x55f88ac8	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x57069ace	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x615447c8	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x624d2c9b	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6629377d	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x755c1068	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x75740800	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x84f7f059	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x86c4f912	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x88a19dd8	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8974149c	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8f660130	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x947df60c	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x966d16cf	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa78c7d7e	rt2800_get_tkip_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xacd7de14	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd3a519fe	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd8bffb21	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe01986f3	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xe0a080b1	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeb647225	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xeeddc2ef	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf2feb82d	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf30c808b	rt2800_rt2x00debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xf47125ee	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xfec234a2	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x05495937	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c48c3c8	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2e486759	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x339a86f8	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x33b10996	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x3c5a91c2	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x41b389f5	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x49277e80	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x54160400	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5620c4fb	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5718b74b	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x69bcbf67	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x77f08919	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x80528f2f	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x80e5c034	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x85605b6a	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x85a9f5dd	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x87fc118b	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8f3df8df	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x90691e57	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x92d1485d	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x932296d1	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x98012538	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x99f8f1de	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9edb5999	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa186a97a	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa5993e99	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa72b4609	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa7a6b9d0	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb9fee04a	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbf53bba7	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbfe34936	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcd9cf105	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcfec5da3	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd363e084	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd7d25069	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xdea6314c	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe136138d	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe36e9556	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe3dee348	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe84fd993	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe87eb9a2	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xeaf17b6a	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xeba3bab7	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xec178d0c	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xec4a154b	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfea7f988	rt2x00debug_dump_frame
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0a883b15	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x1e9da9d9	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x2fd57731	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x441140cd	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x49647a5b	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x4d8b80a1	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x51dacb54	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5646142b	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5d0ccc4c	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x5dbed291	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x64863091	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x73d200b2	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb3030379	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xcd87352a	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xcfe5c651	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xef120d7f	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x415536cb	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x094b00ad	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x2a940814	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x2d882d91	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x36f7b472	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x467038a5	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x46e775ee	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x4ac3eeb9	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x5250095d	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x6955c3e9	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x880e4a82	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x8c433b65	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x979f3f2f	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xa0ab7f5b	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xa148ca88	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xc54c0549	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xc806fa49	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xe584c3e3	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xf91bb9b9	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x1fc147f9	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x200bfcf7	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xd04d90c3	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x042ecec9	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x05294fba	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x0590a755	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2574f47f	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x25b11df5	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x299ac2b0	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x36fed01f	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x37b206b7	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x37ca9616	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x45a2df23	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x579449f8	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x581c4a5e	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x59b5e1f9	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5c26622c	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5e204caf	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x65ff3aab	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6bb047a7	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6c523569	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6d32ad89	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x6ea31691	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x71ad81c0	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x77101eab	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x78094868	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x875437e6	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x9282b8b0	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x96c28878	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x980071a4	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa54e1d70	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa76d99c1	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xac4937cd	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc37edb22	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd5d177a6	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd793da7e	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdf96ad19	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe731634e	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe885ca99	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xea994afa	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xec86c843	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf3da4f32	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf4adf860	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf574f90a	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfee6e5bb	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x4818e1c5	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x96b413ad	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0xea6adb1e	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x26975ad6	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x3a057589	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x61f29fad	mc13xxx_get_num_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xb48d344e	mc13xxx_parse_regulators_dt
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xe6878df6	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x28baa0d2	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x39235e1d	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x5e720109	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x79375bfd	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xbe3b4e03	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xd9e350c5	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0xa9cb06b8	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x26a6cb51	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x58065117	scsi_register_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x593a36c2	scsi_dh_handler_exist
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x8485dc1d	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xa3e2532a	scsi_dh_activate
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xa877354a	scsi_dh_set_params
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xb95478c4	scsi_dh_attach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xdd34b804	scsi_dh_detach
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x074a9fcf	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x08ad0425	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0f5eff2e	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x388e8c77	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5d4daf1e	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7616725a	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x89964877	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa1265c55	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xa136413b	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb656405e	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xb8fa6420	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc0760e27	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xdf4747f7	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xdfddd512	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe3bb75e3	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xe6682bef	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x032fb243	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x1070b933	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x329ad5e6	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x9631489d	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xa5dede7b	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xff40299a	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x02a24281	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1d0ad221	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2eb88f8b	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x345a76f9	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x38a690b5	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3c13a329	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3d6c9932	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x415ec2c6	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4298254b	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x456bfd68	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4726c46c	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x48e348b1	iscsi_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4bb1b8b5	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4ded8360	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x50d1e7e8	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x53d80ec9	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x564a1ad5	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5e4b364b	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x67ef9c3f	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6f520752	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x70717c2a	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x73293997	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7cd7e77b	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7d8378a4	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x83340efe	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x854bebee	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x856e9da0	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x95cc49a7	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4832cf0	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa645397e	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa748c094	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa7c90e61	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb93a2679	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb95b41eb	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xba102244	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xba8f082b	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbc87915d	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbee05ec3	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc50bd997	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xce142d2b	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd0e6c13e	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xd8408644	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe1c386bb	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe2a9b49f	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xea71c5fc	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf52d07c0	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2019494d	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x464d3c31	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x48f4f082	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4a9dd292	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4cacc579	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x533360c1	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x59b5ad30	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6656915b	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x969b0cdd	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xb496d836	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xd7427380	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xddfa789b	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe3b70018	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe64c60d7	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf67967f4	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xfbb03681	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xfe5c154b	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x0645aefb	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x1613db85	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x25aa7dec	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3b10797d	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x3d59d576	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x51294080	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x5b7959bb	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x6235e2ff	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x73c60fdc	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x82f435da	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8b342414	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x959b1c03	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9963dacb	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xa87986c2	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xab55dbdb	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xabe70624	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xac6d68a3	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xac8a91b9	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb3852297	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xcfee8bfe	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xda2e4159	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xe81e7948	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xeb27e7b4	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf51372f7	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfc9e9e82	sas_change_queue_type
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x18d8e460	scsi_tgt_cmd_to_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x2ef22f07	scsi_tgt_alloc_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x3eff27c8	scsi_tgt_tsk_mgmt_request
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x53359fc4	scsi_tgt_queue_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x98d07d6e	scsi_tgt_it_nexus_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xa9487d23	scsi_tgt_it_nexus_create
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xab9fda4f	scsi_host_put_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xac773146	scsi_tgt_free_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xc1a7dd01	scsi_host_get_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x051d34fc	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0c6825cd	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x0f0170ca	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x10dd0cab	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x11def01b	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x13f522c2	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x311a51a1	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x3b88dbe8	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x406274e4	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4d982724	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x52cea236	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x557a3c24	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x61bb3c6d	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6a033e8d	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6e796ce8	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6f583b00	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x6f7c7101	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x72d04903	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7ba52830	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x7f5d9630	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x802ad5fa	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x86b48f7d	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x9ac828e6	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa2b6f0ed	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa74fcace	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xacca69a7	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb5e9b523	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc22d27e5	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc43d1d93	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd1221061	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd240f37a	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xd87d9865	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe32f2df1	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe926ee70	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xe932d442	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xec00685a	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf6354ceb	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfb52ebd0	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfbbdd97e	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xfdfefbd0	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x1b7fe0fc	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x4b4bc87e	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x6503d7ea	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xd346afe5	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_spi 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x2974d0db	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x3efd5852	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x4b6f309a	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x65d35bff	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x8aaf063e	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xaab81d73	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xd3515797	ufshcd_resume
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xe7e7bcdb	ufshcd_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xeda1f0f4	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x52343f17	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x56f6ba50	spi_bitbang_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x7b94a7a4	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xb9262c28	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc1c586a9	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xc7a40a61	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x0a1e534f	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x4a4129ba	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x4b004ba1	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x7eb8ac0c	dw_spi_xfer_done
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x8983e806	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0x63a93d84	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x02bd049d	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e31114d	comedi_buf_memcpy_to
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x118898e2	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2cea82ac	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2d35f1ec	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3ba9a19d	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3cc37ac7	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3fe71dd1	comedi_dev_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4f478339	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x59f664d9	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x61c1ddd5	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x63448efa	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6444eb1b	comedi_buf_get
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x742434d8	comedi_buf_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8a131147	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8d8056d5	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x917c6977	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x928fb568	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9ff7cd8f	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa26e1fe5	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa93795e5	comedi_error
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb22e8951	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb538feb5	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc02ff961	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc78473b6	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc8469c06	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xd72ee26a	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb985c16	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdeaa0e79	comedi_buf_memcpy_from
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe1215bfb	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe2180655	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x454a5cb1	subdev_8255_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0xaf1f1c00	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0xbe72c18b	subdev_8255_init_irq
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x1645e599	cfc_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x3a993302	cfc_write_array_to_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0x89e8ff18	cfc_read_array_from_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x78556333	comedi_dio_bitfield
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x94932717	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xd6504d3b	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xdae403cc	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xf97443dc	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xfc902c8e	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0xbcdd6498	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/rts5139/rts5139 0xbd5a0e51	rts5139_usb_ids
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1a5839c6	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x1cb021e6	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x44fa055a	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x649f1f0d	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x81fa0aa9	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x86442336	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x917a1270	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x91fe7220	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xaf5d671c	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb2978dbc	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd479613c	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xfd043433	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x382418a4	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x3f63d8ce	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x47ca5ac1	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x5bc2059f	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x5e6fb78b	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x6ec79d2e	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x90140543	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xb8f8aff1	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xc7dbb1b2	sockfd_to_socket
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xc8a686fd	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe1038569	usbip_recv
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe6df1535	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xf9e0315a	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x39575404	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x5b0ea943	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x92f9b2c6	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x0c5dd962	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xfb70b151	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/dwc3/dwc3-omap 0x4db92025	dwc3_omap_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x13e84ed7	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x255de333	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2a98f63a	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4d3cd6f4	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x57180601	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5d8e64c9	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x682be422	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6e18a2d3	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x6ee86e2d	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x74eb7fab	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x758b9c0f	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x7e16ed85	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8a2b9c93	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8af2d157	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x8e8e4e78	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x912c644c	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x91e5aeb3	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9d850a40	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9f1b2104	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa26bc4cd	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa5c3153b	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xacf3240b	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb373f755	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xb4804936	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcdc4a21b	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe6169e83	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xfdaf8ec4	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x0419b22a	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x144d6370	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x70a367e3	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xcf663bec	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xbd42d522	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xde3207a7	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x0edcd6d7	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x3863ebf7	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x386cf50d	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x6618940e	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x68841ad4	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x697de26e	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb6135ff2	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xb9d52a91	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf3138e0e	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x00ddf23f	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x38eb5145	samsung_usbphy_set_isolation_4210
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x4806c4fb	samsung_usbphy_rate_to_clksel_4x12
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xb52bbc64	samsung_usbphy_rate_to_clksel_64xx
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xc8e023d1	samsung_usbphy_parse_dt
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xd90bcdb7	samsung_usbphy_cfg_sel
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xe39fac2a	samsung_usbphy_get_refclk_freq
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xe9cd033e	samsung_usbphy_set_type
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x011298be	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x12801151	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x18804359	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x25614c1c	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2a6f0082	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x361dd9c7	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x3deac5a1	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x4d3564cd	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x52dc24ab	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x53b60d55	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x5bca97a3	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6592ae72	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6e7fc046	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7fa1ca1b	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x817db22b	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xa61a7397	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcbfb7ace	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xdc9ec4d9	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xedeccc89	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf484312a	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xfb1f6719	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x0c851280	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x29c10031	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x5d461e2a	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x7be4ba7d	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8199325f	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x82b25173	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x8cc70c37	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x9a0ad2bc	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa075a68f	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa25d6901	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa913561b	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xac1bac8e	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xacbac71c	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbe1cd82a	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc03fa9b8	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcc24f58c	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xcd6340b3	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd0cf380b	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xe8acd41e	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf01372a0	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xfdc93f2d	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xff81b5aa	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x10726a47	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1566c941	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x1df7a96e	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x232256c4	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2b3bedba	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x2ef38de0	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x32bcc5e8	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x339450c7	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x38e6448a	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3a52d41e	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5d76afe9	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6699292c	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x6ea23c6f	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x810e4671	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x91bbbc92	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9335c8ef	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9acb4f4e	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xa1a849a3	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xb778b992	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc47b8166	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc6baec34	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xce757c84	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd2fbe31f	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd54a01cc	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd700723a	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd8a4e7ab	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdd4197c7	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe021bfbc	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xeb42453f	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xfcbb51ba	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x058df9e8	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x0c6637f8	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x1e7080c3	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x6e55a441	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x805ea57f	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x9824ac6b	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xcfeb1018	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xd54589cb	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xe57fe3e0	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xfe8c8e3b	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x5e17e49f	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x7b214780	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xa1d5e71b	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb907c609	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xc28fd9b6	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xcaecb8eb	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xf25175d4	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x3d33cd86	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x41ea67b4	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x17ef32a1	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x3011fea3	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x6daee60b	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x828aff10	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x86cb7b44	w1_write_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x96233b6d	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x9b3fc552	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc55bc461	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xd95c4c5e	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0x33c5c935	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x4bac1469	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x4e724d3e	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x8e56acc5	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x03db17a0	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x17ce645d	locks_end_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x1e9b82d0	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x2bac3f0f	locks_in_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x5ac7fca1	locks_start_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x6c02c149	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xc81e1022	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xdd8ef543	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xee3d2f8c	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xfcd1932f	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0067fcab	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00ede72c	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0368573b	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x04a38982	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x05d9ad18	nfs_setlease
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x075be4c0	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0deed2fb	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x104e07e4	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x109a2216	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10b75c21	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1267d5a6	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x14c5dfd3	nfs_initiate_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x15443feb	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x184c5497	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1a4e76f9	nfs_file_splice_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b11adf7	nfs_writehdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1d05fba3	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2131babf	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x216e824a	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x23caa565	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x23d9a404	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x24e9b280	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x256c0fe4	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2596a232	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x27b7a628	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2807abd0	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28d9282f	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29832f44	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2d33b2d8	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2f2dacef	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2fde513e	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x30505cd0	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x30729e75	nfs_pageio_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3173c7ce	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x31c6d924	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3232b0dd	nfs_readhdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x37fc4625	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3881cdd0	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3982463d	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3b219c6e	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3da29648	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x41d7fa0e	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4259e334	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x45fe3b35	nfs_initiate_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x484857ed	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x48491b09	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x486e8aee	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4bf60fd7	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51e209d1	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x535272d1	nfs_generic_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x566fed9c	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5a34a503	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5d931768	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e1d863a	nfs_sockaddr_match_ipaddr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x617d7f25	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x625e28ee	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6955686d	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6db875c2	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7037885f	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7132caf9	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x77059dd9	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x77c1c285	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x78094903	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7bcd5fe0	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7c980e71	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8241e65e	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x82a59ff4	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x840411d9	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x84929f56	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x849dd005	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x853d12d0	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85c5e835	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87937d7f	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x87ffbabe	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88d706c2	nfs_file_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x88e30d32	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89bc5a64	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8c6e2513	nfs_generic_pagein
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x991f08a5	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x995e33f1	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9e48ba22	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa011812f	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa01aefbd	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa4a039f6	nfs_writedata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa5879f3f	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8d2d1ce	nfs_callback_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa48cd89	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa92ac7	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaca4c0a9	nfs_readdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb10b3c6a	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2c8bf64	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb42f4c90	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb4b5f7db	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb5965d01	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb5da29c2	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb87f2d63	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb8f0814a	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbb554f16	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd7ab54f	nfs_put_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc38a1b0c	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5666432	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc7666110	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc963d1e0	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc56ec91	nfs_pageio_add_request
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcf6a327f	nfs_fscache_set_inode_cookie
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd418477a	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd43c2668	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd4ea1b80	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd8083e4c	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd8349519	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xda5b079a	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb62e532	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdbbb44e0	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xde65d638	nfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdfbcd97f	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe0d91a94	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe2a65492	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe3762a47	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe77ddbce	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe84306f7	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeb900503	nfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xebe45f38	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec0bf194	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xec94357e	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xedebfd45	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeeceb206	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf06e4d4c	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa217b9a	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfa3c6938	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfc753924	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfdf149cb	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x06a061d2	pnfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x08d04ea8	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x09c1afda	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0bcced59	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0d6ae5f5	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x12fea4b4	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x16139488	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x176f1d72	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2cedbdee	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x35c114b9	pnfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x37141036	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5b90d2b4	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x67f12396	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69f28b5d	nfs4_insert_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6c38077e	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6e41ebbb	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x84388754	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9157ec0f	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x94d34c9e	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9e162168	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x9f7c25ba	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa3f90376	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa92e3e31	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb20e5825	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbff13b3f	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc211f200	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc9ace861	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xda329923	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xdd81eabf	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe5cc85b5	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe6d199ab	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xea7310fa	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xef8fe399	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf9e25453	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xff13ab34	nfs4_proc_getdevicelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xff527fb3	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x10f22c8f	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xc07fa8f5	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1919284a	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x247dbc7a	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x2723aa59	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x37e1b9d5	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x74c97109	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x87dbf5e2	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x959c6457	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x4939bac5	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x65072f49	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6d82fa8b	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xb0e3c4e9	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xe9b57c75	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xeb6e0512	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x025e2d69	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0562c415	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x16b2e575	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x377b647f	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x5469ce31	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x7083dbd5	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x89502fe7	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xb4bd060c	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xd46e714e	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdc823ea4	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe2bd47db	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe417d940	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xf119b2cb	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x2ef544ca	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x63820d7c	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x05513b71	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL net/802/garp 0x4b4fbc29	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0x51774f31	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x7ddff9cc	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0xb68ee1db	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xd3da9aaf	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0xf5b3d6de	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x0d9887e0	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x248e3aee	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x4053e889	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xa897172b	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/mrp 0xb981fa4c	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xc4d7ff25	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/stp 0x699ef0e1	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0x88ba77a4	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x6e387716	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0xf2801e15	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xe5ecdbe7	ax25_register_pid
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x4ad0b245	bt_debugfs
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x09a123b7	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0fd686ab	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x10bce644	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2a7411bb	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x38d3481d	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x3d70929a	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x41eefaff	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x487f17a7	dccp_insert_option_elapsed_time
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x555c355f	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x561cd287	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5b2147ee	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5bb01cd4	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5dbde425	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5dc56032	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x60a6c225	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6a2bccd6	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x6c1b1767	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8481f5fa	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8a64a167	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x93d5ec81	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9565607e	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9a81a6d6	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9c799f55	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9f428e88	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa4cfae53	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa72171f3	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xad04ce82	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb4a6bbc2	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xbd2bc916	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xc2548a8c	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcc421587	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd4686dd7	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd92f50f9	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xdcbc0764	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf3017e21	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf8166f00	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x360590e9	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x6f86893b	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x7675bdf7	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x78ea6fbd	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xa6e58b61	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xb7052160	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x34a8238d	register_switch_driver
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0xd323b6b6	unregister_switch_driver
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x0c4133c1	gre_cisco_register
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x1f6efd86	gre_cisco_unregister
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xa259b785	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xae61d2a8	gre_build_header
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xbbc96fbf	gre_handle_offloads
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xeef0854e	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x16495f63	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x1fba7de1	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x21e96d1a	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x95f488a6	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xe6364b93	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xf8afcf4e	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x02da6569	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x103a4367	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1ef2b7b4	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x1f623a5c	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x2ff04fc8	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x4106206e	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x47b49b63	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x4c43cbe4	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x56e73c15	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x57230444	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x67859ac9	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x9e0a2967	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xa052e117	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xca264d0d	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xb533fbd9	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0xb0873be1	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_conntrack_ipv4 0x6d40a921	need_ipv4_conntrack
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0x0fc1ffb9	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x832c45c2	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xac76f9e9	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xd0579678	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xd5c2db53	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xe135631f	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x31c25407	xfrm4_mode_tunnel_input_deregister
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x66273258	xfrm4_mode_tunnel_input_register
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x06744267	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x4707b04c	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x47bb8d24	ip6_tnl_dst_check
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x81549220	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x89888fae	ip6_tnl_dst_store
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x5e85974b	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x24d9569d	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x02fda20a	l2tp_tunnel_sock_put
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x171e9ab4	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x23acb84e	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2e1d0510	l2tp_tunnel_sock_lookup
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5c7cc1f5	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x5fe251b7	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x66d1d2b3	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6baabd7d	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x6db7374f	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x79f0aedc	l2tp_session_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9a9b2497	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb37a02fd	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xba0daee0	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc0b1da9a	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc58980e7	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xc78d518e	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xce06af4b	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x93895094	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x00575a72	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x55a9e607	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x59247b8e	ieee80211_iterate_active_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x62f74c6d	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x82644264	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xa6fb6aaf	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb1a3f6eb	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc71891d0	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xe3671e2a	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xff02fbd3	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x0c9a591a	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x1a6ef9ef	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3244bb1d	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5ead1cd6	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7762965e	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7daa2a59	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80339d78	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80ee118c	ip_set_nfnl_get
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x883d6572	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x8bde07ab	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x92067f38	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa53f3d28	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc3b062db	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe7be15f6	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfda3ec7a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x319cb64f	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x3ba5ed1c	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x45354452	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x9b2d74a0	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x041f1403	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x09323f83	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0a968667	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x100fbee5	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x12cea41f	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x16a9268e	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x19faf628	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x1f7bd53b	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x21a5e374	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x21c12942	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x22d247df	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x26546b22	nf_nat_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2779eb62	nf_ct_dying_timeout
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2c9b8b5a	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2ce6cb5c	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2ea4277e	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32be4a0a	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x33d28ee1	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x340fd657	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x411ed766	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x42295834	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4675b36e	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x49bb6bf2	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4e822641	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5176f2e3	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x56a0e152	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x57911155	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5d689224	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5dd6430c	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5fe0e06d	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6267c62a	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x639a70eb	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x63f9aafe	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x644e1935	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x650ef42a	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x692e281e	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6b7ee898	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6d6407a5	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x701f3ab6	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x73426d58	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x798f75ae	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x819b6642	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x82fdbdd5	nf_ct_l3proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x86f2c647	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x887ff4c9	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8e178d61	nf_ct_delete_from_lists
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x944928b9	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x98839071	nf_conntrack_flush_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9a2a94a9	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9b4e59fe	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9bb08e0c	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9cb32880	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9f97dae2	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa564a899	__nf_conntrack_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xabc7f1b5	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xada55f03	nf_ct_nat_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb002d6e6	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb23f3373	nf_conntrack_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb64d0316	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb6a53652	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbcfadf1b	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbd59b62b	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0240dd4	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0e6e8ef	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc54451fe	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc96d2778	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcbb14c13	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xda58b10f	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xec60c736	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xed3d50c6	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xee7ac0af	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf2d08a6d	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf94a28d7	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfb3a92ba	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfcfb968d	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfe67ad39	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x4bcb32cc	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0x6422488d	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x0a9d4005	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x0f617d36	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x1be519f3	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x501911de	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x63eb1004	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x7a51e626	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8a6ff009	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x8ea1298e	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc8c91ee7	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xcf229065	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf14072fe	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0x88cf648b	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x3cac8ea3	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xb781a019	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xd659a799	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xfac2351c	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xc0114e20	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xe639db70	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x00c87f6b	nf_nat_sdp_port_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x06f12af7	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x14984f43	nf_nat_sip_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2b1cf2ac	nf_nat_sip_expect_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x30aed830	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x4eabf0b3	nf_nat_sdp_media_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x69e5692d	nf_nat_sdp_session_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x90130ee0	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa21ca8db	nf_nat_sip_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa232900d	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xb14020fe	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xecf9e084	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xfc41cc89	nf_nat_sdp_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xde186bc0	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xeb1e1b2e	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x005e1e1d	nf_nat_tcp_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x40997c3e	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4ae5e608	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4f76a0d3	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4fd07ec0	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5adb6158	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7d938709	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xbeb0e472	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xf9684092	nf_nat_set_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_tproxy_core 0xcc86f7b4	nf_tproxy_assign_sock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x161fc656	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x1b610b84	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x39f94023	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x6f9cbd63	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb2aca5d1	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb62b153c	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xb66bd457	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x21f6bba6	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x9fb30151	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0xa76cfa7e	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0ce086b4	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x451ce2ad	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x4df73056	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x5b47516a	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x66f4df94	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x6abadd6f	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x745a66ee	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x9b7783d6	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xac873af3	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb42059af	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xed217a59	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf3219429	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xfd7c72c7	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x57909dc1	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xd0f26ea3	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x07f2a354	nci_spi_free_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x273f1938	nci_spi_allocate_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x9bcfee4f	nci_spi_register_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xe7e32d79	nci_spi_unregister_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xf2deb302	nci_spi_recv_frame
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x05853561	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x078b5852	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x2d629515	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x2fa3f386	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3221e3b6	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x3c23af7a	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x43839bce	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x4ed38f52	rds_message_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x56678be4	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0x658e3861	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x7fe61e67	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x910a5de2	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x9633780e	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xa17defd2	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0xadf4559a	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xc642cc2c	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xd5cf6f51	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0xd68587bd	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xde862d50	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0xea579e39	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0xee0eebd1	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xf614d862	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0xfb72151b	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xfc86adf1	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x0a0ee9a9	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xdc0bd424	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x3a209e20	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x57ccee66	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xde206ebf	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x01acce38	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x022fceeb	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x026d8bc1	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x033b0988	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05ee9910	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05fd549d	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x06b8b005	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x082b1a68	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x08700810	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09199eba	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09515f63	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0dd0aacd	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0ebcda20	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0fdd62de	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12c586c5	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12ca4fab	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x13d25872	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14954ad6	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x149bc91e	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14e34aa1	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x15966b0f	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1819999b	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1831c722	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x185f7bac	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x197dd6af	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1a0f4cd0	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1adbf055	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b151510	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1b8934c2	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1bcc6a48	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c36f7e5	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1cb447f3	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1d6b7b3b	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ecfe5a4	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1fb449bb	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x240b08c5	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2750ed01	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27c62ba8	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x27fafc88	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x282a0ede	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28e6ec13	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28f8e374	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2974a75e	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2ad05a2f	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e5c43e3	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f9fb289	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31f9d9bc	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x33b452eb	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35b69fcc	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x35dbbbd4	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39771151	xprt_alloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a927cd7	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f218ca4	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40bd5c8d	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x40d47451	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4226a167	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47605b08	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x47912729	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48b36534	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x491d357a	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4be6cdfc	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d3d7c07	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5006c50c	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x501047cb	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x52f37256	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x539b3fc7	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53ce78ef	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x54bf079d	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5622a6f3	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x58037a91	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5869f711	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59da71ab	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5af399f8	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5b76bc26	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5bd4d939	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5c5c06f2	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5dde3c42	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61e2704d	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x63d25f55	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66ee0e1b	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x678f5676	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69502053	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69a378ba	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69da0165	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f031a31	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6f5b5746	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x710f315a	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7309fedb	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x731c8110	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x73b3a795	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x750a683e	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77de1ba9	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78135b88	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x790ea6f3	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7afc3f3f	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7dc6426e	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f28d6e1	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f8c65cc	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x805dad1c	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80a8fb9a	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x824239c8	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x85fc70a8	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x86da1867	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x87c96627	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8916825f	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x89a0451a	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8b3bc73f	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8d3e8ed1	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8f2acf1d	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x902b06ea	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x92069bbc	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9251b2b2	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9473c471	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x95e8c750	xs_swapper
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x96561668	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x96825ff2	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x981e2ff4	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9985bdc5	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x99e2a07a	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9cefdfb4	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9f6e61f8	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa087a88c	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa099bd54	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa29d43c4	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa459dec0	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa49efef	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac3153f1	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xac63f09b	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xad3c4deb	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaeccfb0c	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xafd5d14b	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb07b6436	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb18f3aa9	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb1b276e2	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb201c298	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5b5fc2c	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb5ee0a99	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8814bf5	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb8e3b165	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9867cd9	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9ac38aa	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb9f69be2	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc074d17b	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3fe047b	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc4d49172	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc70aa09f	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc9aa5787	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc9d46064	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcfbf664c	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd0b53cf9	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd2c86c84	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd315ee2f	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7ba4c0e	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd7fdff14	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd822ecb2	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdaf0702c	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc18d5a9	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc224e84	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdd40cc10	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xddd3d005	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2913272	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe2d73bb6	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe62da0f6	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe76cf3e9	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe888f985	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe962a9b8	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe9fbfdca	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xea4a6a29	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeab15379	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeaf40ded	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xee489088	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf09813df	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf6b77883	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf97986e9	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9bf3df5	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfe05aa0e	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c1a83d6	vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0d4e7481	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x271ed1ff	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x28a3a129	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x54cfc5a5	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8be606e5	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x8fbc162d	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9bd8d861	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xa0528e31	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xb2d95413	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbe123dd6	vsock_add_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xe5e9a9eb	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xec9e73ff	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x0c1b7203	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2452a822	wimax_msg
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x28f36ba6	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x2f24f4f9	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x4dd63c32	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x511698e4	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x52ccec7b	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x906bd4ef	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x93f4893b	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xaab219b9	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb3736063	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xb8627523	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xcdf3a80a	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x014ff54a	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x11b6df64	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x217832bc	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x2b7ff8e1	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x42aa2227	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6faf10e2	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x85c3badf	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc44b6e92	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xc971b863	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe0e11485	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xed511e94	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x00778770	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x056bb269	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0b9e5852	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x33b96ccc	pskb_put
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x74e1a843	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7c30b8c7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x92dbc6c1	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xbc8b0f41	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xce7a55c1	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xe122af95	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x12efbd3d	ipcomp_input
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xa2945320	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xe2d99272	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xea2e3cb7	ipcomp_destroy
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x005c2fad	atmel_pcm_mmap
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x75ea15b3	atmel_pcm_new
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xece0c892	atmel_pcm_free
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0x6848f086	pm860x_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0xbeeed40d	pm860x_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0x6d2cf1aa	ab8500_audio_setup_mics
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0xca05c8d0	ab8500_audio_set_ear_cmv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x05ddbf0f	arizona_lhpf4_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x12ecde17	arizona_out_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x196694e3	arizona_ng_hold
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x206e3ddf	arizona_in_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x296459a8	arizona_init_spk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3bbba352	arizona_hp_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3bfcb4ef	arizona_set_output_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3f429d4c	arizona_isrc_fsl
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x41b95c1f	arizona_in_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x48921a3f	arizona_set_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x547a7178	arizona_rate_val
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57170933	arizona_init_dai
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57e590a8	arizona_lhpf1_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x660d8a35	arizona_lhpf2_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x6c2d0120	arizona_in_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x733bbfd7	arizona_out_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8c821bc2	arizona_rate_text
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8dd35bf2	arizona_mixer_values
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xab6861be	arizona_mixer_texts
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xade3792b	arizona_simple_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xb2c7f9e1	arizona_set_fll_refclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc07a8181	arizona_lhpf3_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc9c29637	arizona_mixer_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xd37f6c01	arizona_init_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xdaf4d199	arizona_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xe752a77b	arizona_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xf6b27bea	arizona_out_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cx20442 0x7cd8c91f	v253_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-l3 0x78c84c7e	l3_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x62ad32fb	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0x2d2b750c	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max9877 0xd46359a7	max9877_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x3ef322c8	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0xb581462a	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x2ba8d2e2	twl6040_get_clk_id
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x527d2b45	twl6040_get_dl1_gain
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x9ef4a608	twl6040_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xa7bf71b9	twl6040_get_trim_value
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xffff70a5	twl6040_get_hs_step_size
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wl1273 0x24399933	wl1273_get_format
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x005003ed	wm_adsp1_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x12a3476c	wm_adsp1_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x4f9c8211	wm_adsp1_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xc254988f	wm_adsp2_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xd4fd833f	wm_adsp2_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0xf8259a0e	wm_adsp2_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x03044d27	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x142bde64	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x3ad82ecc	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x3af709d0	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x9cfa92ec	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xa0b3b615	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xb7595fa4	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xd35ff2ba	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0x47709ca2	wm8350_hp_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0xbf5224b7	wm8350_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x08d437d0	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0x31f58af8	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0x8f015a3c	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xe7aedbdb	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8996 0x1fc971be	wm8996_detect
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x0c34cdef	lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1bba79d3	vfs_lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x271ca00c	lib_ring_buffer_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x290bb128	lib_ring_buffer_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x30e9921b	lib_ring_buffer_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x3b605fc9	lib_ring_buffer_switch_remote
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x408bff2b	channel_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x426b4c35	lib_ring_buffer_read_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x47baecf5	_lib_ring_buffer_memset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4e7b5442	lib_ring_buffer_read_cstr
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4fd4605c	channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x5925a5f2	lib_ring_buffer_reserve_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x63d35f04	channel_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x65947160	__lib_ring_buffer_copy_to_user
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x6a2b339c	lib_ring_buffer_poll
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x6b838853	channel_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x78cd7f88	lib_ring_buffer_switch_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x7f0be64f	lib_ring_buffer_move_consumer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x7fbb0990	_lib_ring_buffer_copy_from_user_inatomic
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x80fb9bcb	channel_create
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x84b217d9	lib_ring_buffer_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x875b4b01	lib_ring_buffer_snapshot
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9c7440f3	_lib_ring_buffer_write
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xae9ba9bb	lib_ring_buffer_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xce58d229	lib_ring_buffer_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xceb12363	lib_ring_buffer_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd77a142a	vfs_lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd91eea03	channel_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd9c1a41b	channel_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe2086e72	lib_ring_buffer_release_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe74cb79e	lib_ring_buffer_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe760a326	lib_ring_buffer_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe7888dbb	lib_ring_buffer_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe889123c	lib_ring_buffer_ioctl
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xebdef9d9	lib_ring_buffer_get_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xee5295f3	lib_ring_buffer_put_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xee9a98c3	vfs_lib_ring_buffer_no_llseek
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xf0c1622a	lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xf5926403	lib_ring_buffer_read_get_page
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xfa6125db	lib_ring_buffer_open_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xfbf81ece	channel_get_ring_buffer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-statedump 0xfc319b21	lttng_statedump_start
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x05f28425	lttng_add_prio_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x0ed64a49	lttng_find_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x16b8c009	lttng_probe_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x28c1eb6e	lttng_event_get
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x3ab07e18	lttng_add_hostname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x52cef5f3	lttng_add_ppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x55d24d13	lttng_remove_context_field
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x578ea042	lttng_event_put
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x65fe95bd	lttng_probe_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x72e31c04	lttng_transport_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x734e02f8	lttng_metadata_channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x88be006d	lttng_add_vppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x8a3ca880	lttng_add_procname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x9059e485	lttng_add_pid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xad5963bc	lttng_add_vtid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xc0b33a9b	lttng_transport_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd050476d	lttng_add_tid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xd3c41ac2	lttng_append_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xed50c054	lttng_add_vpid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xf56c3e23	lttng_add_nice_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x7540ff22	lttng_kprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x7db67683	lttng_kprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0xe2d29390	lttng_kprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0x6db2b365	lttng_kretprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xa322fbd9	lttng_kretprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xa99c4934	lttng_kretprobes_destroy_private
++EXPORT_SYMBOL_GPL vmlinux 0x00007bf1	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x0003c88c	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x0028322b	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x0031592b	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x0067df75	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x00c4dc87	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x00e08355	snd_soc_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x010988f7	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0x01120c7f	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x013b64af	udc_attach_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0144806c	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0x0148adb6	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x014ba6d2	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0x015a81a0	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0x015ef88a	snd_soc_dapm_get_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x015ef909	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x01c57b4a	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x01c6cb0c	cpu_cluster_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x01dd5e58	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02049993	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0x02403416	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x02516014	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x02925ea2	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x02955e76	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x02bc3aef	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0x02c625b8	cred_to_ucred
++EXPORT_SYMBOL_GPL vmlinux 0x02d3a2d7	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x02d91fa6	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0x02d9a336	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x02dd7ba3	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x02e79677	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x0326e9fb	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x03298e5d	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x0345555a	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x0359759a	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0x03743b37	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0x03ba9c4c	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x03dced20	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x0431a5bb	cgroup_load_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x043c9806	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x04486e88	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x045991cd	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x04755a1d	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0x04884d86	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x048b5f8d	twl4030_audio_get_mclk
++EXPORT_SYMBOL_GPL vmlinux 0x04911920	snd_soc_register_platform
++EXPORT_SYMBOL_GPL vmlinux 0x0496f14a	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04ddb3f5	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x04e71151	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x04f6c792	ahci_ops
++EXPORT_SYMBOL_GPL vmlinux 0x05072659	platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0x050d51d8	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x0531dcb8	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0551f0ce	tick_nohz_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x05703992	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0578b459	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x06055d83	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0x06178847	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0x062a415c	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x062fc169	xen_hvm_resume_frames
++EXPORT_SYMBOL_GPL vmlinux 0x0630452d	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x06311dd2	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x06438115	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x064a48be	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x06ba0bb4	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0x06dceffb	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL vmlinux 0x06eec0e8	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0x06f7ca31	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x06fa3554	gfn_to_page
++EXPORT_SYMBOL_GPL vmlinux 0x070e5bdd	netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0x07455fa9	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x075fd832	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x07787639	device_move
++EXPORT_SYMBOL_GPL vmlinux 0x07b0576a	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b291d1	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07cf3227	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x07e34ec6	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x07ed48c3	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x07f147fc	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x0800d2d1	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x08166d09	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x0832fae0	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x0845b77d	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x0853dfea	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x08576cea	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0x0863824c	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0867ff22	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x08729bda	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x087fd0f4	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x088adb66	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0x0899f091	hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x08c227de	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x08cd6f4c	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x08e246b9	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x0912d62d	vchan_dma_desc_free_list
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x092f6601	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x09469482	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x094a3e04	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x0966effa	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0973d186	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x0999141f	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x09b360d4	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x09c891f9	kvm_put_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL vmlinux 0x0a09b0d9	filter_current_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0x0a0bc03e	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x0a10f4b2	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x0a1863e3	mtd_del_partition
++EXPORT_SYMBOL_GPL vmlinux 0x0a2c46c4	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x0a305b58	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0x0a4894a2	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x0a498376	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x0a4e145b	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x0a522ee0	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0x0a5958e8	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x0a6d302f	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x0aad634e	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x0aba2d8c	balloon_mapping_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x0ad41321	register_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b42bd68	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x0b461ea5	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x0b59390b	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0b5cd8ff	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x0b6936c1	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0b6ee9a2	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0x0b7e3554	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x0b88412d	kill_mtd_super
++EXPORT_SYMBOL_GPL vmlinux 0x0b891204	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL vmlinux 0x0b9dc6a8	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0ba651d1	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0ba8374b	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x0bae62b1	ktime_get_monotonic_offset
++EXPORT_SYMBOL_GPL vmlinux 0x0bbae511	return_address
++EXPORT_SYMBOL_GPL vmlinux 0x0bcc8e3a	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c08a06e	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c1aa6b3	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x0c1d1dfa	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x0c21c9c6	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c33220f	snd_soc_info_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cc2fd78	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x0cd45726	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x0d104082	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x0d2260e3	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x0d2e7958	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0x0d3603df	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x0d42ab18	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0x0dbd0e20	of_property_read_u8_array
++EXPORT_SYMBOL_GPL vmlinux 0x0dd45c7f	tpm_show_owned
++EXPORT_SYMBOL_GPL vmlinux 0x0de1874b	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x0de84ec1	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0x0e0852d3	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x0e215570	cgroup_is_descendant
++EXPORT_SYMBOL_GPL vmlinux 0x0e263d3f	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x0e80281d	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0x0ea5fcd4	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x0eab7ebd	ahci_print_info
++EXPORT_SYMBOL_GPL vmlinux 0x0ed36b2f	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x0ef19327	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0ef4e192	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0x0f1ca1f6	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0f20f4e2	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f4b3dd4	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0x0f64590f	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f8d0d38	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x0f907b3e	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x0f9db829	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0fb78fc3	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x0fbc1138	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fc3bd35	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x0fdbd5bb	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x0fe112dc	of_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x0fe65e8c	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x0ffffb53	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x1013a4d0	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x1017a0cc	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x1026c1d9	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x10291853	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x107b173e	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x1097f25e	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0x10c866af	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0x10def572	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x10edaf0c	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x11a903e7	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x11b64c6c	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x11c155df	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0x11d4b0a8	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x11f447ce	__gpio_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x121ed3f3	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0x122a3634	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1257daff	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x1258d9d9	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x125f6260	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x126a6819	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x12c485d9	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x12dedfba	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x12df9afe	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0x12e76a6d	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0x12ff9cc1	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x130eb3da	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x132ad03e	cgroup_next_descendant_pre
++EXPORT_SYMBOL_GPL vmlinux 0x1334ab43	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x133ef061	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x13436404	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x134535ae	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x1376dd2d	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13c83509	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x13e21824	task_current_syscall
++EXPORT_SYMBOL_GPL vmlinux 0x13f1cbf5	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x13f96852	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x1404bec2	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0x1405efc5	snd_soc_update_bits_locked
++EXPORT_SYMBOL_GPL vmlinux 0x140c1410	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x142a8be4	of_clk_get_parent_name
++EXPORT_SYMBOL_GPL vmlinux 0x1441541f	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x146b7e3a	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x14778a7b	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0x149b029a	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0x149dc4f0	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x149e4740	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x14a1d193	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x14a2abcd	sec_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x14d3e15c	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x14db47b1	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0x14f0f613	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0x14f875ce	devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x150adc37	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0x15166217	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1525f36d	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0x154a1cd8	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15ab5874	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x15b29e09	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x15f1ef3d	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x15f40010	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x1605c9eb	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0x164a71e5	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165c2efb	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x167a3d2f	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x16b731c4	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x16dcaa8f	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0x172f4dec	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x1739b81f	sec_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x175c8e23	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x177c338d	twl_get_version
++EXPORT_SYMBOL_GPL vmlinux 0x17829589	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0x178ea02e	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x179466c0	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x17acc7fa	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0x17b789d6	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x17b8ee89	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x17c55e8c	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x17f1f7ad	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x182306cf	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x18a27f34	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0x18b57eee	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x18c30c1a	blkdev_aio_write
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x1919e9aa	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x193c55d2	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x193d48e0	trace_current_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x197c330d	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19c0811f	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x19ee9869	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL vmlinux 0x19fc7f60	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1a082d69	max77693_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1a2a8267	mtd_erase
++EXPORT_SYMBOL_GPL vmlinux 0x1a318a32	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1a323362	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1a3fd9a7	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x1a462faa	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x1a839d4f	spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1ad83009	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x1af47d89	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0x1b1db26b	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x1b2409d3	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x1b28704b	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x1b2cb5c9	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x1b3193ff	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x1b3261e0	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b7ed001	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x1b92dd8c	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1bb5fc26	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1bb75c84	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1bce4eb5	xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x1bd0b5d2	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x1be672a9	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x1beff5a2	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0x1bff3cff	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x1c3c9c58	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1c52f1fc	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x1c544ad9	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c9f9bfc	dm_dispatch_request
++EXPORT_SYMBOL_GPL vmlinux 0x1ca15c9b	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x1cab44c8	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1cad6801	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x1cb5f86a	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0x1cc29d8b	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x1cd37c4d	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x1cf141c4	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1cfe78d1	kvm_release_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x1cffc4df	RSA_public_key_algorithm
++EXPORT_SYMBOL_GPL vmlinux 0x1d0d1717	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x1d1a6c27	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d7c3072	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x1d85d602	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x1daa29ec	sdhci_disable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x1dad443e	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x1de054d5	of_clk_del_provider
++EXPORT_SYMBOL_GPL vmlinux 0x1df4e366	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x1dfe433d	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL vmlinux 0x1dff8114	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x1e073151	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x1e09e9a0	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x1e214a4b	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x1e314b21	regulator_use_dummy_regulator
++EXPORT_SYMBOL_GPL vmlinux 0x1e3a88fb	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x1e426974	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x1e596df0	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e83fee6	HYPERVISOR_physdev_op
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ec4bf7e	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0x1ef58632	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0x1ef86fd5	devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x1f0cee33	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x1f0e3788	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x1f332e4c	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x1f37286e	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x1f54f1b4	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x1f7fe0aa	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x1f7fe22d	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f892675	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1fcece42	inet_twdr_twcal_tick
++EXPORT_SYMBOL_GPL vmlinux 0x1ffa4e78	snd_soc_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x20296101	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0x20918765	mmc_send_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x209c8bc9	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x20b95744	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x20bc3470	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x20bc7e3c	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0x20bd2cd9	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x20c5a303	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x20c8ec1b	snd_soc_jack_new
++EXPORT_SYMBOL_GPL vmlinux 0x20d57359	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL vmlinux 0x20ef43d7	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x2107cc33	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x21548fb2	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x219371d5	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0x21edf38c	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x2210a016	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x222ef222	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2241f645	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x2247b2e6	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x2259962f	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x22605d85	mtd_get_device_size
++EXPORT_SYMBOL_GPL vmlinux 0x22661f1e	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x226a674d	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22a3b0f1	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x22c16ecb	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x22cbf016	of_clk_src_simple_get
++EXPORT_SYMBOL_GPL vmlinux 0x22fb7c94	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x230233b2	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0x230994d4	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x232fe98d	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0x235cc705	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x23679939	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0x236904e2	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0x2373352a	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x2392bc6e	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x240580a9	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0x243647c0	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2447533c	ktime_get_real
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24e88ea2	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f2d831	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24fc46b6	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x257293b0	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0x2587f84b	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x25946228	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x259641fd	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x25c7ca89	fuse_conn_kill
++EXPORT_SYMBOL_GPL vmlinux 0x260404d6	snd_soc_get_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x263cd858	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x2649f527	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x265686b6	blk_queue_bio
++EXPORT_SYMBOL_GPL vmlinux 0x265e6f8e	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x269c505a	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0x26adb815	thread_notify_head
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26db49dc	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0x26f2b773	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2706d145	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x27132ab6	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2724fe75	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0x2778f247	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278899be	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x27cc3f4d	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x27dc125c	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x27df7c55	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x27e5f551	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x282198c8	tpm_show_caps_1_2
++EXPORT_SYMBOL_GPL vmlinux 0x28352ffa	snd_soc_platform_write
++EXPORT_SYMBOL_GPL vmlinux 0x2844daba	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0x284e08b1	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x28636232	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x2869ebaf	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x287e521c	nfq_ct_nat_hook
++EXPORT_SYMBOL_GPL vmlinux 0x288a1f77	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0x28a82da4	snmp_mib_init
++EXPORT_SYMBOL_GPL vmlinux 0x28a903c8	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0x28e7de88	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x29047f1a	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0x290da0d9	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x291fe74b	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0x29489c5a	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0x2957caca	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x297f10bc	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0x29a5cceb	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x29b7cd2d	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x29cbe42b	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0x29d201da	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x29d998bc	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0x29e66843	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0x29f3faaf	xen_dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x29ff00bd	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0x2a050ff0	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x2a504ad2	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x2a666e52	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2a8af21e	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x2ad1ece4	zs_get_total_size_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2ad9d326	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2aef59fb	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0x2aefedaa	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2b0b9d58	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x2b19af31	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x2b30babd	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x2b47382f	sec_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a6de8	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2b8b92ac	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x2b9a15e0	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x2ba0c0fe	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0x2babe81f	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x2baf9cd5	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL vmlinux 0x2bbd1a6c	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2bd73efe	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2bddfb83	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2c0c45a6	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c2c5fbc	regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x2c3ce44e	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x2c400c99	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2ca436af	ata_sas_port_async_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2ca4ebcd	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2cda2e9e	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x2cda89e7	dm_kill_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0x2ce32332	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2cf441ca	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x2d17a0e1	cgroup_taskset_size
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d64b5a1	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x2d92f3d0	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL vmlinux 0x2da5e9b5	nand_update_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x2daff675	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0x2db0e761	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x2db34e67	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x2dc3cff7	kvm_get_kvm
++EXPORT_SYMBOL_GPL vmlinux 0x2de59d3f	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x2e06877c	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x2e15c5cd	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e45e488	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x2e9670c0	pl320_ipc_transmit
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ebfc1ec	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x2ec789ca	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x2edd78d5	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x2ee89390	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2ef0abd2	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0x2ef6b5bf	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f3ee54d	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f64b532	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x2f8baf4d	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x2f99b0f7	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x2fb0f6ed	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x3015d5f3	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x30670cb1	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x3078082c	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x30877f1a	snd_soc_cnew
++EXPORT_SYMBOL_GPL vmlinux 0x308b733a	getboottime
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x30a8de05	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0x30fa0aec	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL vmlinux 0x30fbeb71	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3120bac1	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x31280f6e	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x313f59e5	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3172c6b8	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x317c466e	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0x31859993	of_irq_to_resource_table
++EXPORT_SYMBOL_GPL vmlinux 0x318b55a5	mtd_unpoint
++EXPORT_SYMBOL_GPL vmlinux 0x31a820ed	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x31be35d5	of_get_named_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x32259e86	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x32694156	rtc_set_mmss
++EXPORT_SYMBOL_GPL vmlinux 0x32711540	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328c42f3	sk_unattached_filter_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x329bbbde	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0x32a8d213	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x32b31a8c	ktime_get_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x32b9c5f6	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32d1c7c5	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0x32d4a37b	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL vmlinux 0x32f16325	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x32fd447a	monotonic_to_bootbased
++EXPORT_SYMBOL_GPL vmlinux 0x333e201a	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x33499090	soc_ac97_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33503290	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x336552ef	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x3385c8de	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL vmlinux 0x33883929	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x33a94a45	of_irq_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x33abca4e	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0x33cf9820	ahci_shost_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x34240e2b	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x3441c3d6	gpio_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x34474649	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x344c304d	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x346c64dd	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x348faeab	otg_ulpi_create
++EXPORT_SYMBOL_GPL vmlinux 0x34e1ecd1	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL vmlinux 0x34f4c8b9	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL vmlinux 0x34fe6739	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x35100cd5	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3511acef	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x352251d9	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x352b7d23	blk_rq_check_limits
++EXPORT_SYMBOL_GPL vmlinux 0x354056a1	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x3541f1ff	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL vmlinux 0x354570d1	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x355f30e3	usbmisc_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3582efb0	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x358ff60f	twl_get_hfclk_rate
++EXPORT_SYMBOL_GPL vmlinux 0x35cbe0b2	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL vmlinux 0x35deb20d	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL vmlinux 0x35f165f1	devm_reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x36480f5e	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x365b3af4	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x366e55e2	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x368eb2eb	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36b2e712	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x36be4912	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0x36de418c	crypto_lookup_aead
++EXPORT_SYMBOL_GPL vmlinux 0x36eeb311	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x36f82717	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3700154c	pkey_hash_algo
++EXPORT_SYMBOL_GPL vmlinux 0x37033f9e	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x37098fbd	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x372bcec7	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x372f97b0	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x3749d6cf	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL vmlinux 0x375d3f28	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x37711e6d	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x37a584ee	ahci_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x37b228c5	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x37cdc17b	tpm_register_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x37d6c516	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x381ad2d6	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x3823405b	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0x38620e38	gnttab_grant_foreign_access_trans_ref
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38abc000	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x38fc6b00	dapm_mark_io_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x39009ac5	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0x39030ab7	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x395cf18b	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x3967b095	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x39ba5d21	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0x39c75c09	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x39cb36e2	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x39fb16f0	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x3a24fbf6	opp_find_freq_exact
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a2abdbf	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3aa19d5b	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3aaaa4b0	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x3ab940fe	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x3ac75973	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0x3acdf325	twl4030_audio_enable_resource
++EXPORT_SYMBOL_GPL vmlinux 0x3ad1decc	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3ad82802	of_property_read_u32_index
++EXPORT_SYMBOL_GPL vmlinux 0x3af0db61	bmp085_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3af31f85	opp_enable
++EXPORT_SYMBOL_GPL vmlinux 0x3afdd7fe	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x3b0edb66	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0x3b94be6a	snd_soc_put_volsw_s8
++EXPORT_SYMBOL_GPL vmlinux 0x3ba89123	sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0x3c5f50f6	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x3c831441	arm_check_condition
++EXPORT_SYMBOL_GPL vmlinux 0x3ca17104	__snd_printk
++EXPORT_SYMBOL_GPL vmlinux 0x3cac21b9	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cd4862e	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0x3d0c8936	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d5cd5d3	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x3d682e79	balloon_devinfo_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d89b531	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x3dc526a9	arizona_of_match
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3e01c854	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x3e04a60f	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x3e0a89d4	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x3e2fa31f	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e452a00	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x3e54bea9	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e86a536	xenbus_bind_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x3e8af1c3	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x3eca2ad7	default_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3efb86e0	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x3f0b6748	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f14917d	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x3f3247b6	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x3f39d465	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x3f39f1aa	snd_soc_dapm_get_enum_virt
++EXPORT_SYMBOL_GPL vmlinux 0x3f5f9f9c	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x3f620a84	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3f69c73a	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f992790	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0x3fc001ac	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x3fff6814	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0x403064db	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x4031d3a6	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x40455e90	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x407ba39d	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x409db2f9	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c3202b	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40e0c2fa	aead_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x40ef29e8	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x40fbc2ba	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x4155a2f5	snd_soc_codec_set_cache_io
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418af62e	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x41a31c22	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x41e5ee1c	ata_sas_port_async_resume
++EXPORT_SYMBOL_GPL vmlinux 0x41fff2f3	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4207e7fc	dma_buf_export_named
++EXPORT_SYMBOL_GPL vmlinux 0x420cb500	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x420ff368	of_clk_src_onecell_get
++EXPORT_SYMBOL_GPL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x4258d116	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x426e3e98	tpm_write
++EXPORT_SYMBOL_GPL vmlinux 0x4270fc87	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0x42716f49	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x4282d990	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x428655ac	snd_soc_resume
++EXPORT_SYMBOL_GPL vmlinux 0x428e2a9f	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x42a84af1	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x42cab898	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x42e7e92c	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x42edca97	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x430e5257	of_alias_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x432fd7f6	__gpio_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x43505176	deregister_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0x43554fff	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x4355c42c	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x43977d9b	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43b466b0	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x43bac17f	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x43d7c1d9	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x43ed43ec	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x43ed82eb	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x43f84d2b	ahci_start_engine
++EXPORT_SYMBOL_GPL vmlinux 0x441e0ca2	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0x442bdd36	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL vmlinux 0x44404f11	kdb_register_repeat
++EXPORT_SYMBOL_GPL vmlinux 0x444f1735	cpu_pm_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4455e1b3	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x447497f5	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44987bf5	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x44a793ab	HYPERVISOR_grant_table_op
++EXPORT_SYMBOL_GPL vmlinux 0x44e3bcc3	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x44f5268d	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x452bab69	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x454d73c0	sdhci_free_host
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x457b77ca	of_fixed_factor_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x46066e5b	perf_pmu_name
++EXPORT_SYMBOL_GPL vmlinux 0x46074c17	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4607702b	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL vmlinux 0x460f7531	wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x4631e888	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x464a944a	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0x464e7c19	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x4672e88b	__crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x469dfe5f	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x46d8fd35	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x46d9f914	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x46f08551	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x46f6801b	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x46f8ce4d	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL vmlinux 0x471fd7b9	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x475b29b5	tpm_read
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4769208d	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47a97300	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x47c90544	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x47e2c0d5	bmp085_detect
++EXPORT_SYMBOL_GPL vmlinux 0x47eec715	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x47ff399f	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x480fb54d	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0x48146b7f	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x48213844	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL vmlinux 0x48ab5da7	pkey_algo
++EXPORT_SYMBOL_GPL vmlinux 0x48c865a1	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x48ca8947	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x49170b10	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x492621d2	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x49348758	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x493acade	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0x494587ea	amba_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x494fe8e1	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x496fa379	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x497388b4	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x49774c92	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0x4977ba6e	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x498d293a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49923f7f	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x4994ee1c	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x49976efc	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x49ae9c59	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0x49c71af5	tpm_open
++EXPORT_SYMBOL_GPL vmlinux 0x49e0e7aa	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x49ead211	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x49ebc672	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4a259491	snd_compress_new
++EXPORT_SYMBOL_GPL vmlinux 0x4a6a7611	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0x4a83000d	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x4a89726c	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ab04318	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0x4adfc15c	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0x4b05673c	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL vmlinux 0x4b106a97	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x4b17b645	of_property_read_u16_array
++EXPORT_SYMBOL_GPL vmlinux 0x4b3d899e	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4b46ca88	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4b542ef2	blkg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4b81243d	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x4bac624a	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0x4bbc637c	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x4bc62a81	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x4bde5c77	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x4be5a7e4	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x4c23178c	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0x4c26fb6e	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x4c44cd11	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x4c47ec15	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0x4c4894ac	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c6a2906	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x4c6b3b71	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4c773548	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x4c80edcb	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x4ca5c4e0	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4caeab49	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x4cf4e4d5	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4d018135	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x4d1f621a	amba_ahb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x4d4e721e	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0x4d7aa3bd	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x4dce24f4	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4dfcf815	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x4dff2246	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e47d8f2	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x4e4db67d	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x4e4e5742	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x4e77e7ce	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x4e7913a6	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0x4e844c88	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4e866fa4	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x4e9ae187	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0x4eb67aca	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4ec1aa69	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x4ee3afd0	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x4eee83aa	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x4ef16711	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4ef915e6	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f1dbbf9	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x4f334a73	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x4f37eaf8	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x4f6172ff	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0x4f98d766	cpu_pm_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4fa09a3d	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x4fafd712	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x4fd1978c	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x4fd4e89d	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x4fd75e91	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x5053e2a6	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x505ab52d	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x50601122	of_property_match_string
++EXPORT_SYMBOL_GPL vmlinux 0x506691f1	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x50673ef0	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0x506cc085	tracepoint_iter_stop
++EXPORT_SYMBOL_GPL vmlinux 0x50850b55	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x50c3be0b	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x5113a361	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x5126397c	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x512cf16c	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x513a65fd	snd_soc_register_codec
++EXPORT_SYMBOL_GPL vmlinux 0x514729e5	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0x516cc767	__clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518e316a	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x51927070	wm8994_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x51961f49	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x5197b731	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x51dac032	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x51f1fc11	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x52150e29	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0x521e1fff	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x52212010	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x522beacf	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x5250d4aa	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0x525fceab	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x526e97c4	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x5290fb47	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x52a9eff3	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x52df039c	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL vmlinux 0x52f5323a	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0x5300536d	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x530c2872	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x5321b688	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x5340073c	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5355b8c6	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x537ec717	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0x538645df	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0x5394a00a	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0x53a3e486	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x53bb3ea3	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x53dfb33a	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0x53e80b9b	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x54011f08	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x541fba34	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x543f1a3f	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x544031e2	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x5444c774	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0x544aab61	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x5460f155	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x546477b2	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0x546b8f2d	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0x547406c4	extcon_find_cable_index
++EXPORT_SYMBOL_GPL vmlinux 0x547e5dcf	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x548d2bda	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL vmlinux 0x5494eb6c	usb_gadget_map_request
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x549b3670	tty_prepare_flip_string_flags
++EXPORT_SYMBOL_GPL vmlinux 0x55337174	usbmisc_get_init_data
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x55b45153	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x55dc64ed	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x55f04c21	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x55ff4dba	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL vmlinux 0x561e4b77	irq_of_parse_and_map
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564f1dca	klist_add_after
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x568666bc	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x569f66ef	dev_get_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56c74768	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56dfe15c	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x56e9103b	cpu_pm_enter
++EXPORT_SYMBOL_GPL vmlinux 0x5713bc14	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5714f08f	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x573f3d77	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x575257cb	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57e850be	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5818a581	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x5819c8aa	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0x582490ea	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x582be91b	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x583dcd19	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0x58413099	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x5863053b	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58b322c4	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0x58e14f15	HYPERVISOR_event_channel_op
++EXPORT_SYMBOL_GPL vmlinux 0x58f54cf7	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0x590481c7	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x5922b9e6	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x5922c603	amba_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x59366e64	mtd_write
++EXPORT_SYMBOL_GPL vmlinux 0x593f5d10	snd_soc_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x594074b8	mdio_mux_init
++EXPORT_SYMBOL_GPL vmlinux 0x5947abbe	max77693_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x5971d31f	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x59b048fb	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x59c372a7	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x59cb6de6	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0x59dff930	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x59e2743e	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x59ed4eed	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a30b8af	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0x5a3c2afd	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x5a446332	of_clk_add_provider
++EXPORT_SYMBOL_GPL vmlinux 0x5a48534a	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x5a532c71	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL vmlinux 0x5a5d98a1	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0x5a6db9bf	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a999b32	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x5aa17998	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0x5ab691b7	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5adb799d	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5af21a77	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x5b1016e0	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x5b212457	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0x5b4e379c	of_prop_next_u32
++EXPORT_SYMBOL_GPL vmlinux 0x5b5cc4a9	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5b8ca26d	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL vmlinux 0x5bfab84c	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x5bfc6427	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5c0dff42	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x5c2f49ed	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x5c3370a5	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x5c4bfff6	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x5c544a21	ahci_save_initial_config
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cccc4a0	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5cd1e39d	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x5cd7c3d0	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x5d1098c6	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d1c1bac	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0x5d2efac4	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x5d3141ab	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d71f799	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0x5d86cecc	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x5d8c44d3	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x5dd18380	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5dfb3f19	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5e15104c	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x5e163eae	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL vmlinux 0x5e2503ba	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0x5e34ab39	xen_remap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x5e67f5b6	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x5e8c40c0	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x5e96e542	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0x5eacba1f	ahci_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x5ec11326	crypto_nivaead_type
++EXPORT_SYMBOL_GPL vmlinux 0x5ee4b72f	tcp_is_cwnd_limited
++EXPORT_SYMBOL_GPL vmlinux 0x5f0f027e	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL vmlinux 0x5f127cff	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0x5f248f72	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0x5f7a210f	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0x5f8158de	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x5fc3cf72	dapm_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x5fd44d97	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x5fdbf101	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x600dd8ff	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x602ecb65	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x6032b4ef	snd_soc_dapm_put_enum_virt
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60ad1236	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x60e6c59a	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0x60f26fdf	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x6101113d	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x6114d8a4	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6139cf0d	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0x613b8620	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0x615069a2	xenbus_dev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x61570fe1	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0x61757702	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL vmlinux 0x617a5345	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x618944ef	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x61932978	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0x61afdac1	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x61b669b5	regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x61f99fd5	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL vmlinux 0x6219e127	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622dacba	tick_nohz_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x6248b5be	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x624a6406	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x625921c8	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x6267ac40	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6291991e	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x62de8818	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0x62e1b7f6	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x63031775	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x6316e61d	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x6318757f	mdio_mux_uninit
++EXPORT_SYMBOL_GPL vmlinux 0x63205de1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x63771f72	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x6390efda	of_modalias_node
++EXPORT_SYMBOL_GPL vmlinux 0x63cc88b6	user_read
++EXPORT_SYMBOL_GPL vmlinux 0x6420296f	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x64311a16	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x645ee1b0	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x64730aef	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x647537f3	pl320_ipc_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6475aeec	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x64bd7a23	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x64bda35d	nand_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0x64d35397	sysfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x651b3517	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x653ba8ee	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0x654192a0	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x65693695	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0x656a2ac1	blkio_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x65816b12	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0x65859cfe	mtd_writev
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65cf79d9	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x65d5c42d	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x65d6d0f0	gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x65eada12	gfn_to_memslot
++EXPORT_SYMBOL_GPL vmlinux 0x65f022bc	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x661128b9	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x663c16d6	gnttab_grant_foreign_access_subpage_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6644fe20	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x66479d3a	omap_control_usb_phy_power
++EXPORT_SYMBOL_GPL vmlinux 0x6649e2e5	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66939b5a	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x66948e36	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL vmlinux 0x66a0e800	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL vmlinux 0x66b73278	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x66c49506	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x66c6c80e	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66f7f60d	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x67128609	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0x6722a187	vchan_init
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x67643d26	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x676c10fc	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x6791040e	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x6812cf8d	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x68226e85	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x682452df	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x684356e9	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x68b84015	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x68c6eb59	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0x68cd5e1e	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x68dd992c	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL vmlinux 0x68f02910	devm_kzalloc
++EXPORT_SYMBOL_GPL vmlinux 0x69041aaf	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x694607d7	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x694be42a	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x694f923e	ahci_thread_fn
++EXPORT_SYMBOL_GPL vmlinux 0x6956f67d	serial8250_rx_dma
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x69887ba3	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x698be398	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6992c344	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x69a31e8d	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0x69a41416	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x69e9a2cb	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x69eaa920	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x6a49ca07	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a6062a0	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x6a650cd3	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x6a811370	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x6a9d3ad6	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x6aa04335	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0x6ab498eb	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL vmlinux 0x6ab77430	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x6ab922b2	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x6aba167a	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6aea0700	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x6aedf354	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x6af21a31	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0x6b12a286	__inet_hash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b39765c	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL vmlinux 0x6b89ab24	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x6b94a42e	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x6ba89a20	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x6bc211b1	tcp_init_congestion_ops
++EXPORT_SYMBOL_GPL vmlinux 0x6c2d5f0a	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0x6c31a4d1	device_schedule_callback_owner
++EXPORT_SYMBOL_GPL vmlinux 0x6c49c4f2	clockevents_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c4f3bc0	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x6c620ed2	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0x6c63dd2f	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0x6c749afe	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x6c7b1685	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d5ae8	__gpio_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x6c96b83c	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6caeaca8	wm8994_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x6cb23039	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x6cb52c0e	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x6cc78c5c	set_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x6cd4eb2c	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0x6cf1a8ef	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x6d1c48b7	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0x6d24b98b	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x6d2c37b8	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d31e93b	tracepoint_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x6d672d33	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x6d8f58d8	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x6d9e5425	of_address_to_resource
++EXPORT_SYMBOL_GPL vmlinux 0x6df7f269	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e05c4e7	ahci_hw_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x6e0efb34	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x6e224c6e	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0x6e3fd0df	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x6e42d5cc	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e680a3b	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x6e69a2fd	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x6e7114d4	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x6e7f53ec	snd_soc_register_component
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6eba0f06	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f26a6b9	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x6f4b7c08	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x6f52d6c9	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x6f83e5e2	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x6fa38f87	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x70003d9c	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0x700c19aa	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL vmlinux 0x703189d7	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x703b442b	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x703bee35	snd_soc_put_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0x704e5fc8	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x704fea6e	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL vmlinux 0x7076b111	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70b30879	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x70b75e61	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x70bb651d	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x70bc504e	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d85f89	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x71008581	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7116a9ba	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x718f76e2	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x71930ed3	of_property_read_string
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x71edb0af	kvm_vcpu_init
++EXPORT_SYMBOL_GPL vmlinux 0x71f6b7be	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x71fa0970	mtd_block_markbad
++EXPORT_SYMBOL_GPL vmlinux 0x7224e89a	tpm_show_durations
++EXPORT_SYMBOL_GPL vmlinux 0x7267db00	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72909ea7	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0x7291019b	__cci_control_port_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x72b212ff	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x72b72455	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x72ba80f1	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x73056d81	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x730bd0c7	asic3_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x7336201f	dm_requeue_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0x736a8581	gfn_to_pfn_async
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73aa21f2	sdhci_add_host
++EXPORT_SYMBOL_GPL vmlinux 0x73b5e517	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0x73be2104	smpboot_register_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e234d1	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x73fa1ea0	tpm_show_active
++EXPORT_SYMBOL_GPL vmlinux 0x74034676	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x740849ea	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x7424f96c	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x744a174f	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x744b2cd6	irq_find_host
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x747ca62f	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x74926cb1	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x74954462	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0x7499972c	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c96c68	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x74c9d5ed	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x74d30eaf	mmput
++EXPORT_SYMBOL_GPL vmlinux 0x74df5044	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x7511dad1	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x751f549a	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x752cad66	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x753c0419	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75abae33	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x75b89bf9	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x75ba8f7b	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75c8a11c	inet_twdr_twkill_work
++EXPORT_SYMBOL_GPL vmlinux 0x75dc70b0	musb_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x75fd5b3f	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x75fdb615	crypto_rng_type
++EXPORT_SYMBOL_GPL vmlinux 0x7625f47d	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0x7642f552	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x768c5005	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x768fb6db	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL vmlinux 0x76973ec1	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x76ce992a	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x76e2c1d1	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x77145222	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x7718d3b8	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0x77214cea	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x7733b822	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x7733e783	snd_soc_jack_report
++EXPORT_SYMBOL_GPL vmlinux 0x7735c674	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL vmlinux 0x77733898	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x77797a3c	mtd_point
++EXPORT_SYMBOL_GPL vmlinux 0x779355c1	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x77ac32c9	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0x77e35191	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x77e78218	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x77e8352f	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x77fcdfb4	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0x77fe2035	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0x78011431	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x7829ca45	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7840b42c	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x78772456	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x787d5fcd	css_id
++EXPORT_SYMBOL_GPL vmlinux 0x788f04af	xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0x78a401b8	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x78c02d3f	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL vmlinux 0x78c5834c	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0x78ccf60e	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x78cf4589	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x790dfb19	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0x792f8bf9	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x795a49b4	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79764997	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x7977e705	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x799c98e2	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x79c1ff1d	register_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0x7a51b64b	opp_get_opp_count
++EXPORT_SYMBOL_GPL vmlinux 0x7a86d427	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7a933c98	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7aa441b1	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ad25e3e	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b2163bd	HYPERVISOR_tmem_op
++EXPORT_SYMBOL_GPL vmlinux 0x7b5a411d	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7b601576	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7ba4b5ac	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x7bb496f9	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x7bd4b199	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x7bf035e9	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x7c09ea94	kvm_read_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x7c13ab72	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x7c262e82	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0x7c31aec4	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x7c6a49ce	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7c74ad6f	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0x7c7f1de5	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7c8b51e4	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL vmlinux 0x7c8ecda0	__mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x7c9ad2eb	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x7cb2b989	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cc1b7fd	max77693_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x7cc2e814	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7cee0bbf	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x7d058bad	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x7d0e1168	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7d5da024	dapm_reg_event
++EXPORT_SYMBOL_GPL vmlinux 0x7d7b9c2f	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dd4758a	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0x7e52022a	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x7e528150	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7ed27270	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7ed68941	asic3_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x7edd00fb	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x7f0038a8	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0x7f0ae534	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x7f60e837	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x7f7088b4	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0x7f7422ed	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x7f82ac5f	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x7fab5350	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7fabdddf	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x7fd6adf8	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x7fda896b	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL vmlinux 0x7ffc8718	gpio_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x800808d5	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8043eb8c	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x80482765	sysfs_get_dirent
++EXPORT_SYMBOL_GPL vmlinux 0x808b7e85	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x8095ddab	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL vmlinux 0x80a65392	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x80afc6ed	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x811b4260	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x812849de	cgroup_unload_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x814150fd	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x81ebf787	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x81efd8ad	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x81f90b5d	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL vmlinux 0x81fe2d07	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x82014073	opp_find_freq_floor
++EXPORT_SYMBOL_GPL vmlinux 0x8208096d	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x82145b55	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0x8226642f	__gpio_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x8230c27e	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL vmlinux 0x8235e053	sdhci_alloc_host
++EXPORT_SYMBOL_GPL vmlinux 0x826a78b8	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x827a507e	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8292d93c	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x82939ebd	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x82a1722f	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x82a2599d	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x82c2e31e	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82e929e9	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x82fec260	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0x83356871	tpm_store_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x833dfb03	unregister_mtd_user
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83a5ae2e	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x83bcdd46	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x840f96b7	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x844c6a88	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x84e608c6	inet6_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x85094737	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x8509ee8a	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x8518e4fa	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x851f3d83	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0x852e568d	of_get_nand_ecc_mode
++EXPORT_SYMBOL_GPL vmlinux 0x852f3e32	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x853fadb6	snd_soc_read
++EXPORT_SYMBOL_GPL vmlinux 0x85478a0b	inet6_hash_frag
++EXPORT_SYMBOL_GPL vmlinux 0x85573a4a	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x856629e7	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x857fd892	__rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x859ce5f9	ahci_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x85a55f5d	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x85c0bc8c	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x85c10896	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x8600681f	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x861359ed	of_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x86278c3c	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x862b9816	cpu_topology
++EXPORT_SYMBOL_GPL vmlinux 0x8654b538	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0x865ce34d	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x868a97c5	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86b4d1f7	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x86eb7c36	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f90bcc	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0x86ffbf0b	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x871df5e3	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x873f3d33	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x875156d1	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x87984b16	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x87a2d870	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0x87a4120c	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0x87ba8758	__cci_control_port_by_device
++EXPORT_SYMBOL_GPL vmlinux 0x87bb4e32	of_usb_get_phy_mode
++EXPORT_SYMBOL_GPL vmlinux 0x87d3ccb5	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x8817e59d	sdhci_remove_host
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88ad57a6	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88bd0a5e	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x88c86b65	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0x88d6dff1	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x88f4cb06	blkg_lookup_create
++EXPORT_SYMBOL_GPL vmlinux 0x89039670	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x8909c022	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x890a67c9	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89295f62	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x8939f2a9	register_mtd_parser
++EXPORT_SYMBOL_GPL vmlinux 0x89403c8b	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0x89446b57	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL vmlinux 0x89502f0c	gnttab_subpage_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0x89678915	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x8968c9dc	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x896f19e5	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x897cfbc3	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0x8995c0f8	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x899a601e	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89cea9a8	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x89db1701	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x89e12085	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x8a04b9fe	tracepoint_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8a0e08d1	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x8a123efc	cgroup_taskset_first
++EXPORT_SYMBOL_GPL vmlinux 0x8a3cd082	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x8a4b8cda	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8a57463a	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x8a5c7a80	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8a6b660d	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8ae152b5	of_get_nand_bus_width
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b1759fa	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x8b1c405d	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8b3b6c09	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0x8b4c0196	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x8b66f9e0	xen_platform_pci_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x8b752ac1	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x8b775d3a	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x8ba5afe9	HYPERVISOR_memory_op
++EXPORT_SYMBOL_GPL vmlinux 0x8bd159ea	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x8bf371f6	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c127c88	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x8c18e6ae	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL vmlinux 0x8c21054b	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x8c488ae8	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8c7139ba	css_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x8c8ba878	snd_soc_codec_readable_register
++EXPORT_SYMBOL_GPL vmlinux 0x8c962f69	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8cc8ab28	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0x8cd607c8	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0x8cecfaf2	sdhci_resume_host
++EXPORT_SYMBOL_GPL vmlinux 0x8d10807b	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x8d12dd36	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x8d94386a	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x8da11d63	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8dbf7aaa	privcmd_call
++EXPORT_SYMBOL_GPL vmlinux 0x8de4310b	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0x8ded6912	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL vmlinux 0x8e2f4183	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0x8e30636e	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x8e3759cd	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x8e3be5eb	mtd_panic_write
++EXPORT_SYMBOL_GPL vmlinux 0x8e5f0671	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8e7894bd	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x8e8d22ee	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x8ea55ba6	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x8ea6a6d0	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0x8eb1f650	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x8eea75f9	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x8efe4938	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0x8effebd3	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x8f27a2e0	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0x8f5525fc	opp_get_freq
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8fbcae97	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x8fd134a5	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0x90228d68	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL vmlinux 0x90500c7c	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x90574050	cci_ace_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90705b7f	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9082d068	kprobe_decode_arm_table
++EXPORT_SYMBOL_GPL vmlinux 0x9083cea6	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x908e64ed	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x909ad11f	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90adb223	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x90b763f1	HYPERVISOR_console_io
++EXPORT_SYMBOL_GPL vmlinux 0x90c8e094	gfn_to_hva
++EXPORT_SYMBOL_GPL vmlinux 0x90cb40f5	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0x90e66d47	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x90fa0853	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x91948486	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x920aacca	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x920f695a	snd_soc_cache_read
++EXPORT_SYMBOL_GPL vmlinux 0x922187f1	register_mtd_blktrans
++EXPORT_SYMBOL_GPL vmlinux 0x9224f3d8	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x923dfc4f	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x9265cdff	snd_soc_bulk_write_raw
++EXPORT_SYMBOL_GPL vmlinux 0x9269f24b	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x92727509	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL vmlinux 0x9290a59b	snd_soc_test_bits
++EXPORT_SYMBOL_GPL vmlinux 0x92981d12	snd_soc_add_platform
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92b5758a	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x92d291cb	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x92d31cfb	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x930ed9b9	of_usb_get_dr_mode
++EXPORT_SYMBOL_GPL vmlinux 0x931005fd	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9326988d	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9328301c	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x933183c7	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x9354cd33	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x93756eb8	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x93d2422d	snmp_mib_free
++EXPORT_SYMBOL_GPL vmlinux 0x93d54205	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0x93e3b41b	tpm_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x93e7dbf3	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x9404915f	mtd_table_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x940cf7db	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x942d49fd	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x942e1958	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x9458d0c4	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL vmlinux 0x947d7b6e	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x948476a6	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0x94a4e7dc	ahci_kick_engine
++EXPORT_SYMBOL_GPL vmlinux 0x94a68723	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94cda681	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x94d5e268	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0x94e1823c	hrtimer_start
++EXPORT_SYMBOL_GPL vmlinux 0x94e8cd13	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0x94f24ae8	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x952a3ffb	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956a91ba	gpio_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x95847556	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x9593d904	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x95c01219	vchan_tx_submit
++EXPORT_SYMBOL_GPL vmlinux 0x95c70a71	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0x95f6ee15	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x963592fa	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0x96459603	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x96475454	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x964e62c6	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x96619305	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x9673ddc2	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x96a22790	vmcore_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x970b89c7	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0x970cce24	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x9711f62a	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x971e0c7c	clockevents_unbind
++EXPORT_SYMBOL_GPL vmlinux 0x97298abf	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x9745c52a	of_fixed_clk_setup
++EXPORT_SYMBOL_GPL vmlinux 0x97704c40	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x9787df50	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x9793f9f3	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0x97a3ec56	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x97bc2120	kvm_set_memory_region
++EXPORT_SYMBOL_GPL vmlinux 0x97caa3b7	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97e8f73b	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x97ea5618	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0x97f355b6	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0x980fd3ee	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x98202095	of_init_opp_table
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983fd966	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9864bfc5	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x98731efa	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9894c452	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0x98bde311	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0x98c9f584	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x98cc564a	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x991484c4	of_property_count_strings
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x99527677	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x9968a838	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x9978f00e	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x999a7dc1	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x99a97c68	__netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a2449ae	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x9a357d9b	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x9a3f6f86	tpm_show_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x9a7ffb18	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9ab95fb7	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9ac75faf	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x9aca444b	get_monotonic_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x9ad57ee5	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b0e9c58	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x9b11dbc1	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x9b4f364b	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x9b6b7a17	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9b6f61cd	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9ba0956e	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0x9ba9493a	nand_release
++EXPORT_SYMBOL_GPL vmlinux 0x9be8d0cc	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c160f36	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9c34a3ea	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x9c403b3a	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL vmlinux 0x9c576e57	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x9c812e2a	ahci_stop_engine
++EXPORT_SYMBOL_GPL vmlinux 0x9c82078b	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x9c86ed6a	snd_compress_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x9c86ede0	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x9c9d3c82	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x9cb8848b	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ce88add	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x9cf9668e	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d0dbc0e	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d2806a6	kvm_init
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d4a2042	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x9d7ce5e4	ahci_init_controller
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d872af9	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL vmlinux 0x9d9c7113	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x9d9d1522	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x9dbeec66	tpm_remove_hardware
++EXPORT_SYMBOL_GPL vmlinux 0x9de4203a	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x9de86b31	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9dfe35c3	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0x9e09d274	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9e0e4580	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0x9eb4ae70	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x9ec2f9fe	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x9eced4be	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ed996a8	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x9ee37756	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x9ef06e8a	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL vmlinux 0x9f0664bf	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0x9f30f83d	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x9f3f98e1	of_get_nand_on_flash_bbt
++EXPORT_SYMBOL_GPL vmlinux 0x9f517986	HYPERVISOR_hvm_op
++EXPORT_SYMBOL_GPL vmlinux 0x9f7918c1	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0x9f7acd9d	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x9fabd667	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0xa017d223	cgroup_rightmost_descendant
++EXPORT_SYMBOL_GPL vmlinux 0xa0233697	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0xa05166aa	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xa060a4dc	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0xa064f393	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xa07dc017	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0xa0b2eca5	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0xa0b35aac	cgroup_taskset_next
++EXPORT_SYMBOL_GPL vmlinux 0xa0b5eb5a	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa0b89d3d	class_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xa0babc40	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xa0bdc5a8	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xa0e0a4be	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa12ce9e8	__scsi_get_command
++EXPORT_SYMBOL_GPL vmlinux 0xa14225e1	ahci_reset_controller
++EXPORT_SYMBOL_GPL vmlinux 0xa15ff219	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xa1a81ab0	mtd_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xa1acf639	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa1bd7822	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa1d4dd59	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xa206a6a6	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL vmlinux 0xa29fd310	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0xa2b2b915	usbmisc_unset_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa2b9ddf9	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0xa2c29f28	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xa2d6e175	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0xa2e5748a	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0xa31e850f	mount_mtd
++EXPORT_SYMBOL_GPL vmlinux 0xa32062ce	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0xa32cac66	cgroup_next_sibling
++EXPORT_SYMBOL_GPL vmlinux 0xa34190b4	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa367f693	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xa38160a2	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xa3833504	vchan_find_desc
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3b010fb	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa40ee827	opp_find_freq_ceil
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa4a2a492	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0xa4bac758	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa4ea04ee	of_property_read_u64
++EXPORT_SYMBOL_GPL vmlinux 0xa4eed856	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0xa50b646e	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xa5159c36	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0xa533316b	user_update
++EXPORT_SYMBOL_GPL vmlinux 0xa53459c2	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xa55053ed	sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xa565d974	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xa56ba5c2	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa57ef540	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0xa588f371	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xa594e9c5	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xa5a1f095	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0xa5a5c9a8	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0xa5aa9513	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0xa5d60fe4	ftrace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa5db4934	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa5eff7ac	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xa61b1477	tracepoint_iter_start
++EXPORT_SYMBOL_GPL vmlinux 0xa61d64cd	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa63485af	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0xa66f8149	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa694c604	snd_soc_dapm_put_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xa6a0a273	max77693_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa6a609f3	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xa6b12d35	snd_soc_cache_write
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6c6a3ff	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0xa6cffb05	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa6dc7234	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6fad7ad	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xa6fba5c9	tpm_show_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xa7096961	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xa71f9930	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xa724257f	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa75312bc	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0xa7bb7b74	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0xa7c50b55	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xa7e20df3	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7f137c3	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL vmlinux 0xa7f92105	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0xa80277d2	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0xa84687dc	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa8524ce5	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xa8925658	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0xa8937c67	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xa89b7f49	get_mtd_device_nm
++EXPORT_SYMBOL_GPL vmlinux 0xa8a92393	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0xa8efe65d	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0xa8f59416	gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xa90b07a9	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0xa92541c5	of_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xa95766a7	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0xa9707968	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xa9886e0d	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0xa9a82042	gnttab_trans_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0xa9aef2e1	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL vmlinux 0xa9b2cfd8	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL vmlinux 0xa9c5f7af	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9e94c4f	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0xa9fc3f54	gnttab_grant_foreign_access_trans
++EXPORT_SYMBOL_GPL vmlinux 0xaa03d0b2	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0xaa08026b	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa2afc51	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xaa38c2e0	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaa438561	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xaa4cb3af	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xaa4d2120	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0xaa4d8c40	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xaa71f9db	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xaa9278ed	inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaab45034	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xaac1ba13	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xaad615ae	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0xaae5e60a	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab0bed26	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xab1b9c93	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xab2ab7d2	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0xab3c8338	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab8ceced	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0xab93d26a	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xabc044b2	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xabc270f3	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xabca2a18	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xac5b7b77	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0xac5eb4e0	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0xac648b43	snd_soc_info_enum_ext
++EXPORT_SYMBOL_GPL vmlinux 0xac83f4ef	snd_soc_codec_volatile_register
++EXPORT_SYMBOL_GPL vmlinux 0xac8c410b	crypto_aead_type
++EXPORT_SYMBOL_GPL vmlinux 0xac9487f2	md_trim_bio
++EXPORT_SYMBOL_GPL vmlinux 0xaca1d4f6	tcp_reno_min_cwnd
++EXPORT_SYMBOL_GPL vmlinux 0xace30988	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xacfa4a89	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xad10e1cb	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0xad17645a	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0xad1d2da3	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0xad35c10f	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xad5a6715	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xad6ced12	cgroup_taskset_cur_cgroup
++EXPORT_SYMBOL_GPL vmlinux 0xad6ed473	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0xad79f959	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL vmlinux 0xad873046	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xad8d9ac4	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0xad8f9554	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xada073a3	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0xada38534	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadd5dd1f	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae05cab2	snd_soc_codec_writable_register
++EXPORT_SYMBOL_GPL vmlinux 0xae0dd7d0	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xae0f6b4e	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xae1d38c2	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xae401066	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6b3096	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xaea1d4ad	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xaeb8a09e	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xaebf1511	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0xaed69690	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xaedafa5f	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0xaee7647c	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xaef67399	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xaef8775e	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xaf1c1638	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0xaf2123c0	tpm_dev_vendor_release
++EXPORT_SYMBOL_GPL vmlinux 0xaf30a508	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0xaf348da7	cpu_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xaf368d09	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xaf39a666	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xaf4ff4d8	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL vmlinux 0xaf641b83	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xaf6ad30a	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xaf791208	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0xafc8f883	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0xafcf77eb	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0xafd2c8ac	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0xafd32555	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xb00e4af5	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xb0265f52	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb03025e9	amba_ahb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0xb0329a15	tpm_show_caps
++EXPORT_SYMBOL_GPL vmlinux 0xb03ace19	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb05a6087	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0xb06b7b58	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xb0715237	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0xb0afdf36	kvm_write_guest_page
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb0c54ace	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb0ceead1	amba_apb_device_add
++EXPORT_SYMBOL_GPL vmlinux 0xb0fb01b7	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xb10d55bc	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xb13d1800	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb149e343	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xb15261c3	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0xb17d98a6	serial8250_tx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb196bdde	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1c1bb3b	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1f4df8a	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL vmlinux 0xb212e9cb	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb21e121d	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb22467b0	dm_set_device_limits
++EXPORT_SYMBOL_GPL vmlinux 0xb225b98d	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0xb23b6684	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xb254339c	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xb265940d	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xb2a06a45	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0xb2a6e358	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xb2a94798	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0xb2b810f7	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0xb2e4e53b	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb33899f8	sync_filesystem
++EXPORT_SYMBOL_GPL vmlinux 0xb350f190	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb36f15af	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb37daad9	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0xb39bac15	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xb3ccaa5e	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xb3cd3f3f	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0xb3d807b8	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0xb41d4f26	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xb43332d1	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0xb466d3c1	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0xb4a4de80	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4cbfc87	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xb4d9b515	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0xb4db4c95	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4e5fc05	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb50fe3b2	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb52553ce	snd_soc_write
++EXPORT_SYMBOL_GPL vmlinux 0xb56f8c8c	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0xb5884e82	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5cb8145	hrtimer_get_res
++EXPORT_SYMBOL_GPL vmlinux 0xb5e35823	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb63752a2	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xb6457e75	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xb64d1378	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xb67021c2	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xb671a841	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb67b2219	cm_suspend_again
++EXPORT_SYMBOL_GPL vmlinux 0xb67c64fd	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb6807d42	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0xb6932cd2	dapm_regulator_event
++EXPORT_SYMBOL_GPL vmlinux 0xb6951ad7	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6c635af	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb70f8bae	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0xb74c417a	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0xb75eba95	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0xb7646cb1	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xb77bae46	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xb78bf568	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0xb7951210	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xb7bb3bb7	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xb7d69434	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb800a72c	inet6_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xb8076886	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0xb83ab14f	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0xb8562aec	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xb86a8159	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb8805c79	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xb890a927	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0xb8b5e773	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xb9089651	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xb916b80b	__get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb91c012c	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xb972aa1f	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b6c815	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9da2997	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0xb9fc129f	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xba1491eb	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0xba59b381	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbaab8784	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xbab0d535	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xbad71da0	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0xbadb3b36	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xbae4c7c4	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xbaea8c6a	get_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xbaed6bf5	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb11cfba	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xbb306bc4	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL vmlinux 0xbb644cd6	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xbbe74368	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xbc276e81	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xbc59a7af	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xbc682645	snd_compress_register
++EXPORT_SYMBOL_GPL vmlinux 0xbc84947e	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0xbc9c37b2	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0xbc9e70d2	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xbca8c567	mtd_lock
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcaf3971	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0xbcbaa80a	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0xbcc4227b	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0xbcc566b2	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0xbcc9217c	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd29232	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0xbcd45748	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xbcf89ab6	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0xbd07db28	ahci_do_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xbd0cdf44	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xbd2f5b72	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbd79872f	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xbd9baec6	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0xbdce30ee	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL vmlinux 0xbe106d11	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe1abdc2	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xbe4567f8	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xbe86c0c4	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xbe98086e	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbea04544	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0xbeaa040b	regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xbee6e0e6	mtd_is_locked
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf1d0256	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xbf34a1e8	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xbf72230f	d_materialise_unique
++EXPORT_SYMBOL_GPL vmlinux 0xbf86ecd8	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0xbf8d86c3	bmp085_probe
++EXPORT_SYMBOL_GPL vmlinux 0xbfa234d5	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xbfe84f6b	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xc03bd33c	kvm_read_guest
++EXPORT_SYMBOL_GPL vmlinux 0xc073c535	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc088467b	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xc0a0738f	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc0adadab	sdhci_get_of_property
++EXPORT_SYMBOL_GPL vmlinux 0xc0b580e8	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0xc0bf6ead	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0ec0bd9	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL vmlinux 0xc11b4470	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0xc11bd00f	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc1367c29	ahci_check_ready
++EXPORT_SYMBOL_GPL vmlinux 0xc154e25e	snd_soc_platform_read
++EXPORT_SYMBOL_GPL vmlinux 0xc1641cb6	skb_gro_receive
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc19f59d7	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc1f04f68	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xc1f4e995	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0xc206551f	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc25a7118	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0xc25bda1e	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc292e736	snd_soc_info_volsw_ext
++EXPORT_SYMBOL_GPL vmlinux 0xc2a0fd26	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0xc2a97c37	usb_gadget_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xc2ae43b8	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xc2affcd8	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0xc2b1a283	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL vmlinux 0xc2b8f021	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0xc33c7900	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc3440a92	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xc34efe27	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0xc354685e	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0xc35b3d63	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc3678f8f	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc3712b8a	of_platform_populate
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc37e4a67	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc385cb58	perf_num_counters
++EXPORT_SYMBOL_GPL vmlinux 0xc3a0b7b0	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0xc3ae58b4	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0xc3b93bba	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xc3f2c98b	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0xc40447fb	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc43fe475	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0xc454fc7b	twl_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xc471c67a	twl4030_audio_disable_resource
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4b50c4f	rq_flush_dcache_pages
++EXPORT_SYMBOL_GPL vmlinux 0xc4bd4a4e	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0xc4c7de0e	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc4d07a02	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xc4eb271b	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0xc508bf0b	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xc50b9e9a	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0xc5356d50	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc553442c	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc5d37180	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xc5dca0ee	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0xc60f75ec	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc614d9f4	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xc6160728	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc644f240	kvm_resched
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa090	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0xc68b9c4c	mtd_block_isbad
++EXPORT_SYMBOL_GPL vmlinux 0xc690866c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6b995cb	of_reset_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xc6cc8b65	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc7074e2a	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xc7189dd6	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0xc71b3595	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0xc71c0098	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL vmlinux 0xc722bf28	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc769b61a	opp_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xc792482e	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc794bcb0	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7abe998	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0xc7adf833	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xc7b690db	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7fdaa46	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0xc7ff0063	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc810d3ce	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc815ecad	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xc81fe249	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL vmlinux 0xc836da1f	sysfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xc852b487	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc8806288	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8b3312d	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xc8dc13be	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xc8f0c7bd	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0xc902cf65	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc9928bf7	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc99d3447	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc9dd70aa	snd_soc_get_value_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9ee7908	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc9eef639	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xc9f395fd	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xca08baa3	sdhci_suspend_host
++EXPORT_SYMBOL_GPL vmlinux 0xca29b648	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xca2ac067	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xca3d7200	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xca65b324	sec_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xca737f8c	kvm_release_page_clean
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xca85d8cf	tracepoint_probe_update_all
++EXPORT_SYMBOL_GPL vmlinux 0xca914509	opp_disable
++EXPORT_SYMBOL_GPL vmlinux 0xcaa85a5b	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0xcaa92b2c	wm8994_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcad970b6	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0xcb0dcbe3	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0xcb1492ae	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0xcb3637e4	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb6a23c4	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xcb9de59e	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xcb9e2d6c	bmp085_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xcbc23308	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xcbc46759	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xcbddce51	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcbe1c612	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcbfcc5ea	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0xcc183bb7	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0xcc1f1c3d	inet_twdr_hangman
++EXPORT_SYMBOL_GPL vmlinux 0xcc76507b	xen_unmap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc8d4b67	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xccadf7f3	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xccb23881	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0xccbfe1a2	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccdab5d3	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0xccedc2ed	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xccf7a115	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xcd2a4e2a	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcd48d405	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcdb7d8d5	arizona_of_get_type
++EXPORT_SYMBOL_GPL vmlinux 0xcdc0594e	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd15087	of_irq_map_one
++EXPORT_SYMBOL_GPL vmlinux 0xcdd3001d	snd_soc_cache_sync
++EXPORT_SYMBOL_GPL vmlinux 0xcddba9cc	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xce0b9b59	max77693_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xce46e140	ktime_get_ts
++EXPORT_SYMBOL_GPL vmlinux 0xce4b1802	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL vmlinux 0xce5847f7	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xce5d4ac1	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce6c8fce	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0xce93a912	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xce96095d	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xcea36623	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xcea53321	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xced18b96	omap_control_usb3_phy_power
++EXPORT_SYMBOL_GPL vmlinux 0xced3129f	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcf064bdd	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0xcf164361	tpm_show_pubek
++EXPORT_SYMBOL_GPL vmlinux 0xcf16ac6e	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c1b75	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c2828	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0xcf93f37f	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0xcfaaa852	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfccb7a0	tpm_show_pcrs
++EXPORT_SYMBOL_GPL vmlinux 0xcfd4937f	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xcfda9d4a	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xcfed6bb1	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xd00531d8	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xd014df0d	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0xd025b4ac	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0xd026d518	HYPERVISOR_vcpu_op
++EXPORT_SYMBOL_GPL vmlinux 0xd02e4907	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0xd03a6341	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd03e51a2	dm_underlying_device_busy
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd0a1f665	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0e1a150	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd0e8c5e4	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0xd111ed82	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0xd13556a3	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0xd13d2d26	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xd13e2e0e	ahci_reset_em
++EXPORT_SYMBOL_GPL vmlinux 0xd1466e45	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xd14bc4d9	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xd14e4c06	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd17fd764	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0xd18a155e	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0xd1a4c904	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0xd1abc937	devres_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xd1b0a9a9	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL vmlinux 0xd1b2db37	tracepoint_probe_register_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xd1f526a2	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd201f793	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd2197b0b	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xd21df6ee	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xd22ee7bd	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0xd240a616	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL vmlinux 0xd261c134	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0xd26825e8	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2793388	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd2814933	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xd28efd32	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2ada7a6	snd_soc_register_card
++EXPORT_SYMBOL_GPL vmlinux 0xd2b35dd7	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0xd2e945d0	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd2f5c2a1	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0xd31c8ee5	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xd31ca0f5	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0xd31e7254	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0xd31e8ea9	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd327fd97	xen_dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xd32fe193	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd3314414	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0xd33ada8b	cci_probed
++EXPORT_SYMBOL_GPL vmlinux 0xd34a2e8e	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0xd372435b	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xd375c96b	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0xd3778abf	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd37e13b4	regulator_set_optimum_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd39528ff	mtd_read_oob
++EXPORT_SYMBOL_GPL vmlinux 0xd3a1d558	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0xd3af9066	user_match
++EXPORT_SYMBOL_GPL vmlinux 0xd3b8eb5a	amba_apb_device_add_res
++EXPORT_SYMBOL_GPL vmlinux 0xd3ed3b7a	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0xd3fa226d	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd44c2f38	cci_disable_port_by_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd488a419	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd4a45afd	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL vmlinux 0xd4a647ad	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd5350c42	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xd598c31d	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5c126a3	inet_csk_reqsk_queue_prune
++EXPORT_SYMBOL_GPL vmlinux 0xd5c78ea4	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd60105f7	ahci_set_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0xd62d800b	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0xd636db0d	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xd65b2c72	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xd65d535f	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd67f4d21	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd6a617cf	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL vmlinux 0xd6b5dd44	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0xd6c2e04b	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd6ee11cb	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0xd6f0c952	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0xd6f569ff	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd75ba589	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd77fa56a	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xd788742d	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xd7b97cad	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0xd7c45461	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd7fd9306	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd81ffcd3	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd82a76ea	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0xd84418ad	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd8525ea7	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xd85ac634	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd891214a	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0xd898cd9c	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xd8ae9891	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0xd8b04281	put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xd8b493f8	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xd8ff014c	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0xd9002c0d	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0xd9364184	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd950b4f7	event_storage_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xd992e157	mtd_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd9d7f623	pkey_id_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9eb1baa	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xd9fa2d55	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0xda3a7ca9	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xda44cb37	setup_charger_manager
++EXPORT_SYMBOL_GPL vmlinux 0xda70ea80	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xda734b28	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0xda7dfa5e	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0xda98b28b	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0xdabc818e	cgroup_add_cftypes
++EXPORT_SYMBOL_GPL vmlinux 0xdabdd85c	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xdac11bae	of_property_read_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0xdac33295	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xdacd26c5	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xdae0e2a2	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdaf80720	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0xdb04cacc	tracepoint_probe_unregister_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xdb3b8112	mtd_is_partition
++EXPORT_SYMBOL_GPL vmlinux 0xdb46d7c3	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xdb507b1a	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0xdb67b6c7	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xdb801a13	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdba4ad93	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xdba80fc1	of_fdt_unflatten_tree
++EXPORT_SYMBOL_GPL vmlinux 0xdbb55d0a	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xdbc70479	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0xdbd7487c	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdbf976c2	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc461430	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xdc942e40	__put_mtd_device
++EXPORT_SYMBOL_GPL vmlinux 0xdc971893	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdca28d7f	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0xdcb83c11	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xdd158b50	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xdd2593e0	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xdd2b33ec	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0xdd2e715f	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd5e2e14	device_create
++EXPORT_SYMBOL_GPL vmlinux 0xddac6e6b	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xde140550	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xde15e43c	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0xde2c5a6e	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xde515e64	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0xde5e203a	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0xde886392	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdeb2d03d	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0xdebf0ce5	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0xdef4e092	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0xdf0b9412	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf7923bc	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xdf825fbd	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdf8af570	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0xdfb0e20d	of_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xdfebfcd4	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL vmlinux 0xdff7c9ce	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe03525ac	of_irq_map_raw
++EXPORT_SYMBOL_GPL vmlinux 0xe043d7e6	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0xe048e318	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe0595813	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xe064e9b0	__clocksource_updatefreq_scale
++EXPORT_SYMBOL_GPL vmlinux 0xe0727b09	mtd_add_partition
++EXPORT_SYMBOL_GPL vmlinux 0xe07ca631	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0xe07e97e9	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xe0b772e1	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0xe0bb945e	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xe0d3383f	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xe0e2bebb	sk_unattached_filter_create
++EXPORT_SYMBOL_GPL vmlinux 0xe0e3147c	HYPERVISOR_sched_op
++EXPORT_SYMBOL_GPL vmlinux 0xe10072db	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xe10db75e	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0xe13c1dc4	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0xe14e0ca2	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe16591ab	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0xe1b31d59	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xe1d24222	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0xe1d363f6	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0xe217ad55	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0xe217bc19	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe22d047f	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0xe239ceea	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xe2419d21	free_css_id
++EXPORT_SYMBOL_GPL vmlinux 0xe26ab73d	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xe2dd67e5	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xe2e7840d	regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe3250897	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0xe340e234	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL vmlinux 0xe35c359f	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0xe3725a90	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe384a102	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0xe3b5bb1e	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xe3c335fe	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0xe3d52e9d	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xe40378de	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe42e1f70	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe4766ec0	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe484d6e8	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe4cd70b6	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xe4e6006c	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe502603d	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe50e65bf	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5159a74	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xe539af96	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xe5529de7	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xe55e8dc3	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xe5833865	tpm_release
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58e1bd4	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xe5c3b58e	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe5f344e8	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xe6190047	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe6577386	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0xe6803091	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0xe690aefa	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xe6c67f3b	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6d586fd	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0xe6dd04af	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe70b31bb	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xe73e9728	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xe742116b	devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0xe764488a	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe78fca2f	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xe7b15338	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe7dac2db	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe8179d3e	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe81c7890	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe8272542	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe8400441	of_property_read_string_index
++EXPORT_SYMBOL_GPL vmlinux 0xe845549f	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe8515992	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0xe85a9fd3	cpu_cluster_pm_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe85f53ed	put_device
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe8678eae	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xe86a6a77	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe86b277c	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0xe8c58613	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xe8c6b70d	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xe8de4644	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xe8e60cc6	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xe8edf950	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xe8f2dff3	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0xe90b2198	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe94a4504	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xe956a75c	pl320_ipc_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xe980f9fe	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xe9910827	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xe9955aff	cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0xe9a7fa08	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe9a98cd6	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0xe9b7957e	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea20ff61	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xea3f6a64	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea43355b	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL vmlinux 0xea5eaa31	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0xea6e5741	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xea7313ec	inet_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xea90e0be	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xeafc7961	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0xeb1c3628	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xeb322503	snd_soc_default_readable_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb3938f7	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xeb3ef01d	arm_pm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xeb4bc07e	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xeb5afab6	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xeb68ff32	mtd_read
++EXPORT_SYMBOL_GPL vmlinux 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL vmlinux 0xeb725f6c	snd_soc_default_volatile_register
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xebd9651b	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebee7478	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec1e951a	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec2ff70b	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xec43ee46	unregister_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0xec521246	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xecb26747	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL vmlinux 0xecbd5b19	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xecbf6b50	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0xecf6ee9e	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xed02ce65	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xed06b916	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xed25a84d	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xed27da01	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0xed4e2d45	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL vmlinux 0xed564c49	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0xed62e7ed	class_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xed695a2d	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0xed9fc5aa	mtd_device_parse_register
++EXPORT_SYMBOL_GPL vmlinux 0xedae7530	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xedb69609	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedbf3cbb	of_get_dma_window
++EXPORT_SYMBOL_GPL vmlinux 0xedc73182	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0xedd49930	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0xeddcab70	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xeddffc0b	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0xee279593	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xee4f3181	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xeea4e9aa	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL vmlinux 0xeeac55b5	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0xeeb2f663	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xef3bdcce	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef6be092	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef73e084	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xef782b88	gnttab_grant_foreign_access_subpage
++EXPORT_SYMBOL_GPL vmlinux 0xef9b1ed1	user_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0xefb91c49	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL vmlinux 0xefc7fd45	kvm_clear_guest
++EXPORT_SYMBOL_GPL vmlinux 0xefc91531	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xefcdc4a6	__mtd_next_device
++EXPORT_SYMBOL_GPL vmlinux 0xefd88a24	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xefdbfbc5	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0xefe7ddb5	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0xeff1157c	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0xf00d58f7	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xf00f31c9	gfn_to_pfn
++EXPORT_SYMBOL_GPL vmlinux 0xf03379f8	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xf05230f0	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xf0626a6b	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xf078fa3f	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xf0b58072	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL vmlinux 0xf0e220d4	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf0f72dee	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xf0ff873f	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0xf115dd37	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf18fce76	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1bb9c81	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0xf1e8918d	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xf1f4d0c1	sysfs_notify_dirent
++EXPORT_SYMBOL_GPL vmlinux 0xf21b0f48	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf222f80f	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xf25c07ba	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf2835b23	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf285f074	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0xf29c5dc1	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xf2b51302	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0xf2ce7853	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL vmlinux 0xf2dc633a	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0xf2e8f1b1	md_run
++EXPORT_SYMBOL_GPL vmlinux 0xf2f33cfc	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf2fc7f6e	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf2fe4f31	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf304ab71	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0xf30d91c3	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf313a742	__ip_route_output_key
++EXPORT_SYMBOL_GPL vmlinux 0xf315e1f7	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf3209b59	sysfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf351a5b3	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xf3816583	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0xf3884cde	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0xf3b150b4	aead_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd036d	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xf3eaf87e	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0xf3ef0306	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0xf3fad09d	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf415d178	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL vmlinux 0xf442d334	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0xf44d1f1c	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4bb04a2	bdi_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0xf4d9c56f	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0xf4e0f677	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf50c3392	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0xf511c844	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0xf5175511	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0xf534964c	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf55d2cfc	dapm_clock_event
++EXPORT_SYMBOL_GPL vmlinux 0xf5639f00	of_regulator_match
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf57f869d	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5b979ee	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL vmlinux 0xf5fb3b7c	sysfs_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xf5fef4e3	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf60d1625	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xf622a273	platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xf635269c	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xf63c5886	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf6464980	ahci_em_messages
++EXPORT_SYMBOL_GPL vmlinux 0xf647d66d	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf655b4e3	tpm_show_temp_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0xf68fc6c1	snd_soc_default_writable_register
++EXPORT_SYMBOL_GPL vmlinux 0xf6b63220	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xf6b8d73f	sysfs_schedule_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf6c5d823	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xf6d4b251	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0xf6dc7531	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0xf6e04730	event_storage
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f529a3	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0xf6f83242	omap_get_control_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf7056794	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xf7136139	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0xf74656ab	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf74dae0f	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf76b0a59	read_current_timer
++EXPORT_SYMBOL_GPL vmlinux 0xf76df94d	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xf7739bff	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xf78fe46a	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xf7a28da8	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xf7a8970b	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0xf7c4fdc5	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xf7e19dbc	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xf7e43963	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0xf8131e3f	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf8135f44	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL vmlinux 0xf8164591	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf846506f	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf84bf74f	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0xf86a3a9f	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf8b54c17	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xf8c7232a	cgroup_next_descendant_post
++EXPORT_SYMBOL_GPL vmlinux 0xf8d490ee	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf907ac38	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0xf90c4b34	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0xf92a7e50	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf960818b	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xf967422b	HYPERVISOR_xen_version
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9b671c4	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9de08d9	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xf9e1a77c	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0xfa012fe7	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa13318a	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa2c6f02	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0xfa381d53	devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xfa47b9a6	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0xfa52b80f	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xfa5a4972	of_get_regulator_init_data
++EXPORT_SYMBOL_GPL vmlinux 0xfa63cc6a	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xfa763e06	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL vmlinux 0xfaaa14a0	nfq_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0xfad44714	sec_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0xfaf3d5e7	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL vmlinux 0xfafb6151	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL vmlinux 0xfb0521d6	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb6a60f3	mtd_erase_callback
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb8e7111	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfb95ab8f	device_add
++EXPORT_SYMBOL_GPL vmlinux 0xfba69bec	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0xfbbc9c3a	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xfbbedefd	of_prop_next_string
++EXPORT_SYMBOL_GPL vmlinux 0xfbca9f3b	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL vmlinux 0xfbd8e794	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc0468c0	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xfc132306	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xfc188c01	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xfc4976b2	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xfc4c6469	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0xfc4f1174	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL vmlinux 0xfc4f1d60	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xfc78baa3	kvm_set_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xfc84c3cb	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0xfca47465	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xfcd7bc0b	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfcdadee3	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0xfcdb4034	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xfcef6437	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0xfd23dd54	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xfd4f2f6a	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd6fdbb8	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0xfd9215ec	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0xfd9c7a45	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xfdabf17a	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfdb7df3b	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0xfdc7f587	sysfs_rename_link
++EXPORT_SYMBOL_GPL vmlinux 0xfddb4144	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xfe502221	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfe8969af	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfe9ee428	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfed33c29	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0xfeda4e1c	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0xfedb3835	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xfee4597e	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xfee700e9	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff0960fa	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0xff180b7d	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xff3ef088	amba_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5cda7c	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xff638a4e	wm8994_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xff69123f	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0xff74af80	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL vmlinux 0xff7acf72	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xff872ec9	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0xffc82486	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xffeb8819	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xffef397a	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0xfffac33a	ip6_append_data
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.compiler b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.compiler
+new file mode 100644
+index 0000000..682fb55
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 4.7.3-7ubuntu3) 4.7.3
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.modules b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.modules
+new file mode 100644
+index 0000000..c2b4eab
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic-lpae.modules
+@@ -0,0 +1,2834 @@
++6lowpan
++6pack
++8021q
++8250_dw
++8255
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++88pm860x-ts
++9p
++9pnet
++9pnet_virtio
++a3d
++a8293
++aat2870_bl
++aat2870-regulator
++ab3100
++ab3100-otp
++ac97_bus
++acecad
++act200l-sir
++act_csum
++act_gact
++act_ipt
++actisys-sir
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5930
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad9850
++ad9852
++ad9910
++ad9951
++adcxx
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm9240
++adp5520_bl
++adp5520-keys
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++ads1015
++ads7828
++ads7846
++ads7871
++ad_sigma_delta
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7180
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-arm
++af_802154
++af9013
++af9033
++af_alg
++affs
++af_key
++af_packet_diag
++af-rxrpc
++afs
++ah4
++ah6
++ahci_imx
++ahci_platform
++aiptek
++aircable
++ak8975
++alauda
++algif_hash
++algif_skcipher
++alphatrack
++altera_jtaguart
++altera_ps2
++altera-stapl
++altera_uart
++ambakmi
++amba-pl010
++amc6821
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9802als
++apds990x
++appledisplay
++appletalk
++appletouch
++ar5523
++ar7part
++arc4
++arc_emac
++arc_ps2
++arc_uart
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arptable_filter
++arp_tables
++arpt_mangle
++as3711_bl
++as3711-regulator
++as5011
++asc7621
++asix
++asus_oled
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at86rf230
++at91_can
++at91_ether
++atbm8830
++aten
++ath
++ath10k_core
++ath3k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atm
++atmel_mxt_ts
++atmel_pwm
++atmel-pwm-bl
++atmel-ssc
++atmtcp
++atxp1
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auo-pixcir-ts
++authenc
++authencesn
++auth_rpcgss
++autofs4
++ax25
++ax88179_178a
++ax88796
++b2c2-flexcop
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bcm203x
++bcm3510
++bcm5974
++bcma
++bcm_wimax
++befs
++belkin_sa
++bfs
++bfusb
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bma150
++bmp085-i2c
++bmp085-spi
++bnep
++bonding
++bpa10x
++bpck
++bpck6
++bpqether
++bq2415x_charger
++bq27x00_battery
++br2684
++brcmfmac
++brcmsmac
++brcmutil
++bridge
++broadsheetfb
++bsd_comp
++btmrvl
++btmrvl_sdio
++btmtk_usb
++btrfs
++btsdio
++btusb
++btwilink
++bu21013_ts
++bw-qcam
++c67x00
++cachefiles
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++carl9170
++cast5_generic
++cast6_generic
++cast_common
++catc
++cc770
++cc770_isa
++cc770_platform
++c_can
++c_can_platform
++ccm
++cdc-acm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc-phonet
++cdc_subset
++cdc-wdm
++cedusb
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++chnl_net
++cifs
++clearpad_tm1217
++clip
++clk-max77686
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_cgroup
++cls_flow
++cls_fw
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmtp
++cobra
++coda
++comedi
++comedi_bond
++comedi_fc
++comedi_parport
++comedi_test
++comm
++configfs
++cordic
++core
++cp210x
++cpia2
++cpu-notifier-error-inject
++c-qcam
++cramfs
++crc32
++crc7
++crc8
++crc-ccitt
++crc-itu-t
++cros_ec
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++cryptd
++cryptoloop
++crypto_null
++crypto_user
++cs53l32a
++cs89x0
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx24113
++cx24116
++cx24123
++cx25840
++cx82310_eth
++cxacru
++cxd2820r
++cy8ctmg110_ts
++cyapa
++cyberjack
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052_bl
++da9052-hwmon
++da9052_onkey
++da9052-regulator
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055_onkey
++da9055-regulator
++da9055_wdt
++db9
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++decnet
++deflate
++denali
++denali_dt
++des_generic
++designware_i2s
++dgrp
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++dlci
++dlm
++dm9000
++dm9601
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-crypt
++dm-delay
++dme1737
++dm-flakey
++dm-log
++dm-log-userspace
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-raid45
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dm-zero
++dnet
++dn_rtmsg
++docg3
++docg4
++drbd
++drm
++drm_kms_helper
++drm_usb
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsa_core
++dsbr100
++dss1_divert
++dstr
++dt9812
++dummy
++dummy-irq
++dvb-as102
++dvb-core
++dvb-pll
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-it913x
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb_usb_v2
++dvb-usb-vp702x
++dvb-usb-vp7045
++dwc3
++dwc3-exynos
++dwc3-omap
++dw_dmac
++dw_dmac_core
++dw_mmc
++dw_mmc-exynos
++dw_mmc-pltfm
++dw_mmc-socfpga
++dw_wdt
++dynapro
++e4000
++ebt_802_3
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ec100
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++emc1403
++emc2103
++emc6w201
++em_canid
++em_cmp
++emi26
++emi62
++em_ipset
++em_meta
++em_nbyte
++empeg
++ems_usb
++em_text
++em_u32
++enc28j60
++enclosure
++epat
++epia
++eql
++esd_usb2
++esi-sir
++esp4
++esp6
++ethoc
++evbug
++exofs
++ext2
++extcon-adc-jack
++extcon-arizona
++extcon-gpio
++extcon-max77693
++extcon-max8997
++extcon-palmas
++exynos-rng
++ezusb
++f2fs
++f71805f
++f71882fg
++f75375s
++f81232
++fakelb
++fan53555
++faulty
++fb_sys_fops
++fc0011
++fc0012
++fc0013
++fc2580
++fcrypt
++ff-memless
++fit2
++fit3
++flashloader
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fm_drv
++fotg210-udc
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl_lpuart
++ft1000
++ftdi-elan
++ftdi_sio
++ftgmac100
++ftl
++ftmac100
++fujitsu_ts
++funsoft
++fusbh200-hcd
++g760a
++g762
++g_acm_ms
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++g_audio
++g_cdc
++gcm
++g_dbgp
++gdmwm
++generic
++generic-adc-battery
++generic_bl
++gen_probe
++g_ether
++gf128mul
++gf2k
++g_ffs
++gfs2
++ghash-generic
++g_hid
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++g_mass_storage
++g_midi
++g_multi
++g_ncm
++g_nokia
++go7007
++go7007-loader
++go7007-usb
++goldfish_battery
++goldfishfb
++gp2ap002a00f
++gpio
++gpio-74x164
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-arizona
++gpio-charger
++gpio-da9052
++gpio-da9055
++gpio-fan
++gpio-generic
++gpio-grgpio
++gpio-ir-recv
++gpio_keys
++gpio_keys_polled
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio_mouse
++gpio-pca953x
++gpio-pcf857x
++gpio-rcar
++gpio-regulator
++gpio_tilt_polled
++gpio-tps65912
++gpio-ts5500
++gpio-twl6040
++gpio-viperboard
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++g_printer
++grcan
++gre
++grip
++grip_mp
++g_serial
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++g_webcam
++g_zero
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdlc
++hdlc_cisco
++hdlcdrv
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdpvr
++hfc4s8s_l1
++hfcsusb
++hfc_usb
++hfs
++hfsplus
++hid
++hid-a4tech
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-cherry
++hid-chicony
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-generic
++hid-gyration
++hid-holtekff
++hid-holtek-kbd
++hid-holtek-mouse
++hid-huion
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo-tpkbd
++hid-logitech
++hid-logitech-dj
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hidp
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-primax
++hid-prodikeys
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-magn-3d
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-wacom
++hid-waltop
++hid-wiimote
++hid-zpff
++hid-zydacron
++highbank_l2_edac
++highbank_mc_edac
++hih6130
++hisax
++hisax_st5481
++hmc5843
++hmc6352
++hostap
++hp4x
++hpfs
++hsi
++hsi_char
++hso
++htc-pasic3
++hwmon-vid
++hx8357
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-platform
++i2c-dev
++i2c-diolan-u2c
++i2c-gpio
++i2c-hid
++i2c-kempld
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-nomadik
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-simtec
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-versatile
++i2c-viperboard
++i2c-xiic
++ibmaem
++ibmpex
++ics932s401
++idmouse
++ieee802154
++ifb
++iforce
++iguanair
++iio_dummy
++iio_hwmon
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++ili210x
++ili922x
++ili9320
++imm
++imon
++impa7
++ims-pcu
++imx074
++ina209
++ina2xx
++industrialio
++industrialio-triggered-buffer
++inet_diag
++inexio
++inftl
++input-polldev
++int51x1
++interact
++interval_tree_test
++inv-mpu6050
++io_edgeport
++io_ti
++iowarrior
++ip6_gre
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6_tables
++ip6table_security
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_MASQUERADE
++ip6t_mh
++ip6t_NPT
++ip6t_REJECT
++ip6t_rpfilter
++ip6t_rt
++ip6_tunnel
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++ip_gre
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_watchdog
++ipoctal
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netport
++ip_set_list_set
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++ip_tables
++iptable_security
++ipt_ah
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_rpfilter
++ipt_ULOG
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipw
++ipx
++ircomm
++ircomm-tty
++irda
++irda-usb
++ir-jvc-decoder
++ir-kbd-i2c
++irlan
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++irnet
++ir-rc5-decoder
++ir-rc5-sz-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sony-decoder
++irtty-sir
++ir-usb
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl6271a-regulator
++isl6421
++isl6423
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it913x-fe
++itd1000
++itg3200
++iuu_phoenix
++ix2505v
++jc42
++jedec_probe
++jffs2
++jfs
++joydev
++joydump
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++kempld-core
++kempld_wdt
++kernelcapi
++keucr
++keyspan
++keyspan_pda
++keyspan_remote
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ktti
++kvaser_usb
++kxsd9
++kxtj9
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++leds-88pm860x
++leds-adp5520
++leds-atmel-pwm
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8788
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca9633
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg2160
++lgdt3305
++lgdt330x
++lgs8gxx
++lg-vl600
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libceph
++libcomposite
++libcrc32c
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++lightning
++line6usb
++lineage-pem
++linear
++lirc_dev
++lirc_igorplugusb
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533_bl
++lm3533-core
++lm3533-ctrlbank
++lm3630_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbp21
++lnbp22
++lockd
++lp
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp8755
++lp8788_bl
++lp8788-charger
++lpddr_cmds
++lru_cache
++lrw
++ltc2978
++ltc4151
++ltc4215
++ltc4245
++ltc4261
++lttng-kprobes
++lttng-kretprobes
++lttng-lib-ring-buffer
++lttng-probe-asoc
++lttng-probe-block
++lttng-probe-btrfs
++lttng-probe-compaction
++lttng-probe-ext3
++lttng-probe-ext4
++lttng-probe-gpio
++lttng-probe-irq
++lttng-probe-jbd
++lttng-probe-jbd2
++lttng-probe-kmem
++lttng-probe-kvm
++lttng-probe-module
++lttng-probe-napi
++lttng-probe-net
++lttng-probe-power
++lttng-probe-printk
++lttng-probe-random
++lttng-probe-rcu
++lttng-probe-regmap
++lttng-probe-regulator
++lttng-probe-rpm
++lttng-probe-sched
++lttng-probe-scsi
++lttng-probe-signal
++lttng-probe-skb
++lttng-probe-sock
++lttng-probe-statedump
++lttng-probe-sunrpc
++lttng-probe-timer
++lttng-probe-udp
++lttng-probe-vmscan
++lttng-probe-workqueue
++lttng-probe-writeback
++lttng-ring-buffer-client-discard
++lttng-ring-buffer-client-mmap-discard
++lttng-ring-buffer-client-mmap-overwrite
++lttng-ring-buffer-client-overwrite
++lttng-ring-buffer-metadata-client
++lttng-ring-buffer-metadata-mmap-client
++lttng-statedump
++lttng-tracer
++lttng-types
++ltv350qv
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m88rs2000
++ma600-sir
++mac80211
++mac80211_hwsim
++mac802154
++macb
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++mac-roman
++mac-romanian
++mac-turkish
++macvlan
++macvtap
++magellan
++map_absent
++map_ram
++map_rom
++matrix-keymap
++matrix_keypad
++max1111
++max11801_ts
++max1363
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max2165
++max3100
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8925-regulator
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8998
++max8998_charger
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp4725
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md4
++mdc800
++mem2mem_testdev
++memstick
++mena21_wdt
++metronomefb
++metro-usb
++mg_disk
++michael_mic
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mISDN_core
++mISDN_dsp
++mk712
++mkiss
++mma8450
++mms114
++mos7720
++mos7840
++moto_modem
++mpoa
++mpr121_touchkey
++mpu3050
++mrf24j40
++mrp
++msdos
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2266
++mt312
++mt352
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtouch
++multipath
++mv88e6060
++mv88e6xxx_drv
++mvmdio
++mv_u3d_core
++mv_udc
++mwifiex
++mwifiex_sdio
++mwifiex_usb
++mxl111sf-demod
++mxl111sf-tuner
++mxl5005s
++mxl5007t
++nandsim
++navman
++nbd
++nci
++ncpfs
++nct6775
++net1080
++net2272
++netconsole
++netlink_diag
++netprio_cgroup
++netrom
++newtonkbd
++nfc
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nfcsim
++nfcwilink
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfsd
++nfs_layout_nfsv41_files
++nfsv2
++nfsv3
++nfsv4
++nftl
++nf_tproxy_core
++n_hdlc
++nilfs2
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-1
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++notifier-error-inject
++n_r3964
++ns558
++ntc_thermistor
++ntfs
++n_tracerouter
++n_tracesink
++nvram
++nxt200x
++nxt6000
++objlayoutdriver
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stackglue
++ocfs2_stack_o2cb
++ocfs2_stack_user
++old_belkin-sir
++olpc_apsp
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opticon
++option
++osd
++osdblk
++osst
++oti6858
++output
++ov2640
++ov5642
++ov6650
++ov7640
++ov772x
++ov9640
++ov9740
++overlayfs
++oxu210hp-hcd
++ozwpan
++p54common
++p54spi
++p54usb
++p8022
++p8023
++palmas-regulator
++pandora_bl
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_pc
++pata_arasan_cf
++pata_of_platform
++pata_platform
++pc87360
++pc87427
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pcrypt
++pcwd_usb
++pd
++pda_power
++peak_usb
++pegasus
++penmount
++pf
++pg
++phonet
++phram
++phy-gpio-vbus-usb
++phy-isp1301
++phy-omap-usb3
++phy-rcar-usb
++phy-samsung-usb
++phy-samsung-usb2
++phy-samsung-usb3
++physmap
++physmap_of
++pixcir_i2c_ts
++pktcdvd
++pktgen
++pl2303
++pl330
++platform_lcd
++plat_nand
++plat-ram
++plip
++plusb
++pmbus
++pmbus_core
++pm-notifier-error-inject
++pn533
++pn544
++pn544_i2c
++pn_pep
++poseidon
++powermate
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++pppoatm
++pppoe
++pppox
++ppp_synctty
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++pvrusb2
++pwc
++pwm-beeper
++pwm_bl
++pwm-pca9685
++pwm-twl
++pwm-twl-led
++pxa27x_udc
++qcaux
++qcserial
++qinfo_probe
++qmi_wwan
++qnx4
++qnx6
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++r8152
++r815x
++r820t
++r8712u
++r8a66597-hcd
++r8a66597-udc
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-mr800
++radio-shark
++radio-si4713
++radio-si476x
++radio-tea5764
++radio-usb-si470x
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++rbd
++rbtree_test
++rc5t583-regulator
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rcar-du-drm
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv2
++rc-encore-enltv-fm53
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-tbs-nec
++rc-technisat-usb2
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rds
++rds_tcp
++redboot
++redrat3
++reed_solomon
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rndis_host
++rndis_wlan
++romfs
++rose
++rotary_encoder
++rpcsec_gss_krb5
++rt2500usb
++rt2800lib
++rt2800usb
++rt2x00lib
++rt2x00usb
++rt73usb
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab3100
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-msm6242
++rtc-palmas
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-pl030
++rtc-pl031
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-snvs
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtl2830
++rtl2832
++rtl8150
++rtl8187
++rtl8192c-common
++rtl8192cu
++rtl_usb
++rtlwifi
++rts5139
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2mps11
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s6e63m0
++s921
++saa7115
++saa7706h
++safe_serial
++salsa20_generic
++samsung-keypad
++sata_mv
++sata_rcar
++sbs-battery
++sca3000
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_tgt
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci-pxav2
++sdhci-pxav3
++sdio_uart
++seed
++seqiv
++ser_gigaset
++serial2002
++serio_raw
++sermouse
++serpent_generic
++serport
++serqt_usb2
++ses
++sha1-arm
++shark2
++sh_eth
++shmob-drm
++sh_mobile_ceu_camera
++sh_mobile_csi2
++sht15
++sht21
++sh_veu
++si21xx
++si4713-i2c
++si476x-core
++sidewinder
++siemens_mpi
++sierra
++sierra_net
++sil164
++sir-dev
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_of_platform
++sja1000_platform
++skel
++sl811-hcd
++slcan
++slip
++slram
++sm501
++sm501fb
++smb347-charger
++smc911x
++smc91x
++sm_ftl
++smm665
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd-aaci
++snd-ac97-codec
++snd-aloop
++snd-at73c213
++snd-dummy
++snd-hrtimer
++snd-hwdep
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-portman2x4
++snd-rawmidi
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-88pm860x
++snd-soc-ab8500-codec
++snd-soc-ad1836
++snd-soc-ad193x
++snd-soc-ad73311
++snd-soc-adau1373
++snd-soc-adav80x
++snd-soc-ads117x
++snd-soc-ak4104
++snd-soc-ak4535
++snd-soc-ak4641
++snd-soc-ak4642
++snd-soc-ak4671
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-alc5632
++snd-soc-arizona
++snd-soc-atmel-pcm
++snd-soc-bt-sco
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs42l51
++snd-soc-cs42l52
++snd-soc-cs42l73
++snd-soc-cx20442
++snd-soc-da7210
++snd-soc-da7213
++snd-soc-da732x
++snd-soc-da9055
++snd-soc-hdmi-codec
++snd-soc-isabelle
++snd-soc-jz4740-codec
++snd-soc-l3
++snd-soc-lm4857
++snd-soc-lm49453
++snd-soc-max9768
++snd-soc-max98088
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max9850
++snd-soc-max9877
++snd-soc-mc13783
++snd-soc-ml26124
++snd-soc-pcm3008
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2518
++snd-soc-ssm2602
++snd-soc-sta32x
++snd-soc-sta529
++snd-soc-tas5086
++snd-soc-tlv320aic23
++snd-soc-tlv320aic26
++snd-soc-tlv320aic32x4
++snd-soc-tlv320aic3x
++snd-soc-tlv320dac33
++snd-soc-tpa6130a2
++snd-soc-twl4030
++snd-soc-twl6040
++snd-soc-uda134x
++snd-soc-uda1380
++snd-soc-wl1273
++snd-soc-wm0010
++snd-soc-wm1250-ev1
++snd-soc-wm2000
++snd-soc-wm2200
++snd-soc-wm5100
++snd-soc-wm5102
++snd-soc-wm5110
++snd-soc-wm8350
++snd-soc-wm8400
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8727
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8782
++snd-soc-wm8804
++snd-soc-wm8900
++snd-soc-wm8903
++snd-soc-wm8904
++snd-soc-wm8940
++snd-soc-wm8955
++snd-soc-wm8960
++snd-soc-wm8961
++snd-soc-wm8962
++snd-soc-wm8971
++snd-soc-wm8974
++snd-soc-wm8978
++snd-soc-wm8983
++snd-soc-wm8985
++snd-soc-wm8988
++snd-soc-wm8990
++snd-soc-wm8991
++snd-soc-wm8993
++snd-soc-wm8994
++snd-soc-wm8995
++snd-soc-wm8996
++snd-soc-wm9081
++snd-soc-wm9090
++snd-soc-wm-adsp
++snd-soc-wm-hubs
++snd-tea575x-tuner
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usbmidi-lib
++snd-virmidi
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++sony-btf-mpx
++sp805_wdt
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spidev
++spi-dw
++spi-dw-mmio
++spi-gpio
++spi_ks8995
++spi-lm70llp
++spi-oc-tiny
++spi-pl022
++spi-sc18is602
++spi-tle62x0
++spi-xcomm
++squashfs
++ssb
++ssd1307fb
++ssfdc
++sst25l
++ssu100
++st
++st1232
++st_accel
++st_accel_i2c
++st_accel_spi
++stb0899
++stb6000
++stb6100
++st_drv
++ste_modem_rproc
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++stinger
++stir4200
++stk1160
++stkwebcam
++st_magn
++st_magn_i2c
++st_magn_spi
++stmmac
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++streamzap
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++stv0288
++stv0297
++stv0299
++stv0900
++stv090x
++stv6110
++stv6110x
++sunkbd
++sunrpc
++suunto
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++sysv
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++tc3589x-keypad
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_usb_gadget
++tcp_bic
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda826x
++tda827x
++tda8290
++tda9887
++tda998x
++tdo24m
++tea
++tea5761
++tea5767
++tef6862
++tekram-sir
++test-kprobes
++test-kstrtox
++test_power
++test-string_helpers
++tgr192
++thmc50
++ti-adc081c
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++timb_dma
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++ti_usb_3410_5052
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmiofb
++tmio_mmc
++tmio_mmc_core
++tmio_nand
++tmp102
++tmp401
++tmp421
++toim3232-sir
++touchit213
++touchright
++touchwin
++tpm_i2c_infineon
++tpm_i2c_stm_st33
++tpm-rng
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217
++tps65217_bl
++tps65217-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++tranzport
++ts2020
++ts_bm
++tsc2005
++tsc2007
++tsc40
++ts_fsm
++ts_kmp
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++ttpci-eeprom
++ttusbir
++tua9001
++tuner
++tuner_it913x
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tveeprom
++tvp5150
++tw2804
++tw9903
++tw9906
++tw9910
++twidjoy
++twl4030_charger
++twl4030_keypad
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_wdt
++twl6040-vibra
++twofish_common
++twofish_generic
++u132-hcd
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udf
++udl
++udlfb
++udp_diag
++ueagle-atm
++u_ether
++ufs
++ufshcd
++ufshcd-pltfrm
++uhid
++uio
++uio_dmem_genirq
++uio_pdrv
++uio_pdrv_genirq
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unix_diag
++u_rndis
++usb3503
++usb_8dev
++usb8xxx
++usbatm
++usb_debug
++usbdux
++usbduxfast
++usbduxsigma
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_gigaset
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usb-storage
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usb_wwan
++u_serial
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++ux500
++v4l2-common
++v4l2-int-device
++v4l2-mem2mem
++vcan
++vcnl4000
++veth
++vexpress
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via-velocity
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-memops
++videobuf2-vmalloc
++videobuf-core
++videobuf-dma-contig
++videobuf-dvb
++videobuf-vmalloc
++videodev
++viperboard
++viperboard_adc
++virtio_balloon
++virtio-rng
++virtio_scsi
++virtual
++visor
++vivi
++vivopay-serial
++vmac
++vmk80xx
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6656_stage
++vub300
++vxlan
++w1_bq27000
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1-gpio
++w1_smem
++w1_therm
++w35und
++w5100
++w5300
++w83627ehf
++w83627hf
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83l785ts
++w83l786ng
++w90p910_ts
++w9966
++wacom
++wacom_i2c
++wacom_w8001
++walkera0701
++warrior
++whiteheat
++wimax
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x_backup
++wm831x_bl
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x_power
++wm831x-ts
++wm831x_wdt
++wm8350-hwmon
++wm8350_power
++wm8350-regulator
++wm8350_wdt
++wm8400-regulator
++wm8775
++wm8994-regulator
++wm97xx-ts
++wp512
++x25
++x25_asy
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xenfs
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-privcmd
++xen_wdt
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgmac
++xilinx_uartps
++xor
++xpad
++xsens_mt
++x_tables
++xt_addrtype
++xt_AUDIT
++xt_bpf
++xt_CHECKSUM
++xt_CLASSIFY
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_CONNSECMARK
++xt_conntrack
++xt_cpu
++xt_CT
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_DSCP
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_iprange
++xt_ipvs
++xtkbd
++xt_LED
++xt_length
++xt_limit
++xt_LOG
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_NETMAP
++xt_nfacct
++xt_NFLOG
++xt_NFQUEUE
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_RATEEST
++xt_realm
++xt_recent
++xt_REDIRECT
++xts
++xt_sctp
++xt_SECMARK
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_tcpudp
++xt_TEE
++xt_time
++xt_TPROXY
++xt_TRACE
++xt_u32
++xusbatm
++xz_dec_test
++yam
++yealink
++yurex
++zaurus
++zd1201
++zd1211rw
++zhenhua
++zio
++zl10039
++zl10353
++zl6100
++zlib
++zlib_deflate
++zr364xx
++zram
++zte_ev
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic.compiler b/debian.master/abi/3.11.0-13.20/armhf/generic.compiler
+new file mode 100644
+index 0000000..682fb55
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 4.7.3-7ubuntu3) 4.7.3
+diff --git a/debian.master/abi/3.11.0-13.20/armhf/generic.modules b/debian.master/abi/3.11.0-13.20/armhf/generic.modules
+new file mode 100644
+index 0000000..6cc4ba3
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/armhf/generic.modules
+@@ -0,0 +1,3668 @@
++3w-9xxx
++3w-sas
++3w-xxxx
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_dw
++8255
++8255_pci
++8390
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++88pm860x-ts
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++a100u2w
++a3d
++a8293
++aacraid
++aat2870_bl
++aat2870-regulator
++ab3100
++ab3100-otp
++acard-ahci
++acecad
++acenic
++act200l-sir
++act_csum
++act_gact
++act_ipt
++actisys-sir
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5930
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad9850
++ad9852
++ad9910
++ad9951
++adcxx
++addi_apci_035
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520_bl
++adp5520-keys
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++ads1015
++ads7828
++ads7846
++ads7871
++ad_sigma_delta
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7180
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-arm
++af_802154
++af9013
++af9033
++af_alg
++affs
++af_key
++af_packet_diag
++af-rxrpc
++afs
++ah4
++ah6
++ahci
++aic79xx
++aic7xxx
++aic94xx
++aiptek
++aircable
++ak8975
++alauda
++algif_hash
++algif_skcipher
++alim7101_wdt
++alphatrack
++altera-ci
++altera_jtaguart
++altera_ps2
++altera-stapl
++altera_uart
++alx
++ambakmi
++amba-pl010
++amc6821
++amd5536udc
++amd8111e
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pci224
++amplc_pci230
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apbps2
++apds9802als
++apds990x
++appledisplay
++appletalk
++appletouch
++applicom
++ar5523
++ar7part
++arc4
++arc_emac
++arcmsr
++arcnet
++arc_ps2
++arc-rawmode
++arc-rimi
++arc_uart
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arptable_filter
++arp_tables
++arpt_mangle
++as3711_bl
++as3711-regulator
++as5011
++asc7621
++asix
++ast
++asus_oled
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at86rf230
++at91_can
++at91_ether
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atm
++atmel
++atmel_mxt_ts
++atmel_pci
++atmel_pwm
++atmel-pwm-bl
++atmel-ssc
++atmtcp
++atp870u
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auo-pixcir-ts
++authenc
++authencesn
++auth_rpcgss
++autofs4
++avmfritz
++ax25
++ax88179_178a
++ax88796
++b1
++b1dma
++b1pci
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bcm203x
++bcm3510
++bcm5974
++bcma
++bcm_wimax
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1770glc
++bh1780gli
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluetooth
++bma150
++bmp085-i2c
++bmp085-spi
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bonding
++bpa10x
++bpck
++bpck6
++bpctl_mod
++bpqether
++bq2415x_charger
++bq27x00_battery
++br2684
++brcmfmac
++brcmsmac
++brcmutil
++bridge
++broadsheetfb
++bsd_comp
++bt878
++btcx-risc
++btmrvl
++btmrvl_sdio
++btmtk_usb
++btrfs
++btsdio
++bttv
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++bw-qcam
++bypass
++c4
++c67x00
++cachefiles
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc770
++cc770_isa
++cc770_platform
++c_can
++c_can_pci
++c_can_platform
++cciss
++ccm
++cdc-acm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc-phonet
++cdc_subset
++cdc-wdm
++cedusb
++ceph
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++chnl_net
++cifs
++cirrus
++cirrusfb
++clearpad_tm1217
++clip
++clk-max77686
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_cgroup
++cls_flow
++cls_fw
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmtp
++cnic
++cobra
++coda
++com20020
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_bond
++comedi_fc
++comedi_parport
++comedi_test
++comm
++configfs
++connector-analog-tv
++connector-dvi
++connector-hdmi
++contec_pci_dio
++cordic
++core
++cp210x
++cpia2
++cpu-notifier-error-inject
++c-qcam
++cramfs
++crc32
++crc7
++crc8
++crc-ccitt
++crc-itu-t
++cros_ec
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++cryptd
++cryptoloop
++crypto_null
++crypto_user
++crystalhd
++cs5345
++cs53l32a
++cs89x0
++csiostor
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx8800
++cx8802
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cxt1e1
++cy8ctmg110_ts
++cyapa
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052_bl
++da9052-hwmon
++da9052_onkey
++da9052-regulator
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055_onkey
++da9055-regulator
++da9055_wdt
++DAC960
++daqboard2000
++das08
++das08_pci
++davinci_cpdma
++davinci_emac
++davinci_mdio
++db9
++dc395x
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++ddbridge
++de2104x
++decnet
++deflate
++defxx
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgrp
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++divacapi
++divadidd
++diva_idi
++diva_mnt
++divas
++dl2k
++dlci
++dlm
++dm1105
++dm644x_ccdc
++dm9000
++dm9601
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-crypt
++dm-delay
++dme1737
++dmfe
++dm-flakey
++dm-log
++dm-log-userspace
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-raid45
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dmx3191d
++dm-zero
++dnet
++dn_rtmsg
++docg3
++docg4
++drbd
++drm
++drm_kms_helper
++drm_usb
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsa_core
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt3000
++dt3155v4l
++dt9812
++dummy
++dummy-irq
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-it913x
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb_usb_v2
++dvb-usb-vp702x
++dvb-usb-vp7045
++dwc3
++dwc3-exynos
++dwc3-omap
++dwc3-pci
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dw_mmc
++dw_mmc-exynos
++dw_mmc-pci
++dw_mmc-pltfm
++dw_mmc-socfpga
++dw_wdt
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e4000
++earth-pt1
++ebt_802_3
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ec100
++echo
++edac_core
++edt-ft5x06
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efs
++egalax_ts
++elo
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++emc1403
++emc2103
++emc6w201
++em_canid
++em_cmp
++emi26
++emi62
++emif
++em_ipset
++em_meta
++em_nbyte
++empeg
++ems_pci
++ems_usb
++em_text
++emu10k1-gp
++em_u32
++enc28j60
++enclosure
++encoder-tfp410
++encoder-tpd12s015
++eni
++enic
++epat
++epia
++epic100
++eql
++esd_usb2
++esi-sir
++esp4
++esp6
++et131x
++ethoc
++evbug
++exofs
++ext2
++extcon-adc-jack
++extcon-arizona
++extcon-gpio
++extcon-max77693
++extcon-max8997
++extcon-palmas
++exynos-rng
++ezusb
++f2fs
++f71805f
++f71882fg
++f75375s
++f81232
++fakelb
++fan53555
++farsync
++faulty
++fb_ddc
++fb_sys_fops
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fealnx
++ff-memless
++firedtv
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++flashloader
++fm801-gp
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fm_drv
++forcedeth
++fore_200e
++fotg210-udc
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fsl_lpuart
++ft1000
++ftdi-elan
++ftdi_sio
++ftgmac100
++ftl
++ftmac100
++fujitsu_ts
++funsoft
++fusb300_udc
++fusbh200-hcd
++g450_pll
++g760a
++g762
++g_acm_ms
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++g_audio
++g_cdc
++gcm
++g_dbgp
++gdmwm
++generic
++generic-adc-battery
++generic_bl
++gen_probe
++g_ether
++gf128mul
++gf2k
++g_ffs
++gfs2
++ghash-generic
++g_hid
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++g_mass_storage
++g_midi
++g_multi
++g_ncm
++g_nokia
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goldfish_battery
++goldfishfb
++gp2ap002a00f
++gpio
++gpio-74x164
++gpio-addr-flash
++gpio-adnp
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-arizona
++gpio-charger
++gpio-da9052
++gpio-da9055
++gpio-fan
++gpio-grgpio
++gpio-ir-recv
++gpio-janz-ttl
++gpio_keys
++gpio_keys_polled
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio_mouse
++gpio-pca953x
++gpio-pcf857x
++gpio-rcar
++gpio-rdc321x
++gpio-regulator
++gpio_tilt_polled
++gpio-tps65912
++gpio-ts5500
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++g_printer
++grcan
++gre
++grip
++grip_mp
++gsc_hpdi
++g_serial
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++g_webcam
++g_zero
++hamachi
++hampshire
++hanwang
++hci
++hci_uart
++hci_vhci
++hdlc
++hdlc_cisco
++hdlcdrv
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdpvr
++he
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfcmulti
++hfcpci
++hfcsusb
++hfc_usb
++hfs
++hfsplus
++hid
++hid-a4tech
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-cherry
++hid-chicony
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-generic
++hid-gyration
++hid-holtekff
++hid-holtek-kbd
++hid-holtek-mouse
++hid-huion
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo-tpkbd
++hid-logitech
++hid-logitech-dj
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hidp
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-primax
++hid-prodikeys
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-magn-3d
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-wacom
++hid-waltop
++hid-wiimote
++hid-zpff
++hid-zydacron
++hifn_795x
++highbank_l2_edac
++highbank_mc_edac
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hmc5843
++hmc6352
++hopper
++host1x
++hostap
++hostap_pci
++hostap_plx
++hp100
++hp4x
++hpfs
++hpilo
++hpsa
++hptiop
++hsi
++hsi_char
++hso
++htc-pasic3
++hwa-hc
++hwa-rc
++hwmon-vid
++hx8357
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd8111
++i2c-arb-gpio-challenge
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-dev
++i2c-diolan-u2c
++i2c-eg20t
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-mux-pinctrl
++i2c-nforce2
++i2c-nomadik
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-platform
++i2c-piix4
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tegra
++i2c-tiny-usb
++i2c-versatile
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i2o_block
++i2o_bus
++i2o_core
++i2o_proc
++i2o_scsi
++i5k_amb
++i6300esb
++i740fb
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ibmaem
++ibmpex
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++icp_multi
++ics932s401
++idmouse
++idt77252
++ieee802154
++ifb
++iforce
++igb
++igbvf
++iguanair
++iio_dummy
++iio_hwmon
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++ii_pci20kc
++ili210x
++ili922x
++ili9320
++imm
++imon
++impa7
++ims-pcu
++imx074
++ina209
++ina2xx
++industrialio
++industrialio-triggered-buffer
++inet_diag
++inexio
++inftl
++initio
++input-polldev
++int51x1
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++ioc4
++io_edgeport
++io_ti
++iowarrior
++ip6_gre
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6_tables
++ip6table_security
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_MASQUERADE
++ip6t_mh
++ip6t_NPT
++ip6t_REJECT
++ip6t_rpfilter
++ip6t_rt
++ip6_tunnel
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++ipg
++ip_gre
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netport
++ip_set_list_set
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++ip_tables
++iptable_security
++ipt_ah
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_rpfilter
++ipt_ULOG
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipw
++ipw2100
++ipw2200
++ipx
++ircomm
++ircomm-tty
++irda
++irda-usb
++ir-jvc-decoder
++ir-kbd-i2c
++irlan
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++irnet
++ir-rc5-decoder
++ir-rc5-sz-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sony-decoder
++irtty-sir
++ir-usb
++iscsi_boot_sysfs
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it913x-fe
++itd1000
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++iw_nes
++ix2505v
++ixgb
++ixgbe
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsm
++kafs
++kalmia
++kaweth
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keucr
++keyspan
++keyspan_pda
++keyspan_remote
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kobil_sct
++ks0108
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l4f00242t03
++l64781
++lanai
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++leds-88pm860x
++leds-adp5520
++leds-atmel-pwm
++leds-bd2802
++leds-blinkm
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8788
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca9633
++leds-pwm
++leds-regulator
++leds-tca6507
++leds-wm831x-status
++leds-wm8350
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg2160
++lgdt3305
++lgdt330x
++lgs8gxx
++lg-vl600
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++libsrp
++lightning
++line6usb
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_igorplugusb
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3lv02d
++lis3lv02d_i2c
++lis3lv02d_spi
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533_bl
++lm3533-core
++lm3533-ctrlbank
++lm3630_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lms283gf05
++lms501kf03
++lnbp21
++lnbp22
++lockd
++lp
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp8755
++lp8788_bl
++lp8788-charger
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2978
++ltc4151
++ltc4215
++ltc4245
++ltc4261
++lttng-kprobes
++lttng-kretprobes
++lttng-lib-ring-buffer
++lttng-probe-asoc
++lttng-probe-block
++lttng-probe-btrfs
++lttng-probe-compaction
++lttng-probe-ext3
++lttng-probe-ext4
++lttng-probe-gpio
++lttng-probe-irq
++lttng-probe-jbd
++lttng-probe-jbd2
++lttng-probe-kmem
++lttng-probe-module
++lttng-probe-napi
++lttng-probe-net
++lttng-probe-power
++lttng-probe-printk
++lttng-probe-random
++lttng-probe-rcu
++lttng-probe-regmap
++lttng-probe-regulator
++lttng-probe-rpm
++lttng-probe-sched
++lttng-probe-scsi
++lttng-probe-signal
++lttng-probe-skb
++lttng-probe-sock
++lttng-probe-statedump
++lttng-probe-sunrpc
++lttng-probe-timer
++lttng-probe-udp
++lttng-probe-vmscan
++lttng-probe-workqueue
++lttng-probe-writeback
++lttng-ring-buffer-client-discard
++lttng-ring-buffer-client-mmap-discard
++lttng-ring-buffer-client-mmap-overwrite
++lttng-ring-buffer-client-overwrite
++lttng-ring-buffer-metadata-client
++lttng-ring-buffer-metadata-mmap-client
++lttng-statedump
++lttng-tracer
++lttng-types
++ltv350qv
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m88rs2000
++ma600-sir
++mac80211
++mac80211_hwsim
++mac802154
++macb
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac-iceland
++mac-inuit
++macmodes
++mac-roman
++mac-romanian
++mac-turkish
++macvlan
++macvtap
++magellan
++mailbox_omap2
++mantis
++mantis_core
++map_absent
++map_ram
++map_rom
++matrix-keymap
++matrix_keypad
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_DAC1064
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++matroxfb_Ti3026
++matrox_w1
++max1111
++max11801_ts
++max1363
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max2165
++max3100
++max34440
++max517
++max63xx_wdt
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8925-regulator
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp4725
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md4
++mdc800
++mdio
++me4000
++me_daq
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mem2mem_testdev
++memstick
++mena21_wdt
++metronomefb
++metro-usb
++mfd
++mga
++mg_disk
++michael_mic
++microread
++microread_i2c
++microtek
++mii
++minix
++mip6
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++mite
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mma8450
++mms114
++mos7720
++mos7840
++moto_modem
++moxa
++mpoa
++mpr121_touchkey
++mpt2sas
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++mrst_max3110
++msdos
++msp3400
++mspro_block
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt312
++mt352
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtouch
++multipath
++mv88e6060
++mv88e6xxx_drv
++mvmdio
++mvsas
++mv_u3d_core
++mv_udc
++mvumi
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxl111sf-demod
++mxl111sf-tuner
++mxl5005s
++mxl5007t
++mxser
++myri10ge
++nandsim
++natsemi
++navman
++nbd
++nci
++ncpfs
++nct6775
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netprio_cgroup
++netrom
++netxen_nic
++newtonkbd
++nfc
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nfcsim
++nfcwilink
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfsd
++nfs_layout_nfsv41_files
++nfsv2
++nfsv3
++nfsv4
++nftl
++nf_tproxy_core
++ngene
++n_hdlc
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++nicstar
++ni_labpc
++ni_labpc_pci
++nilfs2
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-1
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nosy
++notifier-error-inject
++nouveau
++nozomi
++n_r3964
++ns558
++ns83820
++nsp32
++ntc_thermistor
++ntfs
++n_tracerouter
++n_tracesink
++nvec
++nvec_kbd
++nvec_paz00
++nvec_power
++nvec_ps2
++nvidiafb
++nvme
++nvram
++nxt200x
++nxt6000
++objlayoutdriver
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stackglue
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocrdma
++ohci-pci
++old_belkin-sir
++olpc_apsp
++omap
++omap2
++omap2430
++omap4-keypad
++omap-aes
++omap_hdq
++omap-mailbox
++omap-ocp2scp
++omap_remoteproc
++omap-sham
++omap-vout
++omap_wdt
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++output
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlayfs
++oxu210hp-hcd
++ozwpan
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++palmas-regulator
++pandora_bl
++panel
++panel-acx565akm
++panel-dpi
++panel-dsi-cm
++panel-lgphilips-lb035q02
++panel-nec-nl8048hl11
++panel-nec-nl8048hl11-01b
++panel-picodlp
++panel-sharp-ls037v7dw01
++panel-sony-acx565akm
++panel-tpo-td043mtea1
++paride
++parkbd
++parport
++parport_ax88796
++parport_pc
++parport_serial
++pata_ali
++pata_amd
++pata_arasan_cf
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cs5520
++pata_cs5530
++pata_cs5536
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_of_platform
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sc1200
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc300too
++pc87360
++pc87427
++pcbc
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_can
++pch_phub
++pch_uart
++pch_udc
++pci
++pci200syn
++pcips2
++pci-stub
++pcnet32
++pcrypt
++pcwd_pci
++pcwd_usb
++pd
++pda_power
++pdc_adma
++peak_pci
++peak_usb
++pegasus
++penmount
++pf
++pg
++phantom
++phison
++phonet
++phram
++phy-gpio-vbus-usb
++phy-isp1301
++phy-omap-usb3
++phy-rcar-usb
++phy-samsung-usb
++phy-samsung-usb2
++phy-samsung-usb3
++physmap
++physmap_of
++phy-twl4030-usb
++phy-twl6030-usb
++pixcir_i2c_ts
++pktcdvd
++pktgen
++pl2303
++pl330
++platform_lcd
++plat_nand
++plat-ram
++plip
++plusb
++pluto2
++plx_pci
++pm2fb
++pm3fb
++pm80xx
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pm-notifier-error-inject
++pn533
++pn544
++pn544_i2c
++pn_pep
++poseidon
++powermate
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++pppoatm
++pppoe
++pppox
++ppp_synctty
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++pvrusb2
++pwc
++pwm-beeper
++pwm_bl
++pwm-pca9685
++pwm-tegra
++pwm-twl
++pwm-twl-led
++pxa27x_udc
++qcaux
++qcserial
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qmi_wwan
++qnx4
++qnx6
++qt1010
++qt1070
++qt2160
++quatech2
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r815x
++r8169
++r8187se
++r8192e_pci
++r8192u_usb
++r820t
++r852
++r8712u
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-i2c-si470x
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-mr800
++radio-shark
++radio-si4713
++radio-si476x
++radio-tea5764
++radio-timb
++radio-usb-si470x
++radio-wl1273
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++rbd
++rbtree_test
++rc5t583-regulator
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rcar-du-drm
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv2
++rc-encore-enltv-fm53
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-tbs-nec
++rc-technisat-usb2
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++redboot
++redrat3
++reed_solomon
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rndis_host
++rndis_wlan
++rocket
++romfs
++rose
++rotary_encoder
++rp2
++rpcsec_gss_krb5
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt61pci
++rt73usb
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab3100
++rtc-bq32k
++rtc-bq4802
++rtc-cmos
++rtc-da9052
++rtc-da9055
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-msm6242
++rtc-palmas
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-pl030
++rtc-pl031
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-snvs
++rtc-stk17ta8
++rtc-tegra
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rtl2830
++rtl2832
++rtl8150
++rtl8180
++rtl8187
++rtl8188ee
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192se
++rtl8723ae
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtl_pci
++rtl_usb
++rtlwifi
++rts5139
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rx51_battery
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mps11
++s3fb
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7706h
++safe_serial
++sahara
++salsa20_generic
++samsung-keypad
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_rcar
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sbe-2t3e3
++sbp_target
++sbs-battery
++sc92031
++sca3000
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_tgt
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_spi
++scsi_transport_srp
++sctp
++sctp_probe
++sdhci-pci
++sdhci-pxav2
++sdhci-pxav3
++sdhci-tegra
++sdio_uart
++seed
++sep_driver
++seqiv
++ser_gigaset
++serial2002
++serial-tegra
++serio_raw
++sermouse
++serpent_generic
++serport
++serqt_usb2
++ses
++sfc
++sha1-arm
++shark2
++sh_eth
++shmob-drm
++sh_mobile_ceu_camera
++sh_mobile_csi2
++sht15
++sht21
++sh_veu
++si21xx
++si4713-i2c
++si476x-core
++sidewinder
++siemens_mpi
++sierra
++sierra_net
++sil164
++sir-dev
++sis190
++sis5595
++sis900
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_of_platform
++sja1000_platform
++skel
++skfp
++skge
++sky2
++sl811-hcd
++slcan
++slip
++slram
++sm501
++sm501fb
++sm7xxfb
++smb347-charger
++smc911x
++smc91x
++sm_common
++sm_ftl
++smm665
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd-aaci
++snd-ac97-codec
++snd-ad1889
++snd-ak4113
++snd-ak4114
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als300
++snd-at73c213
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt3328
++snd-bt87x
++snd-ca0106
++snd-cmipci
++snd-cs4281
++snd-cs46xx
++snd-cs5535audio
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1938
++snd-es1968
++snd-firewire-lib
++snd-firewire-speakers
++snd-fm801
++snd-gina20
++snd-gina24
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-isight
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-maestro3
++snd-mia
++snd-mixart
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3-synth
++snd-oxygen
++snd-oxygen-lib
++snd-pcxhr
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-soc-88pm860x
++snd-soc-ab8500-codec
++snd-soc-ac97
++snd-soc-ad1836
++snd-soc-ad193x
++snd-soc-ad1980
++snd-soc-ad73311
++snd-soc-adau1373
++snd-soc-adav80x
++snd-soc-ads117x
++snd-soc-ak4104
++snd-soc-ak4535
++snd-soc-ak4641
++snd-soc-ak4642
++snd-soc-ak4671
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-alc5632
++snd-soc-arizona
++snd-soc-atmel-pcm
++snd-soc-bt-sco
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs42l51
++snd-soc-cs42l52
++snd-soc-cs42l73
++snd-soc-cx20442
++snd-soc-da7210
++snd-soc-da7213
++snd-soc-da732x
++snd-soc-da9055
++snd-soc-imx-mc13783
++snd-soc-imx-ssi
++snd-soc-imx-wm8962
++snd-soc-isabelle
++snd-soc-jz4740-codec
++snd-soc-l3
++snd-soc-lm4857
++snd-soc-lm49453
++snd-soc-max9768
++snd-soc-max98088
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max9850
++snd-soc-max9877
++snd-soc-mc13783
++snd-soc-ml26124
++snd-soc-omap3pandora
++snd-soc-pcm3008
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-si476x
++snd-soc-simple-card
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2518
++snd-soc-ssm2602
++snd-soc-sta32x
++snd-soc-sta529
++snd-soc-stac9766
++snd-soc-tas5086
++snd-soc-tegra20-ac97
++snd-soc-tegra20-das
++snd-soc-tegra20-i2s
++snd-soc-tegra20-spdif
++snd-soc-tegra30-ahub
++snd-soc-tegra30-i2s
++snd-soc-tegra-alc5632
++snd-soc-tegra-pcm
++snd-soc-tegra-rt5640
++snd-soc-tegra-trimslice
++snd-soc-tegra-utils
++snd-soc-tegra-wm8753
++snd-soc-tegra-wm8903
++snd-soc-tegra-wm9712
++snd-soc-tlv320aic23
++snd-soc-tlv320aic26
++snd-soc-tlv320aic32x4
++snd-soc-tlv320aic3x
++snd-soc-tlv320dac33
++snd-soc-tpa6130a2
++snd-soc-uda134x
++snd-soc-uda1380
++snd-soc-wl1273
++snd-soc-wm0010
++snd-soc-wm1250-ev1
++snd-soc-wm2000
++snd-soc-wm2200
++snd-soc-wm5100
++snd-soc-wm5102
++snd-soc-wm5110
++snd-soc-wm8350
++snd-soc-wm8400
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8727
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8782
++snd-soc-wm8804
++snd-soc-wm8900
++snd-soc-wm8903
++snd-soc-wm8904
++snd-soc-wm8940
++snd-soc-wm8955
++snd-soc-wm8960
++snd-soc-wm8961
++snd-soc-wm8962
++snd-soc-wm8971
++snd-soc-wm8974
++snd-soc-wm8978
++snd-soc-wm8983
++snd-soc-wm8985
++snd-soc-wm8988
++snd-soc-wm8990
++snd-soc-wm8991
++snd-soc-wm8993
++snd-soc-wm8994
++snd-soc-wm8995
++snd-soc-wm8996
++snd-soc-wm9081
++snd-soc-wm9090
++snd-soc-wm9705
++snd-soc-wm9712
++snd-soc-wm9713
++snd-soc-wm-adsp
++snd-soc-wm-hubs
++snd-sonicvibes
++snd-tea575x-tuner
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usbmidi-lib
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx222
++snd-vx-lib
++snd-ymfpci
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++solo6x10
++solos-pci
++sony-btf-mpx
++sp805_wdt
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spidev
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi-imx
++spi_ks8995
++spi-lm70llp
++spi-oc-tiny
++spi-pl022
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tegra114
++spi-tegra20-sflash
++spi-tegra20-slink
++spi-tle62x0
++spi-topcliff-pch
++spi-xcomm
++squashfs
++ssb
++ssd1307fb
++ssfdc
++sst25l
++sstfb
++ssu100
++ssv_dnp
++st
++st1232
++st_accel
++st_accel_i2c
++st_accel_spi
++starfire
++stb0899
++stb6000
++stb6100
++st_drv
++ste_modem_rproc
++stex
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++stinger
++stir4200
++stk1160
++stkwebcam
++st_magn
++st_magn_i2c
++st_magn_spi
++stmmac
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++streamzap
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++suunto
++svcrdma
++svgalib
++sx8
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink_gt
++synclinkmp
++sysv
++t1pci
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++tc3589x-keypad
++tca6416-keypad
++tca8418_keypad
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea5761
++tea5767
++tea6415c
++tea6420
++tef6862
++tegra-aes
++tegra-kbc
++tehuti
++tekram-sir
++test-kprobes
++test-kstrtox
++test_power
++test-string_helpers
++tg3
++tgr192
++thmc50
++ti-adc081c
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++ti_hecc
++timb_dma
++timberdale
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++ti-soc-thermal
++ti_usb_3410_5052
++tlan
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmiofb
++tmio_mmc
++tmio_mmc_core
++tmio_nand
++tmp102
++tmp401
++tmp421
++tmscsim
++toim3232-sir
++touchit213
++touchright
++touchwin
++tpci200
++tpm_i2c_infineon
++tpm_i2c_stm_st33
++tpm-rng
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217
++tps65217_bl
++tps65217-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++tranzport
++tridentfb
++ts2020
++ts_bm
++tsc2005
++tsc2007
++tsc40
++ts_fsm
++ts_kmp
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner_it913x
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw9903
++tw9906
++tw9910
++twidjoy
++twl4030_charger
++twl4030_keypad
++twl4030-madc
++twl4030-madc-hwmon
++twl4030-pwrbutton
++twl4030-vibra
++twl4030_wdt
++twl6040-vibra
++twofish_common
++twofish_generic
++typhoon
++u132-hcd
++uartlite
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udf
++udl
++udlfb
++udp_diag
++ueagle-atm
++u_ether
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_netx
++uio_pci_generic
++uio_pdrv
++uio_pdrv_genirq
++uio_sercos3
++uli526x
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unioxx5
++unix_diag
++upd64031a
++upd64083
++u_rndis
++usb3503
++usb_8dev
++usb8xxx
++usbatm
++usb_debug
++usbdux
++usbduxfast
++usbduxsigma
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_gigaset
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usb-storage
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usb_wwan
++u_serial
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++ux500
++v4l2-common
++v4l2-int-device
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++veth
++vexpress
++vfio
++vfio-pci
++vgastate
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via686a
++via-rhine
++via-sdmmc
++via-velocity
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-memops
++videobuf2-vmalloc
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videodev
++viperboard
++viperboard_adc
++virtio_balloon
++virtio-rng
++virtio_rpmsg_bus
++virtio_scsi
++virtual
++visor
++vivi
++vivopay-serial
++vlsi_ir
++vmac
++vme
++vme_pio2
++vme_user
++vme_vmivme7805
++vmk80xx
++vmwgfx
++vmxnet3
++vp27smpx
++vpfe_capture
++vpss
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++w1_bq27000
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1-gpio
++w1_smem
++w1_therm
++w35und
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83l785ts
++w83l786ng
++w90p910_ts
++w9966
++wacom
++wacom_i2c
++wacom_w8001
++walkera0701
++wanxl
++warrior
++wdt_pci
++whci
++whci-hcd
++whc-rc
++whiteheat
++wimax
++winbond-840
++wire
++wishbone-serial
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x_backup
++wm831x_bl
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x_power
++wm831x-ts
++wm831x_wdt
++wm8350-hwmon
++wm8350_power
++wm8350-regulator
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-regulator
++wm97xx-ts
++wp512
++wusb-cbaf
++wusbcore
++wusb-wa
++x25
++x25_asy
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xenfs
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-privcmd
++xen_wdt
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xgmac
++xilinx_uartps
++xor
++xpad
++xprtrdma
++xsens_mt
++x_tables
++xt_addrtype
++xt_AUDIT
++xt_bpf
++xt_CHECKSUM
++xt_CLASSIFY
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_CONNSECMARK
++xt_conntrack
++xt_cpu
++xt_CT
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_DSCP
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_iprange
++xt_ipvs
++xtkbd
++xt_LED
++xt_length
++xt_limit
++xt_LOG
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_NETMAP
++xt_nfacct
++xt_NFLOG
++xt_NFQUEUE
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_RATEEST
++xt_realm
++xt_recent
++xt_REDIRECT
++xts
++xt_sctp
++xt_SECMARK
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_tcpudp
++xt_TEE
++xt_time
++xt_TPROXY
++xt_TRACE
++xt_u32
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yurex
++zaurus
++zd1201
++zd1211rw
++zhenhua
++zio
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zlib_deflate
++zr364xx
++zram
++zte_ev
+diff --git a/debian.master/abi/3.11.0-13.20/fwinfo b/debian.master/abi/3.11.0-13.20/fwinfo
+new file mode 100644
+index 0000000..3dfa90b
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/fwinfo
+@@ -0,0 +1,726 @@
++firmware:       3826.arm
++firmware:       3com/typhoon.bin
++firmware:       6fire/dmx6fireap.ihx
++firmware:       6fire/dmx6firecf.bin
++firmware:       6fire/dmx6firel2.ihx
++firmware:       acenic/tg1.bin
++firmware:       acenic/tg2.bin
++firmware:       adaptec/starfire_rx.bin
++firmware:       adaptec/starfire_tx.bin
++firmware:       advansys/3550.bin
++firmware:       advansys/38C0800.bin
++firmware:       advansys/38C1600.bin
++firmware:       advansys/mcode.bin
++firmware:       agere_ap_fw.bin
++firmware:       agere_sta_fw.bin
++firmware:       aic94xx-seq.fw
++firmware:       ar5523.bin
++firmware:       asihpi/dsp5000.bin
++firmware:       asihpi/dsp6200.bin
++firmware:       asihpi/dsp6205.bin
++firmware:       asihpi/dsp6400.bin
++firmware:       asihpi/dsp6600.bin
++firmware:       asihpi/dsp8700.bin
++firmware:       asihpi/dsp8900.bin
++firmware:       ath10k/QCA988X/hw1.0/board.bin
++firmware:       ath10k/QCA988X/hw1.0/firmware.bin
++firmware:       ath10k/QCA988X/hw1.0/otp.bin
++firmware:       ath10k/QCA988X/hw2.0/board.bin
++firmware:       ath10k/QCA988X/hw2.0/firmware.bin
++firmware:       ath10k/QCA988X/hw2.0/otp.bin
++firmware:       ath3k-1.fw
++firmware:       ath6k/AR6003/hw2.0/athwlan.bin.z77
++firmware:       ath6k/AR6003/hw2.0/bdata.bin
++firmware:       ath6k/AR6003/hw2.0/bdata.SD31.bin
++firmware:       ath6k/AR6003/hw2.0/data.patch.bin
++firmware:       ath6k/AR6003/hw2.0/otp.bin.z77
++firmware:       ath6k/AR6003/hw2.1.1/athwlan.bin
++firmware:       ath6k/AR6003/hw2.1.1/bdata.bin
++firmware:       ath6k/AR6003/hw2.1.1/bdata.SD31.bin
++firmware:       ath6k/AR6003/hw2.1.1/data.patch.bin
++firmware:       ath6k/AR6003/hw2.1.1/otp.bin
++firmware:       ath6k/AR6004/hw1.0/bdata.bin
++firmware:       ath6k/AR6004/hw1.0/bdata.DB132.bin
++firmware:       ath6k/AR6004/hw1.0/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.1/bdata.bin
++firmware:       ath6k/AR6004/hw1.1/bdata.DB132.bin
++firmware:       ath6k/AR6004/hw1.1/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.2/bdata.bin
++firmware:       ath6k/AR6004/hw1.2/fw.ram.bin
++firmware:       ath6k/AR6004/hw1.3/bdata.bin
++firmware:       ath6k/AR6004/hw1.3/fw.ram.bin
++firmware:       atmel_at76c502_3com.bin
++firmware:       atmel_at76c502_3com-wpa.bin
++firmware:       atmel_at76c502.bin
++firmware:       atmel_at76c502d.bin
++firmware:       atmel_at76c502d-wpa.bin
++firmware:       atmel_at76c502e.bin
++firmware:       atmel_at76c502e-wpa.bin
++firmware:       atmel_at76c502-wpa.bin
++firmware:       atmel_at76c503-i3861.bin
++firmware:       atmel_at76c503-i3863.bin
++firmware:       atmel_at76c503-rfmd-acc.bin
++firmware:       atmel_at76c503-rfmd.bin
++firmware:       atmel_at76c504_2958.bin
++firmware:       atmel_at76c504_2958-wpa.bin
++firmware:       atmel_at76c504a_2958.bin
++firmware:       atmel_at76c504a_2958-wpa.bin
++firmware:       atmel_at76c504.bin
++firmware:       atmel_at76c504-wpa.bin
++firmware:       atmel_at76c505amx-rfmd.bin
++firmware:       atmel_at76c505a-rfmd2958.bin
++firmware:       atmel_at76c505-rfmd2958.bin
++firmware:       atmel_at76c505-rfmd.bin
++firmware:       atmel_at76c506.bin
++firmware:       atmel_at76c506-wpa.bin
++firmware:       atmsar11.fw
++firmware:       atsc_denver.inp
++firmware:       av7110/bootcode.bin
++firmware:       b43legacy/ucode2.fw
++firmware:       b43legacy/ucode4.fw
++firmware:       b43/ucode11.fw
++firmware:       b43/ucode13.fw
++firmware:       b43/ucode14.fw
++firmware:       b43/ucode15.fw
++firmware:       b43/ucode16_mimo.fw
++firmware:       b43/ucode5.fw
++firmware:       b43/ucode9.fw
++firmware:       BCM2033-FW.bin
++firmware:       BCM2033-MD.hex
++firmware:       bfubase.frm
++firmware:       bnx2/bnx2-mips-06-6.2.3.fw
++firmware:       bnx2/bnx2-mips-09-6.2.1b.fw
++firmware:       bnx2/bnx2-rv2p-06-6.0.15.fw
++firmware:       bnx2/bnx2-rv2p-09-6.0.17.fw
++firmware:       bnx2/bnx2-rv2p-09ax-6.0.17.fw
++firmware:       bnx2x/bnx2x-e1-7.8.17.0.fw
++firmware:       bnx2x/bnx2x-e1h-7.8.17.0.fw
++firmware:       bnx2x/bnx2x-e2-7.8.17.0.fw
++firmware:       brcm/bcm43xx-0.fw
++firmware:       brcm/bcm43xx_hdr-0.fw
++firmware:       brcm/brcmfmac43143.bin
++firmware:       brcm/brcmfmac43236b.bin
++firmware:       brcm/brcmfmac43242a.bin
++firmware:       brcm/brcmfmac-sdio.bin
++firmware:       brcm/brcmfmac-sdio.txt
++firmware:       BT3CPCC.bin
++firmware:       c218tunx.cod
++firmware:       c320tunx.cod
++firmware:       carl9170-1.fw
++firmware:       cbfw-3.2.1.0.bin
++firmware:       cis/3CCFEM556.cis
++firmware:       cis/3CXEM556.cis
++firmware:       cis/COMpad2.cis
++firmware:       cis/COMpad4.cis
++firmware:       cis/DP83903.cis
++firmware:       cis/LA-PCM.cis
++firmware:       cis/MT5634ZLX.cis
++firmware:       cis/NE2K.cis
++firmware:       cis/PCMLM28.cis
++firmware:       cis/PE-200.cis
++firmware:       cis/PE520.cis
++firmware:       cis/RS-COM-2P.cis
++firmware:       cis/SW_555_SER.cis
++firmware:       cis/SW_7xx_SER.cis
++firmware:       cis/SW_8xx_SER.cis
++firmware:       cis/tamarack.cis
++firmware:       cmmb_ming_app.inp
++firmware:       cmmb_vega_12mhz.inp
++firmware:       cmmb_venice_12mhz.inp
++firmware:       comedi/jr3pci.idm
++firmware:       cp204unx.cod
++firmware:       cpia2/stv0672_vp4.bin
++firmware:       ct2fw-3.2.1.0.bin
++firmware:       ctefx.bin
++firmware:       ctfw-3.2.1.0.bin
++firmware:       cxgb3/ael2005_opt_edc.bin
++firmware:       cxgb3/ael2005_twx_edc.bin
++firmware:       cxgb3/ael2020_twx_edc.bin
++firmware:       cxgb3/t3b_psram-1.1.0.bin
++firmware:       cxgb3/t3c_psram-1.1.0.bin
++firmware:       cxgb3/t3fw-7.12.0.bin
++firmware:       cxgb4/t4fw.bin
++firmware:       cxgb4/t5fw.bin
++firmware:       cyzfirm.bin
++firmware:       daqboard2000_firmware.bin
++firmware:       digiface_firmware.bin
++firmware:       digiface_firmware_rev11.bin
++firmware:       dvb-cx18-mpc718-mt352.fw
++firmware:       dvb-fe-af9013.fw
++firmware:       dvb-fe-ds3000.fw
++firmware:       dvb-fe-tda10071.fw
++firmware:       dvb-fe-xc5000-1.6.114.fw
++firmware:       dvb-fe-xc5000c-4.1.30.7.fw
++firmware:       dvbh_rio.inp
++firmware:       dvb_nova_12mhz_b0.inp
++firmware:       dvb_nova_12mhz.inp
++firmware:       dvb_rio.inp
++firmware:       dvb-usb-af9015.fw
++firmware:       dvb-usb-af9035-02.fw
++firmware:       dvb-usb-dib0700-1.20.fw
++firmware:       dvb-usb-dw2101.fw
++firmware:       dvb-usb-dw2102.fw
++firmware:       dvb-usb-dw2104.fw
++firmware:       dvb-usb-dw3101.fw
++firmware:       dvb-usb-ec168.fw
++firmware:       dvb-usb-it9135-01.fw
++firmware:       dvb-usb-it9135-02.fw
++firmware:       dvb-usb-it9137-01.fw
++firmware:       dvb-usb-lme2510c-lg.fw
++firmware:       dvb-usb-lme2510c-rs2000.fw
++firmware:       dvb-usb-lme2510c-s0194.fw
++firmware:       dvb-usb-lme2510c-s7395.fw
++firmware:       dvb-usb-lme2510-lg.fw
++firmware:       dvb-usb-lme2510-s0194.fw
++firmware:       dvb-usb-p1100.fw
++firmware:       dvb-usb-p7500.fw
++firmware:       dvb-usb-s630.fw
++firmware:       dvb-usb-s660.fw
++firmware:       dvb-usb-terratec-h7-az6007.fw
++firmware:       e100/d101m_ucode.bin
++firmware:       e100/d101s_ucode.bin
++firmware:       e100/d102e_ucode.bin
++firmware:       ea/3g_asic.fw
++firmware:       ea/darla20_dsp.fw
++firmware:       ea/darla24_dsp.fw
++firmware:       ea/echo3g_dsp.fw
++firmware:       ea/gina20_dsp.fw
++firmware:       ea/gina24_301_asic.fw
++firmware:       ea/gina24_301_dsp.fw
++firmware:       ea/gina24_361_asic.fw
++firmware:       ea/gina24_361_dsp.fw
++firmware:       ea/indigo_dj_dsp.fw
++firmware:       ea/indigo_djx_dsp.fw
++firmware:       ea/indigo_dsp.fw
++firmware:       ea/indigo_io_dsp.fw
++firmware:       ea/indigo_iox_dsp.fw
++firmware:       ea/layla20_asic.fw
++firmware:       ea/layla20_dsp.fw
++firmware:       ea/layla24_1_asic.fw
++firmware:       ea/layla24_2A_asic.fw
++firmware:       ea/layla24_2S_asic.fw
++firmware:       ea/layla24_dsp.fw
++firmware:       ea/loader_dsp.fw
++firmware:       ea/mia_dsp.fw
++firmware:       ea/mona_2_asic.fw
++firmware:       ea/mona_301_1_asic_48.fw
++firmware:       ea/mona_301_1_asic_96.fw
++firmware:       ea/mona_301_dsp.fw
++firmware:       ea/mona_361_1_asic_48.fw
++firmware:       ea/mona_361_1_asic_96.fw
++firmware:       ea/mona_361_dsp.fw
++firmware:       edgeport/boot2.fw
++firmware:       edgeport/boot.fw
++firmware:       edgeport/down2.fw
++firmware:       edgeport/down3.bin
++firmware:       edgeport/down.fw
++firmware:       emi26/bitstream.fw
++firmware:       emi26/firmware.fw
++firmware:       emi26/loader.fw
++firmware:       emi62/bitstream.fw
++firmware:       emi62/loader.fw
++firmware:       emi62/spdif.fw
++firmware:       emu/audio_dock.fw
++firmware:       emu/emu0404.fw
++firmware:       emu/emu1010b.fw
++firmware:       emu/emu1010_notebook.fw
++firmware:       emu/hana.fw
++firmware:       emu/micro_dock.fw
++firmware:       ene-ub6250/ms_init.bin
++firmware:       ene-ub6250/msp_rdwr.bin
++firmware:       ene-ub6250/ms_rdwr.bin
++firmware:       ene-ub6250/sd_init1.bin
++firmware:       ene-ub6250/sd_init2.bin
++firmware:       ene-ub6250/sd_rdwr.bin
++firmware:       ess/maestro3_assp_kernel.fw
++firmware:       ess/maestro3_assp_minisrc.fw
++firmware:       f2255usb.bin
++firmware:       fm_radio.inp
++firmware:       fm_radio_rio.inp
++firmware:       fw.ram.bin
++firmware:       go7007/go7007fw.bin
++firmware:       go7007/go7007tv.bin
++firmware:       go7007/lr192.fw
++firmware:       go7007/px-m402u.fw
++firmware:       go7007/px-tv402u.fw
++firmware:       go7007/s2250-1.fw
++firmware:       go7007/s2250-2.fw
++firmware:       go7007/wis-startrek.fw
++firmware:       htc_7010.fw
++firmware:       htc_9271.fw
++firmware:       i1480-phy-0.0.bin
++firmware:       i1480-pre-phy-0.0.bin
++firmware:       i1480-usb-0.0.bin
++firmware:       i2400m-fw-usb-1.5.sbcf
++firmware:       i6050-fw-usb-1.5.sbcf
++firmware:       ipw2100-1.3.fw
++firmware:       ipw2100-1.3-i.fw
++firmware:       ipw2100-1.3-p.fw
++firmware:       ipw2200-bss.fw
++firmware:       ipw2200-ibss.fw
++firmware:       ipw2200-sniffer.fw
++firmware:       isci/isci_firmware.bin
++firmware:       isdbt_nova_12mhz_b0.inp
++firmware:       isdbt_nova_12mhz.inp
++firmware:       isdbt_pele.inp
++firmware:       isdbt_rio.inp
++firmware:       isdn/ISAR.BIN
++firmware:       isi4608.bin
++firmware:       isi4616.bin
++firmware:       isi608.bin
++firmware:       isi608em.bin
++firmware:       isi616em.bin
++firmware:       isight.fw
++firmware:       isl3886pci
++firmware:       isl3886usb
++firmware:       isl3887usb
++firmware:       iwlwifi-1000-5.ucode
++firmware:       iwlwifi-100-5.ucode
++firmware:       iwlwifi-105-6.ucode
++firmware:       iwlwifi-135-6.ucode
++firmware:       iwlwifi-2000-6.ucode
++firmware:       iwlwifi-2030-6.ucode
++firmware:       iwlwifi-3160-7.ucode
++firmware:       iwlwifi-3945-2.ucode
++firmware:       iwlwifi-4965-2.ucode
++firmware:       iwlwifi-5000-5.ucode
++firmware:       iwlwifi-5150-2.ucode
++firmware:       iwlwifi-6000-4.ucode
++firmware:       iwlwifi-6000g2a-5.ucode
++firmware:       iwlwifi-6000g2b-6.ucode
++firmware:       iwlwifi-6050-5.ucode
++firmware:       iwlwifi-7260-7.ucode
++firmware:       kaweth/new_code.bin
++firmware:       kaweth/new_code_fix.bin
++firmware:       kaweth/trigger_code.bin
++firmware:       kaweth/trigger_code_fix.bin
++firmware:       keyspan/mpr.fw
++firmware:       keyspan_pda/keyspan_pda.fw
++firmware:       keyspan_pda/xircom_pgs.fw
++firmware:       keyspan/usa18x.fw
++firmware:       keyspan/usa19.fw
++firmware:       keyspan/usa19qi.fw
++firmware:       keyspan/usa19qw.fw
++firmware:       keyspan/usa19w.fw
++firmware:       keyspan/usa28.fw
++firmware:       keyspan/usa28xa.fw
++firmware:       keyspan/usa28xb.fw
++firmware:       keyspan/usa28x.fw
++firmware:       keyspan/usa49w.fw
++firmware:       keyspan/usa49wlc.fw
++firmware:       korg/k1212.dsp
++firmware:       lbtf_usb.bin
++firmware:       lgs8g75.fw
++firmware:       libertas/cf8305.bin
++firmware:       libertas/cf8381.bin
++firmware:       libertas/cf8381_helper.bin
++firmware:       libertas/cf8385.bin
++firmware:       libertas/cf8385_helper.bin
++firmware:       libertas_cs.fw
++firmware:       libertas_cs_helper.fw
++firmware:       libertas/gspi8385.bin
++firmware:       libertas/gspi8385_helper.bin
++firmware:       libertas/gspi8385_hlp.bin
++firmware:       libertas/gspi8686.bin
++firmware:       libertas/gspi8686_hlp.bin
++firmware:       libertas/gspi8686_v9.bin
++firmware:       libertas/gspi8686_v9_helper.bin
++firmware:       libertas/gspi8688.bin
++firmware:       libertas/gspi8688_helper.bin
++firmware:       libertas/sd8385.bin
++firmware:       libertas/sd8385_helper.bin
++firmware:       libertas/sd8686_v8.bin
++firmware:       libertas/sd8686_v8_helper.bin
++firmware:       libertas/sd8686_v9.bin
++firmware:       libertas/sd8686_v9_helper.bin
++firmware:       libertas/sd8688.bin
++firmware:       libertas/sd8688_helper.bin
++firmware:       libertas/usb8388.bin
++firmware:       libertas/usb8388_v5.bin
++firmware:       libertas/usb8388_v9.bin
++firmware:       libertas/usb8682.bin
++firmware:       matrox/g200_warp.fw
++firmware:       matrox/g400_warp.fw
++firmware:       me2600_firmware.bin
++firmware:       mixart/miXart8AES.xlx
++firmware:       mixart/miXart8.elf
++firmware:       mixart/miXart8.xlx
++firmware:       mrvl/pcie8766_uapsta.bin
++firmware:       mrvl/pcie8897_uapsta.bin
++firmware:       mrvl/sd8688.bin
++firmware:       mrvl/sd8688_helper.bin
++firmware:       mrvl/sd8786_uapsta.bin
++firmware:       mrvl/sd8787_uapsta.bin
++firmware:       mrvl/sd8797_uapsta.bin
++firmware:       mrvl/sd8897_uapsta.bin
++firmware:       mrvl/usb8797_uapsta.bin
++firmware:       mt7650.bin
++firmware:       mt7662.bin
++firmware:       mts_cdma.fw
++firmware:       mts_edge.fw
++firmware:       mts_gsm.fw
++firmware:       mts_mt9234mu.fw
++firmware:       mts_mt9234zba.fw
++firmware:       multiface_firmware.bin
++firmware:       multiface_firmware_rev11.bin
++firmware:       mwl8k/fmimage_8363.fw
++firmware:       mwl8k/fmimage_8366_ap-3.fw
++firmware:       mwl8k/fmimage_8366.fw
++firmware:       mwl8k/fmimage_8687.fw
++firmware:       mwl8k/helper_8363.fw
++firmware:       mwl8k/helper_8366.fw
++firmware:       mwl8k/helper_8687.fw
++firmware:       myri10ge_ethp_z8e.dat
++firmware:       myri10ge_eth_z8e.dat
++firmware:       myri10ge_rss_ethp_z8e.dat
++firmware:       myri10ge_rss_eth_z8e.dat
++firmware:       ni6534a.bin
++firmware:       niscrb01.bin
++firmware:       niscrb02.bin
++firmware:       orinoco_ezusb_fw
++firmware:       ositech/Xilinx7OD.bin
++firmware:       pca200e_ecd.bin2
++firmware:       pcxhr/dspb1222e.b56
++firmware:       pcxhr/dspb1222hr.b56
++firmware:       pcxhr/dspb882e.b56
++firmware:       pcxhr/dspb882hr.b56
++firmware:       pcxhr/dspb924.b56
++firmware:       pcxhr/dspd1222.d56
++firmware:       pcxhr/dspd222.d56
++firmware:       pcxhr/dspd882.d56
++firmware:       pcxhr/dspe882.e56
++firmware:       pcxhr/dspe924.e56
++firmware:       pcxhr/xlxc1222e.dat
++firmware:       pcxhr/xlxc1222hr.dat
++firmware:       pcxhr/xlxc222.dat
++firmware:       pcxhr/xlxc882e.dat
++firmware:       pcxhr/xlxc882hr.dat
++firmware:       pcxhr/xlxc924.dat
++firmware:       pcxhr/xlxint.dat
++firmware:       phanfw.bin
++firmware:       prism2_ru.fw
++firmware:       prism_ap_fw.bin
++firmware:       prism_sta_fw.bin
++firmware:       ql2100_fw.bin
++firmware:       ql2200_fw.bin
++firmware:       ql2300_fw.bin
++firmware:       ql2322_fw.bin
++firmware:       ql2400_fw.bin
++firmware:       ql2500_fw.bin
++firmware:       qlogic/1040.bin
++firmware:       qlogic/12160.bin
++firmware:       qlogic/1280.bin
++firmware:       qlogic/sd7220.fw
++firmware:       r128/r128_cce.bin
++firmware:       radeon/ARUBA_me.bin
++firmware:       radeon/ARUBA_pfp.bin
++firmware:       radeon/ARUBA_rlc.bin
++firmware:       radeon/BARTS_mc.bin
++firmware:       radeon/BARTS_me.bin
++firmware:       radeon/BARTS_pfp.bin
++firmware:       radeon/BARTS_smc.bin
++firmware:       radeon/BONAIRE_ce.bin
++firmware:       radeon/BONAIRE_mc.bin
++firmware:       radeon/BONAIRE_me.bin
++firmware:       radeon/BONAIRE_mec.bin
++firmware:       radeon/BONAIRE_pfp.bin
++firmware:       radeon/BONAIRE_rlc.bin
++firmware:       radeon/BONAIRE_sdma.bin
++firmware:       radeon/BONAIRE_uvd.bin
++firmware:       radeon/BTC_rlc.bin
++firmware:       radeon/CAICOS_mc.bin
++firmware:       radeon/CAICOS_me.bin
++firmware:       radeon/CAICOS_pfp.bin
++firmware:       radeon/CAICOS_smc.bin
++firmware:       radeon/CAYMAN_mc.bin
++firmware:       radeon/CAYMAN_me.bin
++firmware:       radeon/CAYMAN_pfp.bin
++firmware:       radeon/CAYMAN_rlc.bin
++firmware:       radeon/CAYMAN_smc.bin
++firmware:       radeon/CEDAR_me.bin
++firmware:       radeon/CEDAR_pfp.bin
++firmware:       radeon/CEDAR_rlc.bin
++firmware:       radeon/CEDAR_smc.bin
++firmware:       radeon/CYPRESS_me.bin
++firmware:       radeon/CYPRESS_pfp.bin
++firmware:       radeon/CYPRESS_rlc.bin
++firmware:       radeon/CYPRESS_smc.bin
++firmware:       radeon/CYPRESS_uvd.bin
++firmware:       radeon/HAINAN_ce.bin
++firmware:       radeon/HAINAN_mc.bin
++firmware:       radeon/HAINAN_me.bin
++firmware:       radeon/HAINAN_pfp.bin
++firmware:       radeon/HAINAN_rlc.bin
++firmware:       radeon/HAINAN_smc.bin
++firmware:       radeon/JUNIPER_me.bin
++firmware:       radeon/JUNIPER_pfp.bin
++firmware:       radeon/JUNIPER_rlc.bin
++firmware:       radeon/JUNIPER_smc.bin
++firmware:       radeon/KABINI_ce.bin
++firmware:       radeon/KABINI_me.bin
++firmware:       radeon/KABINI_mec.bin
++firmware:       radeon/KABINI_pfp.bin
++firmware:       radeon/KABINI_rlc.bin
++firmware:       radeon/KABINI_sdma.bin
++firmware:       radeon/KAVERI_ce.bin
++firmware:       radeon/KAVERI_me.bin
++firmware:       radeon/KAVERI_mec.bin
++firmware:       radeon/KAVERI_pfp.bin
++firmware:       radeon/KAVERI_rlc.bin
++firmware:       radeon/KAVERI_sdma.bin
++firmware:       radeon/OLAND_ce.bin
++firmware:       radeon/OLAND_mc.bin
++firmware:       radeon/OLAND_me.bin
++firmware:       radeon/OLAND_pfp.bin
++firmware:       radeon/OLAND_rlc.bin
++firmware:       radeon/OLAND_smc.bin
++firmware:       radeon/PALM_me.bin
++firmware:       radeon/PALM_pfp.bin
++firmware:       radeon/PITCAIRN_ce.bin
++firmware:       radeon/PITCAIRN_mc.bin
++firmware:       radeon/PITCAIRN_me.bin
++firmware:       radeon/PITCAIRN_pfp.bin
++firmware:       radeon/PITCAIRN_rlc.bin
++firmware:       radeon/PITCAIRN_smc.bin
++firmware:       radeon/R100_cp.bin
++firmware:       radeon/R200_cp.bin
++firmware:       radeon/R300_cp.bin
++firmware:       radeon/R420_cp.bin
++firmware:       radeon/R520_cp.bin
++firmware:       radeon/R600_me.bin
++firmware:       radeon/R600_pfp.bin
++firmware:       radeon/R600_rlc.bin
++firmware:       radeon/R700_rlc.bin
++firmware:       radeon/REDWOOD_me.bin
++firmware:       radeon/REDWOOD_pfp.bin
++firmware:       radeon/REDWOOD_rlc.bin
++firmware:       radeon/REDWOOD_smc.bin
++firmware:       radeon/RS600_cp.bin
++firmware:       radeon/RS690_cp.bin
++firmware:       radeon/RS780_me.bin
++firmware:       radeon/RS780_pfp.bin
++firmware:       radeon/RV610_me.bin
++firmware:       radeon/RV610_pfp.bin
++firmware:       radeon/RV620_me.bin
++firmware:       radeon/RV620_pfp.bin
++firmware:       radeon/RV630_me.bin
++firmware:       radeon/RV630_pfp.bin
++firmware:       radeon/RV635_me.bin
++firmware:       radeon/RV635_pfp.bin
++firmware:       radeon/RV670_me.bin
++firmware:       radeon/RV670_pfp.bin
++firmware:       radeon/RV710_me.bin
++firmware:       radeon/RV710_pfp.bin
++firmware:       radeon/RV710_smc.bin
++firmware:       radeon/RV710_uvd.bin
++firmware:       radeon/RV730_me.bin
++firmware:       radeon/RV730_pfp.bin
++firmware:       radeon/RV730_smc.bin
++firmware:       radeon/RV740_smc.bin
++firmware:       radeon/RV770_me.bin
++firmware:       radeon/RV770_pfp.bin
++firmware:       radeon/RV770_smc.bin
++firmware:       radeon/SUMO2_me.bin
++firmware:       radeon/SUMO2_pfp.bin
++firmware:       radeon/SUMO_me.bin
++firmware:       radeon/SUMO_pfp.bin
++firmware:       radeon/SUMO_rlc.bin
++firmware:       radeon/SUMO_uvd.bin
++firmware:       radeon/TAHITI_ce.bin
++firmware:       radeon/TAHITI_mc.bin
++firmware:       radeon/TAHITI_me.bin
++firmware:       radeon/TAHITI_pfp.bin
++firmware:       radeon/TAHITI_rlc.bin
++firmware:       radeon/TAHITI_smc.bin
++firmware:       radeon/TAHITI_uvd.bin
++firmware:       radeon/TURKS_mc.bin
++firmware:       radeon/TURKS_me.bin
++firmware:       radeon/TURKS_pfp.bin
++firmware:       radeon/TURKS_smc.bin
++firmware:       radeon/VERDE_ce.bin
++firmware:       radeon/VERDE_mc.bin
++firmware:       radeon/VERDE_me.bin
++firmware:       radeon/VERDE_pfp.bin
++firmware:       radeon/VERDE_rlc.bin
++firmware:       radeon/VERDE_smc.bin
++firmware:       riptide.hex
++firmware:       rp2.fw
++firmware:       rpm_firmware.bin
++firmware:       rt2561.bin
++firmware:       rt2561s.bin
++firmware:       rt2661.bin
++firmware:       rt2860.bin
++firmware:       rt2870.bin
++firmware:       rt73.bin
++firmware:       RTL8192E/boot.img
++firmware:       RTL8192E/data.img
++firmware:       RTL8192E/main.img
++firmware:       RTL8192U/boot.img
++firmware:       RTL8192U/data.img
++firmware:       RTL8192U/main.img
++firmware:       rtl_nic/rtl8105e-1.fw
++firmware:       rtl_nic/rtl8106e-1.fw
++firmware:       rtl_nic/rtl8106e-2.fw
++firmware:       rtl_nic/rtl8168d-1.fw
++firmware:       rtl_nic/rtl8168d-2.fw
++firmware:       rtl_nic/rtl8168e-1.fw
++firmware:       rtl_nic/rtl8168e-2.fw
++firmware:       rtl_nic/rtl8168e-3.fw
++firmware:       rtl_nic/rtl8168f-1.fw
++firmware:       rtl_nic/rtl8168f-2.fw
++firmware:       rtl_nic/rtl8168g-2.fw
++firmware:       rtl_nic/rtl8168g-3.fw
++firmware:       rtl_nic/rtl8402-1.fw
++firmware:       rtl_nic/rtl8411-1.fw
++firmware:       rtl_nic/rtl8411-2.fw
++firmware:       rtlwifi/rtl8188efw.bin
++firmware:       rtlwifi/rtl8192cfw.bin
++firmware:       rtlwifi/rtl8192cfwU_B.bin
++firmware:       rtlwifi/rtl8192cfwU.bin
++firmware:       rtlwifi/rtl8192cufw.bin
++firmware:       rtlwifi/rtl8192defw.bin
++firmware:       rtlwifi/rtl8192sefw.bin
++firmware:       rtlwifi/rtl8712u.bin
++firmware:       rtlwifi/rtl8723fw_B.bin
++firmware:       rtlwifi/rtl8723fw.bin
++firmware:       sb16/alaw_main.csp
++firmware:       sb16/ima_adpcm_capture.csp
++firmware:       sb16/ima_adpcm_init.csp
++firmware:       sb16/ima_adpcm_playback.csp
++firmware:       sb16/mulaw_main.csp
++firmware:       scope.cod
++firmware:       sd8385.bin
++firmware:       sd8385_helper.bin
++firmware:       sd8686.bin
++firmware:       sd8686_helper.bin
++firmware:       sd8688.bin
++firmware:       sd8688_helper.bin
++firmware:       slicoss/gbdownload.sys
++firmware:       slicoss/gbrcvucode.sys
++firmware:       slicoss/oasisdownload.sys
++firmware:       slicoss/oasisrcvucode.sys
++firmware:       sms1xxx-hcw-55xxx-dvbt-02.fw
++firmware:       sms1xxx-hcw-55xxx-isdbt-02.fw
++firmware:       sms1xxx-nova-a-dvbt-01.fw
++firmware:       sms1xxx-nova-b-dvbt-01.fw
++firmware:       sms1xxx-stellar-dvbt-01.fw
++firmware:       sndscape.co0
++firmware:       sndscape.co1
++firmware:       sndscape.co2
++firmware:       sndscape.co3
++firmware:       sndscape.co4
++firmware:       softing-4.6/bcard2.bin
++firmware:       softing-4.6/bcard.bin
++firmware:       softing-4.6/cancard.bin
++firmware:       softing-4.6/cancrd2.bin
++firmware:       softing-4.6/cansja.bin
++firmware:       softing-4.6/ldcard2.bin
++firmware:       softing-4.6/ldcard.bin
++firmware:       solos-db-FPGA.bin
++firmware:       solos-Firmware.bin
++firmware:       solos-FPGA.bin
++firmware:       sun/cassini.bin
++firmware:       symbol_sp24t_prim_fw
++firmware:       symbol_sp24t_sec_fw
++firmware:       tdmb_denver.inp
++firmware:       tdmb_nova_12mhz_b0.inp
++firmware:       tdmb_nova_12mhz.inp
++firmware:       tehuti/bdx.bin
++firmware:       ti_3410.fw
++firmware:       ti_5052.fw
++firmware:       ti-connectivity/wl1271-nvs.bin
++firmware:       ti-connectivity/wl127x-fw-5-mr.bin
++firmware:       ti-connectivity/wl127x-fw-5-plt.bin
++firmware:       ti-connectivity/wl127x-fw-5-sr.bin
++firmware:       ti-connectivity/wl128x-fw-5-mr.bin
++firmware:       ti-connectivity/wl128x-fw-5-plt.bin
++firmware:       ti-connectivity/wl128x-fw-5-sr.bin
++firmware:       ti-connectivity/wl18xx-fw-2.bin
++firmware:       tigon/tg3.bin
++firmware:       tigon/tg3_tso5.bin
++firmware:       tigon/tg3_tso.bin
++firmware:       tlg2300_firmware.bin
++firmware:       ttusb-budget/dspbootcode.bin
++firmware:       turtlebeach/msndinit.bin
++firmware:       turtlebeach/msndperm.bin
++firmware:       turtlebeach/pndsperm.bin
++firmware:       turtlebeach/pndspini.bin
++firmware:       ueagle-atm/930-fpga.bin
++firmware:       ueagle-atm/adi930.fw
++firmware:       ueagle-atm/CMV4i.bin
++firmware:       ueagle-atm/CMV4i.bin.v2
++firmware:       ueagle-atm/CMV4p.bin
++firmware:       ueagle-atm/CMV4p.bin.v2
++firmware:       ueagle-atm/CMV9i.bin
++firmware:       ueagle-atm/CMV9i.bin.v2
++firmware:       ueagle-atm/CMV9p.bin
++firmware:       ueagle-atm/CMV9p.bin.v2
++firmware:       ueagle-atm/CMVei.bin
++firmware:       ueagle-atm/CMVei.bin.v2
++firmware:       ueagle-atm/CMVep.bin
++firmware:       ueagle-atm/CMVep.bin.v2
++firmware:       ueagle-atm/DSP4i.bin
++firmware:       ueagle-atm/DSP4p.bin
++firmware:       ueagle-atm/DSP9i.bin
++firmware:       ueagle-atm/DSP9p.bin
++firmware:       ueagle-atm/DSPei.bin
++firmware:       ueagle-atm/DSPep.bin
++firmware:       ueagle-atm/eagle.fw
++firmware:       ueagle-atm/eagleI.fw
++firmware:       ueagle-atm/eagleII.fw
++firmware:       ueagle-atm/eagleIII.fw
++firmware:       ueagle-atm/eagleIV.fw
++firmware:       usb8388.bin
++firmware:       usbduxfast_firmware.bin
++firmware:       usbdux_firmware.bin
++firmware:       usbduxsigma_firmware.bin
++firmware:       v4l-cx231xx-avcore-01.fw
++firmware:       v4l-cx23418-apu.fw
++firmware:       v4l-cx23418-cpu.fw
++firmware:       v4l-cx23418-dig.fw
++firmware:       v4l-cx2341x-dec.fw
++firmware:       v4l-cx2341x-enc.fw
++firmware:       v4l-cx2341x-init.mpg
++firmware:       v4l-cx23885-avcore-01.fw
++firmware:       v4l-cx23885-enc.fw
++firmware:       v4l-cx25840.fw
++firmware:       v4l-pvrusb2-24xxx-01.fw
++firmware:       v4l-pvrusb2-29xxx-01.fw
++firmware:       v4l-pvrusb2-73xxx-01.fw
++firmware:       vicam/firmware.fw
++firmware:       vntwusb.fw
++firmware:       vx/bd56002.boot
++firmware:       vx/bd563s3.boot
++firmware:       vx/bd563v2.boot
++firmware:       vx/bx_1_vp4.b56
++firmware:       vx/bx_1_vxp.b56
++firmware:       vxge/X3fw.ncf
++firmware:       vxge/X3fw-pxe.ncf
++firmware:       vx/l_1_v22.d56
++firmware:       vx/l_1_vp4.d56
++firmware:       vx/l_1_vx2.d56
++firmware:       vx/l_1_vxp.d56
++firmware:       vx/x1_1_vp4.xlx
++firmware:       vx/x1_1_vx2.xlx
++firmware:       vx/x1_1_vxp.xlx
++firmware:       vx/x1_2_v22.xlx
++firmware:       wavefront.os
++firmware:       whiteheat.fw
++firmware:       whiteheat_loader.fw
++firmware:       wl1251-fw.bin
++firmware:       xc3028L-v36.fw
++firmware:       xc3028-v27.fw
++firmware:       yam/1200.bin
++firmware:       yam/9600.bin
++firmware:       yamaha/ds1_ctrl.fw
++firmware:       yamaha/ds1_dsp.fw
++firmware:       yamaha/ds1e_ctrl.fw
++firmware:       yamaha/yss225_registers.bin
++firmware:       zd1201-ap.fw
++firmware:       zd1201.fw
++firmware:       zd1211/zd1211b_ub
++firmware:       zd1211/zd1211b_uphr
++firmware:       zd1211/zd1211b_ur
++firmware:       zd1211/zd1211_ub
++firmware:       zd1211/zd1211_uphr
++firmware:       zd1211/zd1211_ur
+diff --git a/debian.master/abi/3.11.0-13.20/i386/generic b/debian.master/abi/3.11.0-13.20/i386/generic
+new file mode 100644
+index 0000000..7c5fe9a
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/i386/generic
+@@ -0,0 +1,15645 @@
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x130d743b	kvm_cpu_has_pending_timer
++EXPORT_SYMBOL arch/x86/kvm/kvm 0x93f16c06	kvm_read_guest_atomic
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x254e5667	scx200_gpio_base
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x35a3c008	scx200_gpio_configure
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x8cfa375c	scx200_gpio_shadow
++EXPORT_SYMBOL arch/x86/platform/scx200/scx200 0x907665bd	scx200_cb_base
++EXPORT_SYMBOL crypto/gf128mul 0x0c2f123f	gf128mul_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x1068004b	gf128mul_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x2f2889a0	gf128mul_init_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x3755f990	gf128mul_init_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x384ef9ce	gf128mul_64k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x56af0dbd	gf128mul_x_ble
++EXPORT_SYMBOL crypto/gf128mul 0x83581089	gf128mul_init_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0x9b2560b9	gf128mul_init_4k_bbe
++EXPORT_SYMBOL crypto/gf128mul 0x9e13f6f6	gf128mul_lle
++EXPORT_SYMBOL crypto/gf128mul 0xbd17a0df	gf128mul_4k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xc0890413	gf128mul_64k_lle
++EXPORT_SYMBOL crypto/gf128mul 0xd60736ec	gf128mul_free_64k
++EXPORT_SYMBOL crypto/xor 0x5b6c00e6	xor_blocks
++EXPORT_SYMBOL drivers/acpi/video 0x674bc758	acpi_video_get_edid
++EXPORT_SYMBOL drivers/acpi/video 0x7a45377b	acpi_video_unregister
++EXPORT_SYMBOL drivers/acpi/video 0x8826c13b	acpi_video_register
++EXPORT_SYMBOL drivers/atm/suni 0xa1a96190	suni_init
++EXPORT_SYMBOL drivers/atm/uPD98402 0xba043a0e	uPD98402_init
++EXPORT_SYMBOL drivers/bcma/bcma 0x6a3247df	bcma_core_dma_translation
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x127a5901	drbd_set_st_err_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x35131b36	drbd_role_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0x7730f22d	drbd_conn_str
++EXPORT_SYMBOL drivers/block/drbd/drbd 0xaf27bebf	drbd_disk_str
++EXPORT_SYMBOL drivers/block/paride/paride 0x01fd3b76	pi_connect
++EXPORT_SYMBOL drivers/block/paride/paride 0x1abf361f	pi_schedule_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0x31d90e01	pi_release
++EXPORT_SYMBOL drivers/block/paride/paride 0x434a0753	pi_disconnect
++EXPORT_SYMBOL drivers/block/paride/paride 0x4a1feaec	pi_read_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0x595b8a60	paride_unregister
++EXPORT_SYMBOL drivers/block/paride/paride 0x9286aa66	pi_write_regr
++EXPORT_SYMBOL drivers/block/paride/paride 0xa30d9570	pi_init
++EXPORT_SYMBOL drivers/block/paride/paride 0xc87a991e	pi_write_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xe0fa3784	pi_read_block
++EXPORT_SYMBOL drivers/block/paride/paride 0xecd00d2b	pi_do_claimed
++EXPORT_SYMBOL drivers/block/paride/paride 0xfeccc350	paride_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x0a8ea925	ipmi_register_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1348760d	ipmi_request_settime
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x16dcec76	ipmi_set_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1a10c898	ipmi_set_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x1aba5db8	ipmi_unregister_smi
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x30a65532	ipmi_smi_add_proc_entry
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x40f2b10c	ipmi_alloc_smi_msg
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x423b776a	ipmi_create_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x4c971bec	ipmi_smi_msg_received
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x524f6f51	ipmi_get_my_address
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5e80f37c	ipmi_unregister_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x5fcdcc05	ipmi_get_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x67cb9784	ipmi_poll_interface
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x728f9c4d	ipmi_smi_watcher_register
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x78fd36e7	ipmi_request_supply_msgs
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x804f922a	ipmi_addr_length
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x861eeed4	ipmi_smi_watcher_unregister
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x8c8ee770	ipmi_destroy_user
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0x96cbcc81	ipmi_get_version
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa28a2ace	ipmi_set_gets_events
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xa2a98b91	ipmi_get_maintenance_mode
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xb3d02b1d	ipmi_get_smi_info
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe0fa83f2	ipmi_register_for_cmd
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe4f4665b	ipmi_validate_addr
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xe6ab72a6	ipmi_set_my_LUN
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xf2576cb9	ipmi_smi_watchdog_pretimeout
++EXPORT_SYMBOL drivers/char/ipmi/ipmi_msghandler 0xfcb77cfd	ipmi_free_recv_msg
++EXPORT_SYMBOL drivers/char/nsc_gpio 0x452315ca	nsc_gpio_write
++EXPORT_SYMBOL drivers/char/nsc_gpio 0xaf5d33e7	nsc_gpio_dump
++EXPORT_SYMBOL drivers/char/nsc_gpio 0xd79e5573	nsc_gpio_read
++EXPORT_SYMBOL drivers/char/nvram 0x0f28cb91	nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x17ff2c1d	__nvram_read_byte
++EXPORT_SYMBOL drivers/char/nvram 0x2adec1e0	__nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x7da28f12	nvram_check_checksum
++EXPORT_SYMBOL drivers/char/nvram 0x9ce3f83f	nvram_write_byte
++EXPORT_SYMBOL drivers/char/nvram 0xa8813189	__nvram_write_byte
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x188bc347	dw_dma_cyclic_start
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x1b78b64b	dw_dma_get_dst_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x6a2563d5	dw_dma_cyclic_free
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x7f2a6808	dw_dma_cyclic_stop
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0x99821d2a	dw_dma_get_src_addr
++EXPORT_SYMBOL drivers/dma/dw/dw_dmac_core 0xf7d7e0e9	dw_dma_cyclic_prep
++EXPORT_SYMBOL drivers/dma/ioat/ioatdma 0xb600edbc	ioat_dma_setup_interrupts
++EXPORT_SYMBOL drivers/edac/edac_core 0xc8a4df83	edac_mc_find
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04a2fa30	fw_iso_context_flush_completions
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x04dd92ce	fw_core_add_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x09e6fb53	fw_iso_context_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x16e91e21	fw_csr_iterator_next
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x20a367d7	fw_cancel_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x21d789b3	fw_core_remove_card
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2885fec5	fw_get_request_speed
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2ee22a63	fw_iso_context_queue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x2f8dc583	fw_card_add
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c1dd642	fw_iso_context_start
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x3c56ef91	fw_workqueue
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4506df65	fw_iso_buffer_destroy
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4d5d4eca	fw_core_remove_descriptor
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x4e57c07c	fw_iso_context_create
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x50c11815	fw_core_remove_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x53182035	fw_send_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x5559d0b5	fw_core_handle_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x584701f0	fw_card_initialize
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x64ac0d90	fw_send_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x65c9438b	fw_csr_iterator_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x6e445645	fw_iso_resource_manage
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x7e431b14	fw_csr_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x86468d44	fw_rcode_string
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x8cd79796	fw_bus_type
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x90863005	fw_high_memory_region
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x961f6b81	fw_core_add_address_handler
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9decaab2	fw_core_handle_bus_reset
++EXPORT_SYMBOL drivers/firewire/firewire-core 0x9f5c04dc	fw_run_transaction
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xa732fed4	fw_iso_buffer_init
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xaf776a1e	fw_device_enable_phys_dma
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xb81b9acc	fw_iso_context_stop
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xbd154786	fw_core_handle_request
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc4864b5f	fw_iso_context_queue_flush
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xc53a9e79	fw_fill_response
++EXPORT_SYMBOL drivers/firewire/firewire-core 0xcc553d47	fw_schedule_bus_reset
++EXPORT_SYMBOL drivers/firmware/dcdbas 0xa75079d6	dcdbas_smi_request
++EXPORT_SYMBOL drivers/fmc/fmc 0x3ed49751	fmc_device_register_n
++EXPORT_SYMBOL drivers/fmc/fmc 0x53ae3991	fmc_driver_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x5502a0ed	fmc_show_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x5f03a568	fmc_device_unregister
++EXPORT_SYMBOL drivers/fmc/fmc 0x763207e8	fmc_driver_register
++EXPORT_SYMBOL drivers/fmc/fmc 0x96b18708	fmc_scan_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0x9c06d651	fmc_find_sdb_device
++EXPORT_SYMBOL drivers/fmc/fmc 0xad9405b1	fmc_device_unregister_n
++EXPORT_SYMBOL drivers/fmc/fmc 0xc807aa6f	fmc_device_register
++EXPORT_SYMBOL drivers/fmc/fmc 0xd8e77aeb	fmc_free_sdb_tree
++EXPORT_SYMBOL drivers/fmc/fmc 0xd9632b36	fmc_reprogram
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0027326e	drm_mm_clean
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x015e9918	drm_mode_config_reset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x027a64ab	drm_connector_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02e6e099	drm_mode_width
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x02f2e985	drm_platform_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0310877f	drm_gem_prime_import
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x03d922c6	drm_ioctl
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x06d9b688	drm_gem_create_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x07c00207	drm_gem_vm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x088e0a13	drm_gem_prime_handle_to_fd
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0a914ae3	drm_rmmap_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ae4b94c	drm_ht_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0bca79c5	drm_mm_scan_add_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0ca81641	drm_mm_init_scan
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0d068abc	drm_prime_gem_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0e8df279	drm_i2c_encoder_save
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fccafb1	drm_global_item_unref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x0fd60df2	drm_get_connector_status_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x11065515	drm_mode_equal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x119c36d8	drm_fasync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12c6276a	drm_buffer_read_object
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12cfa2f6	drm_rmmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x12ea1c75	drm_mm_insert_node_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x139bb8d1	drm_get_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x142b8b35	drm_buffer_copy_from_user
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x14a9a178	drm_get_format_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x17b639a9	drm_framebuffer_reference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x18813209	drm_agp_acquire
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x194eadaa	drm_edid_header_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1a770ac3	drm_detect_hdmi_monitor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1aa0ab88	drm_mode_validate_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1adca954	drm_get_connector_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d281245	drm_ati_pcigart_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1d683f92	drm_av_sync_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x1eba81ff	drm_mm_search_free_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x20645642	drm_debug
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x226fd3e4	drm_framebuffer_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x26256356	drm_mode_equal_no_clocks
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2782332a	drm_core_ioremap_wc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27e3a883	drm_gem_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27e51d8c	drm_mode_find_dmt
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x27e6ef05	drm_pci_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2b5ffdf6	drm_connector_unplug_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2d50570f	drm_rect_calc_hscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2e7a4300	drm_rgb_quant_range_selectable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ec7d975	drm_mode_create_dirty_info_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2ee6a0fb	drm_mm_dump_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x2f66e9eb	drm_vblank_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3074f033	drm_order
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x321850eb	drm_agp_unbind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x325ba5c1	drm_fill_in_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33022635	drm_mm_replace_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x33883232	drm_pci_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x346127a7	drm_global_item_ref
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x36ba7ce3	drm_mode_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x37feac63	drm_plane_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38a4f7ae	drm_format_num_planes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38ba0572	drm_i2c_encoder_mode_fixup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x38fa1a1b	drm_pci_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3910b32c	drm_mode_connector_update_edid_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x394c597a	drm_pci_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x39d7a59c	drm_modeset_unlock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3a0f87a2	drm_vblank_post_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3ac1fef9	drm_mode_legacy_fb_format
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3b9d009a	drm_format_plane_cpp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c14c7b7	drm_gem_private_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c228b57	drm_mode_crtc_set_gamma_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3c5dd832	drm_mm_put_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3cbfe33d	drm_global_mutex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3d26f6fa	drm_read
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3de0b056	drm_mode_group_init_legacy_group
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3eb37b9d	drm_ht_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x3fdc7825	drm_mm_pre_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x414af14a	drm_gtf_mode_complex
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43384bd9	drm_buffer_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x43b713cb	drm_gem_mmap_obj
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x44a0c113	drm_mode_height
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x475d7efe	drm_sysfs_connector_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x48cabe41	drm_mode_create_from_cmdline_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4980c582	drm_gem_object_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x498dcb5e	drm_ut_debug_printk
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x49c23e1f	drm_framebuffer_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ae8d5ef	drm_agp_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ae9884f	drm_mode_config_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4c511235	drm_edid_is_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4e0c01ee	drm_unbind_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4ea1f5a2	drm_gem_object_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f63def2	drm_modeset_lock_all
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x4f683950	drm_vblank_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x50e28c07	drm_edid_to_sad
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x521e4b9d	drm_connector_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x526f6f71	drm_rect_calc_hscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x547ed66c	drm_mode_create_scaling_mode_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x549f3d58	drm_i2c_encoder_detect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x580329c3	drm_mode_create_dvi_i_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x59a62c11	drm_i2c_encoder_restore
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ae051af	drm_mm_insert_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e1e7a7a	drm_getsarea
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e33b78f	drm_mode_create_dithering_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5e926e8d	drm_open
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5eafb8e9	drm_mode_set_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x5ecf13cb	drm_mode_create_tv_properties
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x60fc359c	drm_core_ioremapfree
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x617cf89a	drm_mm_debug_table
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x629c05e1	drm_clflush_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x64d8f617	drm_prime_remove_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x651133e4	drm_vblank_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65287ba8	drm_mm_takedown
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x65a27574	drm_poll
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6900d335	drm_rect_clip_scaled
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69be2e83	drm_get_last_vbltimestamp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x69eb2c41	drm_addbufs_pci
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6b6d7375	drm_timestamp_precision
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6cee2e42	drm_object_property_get_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6d7e5682	drm_probe_ddc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6e7869ed	drm_prime_lookup_buf_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ee3e89c	drm_mm_scan_remove_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6ee961a4	drm_mm_insert_node_in_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6f090540	drm_mm_get_block_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x6fe952d5	drm_master_put
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7034f4e0	drm_mode_parse_command_line_for_connector
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x71870f3e	drm_property_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7300ec28	drm_idlelock_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x738724cd	drm_irq_install
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x765c0602	drm_pcie_get_speed_cap_mask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x76b18044	drm_mode_duplicate
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7848f485	drm_property_create_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x78a13731	drm_mode_object_find
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x79cd7104	drm_vblank_count_and_time
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a4e7297	drm_edid_block_valid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7a5afafb	drm_calc_vbltimestamp_from_scanoutpos
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7afe05d0	drm_framebuffer_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7b42b5d4	drm_mode_copy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7bc99cf2	drm_mm_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7c3a5a62	drm_debugfs_remove_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x7f25300f	drm_i2c_encoder_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8216c83f	drm_prime_destroy_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83a93bde	drm_select_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x83d08f63	drm_mmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x871ab41a	drm_rect_intersect
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8775d99b	drm_mm_search_free_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x88203261	drm_property_create_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x886b39e1	drm_vblank_pre_modeset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8878816e	drm_prime_sg_to_page_addr_arrays
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8ad31f67	drm_agp_alloc
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c510862	drm_find_cea_extension
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8c644195	drm_plane_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8de13715	drm_format_vert_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8dfb019d	drm_buffer_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8eff9111	drm_ht_find_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f262bff	drm_platform_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x8f7df3a7	drm_object_attach_property
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91cb276c	drm_gem_free_mmap_offset
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x91fec1cc	drm_rect_calc_vscale
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x93ed907f	drm_i2c_encoder_prepare
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x942ef2e2	drm_vblank_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x95d40514	drm_get_pci_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9670d850	drm_send_vblank_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9745d638	drm_err
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9972db48	drm_rect_calc_vscale_relaxed
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a1b2d8c	drm_property_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9a6662c3	drm_vblank_count
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9afd6887	drm_gem_object_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9be5f616	drm_addbufs_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9c14d53d	drm_get_platform_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f6cc61f	drm_mm_create_block
++EXPORT_SYMBOL drivers/gpu/drm/drm 0x9f8fe4d4	drm_vblank_off
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa15a32dc	drm_gem_handle_create
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1e561b8	drm_agp_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1e99a1f	drm_gem_prime_export
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa1eabd87	drm_mode_list_concat
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa5183f05	drm_add_modes_noedid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa63aa849	drm_i2c_encoder_commit
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa6ba74dd	drm_mode_connector_list_update
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa807801d	drm_crtc_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xa96acfcb	drm_rect_debug_print
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaa8b5c45	drm_noop
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xaacb6efd	drm_framebuffer_unregister_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xad0a0d71	drm_prime_init_file_private
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb2ead560	drm_mm_get_block_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb37d75ed	drm_put_minor
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4b757cc	drm_mode_set_config_internal
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb4e090dc	drm_addmap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb532a618	drm_cvt_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb810cefc	drm_plane_force_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xb95beb55	drm_object_property_set_value
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xba2d0719	drm_mode_hsync
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbae4dc9a	drm_handle_vblank
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbb130c25	drm_agp_bind
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbbb67d13	drm_i2c_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbcc432c1	drm_gem_vm_close
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbe001c53	drm_property_add_enum
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xbf8fdaa4	drm_irq_uninstall
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc083b2b3	drm_master_get
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc0f81b59	drm_property_create_bitmask
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc20ed002	drm_mode_validate_size
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc25a61ec	drm_mode_set_crtcinfo
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc2a56f5b	drm_mode_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc35f2695	drm_mm_init_scan_with_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc414c422	drm_vblank_offdelay
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc4329210	drm_framebuffer_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc52bbc77	drm_agp_info
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc55c7ef8	drm_sysfs_connector_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc6f7d579	drm_mm_remove_node
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xc91c1499	drm_free_agp
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca093d30	drm_get_edid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xca45efbc	drm_format_horz_chroma_subsampling
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcb1beab5	drm_mode_vrefresh
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xccc04926	drm_gem_object_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcd0fc417	drm_ht_just_insert_please
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcda91c46	drm_mode_debug_printmodeline
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xce440e77	drm_unplug_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xcfda5e61	drm_sysfs_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd04b40e9	drm_get_encoder_name
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd0b3be1d	drm_agp_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd125790d	drm_hdmi_avi_infoframe_from_display_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd2335101	drm_fb_get_bpp_depth
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd379817d	drm_crtc_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd41773f1	drm_i2c_encoder_destroy
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd4a2d991	drm_edid_to_eld
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd6e65c27	drm_core_ioremap
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd761bb26	drm_idlelock_take
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd79083ce	drm_gem_object_handle_free
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd7c22139	drm_debugfs_create_files
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd84e1c53	drm_mm_insert_node_in_range_generic
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xd8d901a2	drm_mode_remove
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdb43eab1	drm_warn_on_modeset_not_all_locked
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdbb5a9f5	drm_ht_remove_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xdd178171	drm_ati_pcigart_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe00d110b	drm_mode_prune_invalid
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe586f6aa	drm_core_reclaim_buffers
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6083a63	drm_encoder_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe694444a	drm_add_edid_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6ba3380	drm_mode_connector_attach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe6f46e6e	drm_clflush_virt_range
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7197773	drm_ht_insert_item
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe77924e8	drm_match_cea_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe7adb4c2	drm_gem_handle_delete
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe889ecfc	drm_i2c_encoder_mode_set
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe8a077d7	drm_encoder_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9032502	drm_mode_config_init
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xe9a77608	drm_mode_probed_add
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xeac37b2b	drm_put_dev
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed66c343	drm_gem_prime_fd_to_handle
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xed8dd554	drm_mode_connector_detach_encoder
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf11da40c	drm_gtf_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf1421d13	drm_mode_sort
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf6fa4219	drm_agp_bind_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf7667525	drm_gem_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xf9f98ce0	drm_clflush_pages
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfc72a487	drm_prime_pages_to_sg
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfcfad184	drm_release
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xff11f402	drm_framebuffer_unreference
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xffc6c87a	drm_detect_monitor_audio
++EXPORT_SYMBOL drivers/gpu/drm/drm 0xfff57a2c	drm_calc_timestamping_constants
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x0b1525c6	drm_kms_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x117fd3d1	drm_helper_connector_dpms
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x14f6fd24	drm_fb_helper_debug_leave
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x28915fbc	drm_helper_hpd_irq_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2d7a787f	drm_dp_clock_recovery_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x2f4eb605	drm_crtc_helper_set_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x3107d9b6	drm_fb_helper_fill_fix
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x33f2d692	drm_kms_helper_poll_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x35680d9f	drm_fb_helper_set_par
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x35a0a8ff	drm_kms_helper_poll_enable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4a5c38a2	drm_fb_helper_fill_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x4a99cb60	drm_helper_move_panel_connectors_to_head
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x62f780b2	drm_helper_mode_fill_fb_struct
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x711a004a	drm_dp_link_rate_to_bw_code
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7175126b	drm_fb_helper_hotplug_event
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x754c8d9e	drm_fb_helper_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7d2832a9	drm_fb_helper_initial_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x7e5632bf	drm_helper_resume_force_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x864cfc1f	drm_fb_helper_debug_enter
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x974cc3fb	drm_kms_helper_poll_disable
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x99fe5543	drm_fb_helper_blank
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0x9c558f75	drm_helper_probe_single_connector_modes
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa6904b72	drm_fb_helper_single_add_all_connectors
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xa8d6809d	drm_dp_bw_code_to_link_rate
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xab480ae6	drm_helper_encoder_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb37a0603	drm_dp_link_train_channel_eq_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xb8b98198	drm_fb_helper_setcmap
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc65a18f5	drm_fb_helper_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xc7fd39bb	drm_dp_channel_eq_ok
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd02c73c7	drm_dp_link_train_clock_recovery_delay
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd0d03436	i2c_dp_aux_add_bus
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd116284e	drm_fb_helper_pan_display
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5ab8ecc	drm_fb_helper_restore_fbdev_mode
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5d8b6b8	drm_dp_get_adjust_request_pre_emphasis
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd5eda711	drm_crtc_helper_set_config
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xd6ae63f1	drm_fb_helper_check_var
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe13ca1f8	drm_kms_helper_poll_fini
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xe21f7e93	drm_helper_crtc_in_use
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xf422e19d	drm_helper_disable_unused_functions
++EXPORT_SYMBOL drivers/gpu/drm/drm_kms_helper 0xfee43a69	drm_dp_get_adjust_request_voltage
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x13919866	drm_usb_init
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0x97d8422c	drm_usb_exit
++EXPORT_SYMBOL drivers/gpu/drm/drm_usb 0xa759c092	drm_get_usb_dev
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x008f7989	ttm_pool_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0216e86a	ttm_bo_add_to_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d019992	ttm_bo_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d1180f3	ttm_base_object_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x0d1513e8	ttm_eu_fence_buffer_objects
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x132b05be	ttm_round_pot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x15034467	ttm_dma_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17d67f3d	ttm_object_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x17e48a1d	ttm_base_object_lookup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x19db1305	ttm_read_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x229b8f75	ttm_agp_tt_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x266d8a60	ttm_io_prot
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x27110ab5	ttm_mem_global_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x28909165	ttm_mem_io_free
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2a473953	ttm_dma_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2a8bfb95	ttm_bo_move_accel_cleanup
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b0d0aa7	ttm_bo_device_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x2b54aa9a	ttm_object_file_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3183d519	ttm_suspend_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x31cddedd	ttm_mem_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x32a5d162	ttm_tt_set_placement_caching
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3515032a	ttm_agp_tt_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x35240ec4	ttm_bo_validate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x3d6a779b	ttm_write_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4376cea7	ttm_bo_kunmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x470db7e2	ttm_bo_move_memcpy
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4d1eea63	ttm_base_object_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4ec708d1	ttm_fbdev_mmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x4fbecf74	ttm_tt_bind
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x530b4377	ttm_bo_unlock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x556f3592	ttm_tt_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x55d6204b	ttm_tt_fini
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x55ea4392	ttm_bo_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5cf59609	ttm_bo_global_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x5ee83ca5	ttm_bo_unmap_virtual
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x67b1d568	ttm_bo_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x682099b8	ttm_bo_kmap
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x68aec421	ttm_eu_backoff_reservation
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x69558cd7	ttm_vt_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x6bda0fb6	ttm_bo_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x71ea15a9	ttm_bo_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7617732f	ttm_bo_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x780098a9	ttm_bo_wait
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7a4f03f9	ttm_bo_manager_func
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7a622979	ttm_bo_create
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x7a9c4dff	ttm_bo_lock_delayed_workqueue
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x80d86f0e	ttm_object_device_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x8c946335	ttm_mem_io_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x90da1b38	ttm_bo_synccpu_write_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x998e45c0	ttm_ref_object_base_unref
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0x9bdfdc93	ttm_mem_io_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa26f2680	ttm_bo_swapout_all
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa822b180	ttm_mem_global_alloc
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xa95a4711	ttm_read_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xac506855	ttm_bo_synccpu_write_grab
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb505a04a	ttm_bo_clean_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb7902d7f	ttm_ref_object_add
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xb9721305	ttm_agp_tt_unpopulate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbd51692c	ttm_write_unlock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xbe071587	ttm_eu_reserve_buffers
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc2f7a143	ttm_suspend_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5f787f3	ttm_page_alloc_debugfs
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc5ff39a2	ttm_bo_mem_put
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xc99a81be	ttm_bo_move_ttm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xca74b51f	ttm_bo_init_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcc16f448	ttm_mem_global_release
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xcdeb2ffe	ttm_bo_dma_acc_size
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xd4d7df06	ttm_pool_populate
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xdbf32d07	ttm_lock_init
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xddaf7099	ttm_bo_evict_mm
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea3fd16e	ttm_mem_io_reserve
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xea603afc	ttm_bo_del_sub_from_lru
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xee4a19bf	ttm_vt_lock
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xf7effd47	ttm_bo_mem_space
++EXPORT_SYMBOL drivers/gpu/drm/ttm/ttm 0xfbc2c5ec	ttm_object_file_release
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0x2d481753	vmbus_sendpacket
++EXPORT_SYMBOL drivers/hv/hv_vmbus 0xd4bc7996	vmbus_recvpacket
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0x0903c239	vid_from_reg
++EXPORT_SYMBOL drivers/hwmon/hwmon-vid 0xef1c781c	vid_which_vrm
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x011b6d7e	sch56xx_watchdog_register
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0e2a6864	sch56xx_read_virtual_reg
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x0f5877d4	sch56xx_read_virtual_reg16
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0x34257f35	sch56xx_watchdog_unregister
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xe5022f95	sch56xx_read_virtual_reg12
++EXPORT_SYMBOL drivers/hwmon/sch56xx-common 0xed1d2a08	sch56xx_write_virtual_reg
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x5f6d9964	i2c_bit_add_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0x85853be7	i2c_bit_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-bit 0xc65d7f1c	i2c_bit_algo
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0x47acd17f	i2c_pca_add_numbered_bus
++EXPORT_SYMBOL drivers/i2c/algos/i2c-algo-pca 0xdc5cbc8b	i2c_pca_add_bus
++EXPORT_SYMBOL drivers/i2c/busses/i2c-amd756 0x7cdb34cd	amd756_smbus
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xce9e96e2	st_accel_common_remove
++EXPORT_SYMBOL drivers/iio/accel/st_accel 0xd040ee92	st_accel_common_probe
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x13a51a2a	hid_sensor_write_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x2add5f32	hid_sensor_read_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x31541952	hid_sensor_write_samp_freq_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x339f0b05	hid_sensor_parse_common_attributes
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-iio-common 0x69c8fedc	hid_sensor_read_raw_hyst_value
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xbe2616d4	hid_sensor_setup_trigger
++EXPORT_SYMBOL drivers/iio/common/hid-sensors/hid-sensor-trigger 0xeed60b73	hid_sensor_remove_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x074d7047	st_sensors_trigger_handler
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x09c6b071	st_sensors_set_fullscale_by_gain
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x358a368e	st_sensors_check_device_support
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x49824244	st_sensors_get_buffer_element
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x6e65d893	st_sensors_allocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x72e50d7a	st_sensors_deallocate_trigger
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0x7faa9fc0	st_sensors_set_dataready_irq
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa2a22034	st_sensors_set_odr
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xa571bec8	st_sensors_init_sensor
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xb7a28d4a	st_sensors_sysfs_get_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xba45ee6d	st_sensors_set_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xd5d0699c	st_sensors_sysfs_scale_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xdeed8a6c	st_sensors_read_info_raw
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xe81d51fa	st_sensors_sysfs_sampling_frequency_avail
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf27e86cd	st_sensors_sysfs_set_sampling_frequency
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors 0xf75a9c50	st_sensors_set_axis_enable
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_i2c 0xb2edf0e3	st_sensors_i2c_configure
++EXPORT_SYMBOL drivers/iio/common/st_sensors/st_sensors_spi 0xfebc35d0	st_sensors_spi_configure
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x209f067a	st_gyro_common_remove
++EXPORT_SYMBOL drivers/iio/gyro/st_gyro 0x3bf56623	st_gyro_common_probe
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xc023aa43	adis_debugfs_reg_access
++EXPORT_SYMBOL drivers/iio/imu/adis_lib 0xf3c101a3	adis_enable_irq
++EXPORT_SYMBOL drivers/iio/industrialio 0x11e03ee5	iio_trigger_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x2d6bcdcb	iio_trigger_generic_data_rdy_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x331f35b5	iio_buffer_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x393f8869	iio_triggered_buffer_predisable
++EXPORT_SYMBOL drivers/iio/industrialio 0x4d4799f5	iio_device_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x50054f6a	iio_device_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0x58604ed5	iio_triggered_buffer_postenable
++EXPORT_SYMBOL drivers/iio/industrialio 0x5a8401ee	iio_trigger_free
++EXPORT_SYMBOL drivers/iio/industrialio 0x63355d25	iio_buffer_store_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0x6591aa7f	iio_trigger_poll
++EXPORT_SYMBOL drivers/iio/industrialio 0x73e0666f	iio_trigger_poll_chained
++EXPORT_SYMBOL drivers/iio/industrialio 0x7f55c394	iio_trigger_register
++EXPORT_SYMBOL drivers/iio/industrialio 0x92e2e6a0	iio_read_const_attr
++EXPORT_SYMBOL drivers/iio/industrialio 0xa819a2b8	iio_buffer_unregister
++EXPORT_SYMBOL drivers/iio/industrialio 0xadd32580	iio_sw_buffer_preenable
++EXPORT_SYMBOL drivers/iio/industrialio 0xb59e4c0a	iio_push_event
++EXPORT_SYMBOL drivers/iio/industrialio 0xb5b17b52	iio_trigger_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xc8dac364	iio_buffer_init
++EXPORT_SYMBOL drivers/iio/industrialio 0xd4757604	iio_buffer_write_length
++EXPORT_SYMBOL drivers/iio/industrialio 0xdf76bbeb	iio_pollfunc_store_time
++EXPORT_SYMBOL drivers/iio/industrialio 0xe2cf8c57	iio_buffer_read_length
++EXPORT_SYMBOL drivers/iio/industrialio 0xe60cc8d7	iio_trigger_notify_done
++EXPORT_SYMBOL drivers/iio/industrialio 0xf192aae1	iio_device_alloc
++EXPORT_SYMBOL drivers/iio/industrialio 0xf7d4154f	iio_bus_type
++EXPORT_SYMBOL drivers/iio/industrialio 0xfc7ed235	iio_buffer_show_enable
++EXPORT_SYMBOL drivers/iio/industrialio 0xfd8320c8	iio_device_register
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xadbd0d61	iio_triggered_buffer_setup
++EXPORT_SYMBOL drivers/iio/industrialio-triggered-buffer 0xcbcbcf8f	iio_triggered_buffer_cleanup
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0x57dc41bc	iio_kfifo_allocate
++EXPORT_SYMBOL drivers/iio/kfifo_buf 0xdc2e2b56	iio_kfifo_free
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x3be7c188	st_magn_common_probe
++EXPORT_SYMBOL drivers/iio/magnetometer/st_magn 0x619b6ebd	st_magn_common_remove
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x2d4cad35	st_press_common_probe
++EXPORT_SYMBOL drivers/iio/pressure/st_pressure 0x86d1acea	st_press_common_remove
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x1c3c0ad3	rdma_addr_size
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x37838b44	rdma_translate_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x4322552e	rdma_copy_addr
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x8ed679ff	rdma_addr_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0x9d1f522d	rdma_addr_cancel
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xb93baf0d	rdma_resolve_ip
++EXPORT_SYMBOL drivers/infiniband/core/ib_addr 0xc0bf4edc	rdma_addr_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x193dd67e	ib_send_cm_rej
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x1f1a6bea	ib_send_cm_lap
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x36e98b0f	ib_send_cm_sidr_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x3a917d33	ib_send_cm_dreq
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x3c5021cc	ib_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x53d28175	ib_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x5492e698	ib_cm_notify
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0x86249939	ib_send_cm_sidr_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa0dc5684	ib_send_cm_drep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa19eacc8	ib_send_cm_rep
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xa317bf15	ib_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xc67fd0a4	cm_class
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xd24d3a8d	ib_send_cm_apr
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xdd6df951	ib_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xed72c5f5	ib_send_cm_req
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xeeb5d308	ib_send_cm_mra
++EXPORT_SYMBOL drivers/infiniband/core/ib_cm 0xfdb4d89c	ib_send_cm_rtu
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x00a2aba2	ib_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0639e2c7	ib_get_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x06c82fcf	mult_to_ib_rate
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0843258d	ib_query_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0a540f1d	ib_unregister_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0c1b9ac1	ib_ud_header_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x0d229051	ib_find_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x119819d8	ib_destroy_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14393b13	ib_dispatch_event
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x14f84918	ib_rate_to_mbps
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x16be6621	ib_get_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x171f99f1	ib_rate_to_mult
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1e491a04	ib_unmap_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x1fe23f81	ib_modify_qp_is_ok
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x22028eaf	ib_detach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2664c554	ib_umem_page_count
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x286d715c	ib_find_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x289557b3	ib_alloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2a42b347	ib_register_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2a6b8c62	ib_create_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2aa315c2	ib_set_client_data
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2bbe4506	ib_fmr_pool_map_phys
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x2ed6e386	ib_ud_header_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x307ea179	ib_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x334f574e	ib_query_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x36e4caa7	ib_dealloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3783ea07	ib_create_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x3b8d56d4	ib_dealloc_pd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x48ac6980	ib_open_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4be34a6e	ib_query_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x4cd5df35	ib_modify_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x50dbc447	ib_flush_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x513f56cf	ib_alloc_xrcd
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x520b2638	ib_pack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x52cf6384	ib_free_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x53704ceb	ib_create_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x5d6003fc	ib_fmr_pool_unmap
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6dd54921	ibnl_put_msg
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x6fef1d67	ib_close_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x76e9d1aa	ib_query_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7720d57d	ib_dealloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x78e256fd	ib_modify_port
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7d0037a6	ib_modify_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7e769257	ib_create_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x7fb54880	ib_register_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x82f2c8ac	ib_rereg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8b4218bb	ib_find_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x8e863491	ib_query_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9003db5e	ib_modify_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x90d15385	ibnl_put_attr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x96ce6c46	rdma_node_get_transport
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x97c4ee9a	ib_umem_release
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9bbca355	ib_alloc_fmr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0x9d98110b	ib_alloc_fast_reg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa77b61b5	ib_attach_mcast
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa87fa080	ibnl_add_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xa9e18492	ib_find_exact_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaaed3440	ib_query_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xabaa1ea8	ib_destroy_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xaceba16c	ib_query_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb1a312e1	ib_unpack
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xb529f482	ib_destroy_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbeb0aa04	ib_query_ah
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xbf078da2	ib_dealloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc0433378	ib_modify_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc32b59ff	ib_destroy_fmr_pool
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc586e6b7	ib_umem_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc67f14a5	ibnl_remove_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc8600471	ib_create_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xc865a7c7	ib_get_dma_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xcd4792f7	rdma_port_get_link_layer
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd093211d	ib_resize_cq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd1b4cad3	ib_destroy_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd52c33a0	ib_get_cached_lmc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xd86398e0	ib_dereg_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe0c4d145	ib_reg_phys_mr
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe19c0987	ib_alloc_mw
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe48b86e3	ib_modify_srq
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe5829e92	ib_init_ah_from_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe652499a	ib_alloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xe73f79b8	ib_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xecee6048	ib_unregister_event_handler
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xee8e0b2f	ib_dealloc_device
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xf1f40863	ib_get_cached_gid
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfa69e2f3	ib_alloc_fast_reg_page_list
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfc150956	ib_ud_header_init
++EXPORT_SYMBOL drivers/infiniband/core/ib_core 0xfd6ee9f0	ib_find_cached_pkey
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x05c23274	ib_get_rmpp_segment
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x0fbe4b6c	ib_redirect_mad_qp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x1d957d18	ib_free_recv_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x26db6a7d	ib_unregister_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x2e4d7490	ib_process_mad_wc
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x5d785056	ib_cancel_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x66fd7b47	ib_free_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x6f077fcf	ib_get_mad_data_offset
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x7b5d4b7a	ib_is_mad_class_rmpp
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x86573e6e	ib_post_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x91c63218	ib_modify_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0x946d5d27	ib_response_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd8859954	ib_create_send_mad
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd9131705	ib_register_mad_agent
++EXPORT_SYMBOL drivers/infiniband/core/ib_mad 0xd9baa4e6	ib_register_mad_snoop
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x00c07e20	ib_sa_service_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x2c026d31	ib_init_ah_from_mcmember
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x333382f5	ib_init_ah_from_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x364c8e62	ib_sa_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x576fdbac	ib_sa_free_multicast
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x5d432e24	ib_sa_get_mcmember_rec
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x6e44fd9f	ib_sa_register_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x6ee3ec0b	ib_sa_path_rec_get
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0x8001438f	ib_sa_unregister_client
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xda0d50ec	ib_sa_cancel_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xe9efd86f	ib_sa_pack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf07f032f	ib_sa_guid_info_rec_query
++EXPORT_SYMBOL drivers/infiniband/core/ib_sa 0xf6b6444b	ib_sa_unpack_path
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x02f847bc	ib_copy_path_rec_from_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x07cf5a51	ib_copy_ah_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x18382f6a	ib_copy_path_rec_to_user
++EXPORT_SYMBOL drivers/infiniband/core/ib_uverbs 0x184f3575	ib_copy_qp_attr_to_user
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x09964b03	iw_cm_accept
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3487543f	iw_cm_connect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x3e276b9c	iw_cm_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x443a66f7	iw_cm_reject
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x55ababb9	iw_cm_listen
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x6a74cd72	iw_cm_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0x9c832a72	iw_destroy_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/iw_cm 0xddb50005	iw_create_cm_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x26007b7b	rdma_create_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x35d9f807	rdma_set_reuseaddr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4085580a	rdma_accept
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x4a50949b	rdma_disconnect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x5a36fb1f	rdma_set_service_type
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x713d5117	rdma_set_afonly
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x7632ed25	rdma_get_service_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x789141eb	rdma_join_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x82676bfd	rdma_leave_multicast
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x923a4ef9	rdma_resolve_route
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0x9a8ff632	rdma_resolve_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xa4196307	rdma_notify
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xb8848854	rdma_reject
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xba6b9b3b	rdma_set_ib_paths
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xce7c1b68	rdma_destroy_id
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd4934309	rdma_create_qp
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xd8483e20	rdma_init_qp_attr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf0ca4f00	rdma_connect
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf7b497f7	rdma_listen
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xf7ee7210	rdma_bind_addr
++EXPORT_SYMBOL drivers/infiniband/core/rdma_cm 0xfa6ef9ff	rdma_destroy_qp
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x234688d7	gameport_stop_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x3f446043	gameport_set_phys
++EXPORT_SYMBOL drivers/input/gameport/gameport 0x9be9da7f	__gameport_register_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xafb576e5	__gameport_register_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xc338eda0	gameport_start_polling
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe01253a7	gameport_open
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe2baf1b0	gameport_unregister_port
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xe317832a	gameport_unregister_driver
++EXPORT_SYMBOL drivers/input/gameport/gameport 0xecf06de5	gameport_close
++EXPORT_SYMBOL drivers/input/input-polldev 0x06ad5d80	input_register_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x550c9125	input_free_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0x72e2e1c9	input_allocate_polled_device
++EXPORT_SYMBOL drivers/input/input-polldev 0xf4f7bb60	input_unregister_polled_device
++EXPORT_SYMBOL drivers/input/matrix-keymap 0xb180db0c	matrix_keypad_build_keymap
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x7fce2bec	ad714x_probe
++EXPORT_SYMBOL drivers/input/misc/ad714x 0x9db851ec	ad714x_enable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xb8721c9c	ad714x_disable
++EXPORT_SYMBOL drivers/input/misc/ad714x 0xe618c3f1	ad714x_remove
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x4c0684e2	cma3000_init
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x892d76b2	cma3000_resume
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0x89d9444e	cma3000_exit
++EXPORT_SYMBOL drivers/input/misc/cma3000_d0x 0xca3f100a	cma3000_suspend
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x340de2ff	sparse_keymap_entry_from_scancode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x54a3f353	sparse_keymap_free
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x7656aa2d	sparse_keymap_report_event
++EXPORT_SYMBOL drivers/input/sparse-keymap 0x94ea2002	sparse_keymap_report_entry
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xaf9606c7	sparse_keymap_entry_from_keycode
++EXPORT_SYMBOL drivers/input/sparse-keymap 0xb8563cd1	sparse_keymap_setup
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x97f83edf	ad7879_remove
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0x9e6d23d8	ad7879_probe
++EXPORT_SYMBOL drivers/input/touchscreen/ad7879 0xabf14a04	ad7879_pm_ops
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x04403fcf	unregister_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x14f2aa5a	capi20_get_version
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b44125f	capi20_put_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2b8eab1f	capilib_free_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x2baa6586	capilib_new_ncci
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x31c24aa4	capi20_isinstalled
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x3b88cb65	capi_ctr_resume_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x47d3fc51	capi_info2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x50b33ca4	capi_cmsg2message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x6057c6f3	capi_message2cmsg
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x62e32d43	capilib_data_b3_conf
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7117224f	capi_ctr_down
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x71e8d5ba	capilib_data_b3_req
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7a33596c	capi20_get_serial
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x7e6f1307	capi20_get_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x87273dee	detach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x896bc063	capi_ctr_suspend_output
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8c2ee55f	attach_capi_ctr
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x8f699913	capilib_release
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0x9f823278	register_capi_driver
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xa7c4fd6c	capi_message2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xaa165d27	capilib_release_appl
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb19fda8d	capi_cmd2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xb60e5e5f	capi_cmsg_header
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xc10fe128	cdebbuf_free
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xdc265343	capi_ctr_handle_message
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe19a11ac	capi20_get_profile
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xe8ad9bd1	capi_cmsg2str
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed061606	capi20_manufacturer
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xed11060e	capi_ctr_ready
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xedbdee40	capi20_register
++EXPORT_SYMBOL drivers/isdn/capi/kernelcapi 0xfd4b5dc7	capi20_release
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x0dfdc797	b1_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x1bde8f30	b1_load_t4file
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x20fc8a7b	b1ctl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x365a248c	avmcard_dma_free
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x46cfd021	b1_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x703816c6	b1_parse_version
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x7f119305	b1_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x85f09690	b1_irq_table
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x90612bd1	b1_alloc_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x9898eeb1	b1_getrevision
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0x98ccdb28	b1_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa0ea7e88	b1_loaded
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xa3c73f69	b1_free_card
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xc46825c6	avmcard_dma_alloc
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xdfd28376	b1_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf32154c3	b1_load_config
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xf96ab851	b1_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1 0xfa10fee4	b1_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x1ddc01a1	b1dma_register_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x61619c71	b1dmactl_proc_fops
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x623b6615	b1dma_load_firmware
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x6cec88a8	b1dma_reset_ctr
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x72b8103f	t1pci_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x73b90b00	b1pciv4_detect
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0x90fc5151	b1dma_send_message
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xc4a8c6b5	b1dma_release_appl
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xd6f9f1ea	b1dma_interrupt
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1dma 0xe1389a07	b1dma_reset
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0x29562993	b1pcmcia_delcard
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xaec3240e	b1pcmcia_addcard_m1
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xea620116	b1pcmcia_addcard_m2
++EXPORT_SYMBOL drivers/isdn/hardware/avm/b1pcmcia 0xf14bf8b1	b1pcmcia_addcard_b1
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x2974ead1	DIVA_DIDD_Read
++EXPORT_SYMBOL drivers/isdn/hardware/eicon/divadidd 0x7ab59853	proc_net_eicon
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0x2a6d6e10	mISDNipac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xd4bac534	mISDNisac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xde021712	mISDNipac_init
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNipac 0xe2f1a818	mISDNisac_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0x8ede4abe	mISDNisar_irq
++EXPORT_SYMBOL drivers/isdn/hardware/mISDN/mISDNisar 0xfbdd7c46	mISDNisar_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x07f4f2ce	hisax_unregister
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x148f0c99	FsmFree
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x41e5fa97	hisax_init_pcmcia
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x7f29ce36	FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x93a64734	FsmChangeState
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0x9df0cd27	FsmEvent
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xe227344e	FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xee93522c	hisax_register
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xf0a16657	FsmNew
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xfc27303b	HiSax_closecard
++EXPORT_SYMBOL drivers/isdn/hisax/hisax 0xff2db2cf	FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x005e2f0f	isacsx_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x2bdc51a7	isac_init
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x3f3b323a	isac_d_l2l1
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x523958be	isac_setup
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0x5cc3f3ca	isac_irq
++EXPORT_SYMBOL drivers/isdn/hisax/hisax_isac 0xc9bd7483	isacsx_irq
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0x24790eac	register_isdn
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xc21034c0	isdn_ppp_unregister_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xde8dd539	isdn_ppp_register_compressor
++EXPORT_SYMBOL drivers/isdn/i4l/isdn 0xfa06820f	isdn_register_divert
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x3b71e4fc	isdnhdlc_decode
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x59cc8a7e	isdnhdlc_out_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0x8ee38862	isdnhdlc_rcv_init
++EXPORT_SYMBOL drivers/isdn/i4l/isdnhdlc 0xfd9d4c09	isdnhdlc_encode
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x0598fc19	mISDNDevName4ch
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x1c89bc32	mISDN_initbchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2348cc3c	mISDN_FsmFree
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2e65ac7b	recv_Bchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x2f11a76c	mISDN_ctrl_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x3aab50a5	recv_Echannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x402b9553	recv_Dchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x4efdf3ca	bchannel_get_rxbuf
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x50c2230c	mISDN_FsmChangeState
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x54451388	mISDN_FsmRestartTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x588886a6	l1_event
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x589af3d8	get_next_dframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5c172728	mISDN_register_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x5e8f7624	create_l1
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x614ede30	mISDN_FsmAddTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x647dcd77	dchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x6f1734eb	mISDN_unregister_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x79f3c32e	mISDN_freedchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8466f214	recv_Dchannel_skb
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x86a5f85c	mISDN_freebchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x873ce598	get_next_bframe
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x89203628	mISDN_unregister_device
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x8a4e99fb	mISDN_clock_update
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0x96309324	mISDN_FsmDelTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xab0c627a	bchannel_senddata
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xc3401729	mISDN_register_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xca56e0fc	mISDN_clear_bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd285995f	mISDN_clock_get
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd5145151	mISDN_FsmEvent
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xd6cf2fc9	mISDN_register_Bprotocol
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe71a7819	recv_Bchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe87943cf	mISDN_FsmInitTimer
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xe8f617eb	mISDN_unregister_clock
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xebb014f9	mISDN_initdchannel
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf157c81c	queue_ch_frame
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_core 0xf9e7832f	mISDN_FsmNew
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x01087af0	mISDN_dsp_element_unregister
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0x60721da7	dsp_audio_law_to_s32
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xa215f1b2	dsp_audio_s16_to_law
++EXPORT_SYMBOL drivers/isdn/mISDN/mISDN_dsp 0xb98308d8	mISDN_dsp_element_register
++EXPORT_SYMBOL drivers/md/dm-log 0xa7000aef	dm_dirty_log_destroy
++EXPORT_SYMBOL drivers/md/dm-log 0xb434de7f	dm_dirty_log_type_unregister
++EXPORT_SYMBOL drivers/md/dm-log 0xd4297723	dm_dirty_log_create
++EXPORT_SYMBOL drivers/md/dm-log 0xdab7a31d	dm_dirty_log_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x01285316	dm_snap_cow
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x41f4aca0	dm_exception_store_type_register
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x5c47cb0d	dm_exception_store_type_unregister
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x6cce84ca	dm_exception_store_create
++EXPORT_SYMBOL drivers/md/dm-snapshot 0x95d4625a	dm_exception_store_destroy
++EXPORT_SYMBOL drivers/md/dm-snapshot 0xbd89b3a0	dm_snap_origin
++EXPORT_SYMBOL drivers/md/raid456 0x3674a459	raid5_set_cache_size
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x188773cf	flexcop_pid_feed_control
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x3bc84c46	flexcop_pass_dmx_data
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x4ad92d49	flexcop_device_initialize
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x58631b5c	flexcop_eeprom_check_mac_addr
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x67ddbc6e	flexcop_pass_dmx_packets
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x70328807	flexcop_device_exit
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x70aa4f7c	flexcop_sram_set_dest
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x7655f84d	flexcop_dump_reg
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0x8298d821	flexcop_device_kfree
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xb1ef4a8b	flexcop_i2c_request
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xc49fc60a	flexcop_device_kmalloc
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xd31b6cea	flexcop_sram_ctrl
++EXPORT_SYMBOL drivers/media/common/b2c2/b2c2-flexcop 0xfdd393ad	flexcop_wan_set_speed
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0x495e4b0c	btcx_calc_skips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xad2fe38b	btcx_sort_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xb5cb40c7	btcx_riscmem_alloc
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xc368f8e6	btcx_align
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xcda0ded2	btcx_screen_clips
++EXPORT_SYMBOL drivers/media/common/btcx-risc 0xf4169365	btcx_riscmem_free
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x0be33e13	cx2341x_handler_init
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x1ca0c084	cx2341x_log_status
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x2f25eee2	cx2341x_update
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x3db8be82	cx2341x_ctrl_query
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x5b88faf6	cx2341x_ext_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x6d6ee253	cx2341x_handler_set_50hz
++EXPORT_SYMBOL drivers/media/common/cx2341x 0x9c0c1bfe	cx2341x_handler_setup
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xc184ec1e	cx2341x_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf76ce95	cx2341x_fill_defaults
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xcf8b77a4	cx2341x_mpeg_ctrls
++EXPORT_SYMBOL drivers/media/common/cx2341x 0xd4b421cc	cx2341x_handler_set_busy
++EXPORT_SYMBOL drivers/media/common/cypress_firmware 0x6876d804	cypress_load_firmware
++EXPORT_SYMBOL drivers/media/common/tveeprom 0x3713776d	tveeprom_read
++EXPORT_SYMBOL drivers/media/common/tveeprom 0xfbe56309	tveeprom_hauppauge_analog
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x101a29b8	dvb_ringbuffer_flush_spinlock_wakeup
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x17523ce7	dvb_frontend_sleep_until
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x196f1ac1	dvb_ringbuffer_flush
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x1e9d266e	dvb_generic_ioctl
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x202e0df4	dvb_ca_en50221_frda_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x237f7910	dvb_ringbuffer_free
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x2ae3a7fd	dvb_generic_open
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x300f2abb	dvb_ringbuffer_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x31264da0	dvb_frontend_resume
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x3db304cb	dvb_frontend_detach
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x409e4cc6	dvb_ca_en50221_camready_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x4c70c35a	dvb_ringbuffer_write
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5234b54b	dvb_ca_en50221_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x5c793f9d	dvb_dmx_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x69f061e5	dvb_dmx_swfilter_packets
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6f694382	dvb_dmx_swfilter_raw
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x6fa02a44	dvb_dmx_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x709b9812	dvb_dmx_swfilter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x74a5a698	dvb_filter_pes2ts_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x79fee19f	dvb_register_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x80e3832d	dvb_filter_get_ac3info
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x82c003c9	dvb_register_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x907fd119	dvb_ca_en50221_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x981587c4	dvb_dmx_swfilter_204
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x983b6441	dvb_unregister_device
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x987dcfde	dvb_ringbuffer_avail
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0x9b260973	dvb_dmxdev_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xac4ca1b0	intlog2
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb44d5b67	dvb_net_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xb72b5fa0	dvb_ringbuffer_empty
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbb41204f	dvb_unregister_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbc80d75b	dvb_generic_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xbfec9806	dvb_frontend_suspend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xc891d395	dvb_ca_en50221_camchange_irq
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xcb57468e	dvb_dmxdev_release
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd3ee7530	dvb_ringbuffer_read
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd546d017	dvb_net_init
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xd68a099e	timeval_usec_diff
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xdd219e29	dvb_unregister_frontend
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe19df994	dvb_frontend_reinitialise
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xe5ae8707	intlog10
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xf826deb0	dvb_filter_pes2ts
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfca5e7d8	dvb_register_adapter
++EXPORT_SYMBOL drivers/media/dvb-core/dvb-core 0xfcc0ed9c	dvb_ringbuffer_read_user
++EXPORT_SYMBOL drivers/media/dvb-frontends/a8293 0x03a1bce5	a8293_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9013 0x177cad60	af9013_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/af9033 0x762d3ab7	af9033_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/atbm8830 0xd45221fd	atbm8830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x4a11cf94	au8522_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x547f21ad	au8522_init
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x64fa04b8	au8522_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0x835a114b	au8522_readreg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xb4a4a77e	au8522_analog_i2c_gate_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xbdca2f93	au8522_writereg
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xda72a655	au8522_led_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xe6945c3d	au8522_get_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_common 0xf777c2a0	au8522_release_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/au8522_dig 0xba5f6e92	au8522_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/bcm3510 0xa85bcc9d	bcm3510_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22700 0xfdbcfe13	cx22700_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx22702 0x41383f4a	cx22702_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24110 0xb9c443fd	cx24110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x11ac120c	cx24113_agc_callback
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24113 0x230ad09f	cx24113_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24116 0x75b16002	cx24116_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x0d4b004b	cx24123_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/cx24123 0x46bc0fde	cx24123_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/cxd2820r 0xd484e7ff	cxd2820r_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x2721bbd7	dib0070_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0x3d663282	dib0070_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xa4493a4b	dib0070_ctrl_agc_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xea719445	dib0070_get_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0070 0xeb8290b4	dib0070_set_rf_output
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x0be31233	dib0090_get_wbd_target
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x1cb87720	dib0090_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x1d650f55	dib0090_pwm_gain_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x3e5a8f32	dib0090_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5ba55c2b	dib0090_set_dc_servo
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x5f1fe410	dib0090_dcc_freq
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0x6b237d5c	dib0090_gain_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xa7afda94	dib0090_update_tuning_table_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xaf0a9d8c	dib0090_update_rframp_7090
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd3cda639	dib0090_set_switch
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xd8e11289	dib0090_get_wbd_offset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xedcc2dbd	dib0090_get_current_gain
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf2a63579	dib0090_set_vga
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf5182734	dib0090_fw_register
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib0090 0xf992ada1	dib0090_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mb 0x835e078e	dib3000mb_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x0a9c80fd	dib3000mc_pid_control
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x3f0c72b7	dib3000mc_pid_parse
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x48b039cf	dib3000mc_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x72ca3fee	dib3000mc_get_tuner_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0x9768eda5	dib3000mc_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib3000mc 0xa424a145	dib3000mc_set_config
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x056712fc	dib7000m_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0x3a1ba0ca	dib7000m_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xafaff95a	dib7000m_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000m 0xafff7273	dib7000m_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x0ea61d46	dib7000p_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3d5b1f77	dib7000p_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x3f2043ac	dib7000p_set_agc1_min
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x514ec26a	dib7000p_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x522810af	dib7090_slave_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0x8cb76e4d	dib7000pc_detection
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xac7754e9	dib7000p_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xb18d7aea	dib7090_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xbab14f01	dib7000p_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xbe2ff33d	dib7090_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xbf1fce3f	dib7000p_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xc6cf0055	dib7000p_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xcff951fe	dib7000p_get_agc_values
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xe3898678	dib7000p_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xe8784cbd	dib7000p_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib7000p 0xfb97eb18	dib7090_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x08302058	dib8096p_get_i2c_tuner
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x0de17846	dib8000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x142c3f97	dib8000_get_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x17f2d1a4	dib8000_pid_filter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x37f32a51	dib8000_set_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x455ad8aa	dib8000_get_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x53bcae48	dib8000_update_pll
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x8f7a60d5	dib8000_ctrl_timf
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x958b1be3	dib8000_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0x9aee2610	dib8090p_get_dc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xa36bede7	dib8000_get_adc_power
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xb5fa7f5f	dib8000_set_tune_state
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xbbf763bb	dib8000_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xbe306ed0	dib8096p_tuner_sleep
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xc3c416d6	dib8000_i2c_enumeration
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xcad517b6	dib8000_pwm_agc_reset
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd57749b2	dib8000_set_wbd_ref
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd7b43634	dib8000_get_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dib8000 0xd9d7335b	dib8000_remove_slave_frontend
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x1abbbdb7	dibx000_i2c_set_speed
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x2229f199	dibx000_get_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0x3e6d6afb	dibx000_exit_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xad3ad91c	systime
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xc5ab77d0	dibx000_init_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/dibx000_common 0xccaf9e95	dibx000_reset_i2c_master
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0x97e03019	drxd_config_i2c
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxd 0xdec3788d	drxd_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/drxk 0xde100ce7	drxk_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ds3000 0xf0da774c	ds3000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/dvb-pll 0x94311a6b	dvb_pll_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ec100 0xe9bc0e92	ec100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6405 0x6688e5ae	isl6405_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6421 0x2d3062fb	isl6421_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/isl6423 0x999579de	isl6423_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/it913x-fe 0x88811dcd	it913x_fe_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/itd1000 0xf0ca0b36	itd1000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ix2505v 0x2f99c3b2	ix2505v_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/l64781 0x618ddd89	l64781_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lg2160 0xe0f7aaef	lg2160_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt3305 0xde40b12a	lgdt3305_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgdt330x 0x3b8a351c	lgdt330x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lgs8gxx 0x279602d3	lgs8gxx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x0ad8c656	lnbh24_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp21 0x8a0aba06	lnbp21_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/lnbp22 0x75dfb185	lnbp22_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/m88rs2000 0xab048afb	m88rs2000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a16 0x907b177b	mb86a16_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mb86a20s 0x5613e7da	mb86a20s_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt312 0x764ec667	mt312_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/mt352 0x3a500227	mt352_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt200x 0x7f85a4fa	nxt200x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/nxt6000 0xd3f5521a	nxt6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51132 0xfeff481d	or51132_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/or51211 0x9f0cdc8e	or51211_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xa33f8c96	rtl2830_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2830 0xbc5765d4	rtl2830_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/rtl2832 0xa4157c43	rtl2832_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1409 0x15e16d10	s5h1409_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1411 0x20edfbc8	s5h1411_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0x9efd09c9	s5h1420_get_tuner_i2c_adapter
++EXPORT_SYMBOL drivers/media/dvb-frontends/s5h1420 0xa59e0d87	s5h1420_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/s921 0x81b549af	s921_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/si21xx 0x2452ada4	si21xx_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp8870 0xb00f1b0b	sp8870_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/sp887x 0x2893e2d0	sp887x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb0899 0xfb46b2f7	stb0899_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6000 0xa588828e	stb6000_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stb6100 0x9b7004e1	stb6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0288 0xed63f132	stv0288_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0297 0x23931e3b	stv0297_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0299 0xacf9e264	stv0299_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0x26144ea2	stv0367ter_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0367 0xfed76e9f	stv0367cab_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv0900 0x40b6c396	stv0900_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0x06bae93b	stv090x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv090x 0xfd1ffc61	stv090x_set_gpio
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110 0x338e2c93	stv6110_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/stv6110x 0x42f73078	stv6110x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10021 0xc24aa3df	tda10021_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10023 0x0a1bad8c	tda10023_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10048 0xc1e61c02	tda10048_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0x6530cc12	tda10046_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda1004x 0xb55c5f06	tda10045_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10071 0x2f6f6c26	tda10071_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda10086 0x37a851d2	tda10086_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda665x 0x24b71a8c	tda665x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8083 0xfca6c92e	tda8083_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda8261 0x25d64ec7	tda8261_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tda826x 0x9b5b0a04	tda826x_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ts2020 0xba705579	ts2020_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/tua6100 0x3f9909c3	tua6100_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1820 0x902fd4c0	ves1820_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/ves1x93 0x7cf4839d	ves1x93_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10036 0x55e75823	zl10036_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10039 0xd3228935	zl10039_attach
++EXPORT_SYMBOL drivers/media/dvb-frontends/zl10353 0xeae86cf9	zl10353_attach
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x4278c43a	flexcop_dma_config
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x52cc3134	flexcop_dma_xfer_control
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x6ea4a282	flexcop_dma_control_timer_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0x77967220	flexcop_dma_allocate
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xa54bb55f	flexcop_dma_config_timer
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xd79775be	flexcop_dma_control_size_irq
++EXPORT_SYMBOL drivers/media/pci/b2c2/b2c2-flexcop-pci 0xe80022ba	flexcop_dma_free
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0x26920afa	bt878_device_control
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xb816f28e	bt878_stop
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xc0c888a9	bt878
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xce74bf45	bt878_start
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bt878 0xd5d0bdef	bt878_num
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x0256537c	bttv_sub_register
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x0a31ce18	bttv_get_pcidev
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x11dc4b6d	bttv_gpio_enable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0x8ecf4acc	bttv_write_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xaea43d54	bttv_sub_unregister
++EXPORT_SYMBOL drivers/media/pci/bt8xx/bttv 0xbcf2d2fb	bttv_read_gpio
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x141fa5a1	read_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x2b58493a	write_dst
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x2d16891e	dst_pio_disable
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x493fa27d	dst_error_bailout
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0x592c700f	dst_error_recovery
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe0a3911c	dst_attach
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe14114e9	rdc_reset_state
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe28fa10c	dst_comm_init
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xe94b8c9c	dst_check_sum
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst 0xfda007a9	dst_wait_dst_ready
++EXPORT_SYMBOL drivers/media/pci/bt8xx/dst_ca 0x8ac66eec	dst_ca_attach
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x03722ace	cx18_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x08d20e77	cx18_ext_init
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x2cdea06d	cx18_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x56fd7957	cx18_release_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x7a18dfdf	cx18_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/cx18/cx18 0x9c51685e	cx18_claim_stream
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x179c1ac4	altera_pid_feed_control
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x6ff7510d	altera_ci_tuner_reset
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0x9247b72f	altera_hw_filt_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xad3d99f7	altera_hw_filt_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xd865ae6e	altera_ci_init
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xdb3faf38	altera_ci_release
++EXPORT_SYMBOL drivers/media/pci/cx23885/altera-ci 0xe66b9812	altera_ci_irq
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x3661ac7a	cx25821_dev_unregister
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6965f2c2	cx25821_sram_channel_dump_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x6b81d2cd	cx25821_dev_get
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x721b741d	cx25821_risc_databuffer_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0x784853c3	cx25821_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xb1cf474a	cx25821_sram_channel_setup_audio
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc4a22091	cx25821_set_gpiopin_direction
++EXPORT_SYMBOL drivers/media/pci/cx25821/cx25821 0xc5d38741	cx25821_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x31a50986	vp3054_i2c_probe
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88-vp3054-i2c 0x8e74fff7	vp3054_i2c_remove
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x007764bf	cx88_enum_input
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x22a9be73	cx88_querycap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x38ef5bb7	cx88_set_freq
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8800 0x8c00f737	cx88_video_mux
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x38e3c050	cx8802_cancel_buffers
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x41f16aed	cx8802_buf_queue
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0x5a7c4e4e	cx8802_get_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xd3a8e724	cx8802_unregister_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xde3d6452	cx8802_buf_prepare
++EXPORT_SYMBOL drivers/media/pci/cx88/cx8802 0xf9c1045a	cx8802_register_driver
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x11b3c1d0	cx88_ir_start
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x23ba97ba	cx88_newstation
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x34667cbb	cx88_free_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3ee458e8	cx88_wakeup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x3eea1e26	cx88_get_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4216fc84	cx88_sram_channels
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x4df677d1	cx88_set_tvaudio
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x6141c8c5	cx88_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x634b5a0b	cx88_set_tvnorm
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x662da8ba	cx88_risc_buffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x698d6ced	cx88_set_stereo
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x7642ed3c	cx88_print_irqbits
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x77b427cd	cx88_reset
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x785cdace	cx88_ir_stop
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x801b5957	cx88_risc_stopper
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x89455fe5	cx88_core_get
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x8c914c88	cx88_vdev_init
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x904b8696	cx88_audio_thread
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0x964b457b	cx88_set_scale
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xa68f02e5	cx88_core_put
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xaeacbea8	cx88_sram_channel_dump
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xb14e2c40	cx88_dsp_detect_stereo_sap
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe042f19e	cx88_sram_channel_setup
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xe5097599	cx88_shutdown
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf76d62a3	cx88_risc_databuffer
++EXPORT_SYMBOL drivers/media/pci/cx88/cx88xx 0xf7998467	cx88_core_irq
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x00b9a546	ivtv_udma_prepare
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x0e523d9f	ivtv_set_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x14f67530	ivtv_debug
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x1c90dd6a	ivtv_init_on_first_open
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2299948c	ivtv_claim_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2799304f	ivtv_stop_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x2d50db7c	ivtv_udma_setup
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x30677b12	ivtv_release_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x344a2486	ivtv_reset_ir_gpio
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x43c479f5	ivtv_firmware_check
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x5676fa9d	ivtv_ext_init
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x63f7360a	ivtv_udma_alloc
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x7079e55d	ivtv_vapi_result
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x72c1d334	ivtv_start_v4l2_encode_stream
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x83cfd2fc	ivtv_vapi
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x88810f90	ivtv_clear_irq_mask
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0x90dfe7e5	ivtv_udma_unmap
++EXPORT_SYMBOL drivers/media/pci/ivtv/ivtv 0xace32fee	ivtv_api
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x00b3530e	saa7134_dmasound_init
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x04e83446	saa7134_tuner_callback
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x1211df5d	saa7134_devlist
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x20a4c29a	saa7134_dmasound_exit
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x21a62b09	saa7134_set_dmabits
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x427fb0e4	saa7134_pgtable_build
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x56e9fc05	saa7134_ts_register
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x5d05da50	saa7134_ts_unregister
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x73039031	saa7134_boards
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x78875e5e	saa7134_devlist_lock
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0x889d2f50	saa_dsp_writel
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xbb2316bd	saa7134_tvaudio_setmute
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xc3f13dd7	saa7134_set_gpio
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xdf32c337	saa7134_pgtable_free
++EXPORT_SYMBOL drivers/media/pci/saa7134/saa7134 0xf31fdebb	saa7134_pgtable_alloc
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xc3e4c127	ttpci_eeprom_decode_mac
++EXPORT_SYMBOL drivers/media/pci/ttpci/ttpci-eeprom 0xfcc861f3	ttpci_eeprom_parse_mac
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x22696884	videocodec_detach
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x33c7cac7	videocodec_unregister
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x54ed4b61	videocodec_register
++EXPORT_SYMBOL drivers/media/pci/zoran/videocodec 0x77357882	videocodec_attach
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x3b0435d8	soc_camera_unlock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x48d1fc38	soc_camera_lock
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x5ae75e3b	soc_camera_xlate_by_fourcc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x6397a2a8	soc_camera_host_unregister
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8cdb85f6	soc_camera_power_on
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0x8dd39d8f	soc_camera_power_init
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xd53d3d97	soc_camera_power_off
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xe2678d43	soc_camera_apply_board_flags
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_camera 0xf026a3ac	soc_camera_host_register
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x25c52d97	soc_mbus_samples_per_pixel
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x2863728e	soc_mbus_image_size
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x46b1be73	soc_mbus_find_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0x5f3e3558	soc_mbus_bytes_per_line
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xc8b28da5	soc_mbus_config_compatible
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_mediabus 0xd4d5a2f0	soc_mbus_get_fmtdesc
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x18d1e182	soc_camera_client_g_rect
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0x4cd4def7	soc_camera_client_scale
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xeeb1f937	soc_camera_client_s_crop
++EXPORT_SYMBOL drivers/media/platform/soc_camera/soc_scale_crop 0xefc1aeb8	soc_camera_calc_client_output
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x04dca738	lirc_unregister_driver
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x16ad8961	lirc_dev_fop_read
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x6639c037	lirc_dev_fop_write
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0x9c01429a	lirc_get_pdata
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xa3b588fa	lirc_dev_fop_open
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xac782409	lirc_dev_fop_poll
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xb4430c75	lirc_dev_fop_close
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xd98bbefa	lirc_dev_fop_ioctl
++EXPORT_SYMBOL drivers/media/rc/lirc_dev 0xf901b65d	lirc_register_driver
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xec7a336b	ir_raw_handler_unregister
++EXPORT_SYMBOL drivers/media/rc/rc-core 0xffc570ef	ir_raw_handler_register
++EXPORT_SYMBOL drivers/media/tuners/e4000 0xf6c503e7	e4000_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0011 0xfe88a5e0	fc0011_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0012 0xcd2d7501	fc0012_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x233b11c7	fc0013_rc_cal_reset
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x253c5df5	fc0013_attach
++EXPORT_SYMBOL drivers/media/tuners/fc0013 0x4c2fca78	fc0013_rc_cal_add
++EXPORT_SYMBOL drivers/media/tuners/fc2580 0x246a1a95	fc2580_attach
++EXPORT_SYMBOL drivers/media/tuners/max2165 0x9fb6a1f0	max2165_attach
++EXPORT_SYMBOL drivers/media/tuners/mc44s803 0x2a896a5d	mc44s803_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2060 0x6394770f	mt2060_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2131 0x48d71f4b	mt2131_attach
++EXPORT_SYMBOL drivers/media/tuners/mt2266 0xb4f7af0a	mt2266_attach
++EXPORT_SYMBOL drivers/media/tuners/mxl5005s 0x2d752bf4	mxl5005s_attach
++EXPORT_SYMBOL drivers/media/tuners/qt1010 0x59188c9c	qt1010_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18212 0xf70fa1fe	tda18212_attach
++EXPORT_SYMBOL drivers/media/tuners/tda18218 0x95900d8f	tda18218_attach
++EXPORT_SYMBOL drivers/media/tuners/tua9001 0x13ea3e2d	tua9001_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0x0cb4b189	tuners
++EXPORT_SYMBOL drivers/media/tuners/tuner-types 0xc2821775	tuner_count
++EXPORT_SYMBOL drivers/media/tuners/tuner-xc2028 0x0089fb96	xc2028_attach
++EXPORT_SYMBOL drivers/media/tuners/tuner_it913x 0xf0ae10b9	it913x_attach
++EXPORT_SYMBOL drivers/media/tuners/xc4000 0xdaeabc56	xc4000_attach
++EXPORT_SYMBOL drivers/media/tuners/xc5000 0x1b6ca9c9	xc5000_attach
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xaef4acbb	cx231xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/cx231xx/cx231xx 0xce31eb34	cx231xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x1d2d2369	dvb_usbv2_probe
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x27d30115	dvb_usbv2_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x42791c02	dvb_usbv2_disconnect
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x834fc8da	dvb_usbv2_generic_write_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x8f8a3451	dvb_usbv2_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0x93fc4435	dvb_usbv2_suspend
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xb130ed8c	dvb_usbv2_reset_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xc352ecde	dvb_usbv2_resume
++EXPORT_SYMBOL drivers/media/usb/dvb-usb-v2/dvb_usb_v2 0xea34e095	dvb_usbv2_generic_rw_locked
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x1fb7825e	dvb_usb_generic_write
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x22e7b287	dvb_usb_get_hexline
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x482b8258	usb_cypress_load_firmware
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x63d4cc5a	dvb_usb_nec_rc_key_to_event
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0x71890441	dvb_usb_device_exit
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xc7224927	dvb_usb_generic_rw
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb 0xe6ec351c	dvb_usb_device_init
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x019a1e67	af9005_rc_decode
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0x13e247e0	rc_map_af9005_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-af9005-remote 0xd4e288db	rc_map_af9005_table_size
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0134f249	dibusb_i2c_algo
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x0e89b3e4	dibusb2_0_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x171f5312	dibusb_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x19f45eb8	dibusb_read_eeprom_byte
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x366e1514	dibusb_dib3000mc_tuner_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x37050d69	dibusb_pid_filter_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x5e1433d7	dibusb_pid_filter
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x75d94f3e	dibusb2_0_streaming_ctrl
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0x95594d0c	dibusb_dib3000mc_frontend_attach
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xa6ca822c	dibusb_rc_query
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xb47559e0	rc_map_dibusb_table
++EXPORT_SYMBOL drivers/media/usb/dvb-usb/dvb-usb-dibusb-common 0xfb91026d	dibusb_power_ctrl
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0x6e606f9e	em28xx_register_extension
++EXPORT_SYMBOL drivers/media/usb/em28xx/em28xx 0xbbd7e524	em28xx_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x0ba08dac	gspca_disconnect
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x204a5fb2	gspca_suspend
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x9670af2c	gspca_debug
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0x99d60c4c	gspca_resume
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb406634d	gspca_coarse_grained_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xb4b2b175	gspca_frame_add
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xcd488379	gspca_dev_probe
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xd9c6e05f	gspca_expo_autogain
++EXPORT_SYMBOL drivers/media/usb/gspca/gspca_main 0xe775c606	gspca_dev_probe2
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0x80b11b1d	tm6000_register_extension
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xd1b3239e	tm6000_init_digital_mode
++EXPORT_SYMBOL drivers/media/usb/tm6000/tm6000 0xf56fabca	tm6000_unregister_extension
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0x96edd5c5	ttusbdecfe_dvbt_attach
++EXPORT_SYMBOL drivers/media/usb/ttusb-dec/ttusbdecfe 0xbd2ad40f	ttusbdecfe_dvbs_attach
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x42c8e001	v4l2_ctrl_next
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x4adaf0f3	v4l2_ctrl_query_menu_valid_items
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x53c9394f	v4l2_ctrl_query_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0x5f96a661	v4l2_ctrl_check
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-common 0xabe27502	v4l2_ctrl_query_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x4205d5ce	v4l2_m2m_mmap
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x459e133f	v4l2_m2m_get_curr_priv
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0x804382aa	v4l2_m2m_job_finish
++EXPORT_SYMBOL drivers/media/v4l2-core/v4l2-mem2mem 0xbe4573af	v4l2_m2m_get_vq
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x0d716f33	videobuf_dvb_get_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x38b62f2e	videobuf_dvb_alloc_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x47d99fe8	videobuf_dvb_find_frontend
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0x55d64ce1	videobuf_dvb_unregister_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xa19959fa	videobuf_dvb_dealloc_frontends
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf-dvb 0xd418e055	videobuf_dvb_register_bus
++EXPORT_SYMBOL drivers/media/v4l2-core/videobuf2-core 0x16c5f089	vb2_querybuf
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x001eb96b	video_ioctl2
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x036a925f	v4l2_ctrl_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0614dd5a	v4l2_video_std_frame_period
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x061f0ed8	v4l2_clk_get_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x08c31379	v4l2_ctrl_new_std_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0dd2e2ee	v4l2_ctrl_find
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x0f5ecb7f	v4l2_ctrl_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x123959a1	v4l2_type_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x13e204a8	v4l2_subdev_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x16244fe5	v4l2_prio_check
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x1b01502e	v4l2_ctrl_new_std
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2342f1ae	v4l2_prio_open
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x24b020c5	v4l2_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x28c8010c	v4l2_ctrl_sub_ev_ops
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x2bb9a3c4	v4l2_ctrl_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x36026779	v4l2_ctrl_radio_filter
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3adbd595	v4l2_field_names
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3bdd0f94	v4l2_prio_change
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x3c7da0b8	video_usercopy
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4322c115	v4l2_ctrl_subdev_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x43cec845	v4l2_ctrl_subdev_subscribe_event
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x47d02ab9	v4l2_async_unregister_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x492e85e6	v4l2_ctrl_add_handler
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x495426ee	v4l2_ctrl_get_name
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x49b57bb0	v4l2_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4aca217c	v4l2_async_register_subdev
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x4e70d15f	__video_register_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x523b0c7d	v4l2_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5374137a	video_devdata
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x53bd8c86	v4l2_subdev_try_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x544a305e	v4l2_ctrl_auto_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x59b5d7ca	v4l2_ctrl_new_std_menu_items
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x5e80472c	v4l2_async_notifier_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x633a3525	v4l2_ctrl_modify_range
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x6823fcff	v4l2_clk_unregister
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x689a955a	v4l2_subdev_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x68b097bf	v4l2_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x69ca8b1a	v4l2_clk_get
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7451905a	v4l2_subdev_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x796f0282	v4l2_ctrl_cluster
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7a3cd015	v4l2_ctrl_get_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7ae8cdb2	v4l2_g_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7b09459f	v4l2_ctrl_handler_free
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7b9fc66f	v4l2_clk_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7ce64ed5	v4l2_ctrl_poll
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x7d048cab	v4l2_ctrl_add_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8106095a	v4l2_prio_max
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8486d445	v4l2_clk_put
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8b27823c	v4l2_subdev_g_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8f018e17	video_device_alloc
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x8fb22d17	v4l2_ctrl_handler_log_status
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x900a3b87	v4l2_ctrl_s_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x91031dd6	v4l2_subdev_queryctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x94c482d8	v4l2_querymenu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9651e479	v4l2_ctrl_new_int_menu
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9855c778	v4l2_subdev_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x99f4fd92	v4l2_ctrl_handler_init_class
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0x9b699b79	video_device_release
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa1013a8a	v4l2_ctrl_new_custom
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa15493ca	v4l2_async_notifier_register
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa2737737	v4l2_ctrl_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xa429397a	v4l2_clk_disable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb31b66bb	v4l2_ctrl_grab
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb524c84f	v4l2_subdev_s_ext_ctrls
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xb77b0159	v4l2_prio_init
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbac4a225	v4l2_ctrl_fill
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbc5671dc	v4l_printk_ioctl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xbfbd0088	v4l2_ctrl_notify
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc12cf8f8	v4l2_ctrl_replace
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc2275e14	video_device_release_empty
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc6f98e4a	v4l2_ctrl_g_ctrl_int64
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xc6ff7978	v4l2_ctrl_handler_setup
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcba423a5	v4l2_s_ctrl
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xcda04a5b	v4l2_prio_close
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd12a7b2a	v4l2_clk_set_rate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xd398a103	v4l2_ctrl_activate
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe2b92059	v4l2_video_std_construct
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe581ec18	video_unregister_device
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xe6fce6f2	v4l2_ctrl_merge
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xef1574c2	v4l2_clk_enable
++EXPORT_SYMBOL drivers/media/v4l2-core/videodev 0xf3251e7b	v4l2_norm_to_name
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x0575e8a6	memstick_next_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x278ef046	memstick_set_rw_addr
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x3c690523	memstick_free_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x5d820a02	memstick_init_req_sg
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x6a2d5b71	memstick_detect_change
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x72296b60	memstick_remove_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x83ba0ffb	memstick_alloc_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0x9c904579	memstick_new_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa5987a36	memstick_init_req
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xa7031761	memstick_add_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xe6928d46	memstick_register_driver
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xed4c7044	memstick_suspend_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf24267d7	memstick_resume_host
++EXPORT_SYMBOL drivers/memstick/core/memstick 0xf25ed916	memstick_unregister_driver
++EXPORT_SYMBOL drivers/memstick/host/r592 0x52f1b23b	memstick_debug_get_tpc_name
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x077fd060	mpt_put_msg_frame_hi_pri
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x07bfc92e	mpt_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x0cf59fb5	mpt_free_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x10a1377d	mpt_config
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x11586bf8	mpt_raid_phys_disk_pg0
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x12b9224a	mpt_free_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1703fa13	mpt_raid_phys_disk_get_num_paths
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x1e79d4df	mpt_alloc_fw_memory
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x274339ec	mpt_halt_firmware
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2e6c84a6	mpt_send_handshake_request
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x2efa0770	mpt_event_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3c4d1db6	mptbase_sas_persist_operation
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x3fb894db	mpt_detach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x420b0814	mpt_verify_adapter
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4526289b	mpt_event_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x4e03de16	mpt_Soft_Hard_ResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x502108d0	mpt_fwfault_debug
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x537ac885	mpt_findImVolumes
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x57738845	mpt_device_driver_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x67d23705	mpt_raid_phys_disk_pg1
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8036ac81	mpt_HardResetHandler
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x89bba015	mpt_get_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x8a5fd46c	mpt_clear_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x90760f2e	mpt_attach
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x91ba0379	mpt_print_ioc_summary
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0x96343706	mpt_GetIocState
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xb346fefe	mpt_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc0e69f82	mpt_device_driver_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc47c22e8	mpt_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xc75b44ea	mpt_set_taskmgmt_in_progress_flag
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xcb7f385d	mpt_resume
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd8072610	mpt_reset_register
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xd9a92a75	mpt_reset_deregister
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xdd805159	ioc_list
++EXPORT_SYMBOL drivers/message/fusion/mptbase 0xf97f1362	mpt_put_msg_frame
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0059ffb5	mptscsih_abort
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x006974a1	mptscsih_slave_destroy
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x0f8a4764	mptscsih_flush_running_cmds
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x1ae6f469	mptscsih_remove
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x30ac208e	mptscsih_IssueTaskMgmt
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4ef96693	mptscsih_suspend
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x4f690877	mptscsih_get_scsi_lookup
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x5988f8cf	mptscsih_show_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x67d6339a	mptscsih_ioc_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6a1e8409	mptscsih_info
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x6eff6eb1	mptscsih_io_done
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x7353a313	mptscsih_change_queue_depth
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x873a12bf	mptscsih_host_attrs
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8c4df683	mptscsih_is_phys_disk
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8cbb39c1	mptscsih_host_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x8eee059d	mptscsih_dev_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x945d25ca	mptscsih_resume
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0x9fc09689	mptscsih_slave_configure
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xb32ae83e	mptscsih_scandv_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbafbf63a	mptscsih_qcmd
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xbe4b9d23	mptscsih_raid_id_to_num
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xcbe90aea	mptscsih_taskmgmt_response_code
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd3752b4f	mptscsih_bus_reset
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xd6d22438	mptscsih_event_process
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xdfe5a41a	mptscsih_taskmgmt_complete
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xe5b6f6e6	mptscsih_bios_param
++EXPORT_SYMBOL drivers/message/fusion/mptscsih 0xf8818989	mptscsih_shutdown
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x150c49e5	i2o_driver_notify_device_remove_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2a843bef	i2o_dump_message
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x2cb988cc	i2o_parm_issue
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x34b62b7b	i2o_find_iop
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x37a58bbd	i2o_device_claim
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x6ae03be6	i2o_msg_get_wait
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0x922a5be6	i2o_exec_lct_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xa27cabda	i2o_event_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xa32fbad1	i2o_driver_unregister
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xaa1cf738	i2o_driver_register
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb4c00dcf	i2o_controllers
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xb6137e52	i2o_driver_notify_device_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xd465fed7	i2o_driver_notify_controller_remove_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xd4957c1f	i2o_parm_field_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xd631d053	i2o_driver_notify_controller_add_all
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xdd842efe	i2o_status_get
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xe066beb4	i2o_msg_post_wait_mem
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xe0b7bffa	i2o_device_claim_release
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xeef343b2	i2o_iop_find_device
++EXPORT_SYMBOL drivers/message/i2o/i2o_core 0xef5514ca	i2o_parm_table_get
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x2aa2b4da	cros_ec_remove
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x2bce5145	cros_ec_suspend
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x34677be9	cros_ec_prepare_tx
++EXPORT_SYMBOL drivers/mfd/cros_ec 0x3544957f	cros_ec_register
++EXPORT_SYMBOL drivers/mfd/cros_ec 0xf9163c81	cros_ec_resume
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0x38d8493e	pasic3_write_register
++EXPORT_SYMBOL drivers/mfd/htc-pasic3 0xdc4a7cb3	pasic3_read_register
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x029d0bc6	mc13xxx_reg_rmw
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x44b2d84b	mc13xxx_irq_request
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x748d9e57	mc13xxx_irq_mask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7af6d008	mc13xxx_reg_read
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x7bc887c3	mc13xxx_get_flags
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x80c01eda	mc13xxx_unlock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x95b7adde	mc13xxx_reg_write
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9c1f1e15	mc13xxx_irq_unmask
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0x9d9dfa29	mc13xxx_irq_free
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xb91397fa	mc13xxx_irq_status
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xdc5f042e	mc13xxx_irq_ack
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xe3d0981f	mc13xxx_lock
++EXPORT_SYMBOL drivers/mfd/mc13xxx-core 0xfdfcfdc3	mc13xxx_irq_request_nounmask
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x32700120	tps6105x_get
++EXPORT_SYMBOL drivers/mfd/tps6105x 0x72db4599	tps6105x_set
++EXPORT_SYMBOL drivers/mfd/tps6105x 0xd0153856	tps6105x_mask_and_set
++EXPORT_SYMBOL drivers/mfd/tps65010 0x02d4ad0f	tps65013_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0x0c6ad2cf	tps65010_config_vdcdc2
++EXPORT_SYMBOL drivers/mfd/tps65010 0x28485130	tps65010_config_vregs1
++EXPORT_SYMBOL drivers/mfd/tps65010 0x33739de7	tps65010_set_vib
++EXPORT_SYMBOL drivers/mfd/tps65010 0x9fd44c69	tps65010_set_led
++EXPORT_SYMBOL drivers/mfd/tps65010 0xb14080cc	tps65010_set_low_pwr
++EXPORT_SYMBOL drivers/mfd/tps65010 0xd5bb106d	tps65010_set_vbus_draw
++EXPORT_SYMBOL drivers/mfd/tps65010 0xe99b3f36	tps65010_set_gpio_out_value
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0x3d749dcb	ad_dpot_probe
++EXPORT_SYMBOL drivers/misc/ad525x_dpot 0xbf8148b3	ad_dpot_remove
++EXPORT_SYMBOL drivers/misc/altera-stapl/altera-stapl 0x8a05ed90	altera_init
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x45d1af93	ssc_request
++EXPORT_SYMBOL drivers/misc/atmel-ssc 0x5f9c21f6	ssc_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x0e9755b9	pwm_channel_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5a8b82f9	pwm_channel_handler
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x5d5c2951	pwm_clk_free
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x6a5e1f70	pwm_channel_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0x73330c97	pwm_clk_alloc
++EXPORT_SYMBOL drivers/misc/atmel_pwm 0xeb7f2c6f	__pwm_channel_onoff
++EXPORT_SYMBOL drivers/misc/c2port/core 0x3b575bd2	c2port_device_unregister
++EXPORT_SYMBOL drivers/misc/c2port/core 0x4fa72b12	c2port_device_register
++EXPORT_SYMBOL drivers/misc/ioc4 0x57369076	ioc4_unregister_submodule
++EXPORT_SYMBOL drivers/misc/ioc4 0xa906137f	ioc4_register_submodule
++EXPORT_SYMBOL drivers/misc/tifm_core 0x39f86aa1	tifm_queue_work
++EXPORT_SYMBOL drivers/misc/tifm_core 0x5c107fad	tifm_free_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x63fdc68a	tifm_eject
++EXPORT_SYMBOL drivers/misc/tifm_core 0x66eb57b8	tifm_unregister_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0x69338814	tifm_remove_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x6cac7c7e	tifm_alloc_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0x81fb5fd6	tifm_add_adapter
++EXPORT_SYMBOL drivers/misc/tifm_core 0xb1a07f5a	tifm_free_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xbbd69e9d	tifm_alloc_device
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc2dbcad2	tifm_has_ms_pif
++EXPORT_SYMBOL drivers/misc/tifm_core 0xc52f2edb	tifm_unmap_sg
++EXPORT_SYMBOL drivers/misc/tifm_core 0xe5168611	tifm_register_driver
++EXPORT_SYMBOL drivers/misc/tifm_core 0xf64fd292	tifm_map_sg
++EXPORT_SYMBOL drivers/mmc/card/mmc_block 0x77b48e66	mmc_cleanup_queue
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0x7f82c246	cfi_fixup
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xb01aa626	cfi_read_pri
++EXPORT_SYMBOL drivers/mtd/chips/cfi_util 0xddaeb965	cfi_varsize_frob
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x335e6cd6	map_destroy
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0x9ca49d00	do_map_probe
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xdf86723c	register_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/chipreg 0xeb5f1b85	unregister_mtd_chip_driver
++EXPORT_SYMBOL drivers/mtd/chips/gen_probe 0xfab56d41	mtd_do_chip_probe
++EXPORT_SYMBOL drivers/mtd/lpddr/lpddr_cmds 0x14e6fd98	lpddr_cmdset
++EXPORT_SYMBOL drivers/mtd/maps/map_funcs 0xa6f15a7b	simple_map_init
++EXPORT_SYMBOL drivers/mtd/mtd 0x0af8dddc	mtd_concat_create
++EXPORT_SYMBOL drivers/mtd/mtd 0xe146d4e0	mtd_concat_destroy
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x03d7c929	denali_init
++EXPORT_SYMBOL drivers/mtd/nand/denali 0x0fa55bc3	denali_remove
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x195f8202	nand_scan
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x49e6c95a	nand_scan_ident
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x6630123d	nand_lock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0x679a052f	nand_unlock
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xc34e533c	nand_scan_tail
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xca28791f	nand_scan_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand 0xcb5778c2	nand_default_bbt
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x082981c7	nand_bch_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x448e5cba	nand_bch_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x70097aa0	nand_bch_free
++EXPORT_SYMBOL drivers/mtd/nand/nand_bch 0x88dd46e5	nand_bch_init
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x299b73cd	nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x3132ee65	__nand_calculate_ecc
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0x993364e3	nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ecc 0xb4b94377	__nand_correct_data
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0x224c011d	nand_flash_ids
++EXPORT_SYMBOL drivers/mtd/nand/nand_ids 0xa336feb7	nand_manuf_ids
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x1c754ef5	onenand_addr
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0x26176412	onenand_default_bbt
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xc2377201	flexonenand_region
++EXPORT_SYMBOL drivers/mtd/onenand/onenand 0xe0df5885	onenand_scan_bbt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x181dd64a	arcnet_timeout
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x1d71ce11	alloc_arcdev
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x247a6e66	arc_proto_default
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x28cbc729	arc_raw_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x5fb6e05c	arcnet_open
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6534792a	arcnet_debug
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x688eedde	arcnet_unregister_proto
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x6c6e4b57	arcnet_close
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0x9d9a371a	arc_proto_map
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xa96472cf	arcnet_send_packet
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xecb730b0	arcnet_interrupt
++EXPORT_SYMBOL drivers/net/arcnet/arcnet 0xffc0e46d	arc_bcast_proto
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x0ad6635a	com20020_check
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0x5d5a2ebe	com20020_found
++EXPORT_SYMBOL drivers/net/arcnet/com20020 0xed3a4618	com20020_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x09eb16d5	__alloc_ei_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x119721ac	ei_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x2b41a579	ei_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x3cb345fb	ei_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x704ba860	ei_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x747b427e	ei_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x8f49ce60	ei_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0x9256fd25	NS8390_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xabe0ff13	ei_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xd9188711	ei_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390 0xe3b77fa3	ei_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x12192494	eip_open
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x16ffd346	eip_tx_timeout
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x35ff3c6e	__alloc_eip_netdev
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x41888bed	eip_get_stats
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x6734ad2b	eip_set_multicast_list
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x821ebec6	eip_netdev_ops
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x90d290fb	eip_close
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0x99c03fd7	eip_interrupt
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xe266be25	eip_poll
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xf27c7f26	NS8390p_init
++EXPORT_SYMBOL drivers/net/ethernet/8390/8390p 0xf55df78c	eip_start_xmit
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0x636af174	cnic_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/broadcom/cnic 0xebd1519d	cnic_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x0163c5d0	t3_l2e_free
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x06074bd0	dev2t3cdev
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x11f4a832	t3_l2t_send_slow
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x161899b7	cxgb3_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x219c1284	cxgb3_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x32fa635b	cxgb3_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x4e50186d	t3_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x55ee25b4	cxgb3_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0x660c7877	cxgb3_insert_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xc7ec9e81	cxgb3_queue_tid_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xdd778e35	t3_l2t_send_event
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xe74e39e2	cxgb3_unregister_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xea237de4	cxgb3_register_client
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf193a568	t3_register_cpl_handler
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf25e9229	cxgb3_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb3/cxgb3 0xf53106c1	cxgb3_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x05de4d48	cxgb4_create_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x0e3d478c	cxgb4_disable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1598074b	cxgb4_l2t_get
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x1781e51e	cxgb4_l2t_release
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x228dfe49	cxgb4_dbfifo_count
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x297519d9	cxgb4_port_viid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3f53755b	cxgb4_register_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x3fc554d7	cxgb4_alloc_atid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x43e167b9	cxgb4_pktgl_to_skb
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x49040f6f	cxgb4_enable_db_coalescing
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x4b937cb6	cxgb4_alloc_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x54e5c42d	cxgb4_ofld_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x6eed087f	cxgb4_l2t_send
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x799a59de	cxgb4_remove_server_filter
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0x919dcf33	cxgb4_remove_tid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa179a93e	cxgb4_port_chan
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa1a5b72e	cxgb4_port_idx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa400ed82	cxgb4_sync_txq_pidx
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xa629ef71	cxgb4_get_tcp_stats
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xb3dd5329	cxgb4_flush_eq_cache
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xba90f0dc	cxgb4_iscsi_init
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xcd848c58	cxgb4_alloc_sftid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd00e5a36	cxgb4_unregister_uld
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd4c4fd1f	cxgb4_free_stid
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd571bb9b	cxgb4_create_server
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xd69a0294	cxgb4_best_mtu
++EXPORT_SYMBOL drivers/net/ethernet/chelsio/cxgb4/cxgb4 0xf27b01e9	cxgb4_free_atid
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0x443b93c2	be_roce_register_driver
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xbab62e22	be_roce_mcc_cmd
++EXPORT_SYMBOL drivers/net/ethernet/emulex/benet/be2net 0xc652f8c9	be_roce_unregister_driver
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x0f403cab	mlx4_get_parav_qkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1742c829	mlx4_sync_pkey_table
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x188d76c7	mlx4_SET_MCAST_FLTR
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1bdb4a5a	mlx4_SET_PORT_general
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2810cf0a	mlx4_SET_PORT_PRIO2TC
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x35e09a6d	mlx4_get_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x57b61c81	mlx4_SET_PORT_SCHEDULER
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x62db1873	mlx4_assign_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6fe0693a	set_and_calc_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x770cc9f8	mlx4_set_stats_bitmap
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8dac0f64	mlx4_is_slave_active
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x907ec836	mlx4_put_slave_node_guid
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa07bfabe	mlx4_gen_guid_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa2461a03	mlx4_release_eq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa6f8f66b	mlx4_gen_slaves_port_mgt_ev
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb5629844	mlx4_get_slave_port_state
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc4dcec79	mlx4_SET_PORT_qpn_calc
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd3b64390	mlx4_get_slave_pkey_gid_tbl_len
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xda810858	mlx4_gen_port_state_change_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe1bd8f64	mlx4_test_interrupts
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf572226b	mlx4_gen_pkey_eqe
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x0ec440d3	mlx5_dev_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x1466a3bd	mlx5_core_query_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x15bc3f2f	mlx5_core_create_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x18f20d1d	mlx5_core_destroy_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3174df7c	mlx5_cmd_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x31d58957	mlx5_cmd_free_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x50d2550e	mlx5_debugfs_root
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x52414b7b	mlx5_core_arm_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5395fbe8	mlx5_dev_init
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x552cf3e6	mlx5_core_destroy_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5e87c6db	mlx5_core_get_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x65f72429	mlx5_cmd_comp_handler
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x79b0d524	mlx5_cmd_cleanup
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x83f335c2	mlx5_core_query_mkey
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x924ee7f1	mlx5_core_dealloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x96a8ca62	mlx5_core_alloc_pd
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb5e8e8f5	mlx5_cmd_exec
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb636d9f6	mlx5_core_attach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xc500688f	mlx5_core_create_srq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd08e48ca	mlx5_core_destroy_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd201024c	mlx5_core_detach_mcg
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd3c78f5a	mlx5_cmd_alloc_uar
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd8eb02ee	mlx5_core_create_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xf213b24a	mlx5_core_query_cq
++EXPORT_SYMBOL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xffaa08c0	mlx5_core_dump_fill_mkey
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x0206264e	hdlcdrv_transmitter
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x08e3f0b5	hdlcdrv_receiver
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x1944b9ed	hdlcdrv_register
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x46f1187c	hdlcdrv_arbitrate
++EXPORT_SYMBOL drivers/net/hamradio/hdlcdrv 0x863ae522	hdlcdrv_unregister
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x31f9ef1a	irda_register_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x36c5b7c0	irda_unregister_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x3ad446d2	sirdev_receive
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x86bdf0c4	sirdev_raw_write
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x8f97f912	sirdev_get_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0x90375b47	sirdev_set_dtr_rts
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xb5c888a0	sirdev_put_instance
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xc3c25130	sirdev_set_dongle
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xdb306b72	sirdev_write_complete
++EXPORT_SYMBOL drivers/net/irda/sir-dev 0xef9ed3b7	sirdev_raw_read
++EXPORT_SYMBOL drivers/net/mdio 0x22bce513	mdio_mii_ioctl
++EXPORT_SYMBOL drivers/net/mdio 0x43e4defc	mdio45_nway_restart
++EXPORT_SYMBOL drivers/net/mdio 0x7577f992	mdio_set_flag
++EXPORT_SYMBOL drivers/net/mdio 0xa1a29548	mdio45_probe
++EXPORT_SYMBOL drivers/net/mdio 0xb34a7575	mdio45_ethtool_spauseparam_an
++EXPORT_SYMBOL drivers/net/mdio 0xc6b1163f	mdio45_links_ok
++EXPORT_SYMBOL drivers/net/mdio 0xddc98749	mdio45_ethtool_gset_npage
++EXPORT_SYMBOL drivers/net/mii 0x3506f4c6	mii_check_link
++EXPORT_SYMBOL drivers/net/mii 0x4083087b	mii_nway_restart
++EXPORT_SYMBOL drivers/net/mii 0x5699e7f0	mii_ethtool_sset
++EXPORT_SYMBOL drivers/net/mii 0x5727b87a	mii_ethtool_gset
++EXPORT_SYMBOL drivers/net/mii 0xb145430c	generic_mii_ioctl
++EXPORT_SYMBOL drivers/net/mii 0xbf470963	mii_link_ok
++EXPORT_SYMBOL drivers/net/mii 0xc3818054	mii_check_media
++EXPORT_SYMBOL drivers/net/mii 0xc70a46f3	mii_check_gmii_support
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x30e77ca7	register_pppox_proto
++EXPORT_SYMBOL drivers/net/ppp/pppox 0x9eb3c67a	pppox_unbind_sock
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xd6d5ed91	pppox_ioctl
++EXPORT_SYMBOL drivers/net/ppp/pppox 0xe0ff7a18	unregister_pppox_proto
++EXPORT_SYMBOL drivers/net/sungem_phy 0xd98151f7	sungem_phy_probe
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x41563aff	usbnet_manage_power
++EXPORT_SYMBOL drivers/net/usb/usbnet 0x8b7b9b24	usbnet_device_suggests_idle
++EXPORT_SYMBOL drivers/net/usb/usbnet 0xc2f08fb0	usbnet_link_change
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x054729a6	hdlc_ioctl
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x06a90307	hdlc_start_xmit
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x56fb71ca	hdlc_open
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x6ec60fe6	hdlc_close
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x6f652b77	unregister_hdlc_device
++EXPORT_SYMBOL drivers/net/wan/hdlc 0x8e04a8d4	unregister_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xabf43c20	register_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xae4f683b	alloc_hdlcdev
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xc227caf0	attach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xe9253073	detach_hdlc_protocol
++EXPORT_SYMBOL drivers/net/wan/hdlc 0xf3899504	hdlc_change_mtu
++EXPORT_SYMBOL drivers/net/wan/z85230 0x10c78988	z8530_dead_port
++EXPORT_SYMBOL drivers/net/wan/z85230 0x353c4989	z8530_null_rx
++EXPORT_SYMBOL drivers/net/wan/z85230 0x3d930854	z8530_sync_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x40339dbb	z8530_describe
++EXPORT_SYMBOL drivers/net/wan/z85230 0x420ff829	z8530_sync_dma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x489aff6c	z8530_sync
++EXPORT_SYMBOL drivers/net/wan/z85230 0x5cd24d29	z8530_hdlc_kilostream
++EXPORT_SYMBOL drivers/net/wan/z85230 0x681de8ee	z8530_sync_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0x9a7f764b	z8530_sync_txdma_close
++EXPORT_SYMBOL drivers/net/wan/z85230 0x9ee02ea2	z8530_sync_dma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0xa6ef28d4	z8530_nop
++EXPORT_SYMBOL drivers/net/wan/z85230 0xa9ea5aba	z8530_queue_xmit
++EXPORT_SYMBOL drivers/net/wan/z85230 0xaa3617bc	z8530_channel_load
++EXPORT_SYMBOL drivers/net/wan/z85230 0xd4ffebf0	z8530_interrupt
++EXPORT_SYMBOL drivers/net/wan/z85230 0xe345960a	z8530_sync_txdma_open
++EXPORT_SYMBOL drivers/net/wan/z85230 0xe3d80064	z8530_hdlc_kilostream_85230
++EXPORT_SYMBOL drivers/net/wan/z85230 0xf809d854	z8530_init
++EXPORT_SYMBOL drivers/net/wan/z85230 0xfa320527	z8530_shutdown
++EXPORT_SYMBOL drivers/net/wimax/i2400m/i2400m 0x7011769d	i2400m_unknown_barker
++EXPORT_SYMBOL drivers/net/wireless/airo 0x2f2fc24d	reset_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0x88569b52	stop_airo_card
++EXPORT_SYMBOL drivers/net/wireless/airo 0xb627c03b	init_airo_card
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x2ab8b924	ath_rxbuf_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x319c6026	ath_is_49ghz_allowed
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x33dc83ea	ath_key_config
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x4e2481d5	ath_is_world_regd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x50d96603	ath_hw_setbssidmask
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x53358ce3	ath_regd_get_band_ctl
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x7ede9640	ath_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0x84157689	ath_key_delete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xa20867b1	ath_regd_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xbb43242c	ath_reg_notifier_apply
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xc41c10d7	ath_hw_keyreset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xfe79655d	ath_hw_get_listen_time
++EXPORT_SYMBOL drivers/net/wireless/ath/ath 0xffc57c4f	ath_hw_cycle_counters_update
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x0467528f	ath10k_core_unregister
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x1f9525ae	ath10k_core_target_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x23f220ef	ath10k_core_register
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x51a46ccd	ath10k_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x6a1b4333	ath10k_core_target_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x7f762de0	ath10k_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x8246be6c	ath10k_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0x895f9dc2	ath10k_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath10k/ath10k_core 0xaf096710	ath10k_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x0199ec46	ath6kl_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x27cf1694	ath6kl_warn
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2ac39497	ath6kl_stop_txrx
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x2faf02e6	ath6kl_core_rx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x444bed67	ath6kl_cfg80211_suspend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4c6ddcb4	ath6kl_err
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x4e1380ee	ath6kl_printk
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x5041ed24	ath6kl_hif_intr_bh_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x711e3994	ath6kl_core_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x726d0639	ath6kl_cfg80211_resume
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x7fc0f770	ath6kl_core_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0x91cfb84a	ath6kl_hif_rw_comp_handler
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xcb95074a	ath6kl_core_destroy
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xd5d54f07	ath6kl_core_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath6kl/ath6kl_core 0xdc15a8b7	ath6kl_core_create
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x5c6c6328	ath9k_hw_wow_wakeup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0x91fc76f5	ath9k_hw_wow_event_to_string
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0xe129fd37	ath9k_hw_wow_apply_pattern
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k 0xe6db8fa3	ath9k_hw_wow_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x190435a8	ath9k_cmn_update_txpow
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0x1d896766	ath9k_cmn_update_ichannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd25afef4	ath9k_cmn_get_hw_crypto_keytype
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xd2981357	ath9k_cmn_count_streams
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xe524fa85	ath9k_cmn_get_curchannel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_common 0xee49c8db	ath9k_cmn_init_crypto
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x008cadb9	ath9k_hw_gettsf32
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x04325837	ar9003_paprd_init_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x05e5769d	ath9k_hw_set_rx_bufsize
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0d68dbe8	ath9k_hw_set_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x0eb878ce	ath9k_hw_rxprocdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x11bdf302	ath9k_hw_setrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x13826683	ath9k_hw_gen_timer_start
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x140d1b40	ath9k_hw_beaconinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x184d268b	ath9k_hw_write_associd
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x19c7e6a0	ar9003_paprd_create_curve
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x21caac11	ath9k_hw_btcoex_bt_stomp
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x23d550ee	ath9k_hw_gettsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x23fa9dee	ath9k_hw_set_sta_beacon_timers
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x324f76d5	ath9k_hw_enable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x333598ce	ar9003_paprd_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37748549	ath9k_hw_gettxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x379b0724	ath9k_hw_phy_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x37ea1dd0	ath9k_hw_resettxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3ac2deb2	ar9003_mci_get_interrupt
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3aecd07e	ath9k_hw_set_gpio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3da089eb	ath9k_hw_btcoex_disable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x3e0f100c	ath9k_hw_reset_calvalid
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x408392d6	ath_gen_timer_free
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x43ada60c	ath9k_hw_init_btcoex_hw
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x43de228f	ath9k_hw_set_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4444cdd3	ar9003_paprd_setup_gain_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x45d25a6d	ath9k_hw_beaconq_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x46aa34dd	ath9k_hw_reset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4b11d55f	ath9k_hw_abortpcurecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4b2ef316	ath9k_hw_disable_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x4d612a41	ar9003_mci_get_next_gpm_offset
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x51dae8b7	ath9k_hw_startpcureceive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x52f95ee5	ath9k_hw_init_global_settings
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54c7fd41	ath9k_hw_disable_mib_counters
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x54fdd4c6	ath9k_hw_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x570d95a6	ar9003_is_paprd_enabled
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x58aadd4a	ar9003_mci_set_bt_version
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5922a643	ath9k_hw_gpio_get
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x5b83dd67	ath9k_hw_bstuck_nfcal
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x676191a6	ar9003_get_pll_sqsum_dvc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x68053a64	ath9k_hw_get_txq_props
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6ba5a05c	ar9003_mci_setup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6dacbf6d	ath9k_hw_btcoex_enable
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e5ef16e	ath9k_hw_updatetxtriglevel
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6e64fc1d	ath9k_hw_setpower
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x6f70c6ae	ar9003_paprd_populate_single_table
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x773b1009	ar9003_mci_send_message
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7861767f	ath9k_hw_numtxpending
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x78d8a607	ath9k_hw_txstart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7a2d6e65	ath9k_hw_settsf64
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7c8812d3	ar9003_mci_state
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x7e4148b4	ar9003_hw_disable_phy_restart
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x805cfcc1	ath9k_hw_getchan_noise
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x82c6fce7	ath9k_hw_setmcastfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8d18a118	ath9k_hw_stop_dma_queue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x8e9cd87c	ath9k_hw_ani_monitor
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x91216f84	ar9003_mci_send_wlan_channels
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x927d69c3	ath9k_hw_process_rxdesc_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x94d3688c	ath9k_hw_btcoex_init_3wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x97630e20	ath9k_hw_cfg_output
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9838b2c3	ath9k_hw_cfg_gpio_input
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0x9c4d3289	ath9k_hw_deinit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xa172d2f9	ath9k_hw_getrxfilter
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaae8896e	ath_gen_timer_isr
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xab4607cc	ar9003_paprd_is_done
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xabecc999	ath9k_hw_setuptxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xac0f0ac3	ath9k_hw_releasetxqueue
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xadf12062	ath9k_hw_check_alive
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xaf5ff7fe	ath9k_hw_setopmode
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb1408b44	ath9k_hw_gen_timer_stop
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb1e89cfa	ath9k_hw_setup_statusring
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb24259d3	ath9k_hw_name
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xb9569259	ath9k_hw_btcoex_init_scheme
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbab7df29	ar9003_hw_bb_watchdog_dbg_info
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xbca90499	ath9k_hw_btcoex_set_weight
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc1f88f13	ath9k_hw_stopdmarecv
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc4cf4637	ath9k_hw_kill_interrupts
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xc8ab83ac	ath9k_hw_btcoex_init_2wire
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xcefa216d	ath9k_hw_putrxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd0f130d6	ath9k_hw_computetxtime
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd14789a6	ath_gen_timer_alloc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd496598c	ath9k_hw_puttxbuf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd52ff0dd	ath9k_hw_addrxbuf_edma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xd74ea412	ath9k_hw_abort_tx_dma
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xdd1a44d9	ath9k_hw_setuprxdesc
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe43eb7af	ath9k_hw_wait
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe46ab776	ath9k_hw_btcoex_set_concur_txprio
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe5b84f09	ath9k_hw_setantenna
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xe8ee7c28	ath9k_hw_btcoex_init_mci
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xed14edf3	ar9003_mci_cleanup
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xee771dc7	ath9k_hw_init
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf08040f2	ath9k_hw_set_tsfadjust
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf33bcc69	ath9k_hw_set_txpowerlimit
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf3d31e44	ath9k_hw_setrxabort
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xf76c7b27	ath9k_hw_intrpend
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfa952b20	ath9k_hw_getnf
++EXPORT_SYMBOL drivers/net/wireless/ath/ath9k/ath9k_hw 0xfc1491af	ath9k_hw_disable
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x3c6fb8df	stop_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x5be2d84a	atmel_open
++EXPORT_SYMBOL drivers/net/wireless/atmel 0x82848372	init_atmel_card
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0x99b9c91d	brcmf_sdio_probe
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmfmac/brcmfmac 0xdf904ef3	brcmf_sdio_remove
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x037d2f8f	brcmu_pktq_mlen
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x0f3a682e	brcmu_pkt_buf_free_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x1fac5ed3	brcmu_pktq_penq_head
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x20eee95d	brcmu_pktq_init
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x2dc227f8	brcmu_d11_attach
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x32fed858	brcmu_pktq_pdeq_match
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x4918518a	brcmu_pktq_flush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x5f9b88bd	brcmu_pktq_pflush
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x859c6fab	brcmu_pktq_peek_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x97d8e66e	brcmu_pktq_pdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0x9e53585b	brcmu_pktq_pdeq_tail
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbda42343	brcmu_pkt_buf_get_skb
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xbfeade96	brcmu_pktq_mdeq
++EXPORT_SYMBOL drivers/net/wireless/brcm80211/brcmutil/brcmutil 0xc0fe903a	brcmu_pktq_penq
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x09a9e99e	hostap_init_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0ad69602	hostap_set_multicast_list_queue
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x0e8068b3	hostap_set_auth_algs
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x139447b2	hostap_set_antsel
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x13fbd3ba	hostap_set_roaming
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x1bf0ed2c	hostap_setup_dev
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x23425326	hostap_remove_proc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x3ebd8317	hostap_set_hostapd_sta
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x4d63c643	hostap_info_init
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x53d405d3	hostap_set_encryption
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x642a8727	hostap_get_porttype
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x648083d6	hostap_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x894248a4	prism2_update_comms_qual
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0x906ac29e	hostap_80211_rx
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xa12ad27f	hostap_dump_tx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xab07b00a	hostap_handle_sta_tx_exc
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xae9e9a27	hostap_init_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2a945e0	hostap_dump_rx_header
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb2e87265	hostap_set_string
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xb4b77c8b	hostap_80211_get_hdrlen
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xbd8827a6	hostap_info_process
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xca6ccf6b	hostap_add_interface
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xcc915bb7	hostap_set_hostapd
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd6a03e54	hostap_set_word
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xd8b00911	hostap_80211_ops
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xe9078fbf	hostap_free_data
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xec911209	hostap_master_start_xmit
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf63df527	hostap_check_sta_fw_version
++EXPORT_SYMBOL drivers/net/wireless/hostap/hostap 0xf6defdf8	hostap_init_ap_proc
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x12538ca4	libipw_freq_to_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x18b833cb	libipw_get_channel_flags
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x1927ac40	libipw_wx_get_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x22088cc2	libipw_wx_get_scan
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x31ae2d7c	libipw_xmit
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x42824b6e	libipw_rx
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x712135e2	libipw_channel_to_freq
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x768468f9	libipw_channel_to_index
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x9063a3bb	libipw_txb_free
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0x93546a02	free_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xa5182819	libipw_wx_get_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xaa755970	alloc_libipw
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xab275ecc	libipw_get_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb29a83dc	libipw_wx_set_encode
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xb9f4540c	libipw_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xcbfac9e1	libipw_networks_age
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xd4c8a7ad	libipw_is_valid_channel
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xdb69cebd	libipw_set_geo
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xedb5c677	libipw_rx_mgt
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xf6dd9e7a	libipw_wx_set_encodeext
++EXPORT_SYMBOL drivers/net/wireless/ipw2x00/libipw 0xfbb03740	libipw_get_geo
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x031f9413	il_get_active_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x08e3dbde	il_dbgfs_register
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x097fe9fa	il_mac_change_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x0f7a29d7	il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x121779e2	il_mac_reset_tsf
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x15299d7a	il_send_cmd_pdu
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x183f6bdb	il_get_lowest_plcp
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1b710685	il_fill_probe_req
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1bb80de8	il_hdl_spectrum_measurement
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1c34934f	il_irq_handle_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1d29c357	il_set_rxon_ht
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1d67d780	il_set_flags_for_band
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1e9f5dbc	il_set_rxon_channel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x1f41c333	il_rx_queue_alloc
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x2235cd87	il_mac_sta_remove
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x28724431	il_eeprom_query16
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x30428b1f	il_init_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x307d2f1a	il_rx_queue_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x37531c4d	_il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x39c35a07	il_mac_add_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3cb8ca92	il_send_lq_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x3fb2169c	il_set_tx_power
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x434c6e61	il_is_ht40_tx_allowed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4599e0cc	il_send_cmd_pdu_async
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x46c611bc	il_eeprom_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x47fd921a	il_init_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x489f43e6	il_clear_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4aa39103	il_get_cmd_string
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x4e8c8de0	il_cancel_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x511969b6	il_alloc_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x52f742a7	il_rd_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x52fc3fa8	il_scan_cancel_timeout
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x53046cb5	il_tx_queue_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x54d00257	il_get_passive_dwell_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x564c6740	il_debug_level
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x60e90bd5	il_tx_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x62e28417	il_clear_ucode_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6329ebd3	il_mac_hw_scan
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x680dbe0e	il_send_add_sta
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6a0dba3f	il_poll_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6d1c5d8f	il_cmd_queue_unmap
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6ea3bb44	il_scan_cancel
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x6f8c6bd5	il_init_scan_params
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x727495de	il_tx_cmd_protection
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x749a0dd2	il_mac_flush
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x74fd7e7b	il_leds_exit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x762b4f22	il_send_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x77111d40	il_check_rxon_cmd
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7cb179a8	il_power_initialize
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7dcff2be	il_set_rate
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7edfc679	il_mac_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x7fb8f94d	il_eeprom_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x811702a9	il_mac_bss_info_changed
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x842910d3	il_tx_cmd_complete
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x8fd6718b	il_setup_scan_deferred_work
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x90be72bf	il_hdl_pm_sleep
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x92761646	il_wr_prph
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x931d46f2	il_get_single_channel_number
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x94b3c19d	il_setup_rx_scan_handlers
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x957ec4ef	il_add_beacon_time
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9610e40e	il_force_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x98484849	il_hdl_error
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x99318268	il_send_cmd_sync
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9a2d53a3	il_mac_remove_interface
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0x9ab53e09	il_send_bt_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xa65f6295	il_read_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xabe6eff2	il_send_rxon_timing
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb057eb76	il_mac_conf_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb3fa4df4	il_rx_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb7bd33ff	il_isr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb945d597	il_free_channel_map
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb987bd02	il_power_update_mode
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xb9a6a30e	il_get_channel_info
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xba5542f1	il_hdl_pm_debug_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbca7ae27	il_usecs_to_beacons
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xbdd3bccc	il_add_station_common
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc1597690	il_free_geos
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc39cf12c	il_bg_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc5b46293	il_write_targ_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc62db945	il_connection_init_rx_config
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xc6a5b0d2	il_get_free_ucode_key_idx
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xcaa86df9	il_cmd_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd265d18f	il_tx_queue_free
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd53f3e9e	il_pm_ops
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd669ba1f	il_restore_stations
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd84b8597	il_set_decrypted_flag
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd8a264cf	il_tx_queue_reset
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xd947a344	il_send_stats_request
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe256e23b	il_chswitch_done
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe31004f2	il_apm_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe397f8f7	il_leds_init
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe3f68b41	il_update_stats
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe435493a	il_queue_space
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6e1237c	il_set_bit
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe6e7a18b	il_set_rxon_hwcrypto
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xe8845a35	il_free_txq_mem
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xeac9c30a	il_eeprom_query_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xecb10fcb	il_setup_watchdog
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf05592ec	il_hdl_csa
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf2208ce0	il_dbgfs_unregister
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf501278b	il_bcast_addr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf5c036b2	il_full_rxon_required
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xf9965513	il_txq_update_write_ptr
++EXPORT_SYMBOL drivers/net/wireless/iwlegacy/iwlegacy 0xfe6da899	_il_apm_stop
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x08ee1e7d	__tracepoint_iwlwifi_dev_ucode_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x0d9eb5ff	__tracepoint_iwlwifi_dev_ucode_wrap_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x0e7bc05f	__tracepoint_iwlwifi_warn
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x201337b4	__tracepoint_iwlwifi_dev_tx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x249e4b06	__tracepoint_iwlwifi_dev_rx
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x36dcef55	__tracepoint_iwlwifi_dev_iowrite32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x4919d1a5	__tracepoint_iwlwifi_dbg
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x67381a2a	__tracepoint_iwlwifi_dev_ucode_error
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x79e9bf26	__tracepoint_iwlwifi_crit
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x7edec07d	__tracepoint_iwlwifi_dev_ioread32
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x8bfcc307	__tracepoint_iwlwifi_info
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0x9a12c9c5	__tracepoint_iwlwifi_dev_ucode_cont_event
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xc0827b2f	__tracepoint_iwlwifi_dev_iowrite8
++EXPORT_SYMBOL drivers/net/wireless/iwlwifi/iwlwifi 0xda36f3a4	__tracepoint_iwlwifi_err
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x20d7b8d9	__orinoco_ev_rx
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x3ffc92a6	orinoco_process_xmit_skb
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x522e3a8e	orinoco_up
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x5cea252e	orinoco_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x647c2114	orinoco_get_stats
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6638caa9	orinoco_set_multicast_list
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x68d37e19	orinoco_if_del
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x6a8090b8	alloc_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x871a4b00	orinoco_if_add
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x90278e59	orinoco_down
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9700f1cf	orinoco_tx_timeout
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0x9d0b87b4	hermes_struct_init
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb4acad88	__orinoco_ev_info
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xb537dd42	free_orinocodev
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xd3df24e3	orinoco_open
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf28d8cf4	orinoco_stop
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xf38cc597	orinoco_change_mtu
++EXPORT_SYMBOL drivers/net/wireless/orinoco/orinoco 0xffe27bca	orinoco_interrupt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x024857ea	_rtl92c_phy_dbm_to_txpwr_Idx
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x049983f0	_rtl92c_phy_set_rf_sleep
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x08823402	rtl92c_dm_init
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x20599307	rtl92c_phy_set_txpower_level
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x20b1d6b6	rtl92c_download_fw
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x21f02e7f	rtl92c_phy_ap_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x276209f9	rtl92c_phy_rf_config
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x2b289ba9	_rtl92c_phy_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x301de0d9	_rtl92c_phy_fw_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x360c9f67	rtl92c_phy_set_io
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x3a9b5c5e	_rtl92c_phy_rf_serial_read
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x46423585	rtl92c_phy_sw_chnl_callback
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x4b9aa2e3	_rtl92c_phy_txpwr_idx_to_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x533d045f	rtl92c_phy_scan_operation_backup
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5457dae3	rtl92c_phy_sw_chnl
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x5d27bf5a	rtl92c_phy_set_rfpath_switch
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x61365a8e	rtl92c_dm_init_rate_adaptive_mask
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6755effd	_rtl92c_phy_init_bb_rf_register_definition
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x695ddec9	rtl92c_set_fw_rsvdpagepkt
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x6a13c62a	rtl92c_phy_set_bw_mode
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x71cc8263	rtl92c_phy_update_txpower_dbm
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x74dbf461	_rtl92c_store_pwrIndex_diffrate_offset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x8c1662a6	rtl92c_phy_query_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x92a0c1d9	rtl8192_phy_check_is_legal_rfpath
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x9a87ef2c	rtl92c_fill_h2c_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xa154f82a	rtl92ce_phy_set_rf_on
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xafecd314	rtl92c_dm_init_edca_turbo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb132dd71	rtl92c_set_fw_joinbss_report_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb319df70	rtl92c_phy_set_io_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb3314d48	_rtl92c_phy_calculate_bit_shift
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xb74c1bcd	_rtl92c_phy_bb8192c_config_parafile
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xba49958a	rtl92c_set_fw_pwrmode_cmd
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xbe5b3f6f	rtl92c_phy_set_bb_reg
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xc0eb6299	rtl92c_firmware_selfreset
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xcece8787	rtl92c_dm_write_dig
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xde91f6cf	rtl92c_dm_watchdog
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xdf3ea023	rtl92c_dm_check_txpower_tracking
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe2476b8d	rtl92c_phy_lc_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe4ee7e2f	rtl92c_bt_rssi_state_change
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xe53a9d3c	rtl92c_phy_iq_calibrate
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xfa16f64a	_rtl92c_phy_fw_rf_serial_write
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xfbccd718	rtl92c_dm_bt_coexist
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0xfed32803	rtl92c_dm_rf_saving
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x0ab5ee20	rtl_pci_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x3feb96bd	rtl_pci_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0x8f6183c1	rtl_pci_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_pci 0xb14a278e	rtl_pci_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x0c235cc9	rtl_usb_disconnect
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x1d8ec73b	rtl_usb_resume
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0x3edb1976	rtl_usb_probe
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtl_usb 0xdf8f2e0a	rtl_usb_suspend
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x0370e365	rtl_efuse_shadow_map_update
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x05ea3ac5	rtl_process_phyinfo
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x1013d9ae	rtl_cam_add_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x1641c84d	rtl_get_tcb_desc
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x1ccd7008	rtl_cam_del_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x207fbb70	rtl_evm_db_to_percentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x2e71ce32	rtl_send_smps_action
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x38fc2ee2	rtl_cam_reset_all_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x578d257a	rtl_cam_empty_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x79188a02	rtl_query_rxpwrpercentage
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x7b77fccc	rtl_ps_enable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x89a98169	rtl_cam_get_free_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x9427bc05	rtlwifi_rate_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0x9a649bdc	rtl_cam_mark_invalid
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xa58351b7	rtl_ps_set_rf_state
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xc89a8ffb	rtl_ps_disable_nic
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xcf417bab	rtl_signal_scale_mapping
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xd349bbd7	rtl_init_rfkill
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xee44e059	rtl_fw_cb
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xf03d7328	rtl_cam_delete_one_entry
++EXPORT_SYMBOL drivers/net/wireless/rtlwifi/rtlwifi 0xf1ecaf36	efuse_read_1byte
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x411bdebb	wlcore_tx_complete
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0x672fef9d	wl12xx_is_dummy_packet
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xf38f2f71	wl1271_free_tx_id
++EXPORT_SYMBOL drivers/net/wireless/ti/wlcore/wlcore 0xf446631a	wlcore_calc_packet_alignment
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x6c2d4bec	microread_remove
++EXPORT_SYMBOL drivers/nfc/microread/microread 0x9b6da7c6	microread_probe
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0x3e2e5eb4	pn544_hci_remove
++EXPORT_SYMBOL drivers/nfc/pn544/pn544 0xe43274bd	pn544_hci_probe
++EXPORT_SYMBOL drivers/parport/parport 0x009d10c0	parport_claim_or_block
++EXPORT_SYMBOL drivers/parport/parport 0x1257dff4	parport_ieee1284_read_byte
++EXPORT_SYMBOL drivers/parport/parport 0x22c32efe	parport_unregister_driver
++EXPORT_SYMBOL drivers/parport/parport 0x3a4bb20c	parport_get_port
++EXPORT_SYMBOL drivers/parport/parport 0x4d2a941b	parport_ieee1284_interrupt
++EXPORT_SYMBOL drivers/parport/parport 0x4dd6c482	parport_ieee1284_write_compat
++EXPORT_SYMBOL drivers/parport/parport 0x59d1ff18	parport_ieee1284_ecp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x5e3a3912	parport_irq_handler
++EXPORT_SYMBOL drivers/parport/parport 0x63179e12	parport_ieee1284_epp_read_data
++EXPORT_SYMBOL drivers/parport/parport 0x63659386	parport_set_timeout
++EXPORT_SYMBOL drivers/parport/parport 0x659ebce3	parport_release
++EXPORT_SYMBOL drivers/parport/parport 0x6776fb79	parport_ieee1284_read_nibble
++EXPORT_SYMBOL drivers/parport/parport 0x6b2ee5c2	parport_ieee1284_epp_read_addr
++EXPORT_SYMBOL drivers/parport/parport 0x6c068854	parport_remove_port
++EXPORT_SYMBOL drivers/parport/parport 0x6f0b550e	parport_ieee1284_epp_write_data
++EXPORT_SYMBOL drivers/parport/parport 0x70077e6c	parport_ieee1284_epp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0x705692ed	parport_negotiate
++EXPORT_SYMBOL drivers/parport/parport 0x7b149c20	parport_write
++EXPORT_SYMBOL drivers/parport/parport 0x83fcdb12	parport_announce_port
++EXPORT_SYMBOL drivers/parport/parport 0x8b7c31b6	parport_register_port
++EXPORT_SYMBOL drivers/parport/parport 0x9f104249	parport_wait_event
++EXPORT_SYMBOL drivers/parport/parport 0xabd9f684	parport_read
++EXPORT_SYMBOL drivers/parport/parport 0xace3ad38	parport_register_driver
++EXPORT_SYMBOL drivers/parport/parport 0xc48ab8fe	parport_register_device
++EXPORT_SYMBOL drivers/parport/parport 0xd11f8486	parport_find_number
++EXPORT_SYMBOL drivers/parport/parport 0xd2212c12	parport_put_port
++EXPORT_SYMBOL drivers/parport/parport 0xd4dd9232	parport_unregister_device
++EXPORT_SYMBOL drivers/parport/parport 0xe282e254	parport_wait_peripheral
++EXPORT_SYMBOL drivers/parport/parport 0xe998cfce	parport_claim
++EXPORT_SYMBOL drivers/parport/parport 0xee1cf863	parport_ieee1284_ecp_write_addr
++EXPORT_SYMBOL drivers/parport/parport 0xefb6c76b	parport_find_base
++EXPORT_SYMBOL drivers/parport/parport 0xf110d301	parport_ieee1284_ecp_write_data
++EXPORT_SYMBOL drivers/parport/parport_pc 0x60164710	parport_pc_unregister_port
++EXPORT_SYMBOL drivers/parport/parport_pc 0x6652855b	parport_pc_probe_port
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x1985a4cb	pcmcia_loop_config
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x29ce16e6	pcmcia_request_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x307062fb	pcmcia_get_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x317dde50	pcmcia_fixup_vpp
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x3c1177cd	pcmcia_write_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x3c3deefe	pcmcia_get_mac_from_cis
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x43fa890a	pcmcia_register_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x67cfaebb	pcmcia_read_config_byte
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x742f5665	pcmcia_parse_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x7fb00076	pcmcia_loop_tuple
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x8073a28c	pcmcia_dev_present
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x93168d16	pcmcia_release_window
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0x99a93e0d	pcmcia_disable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xa2341988	pcmcia_request_io
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xbda73c51	pcmcia_map_mem_page
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xcc724550	pcmcia_request_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xd4617c1c	pcmcia_unregister_driver
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xf05bcb1a	pcmcia_enable_device
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfa6d79eb	__pcmcia_request_exclusive_irq
++EXPORT_SYMBOL drivers/pcmcia/pcmcia 0xfcc5abf9	pcmcia_fixup_iowidth
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x13236f49	pcmcia_register_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x212db8d2	pcmcia_socket_list
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x603a4597	pcmcia_unregister_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x7e2fa5b9	pccard_register_pcmcia
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x997bf532	pcmcia_reset_card
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9df821a4	pcmcia_get_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0x9fabf5a1	pcmcia_put_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xaa2a8638	pcmcia_socket_list_rwsem
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xb9cda6f4	pcmcia_parse_events
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xcf97f3bd	dead_socket
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xd36c8c32	pcmcia_parse_uevents
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xd756602a	pcmcia_socket_class
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_core 0xf93f180f	pcmcia_get_socket_by_nr
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0x5382b62e	pccard_nonstatic_ops
++EXPORT_SYMBOL drivers/pcmcia/pcmcia_rsrc 0xf7aaa0bf	pccard_static_ops
++EXPORT_SYMBOL drivers/platform/x86/sony-laptop 0x5bb1e117	sony_pic_camera_command
++EXPORT_SYMBOL drivers/pps/pps_core 0x2c32c5fd	pps_unregister_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x46abb7ee	pps_register_source
++EXPORT_SYMBOL drivers/pps/pps_core 0x7035e6f9	pps_lookup_dev
++EXPORT_SYMBOL drivers/pps/pps_core 0xef5339ad	pps_event
++EXPORT_SYMBOL drivers/ptp/ptp 0x5a8b6ff3	ptp_clock_register
++EXPORT_SYMBOL drivers/ptp/ptp 0x76178a90	ptp_clock_unregister
++EXPORT_SYMBOL drivers/ptp/ptp 0x82ccfe6a	ptp_clock_index
++EXPORT_SYMBOL drivers/ptp/ptp 0xa05cb9c1	ptp_clock_event
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x00aed960	pch_ch_control_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x07637c6a	pch_ch_control_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x3da62346	pch_src_uuid_lo_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x403740d6	pch_tx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x430409d1	pch_set_station_address
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x4d7f2573	pch_src_uuid_hi_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0x807c99c3	pch_ch_event_write
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xba919b60	pch_rx_snap_read
++EXPORT_SYMBOL drivers/ptp/ptp_pch 0xe088d6cb	pch_ch_event_read
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x132e346f	rproc_report_crash
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x4b80390c	rproc_del
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x5c00a38b	rproc_add
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x76c9b3e3	rproc_alloc
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x7907fbc9	rproc_boot
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x8540811c	rproc_put
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0x8b1b9ebb	rproc_da_to_va
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xaf8b89ee	rproc_shutdown
++EXPORT_SYMBOL drivers/remoteproc/remoteproc 0xe8e05252	rproc_vq_interrupt
++EXPORT_SYMBOL drivers/scsi/53c700 0x118bca2d	NCR_700_release
++EXPORT_SYMBOL drivers/scsi/53c700 0x3d9cece0	NCR_700_intr
++EXPORT_SYMBOL drivers/scsi/53c700 0x47560b09	NCR_700_detect
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3d04a80e	fcoe_transport_detach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x3dce12d3	fcoe_ctlr_set_fip_mode
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x549fb56e	fcoe_fcf_get_selected
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x5e5a00f6	fcoe_ctlr_destroy
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x79304932	fcoe_ctlr_recv
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x7b81840f	fcoe_ctlr_els_send
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0x912e4b17	fcoe_transport_attach
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xa21d9aa4	fcoe_ctlr_init
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xcf9e02a2	fcoe_ctlr_destroy_store
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xd33674d4	fcoe_ctlr_link_up
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xe6b8a2fa	fcoe_ctlr_link_down
++EXPORT_SYMBOL drivers/scsi/fcoe/libfcoe 0xf9094daa	fcoe_ctlr_recv_flogi
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x026db5cb	fc_frame_alloc_fill
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x047eeb0b	fc_exch_mgr_add
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x0786b25d	fc_disc_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x1cf554b6	fc_linkup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x22b90986	fc_exch_mgr_del
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2627fa0b	fc_lport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2b236ac1	fc_set_rport_loss_tmo
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x2daa49cc	libfc_vport_create
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x36e5fbaf	fc_cpu_mask
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3bc0b434	fc_elsct_send
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x3de7e014	fc_eh_host_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x40d34428	fc_lport_bsg_request
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x46a22658	fc_eh_abort
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4d945c17	fc_linkdown
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x4eff2af7	_fc_frame_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x513000bc	fc_vport_id_lookup
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x521901c0	fc_fc4_deregister_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5dcc7837	fc_exch_mgr_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x5f42f8eb	fc_get_host_speed
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x6464adae	fc_set_mfs
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x64b3d37d	fc_fill_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x72755d42	fc_lport_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7462fb55	fc_exch_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7523b36a	fc_get_host_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x78222178	fc_exch_recv
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7e167ea8	fc_lport_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x7f7b95a5	fc_lport_notifier_head
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x807fbb50	fc_get_host_port_state
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x82d798d6	fc_rport_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x85af3dfa	fc_fabric_logoff
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x87e77f2b	fc_change_queue_depth
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x8fec5723	fc_fcp_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x90ee4add	fc_change_queue_type
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0x96b34dfb	fc_exch_update_stats
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xa74a2355	fc_eh_device_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xad4a48a0	fc_vport_setlink
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb3168af5	fc_exch_mgr_free
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb4e28c22	fc_exch_mgr_list_clone
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb50c8bcf	fc_fc4_register_provider
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb6367db6	fc_frame_crc_check
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xb8da9f32	fc_slave_alloc
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xc52dbb65	fc_lport_logo_resp
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcb84020f	fc_fabric_login
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xcc5b8081	fc_exch_mgr_reset
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd313133b	fc_fcp_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xd38509f4	fc_lport_destroy
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xdecd3f4e	fc_elsct_init
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe4169dff	fc_fill_reply_hdr
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe43d73f0	fc_rport_terminate_io
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe7e3c9ce	fc_queuecommand
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xe80f0026	fc_lport_set_local_id
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeaaba25a	fc_lport_iterate
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xeeac83e3	fc_disc_config
++EXPORT_SYMBOL drivers/scsi/libfc/libfc 0xf164fedb	fc_lport_flogi_resp
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x02391dc0	sas_resume_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x33b6735f	sas_wait_eh
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x79daa402	sas_suspend_ha
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0x8a87e724	try_test_sas_gpio_gp_bit
++EXPORT_SYMBOL drivers/scsi/libsas/libsas 0xa83f79a6	sas_prep_resume_ha
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x2250c66e	mraid_mm_adapter_app_handle
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0x512c956d	mraid_mm_unregister_adp
++EXPORT_SYMBOL drivers/scsi/megaraid/megaraid_mm 0xe048910b	mraid_mm_register_adp
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c17edb1	osd_sec_init_nosec_doall_caps
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x0c73500b	osd_dev_fini
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x106a47c0	osd_req_read_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x10c54430	osd_req_read
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x20cd1a34	osd_req_list_partition_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x229ee815	osd_req_get_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x2876f08b	osd_req_set_attributes
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3b4e66a2	osd_finalize_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3c315df0	osd_req_add_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x3d1f8ede	osd_req_list_dev_partitions
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x44e646c9	osd_req_read_sg
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x45924779	osd_req_write
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4e1ba4b0	osd_req_list_collection_objects
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x4ffbc84f	osd_req_flush_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x56a59490	osd_req_flush_collection
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x5e9fd18b	osd_req_read_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x658ffef3	osd_req_remove_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x69478096	osd_auto_detect_ver
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x6e3ddb4d	osd_execute_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x72b4fd37	osd_req_decode_get_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x78b42d7d	osd_req_remove_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x83aadb2d	osd_req_format
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x8412a4c5	osd_req_flush_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x922e01fd	osd_req_flush_obsd
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0x98ea8c2b	osd_req_add_get_attr_page
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xa8477364	osd_start_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xab8312c9	osd_execute_request_async
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb4ad0c50	osd_end_request
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xb87478d8	osd_req_create_partition
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbec38832	osd_req_list_partition_collections
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xbf3ecb26	osd_req_write_sg_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc4678342	osd_req_create_object
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xc9c3c7f9	osd_req_write_kern
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd493e5b6	osd_req_decode_sense_full
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xd5dd1075	osd_dev_init
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xdbb44c93	osd_req_add_set_attr_list
++EXPORT_SYMBOL drivers/scsi/osd/libosd 0xeb64f382	osd_req_write_sg
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x091c7b12	osduld_device_info
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1bf86474	osduld_info_lookup
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x1e2e56dc	osduld_register_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x5fc48609	osduld_unregister_test
++EXPORT_SYMBOL drivers/scsi/osd/osd 0x8d665f6d	osduld_device_same
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xaaa65f76	osduld_put_device
++EXPORT_SYMBOL drivers/scsi/osd/osd 0xe11abbbe	osduld_path_lookup
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x1b1916b2	qlt_lport_register
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x2ce0ae08	qlt_free_cmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4ec090fb	qlt_xmit_tm_rsp
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x4f56520d	qlt_enable_vha
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x6eb911d7	qlt_unreg_sess
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x896acfd2	qlt_xmit_response
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x89852c67	qlt_stop_phase2
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0x958ab39d	qlt_lport_deregister
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xd3df90dd	qlt_free_mcmd
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xddb20811	qlt_rdy_to_xfer
++EXPORT_SYMBOL drivers/scsi/qla2xxx/qla2xxx 0xeac0bf74	qlt_stop_phase1
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x1f55cd70	qlogicfas408_ihandl
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x3fd8cd71	qlogicfas408_detect
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x565d7fcd	qlogicfas408_disable_ints
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x7afe6e2e	qlogicfas408_abort
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0x81bf48fa	qlogicfas408_info
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xa13cb3b7	qlogicfas408_biosparam
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xd8d875ff	qlogicfas408_bus_reset
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xe76b3b20	qlogicfas408_get_chip_type
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xf2b95199	qlogicfas408_setup
++EXPORT_SYMBOL drivers/scsi/qlogicfas408 0xfea84b05	qlogicfas408_queuecommand
++EXPORT_SYMBOL drivers/scsi/raid_class 0x5a76448b	raid_component_add
++EXPORT_SYMBOL drivers/scsi/raid_class 0x95ade985	raid_class_release
++EXPORT_SYMBOL drivers/scsi/raid_class 0x9eebaa25	raid_class_attach
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x1ea4f16f	fc_vport_terminate
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7954b1ea	fc_get_event_number
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x7fcd57dc	fc_host_post_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0x8ae2a302	fc_remote_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa5ccc8f6	fc_vport_create
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xa8f57ff1	fc_host_post_vendor_event
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xac2488de	fc_block_scsi_eh
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xb0c03c7a	fc_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xcbfc61cc	fc_remote_port_rolechg
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xd1e7cc52	fc_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xe2a8414c	fc_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xebff1141	scsi_is_fc_vport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf27f4770	scsi_is_fc_rport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_fc 0xf4e82a3e	fc_remote_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0a0f33e8	scsi_is_sas_rphy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x0cd66838	sas_port_add_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x15456f0b	sas_release_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x1af98f97	scsi_is_sas_port
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x266c1ccb	sas_port_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2d8161f3	sas_rphy_remove
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2eca10b9	sas_port_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x2fad7bea	sas_phy_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x332e5162	sas_port_get_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x4cdd6ded	sas_read_port_mode_page
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x50c99272	sas_remove_host
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x53991ae5	sas_remove_children
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x574a1d0b	sas_port_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x71514bfe	sas_rphy_unlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x82138e50	sas_port_alloc_num
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x89e73fb5	sas_end_device_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x993bca22	sas_phy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9c48c92c	sas_rphy_delete
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0x9e6af48d	sas_rphy_add
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa594628a	sas_port_delete_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa5b41ede	sas_phy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xa84efb8b	sas_port_mark_backlink
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xac7bdb81	sas_port_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xb3f9acca	scsi_is_sas_phy
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xc7a760a6	sas_expander_alloc
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xd8fe2750	sas_attach_transport
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xe478e5a7	sas_rphy_free
++EXPORT_SYMBOL drivers/scsi/scsi_transport_sas 0xfd79f16c	sas_phy_delete
++EXPORT_SYMBOL drivers/ssb/ssb 0x00ac38e8	ssb_pcicore_dev_irqvecs_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0x09529e8a	ssb_bus_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0x0db5dae2	ssb_device_disable
++EXPORT_SYMBOL drivers/ssb/ssb 0x293cc6a5	ssb_clockspeed
++EXPORT_SYMBOL drivers/ssb/ssb 0x30b5c767	ssb_bus_may_powerdown
++EXPORT_SYMBOL drivers/ssb/ssb 0x378fe7e0	ssb_pmu_set_ldo_paref
++EXPORT_SYMBOL drivers/ssb/ssb 0x4bf5c6cb	ssb_bus_suspend
++EXPORT_SYMBOL drivers/ssb/ssb 0x5a6f5056	ssb_device_is_enabled
++EXPORT_SYMBOL drivers/ssb/ssb 0x652ba6a7	ssb_bus_powerup
++EXPORT_SYMBOL drivers/ssb/ssb 0x6c422881	ssb_pmu_set_ldo_voltage
++EXPORT_SYMBOL drivers/ssb/ssb 0x7827e4cf	ssb_bus_resume
++EXPORT_SYMBOL drivers/ssb/ssb 0x7c81b6ce	ssb_driver_unregister
++EXPORT_SYMBOL drivers/ssb/ssb 0xaa25d2a0	ssb_pcihost_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xba833919	ssb_dma_translation
++EXPORT_SYMBOL drivers/ssb/ssb 0xc0512e0f	ssb_admatch_base
++EXPORT_SYMBOL drivers/ssb/ssb 0xc46020c4	__ssb_driver_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xcc9565a4	ssb_device_enable
++EXPORT_SYMBOL drivers/ssb/ssb 0xcee67ca4	ssb_bus_sdiobus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xd481192b	ssb_admatch_size
++EXPORT_SYMBOL drivers/ssb/ssb 0xd964c948	ssb_commit_settings
++EXPORT_SYMBOL drivers/ssb/ssb 0xeb0ea9b9	ssb_chipco_gpio_control
++EXPORT_SYMBOL drivers/ssb/ssb 0xf9e22031	ssb_bus_pcibus_register
++EXPORT_SYMBOL drivers/ssb/ssb 0xfb8e66f4	ssb_set_devtypedata
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xab4252cf	fwtty_port_get
++EXPORT_SYMBOL drivers/staging/fwserial/firewire-serial 0xc126f133	fwtty_port_put
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x1447515a	adt7316_remove
++EXPORT_SYMBOL drivers/staging/iio/addac/adt7316 0x7d8baadf	adt7316_probe
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x732f4f88	ade7854_remove
++EXPORT_SYMBOL drivers/staging/iio/meter/ade7854 0x9e5330f6	ade7854_probe
++EXPORT_SYMBOL drivers/staging/media/cxd2099/cxd2099 0xcb4c363c	cxd2099_attach
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x0f04dcf2	go7007_snd_init
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x2bfaf376	go7007_alloc
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x3fb19a7c	go7007_register_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x45aaa9fc	go7007_boot_encoder
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x6ec60b25	go7007_snd_remove
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x8d68a4e6	go7007_parse_video_stream
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x9b0dea8c	go7007_read_addr
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0x9c45fd3d	go7007_update_board
++EXPORT_SYMBOL drivers/staging/media/go7007/go7007 0xed17c811	go7007_read_interrupt
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0ae65165	rtllib_stop_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0baad968	rtllib_wx_set_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x0d13b958	rtllib_DisableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x10ac8fe7	rtllib_wx_get_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x184a7225	rtllib_act_scanning
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x250c78bd	rtllib_wx_get_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2a76ecca	rtllib_softmac_stop_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2cdb4a2a	rtllib_wx_set_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2f645541	dot11d_init
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x2fc4fa0c	rtllib_wx_get_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x31bcdfdc	rtllib_wx_set_mode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x40f69b77	rtllib_wpa_supplicant_ioctl
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x43d497d8	rtllib_start_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x4ad38641	rtllib_start_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x531d4e77	rtllib_wx_set_mlme
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x578d987a	rtllib_wx_set_gen_ie
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x57c1a1f0	Dot11d_Channelmap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x598e8e0f	rtllib_wx_set_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5bc88f68	rtllib_stop_send_beacons
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x5f1401aa	rtllib_ps_tx_ack
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6129f5c0	rtllib_wx_get_name
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6208b020	rtllib_stop_scan_syncro
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x6a239fb8	rtllib_get_beacon
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x789ede34	rtllib_wx_get_freq
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x7a3e5748	rtllib_rx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x80841a82	alloc_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x873b1636	HT_update_self_and_peer_setting
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x887fc41e	rtllib_wx_get_rts
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x8cb36123	rtllib_wx_set_rawtx
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x942681c9	rtllib_wx_set_essid
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9eee0378	rtllib_wx_set_power
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0x9fe60fd5	rtllib_wx_get_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xa1e83afa	rtllib_sta_ps_send_null_frame
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xaac375bd	rtllib_MgntDisconnect
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xaf0e575c	rtllib_wx_get_wap
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xbe1420f2	rt_global_debug_component
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc6a7f221	rtllib_wx_get_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc83f9009	rtllib_wx_set_encode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xc9959c44	rtllib_wx_get_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd478ce77	rtllib_reset_queue
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xd5590ed6	rtllib_wx_set_encode_ext
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdddffcd3	free_rtllib
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xdf78f620	rtllib_wlan_frequencies
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe0a2d097	RemovePeerTS
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe12b6ed2	rtllib_wx_set_auth
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe2562fb2	rtllib_EnableIntelPromiscuousMode
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe7b7a21a	rtllib_wx_set_rate
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xe885cc7f	rtllib_wx_set_scan
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xeee54754	rtllib_legal_channel
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf0ae09bb	notify_wx_assoc_event
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf64aa184	rtllib_xmit
++EXPORT_SYMBOL drivers/staging/rtl8192e/rtllib 0xf7899155	rtllib_softmac_start_protocol
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x05e8c072	ieee80211_reset_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x18b5a1da	DOT11D_ScanComplete
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x1c7b23de	ieee80211_wx_set_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x24c08a09	ieee80211_wx_get_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x26dc4683	ieee80211_wx_set_gen_ie_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x37e33afd	ieee80211_wx_set_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3a9957e4	ieee80211_wx_set_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x3cbb989d	ieee80211_is_54g_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4830b329	IsLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x4a662ebb	ieee80211_softmac_start_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x51db2b0a	ieee80211_wx_set_auth_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5377d4c1	Dot11d_Reset
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5488295f	ieee80211_wx_get_rts_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5bea27cb	ieee80211_wx_get_encode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x5c3b1197	ieee80211_wpa_supplicant_ioctl_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x619e4d7f	ieee80211_send_probe_requests_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6505a8be	Dot11d_Init
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6692e430	ieee80211_rx_mgt_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x677622f1	ieee80211_ps_tx_ack_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x699b9e53	ieee80211_wx_get_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x69a8a41b	ToLegalChannel
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x6c32c8b5	ieee80211_is_shortslot_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x72390617	ieee80211_wx_set_mlme_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x7ac6584b	ieee80211_start_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x843ecf2d	ieee80211_wx_set_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x89bab663	notify_wx_assoc_event_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8f37cd6d	ieee80211_softmac_xmit_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x8f812be4	ieee80211_wx_set_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9543adde	ieee80211_wx_set_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x970ed73a	ieee80211_wx_get_essid_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x991c6409	ieee80211_wake_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9b8e82db	Dot11d_UpdateCountryIe
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9bbc5e82	ieee80211_softmac_stop_protocol_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9ed6bb89	ieee80211_wx_get_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0x9f424c99	SendDisassociation_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xa66d125e	ieee80211_wx_set_rate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xaaa40fea	ieee80211_stop_queue_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb6b62846	ieee80211_wx_set_rawtx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xb8103382	ieee80211_wx_get_name_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xbc8566fa	ieee80211_wx_get_mode_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc370a43e	ieee80211_wlan_frequencies_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xc5148821	ieee80211_txb_free_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xce1e2d53	ieee80211_wx_get_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd18fd57e	ieee80211_rx_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xd4580a27	ieee80211_softmac_scan_syncro_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe51dc841	ieee80211_disassociate_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xe72db932	ieee80211_wx_get_power_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xed04d17a	DOT11D_GetMaxTxPwrInDbm
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xee8ad1a3	ieee80211_stop_scan_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf22054fb	ieee80211_stop_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf29e04ee	ieee80211_get_beacon_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf628be7c	ieee80211_wx_get_wap_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf6a58484	ieee80211_wx_set_freq_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf7eaa7a9	ieee80211_start_send_beacons_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xf94db6aa	HTUpdateSelfAndPeerSetting
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xfb9c3290	ieee80211_wx_set_encode_ext_rsl
++EXPORT_SYMBOL drivers/staging/rtl8192u/r8192u_usb 0xffa245ec	ieee80211_wx_set_power_rsl
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0017f35f	set_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x00ea0cde	set_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x06d6f244	get_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x09df8f3e	set_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x0a8d32c3	get_bypass_slave_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1936264c	set_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x1d2eb8ca	get_tap_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x203af1f7	reset_bypass_wd_timer_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2070f14a	set_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x27b990ef	get_bypass_info_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2ba7cd35	get_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2c3f1c17	get_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2f59e636	get_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x2fdb893a	get_tap_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x361cf40a	get_dis_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x45ca99c3	set_wd_autoreset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x550a188c	set_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x5cb59e92	get_bypass_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x66b60122	set_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x675208c0	set_tx_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x692623f2	get_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x75131ec6	set_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x76c0b7d0	set_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e872825	get_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x7e8d701e	get_wd_expire_time_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x86388b07	get_bp_disc_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x93ae4648	get_wd_set_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x95e42b0d	is_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9df5f807	set_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0x9e21f42e	set_std_nic_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xa689a214	get_bypass_wd_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xae117788	get_bp_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xc368d30d	get_dis_tap_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xccab5de0	get_bypass_caps_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd3e034b3	get_bypass_pwoff_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9c1ccfc	get_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xd9d38d97	set_wd_exp_mode_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xe640f06e	set_bp_disc_pwup_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xecdaa456	set_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xedcd3c1b	get_bypass_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf06d67bf	set_bp_dis_disc_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf57c1671	get_bp_hw_reset_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf693c3a1	bp_if_scan_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xf8237882	get_bypass_change_sd
++EXPORT_SYMBOL drivers/staging/silicom/bpctl_mod 0xfa59240d	get_tpl_sd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05af3c4c	set_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x05b08a42	set_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0b0d5ce0	get_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x0fc2e83c	reset_bypass_wd_timer
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x123a8133	get_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x157ec89c	get_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2440f05a	get_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2b01d1d4	set_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2c27a2f0	set_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2da97f4b	is_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x2e86c67b	get_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37416370	get_bp_hw_reset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x37bdab27	get_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x3da96a18	get_bypass_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4025805e	get_bypass_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4940a0cc	get_bypass_info
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x4d21ff51	get_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5147360c	get_bp_disc_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x515d4df1	get_bypass_slave
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5560267e	set_wd_autoreset
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x5be44d44	set_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6653590c	get_wd_exp_mode
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x6bda14ec	get_bp_dis_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x72c618ae	set_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x76d47e6f	set_bp_disc_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x794e3815	set_tap_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x7c6cbc16	get_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x84a263dc	set_tx
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x8a16f22c	set_tpl
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x946ff795	get_wd_set_caps
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x94f6aff2	get_bypass_wd
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0x9d1ecf73	set_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xb1385629	set_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xbff68c45	set_bypass_pwup
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xc871c561	get_dis_bypass
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xcee528df	set_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd202dd85	get_bypass_pwoff
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xd787f151	get_wd_expire_time
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xdb6a39d2	get_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xebd25ae5	get_std_nic
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf1e9f8c1	set_bp_disc
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf224abd9	get_tap_change
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf5a591b2	set_dis_tap
++EXPORT_SYMBOL drivers/staging/silicom/bypasslib/bypass 0xf643fd4c	get_bp_disc_pwup
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x0115cb5b	iscsit_stop_dataout_timer
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x15527853	iscsit_handle_task_mgt_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x18482f25	iscsit_build_task_mgt_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x303399bf	iscsit_logout_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x3e237632	iscsit_build_reject
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x43de458f	iscsit_sequence_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x4491caf0	iscsit_process_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x470c0443	iscsit_cause_connection_reinstatement
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x491bc2b2	iscsit_unregister_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x576ff480	iscsit_check_dataout_payload
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x5dba91da	iscsit_handle_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x653b13d2	iscsit_build_logout_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x6cd41fed	iscsit_setup_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x8d796b3c	iscsit_check_dataout_hdr
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x932c2e7c	iscsit_build_rsp_pdu
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0x96cf9ccb	iscsit_handle_logout_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xa2e60f23	iscsit_set_unsoliticed_dataout
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xaaec5065	iscsit_increment_maxcmdsn
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xae48b5b5	iscsit_build_text_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb5cd0333	iscsit_register_transport
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xb73bc5a1	iscsit_allocate_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xbfdb2326	iscsit_setup_nop_out
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xd1251fb6	iscsit_process_scsi_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xe2f2186c	iscsit_setup_text_cmd
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xeccde35a	iscsit_build_nopin_rsp
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xed1ca1fe	iscsit_tmr_post_handler
++EXPORT_SYMBOL drivers/target/iscsi/iscsi_target_mod 0xf37c64b1	iscsit_process_nop_out
++EXPORT_SYMBOL drivers/target/target_core_mod 0x016acc4b	iscsi_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x02de3b18	transport_set_vpd_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0520026f	transport_kunmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x066a6a5d	fc_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x0a96f855	iscsi_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x12d4d43f	transport_generic_new_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1399efe3	spc_emulate_inquiry_std
++EXPORT_SYMBOL drivers/target/target_core_mod 0x192bed13	core_tpg_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1a8a2539	target_complete_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1dd0ed59	spc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x1f60b0bb	fc_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x249b49f8	transport_subsystem_release
++EXPORT_SYMBOL drivers/target/target_core_mod 0x26822db3	transport_deregister_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2a3db1a6	iscsi_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0x2d8fc864	target_submit_cmd_map_sgls
++EXPORT_SYMBOL drivers/target/target_core_mod 0x341a44ec	transport_check_aborted_status
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3abadbeb	transport_init_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x3e9c17c1	fc_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0x425516e4	target_get_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x464d4d8a	target_execute_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x46649b33	sbc_parse_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4894b0de	target_wait_for_sess_cmds
++EXPORT_SYMBOL drivers/target/target_core_mod 0x4e4af568	target_submit_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x54ce4a00	core_tpg_check_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5811aac4	target_get_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x59453136	transport_kmap_data_sg
++EXPORT_SYMBOL drivers/target/target_core_mod 0x59eb5ec2	transport_generic_handle_tmr
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5dafa4b8	target_setup_cmd_from_cdb
++EXPORT_SYMBOL drivers/target/target_core_mod 0x5f3e0d3f	core_tpg_set_initiator_node_tag
++EXPORT_SYMBOL drivers/target/target_core_mod 0x611aa6ed	target_fabric_configfs_init
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65526dfc	iscsi_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x65b2ee25	transport_send_check_condition_and_sense
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7331ec9c	transport_free_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x741cdcd2	transport_generic_request_failure
++EXPORT_SYMBOL drivers/target/target_core_mod 0x75ec6d33	transport_generic_free_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x766e5a66	transport_handle_cdb_direct
++EXPORT_SYMBOL drivers/target/target_core_mod 0x77bcd9db	core_tpg_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x7dbada9d	transport_set_vpd_ident_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0x81da91db	target_fabric_configfs_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0x821539da	sas_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0x83cb1d1c	transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0x85aa880c	transport_set_vpd_assoc
++EXPORT_SYMBOL drivers/target/target_core_mod 0x87c67261	core_alua_check_nonop_delay
++EXPORT_SYMBOL drivers/target/target_core_mod 0x957bb606	target_put_sess_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0x96908252	spc_emulate_evpd_83
++EXPORT_SYMBOL drivers/target/target_core_mod 0xa387bbc6	target_fabric_configfs_free
++EXPORT_SYMBOL drivers/target/target_core_mod 0xab9c2dce	transport_wait_for_tasks
++EXPORT_SYMBOL drivers/target/target_core_mod 0xac09f02a	sas_get_pr_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb17cbd11	target_fabric_configfs_deregister
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb1b50734	transport_lookup_tmr_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb307daf9	transport_deregister_session_configfs
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb332133c	target_put_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xb3bc4d74	sbc_get_device_type
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbaa3dbbf	sas_parse_pr_out_transport_id
++EXPORT_SYMBOL drivers/target/target_core_mod 0xbe349b7b	transport_subsystem_register
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc34fbbf3	sas_get_pr_transport_id_len
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc6ceb693	core_tpg_clear_object_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xc87207d1	target_submit_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcaafe9ba	sbc_get_write_same_sectors
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcc516bb4	core_tpg_set_initiator_node_queue_depth
++EXPORT_SYMBOL drivers/target/target_core_mod 0xced230f5	transport_lookup_cmd_lun
++EXPORT_SYMBOL drivers/target/target_core_mod 0xcf6327e2	fc_get_fabric_proto_ident
++EXPORT_SYMBOL drivers/target/target_core_mod 0xda362ba6	core_tpg_add_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdaabb86e	target_sess_cmd_list_set_waiting
++EXPORT_SYMBOL drivers/target/target_core_mod 0xdba652d1	core_tpg_del_initiator_node_acl
++EXPORT_SYMBOL drivers/target/target_core_mod 0xe890cff2	spc_emulate_report_luns
++EXPORT_SYMBOL drivers/target/target_core_mod 0xec25527a	__transport_register_session
++EXPORT_SYMBOL drivers/target/target_core_mod 0xec8de327	sbc_execute_unmap
++EXPORT_SYMBOL drivers/target/target_core_mod 0xee35b582	transport_init_se_cmd
++EXPORT_SYMBOL drivers/target/target_core_mod 0xefca1937	core_tmr_alloc_req
++EXPORT_SYMBOL drivers/target/target_core_mod 0xf01621c7	transport_set_vpd_proto_id
++EXPORT_SYMBOL drivers/usb/class/cdc-wdm 0xde475e3f	usb_cdc_wdm_register
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x08958ef0	gether_setup_name
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x245d5b91	gether_register_netdev
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x31718fdb	gether_get_host_addr_cdc
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x4140d32e	gether_get_ifname
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x5a473857	gether_get_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x67b3f92d	gether_set_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x76cb7b25	gether_setup_name_default
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x7e6601df	gether_set_gadget
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x8878cfa6	gether_cleanup
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0x9273c961	gether_get_host_addr_u8
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xa8388294	gether_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xa8f0f163	gether_get_dev_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xaa53e4ca	gether_set_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xc118c5b5	gether_get_qmult
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xc9b85e03	gether_set_host_addr
++EXPORT_SYMBOL drivers/usb/gadget/u_ether 0xd9b5b7cb	gether_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x027f828f	rndis_rm_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3a6d4f22	rndis_free_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x3ca38e3a	rndis_signal_connect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x4ca90996	rndis_signal_disconnect
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x5d22b406	rndis_register
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x785d494b	rndis_msg_parser
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x840dd143	rndis_deregister
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x91dca2d1	rndis_set_param_dev
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x988ad2a2	rndis_set_param_vendor
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0x9acf72e4	rndis_set_param_medium
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xa90054ee	rndis_uninit
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xb971ebca	rndis_get_next_response
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xcf581101	rndis_add_hdr
++EXPORT_SYMBOL drivers/usb/gadget/u_rndis 0xd2fe47b1	rndis_set_host_mac
++EXPORT_SYMBOL drivers/usb/gadget/usb_f_rndis 0x2d941b0b	rndis_borrow_net
++EXPORT_SYMBOL drivers/usb/host/sl811-hcd 0x44999e11	sl811h_driver
++EXPORT_SYMBOL drivers/usb/phy/phy-nop 0xa64a4cea	usb_nop_xceiv_unregister
++EXPORT_SYMBOL drivers/usb/phy/phy-nop 0xd0e43207	usb_nop_xceiv_register
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x0ed6b233	usb_wwan_write_room
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x239a7f41	usb_wwan_dtr_rts
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x29b09dfa	usb_wwan_write
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x3eb95048	usb_wwan_open
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x50bb7eae	usb_wwan_port_remove
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x5e2fa81d	usb_wwan_tiocmset
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x61f423d0	usb_wwan_set_termios
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x67176d54	usb_wwan_ioctl
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x818603c1	usb_wwan_suspend
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0x9fa73793	usb_wwan_resume
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xd7a46dc2	usb_wwan_chars_in_buffer
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf56fa362	usb_wwan_close
++EXPORT_SYMBOL drivers/usb/serial/usb_wwan 0xf994c997	usb_wwan_tiocmget
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x30ffd237	usb_serial_resume
++EXPORT_SYMBOL drivers/usb/serial/usbserial 0x61583d76	usb_serial_suspend
++EXPORT_SYMBOL drivers/vhost/vringh 0x0dda8c5a	vringh_complete_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x1f063017	vringh_init_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x2e91ca97	vringh_iov_pull_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x367ce26a	vringh_iov_push_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x36dfce73	vringh_complete_multi_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x3eaf442a	vringh_abandon_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x3fa42e4f	vringh_notify_enable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x5dafbd4e	vringh_init_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x66af098b	vringh_notify_enable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x6d0e7948	vringh_abandon_user
++EXPORT_SYMBOL drivers/vhost/vringh 0x7bda5e6d	vringh_iov_push_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0x821e9390	vringh_iov_pull_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xaf8e4a0e	vringh_notify_disable_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xafb47dae	vringh_need_notify_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc884d704	vringh_notify_disable_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xc8bee0a4	vringh_need_notify_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xd11d2709	vringh_getdesc_kern
++EXPORT_SYMBOL drivers/vhost/vringh 0xda4ea4cc	vringh_complete_user
++EXPORT_SYMBOL drivers/vhost/vringh 0xfc7dcad2	vringh_getdesc_user
++EXPORT_SYMBOL drivers/video/backlight/generic_bl 0x366d19ef	genericbl_limit_intensity
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x45648515	devm_lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0x6ab5e5e3	lcd_device_register
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xaeb2827e	lcd_device_unregister
++EXPORT_SYMBOL drivers/video/backlight/lcd 0xbc86e6da	devm_lcd_device_register
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x0cc3ede5	cyber2000fb_detach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x26b2ddd0	cyber2000fb_attach
++EXPORT_SYMBOL drivers/video/cyber2000fb 0x534b6f18	cyber2000fb_disable_extregs
++EXPORT_SYMBOL drivers/video/cyber2000fb 0xb39f68d1	cyber2000fb_enable_extregs
++EXPORT_SYMBOL drivers/video/macmodes 0x233917d1	mac_vmode_to_var
++EXPORT_SYMBOL drivers/video/macmodes 0xe2304303	mac_map_monitor_sense
++EXPORT_SYMBOL drivers/video/macmodes 0xfa231ed9	mac_find_mode
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0x13d6de21	matroxfb_g450_setpll_cond
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0x82b2282b	matroxfb_g450_setclk
++EXPORT_SYMBOL drivers/video/matrox/g450_pll 0xe02c2da3	g450_mnp2f
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xa0ba3395	DAC1064_global_restore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xace739f9	DAC1064_global_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xf8fa2843	matrox_mystique
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_DAC1064 0xfcff6c54	matrox_G100
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_Ti3026 0xbd3d6287	matrox_millennium
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_accel 0xc3cc706f	matrox_cfbX_init
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x3c3675ce	matroxfb_register_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x8b3ed020	matroxfb_enable_irq
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0x9798857e	matroxfb_wait_for_sync
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_base 0xb0112023	matroxfb_unregister_driver
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0x2c7185ed	matroxfb_g450_shutdown
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_g450 0xf1fd384d	matroxfb_g450_connect
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x183f7552	matroxfb_vgaHWrestore
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x25cf8049	matroxfb_PLL_calcclock
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x27231775	matroxfb_DAC_out
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x4d3917c5	matroxfb_vgaHWinit
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0x56c4a76c	matroxfb_DAC_in
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xcdc90c64	matroxfb_var2my
++EXPORT_SYMBOL drivers/video/matrox/matroxfb_misc 0xd8a4f6d7	matroxfb_read_pins
++EXPORT_SYMBOL drivers/video/mb862xx/mb862xxfb 0x41f847a3	mb862xxfb_init_accel
++EXPORT_SYMBOL drivers/video/output 0x087f1757	video_output_unregister
++EXPORT_SYMBOL drivers/video/output 0xbeeba51d	video_output_register
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x3037658e	sis_malloc
++EXPORT_SYMBOL drivers/video/sis/sisfb 0x454a3cf0	sis_free
++EXPORT_SYMBOL drivers/video/svgalib 0x17f3f471	svga_set_default_seq_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x198a22da	svga_get_tilemax
++EXPORT_SYMBOL drivers/video/svgalib 0x1be6dc30	svga_set_textmode_vga_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x4ab38ef2	svga_set_default_crt_regs
++EXPORT_SYMBOL drivers/video/svgalib 0x53b4dc7d	svga_tileblit
++EXPORT_SYMBOL drivers/video/svgalib 0x579727ae	svga_tilecopy
++EXPORT_SYMBOL drivers/video/svgalib 0x6d6a5274	svga_tilefill
++EXPORT_SYMBOL drivers/video/svgalib 0x6e4adb1e	svga_check_timings
++EXPORT_SYMBOL drivers/video/svgalib 0x7d68c3ec	svga_get_caps
++EXPORT_SYMBOL drivers/video/svgalib 0x80f24d95	svga_wcrt_multi
++EXPORT_SYMBOL drivers/video/svgalib 0x8de63fb4	svga_set_timings
++EXPORT_SYMBOL drivers/video/svgalib 0xd1429fca	svga_wseq_multi
++EXPORT_SYMBOL drivers/video/svgalib 0xd22ca511	svga_set_default_atc_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xdfb99923	svga_tilecursor
++EXPORT_SYMBOL drivers/video/svgalib 0xe28d2a49	svga_set_default_gfx_regs
++EXPORT_SYMBOL drivers/video/svgalib 0xe653e727	svga_settile
++EXPORT_SYMBOL drivers/video/svgalib 0xef774f5d	svga_compute_pll
++EXPORT_SYMBOL drivers/video/svgalib 0xf2db5956	svga_match_format
++EXPORT_SYMBOL drivers/video/syscopyarea 0xee632861	sys_copyarea
++EXPORT_SYMBOL drivers/video/sysfillrect 0x1270337a	sys_fillrect
++EXPORT_SYMBOL drivers/video/sysimgblt 0x324f455d	sys_imageblit
++EXPORT_SYMBOL drivers/video/vgastate 0x686de290	restore_vga
++EXPORT_SYMBOL drivers/video/vgastate 0xe7a2620e	save_vga
++EXPORT_SYMBOL drivers/vme/vme 0x00d7e722	vme_lm_count
++EXPORT_SYMBOL drivers/vme/vme 0x072f901c	vme_master_rmw
++EXPORT_SYMBOL drivers/vme/vme 0x0ec5babe	vme_dma_free
++EXPORT_SYMBOL drivers/vme/vme 0x1aa581a2	vme_lm_request
++EXPORT_SYMBOL drivers/vme/vme 0x1b2dd64a	vme_bus_type
++EXPORT_SYMBOL drivers/vme/vme 0x20df5a3d	vme_dma_pci_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x341b98a0	vme_dma_request
++EXPORT_SYMBOL drivers/vme/vme 0x378ffee0	vme_master_request
++EXPORT_SYMBOL drivers/vme/vme 0x3e95083c	vme_slave_get
++EXPORT_SYMBOL drivers/vme/vme 0x41862ad4	vme_alloc_consistent
++EXPORT_SYMBOL drivers/vme/vme 0x46649cd1	vme_lm_set
++EXPORT_SYMBOL drivers/vme/vme 0x48b99a13	vme_lm_free
++EXPORT_SYMBOL drivers/vme/vme 0x4b33368f	vme_dma_list_free
++EXPORT_SYMBOL drivers/vme/vme 0x4baf35a7	vme_master_get
++EXPORT_SYMBOL drivers/vme/vme 0x535c8308	vme_dma_pattern_attribute
++EXPORT_SYMBOL drivers/vme/vme 0x5aff4177	vme_lm_get
++EXPORT_SYMBOL drivers/vme/vme 0x6d3f97b0	vme_dma_list_exec
++EXPORT_SYMBOL drivers/vme/vme 0x6f3340a7	vme_irq_handler
++EXPORT_SYMBOL drivers/vme/vme 0x7cda8cbe	vme_dma_list_add
++EXPORT_SYMBOL drivers/vme/vme 0x7cf35220	vme_master_free
++EXPORT_SYMBOL drivers/vme/vme 0x7fde2edb	vme_master_read
++EXPORT_SYMBOL drivers/vme/vme 0x80336d93	vme_register_bridge
++EXPORT_SYMBOL drivers/vme/vme 0x8d024626	vme_irq_free
++EXPORT_SYMBOL drivers/vme/vme 0x90695906	vme_free_consistent
++EXPORT_SYMBOL drivers/vme/vme 0x92fa5abb	vme_lm_detach
++EXPORT_SYMBOL drivers/vme/vme 0x95f2db03	vme_slot_get
++EXPORT_SYMBOL drivers/vme/vme 0x9aeb07e8	vme_lm_attach
++EXPORT_SYMBOL drivers/vme/vme 0xa31bdf07	vme_master_set
++EXPORT_SYMBOL drivers/vme/vme 0xa556a616	vme_register_driver
++EXPORT_SYMBOL drivers/vme/vme 0xc03476c7	vme_unregister_bridge
++EXPORT_SYMBOL drivers/vme/vme 0xd797b9a5	vme_master_write
++EXPORT_SYMBOL drivers/vme/vme 0xdd3d6622	vme_irq_generate
++EXPORT_SYMBOL drivers/vme/vme 0xdff905e5	vme_slave_free
++EXPORT_SYMBOL drivers/vme/vme 0xe693a6ce	vme_get_size
++EXPORT_SYMBOL drivers/vme/vme 0xecd6a9ea	vme_slave_request
++EXPORT_SYMBOL drivers/vme/vme 0xef61bd2d	vme_unregister_driver
++EXPORT_SYMBOL drivers/vme/vme 0xefd1624a	vme_dma_free_attribute
++EXPORT_SYMBOL drivers/vme/vme 0xf1f88869	vme_irq_request
++EXPORT_SYMBOL drivers/vme/vme 0xf29d4c09	vme_new_dma_list
++EXPORT_SYMBOL drivers/vme/vme 0xf5a10e25	vme_slave_set
++EXPORT_SYMBOL drivers/vme/vme 0xfacd8e72	vme_dma_vme_attribute
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x2580929b	w1_ds2760_store_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x32667cc9	w1_ds2760_recall_eeprom
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0x886f21a5	w1_ds2760_write
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2760 0xbbaff5d2	w1_ds2760_read
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x0136d4fc	w1_ds2780_io
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2780 0x6ce9488d	w1_ds2780_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0x15adf2a8	w1_ds2781_eeprom_cmd
++EXPORT_SYMBOL drivers/w1/slaves/w1_ds2781 0xa12f0f84	w1_ds2781_io
++EXPORT_SYMBOL drivers/w1/wire 0x7b1f9828	w1_remove_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xccc990e4	w1_unregister_family
++EXPORT_SYMBOL drivers/w1/wire 0xd92174cd	w1_add_master_device
++EXPORT_SYMBOL drivers/w1/wire 0xfc24eb06	w1_register_family
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0x04e133fc	iTCO_vendor_check_noreboot_on
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xa78bd894	iTCO_vendor_pre_set_heartbeat
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xb5f20875	iTCO_vendor_pre_keepalive
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xc4f657bf	iTCO_vendor_pre_stop
++EXPORT_SYMBOL drivers/watchdog/iTCO_vendor_support 0xdc6effc9	iTCO_vendor_pre_start
++EXPORT_SYMBOL fs/btrfs/btrfs 0x27476846	ulist_reinit
++EXPORT_SYMBOL fs/btrfs/btrfs 0x41e6a9d2	ulist_init
++EXPORT_SYMBOL fs/btrfs/btrfs 0x7e2ee765	ulist_free
++EXPORT_SYMBOL fs/btrfs/btrfs 0xa2eec2e8	ulist_fini
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb1320bc8	ulist_add
++EXPORT_SYMBOL fs/btrfs/btrfs 0xb42289d2	ulist_alloc
++EXPORT_SYMBOL fs/btrfs/btrfs 0xc2c745db	ulist_next
++EXPORT_SYMBOL fs/configfs/configfs 0x1789e655	config_item_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0x1d96879b	configfs_depend_item
++EXPORT_SYMBOL fs/configfs/configfs 0x435eee56	config_group_find_item
++EXPORT_SYMBOL fs/configfs/configfs 0x7bfa2c0f	config_group_init
++EXPORT_SYMBOL fs/configfs/configfs 0x9338e7b8	config_item_set_name
++EXPORT_SYMBOL fs/configfs/configfs 0x9db859f0	config_item_init
++EXPORT_SYMBOL fs/configfs/configfs 0xa19f088a	configfs_unregister_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xa8977019	configfs_register_subsystem
++EXPORT_SYMBOL fs/configfs/configfs 0xad09b486	config_group_init_type_name
++EXPORT_SYMBOL fs/configfs/configfs 0xbca54a60	config_item_get
++EXPORT_SYMBOL fs/configfs/configfs 0xf39de2f6	configfs_undepend_item
++EXPORT_SYMBOL fs/configfs/configfs 0xf3e9a433	config_item_put
++EXPORT_SYMBOL fs/exofs/libore 0x011500ad	ore_calc_stripe_info
++EXPORT_SYMBOL fs/exofs/libore 0x141d7fa4	ore_write
++EXPORT_SYMBOL fs/exofs/libore 0x14e7d3b1	ore_put_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x17491603	ore_get_io_state
++EXPORT_SYMBOL fs/exofs/libore 0x1d82f070	ore_remove
++EXPORT_SYMBOL fs/exofs/libore 0x28806871	ore_verify_layout
++EXPORT_SYMBOL fs/exofs/libore 0x472966bc	ore_create
++EXPORT_SYMBOL fs/exofs/libore 0x6502a527	ore_truncate
++EXPORT_SYMBOL fs/exofs/libore 0x80d99440	extract_attr_from_ios
++EXPORT_SYMBOL fs/exofs/libore 0x9d95bb38	ore_read
++EXPORT_SYMBOL fs/exofs/libore 0xa0eb6fd7	ore_get_rw_state
++EXPORT_SYMBOL fs/exofs/libore 0xa3d2a634	g_attr_logical_length
++EXPORT_SYMBOL fs/exofs/libore 0xee869f5c	ore_check_io
++EXPORT_SYMBOL fs/fscache/fscache 0x003fe8e0	fscache_add_cache
++EXPORT_SYMBOL fs/fscache/fscache 0x020cfca2	__fscache_write_page
++EXPORT_SYMBOL fs/fscache/fscache 0x02adf400	__fscache_register_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x098da311	fscache_mark_pages_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x14be9008	__fscache_acquire_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x1617157c	fscache_mark_page_cached
++EXPORT_SYMBOL fs/fscache/fscache 0x29b83a35	__fscache_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0x2ea14e05	fscache_cache_cleared_wq
++EXPORT_SYMBOL fs/fscache/fscache 0x2fda6396	__fscache_unregister_netfs
++EXPORT_SYMBOL fs/fscache/fscache 0x37a0cfb2	__fscache_relinquish_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x41cd7267	fscache_put_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x525e6456	fscache_object_lookup_negative
++EXPORT_SYMBOL fs/fscache/fscache 0x55d14bfa	__fscache_attr_changed
++EXPORT_SYMBOL fs/fscache/fscache 0x591cd4e1	fscache_fsdef_index
++EXPORT_SYMBOL fs/fscache/fscache 0x5ee83ffc	__fscache_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0x6640127e	__fscache_update_cookie
++EXPORT_SYMBOL fs/fscache/fscache 0x74530ecd	fscache_op_debug_id
++EXPORT_SYMBOL fs/fscache/fscache 0x75070181	fscache_enqueue_operation
++EXPORT_SYMBOL fs/fscache/fscache 0x7bdc9824	__fscache_maybe_release_page
++EXPORT_SYMBOL fs/fscache/fscache 0x85dac3e0	fscache_object_destroy
++EXPORT_SYMBOL fs/fscache/fscache 0xa0d7676d	fscache_obtained_object
++EXPORT_SYMBOL fs/fscache/fscache 0xa82fd18a	__fscache_read_or_alloc_page
++EXPORT_SYMBOL fs/fscache/fscache 0xa873df0e	fscache_check_aux
++EXPORT_SYMBOL fs/fscache/fscache 0xad9b7cae	__fscache_check_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xb0d90933	fscache_object_init
++EXPORT_SYMBOL fs/fscache/fscache 0xb4bf5c5a	__fscache_wait_on_page_write
++EXPORT_SYMBOL fs/fscache/fscache 0xc9d2b2f6	__fscache_uncache_page
++EXPORT_SYMBOL fs/fscache/fscache 0xca03131d	fscache_withdraw_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xcb9f7eae	fscache_io_error
++EXPORT_SYMBOL fs/fscache/fscache 0xdc31b6c1	__fscache_wait_on_invalidate
++EXPORT_SYMBOL fs/fscache/fscache 0xf1a9f44b	fscache_init_cache
++EXPORT_SYMBOL fs/fscache/fscache 0xf2dce727	__fscache_uncache_all_inode_pages
++EXPORT_SYMBOL fs/fscache/fscache 0xfcf2a0a7	fscache_op_complete
++EXPORT_SYMBOL fs/fscache/fscache 0xff07515e	__fscache_read_or_alloc_pages
++EXPORT_SYMBOL fs/nfsd/nfsd 0x040ea5a0	nfs4_acl_nfsv4_to_posix
++EXPORT_SYMBOL fs/nfsd/nfsd 0x35e33c1e	nfs4_acl_write_who
++EXPORT_SYMBOL fs/nfsd/nfsd 0x5a157ae4	nfs4_acl_get_whotype
++EXPORT_SYMBOL fs/nfsd/nfsd 0xcb152562	nfs4_acl_posix_to_nfsv4
++EXPORT_SYMBOL fs/nfsd/nfsd 0xda45bc09	nfs4_acl_new
++EXPORT_SYMBOL fs/ocfs2/cluster/ocfs2_nodemanager 0xbfd7d7a2	o2hb_global_heartbeat_active
++EXPORT_SYMBOL fs/quota/quota_tree 0x8594a882	qtree_read_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0x99aea400	qtree_release_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xc0ad2286	qtree_entry_unused
++EXPORT_SYMBOL fs/quota/quota_tree 0xc16aa7d3	qtree_delete_dquot
++EXPORT_SYMBOL fs/quota/quota_tree 0xfe9f28e8	qtree_write_dquot
++EXPORT_SYMBOL lib/cordic 0x434bfd07	cordic_calc_iq
++EXPORT_SYMBOL lib/crc-ccitt 0x3771b461	crc_ccitt
++EXPORT_SYMBOL lib/crc-ccitt 0x75811312	crc_ccitt_table
++EXPORT_SYMBOL lib/crc-itu-t 0xd29b009f	crc_itu_t_table
++EXPORT_SYMBOL lib/crc-itu-t 0xf5b4a948	crc_itu_t
++EXPORT_SYMBOL lib/crc7 0xa7587646	crc7
++EXPORT_SYMBOL lib/crc7 0xd80c3603	crc7_syndrome_table
++EXPORT_SYMBOL lib/crc8 0x41248eaf	crc8
++EXPORT_SYMBOL lib/crc8 0xab9ad613	crc8_populate_lsb
++EXPORT_SYMBOL lib/crc8 0xd4534d80	crc8_populate_msb
++EXPORT_SYMBOL lib/libcrc32c 0x27000b29	crc32c
++EXPORT_SYMBOL lib/lru_cache 0x06b1da19	lc_try_lock
++EXPORT_SYMBOL lib/lru_cache 0x0896848f	lc_create
++EXPORT_SYMBOL lib/lru_cache 0x0fe4b27d	lc_set
++EXPORT_SYMBOL lib/lru_cache 0x272df302	lc_destroy
++EXPORT_SYMBOL lib/lru_cache 0x33764850	lc_seq_printf_stats
++EXPORT_SYMBOL lib/lru_cache 0x45c3e110	lc_element_by_index
++EXPORT_SYMBOL lib/lru_cache 0x45e23e92	lc_committed
++EXPORT_SYMBOL lib/lru_cache 0x472a0e3c	lc_put
++EXPORT_SYMBOL lib/lru_cache 0x58b1b3d4	lc_seq_dump_details
++EXPORT_SYMBOL lib/lru_cache 0x60ff7fa6	lc_is_used
++EXPORT_SYMBOL lib/lru_cache 0x7d5aafef	lc_find
++EXPORT_SYMBOL lib/lru_cache 0x9352366b	lc_del
++EXPORT_SYMBOL lib/lru_cache 0x9ed82b8f	lc_try_get
++EXPORT_SYMBOL lib/lru_cache 0x9fa08233	lc_reset
++EXPORT_SYMBOL lib/lru_cache 0xbb48a66f	lc_index_of
++EXPORT_SYMBOL lib/lru_cache 0xce0b3dc0	lc_get_cumulative
++EXPORT_SYMBOL lib/lru_cache 0xdfbce8c7	lc_get
++EXPORT_SYMBOL lib/lz4/lz4_compress 0xcbc5d521	lz4_compress
++EXPORT_SYMBOL lib/lz4/lz4hc_compress 0x26c3aa22	lz4hc_compress
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x0bd662f6	raid6_gfmul
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x15fe0cd3	raid6_gfexp
++EXPORT_SYMBOL lib/raid6/raid6_pq 0x5ba93f9d	raid6_gfinv
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xb0d904b7	raid6_empty_zero_page
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xce45a6f1	raid6_gfexi
++EXPORT_SYMBOL lib/raid6/raid6_pq 0xd9e91f83	raid6_vgfmul
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x315c65fd	zlib_deflateInit2
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0x48034724	zlib_deflateReset
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xaf64ad0d	zlib_deflate
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xe9f7149c	zlib_deflate_workspacesize
++EXPORT_SYMBOL lib/zlib_deflate/zlib_deflate 0xf741c793	zlib_deflateEnd
++EXPORT_SYMBOL net/802/p8022 0xd97eae2c	register_8022_client
++EXPORT_SYMBOL net/802/p8022 0xec65688d	unregister_8022_client
++EXPORT_SYMBOL net/802/p8023 0x03f48fca	make_8023_client
++EXPORT_SYMBOL net/802/p8023 0x79a1de79	destroy_8023_client
++EXPORT_SYMBOL net/802/psnap 0x0083449d	unregister_snap_client
++EXPORT_SYMBOL net/802/psnap 0xcefef35a	register_snap_client
++EXPORT_SYMBOL net/9p/9pnet 0x10b39abb	p9_client_fcreate
++EXPORT_SYMBOL net/9p/9pnet 0x167f29b8	p9_client_create
++EXPORT_SYMBOL net/9p/9pnet 0x1a37c7e9	p9_parse_header
++EXPORT_SYMBOL net/9p/9pnet 0x1d2245f9	p9_client_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x2845e2e3	p9_client_rename
++EXPORT_SYMBOL net/9p/9pnet 0x33e225ad	v9fs_unregister_trans
++EXPORT_SYMBOL net/9p/9pnet 0x341b09c2	v9fs_register_trans
++EXPORT_SYMBOL net/9p/9pnet 0x35d1e27e	p9_idpool_get
++EXPORT_SYMBOL net/9p/9pnet 0x3b269690	p9_client_wstat
++EXPORT_SYMBOL net/9p/9pnet 0x3c4eee23	p9_client_getlock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x3d73a797	p9_errstr2errno
++EXPORT_SYMBOL net/9p/9pnet 0x44974e91	p9_client_walk
++EXPORT_SYMBOL net/9p/9pnet 0x46fabfec	p9_client_readdir
++EXPORT_SYMBOL net/9p/9pnet 0x4e060ed8	p9stat_free
++EXPORT_SYMBOL net/9p/9pnet 0x50ed5748	p9_client_statfs
++EXPORT_SYMBOL net/9p/9pnet 0x51cd9d18	p9_client_mkdir_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x60da0df3	p9_client_read
++EXPORT_SYMBOL net/9p/9pnet 0x675c58fe	v9fs_get_trans_by_name
++EXPORT_SYMBOL net/9p/9pnet 0x69bbcc19	p9_client_remove
++EXPORT_SYMBOL net/9p/9pnet 0x6b7345f7	p9_client_link
++EXPORT_SYMBOL net/9p/9pnet 0x6b836fdd	p9_tag_lookup
++EXPORT_SYMBOL net/9p/9pnet 0x6e38ffd5	p9_client_attach
++EXPORT_SYMBOL net/9p/9pnet 0x7282c59a	p9_client_getattr_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x75481666	p9_client_clunk
++EXPORT_SYMBOL net/9p/9pnet 0x78bff6cf	p9_client_cb
++EXPORT_SYMBOL net/9p/9pnet 0x83dab2e6	p9_client_setattr
++EXPORT_SYMBOL net/9p/9pnet 0x84416cfc	p9_client_lock_dotl
++EXPORT_SYMBOL net/9p/9pnet 0x8cc3968a	p9_client_unlinkat
++EXPORT_SYMBOL net/9p/9pnet 0x8cf064da	v9fs_get_default_trans
++EXPORT_SYMBOL net/9p/9pnet 0x8db62dd2	p9_release_pages
++EXPORT_SYMBOL net/9p/9pnet 0x9002e090	p9_client_begin_disconnect
++EXPORT_SYMBOL net/9p/9pnet 0x977a0030	p9_nr_pages
++EXPORT_SYMBOL net/9p/9pnet 0xa0a24aa2	p9stat_read
++EXPORT_SYMBOL net/9p/9pnet 0xb5ea9ce2	p9_payload_gup
++EXPORT_SYMBOL net/9p/9pnet 0xba4c78c3	p9_client_fsync
++EXPORT_SYMBOL net/9p/9pnet 0xc3990127	p9_client_mknod_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xc5db54a9	p9_idpool_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xc8c5fe6b	p9_client_stat
++EXPORT_SYMBOL net/9p/9pnet 0xca782ad4	p9_is_proto_dotu
++EXPORT_SYMBOL net/9p/9pnet 0xcd2723e6	p9_is_proto_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xd1427e97	p9_client_write
++EXPORT_SYMBOL net/9p/9pnet 0xd3df4a3c	p9_client_destroy
++EXPORT_SYMBOL net/9p/9pnet 0xd8eda45e	p9dirent_read
++EXPORT_SYMBOL net/9p/9pnet 0xdb3d861d	p9_client_create_dotl
++EXPORT_SYMBOL net/9p/9pnet 0xe4e7e347	p9_client_open
++EXPORT_SYMBOL net/9p/9pnet 0xe5734c19	p9_client_renameat
++EXPORT_SYMBOL net/9p/9pnet 0xe58a3360	p9_error_init
++EXPORT_SYMBOL net/9p/9pnet 0xefd9429b	p9_client_symlink
++EXPORT_SYMBOL net/9p/9pnet 0xf4a111d8	p9_idpool_create
++EXPORT_SYMBOL net/9p/9pnet 0xf84f2022	p9_idpool_put
++EXPORT_SYMBOL net/9p/9pnet 0xfd40c79d	p9_idpool_check
++EXPORT_SYMBOL net/9p/9pnet 0xfe475ebd	p9_client_readlink
++EXPORT_SYMBOL net/appletalk/appletalk 0x6ac38cdb	alloc_ltalkdev
++EXPORT_SYMBOL net/appletalk/appletalk 0x84ee499b	aarp_send_ddp
++EXPORT_SYMBOL net/appletalk/appletalk 0xb7b4c294	atalk_find_dev_addr
++EXPORT_SYMBOL net/appletalk/appletalk 0xd737477d	atrtr_get_dev
++EXPORT_SYMBOL net/atm/atm 0x0413e051	vcc_release_async
++EXPORT_SYMBOL net/atm/atm 0x238464f6	atm_dev_deregister
++EXPORT_SYMBOL net/atm/atm 0x2cc2d52d	vcc_hash
++EXPORT_SYMBOL net/atm/atm 0x4443d399	atm_proc_root
++EXPORT_SYMBOL net/atm/atm 0x535d22ae	register_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x58e23248	vcc_process_recv_queue
++EXPORT_SYMBOL net/atm/atm 0x5d80e2cf	atm_dev_release_vccs
++EXPORT_SYMBOL net/atm/atm 0x65c0f1da	atm_charge
++EXPORT_SYMBOL net/atm/atm 0x6768f781	deregister_atm_ioctl
++EXPORT_SYMBOL net/atm/atm 0x6fee295b	atm_dev_signal_change
++EXPORT_SYMBOL net/atm/atm 0x730c4a4e	atm_alloc_charge
++EXPORT_SYMBOL net/atm/atm 0x875c2b74	atm_init_aal5
++EXPORT_SYMBOL net/atm/atm 0x93136f41	vcc_sklist_lock
++EXPORT_SYMBOL net/atm/atm 0x959ccb13	vcc_insert_socket
++EXPORT_SYMBOL net/atm/atm 0x9feaf287	sonet_subtract_stats
++EXPORT_SYMBOL net/atm/atm 0xaa024146	sonet_copy_stats
++EXPORT_SYMBOL net/atm/atm 0xaf1af4ed	atm_dev_lookup
++EXPORT_SYMBOL net/atm/atm 0xbef749e7	atm_dev_register
++EXPORT_SYMBOL net/atm/atm 0xf49bc67a	atm_pcr_goal
++EXPORT_SYMBOL net/ax25/ax25 0x026c1368	ax25_display_timer
++EXPORT_SYMBOL net/ax25/ax25 0x13e0d5e8	ax25_findbyuid
++EXPORT_SYMBOL net/ax25/ax25 0x242852b9	ax25_uid_policy
++EXPORT_SYMBOL net/ax25/ax25 0x31dd0edb	ax25_listen_register
++EXPORT_SYMBOL net/ax25/ax25 0x4502c65a	asc2ax
++EXPORT_SYMBOL net/ax25/ax25 0x53dea1ff	ax2asc
++EXPORT_SYMBOL net/ax25/ax25 0x775392d0	ax25_send_frame
++EXPORT_SYMBOL net/ax25/ax25 0x7f6d60d5	ax25_find_cb
++EXPORT_SYMBOL net/ax25/ax25 0x8ede9e26	ax25_protocol_release
++EXPORT_SYMBOL net/ax25/ax25 0xbbae1f7d	ax25_hard_header
++EXPORT_SYMBOL net/ax25/ax25 0xbf593d21	ax25_linkfail_release
++EXPORT_SYMBOL net/ax25/ax25 0xc0c0cc35	ax25_rebuild_header
++EXPORT_SYMBOL net/ax25/ax25 0xc1444946	ax25cmp
++EXPORT_SYMBOL net/ax25/ax25 0xca5e2599	ax25_header_ops
++EXPORT_SYMBOL net/ax25/ax25 0xd43ecbf1	null_ax25_address
++EXPORT_SYMBOL net/ax25/ax25 0xdda77960	ax25_listen_release
++EXPORT_SYMBOL net/ax25/ax25 0xfd143dd1	ax25_linkfail_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x08b74369	l2cap_unregister_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1051a25c	bt_accept_dequeue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x18b63af7	hci_unregister_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x1be48295	bt_sock_link
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x22dd9ecd	l2cap_register_user
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x285a57bd	bt_procfs_init
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2cbcc7ac	hci_unregister_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x2d222d3a	hci_conn_security
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x3304c69f	bt_sock_reclassify_lock
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x453b84cd	__hci_cmd_sync_ev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x56c05abf	l2cap_conn_put
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x59ae4db4	bt_sock_ioctl
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6125adaa	hci_suspend_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x690455b2	hci_conn_switch_role
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x697064a0	l2cap_conn_get
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x6fa31001	__hci_cmd_sync
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x7c640527	bt_info
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x858a1447	hci_recv_stream_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x86d4d817	hci_get_route
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8a424685	bt_accept_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x8fea24bd	bt_sock_unregister
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x91c9a325	bt_to_errno
++EXPORT_SYMBOL net/bluetooth/bluetooth 0x93f41d44	bt_sock_stream_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa1ff3907	l2cap_is_socket
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa35e464c	hci_resume_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xa5191d62	hci_register_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb13b9d2c	hci_register_cb
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb143b951	bt_sock_recvmsg
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb1489465	bt_sock_wait_state
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb3c6a51b	bt_sock_poll
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb61a0c3b	bt_err
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb6333c0b	bt_accept_enqueue
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xb8732327	bt_procfs_cleanup
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbe37e5ae	bt_sock_register
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xbee3b179	hci_free_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcb446c7c	hci_recv_fragment
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xcc1fb551	baswap
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xd9e753e8	hci_conn_check_secure
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xe6933f17	bt_sock_unlink
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xef490e7f	hci_alloc_dev
++EXPORT_SYMBOL net/bluetooth/bluetooth 0xf013895c	hci_recv_frame
++EXPORT_SYMBOL net/bridge/bridge 0x06494fa6	br_should_route_hook
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x2ea1cd45	ebt_unregister_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0x3067c7cb	ebt_do_table
++EXPORT_SYMBOL net/bridge/netfilter/ebtables 0xf80283b2	ebt_register_table
++EXPORT_SYMBOL net/caif/caif 0x1446b60a	caif_client_register_refcnt
++EXPORT_SYMBOL net/caif/caif 0x2a09f713	cfpkt_fromnative
++EXPORT_SYMBOL net/caif/caif 0x329dbd06	cfpkt_info
++EXPORT_SYMBOL net/caif/caif 0x38701a7c	cfcnfg_del_phy_layer
++EXPORT_SYMBOL net/caif/caif 0x4a237e57	cfpkt_tonative
++EXPORT_SYMBOL net/caif/caif 0x5b7b3f29	caif_disconnect_client
++EXPORT_SYMBOL net/caif/caif 0x6a44fc70	cfpkt_extr_head
++EXPORT_SYMBOL net/caif/caif 0x70097abd	caif_connect_client
++EXPORT_SYMBOL net/caif/caif 0x839ddb7b	cfcnfg_set_phy_state
++EXPORT_SYMBOL net/caif/caif 0x966d7de2	cfpkt_add_head
++EXPORT_SYMBOL net/caif/caif 0x9e3e305d	cfpkt_set_prio
++EXPORT_SYMBOL net/caif/caif 0x9ea677e9	caif_enroll_dev
++EXPORT_SYMBOL net/caif/caif 0xb7b6874e	caif_free_client
++EXPORT_SYMBOL net/caif/caif 0xbb47e77c	get_cfcnfg
++EXPORT_SYMBOL net/caif/caif 0xc30a2776	cfcnfg_add_phy_layer
++EXPORT_SYMBOL net/can/can 0x030caf5b	can_rx_register
++EXPORT_SYMBOL net/can/can 0x594df0a4	can_proto_register
++EXPORT_SYMBOL net/can/can 0x850397cc	can_ioctl
++EXPORT_SYMBOL net/can/can 0xbe59da72	can_rx_unregister
++EXPORT_SYMBOL net/can/can 0xd02b2186	can_proto_unregister
++EXPORT_SYMBOL net/can/can 0xeff75cb6	can_send
++EXPORT_SYMBOL net/ceph/libceph 0x00756950	ceph_osdc_writepages
++EXPORT_SYMBOL net/ceph/libceph 0x0158165d	ceph_monc_got_mdsmap
++EXPORT_SYMBOL net/ceph/libceph 0x0606ad60	ceph_con_init
++EXPORT_SYMBOL net/ceph/libceph 0x07b1377b	ceph_put_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x09290ab3	ceph_debugfs_init
++EXPORT_SYMBOL net/ceph/libceph 0x09b3a7ec	osd_req_op_cls_request_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x0ff21788	ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x10940306	ceph_pagelist_set_cursor
++EXPORT_SYMBOL net/ceph/libceph 0x1475bf0d	ceph_pg_poolid_by_name
++EXPORT_SYMBOL net/ceph/libceph 0x1517eea1	ceph_destroy_client
++EXPORT_SYMBOL net/ceph/libceph 0x163f7cc7	osd_req_op_extent_osd_data_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x18de9145	ceph_client_id
++EXPORT_SYMBOL net/ceph/libceph 0x197effcb	ceph_osdc_release_request
++EXPORT_SYMBOL net/ceph/libceph 0x1bf0cf04	ceph_con_send
++EXPORT_SYMBOL net/ceph/libceph 0x20d151cb	ceph_osdc_setup
++EXPORT_SYMBOL net/ceph/libceph 0x23b51024	osd_req_op_extent_osd_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x2484de05	ceph_auth_update_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x25831487	osd_req_op_extent_osd_data
++EXPORT_SYMBOL net/ceph/libceph 0x2616e3b5	ceph_auth_create_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x28c4b85b	ceph_con_close
++EXPORT_SYMBOL net/ceph/libceph 0x30bc7523	ceph_auth_is_authenticated
++EXPORT_SYMBOL net/ceph/libceph 0x3158173e	ceph_pagelist_release
++EXPORT_SYMBOL net/ceph/libceph 0x34a64292	ceph_messenger_init
++EXPORT_SYMBOL net/ceph/libceph 0x34bc2b34	osd_req_op_cls_response_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x36d86121	ceph_create_client
++EXPORT_SYMBOL net/ceph/libceph 0x3796f725	osd_req_op_extent_init
++EXPORT_SYMBOL net/ceph/libceph 0x3abec91f	ceph_pr_addr
++EXPORT_SYMBOL net/ceph/libceph 0x3c925aa4	ceph_monc_validate_auth
++EXPORT_SYMBOL net/ceph/libceph 0x3df0ec7c	ceph_calc_ceph_pg
++EXPORT_SYMBOL net/ceph/libceph 0x3ebfd863	ceph_con_keepalive
++EXPORT_SYMBOL net/ceph/libceph 0x3f688151	ceph_put_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x40c033c2	ceph_monc_init
++EXPORT_SYMBOL net/ceph/libceph 0x4205ffd7	ceph_destroy_options
++EXPORT_SYMBOL net/ceph/libceph 0x427dee8d	ceph_monc_stop
++EXPORT_SYMBOL net/ceph/libceph 0x438b7424	ceph_osdc_start_request
++EXPORT_SYMBOL net/ceph/libceph 0x43c8d341	ceph_buffer_new
++EXPORT_SYMBOL net/ceph/libceph 0x43e458f6	ceph_file_part
++EXPORT_SYMBOL net/ceph/libceph 0x43efd647	ceph_calc_file_object_mapping
++EXPORT_SYMBOL net/ceph/libceph 0x466b85b8	libceph_compatible
++EXPORT_SYMBOL net/ceph/libceph 0x46a9092c	osd_req_op_extent_update
++EXPORT_SYMBOL net/ceph/libceph 0x48765128	ceph_monc_open_session
++EXPORT_SYMBOL net/ceph/libceph 0x4a4affb3	osd_req_op_cls_request_data_pages
++EXPORT_SYMBOL net/ceph/libceph 0x4c1b872a	ceph_osdc_cancel_event
++EXPORT_SYMBOL net/ceph/libceph 0x4dbef8bb	ceph_alloc_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x502a3091	ceph_monc_create_snapid
++EXPORT_SYMBOL net/ceph/libceph 0x5379cea3	ceph_caps_for_mode
++EXPORT_SYMBOL net/ceph/libceph 0x57baf885	ceph_str_hash
++EXPORT_SYMBOL net/ceph/libceph 0x58c40a39	ceph_con_open
++EXPORT_SYMBOL net/ceph/libceph 0x599f907d	osd_req_op_cls_init
++EXPORT_SYMBOL net/ceph/libceph 0x59fe91f1	ceph_auth_verify_authorizer_reply
++EXPORT_SYMBOL net/ceph/libceph 0x5ae4ba6c	ceph_zero_page_vector_range
++EXPORT_SYMBOL net/ceph/libceph 0x5fe4b2fa	ceph_pagelist_truncate
++EXPORT_SYMBOL net/ceph/libceph 0x63758856	ceph_str_hash_name
++EXPORT_SYMBOL net/ceph/libceph 0x646647d2	ceph_get_direct_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x656059d1	ceph_release_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x65e013a2	ceph_copy_page_vector_to_user
++EXPORT_SYMBOL net/ceph/libceph 0x6b2e3bcd	ceph_get_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0x6b97dd94	osd_req_op_cls_response_data
++EXPORT_SYMBOL net/ceph/libceph 0x6c2939b7	ceph_osdc_create_event
++EXPORT_SYMBOL net/ceph/libceph 0x6c5d5ac1	ceph_calc_pg_primary
++EXPORT_SYMBOL net/ceph/libceph 0x6d2d06a1	ceph_pagelist_reserve
++EXPORT_SYMBOL net/ceph/libceph 0x6ed41be2	ceph_pagelist_append
++EXPORT_SYMBOL net/ceph/libceph 0x74cc74a6	ceph_msg_data_add_pagelist
++EXPORT_SYMBOL net/ceph/libceph 0x74cca408	osd_req_op_init
++EXPORT_SYMBOL net/ceph/libceph 0x77692acb	ceph_msg_last_put
++EXPORT_SYMBOL net/ceph/libceph 0x7b2fd296	ceph_auth_invalidate_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0x7bd553b2	ceph_osdc_new_request
++EXPORT_SYMBOL net/ceph/libceph 0x8222d4c6	ceph_osdc_unregister_linger_request
++EXPORT_SYMBOL net/ceph/libceph 0x836d7913	ceph_monc_do_statfs
++EXPORT_SYMBOL net/ceph/libceph 0x855d8d81	ceph_copy_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0x87b2cd34	ceph_osdc_alloc_request
++EXPORT_SYMBOL net/ceph/libceph 0x99e36571	ceph_osdc_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0x9f534f4d	ceph_buffer_release
++EXPORT_SYMBOL net/ceph/libceph 0xa344b9f1	ceph_check_fsid
++EXPORT_SYMBOL net/ceph/libceph 0xa40bd703	ceph_pagelist_free_reserve
++EXPORT_SYMBOL net/ceph/libceph 0xa6e31a05	osd_req_op_raw_data_in_pages
++EXPORT_SYMBOL net/ceph/libceph 0xa9d6bae4	ceph_auth_destroy_authorizer
++EXPORT_SYMBOL net/ceph/libceph 0xad7b8dae	ceph_osdc_readpages
++EXPORT_SYMBOL net/ceph/libceph 0xae3515ba	ceph_create_snap_context
++EXPORT_SYMBOL net/ceph/libceph 0xafb8a407	ceph_msgr_flush
++EXPORT_SYMBOL net/ceph/libceph 0xb219f721	ceph_osdc_set_request_linger
++EXPORT_SYMBOL net/ceph/libceph 0xb54676fa	ceph_msg_type_name
++EXPORT_SYMBOL net/ceph/libceph 0xb6081d6d	ceph_msgr_exit
++EXPORT_SYMBOL net/ceph/libceph 0xb9d62a9e	ceph_msg_data_add_pages
++EXPORT_SYMBOL net/ceph/libceph 0xbdbc408e	ceph_msg_dump
++EXPORT_SYMBOL net/ceph/libceph 0xc461a2c0	ceph_osdc_wait_request
++EXPORT_SYMBOL net/ceph/libceph 0xc4a80955	ceph_debugfs_cleanup
++EXPORT_SYMBOL net/ceph/libceph 0xc55de604	ceph_parse_options
++EXPORT_SYMBOL net/ceph/libceph 0xc7a0b1ff	ceph_msg_new
++EXPORT_SYMBOL net/ceph/libceph 0xc9f82b38	ceph_msgr_init
++EXPORT_SYMBOL net/ceph/libceph 0xcb50a624	ceph_parse_ips
++EXPORT_SYMBOL net/ceph/libceph 0xd2c107bb	ceph_flags_to_mode
++EXPORT_SYMBOL net/ceph/libceph 0xd98cb3f2	osd_req_op_watch_init
++EXPORT_SYMBOL net/ceph/libceph 0xde5af025	ceph_osdc_build_request
++EXPORT_SYMBOL net/ceph/libceph 0xe6996cff	ceph_compare_options
++EXPORT_SYMBOL net/ceph/libceph 0xe7073f3f	ceph_osdc_put_event
++EXPORT_SYMBOL net/ceph/libceph 0xe82c9c32	ceph_pg_pool_name_by_id
++EXPORT_SYMBOL net/ceph/libceph 0xe957519a	__ceph_open_session
++EXPORT_SYMBOL net/ceph/libceph 0xead44a73	ceph_msg_data_add_bio
++EXPORT_SYMBOL net/ceph/libceph 0xebb0babf	ceph_copy_user_to_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xf540c958	osd_req_op_extent_osd_data_bio
++EXPORT_SYMBOL net/ceph/libceph 0xf5540411	ceph_copy_from_page_vector
++EXPORT_SYMBOL net/ceph/libceph 0xfdea40a7	ceph_osdc_sync
++EXPORT_SYMBOL net/dccp/dccp_ipv4 0x8cf279a2	dccp_syn_ack_timeout
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1165ccc3	wpan_phy_for_each
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x15b6c50f	wpan_phy_unregister
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1776eeaa	wpan_phy_register
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x1a58fe87	ieee802154_nl_scan_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x336eeb69	ieee802154_nl_disassoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x400ba74f	wpan_phy_free
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x5f79c1e8	ieee802154_nl_assoc_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x6a28eb71	ieee802154_nl_start_confirm
++EXPORT_SYMBOL net/ieee802154/ieee802154 0x8f3da785	ieee802154_nl_disassoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xc1feb2d4	ieee802154_nl_beacon_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xcc713ae4	ieee802154_nl_assoc_indic
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xd303f57d	wpan_phy_find
++EXPORT_SYMBOL net/ieee802154/ieee802154 0xe380f941	wpan_phy_alloc
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x09c3d459	arpt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0x1a995a43	arpt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/arp_tables 0xca6120ef	arpt_unregister_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x0183aaf9	ipt_register_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0x235b5c3d	ipt_do_table
++EXPORT_SYMBOL net/ipv4/netfilter/ip_tables 0xd09c8b10	ipt_unregister_table
++EXPORT_SYMBOL net/ipv4/tunnel4 0xa3af8043	xfrm4_tunnel_register
++EXPORT_SYMBOL net/ipv4/tunnel4 0xcf7416f5	xfrm4_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x3725a8d6	ip6_tnl_get_cap
++EXPORT_SYMBOL net/ipv6/ip6_tunnel 0x9a1bd38e	ip6_tnl_parse_tlv_enc_lim
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x4b5858ba	ip6t_register_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x67818f4c	ip6t_unregister_table
++EXPORT_SYMBOL net/ipv6/netfilter/ip6_tables 0x7beb8e97	ip6t_do_table
++EXPORT_SYMBOL net/ipv6/tunnel6 0x0cadbc27	xfrm6_tunnel_deregister
++EXPORT_SYMBOL net/ipv6/tunnel6 0xd22ee898	xfrm6_tunnel_register
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0x84f94906	xfrm6_tunnel_alloc_spi
++EXPORT_SYMBOL net/ipv6/xfrm6_tunnel 0xd0d55566	xfrm6_tunnel_spi_lookup
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x09bd29db	ircomm_disconnect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x333b2d91	ircomm_control_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x38ccf9cb	ircomm_data_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x72d1aee2	ircomm_connect_response
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x8579d4fa	ircomm_connect_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0x9d06f71c	ircomm_close
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xd6503a73	ircomm_flow_request
++EXPORT_SYMBOL net/irda/ircomm/ircomm 0xf5f0fc80	ircomm_open
++EXPORT_SYMBOL net/irda/irda 0x015714a4	irlmp_open_lsap
++EXPORT_SYMBOL net/irda/irda 0x01dbeb0e	irias_delete_object
++EXPORT_SYMBOL net/irda/irda 0x03be1420	irttp_open_tsap
++EXPORT_SYMBOL net/irda/irda 0x06a3ee58	irias_new_integer_value
++EXPORT_SYMBOL net/irda/irda 0x07d3647c	irlmp_register_service
++EXPORT_SYMBOL net/irda/irda 0x0bab6037	hashbin_remove
++EXPORT_SYMBOL net/irda/irda 0x10dca1a4	iriap_open
++EXPORT_SYMBOL net/irda/irda 0x2036ad06	irda_param_insert
++EXPORT_SYMBOL net/irda/irda 0x208d37c1	irttp_udata_request
++EXPORT_SYMBOL net/irda/irda 0x2307e2a1	irlmp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0x23a2eee7	hashbin_remove_this
++EXPORT_SYMBOL net/irda/irda 0x271117e0	irlmp_data_request
++EXPORT_SYMBOL net/irda/irda 0x33cbe2c6	proc_irda
++EXPORT_SYMBOL net/irda/irda 0x359de411	irias_insert_object
++EXPORT_SYMBOL net/irda/irda 0x369b9803	irttp_dup
++EXPORT_SYMBOL net/irda/irda 0x3b02f706	async_wrap_skb
++EXPORT_SYMBOL net/irda/irda 0x3b0a2ab6	irias_find_object
++EXPORT_SYMBOL net/irda/irda 0x3b9bdefe	irias_add_octseq_attrib
++EXPORT_SYMBOL net/irda/irda 0x3effef36	irttp_data_request
++EXPORT_SYMBOL net/irda/irda 0x428321fa	hashbin_get_next
++EXPORT_SYMBOL net/irda/irda 0x448b8aaa	irda_qos_bits_to_value
++EXPORT_SYMBOL net/irda/irda 0x46c1c4a2	irlmp_unregister_service
++EXPORT_SYMBOL net/irda/irda 0x48d17824	irias_add_integer_attrib
++EXPORT_SYMBOL net/irda/irda 0x48deb058	irttp_flow_request
++EXPORT_SYMBOL net/irda/irda 0x62acf28c	irias_add_string_attrib
++EXPORT_SYMBOL net/irda/irda 0x645e5cf6	irlmp_close_lsap
++EXPORT_SYMBOL net/irda/irda 0x648c7478	hashbin_get_first
++EXPORT_SYMBOL net/irda/irda 0x669d7b94	iriap_close
++EXPORT_SYMBOL net/irda/irda 0x6b043eba	irda_init_max_qos_capabilies
++EXPORT_SYMBOL net/irda/irda 0x7042bc54	irlmp_register_client
++EXPORT_SYMBOL net/irda/irda 0x7102f901	async_unwrap_char
++EXPORT_SYMBOL net/irda/irda 0x7237d931	irlmp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x763e54a4	irlmp_unregister_client
++EXPORT_SYMBOL net/irda/irda 0x7957f728	irlmp_update_client
++EXPORT_SYMBOL net/irda/irda 0x7d54adaf	irias_new_object
++EXPORT_SYMBOL net/irda/irda 0x7ff509a2	hashbin_lock_find
++EXPORT_SYMBOL net/irda/irda 0x822b9cc8	alloc_irdadev
++EXPORT_SYMBOL net/irda/irda 0x8cd99be0	hashbin_insert
++EXPORT_SYMBOL net/irda/irda 0x91815586	irda_param_pack
++EXPORT_SYMBOL net/irda/irda 0x993ad14b	irda_param_extract_all
++EXPORT_SYMBOL net/irda/irda 0x9bb24194	irlmp_connect_request
++EXPORT_SYMBOL net/irda/irda 0x9c97465c	irttp_connect_response
++EXPORT_SYMBOL net/irda/irda 0x9e326eb3	hashbin_delete
++EXPORT_SYMBOL net/irda/irda 0xa370c681	hashbin_find
++EXPORT_SYMBOL net/irda/irda 0xa8ea6d8f	irttp_connect_request
++EXPORT_SYMBOL net/irda/irda 0xb9394173	irias_delete_value
++EXPORT_SYMBOL net/irda/irda 0xbcd3ef13	irias_object_change_attribute
++EXPORT_SYMBOL net/irda/irda 0xbe40ace9	irlmp_discovery_request
++EXPORT_SYMBOL net/irda/irda 0xc0bee29c	hashbin_new
++EXPORT_SYMBOL net/irda/irda 0xc6615b8f	irlap_open
++EXPORT_SYMBOL net/irda/irda 0xc96b0ac1	iriap_getvaluebyclass_request
++EXPORT_SYMBOL net/irda/irda 0xd6deeaae	irda_setup_dma
++EXPORT_SYMBOL net/irda/irda 0xd996b33b	irlap_close
++EXPORT_SYMBOL net/irda/irda 0xdbc2387a	irda_device_set_media_busy
++EXPORT_SYMBOL net/irda/irda 0xde4c6b3c	irlmp_service_to_hint
++EXPORT_SYMBOL net/irda/irda 0xe1c99e92	irttp_disconnect_request
++EXPORT_SYMBOL net/irda/irda 0xe3317a3c	irda_notify_init
++EXPORT_SYMBOL net/irda/irda 0xedd521c2	irlmp_get_discoveries
++EXPORT_SYMBOL net/irda/irda 0xee4c4304	irttp_close_tsap
++EXPORT_SYMBOL net/l2tp/l2tp_core 0xb7165fa9	l2tp_recv_common
++EXPORT_SYMBOL net/lapb/lapb 0x07387ba7	lapb_connect_request
++EXPORT_SYMBOL net/lapb/lapb 0x1d128cd0	lapb_getparms
++EXPORT_SYMBOL net/lapb/lapb 0x36fa7f0c	lapb_data_request
++EXPORT_SYMBOL net/lapb/lapb 0x41c08bf3	lapb_setparms
++EXPORT_SYMBOL net/lapb/lapb 0x5a457ead	lapb_disconnect_request
++EXPORT_SYMBOL net/lapb/lapb 0x63a9521a	lapb_unregister
++EXPORT_SYMBOL net/lapb/lapb 0x93f8bc17	lapb_register
++EXPORT_SYMBOL net/lapb/lapb 0xa95d9525	lapb_data_received
++EXPORT_SYMBOL net/llc/llc 0x2d17dbeb	llc_set_station_handler
++EXPORT_SYMBOL net/llc/llc 0x38b92846	llc_remove_pack
++EXPORT_SYMBOL net/llc/llc 0x4e0755f9	llc_sap_open
++EXPORT_SYMBOL net/llc/llc 0x52d7b2fd	llc_sap_list
++EXPORT_SYMBOL net/llc/llc 0x642b018b	llc_build_and_send_ui_pkt
++EXPORT_SYMBOL net/llc/llc 0x6e2fd5e1	llc_sap_close
++EXPORT_SYMBOL net/llc/llc 0x6ebc1d6e	llc_add_pack
++EXPORT_SYMBOL net/llc/llc 0x7acce0b3	llc_sap_find
++EXPORT_SYMBOL net/llc/llc 0x9fbfc455	llc_mac_hdr_init
++EXPORT_SYMBOL net/llc/llc 0xd629316a	llc_sap_list_lock
++EXPORT_SYMBOL net/mac80211/mac80211 0x007c57ce	ieee80211_get_tx_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0x009376f2	ieee80211_sta_set_buffered
++EXPORT_SYMBOL net/mac80211/mac80211 0x038543df	ieee80211_wake_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x0570e628	ieee80211_sched_scan_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x0fb7e057	ieee80211_stop_rx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0x13cad671	__ieee80211_get_tx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x1591b293	ieee80211_rate_control_register
++EXPORT_SYMBOL net/mac80211/mac80211 0x21a2ae71	ieee80211_sta_ps_transition
++EXPORT_SYMBOL net/mac80211/mac80211 0x2cbdc37d	ieee80211_stop_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x30dc4170	ieee80211_tx_status
++EXPORT_SYMBOL net/mac80211/mac80211 0x337dba24	ieee80211_pspoll_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x35434dad	ieee80211_connection_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0x360277e1	ieee80211_generic_frame_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x370c5405	__ieee80211_get_radio_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x3d8bd5bc	__ieee80211_get_assoc_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0x4456ca54	ieee80211_unregister_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x46220e2b	ieee80211_get_tkip_p2k
++EXPORT_SYMBOL net/mac80211/mac80211 0x4f52cacd	ieee80211_queue_stopped
++EXPORT_SYMBOL net/mac80211/mac80211 0x545951cd	ieee80211_report_low_ack
++EXPORT_SYMBOL net/mac80211/mac80211 0x5608901d	ieee80211_register_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x56bfd882	ieee80211_stop_queues
++EXPORT_SYMBOL net/mac80211/mac80211 0x5b262052	ieee80211_queue_delayed_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x5c28cca5	ieee80211_get_tkip_p1k_iv
++EXPORT_SYMBOL net/mac80211/mac80211 0x5cc9f3c5	ieee80211_send_bar
++EXPORT_SYMBOL net/mac80211/mac80211 0x6666e426	ieee80211_ap_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x67c50e7b	ieee80211_iter_keys
++EXPORT_SYMBOL net/mac80211/mac80211 0x6872e856	ieee80211_chswitch_done
++EXPORT_SYMBOL net/mac80211/mac80211 0x68a418fc	ieee80211_tx_status_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0x6e46a6e6	ieee80211_rts_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0x72d0e064	ieee80211_cqm_rssi_notify
++EXPORT_SYMBOL net/mac80211/mac80211 0x7a2d5729	ieee80211_radar_detected
++EXPORT_SYMBOL net/mac80211/mac80211 0x7c19de27	ieee80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/mac80211/mac80211 0x81f7a2cd	ieee80211_rate_control_unregister
++EXPORT_SYMBOL net/mac80211/mac80211 0x8dc7b555	ieee80211_disable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0x91558f35	wiphy_to_ieee80211_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x92b9434b	ieee80211_sched_scan_results
++EXPORT_SYMBOL net/mac80211/mac80211 0x99e532af	ieee80211_free_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0x9ac14c4c	ieee80211_queue_work
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c336563	__ieee80211_create_tpt_led_trigger
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c5e6334	ieee80211_sta_eosp
++EXPORT_SYMBOL net/mac80211/mac80211 0x9c9f0875	ieee80211_ctstoself_get
++EXPORT_SYMBOL net/mac80211/mac80211 0x9e393f29	ieee80211_enable_rssi_reports
++EXPORT_SYMBOL net/mac80211/mac80211 0xa0588668	ieee80211_sta_block_awake
++EXPORT_SYMBOL net/mac80211/mac80211 0xa068d07a	__ieee80211_get_rx_led_name
++EXPORT_SYMBOL net/mac80211/mac80211 0xa1fc36c4	ieee80211_start_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xa94c4cf1	ieee80211_proberesp_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa126c5b	ieee80211_ctstoself_duration
++EXPORT_SYMBOL net/mac80211/mac80211 0xaa157485	ieee80211_get_tkip_rx_p1k
++EXPORT_SYMBOL net/mac80211/mac80211 0xb4feb33a	ieee80211_alloc_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xb686acbb	ieee80211_nullfunc_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xbb7f49bf	ieee80211_stop_queue
++EXPORT_SYMBOL net/mac80211/mac80211 0xbe4f9fdf	ieee80211_probereq_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xc17623c6	ieee80211_rx_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xc184ae69	ieee80211_beacon_loss
++EXPORT_SYMBOL net/mac80211/mac80211 0xc7e9782e	ieee80211_get_key_tx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xcccafe99	ieee80211_stop_tx_ba_session
++EXPORT_SYMBOL net/mac80211/mac80211 0xd8c9e956	ieee80211_restart_hw
++EXPORT_SYMBOL net/mac80211/mac80211 0xdba63b93	rate_control_set_rates
++EXPORT_SYMBOL net/mac80211/mac80211 0xddb47d52	ieee80211_get_key_rx_seq
++EXPORT_SYMBOL net/mac80211/mac80211 0xdfa053e0	ieee80211_rts_get
++EXPORT_SYMBOL net/mac80211/mac80211 0xe78120cf	ieee80211_rx
++EXPORT_SYMBOL net/mac80211/mac80211 0xe90e83c6	ieee80211_start_tx_ba_cb_irqsafe
++EXPORT_SYMBOL net/mac80211/mac80211 0xe9939e29	ieee80211_beacon_get_tim
++EXPORT_SYMBOL net/mac80211/mac80211 0xe9fa654c	ieee80211_free_txskb
++EXPORT_SYMBOL net/mac80211/mac80211 0xea07f7a2	ieee80211_scan_completed
++EXPORT_SYMBOL net/mac80211/mac80211 0xea763aec	ieee80211_get_buffered_bc
++EXPORT_SYMBOL net/mac80211/mac80211 0xf3214d92	rate_control_send_low
++EXPORT_SYMBOL net/mac80211/mac80211 0xf395de03	ieee80211_aes_cmac_calculate_k1_k2
++EXPORT_SYMBOL net/mac80211/mac80211 0xfcc4ce24	ieee80211_find_sta
++EXPORT_SYMBOL net/mac80211/mac80211 0xff8ded37	ieee80211_wake_queue
++EXPORT_SYMBOL net/mac802154/mac802154 0x0c3654c2	ieee802154_free_device
++EXPORT_SYMBOL net/mac802154/mac802154 0x447453bc	ieee802154_unregister_device
++EXPORT_SYMBOL net/mac802154/mac802154 0x5946eaa4	ieee802154_rx_irqsafe
++EXPORT_SYMBOL net/mac802154/mac802154 0x7bf9c870	ieee802154_register_device
++EXPORT_SYMBOL net/mac802154/mac802154 0xdf536aba	ieee802154_alloc_device
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x465021ee	ip_vs_nfct_expect_related
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6187854b	ip_vs_tcp_conn_listen
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x65aef121	ip_vs_scheduler_err
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6b75ebc5	ip_vs_conn_out_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6be08e8e	ip_vs_proto_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x6c9ffdb5	register_ip_vs_app_inc
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x719fbf46	ip_vs_proto_data_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x88dcc62b	register_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x893914c7	unregister_ip_vs_scheduler
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9a15cff0	unregister_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0x9c3905a7	register_ip_vs_app
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xb07a150c	ip_vs_conn_new
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xc11bd20c	ip_vs_conn_put
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd7f34825	ip_vs_conn_in_get
++EXPORT_SYMBOL net/netfilter/ipvs/ip_vs 0xd831a1a2	ip_vs_proto_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x8ed96bd2	__nf_ct_ext_add_length
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0x9202a736	nf_conntrack_untracked
++EXPORT_SYMBOL net/netfilter/nf_conntrack 0xcf0d70e8	__nf_ct_ext_destroy
++EXPORT_SYMBOL net/netfilter/nf_conntrack_pptp 0x827cc6a1	pptp_msg_name
++EXPORT_SYMBOL net/netfilter/nf_conntrack_proto_gre 0x39f0be68	nf_ct_gre_keymap_flush
++EXPORT_SYMBOL net/netfilter/nf_nat 0x2bc8e062	nf_xfrm_me_harder
++EXPORT_SYMBOL net/netfilter/nf_nat 0x5020fce7	nf_nat_setup_info
++EXPORT_SYMBOL net/netfilter/nf_nat 0x52dec652	nf_nat_used_tuple
++EXPORT_SYMBOL net/netfilter/nf_nat 0xb3e5df2d	nf_nat_follow_master
++EXPORT_SYMBOL net/netfilter/nf_nat 0xd6b89d8d	__nf_nat_mangle_tcp_packet
++EXPORT_SYMBOL net/netfilter/nf_nat 0xda60684d	nf_nat_mangle_udp_packet
++EXPORT_SYMBOL net/netfilter/x_tables 0x08c473b7	xt_alloc_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0x0b2c5f92	xt_find_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x1254fa89	xt_register_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x13a757af	xt_unregister_targets
++EXPORT_SYMBOL net/netfilter/x_tables 0x22995c09	xt_register_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x650321f0	xt_unregister_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x72d8af42	xt_register_target
++EXPORT_SYMBOL net/netfilter/x_tables 0x738f709f	xt_find_match
++EXPORT_SYMBOL net/netfilter/x_tables 0x73deea27	xt_unregister_matches
++EXPORT_SYMBOL net/netfilter/x_tables 0x9d2411f6	xt_unregister_target
++EXPORT_SYMBOL net/netfilter/x_tables 0xb28f5ef1	xt_free_table_info
++EXPORT_SYMBOL net/netfilter/x_tables 0xcf201dd6	xt_register_targets
++EXPORT_SYMBOL net/nfc/hci/hci 0x008a30a9	nfc_hci_set_param
++EXPORT_SYMBOL net/nfc/hci/hci 0x3893ac9b	nfc_hci_send_cmd
++EXPORT_SYMBOL net/nfc/hci/hci 0x43028a27	nfc_hci_result_to_errno
++EXPORT_SYMBOL net/nfc/hci/hci 0x4731a28a	nfc_hci_recv_frame
++EXPORT_SYMBOL net/nfc/hci/hci 0x4a486841	nfc_hci_disconnect_all_gates
++EXPORT_SYMBOL net/nfc/hci/hci 0x6b677d11	nfc_hci_unregister_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x728f79f3	nfc_hci_register_device
++EXPORT_SYMBOL net/nfc/hci/hci 0x796cfafe	nfc_hci_set_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x7f2cf65b	nfc_hci_connect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0x97322e98	nfc_hci_get_clientdata
++EXPORT_SYMBOL net/nfc/hci/hci 0x9baa900b	nfc_hci_send_event
++EXPORT_SYMBOL net/nfc/hci/hci 0xa3ec58e9	nfc_hci_free_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xb8c0b1f6	nfc_hci_driver_failure
++EXPORT_SYMBOL net/nfc/hci/hci 0xbb1aa79c	nfc_hci_disconnect_gate
++EXPORT_SYMBOL net/nfc/hci/hci 0xbca0b4fd	nfc_hci_sak_to_protocol
++EXPORT_SYMBOL net/nfc/hci/hci 0xc8cb02e7	nfc_hci_allocate_device
++EXPORT_SYMBOL net/nfc/hci/hci 0xddd47fec	nfc_hci_target_discovered
++EXPORT_SYMBOL net/nfc/hci/hci 0xe7f9a91d	nfc_hci_get_param
++EXPORT_SYMBOL net/nfc/hci/hci 0xf0d9a2f2	nfc_hci_send_cmd_async
++EXPORT_SYMBOL net/nfc/hci/hci 0xf34fc334	nfc_hci_send_response
++EXPORT_SYMBOL net/nfc/nci/nci 0x43831ccc	nci_allocate_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x43e38b20	nci_register_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x71a6b8f8	nci_unregister_device
++EXPORT_SYMBOL net/nfc/nci/nci 0x9d7a037d	nci_free_device
++EXPORT_SYMBOL net/nfc/nci/nci 0xb53ec71a	nci_recv_frame
++EXPORT_SYMBOL net/nfc/nci/nci 0xba490602	nci_to_errno
++EXPORT_SYMBOL net/nfc/nfc 0x017036d3	nfc_class
++EXPORT_SYMBOL net/nfc/nfc 0x262e3a0c	nfc_dep_link_is_up
++EXPORT_SYMBOL net/nfc/nfc 0x2d04ba46	nfc_target_lost
++EXPORT_SYMBOL net/nfc/nfc 0x378972b9	nfc_set_remote_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0x399b8731	nfc_proto_unregister
++EXPORT_SYMBOL net/nfc/nfc 0x4e758479	nfc_proto_register
++EXPORT_SYMBOL net/nfc/nfc 0x53c15150	nfc_tm_deactivated
++EXPORT_SYMBOL net/nfc/nfc 0x646115f1	nfc_targets_found
++EXPORT_SYMBOL net/nfc/nfc 0x9ba2fe22	nfc_remove_se
++EXPORT_SYMBOL net/nfc/nfc 0xb0189b3d	nfc_fw_download_done
++EXPORT_SYMBOL net/nfc/nfc 0xb035244e	nfc_get_local_general_bytes
++EXPORT_SYMBOL net/nfc/nfc 0xcd5dd730	nfc_alloc_recv_skb
++EXPORT_SYMBOL net/nfc/nfc 0xd82dfe17	nfc_driver_failure
++EXPORT_SYMBOL net/nfc/nfc 0xe1c27853	nfc_register_device
++EXPORT_SYMBOL net/nfc/nfc 0xe39863a0	nfc_add_se
++EXPORT_SYMBOL net/nfc/nfc 0xf07bc076	nfc_tm_data_received
++EXPORT_SYMBOL net/nfc/nfc 0xf3d4f299	nfc_unregister_device
++EXPORT_SYMBOL net/nfc/nfc 0xf9b7c10a	nfc_tm_activated
++EXPORT_SYMBOL net/nfc/nfc 0xfcb7aab6	nfc_allocate_device
++EXPORT_SYMBOL net/phonet/phonet 0x07293425	pn_sock_unhash
++EXPORT_SYMBOL net/phonet/phonet 0x08210464	pn_sock_hash
++EXPORT_SYMBOL net/phonet/phonet 0x4c0bb12f	phonet_header_ops
++EXPORT_SYMBOL net/phonet/phonet 0x4c6d6bd3	phonet_proto_unregister
++EXPORT_SYMBOL net/phonet/phonet 0x5156828c	phonet_stream_ops
++EXPORT_SYMBOL net/phonet/phonet 0x8f7f8b4f	pn_sock_get_port
++EXPORT_SYMBOL net/phonet/phonet 0xf62dd6bd	phonet_proto_register
++EXPORT_SYMBOL net/phonet/phonet 0xf998bb1e	pn_skb_send
++EXPORT_SYMBOL net/rds/rds 0x5031b8c5	rds_str_array
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x1b839906	rxrpc_kernel_get_abort_code
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2268e9b9	rxrpc_kernel_intercept_rx_messages
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2872fba6	rxrpc_kernel_begin_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x2a2d7866	rxrpc_kernel_is_data_last
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x54ac80c9	rxrpc_kernel_get_error_number
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x5de54def	rxrpc_get_server_data_key
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0x96fc86e0	key_type_rxrpc
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb79aa7bc	rxrpc_kernel_data_delivered
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb99e8d49	rxrpc_kernel_reject_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xb9f5586e	rxrpc_kernel_free_skb
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xc07834e0	rxrpc_kernel_send_data
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xcf9aa293	rxrpc_kernel_abort_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf4d5c9af	rxrpc_kernel_end_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xf666cca9	rxrpc_kernel_accept_call
++EXPORT_SYMBOL net/rxrpc/af-rxrpc 0xfa451668	rxrpc_get_null_key
++EXPORT_SYMBOL net/sctp/sctp 0x9aa3095e	sctp_do_peeloff
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0x59c58538	gss_pseudoflavor_to_service
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xc084aaae	gss_mech_put
++EXPORT_SYMBOL net/sunrpc/auth_gss/auth_rpcgss 0xc9e8017c	gss_mech_get
++EXPORT_SYMBOL net/sunrpc/sunrpc 0x12b00a59	svc_pool_stats_open
++EXPORT_SYMBOL net/wimax/wimax 0xc4c4538d	wimax_rfkill
++EXPORT_SYMBOL net/wimax/wimax 0xdaf8eafa	wimax_reset
++EXPORT_SYMBOL net/wireless/cfg80211 0x0768a1bf	cfg80211_rx_unexpected_4addr_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0x08098e9e	cfg80211_cqm_rssi_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x09c64fbd	ieee80211_frequency_to_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x0d2b919c	cfg80211_classify8021d
++EXPORT_SYMBOL net/wireless/cfg80211 0x1699a7bd	cfg80211_rx_unprot_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x1879fcbd	bridge_tunnel_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x18b5d139	cfg80211_connect_result
++EXPORT_SYMBOL net/wireless/cfg80211 0x18c93977	ieee80211_get_hdrlen_from_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x19e03378	cfg80211_get_p2p_attr
++EXPORT_SYMBOL net/wireless/cfg80211 0x354019ee	cfg80211_testmode_alloc_reply_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0x35ac202b	freq_reg_info
++EXPORT_SYMBOL net/wireless/cfg80211 0x3c9426e8	cfg80211_radar_event
++EXPORT_SYMBOL net/wireless/cfg80211 0x406a8302	cfg80211_chandef_valid
++EXPORT_SYMBOL net/wireless/cfg80211 0x4399c50f	cfg80211_new_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0x4b9b55ba	__ieee80211_get_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c352815	cfg80211_auth_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0x4c3b5878	ieee80211_get_response_rate
++EXPORT_SYMBOL net/wireless/cfg80211 0x4ccaff94	wiphy_rfkill_set_hw_state
++EXPORT_SYMBOL net/wireless/cfg80211 0x4d1e321f	cfg80211_cqm_pktloss_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x577370a4	cfg80211_probe_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x596f98d9	cfg80211_reg_can_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0x5b00b18a	wiphy_rfkill_start_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0x5b3b1ccb	ieee80211_amsdu_to_8023s
++EXPORT_SYMBOL net/wireless/cfg80211 0x5d3c3b8a	ieee80211_data_from_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x64179510	cfg80211_get_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x644560ae	cfg80211_ibss_joined
++EXPORT_SYMBOL net/wireless/cfg80211 0x670f99be	cfg80211_mgmt_tx_status
++EXPORT_SYMBOL net/wireless/cfg80211 0x674549a4	cfg80211_gtk_rekey_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x69b18f43	rfc1042_header
++EXPORT_SYMBOL net/wireless/cfg80211 0x6addf46f	wiphy_apply_custom_regulatory
++EXPORT_SYMBOL net/wireless/cfg80211 0x6c394240	cfg80211_unregister_wdev
++EXPORT_SYMBOL net/wireless/cfg80211 0x6d6cb9ad	ieee80211_operating_class_to_band
++EXPORT_SYMBOL net/wireless/cfg80211 0x6f3829a8	wiphy_free
++EXPORT_SYMBOL net/wireless/cfg80211 0x728b36f4	cfg80211_rx_assoc_resp
++EXPORT_SYMBOL net/wireless/cfg80211 0x79569ebc	ieee80211_data_to_8023
++EXPORT_SYMBOL net/wireless/cfg80211 0x7b3abb37	cfg80211_ref_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x7cb00fd9	cfg80211_sched_scan_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0x7ef39823	ieee80211_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0x7fe1a403	cfg80211_find_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x8b3aa69e	cfg80211_scan_done
++EXPORT_SYMBOL net/wireless/cfg80211 0x8c8849dd	cfg80211_roamed_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0x8cd2af66	cfg80211_remain_on_channel_expired
++EXPORT_SYMBOL net/wireless/cfg80211 0x8ea51b62	cfg80211_check_station_change
++EXPORT_SYMBOL net/wireless/cfg80211 0x92c0c538	ieee80211_bss_get_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0x941bad57	cfg80211_testmode_reply
++EXPORT_SYMBOL net/wireless/cfg80211 0x94e1ca21	cfg80211_michael_mic_failure
++EXPORT_SYMBOL net/wireless/cfg80211 0x95542f6e	cfg80211_tx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0x982e6b6d	ieee80211_radiotap_iterator_init
++EXPORT_SYMBOL net/wireless/cfg80211 0x98319a68	cfg80211_cqm_txe_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0x9d97ea1c	cfg80211_tdls_oper_request
++EXPORT_SYMBOL net/wireless/cfg80211 0xa061dd89	cfg80211_chandef_usable
++EXPORT_SYMBOL net/wireless/cfg80211 0xa0cf96e0	cfg80211_conn_failed
++EXPORT_SYMBOL net/wireless/cfg80211 0xa1425906	ieee80211_channel_to_frequency
++EXPORT_SYMBOL net/wireless/cfg80211 0xa197b1ff	ieee80211_get_mesh_hdrlen
++EXPORT_SYMBOL net/wireless/cfg80211 0xaff6b2c7	cfg80211_ready_on_channel
++EXPORT_SYMBOL net/wireless/cfg80211 0xb14caef1	cfg80211_roamed
++EXPORT_SYMBOL net/wireless/cfg80211 0xb5162161	cfg80211_rx_mlme_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xb6e5e029	cfg80211_notify_new_peer_candidate
++EXPORT_SYMBOL net/wireless/cfg80211 0xb7403cb1	wiphy_register
++EXPORT_SYMBOL net/wireless/cfg80211 0xb924626b	cfg80211_testmode_alloc_event_skb
++EXPORT_SYMBOL net/wireless/cfg80211 0xbf66fe93	cfg80211_del_sta
++EXPORT_SYMBOL net/wireless/cfg80211 0xc113c7b9	cfg80211_crit_proto_stopped
++EXPORT_SYMBOL net/wireless/cfg80211 0xc15c8611	cfg80211_chandef_create
++EXPORT_SYMBOL net/wireless/cfg80211 0xc2e3cde7	cfg80211_inform_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xc3d90ad4	cfg80211_assoc_timeout
++EXPORT_SYMBOL net/wireless/cfg80211 0xc63f1b81	ieee80211_radiotap_iterator_next
++EXPORT_SYMBOL net/wireless/cfg80211 0xc81fdd2d	cfg80211_ch_switch_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xca2b69e2	cfg80211_report_wowlan_wakeup
++EXPORT_SYMBOL net/wireless/cfg80211 0xcb31b9ff	cfg80211_ft_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xcb3a48ab	cfg80211_report_obss_beacon
++EXPORT_SYMBOL net/wireless/cfg80211 0xccb7be94	regulatory_hint
++EXPORT_SYMBOL net/wireless/cfg80211 0xcda60248	cfg80211_disconnected
++EXPORT_SYMBOL net/wireless/cfg80211 0xcf618a57	cfg80211_calculate_bitrate
++EXPORT_SYMBOL net/wireless/cfg80211 0xd7ebe4a5	cfg80211_pmksa_candidate_notify
++EXPORT_SYMBOL net/wireless/cfg80211 0xdb5132ec	cfg80211_testmode_event
++EXPORT_SYMBOL net/wireless/cfg80211 0xdb5d3344	wiphy_unregister
++EXPORT_SYMBOL net/wireless/cfg80211 0xde807476	cfg80211_put_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xe3167eca	ieee80211_mandatory_rates
++EXPORT_SYMBOL net/wireless/cfg80211 0xee42db3c	cfg80211_chandef_compatible
++EXPORT_SYMBOL net/wireless/cfg80211 0xf0cca0d1	cfg80211_rx_mgmt
++EXPORT_SYMBOL net/wireless/cfg80211 0xf1f6749c	wiphy_new
++EXPORT_SYMBOL net/wireless/cfg80211 0xf2be1688	cfg80211_unlink_bss
++EXPORT_SYMBOL net/wireless/cfg80211 0xf84ff12e	cfg80211_sched_scan_results
++EXPORT_SYMBOL net/wireless/cfg80211 0xf99ea858	wiphy_rfkill_stop_polling
++EXPORT_SYMBOL net/wireless/cfg80211 0xfb9981a0	cfg80211_inform_bss_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xfe47a641	cfg80211_rx_spurious_frame
++EXPORT_SYMBOL net/wireless/cfg80211 0xfed4d591	cfg80211_find_vendor_ie
++EXPORT_SYMBOL net/wireless/cfg80211 0xfeedc89a	cfg80211_cac_event
++EXPORT_SYMBOL net/wireless/lib80211 0x2d0f99e5	print_ssid
++EXPORT_SYMBOL net/wireless/lib80211 0x3796dedd	lib80211_crypt_info_free
++EXPORT_SYMBOL net/wireless/lib80211 0x8e2d5ac2	lib80211_get_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0x9949f885	lib80211_crypt_info_init
++EXPORT_SYMBOL net/wireless/lib80211 0xb880628c	lib80211_crypt_delayed_deinit
++EXPORT_SYMBOL net/wireless/lib80211 0xeabd15dc	lib80211_unregister_crypto_ops
++EXPORT_SYMBOL net/wireless/lib80211 0xef6abf65	lib80211_register_crypto_ops
++EXPORT_SYMBOL sound/ac97_bus 0x152bffbf	ac97_bus_type
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x1a724fcc	snd_seq_kernel_client_ctl
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x2345ad38	snd_seq_kernel_client_enqueue_blocking
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3061c52d	snd_use_lock_sync_helper
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x3fb4d161	snd_seq_kernel_client_dispatch
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x4c69e078	snd_seq_event_port_attach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x53cf4695	snd_seq_create_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x6bb71038	snd_seq_delete_kernel_client
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7ac2f329	snd_seq_expand_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq 0x7b8699eb	snd_seq_event_port_detach
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb0548d92	snd_seq_kernel_client_write_poll
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xb8e448a0	snd_seq_set_queue_tempo
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xcac0a3be	snd_seq_kernel_client_enqueue
++EXPORT_SYMBOL sound/core/seq/snd-seq 0xe934da1d	snd_seq_dump_var_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x3a57f235	snd_seq_autoload_unlock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x3de66491	snd_seq_device_register_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x50e4213a	snd_seq_device_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0x6339b6d0	snd_seq_device_load_drivers
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xb90668b2	snd_seq_autoload_lock
++EXPORT_SYMBOL sound/core/seq/snd-seq-device 0xc622fb29	snd_seq_device_unregister_driver
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x6ea09972	snd_midi_channel_alloc_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0x833a3e07	snd_midi_channel_set_clear
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xb9948d2c	snd_midi_channel_free_set
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-emul 0xf0a1fdb3	snd_midi_process_event
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x2b51b084	snd_midi_event_free
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x350963b4	snd_midi_event_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x7f62d029	snd_midi_event_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x83914b9a	snd_midi_event_no_status
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x92ee6bb0	snd_midi_event_reset_decode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0x9e7d3f0f	snd_midi_event_reset_encode
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xbc141dfc	snd_midi_event_encode_byte
++EXPORT_SYMBOL sound/core/seq/snd-seq-midi-event 0xf2bf1549	snd_midi_event_new
++EXPORT_SYMBOL sound/core/seq/snd-seq-virmidi 0x7d739959	snd_virmidi_new
++EXPORT_SYMBOL sound/core/snd 0x14be32e9	_snd_ctl_add_slave
++EXPORT_SYMBOL sound/core/snd 0x15ddbe4b	snd_card_proc_new
++EXPORT_SYMBOL sound/core/snd 0x18e1683f	snd_dma_program
++EXPORT_SYMBOL sound/core/snd 0x191e88cf	snd_dma_pointer
++EXPORT_SYMBOL sound/core/snd 0x1ae9f531	snd_ctl_boolean_stereo_info
++EXPORT_SYMBOL sound/core/snd 0x1d7d8319	snd_ctl_rename_id
++EXPORT_SYMBOL sound/core/snd 0x24a94b26	snd_info_get_line
++EXPORT_SYMBOL sound/core/snd 0x29206b59	snd_device_new
++EXPORT_SYMBOL sound/core/snd 0x2ae3deaa	release_and_free_resource
++EXPORT_SYMBOL sound/core/snd 0x2d4faf31	snd_ctl_find_numid
++EXPORT_SYMBOL sound/core/snd 0x2e2a6738	snd_ctl_new1
++EXPORT_SYMBOL sound/core/snd 0x30ce77a0	snd_add_device_sysfs_file
++EXPORT_SYMBOL sound/core/snd 0x3971b4df	snd_ecards_limit
++EXPORT_SYMBOL sound/core/snd 0x3e570fcf	snd_card_free_when_closed
++EXPORT_SYMBOL sound/core/snd 0x4a3ea5c0	snd_request_card
++EXPORT_SYMBOL sound/core/snd 0x4b015768	snd_iprintf
++EXPORT_SYMBOL sound/core/snd 0x5192d8b6	snd_unregister_device
++EXPORT_SYMBOL sound/core/snd 0x5ae02250	snd_ctl_add
++EXPORT_SYMBOL sound/core/snd 0x602c96f0	copy_to_user_fromio
++EXPORT_SYMBOL sound/core/snd 0x682946e5	snd_power_wait
++EXPORT_SYMBOL sound/core/snd 0x6e471fb5	snd_card_set_id
++EXPORT_SYMBOL sound/core/snd 0x70c15ac1	snd_dma_disable
++EXPORT_SYMBOL sound/core/snd 0x74a939d1	snd_seq_root
++EXPORT_SYMBOL sound/core/snd 0x7ca9fec9	snd_device_register
++EXPORT_SYMBOL sound/core/snd 0x7cf8cf21	snd_ctl_make_virtual_master
++EXPORT_SYMBOL sound/core/snd 0x81b69e41	snd_ctl_enum_info
++EXPORT_SYMBOL sound/core/snd 0x8be63232	snd_ctl_find_id
++EXPORT_SYMBOL sound/core/snd 0x8f595b11	snd_major
++EXPORT_SYMBOL sound/core/snd 0x907bcf0d	snd_info_create_card_entry
++EXPORT_SYMBOL sound/core/snd 0x958a6310	snd_jack_set_key
++EXPORT_SYMBOL sound/core/snd 0x989cdbd0	snd_card_unref
++EXPORT_SYMBOL sound/core/snd 0x9e6d79f8	snd_info_get_str
++EXPORT_SYMBOL sound/core/snd 0xa0fd2427	snd_pci_quirk_lookup_id
++EXPORT_SYMBOL sound/core/snd 0xa5a2d907	snd_card_free
++EXPORT_SYMBOL sound/core/snd 0xaaf2039e	snd_ctl_register_ioctl
++EXPORT_SYMBOL sound/core/snd 0xab2ff4d8	snd_jack_set_parent
++EXPORT_SYMBOL sound/core/snd 0xb0bbba78	snd_ctl_notify
++EXPORT_SYMBOL sound/core/snd 0xb2e5ae4a	snd_lookup_minor_data
++EXPORT_SYMBOL sound/core/snd 0xb7a57312	snd_ctl_remove
++EXPORT_SYMBOL sound/core/snd 0xb8ba608d	snd_pci_quirk_lookup
++EXPORT_SYMBOL sound/core/snd 0xb9201b0b	snd_info_create_module_entry
++EXPORT_SYMBOL sound/core/snd 0xbea8d5e8	snd_card_disconnect
++EXPORT_SYMBOL sound/core/snd 0xbff89a73	snd_jack_new
++EXPORT_SYMBOL sound/core/snd 0xc1e0b284	snd_device_free
++EXPORT_SYMBOL sound/core/snd 0xce3ca308	copy_from_user_toio
++EXPORT_SYMBOL sound/core/snd 0xd5a6fee6	snd_card_file_remove
++EXPORT_SYMBOL sound/core/snd 0xda0b7602	snd_ctl_replace
++EXPORT_SYMBOL sound/core/snd 0xda23dfda	snd_card_register
++EXPORT_SYMBOL sound/core/snd 0xdbcba830	snd_card_file_add
++EXPORT_SYMBOL sound/core/snd 0xde3781b2	snd_cards
++EXPORT_SYMBOL sound/core/snd 0xe12b2500	snd_info_free_entry
++EXPORT_SYMBOL sound/core/snd 0xe9e6172b	snd_ctl_free_one
++EXPORT_SYMBOL sound/core/snd 0xebf208fa	snd_component_add
++EXPORT_SYMBOL sound/core/snd 0xec487d30	snd_card_create
++EXPORT_SYMBOL sound/core/snd 0xedfdd9f3	snd_ctl_boolean_mono_info
++EXPORT_SYMBOL sound/core/snd 0xeee2dba3	snd_ctl_unregister_ioctl
++EXPORT_SYMBOL sound/core/snd 0xef0d0074	snd_jack_report
++EXPORT_SYMBOL sound/core/snd 0xefc03785	snd_info_register
++EXPORT_SYMBOL sound/core/snd 0xf17ec710	snd_register_device_for_dev
++EXPORT_SYMBOL sound/core/snd 0xfc27b27a	snd_ctl_remove_id
++EXPORT_SYMBOL sound/core/snd-hwdep 0x2ecd1026	snd_hwdep_new
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x04398682	snd_dma_reserve_buf
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x1472c184	snd_dma_alloc_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x20424e2a	snd_sgbuf_get_chunk_size
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x26662eee	snd_dma_free_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x3b91f3af	snd_free_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0x99be1128	snd_dma_alloc_pages_fallback
++EXPORT_SYMBOL sound/core/snd-page-alloc 0xade88e76	snd_malloc_pages
++EXPORT_SYMBOL sound/core/snd-page-alloc 0xb4809912	snd_dma_get_reserved_buf
++EXPORT_SYMBOL sound/core/snd-pcm 0x0283dfe3	_snd_pcm_hw_params_any
++EXPORT_SYMBOL sound/core/snd-pcm 0x04cda566	snd_interval_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0x196d34f9	snd_pcm_hw_rule_add
++EXPORT_SYMBOL sound/core/snd-pcm 0x1d027e4b	snd_pcm_format_signed
++EXPORT_SYMBOL sound/core/snd-pcm 0x1fb1b16e	snd_pcm_lib_free_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x2860eb10	snd_pcm_hw_constraint_step
++EXPORT_SYMBOL sound/core/snd-pcm 0x3796bdcc	snd_pcm_format_little_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x39bf9301	_snd_pcm_hw_param_setempty
++EXPORT_SYMBOL sound/core/snd-pcm 0x3bfd44b8	snd_pcm_limit_hw_rates
++EXPORT_SYMBOL sound/core/snd-pcm 0x3edcda33	snd_pcm_new_internal
++EXPORT_SYMBOL sound/core/snd-pcm 0x40dd24d9	snd_pcm_hw_constraint_ratnums
++EXPORT_SYMBOL sound/core/snd-pcm 0x41dea868	snd_pcm_new
++EXPORT_SYMBOL sound/core/snd-pcm 0x42ac8e23	snd_pcm_lib_preallocate_pages_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x495e672e	snd_pcm_debug_name
++EXPORT_SYMBOL sound/core/snd-pcm 0x4d9b6d35	snd_pcm_format_size
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f718a8b	snd_pcm_set_ops
++EXPORT_SYMBOL sound/core/snd-pcm 0x4f816e9b	snd_pcm_format_big_endian
++EXPORT_SYMBOL sound/core/snd-pcm 0x50f887cd	snd_pcm_lib_preallocate_free_for_all
++EXPORT_SYMBOL sound/core/snd-pcm 0x51a3cf6c	snd_pcm_hw_constraint_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x52e3e4a5	snd_pcm_hw_param_value
++EXPORT_SYMBOL sound/core/snd-pcm 0x53d6525f	snd_pcm_notify
++EXPORT_SYMBOL sound/core/snd-pcm 0x55379ea1	snd_pcm_hw_param_first
++EXPORT_SYMBOL sound/core/snd-pcm 0x5e7f4920	snd_pcm_format_set_silence
++EXPORT_SYMBOL sound/core/snd-pcm 0x5ecb7cc5	snd_pcm_hw_constraint_msbits
++EXPORT_SYMBOL sound/core/snd-pcm 0x5efcc48f	snd_pcm_lib_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0x650f8603	snd_pcm_format_silence_64
++EXPORT_SYMBOL sound/core/snd-pcm 0x6888927d	snd_pcm_hw_constraint_minmax
++EXPORT_SYMBOL sound/core/snd-pcm 0x68a24153	snd_pcm_format_physical_width
++EXPORT_SYMBOL sound/core/snd-pcm 0x6a0fa0e1	snd_pcm_lib_get_vmalloc_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x6be9a060	snd_pcm_sgbuf_ops_page
++EXPORT_SYMBOL sound/core/snd-pcm 0x6ef8fcd8	snd_pcm_format_linear
++EXPORT_SYMBOL sound/core/snd-pcm 0x7223b1fa	snd_pcm_lib_malloc_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x78ba001e	snd_pcm_mmap_data
++EXPORT_SYMBOL sound/core/snd-pcm 0x8284f87b	snd_pcm_hw_param_last
++EXPORT_SYMBOL sound/core/snd-pcm 0x8c49fadd	snd_pcm_hw_constraint_integer
++EXPORT_SYMBOL sound/core/snd-pcm 0x90890818	snd_pcm_open_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0x94098ff8	snd_interval_list
++EXPORT_SYMBOL sound/core/snd-pcm 0x9623ad26	snd_pcm_lib_preallocate_pages
++EXPORT_SYMBOL sound/core/snd-pcm 0x9c085dc4	_snd_pcm_lib_alloc_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xa4ac9b38	snd_pcm_release_substream
++EXPORT_SYMBOL sound/core/snd-pcm 0xa61aa028	snd_pcm_format_unsigned
++EXPORT_SYMBOL sound/core/snd-pcm 0xa9adc229	snd_pcm_link_rwlock
++EXPORT_SYMBOL sound/core/snd-pcm 0xb109ac70	snd_pcm_stop
++EXPORT_SYMBOL sound/core/snd-pcm 0xb3166a17	snd_pcm_lib_readv
++EXPORT_SYMBOL sound/core/snd-pcm 0xb3b86ac5	snd_pcm_hw_rule_noresample
++EXPORT_SYMBOL sound/core/snd-pcm 0xb9638db4	snd_pcm_rate_to_rate_bit
++EXPORT_SYMBOL sound/core/snd-pcm 0xc0b16519	snd_pcm_lib_writev
++EXPORT_SYMBOL sound/core/snd-pcm 0xc13bce23	snd_pcm_lib_read
++EXPORT_SYMBOL sound/core/snd-pcm 0xc5a2bd4e	snd_pcm_hw_constraint_ratdens
++EXPORT_SYMBOL sound/core/snd-pcm 0xca5218b5	snd_pcm_new_stream
++EXPORT_SYMBOL sound/core/snd-pcm 0xccf27eda	snd_pcm_kernel_ioctl
++EXPORT_SYMBOL sound/core/snd-pcm 0xd34806b2	snd_pcm_set_sync
++EXPORT_SYMBOL sound/core/snd-pcm 0xd4130f96	snd_pcm_suspend_all
++EXPORT_SYMBOL sound/core/snd-pcm 0xd448bc9b	snd_pcm_lib_mmap_iomem
++EXPORT_SYMBOL sound/core/snd-pcm 0xd5010457	snd_pcm_suspend
++EXPORT_SYMBOL sound/core/snd-pcm 0xd78bb5dd	snd_pcm_lib_write
++EXPORT_SYMBOL sound/core/snd-pcm 0xd848088a	snd_pcm_period_elapsed
++EXPORT_SYMBOL sound/core/snd-pcm 0xd9dff183	snd_pcm_hw_refine
++EXPORT_SYMBOL sound/core/snd-pcm 0xe2870f22	snd_pcm_lib_free_vmalloc_buffer
++EXPORT_SYMBOL sound/core/snd-pcm 0xe56a9336	snd_pcm_format_width
++EXPORT_SYMBOL sound/core/snd-pcm 0xf3797152	snd_interval_ratnum
++EXPORT_SYMBOL sound/core/snd-pcm 0xf4ad3b31	snd_pcm_hw_constraint_pow2
++EXPORT_SYMBOL sound/core/snd-pcm 0xff6104d0	snd_pcm_rate_bit_to_rate
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x047dffae	snd_rawmidi_input_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x09b782f0	snd_rawmidi_drain_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x24d57201	snd_rawmidi_transmit_ack
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x304a1b24	snd_rawmidi_transmit
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x3824f82f	snd_rawmidi_kernel_release
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x4bb28b55	snd_rawmidi_drop_output
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x680b97d2	snd_rawmidi_new
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6a866322	snd_rawmidi_kernel_read
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x6d6de226	snd_rawmidi_transmit_empty
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x738873c2	snd_rawmidi_kernel_write
++EXPORT_SYMBOL sound/core/snd-rawmidi 0x8efad882	snd_rawmidi_transmit_peek
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xac9adfd8	snd_rawmidi_output_params
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xb6fc9fd8	snd_rawmidi_info_select
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xbb0164b4	snd_rawmidi_receive
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xc88b08c3	snd_rawmidi_set_ops
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xe7667747	snd_rawmidi_drain_input
++EXPORT_SYMBOL sound/core/snd-rawmidi 0xecf6d46c	snd_rawmidi_kernel_open
++EXPORT_SYMBOL sound/core/snd-timer 0x1a6ebbfd	snd_timer_open
++EXPORT_SYMBOL sound/core/snd-timer 0x26982aef	snd_timer_notify
++EXPORT_SYMBOL sound/core/snd-timer 0x46176361	snd_timer_close
++EXPORT_SYMBOL sound/core/snd-timer 0x6cfcc851	snd_timer_start
++EXPORT_SYMBOL sound/core/snd-timer 0x777c3529	snd_timer_interrupt
++EXPORT_SYMBOL sound/core/snd-timer 0x9f35c3be	snd_timer_resolution
++EXPORT_SYMBOL sound/core/snd-timer 0xa663ac6d	snd_timer_global_free
++EXPORT_SYMBOL sound/core/snd-timer 0xa6cfafdc	snd_timer_global_new
++EXPORT_SYMBOL sound/core/snd-timer 0xb13219e7	snd_timer_new
++EXPORT_SYMBOL sound/core/snd-timer 0xd1d77c2c	snd_timer_continue
++EXPORT_SYMBOL sound/core/snd-timer 0xd3b5acf8	snd_timer_stop
++EXPORT_SYMBOL sound/core/snd-timer 0xefce7a14	snd_timer_pause
++EXPORT_SYMBOL sound/core/snd-timer 0xf11e5c09	snd_timer_global_register
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0x6d629c59	snd_mpu401_uart_interrupt_tx
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xa989f408	snd_mpu401_uart_new
++EXPORT_SYMBOL sound/drivers/mpu401/snd-mpu401-uart 0xc0fec227	snd_mpu401_uart_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x03b39d64	snd_opl3_init
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x05060a19	snd_opl3_regmap
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x0bbdf0e1	snd_opl3_find_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x1351ecce	snd_opl3_reset
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x20dc6ae1	snd_opl3_interrupt
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x29bd8d76	snd_opl3_load_patch
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x4e02ee11	snd_opl3_timer_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x662a6382	snd_opl3_create
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0x9092998a	snd_opl3_new
++EXPORT_SYMBOL sound/drivers/opl3/snd-opl3-lib 0xd7340605	snd_opl3_hwdep_new
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x06046ed6	snd_opl4_write_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x25745063	snd_opl4_read_memory
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0x7e82970e	snd_opl4_write
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0xe94abf7b	snd_opl4_create
++EXPORT_SYMBOL sound/drivers/opl4/snd-opl4-lib 0xf1479409	snd_opl4_read
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x108719d7	snd_vx_create
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x11340472	snd_vx_resume
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x32941de7	snd_vx_free_firmware
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x43c56dcb	snd_vx_load_boot_image
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x6529a597	snd_vx_suspend
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0x8618b287	snd_vx_dsp_boot
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf0a47142	snd_vx_dsp_load
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf1f04d23	snd_vx_irq_handler
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xf9d23f19	snd_vx_check_reg_bit
++EXPORT_SYMBOL sound/drivers/vx/snd-vx-lib 0xfc8b92b9	snd_vx_setup_firmware
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x04b6023a	amdtp_out_stream_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1498d347	amdtp_out_stream_pcm_prepare
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x1dd53603	amdtp_out_stream_stop
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x2f555fa2	fw_iso_resources_allocate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3247f1bf	amdtp_out_stream_pcm_abort
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x36434b6a	amdtp_out_stream_start
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x3ff155ba	amdtp_out_stream_set_rate
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x42a19f89	fcp_avc_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x4c88761d	fw_iso_resources_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x64528222	cmp_connection_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x64baf3b8	iso_packets_buffer_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x663d7724	amdtp_out_stream_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x66ab3698	amdtp_out_stream_get_max_payload
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x68360b54	amdtp_out_stream_pcm_pointer
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8d95eda9	cmp_connection_establish
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x8fec05ac	amdtp_out_stream_set_pcm_format
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0x92c139f8	snd_fw_transaction
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa513e557	fw_iso_resources_free
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xa609091b	cmp_connection_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xb8f7f650	amdtp_out_stream_update
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xbb84fe12	fcp_bus_reset
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc3ae212d	cmp_connection_break
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xc6f96b6d	cmp_connection_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xd98269b7	fw_iso_resources_destroy
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xdc8b039b	iso_packets_buffer_init
++EXPORT_SYMBOL sound/firewire/snd-firewire-lib 0xe444ff77	fw_iso_resources_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x49b2bf3b	snd_ak4114_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0x64a30302	snd_ak4114_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xa575465c	snd_ak4114_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xabbe1b00	snd_ak4114_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xaf0e2d38	snd_ak4114_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4114 0xd843f8bc	snd_ak4114_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x1801b2f7	snd_ak4117_reinit
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x226b6a29	snd_ak4117_create
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x45f6398d	snd_ak4117_check_rate_and_errors
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x692a80ee	snd_ak4117_reg_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0x92718f6a	snd_ak4117_external_rate
++EXPORT_SYMBOL sound/i2c/other/snd-ak4117 0xe309be6e	snd_ak4117_build
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x4498d2e9	snd_akm4xxx_init
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x470bac76	snd_akm4xxx_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0x5e6b8bb1	snd_akm4xxx_write
++EXPORT_SYMBOL sound/i2c/other/snd-ak4xxx-adda 0xfd759bc1	snd_akm4xxx_reset
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x440ffd1b	snd_pt2258_build_controls
++EXPORT_SYMBOL sound/i2c/other/snd-pt2258 0x60365844	snd_pt2258_reset
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x1761fb5c	snd_tea575x_init
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0x495963b7	snd_tea575x_set_freq
++EXPORT_SYMBOL sound/i2c/other/snd-tea575x-tuner 0xc0504f2a	snd_tea575x_exit
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x1b2a202f	snd_cs8427_reg_write
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x4623a0f3	snd_cs8427_iec958_pcm
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0x8995ed16	snd_cs8427_iec958_build
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xb72b804c	snd_cs8427_create
++EXPORT_SYMBOL sound/i2c/snd-cs8427 0xe3d81a69	snd_cs8427_iec958_active
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x2ae079cd	snd_i2c_probeaddr
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x7a672375	snd_i2c_sendbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0x7bfbd560	snd_i2c_readbytes
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xa2dc692c	snd_i2c_bus_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xc76b7812	snd_i2c_device_create
++EXPORT_SYMBOL sound/i2c/snd-i2c 0xfa10c693	snd_i2c_device_free
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x32df10dc	snd_tea6330t_detect
++EXPORT_SYMBOL sound/i2c/snd-tea6330t 0x5f5a137f	snd_tea6330t_update_mixer
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x1e3ce3af	snd_es1688_pcm
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x52a0fc7e	snd_es1688_create
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x591ef8ec	snd_es1688_mixer_write
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0x7e899448	snd_es1688_mixer
++EXPORT_SYMBOL sound/isa/es1688/snd-es1688-lib 0xbae0d3c9	snd_es1688_reset
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x09010bdf	snd_gf1_mem_alloc
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x0b1e6ee5	snd_gf1_write_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x1c1ce117	snd_gus_interrupt
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x29795e71	snd_gf1_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x2e883199	snd_gf1_mem_free
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x35bd6b80	snd_gus_use_dec
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x37e4b257	snd_gf1_delay
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x4525e886	snd_gus_dram_write
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x46db8d67	snd_gf1_lvol_to_gvol_raw
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x482868f1	snd_gf1_dram_addr
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x4a24930b	snd_gf1_mem_lock
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x4e0e3f8c	snd_gus_use_inc
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x50364735	snd_gf1_i_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x6bf5cb3d	snd_gus_create
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x6ff95e92	snd_gf1_poke
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x71061c91	snd_gf1_pcm_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x7559b1f7	snd_gf1_mem_xfree
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x780d97a5	snd_gf1_stop_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x7885dd85	snd_gus_initialize
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x85221a8d	snd_gf1_free_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x852d0603	snd_gf1_look8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0x9a099c55	snd_gf1_ctrl_stop
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xa23bb3d0	snd_gf1_new_mixer
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xb205fc13	snd_gf1_look16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xbe62af8f	snd_gf1_i_write8
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc43a5527	snd_gf1_atten_table
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xc966226f	snd_gf1_i_look16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xca0dde89	snd_gf1_peek
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xcc740b47	snd_gf1_write16
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xe5a80982	snd_gf1_rawmidi_new
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xe8e84346	snd_gf1_alloc_voice
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xebaac333	snd_gus_dram_read
++EXPORT_SYMBOL sound/isa/gus/snd-gus-lib 0xf11ac168	snd_gf1_translate_freq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x08a59825	snd_msndmix_new
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x0e096be3	snd_msnd_init_queue
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x0e9d0be2	snd_msnd_disable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x206dd4f1	snd_msnd_send_dsp_cmd
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x225cc395	snd_msndmix_force_recsrc
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x235945c0	snd_msnd_pcm
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x4ead67b8	snd_msnd_upload_host
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x514fc880	snd_msnd_dsp_halt
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x5e58da47	snd_msnd_DAPQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x75026b24	snd_msndmidi_input_read
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x770b3c1f	snd_msnd_send_word
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x79e848aa	snd_msnd_enable_irq
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0x8b80f859	snd_msnd_DARQ
++EXPORT_SYMBOL sound/isa/msnd/snd-msnd-lib 0xf8a3a850	snd_msndmix_setup
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0x9ff50cb3	snd_aci_cmd
++EXPORT_SYMBOL sound/isa/opti9xx/snd-miro 0xec87c985	snd_aci_get_aci
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x1931e378	snd_sbdsp_get_byte
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x6bb50f86	snd_sbmixer_read
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x8882a645	snd_sbdsp_command
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x8edffcdf	snd_sbmixer_resume
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0x99666791	snd_sbmixer_add_ctl
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xb4724415	snd_sbmixer_write
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xb79d57a4	snd_sbmixer_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xc5a2b254	snd_sbdsp_reset
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xcecba581	snd_sbmixer_suspend
++EXPORT_SYMBOL sound/isa/sb/snd-sb-common 0xec6007d7	snd_sbdsp_create
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-csp 0xbaab8579	snd_sb_csp_new
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x0849a15c	snd_sb16dsp_get_pcm_ops
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0x521fed74	snd_sb16dsp_configure
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xe0b3f690	snd_sb16dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb16-dsp 0xfabb16d5	snd_sb16dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0x148bec5a	snd_sb8dsp_midi_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xb8eaee15	snd_sb8dsp_pcm
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xbeb35b47	snd_sb8dsp_interrupt
++EXPORT_SYMBOL sound/isa/sb/snd-sb8-dsp 0xde6eb1ba	snd_sb8dsp_midi
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x01b6d70a	snd_emu8000_load_reverb_fx
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x06129d74	snd_emu8000_poke
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x1e7af907	snd_emu8000_load_chorus_fx
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x29dca3ee	snd_emu8000_update_chorus_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x431a8f0c	snd_emu8000_poke_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x478c4fcf	snd_emu8000_peek
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x5b2abcd0	snd_emu8000_update_equalizer
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0x9d93c576	snd_emu8000_dma_chan
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xd03af289	snd_emu8000_peek_dw
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xdb55ad1c	snd_emu8000_update_reverb_mode
++EXPORT_SYMBOL sound/isa/sb/snd-sbawe 0xec554cdd	snd_emu8000_init_fm
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x096f178e	snd_wss_put_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x2876db5a	snd_wss_get_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x2ab26bdf	snd_wss_pcm
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x3a8df118	snd_wss_chip_id
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x3e12fdcc	snd_wss_create
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x5de6a302	snd_wss_get_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x6a4f0af5	snd_wss_info_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x72227517	snd_wss_get_pcm_ops
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x741527bb	snd_wss_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x7b202637	snd_wss_interrupt
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x7cff6fd6	snd_wss_put_single
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x81589643	snd_wss_mce_down
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x8327ef8f	snd_cs4236_ext_in
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0x9094ce37	snd_wss_info_double
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xb0132419	snd_wss_timer
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xba24321c	snd_wss_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xd3139849	snd_cs4236_ext_out
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xe6c39d40	snd_wss_overrange
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xe8c82422	snd_wss_mixer
++EXPORT_SYMBOL sound/isa/wss/snd-wss-lib 0xf49cb510	snd_wss_mce_up
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x3bb3486f	snd_ac97_get_short_name
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x4b73c274	snd_ac97_mixer
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x506e9dd3	snd_ac97_update_bits
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x5f8cf8f8	snd_ac97_update_power
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x643b313a	snd_ac97_read
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x718b0f97	snd_ac97_pcm_assign
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x71bec668	snd_ac97_bus
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0x7fff2bc5	snd_ac97_tune_hardware
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb071e600	snd_ac97_pcm_close
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xb9c1da08	snd_ac97_pcm_double_rate_rules
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xc98b4b92	snd_ac97_set_rate
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xcd3864b8	snd_ac97_suspend
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xdb777b73	snd_ac97_pcm_open
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xde37b632	snd_ac97_update
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xeee17fff	snd_ac97_write
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xeff05c83	snd_ac97_write_cache
++EXPORT_SYMBOL sound/pci/ac97/snd-ac97-codec 0xfc469b01	snd_ac97_resume
++EXPORT_SYMBOL sound/pci/asihpi/snd-asihpi 0x7858ffbb	hpi_send_recv
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x06357204	snd_emu10k1_synth_bzero
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x0e17a6aa	snd_emu10k1_ptr_read
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1b729305	snd_emu10k1_synth_copy_from_user
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x1e525411	snd_emu10k1_synth_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x431171b0	snd_emu10k1_voice_free
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8c0b9297	snd_emu10k1_voice_alloc
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0x8f64c64a	snd_emu10k1_memblk_map
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xc963177d	snd_emu10k1_ptr_write
++EXPORT_SYMBOL sound/pci/emu10k1/snd-emu10k1 0xe40060f4	snd_emu10k1_synth_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x132830b5	snd_ice1712_akm4xxx_free
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x3c30fd88	snd_ice1712_akm4xxx_init
++EXPORT_SYMBOL sound/pci/ice1712/snd-ice17xx-ak4xxx 0x9c7b20cf	snd_ice1712_akm4xxx_build_controls
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x014fd5fd	oxygen_write8
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x02142664	oxygen_pci_probe
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x0bf936c0	oxygen_read16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x158af0d2	oxygen_read_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1e2f2862	oxygen_pci_pm
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x1fa6d749	oxygen_write32_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3010b303	oxygen_write_ac97_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x337e6c54	oxygen_write32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x3693e184	oxygen_write_ac97
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x4398455d	oxygen_reset_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0x9880878a	oxygen_write16_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa441011d	oxygen_write_uart
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xa45a168b	oxygen_write16
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb4b98bb8	oxygen_write8_masked
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xb7a56d1a	oxygen_write_i2c
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xc03c593b	oxygen_read32
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xcbf93a09	oxygen_pci_remove
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd6664d20	oxygen_write_spi
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xd8be0fde	oxygen_pci_shutdown
++EXPORT_SYMBOL sound/pci/oxygen/snd-oxygen-lib 0xdc5cc62b	oxygen_read8
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x36e3884d	snd_trident_free_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x4045cb29	snd_trident_stop_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0x82817820	snd_trident_start_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xaec67c7f	snd_trident_alloc_voice
++EXPORT_SYMBOL sound/pci/trident/snd-trident 0xe4e28ba8	snd_trident_write_voice_regs
++EXPORT_SYMBOL sound/soundcore 0x7d5d700a	sound_class
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x08429ec5	snd_emux_lock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x36554ca0	snd_emux_unlock_voice
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x4329ca76	snd_emux_new
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x48670087	snd_emux_free
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x5e54fa45	snd_emux_terminate_all
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x655cb202	snd_sf_linear_to_log
++EXPORT_SYMBOL sound/synth/emux/snd-emux-synth 0x876f3cd2	snd_emux_register
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x0186f011	snd_util_memhdr_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x1ed9cfcb	__snd_util_mem_free
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x229325cb	__snd_util_memblk_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x2ddf3b11	snd_util_memhdr_new
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x8bb193e4	__snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0x931efe13	snd_util_mem_alloc
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xcbbf08e4	snd_util_mem_avail
++EXPORT_SYMBOL sound/synth/snd-util-mem 0xd030913c	snd_util_mem_free
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x16756dc0	snd_usbmidi_input_start
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x3f1fc678	snd_usbmidi_create
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0x63343b1d	snd_usbmidi_input_stop
++EXPORT_SYMBOL sound/usb/snd-usbmidi-lib 0xd9d2bb03	snd_usbmidi_disconnect
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x2160e673	dm_mem_cache_alloc
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x35c95b1b	dm_mem_cache_client_create
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x86e5acf9	dm_mem_cache_grow
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0x920a7a41	dm_message_parse
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xa43471b6	dm_mem_cache_shrink
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xb544fa6c	dm_mem_cache_free
++EXPORT_SYMBOL ubuntu/dm-raid4-5/dm-raid45 0xd55b290c	dm_mem_cache_client_destroy
++EXPORT_SYMBOL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x2776a3e5	lib_ring_buffer_nesting
++EXPORT_SYMBOL vmlinux 0x00000000	softirq_work_list
++EXPORT_SYMBOL vmlinux 0x0026a1ca	mmc_calc_max_discard
++EXPORT_SYMBOL vmlinux 0x0048cfa5	journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x00514eee	padata_do_serial
++EXPORT_SYMBOL vmlinux 0x005f96e5	fifo_set_limit
++EXPORT_SYMBOL vmlinux 0x006b42a2	md_write_start
++EXPORT_SYMBOL vmlinux 0x00801678	flush_scheduled_work
++EXPORT_SYMBOL vmlinux 0x0084e86d	unregister_shrinker
++EXPORT_SYMBOL vmlinux 0x00a7af2b	free_buffer_head
++EXPORT_SYMBOL vmlinux 0x00c52430	ida_simple_get
++EXPORT_SYMBOL vmlinux 0x00e33ccb	jbd2_journal_start_commit
++EXPORT_SYMBOL vmlinux 0x00e8097b	csum_partial_copy_fromiovecend
++EXPORT_SYMBOL vmlinux 0x00fe1ad8	md_wakeup_thread
++EXPORT_SYMBOL vmlinux 0x00fe80ed	gnet_stats_copy_app
++EXPORT_SYMBOL vmlinux 0x01134c1d	soft_cursor
++EXPORT_SYMBOL vmlinux 0x01139ffc	max_mapnr
++EXPORT_SYMBOL vmlinux 0x01156874	__skb_checksum_complete
++EXPORT_SYMBOL vmlinux 0x011952f9	scsi_get_device_flags_keyed
++EXPORT_SYMBOL vmlinux 0x011ae6f5	uart_suspend_port
++EXPORT_SYMBOL vmlinux 0x012e0428	vfs_readv
++EXPORT_SYMBOL vmlinux 0x012f88a0	pcie_set_readrq
++EXPORT_SYMBOL vmlinux 0x0134bd84	blk_pm_runtime_init
++EXPORT_SYMBOL vmlinux 0x01444cd1	idr_replace
++EXPORT_SYMBOL vmlinux 0x0163ede7	scsi_add_host_with_dma
++EXPORT_SYMBOL vmlinux 0x016a5f4d	acpi_pm_device_sleep_state
++EXPORT_SYMBOL vmlinux 0x01705771	simple_readpage
++EXPORT_SYMBOL vmlinux 0x018ba14b	key_invalidate
++EXPORT_SYMBOL vmlinux 0x018e2d21	scsi_remove_target
++EXPORT_SYMBOL vmlinux 0x01902adf	netpoll_trap
++EXPORT_SYMBOL vmlinux 0x01993321	scm_fp_dup
++EXPORT_SYMBOL vmlinux 0x01d19038	acpi_enable_subsystem
++EXPORT_SYMBOL vmlinux 0x0203b0c1	abx500_get_register_interruptible
++EXPORT_SYMBOL vmlinux 0x0203d298	remove_proc_entry
++EXPORT_SYMBOL vmlinux 0x020ba59c	mmc_free_host
++EXPORT_SYMBOL vmlinux 0x02124474	ip_send_check
++EXPORT_SYMBOL vmlinux 0x0237b57a	arch_unregister_cpu
++EXPORT_SYMBOL vmlinux 0x02649054	security_sock_rcv_skb
++EXPORT_SYMBOL vmlinux 0x0270dc19	proto_unregister
++EXPORT_SYMBOL vmlinux 0x0274dc2b	netif_get_num_default_rss_queues
++EXPORT_SYMBOL vmlinux 0x027b8cfb	md_reap_sync_thread
++EXPORT_SYMBOL vmlinux 0x02872748	posix_acl_to_xattr
++EXPORT_SYMBOL vmlinux 0x028a7804	vlan_vids_del_by_dev
++EXPORT_SYMBOL vmlinux 0x029444f0	native_read_tsc
++EXPORT_SYMBOL vmlinux 0x02a18c74	nf_conntrack_destroy
++EXPORT_SYMBOL vmlinux 0x02a6ce5a	crc16_table
++EXPORT_SYMBOL vmlinux 0x02b62737	tcp_md5_do_del
++EXPORT_SYMBOL vmlinux 0x02ee26c1	free_pages_exact
++EXPORT_SYMBOL vmlinux 0x0313724d	request_key_async
++EXPORT_SYMBOL vmlinux 0x0334da4e	scsi_command_size_tbl
++EXPORT_SYMBOL vmlinux 0x033c4996	generic_file_aio_read
++EXPORT_SYMBOL vmlinux 0x033f03aa	key_alloc
++EXPORT_SYMBOL vmlinux 0x0344202c	filp_close
++EXPORT_SYMBOL vmlinux 0x03578fcc	bdi_set_max_ratio
++EXPORT_SYMBOL vmlinux 0x03592ea0	security_unix_stream_connect
++EXPORT_SYMBOL vmlinux 0x0366307a	console_suspend_enabled
++EXPORT_SYMBOL vmlinux 0x037a0cba	kfree
++EXPORT_SYMBOL vmlinux 0x03b580eb	wait_for_completion_killable
++EXPORT_SYMBOL vmlinux 0x03b8e531	tty_unregister_device
++EXPORT_SYMBOL vmlinux 0x03bd889d	param_get_ulong
++EXPORT_SYMBOL vmlinux 0x03c06156	bitmap_fold
++EXPORT_SYMBOL vmlinux 0x03c90f01	__ps2_command
++EXPORT_SYMBOL vmlinux 0x03d8a491	padata_free
++EXPORT_SYMBOL vmlinux 0x03f3ffdc	kernel_sendmsg
++EXPORT_SYMBOL vmlinux 0x03fbf9d0	agp_generic_destroy_page
++EXPORT_SYMBOL vmlinux 0x03fd2571	vm_unmap_ram
++EXPORT_SYMBOL vmlinux 0x0411be2f	security_path_chown
++EXPORT_SYMBOL vmlinux 0x0422fe4a	inet_csk_timer_bug_msg
++EXPORT_SYMBOL vmlinux 0x04482cdb	__refrigerator
++EXPORT_SYMBOL vmlinux 0x044cfc83	pcim_enable_device
++EXPORT_SYMBOL vmlinux 0x044ff670	dev_mc_del
++EXPORT_SYMBOL vmlinux 0x04539151	pipe_lock
++EXPORT_SYMBOL vmlinux 0x046c1f16	param_ops_invbool
++EXPORT_SYMBOL vmlinux 0x04738e84	neigh_update
++EXPORT_SYMBOL vmlinux 0x047b75e9	pci_request_selected_regions
++EXPORT_SYMBOL vmlinux 0x0486d37b	mmc_can_sanitize
++EXPORT_SYMBOL vmlinux 0x0487f831	fb_find_best_display
++EXPORT_SYMBOL vmlinux 0x04922182	scsi_verify_blk_ioctl
++EXPORT_SYMBOL vmlinux 0x04941c8b	ndo_dflt_fdb_del
++EXPORT_SYMBOL vmlinux 0x0499badc	acpi_bios_warning
++EXPORT_SYMBOL vmlinux 0x04d7723c	__genl_register_family
++EXPORT_SYMBOL vmlinux 0x04d8c750	release_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0x04ea56f9	_kstrtol
++EXPORT_SYMBOL vmlinux 0x04edc96b	blk_execute_rq
++EXPORT_SYMBOL vmlinux 0x050877b9	dmi_first_match
++EXPORT_SYMBOL vmlinux 0x0515fa46	jbd2_journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x051db3f7	tcf_em_tree_validate
++EXPORT_SYMBOL vmlinux 0x05240ee7	percpu_counter_batch
++EXPORT_SYMBOL vmlinux 0x053c3304	md_finish_reshape
++EXPORT_SYMBOL vmlinux 0x054434d6	radix_tree_tag_set
++EXPORT_SYMBOL vmlinux 0x055a8ec1	kobject_init
++EXPORT_SYMBOL vmlinux 0x056b2f28	inet_twsk_deschedule
++EXPORT_SYMBOL vmlinux 0x056e6797	input_inject_event
++EXPORT_SYMBOL vmlinux 0x056ee730	ipv6_hash_secret
++EXPORT_SYMBOL vmlinux 0x057ce975	hex_dump_to_buffer
++EXPORT_SYMBOL vmlinux 0x057da6d4	tcp_disconnect
++EXPORT_SYMBOL vmlinux 0x05927f99	unregister_quota_format
++EXPORT_SYMBOL vmlinux 0x0593a99b	init_timer_key
++EXPORT_SYMBOL vmlinux 0x05a82e1e	mmc_set_blockcount
++EXPORT_SYMBOL vmlinux 0x05f55636	i2c_smbus_read_block_data
++EXPORT_SYMBOL vmlinux 0x0601a05a	dma_async_tx_descriptor_init
++EXPORT_SYMBOL vmlinux 0x061651be	strcat
++EXPORT_SYMBOL vmlinux 0x061afdc3	__locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x0634100a	bitmap_parselist_user
++EXPORT_SYMBOL vmlinux 0x064e70eb	request_firmware_nowait
++EXPORT_SYMBOL vmlinux 0x067d8d35	security_release_secctx
++EXPORT_SYMBOL vmlinux 0x0686e63b	request_key_async_with_auxdata
++EXPORT_SYMBOL vmlinux 0x068c7263	ioremap_cache
++EXPORT_SYMBOL vmlinux 0x06be7dd9	spi_dv_device
++EXPORT_SYMBOL vmlinux 0x06c0dae5	__kernel_fpu_end
++EXPORT_SYMBOL vmlinux 0x06d2f086	dma_spin_lock
++EXPORT_SYMBOL vmlinux 0x06e458e0	ida_get_new_above
++EXPORT_SYMBOL vmlinux 0x06ed6f6b	inet6_unregister_icmp_sender
++EXPORT_SYMBOL vmlinux 0x06fb0c6a	lock_sock_fast
++EXPORT_SYMBOL vmlinux 0x06fe3b14	default_grn
++EXPORT_SYMBOL vmlinux 0x0723c6fd	__quota_error
++EXPORT_SYMBOL vmlinux 0x0727c4f3	iowrite8
++EXPORT_SYMBOL vmlinux 0x073dfa12	generate_resume_trace
++EXPORT_SYMBOL vmlinux 0x07608604	acpi_get_vendor_resource
++EXPORT_SYMBOL vmlinux 0x07666245	starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x076ebea8	pv_lock_ops
++EXPORT_SYMBOL vmlinux 0x077ab26a	tty_chars_in_buffer
++EXPORT_SYMBOL vmlinux 0x07864e9b	free_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0x0799aca4	local_bh_enable
++EXPORT_SYMBOL vmlinux 0x079ed5e8	netdev_master_upper_dev_get
++EXPORT_SYMBOL vmlinux 0x07a66cf2	tcf_hash_release
++EXPORT_SYMBOL vmlinux 0x07a890c8	fb_alloc_cmap
++EXPORT_SYMBOL vmlinux 0x07aa3290	acpi_walk_resource_buffer
++EXPORT_SYMBOL vmlinux 0x07abbacd	ida_destroy
++EXPORT_SYMBOL vmlinux 0x07cc4a5d	printk_timed_ratelimit
++EXPORT_SYMBOL vmlinux 0x07d50a24	csum_partial
++EXPORT_SYMBOL vmlinux 0x07d9fb93	skb_free_datagram
++EXPORT_SYMBOL vmlinux 0x07e7a478	dm_kcopyd_copy
++EXPORT_SYMBOL vmlinux 0x082c3213	pci_root_buses
++EXPORT_SYMBOL vmlinux 0x082c7c95	generic_shutdown_super
++EXPORT_SYMBOL vmlinux 0x083ab8c0	account_page_dirtied
++EXPORT_SYMBOL vmlinux 0x083eb21c	rfkill_unregister
++EXPORT_SYMBOL vmlinux 0x0853f4fa	dev_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x08639c98	try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x0897287b	acpi_disable_all_gpes
++EXPORT_SYMBOL vmlinux 0x08b2f5c2	devm_gpio_request
++EXPORT_SYMBOL vmlinux 0x08bf826c	_raw_spin_unlock_bh
++EXPORT_SYMBOL vmlinux 0x0937b415	i2c_smbus_read_byte
++EXPORT_SYMBOL vmlinux 0x09469f79	fsnotify_add_mark
++EXPORT_SYMBOL vmlinux 0x095fde3d	tty_hangup
++EXPORT_SYMBOL vmlinux 0x0961d71a	fb_is_primary_device
++EXPORT_SYMBOL vmlinux 0x09735155	skb_find_text
++EXPORT_SYMBOL vmlinux 0x0989c85d	neigh_ifdown
++EXPORT_SYMBOL vmlinux 0x098b71c6	fb_dealloc_cmap
++EXPORT_SYMBOL vmlinux 0x0992780d	efi_enabled
++EXPORT_SYMBOL vmlinux 0x099a38ca	swiotlb_dma_mapping_error
++EXPORT_SYMBOL vmlinux 0x09b336ce	tcp_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x09bd8df2	__remove_inode_hash
++EXPORT_SYMBOL vmlinux 0x09c55cec	schedule_timeout_interruptible
++EXPORT_SYMBOL vmlinux 0x09c8a981	put_disk
++EXPORT_SYMBOL vmlinux 0x09c8eb55	font_vga_8x16
++EXPORT_SYMBOL vmlinux 0x09ceb87b	pci_scan_root_bus
++EXPORT_SYMBOL vmlinux 0x09d314b2	journal_dirty_data
++EXPORT_SYMBOL vmlinux 0x09d44df9	in_lock_functions
++EXPORT_SYMBOL vmlinux 0x09d4a97a	mddev_congested
++EXPORT_SYMBOL vmlinux 0x09dad8ba	kmap
++EXPORT_SYMBOL vmlinux 0x09f09313	mdiobus_unregister
++EXPORT_SYMBOL vmlinux 0x0a081894	d_invalidate
++EXPORT_SYMBOL vmlinux 0x0a2487e0	unblock_all_signals
++EXPORT_SYMBOL vmlinux 0x0a3131f6	strnchr
++EXPORT_SYMBOL vmlinux 0x0a469d23	mfd_clone_cell
++EXPORT_SYMBOL vmlinux 0x0a4b3664	jbd2_journal_file_inode
++EXPORT_SYMBOL vmlinux 0x0a6a61b4	__devcgroup_inode_permission
++EXPORT_SYMBOL vmlinux 0x0a6edd77	jbd2_journal_free_reserved
++EXPORT_SYMBOL vmlinux 0x0a723d04	netpoll_send_udp
++EXPORT_SYMBOL vmlinux 0x0a74bee4	__f_setown
++EXPORT_SYMBOL vmlinux 0x0ac525e6	register_sysctl
++EXPORT_SYMBOL vmlinux 0x0acb1a3c	__bitmap_shift_right
++EXPORT_SYMBOL vmlinux 0x0acf7679	dma_issue_pending_all
++EXPORT_SYMBOL vmlinux 0x0ae78929	con_copy_unimap
++EXPORT_SYMBOL vmlinux 0x0b0d888b	icmpv6_err_convert
++EXPORT_SYMBOL vmlinux 0x0b1beb31	vmalloc_32_user
++EXPORT_SYMBOL vmlinux 0x0b48677a	__kfifo_init
++EXPORT_SYMBOL vmlinux 0x0b5d45f7	filemap_fdatawait
++EXPORT_SYMBOL vmlinux 0x0b67c9e8	sk_prot_clear_portaddr_nulls
++EXPORT_SYMBOL vmlinux 0x0b742fd7	simple_strtol
++EXPORT_SYMBOL vmlinux 0x0b7f094f	dquot_operations
++EXPORT_SYMBOL vmlinux 0x0bbc5908	gen_estimator_active
++EXPORT_SYMBOL vmlinux 0x0bbd5d63	fib_default_rule_add
++EXPORT_SYMBOL vmlinux 0x0bc1337a	twl6040_reg_write
++EXPORT_SYMBOL vmlinux 0x0bc477a2	irq_set_irq_type
++EXPORT_SYMBOL vmlinux 0x0bd8d841	vlan_dev_vlan_id
++EXPORT_SYMBOL vmlinux 0x0beafcde	gen_pool_for_each_chunk
++EXPORT_SYMBOL vmlinux 0x0c17cff3	blk_integrity_merge_bio
++EXPORT_SYMBOL vmlinux 0x0c23fa0f	set_user_nice
++EXPORT_SYMBOL vmlinux 0x0c58a8cd	netdev_increment_features
++EXPORT_SYMBOL vmlinux 0x0c62668b	max8925_reg_write
++EXPORT_SYMBOL vmlinux 0x0c62c644	d_find_any_alias
++EXPORT_SYMBOL vmlinux 0x0c65e73c	scsi_normalize_sense
++EXPORT_SYMBOL vmlinux 0x0c7650e7	inet_frag_evictor
++EXPORT_SYMBOL vmlinux 0x0c7b04c9	set_groups
++EXPORT_SYMBOL vmlinux 0x0c8c9e99	scsi_show_extd_sense
++EXPORT_SYMBOL vmlinux 0x0c903e85	pci_fixup_cardbus
++EXPORT_SYMBOL vmlinux 0x0c99b881	md_error
++EXPORT_SYMBOL vmlinux 0x0ca7b7a8	acpi_check_region
++EXPORT_SYMBOL vmlinux 0x0cae232b	utf16s_to_utf8s
++EXPORT_SYMBOL vmlinux 0x0cb28f5a	drop_super
++EXPORT_SYMBOL vmlinux 0x0cb72c76	agp_alloc_page_array
++EXPORT_SYMBOL vmlinux 0x0cc89901	dmam_alloc_coherent
++EXPORT_SYMBOL vmlinux 0x0ccd77f8	eth_commit_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x0cd03800	bprm_change_interp
++EXPORT_SYMBOL vmlinux 0x0cdb7d12	__kernel_fpu_begin
++EXPORT_SYMBOL vmlinux 0x0ce5f387	mntput
++EXPORT_SYMBOL vmlinux 0x0cee2c51	abort_creds
++EXPORT_SYMBOL vmlinux 0x0d15406f	notify_change
++EXPORT_SYMBOL vmlinux 0x0d3dda14	acpi_get_type
++EXPORT_SYMBOL vmlinux 0x0d542439	__ipv6_addr_type
++EXPORT_SYMBOL vmlinux 0x0d5ebbaa	padata_remove_cpu
++EXPORT_SYMBOL vmlinux 0x0d71ed5f	generic_pipe_buf_map
++EXPORT_SYMBOL vmlinux 0x0d74d247	journal_get_create_access
++EXPORT_SYMBOL vmlinux 0x0d9d15b0	agp_generic_alloc_by_type
++EXPORT_SYMBOL vmlinux 0x0da10ec3	security_sock_graft
++EXPORT_SYMBOL vmlinux 0x0da3bbb4	do_SAK
++EXPORT_SYMBOL vmlinux 0x0da80f86	xfrm_policy_delete
++EXPORT_SYMBOL vmlinux 0x0dac6345	sock_no_socketpair
++EXPORT_SYMBOL vmlinux 0x0dc84ead	bdput
++EXPORT_SYMBOL vmlinux 0x0dd6d7b5	pci_scan_bus_parented
++EXPORT_SYMBOL vmlinux 0x0df0176b	block_write_full_page_endio
++EXPORT_SYMBOL vmlinux 0x0dff1a86	kernel_getpeername
++EXPORT_SYMBOL vmlinux 0x0e4b48ea	skb_make_writable
++EXPORT_SYMBOL vmlinux 0x0e6780a6	devm_clk_put
++EXPORT_SYMBOL vmlinux 0x0e6da44a	set_normalized_timespec
++EXPORT_SYMBOL vmlinux 0x0e88d828	tcf_em_tree_destroy
++EXPORT_SYMBOL vmlinux 0x0eb71a26	jbd2_journal_start
++EXPORT_SYMBOL vmlinux 0x0ed71af1	elevator_alloc
++EXPORT_SYMBOL vmlinux 0x0ee0852b	pci_set_master
++EXPORT_SYMBOL vmlinux 0x0ee48d6f	ppp_input_error
++EXPORT_SYMBOL vmlinux 0x0ee94e22	inet_frags_exit_net
++EXPORT_SYMBOL vmlinux 0x0eea594e	serio_open
++EXPORT_SYMBOL vmlinux 0x0f1a91ef	file_remove_suid
++EXPORT_SYMBOL vmlinux 0x0f2b6f2e	dget_parent
++EXPORT_SYMBOL vmlinux 0x0f3350d1	nla_append
++EXPORT_SYMBOL vmlinux 0x0f42635e	nf_unregister_hooks
++EXPORT_SYMBOL vmlinux 0x0f430a09	netpoll_send_skb_on_dev
++EXPORT_SYMBOL vmlinux 0x0f4c91ed	ns_to_timespec
++EXPORT_SYMBOL vmlinux 0x0f5d23d2	xfrm_state_add
++EXPORT_SYMBOL vmlinux 0x0f70ced6	skb_realloc_headroom
++EXPORT_SYMBOL vmlinux 0x0fae8294	pcie_capability_write_dword
++EXPORT_SYMBOL vmlinux 0x0faef0ed	__tasklet_schedule
++EXPORT_SYMBOL vmlinux 0x0fb57715	spi_display_xfer_agreement
++EXPORT_SYMBOL vmlinux 0x0fc27406	sb_min_blocksize
++EXPORT_SYMBOL vmlinux 0x0fd00a68	acpi_clear_event
++EXPORT_SYMBOL vmlinux 0x0fd88fc2	jbd2__journal_start
++EXPORT_SYMBOL vmlinux 0x0ff2b602	slhc_compress
++EXPORT_SYMBOL vmlinux 0x0ffdd584	dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x102c56de	irq_regs
++EXPORT_SYMBOL vmlinux 0x10335daa	skb_pad
++EXPORT_SYMBOL vmlinux 0x106f13ab	crc_t10dif_generic
++EXPORT_SYMBOL vmlinux 0x1097520c	tcp_tso_segment
++EXPORT_SYMBOL vmlinux 0x1098fe43	ip_defrag
++EXPORT_SYMBOL vmlinux 0x10ab7e68	down_killable
++EXPORT_SYMBOL vmlinux 0x10c65c93	inet_csk_accept
++EXPORT_SYMBOL vmlinux 0x10ee20bb	default_blu
++EXPORT_SYMBOL vmlinux 0x10f6a863	pv_mmu_ops
++EXPORT_SYMBOL vmlinux 0x11089ac7	_ctype
++EXPORT_SYMBOL vmlinux 0x111b3b85	mpage_writepages
++EXPORT_SYMBOL vmlinux 0x11257aa4	dev_set_drvdata
++EXPORT_SYMBOL vmlinux 0x11267875	scsi_extd_sense_format
++EXPORT_SYMBOL vmlinux 0x11280881	blk_recount_segments
++EXPORT_SYMBOL vmlinux 0x1139d0a0	single_open
++EXPORT_SYMBOL vmlinux 0x114d06cf	tty_unthrottle
++EXPORT_SYMBOL vmlinux 0x11538277	page_symlink_inode_operations
++EXPORT_SYMBOL vmlinux 0x1163473a	bio_map_user
++EXPORT_SYMBOL vmlinux 0x1163f0a7	blk_max_low_pfn
++EXPORT_SYMBOL vmlinux 0x11687720	n_tty_ioctl_helper
++EXPORT_SYMBOL vmlinux 0x117093be	qdisc_class_hash_init
++EXPORT_SYMBOL vmlinux 0x117810e0	xfrm_prepare_input
++EXPORT_SYMBOL vmlinux 0x118305da	ndo_dflt_fdb_dump
++EXPORT_SYMBOL vmlinux 0x119f3794	blk_queue_max_segments
++EXPORT_SYMBOL vmlinux 0x11a9ad8a	ppp_channel_index
++EXPORT_SYMBOL vmlinux 0x11cb3bf9	vfs_fsync_range
++EXPORT_SYMBOL vmlinux 0x11dd01ad	intel_scu_ipc_command
++EXPORT_SYMBOL vmlinux 0x11e2ec12	flex_array_free_parts
++EXPORT_SYMBOL vmlinux 0x11f7ed4c	hex_to_bin
++EXPORT_SYMBOL vmlinux 0x11fd1f8f	__netdev_pick_tx
++EXPORT_SYMBOL vmlinux 0x120513a7	blk_integrity_compare
++EXPORT_SYMBOL vmlinux 0x120b336a	__rb_insert_augmented
++EXPORT_SYMBOL vmlinux 0x1214994c	dst_destroy
++EXPORT_SYMBOL vmlinux 0x122311c3	netlink_ack
++EXPORT_SYMBOL vmlinux 0x12358ef4	gen_pool_add_virt
++EXPORT_SYMBOL vmlinux 0x124b7484	tty_port_init
++EXPORT_SYMBOL vmlinux 0x1272df53	__dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x1287fadf	nf_log_bind_pf
++EXPORT_SYMBOL vmlinux 0x128a5cf9	complete_all
++EXPORT_SYMBOL vmlinux 0x12a38747	usleep_range
++EXPORT_SYMBOL vmlinux 0x12b3f899	xfrm_state_walk
++EXPORT_SYMBOL vmlinux 0x12d12e90	mpage_writepage
++EXPORT_SYMBOL vmlinux 0x12da5bb2	__kmalloc
++EXPORT_SYMBOL vmlinux 0x12dc5d5d	swiotlb_unmap_sg
++EXPORT_SYMBOL vmlinux 0x12eb38a2	__frontswap_load
++EXPORT_SYMBOL vmlinux 0x13127bf6	netdev_refcnt_read
++EXPORT_SYMBOL vmlinux 0x1319d223	input_register_device
++EXPORT_SYMBOL vmlinux 0x131a5fcd	test_set_page_writeback
++EXPORT_SYMBOL vmlinux 0x13204691	blkdev_fsync
++EXPORT_SYMBOL vmlinux 0x13307fde	vsscanf
++EXPORT_SYMBOL vmlinux 0x133be254	nf_log_unregister
++EXPORT_SYMBOL vmlinux 0x1366a30a	sync_inodes_sb
++EXPORT_SYMBOL vmlinux 0x1375edd7	pskb_expand_head
++EXPORT_SYMBOL vmlinux 0x13a27d16	dev_get_stats
++EXPORT_SYMBOL vmlinux 0x13b715e2	blk_finish_plug
++EXPORT_SYMBOL vmlinux 0x13c2c084	names_cachep
++EXPORT_SYMBOL vmlinux 0x13c51089	nf_register_sockopt
++EXPORT_SYMBOL vmlinux 0x13c962cf	pci_set_dma_seg_boundary
++EXPORT_SYMBOL vmlinux 0x13d0adf7	__kfifo_out
++EXPORT_SYMBOL vmlinux 0x13e8d546	xfrm_state_delete_tunnel
++EXPORT_SYMBOL vmlinux 0x13f42152	system_entering_hibernation
++EXPORT_SYMBOL vmlinux 0x13f7f53a	get_user_pages
++EXPORT_SYMBOL vmlinux 0x1402db07	single_release
++EXPORT_SYMBOL vmlinux 0x1406c183	blkdev_get_by_dev
++EXPORT_SYMBOL vmlinux 0x1406ecd5	do_splice_direct
++EXPORT_SYMBOL vmlinux 0x140e2ab5	unlock_new_inode
++EXPORT_SYMBOL vmlinux 0x1420b379	kstrtou16_from_user
++EXPORT_SYMBOL vmlinux 0x1457af1f	current_fs_time
++EXPORT_SYMBOL vmlinux 0x14a5af9e	sock_kmalloc
++EXPORT_SYMBOL vmlinux 0x14b9477e	max8998_bulk_read
++EXPORT_SYMBOL vmlinux 0x14e8230a	ata_port_printk
++EXPORT_SYMBOL vmlinux 0x150389d6	acpi_processor_power_init_bm_check
++EXPORT_SYMBOL vmlinux 0x1512a8c2	fb_validate_mode
++EXPORT_SYMBOL vmlinux 0x152376dc	mmc_gpio_get_ro
++EXPORT_SYMBOL vmlinux 0x15328210	inetdev_by_index
++EXPORT_SYMBOL vmlinux 0x154c6338	dm_kcopyd_client_destroy
++EXPORT_SYMBOL vmlinux 0x1551dc51	bitmap_find_free_region
++EXPORT_SYMBOL vmlinux 0x15692c87	param_ops_int
++EXPORT_SYMBOL vmlinux 0x1573814a	gen_new_estimator
++EXPORT_SYMBOL vmlinux 0x158f6c43	mmc_align_data_size
++EXPORT_SYMBOL vmlinux 0x15b9125f	hdmi_avi_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x15dd4342	pm860x_page_bulk_write
++EXPORT_SYMBOL vmlinux 0x15f0e192	__set_page_dirty_buffers
++EXPORT_SYMBOL vmlinux 0x15f571ec	blk_set_stacking_limits
++EXPORT_SYMBOL vmlinux 0x16061731	spi_release_transport
++EXPORT_SYMBOL vmlinux 0x160ea4c8	sfi_disabled
++EXPORT_SYMBOL vmlinux 0x16305289	warn_slowpath_null
++EXPORT_SYMBOL vmlinux 0x1639b35a	module_refcount
++EXPORT_SYMBOL vmlinux 0x16571156	scsi_dma_map
++EXPORT_SYMBOL vmlinux 0x167e7f9d	__get_user_1
++EXPORT_SYMBOL vmlinux 0x168f1082	_raw_write_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x169c9c0c	dev_getbyhwaddr_rcu
++EXPORT_SYMBOL vmlinux 0x16cf0e3d	__xfrm_route_forward
++EXPORT_SYMBOL vmlinux 0x16e06957	generic_delete_inode
++EXPORT_SYMBOL vmlinux 0x16feddcb	truncate_inode_pages
++EXPORT_SYMBOL vmlinux 0x170c25ee	acpi_get_next_object
++EXPORT_SYMBOL vmlinux 0x171427cd	mmc_wait_for_app_cmd
++EXPORT_SYMBOL vmlinux 0x173488d3	blk_rq_map_kern
++EXPORT_SYMBOL vmlinux 0x1739fc78	adjust_managed_page_count
++EXPORT_SYMBOL vmlinux 0x173ed59a	__block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x174ea6f7	input_mt_report_pointer_emulation
++EXPORT_SYMBOL vmlinux 0x175058d5	scsi_get_command
++EXPORT_SYMBOL vmlinux 0x1779f91c	input_flush_device
++EXPORT_SYMBOL vmlinux 0x1790d76b	_raw_read_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x17a1af79	gnet_stats_start_copy
++EXPORT_SYMBOL vmlinux 0x17a8b14d	inet_accept
++EXPORT_SYMBOL vmlinux 0x17a9f533	blk_put_queue
++EXPORT_SYMBOL vmlinux 0x17b1125d	gen_kill_estimator
++EXPORT_SYMBOL vmlinux 0x17b570b7	serial8250_set_isa_configurator
++EXPORT_SYMBOL vmlinux 0x17c719d5	tcp_md5_hash_skb_data
++EXPORT_SYMBOL vmlinux 0x17f341a0	i8042_lock_chip
++EXPORT_SYMBOL vmlinux 0x17fa81cd	__idr_get_new_above
++EXPORT_SYMBOL vmlinux 0x1800a773	vga_client_register
++EXPORT_SYMBOL vmlinux 0x180d8c81	journal_restart
++EXPORT_SYMBOL vmlinux 0x181b4f23	blk_queue_free_tags
++EXPORT_SYMBOL vmlinux 0x1826f089	__tracepoint_kmem_cache_alloc_node
++EXPORT_SYMBOL vmlinux 0x183fa88b	mempool_alloc_slab
++EXPORT_SYMBOL vmlinux 0x1849640f	done_path_create
++EXPORT_SYMBOL vmlinux 0x184b82fb	mmc_vddrange_to_ocrmask
++EXPORT_SYMBOL vmlinux 0x184e6c85	radix_tree_gang_lookup_slot
++EXPORT_SYMBOL vmlinux 0x18823be7	__xfrm_decode_session
++EXPORT_SYMBOL vmlinux 0x188a3dfb	timespec_trunc
++EXPORT_SYMBOL vmlinux 0x189868d7	get_random_bytes_arch
++EXPORT_SYMBOL vmlinux 0x1898885c	simple_link
++EXPORT_SYMBOL vmlinux 0x18b28e31	scsi_print_command
++EXPORT_SYMBOL vmlinux 0x18b4daad	invalidate_mapping_pages
++EXPORT_SYMBOL vmlinux 0x18cb1fcb	__dynamic_dev_dbg
++EXPORT_SYMBOL vmlinux 0x18d96501	atomic64_dec_if_positive_cx8
++EXPORT_SYMBOL vmlinux 0x18e935c0	__module_put_and_exit
++EXPORT_SYMBOL vmlinux 0x192e4e94	inet6_bind
++EXPORT_SYMBOL vmlinux 0x195ba347	blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x1975a963	md_check_no_bitmap
++EXPORT_SYMBOL vmlinux 0x1976aa06	param_ops_bool
++EXPORT_SYMBOL vmlinux 0x1986965f	dquot_get_dqinfo
++EXPORT_SYMBOL vmlinux 0x19980329	pci_clear_master
++EXPORT_SYMBOL vmlinux 0x199ed0cd	net_disable_timestamp
++EXPORT_SYMBOL vmlinux 0x19a9e62b	complete
++EXPORT_SYMBOL vmlinux 0x19b75dd9	sock_no_connect
++EXPORT_SYMBOL vmlinux 0x19bd383b	security_secmark_refcount_dec
++EXPORT_SYMBOL vmlinux 0x19d7fb72	prepare_binprm
++EXPORT_SYMBOL vmlinux 0x19df48b0	input_mt_destroy_slots
++EXPORT_SYMBOL vmlinux 0x19f96a85	swiotlb_map_sg_attrs
++EXPORT_SYMBOL vmlinux 0x1a277e94	xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x1a2f7541	xfrm_policy_register_afinfo
++EXPORT_SYMBOL vmlinux 0x1a344715	scsi_get_host_dev
++EXPORT_SYMBOL vmlinux 0x1a45cb6c	acpi_disabled
++EXPORT_SYMBOL vmlinux 0x1a49e3e6	acpi_processor_notify_smm
++EXPORT_SYMBOL vmlinux 0x1a4ef030	fget_raw
++EXPORT_SYMBOL vmlinux 0x1a54768f	scsi_device_quiesce
++EXPORT_SYMBOL vmlinux 0x1a63af34	vga_switcheroo_process_delayed_switch
++EXPORT_SYMBOL vmlinux 0x1a6c7848	filemap_fdatawrite
++EXPORT_SYMBOL vmlinux 0x1a71c283	sk_dst_check
++EXPORT_SYMBOL vmlinux 0x1a75ba4e	vlan_untag
++EXPORT_SYMBOL vmlinux 0x1ab4953d	blk_queue_prep_rq
++EXPORT_SYMBOL vmlinux 0x1abc3781	skb_prepare_seq_read
++EXPORT_SYMBOL vmlinux 0x1ace087b	unregister_key_type
++EXPORT_SYMBOL vmlinux 0x1ace138d	bitmap_allocate_region
++EXPORT_SYMBOL vmlinux 0x1ae14ef5	_raw_write_trylock
++EXPORT_SYMBOL vmlinux 0x1aed4410	tcp_valid_rtt_meas
++EXPORT_SYMBOL vmlinux 0x1b015d25	bitmap_parselist
++EXPORT_SYMBOL vmlinux 0x1b0ac272	__tracepoint_kmalloc_node
++EXPORT_SYMBOL vmlinux 0x1b19a7b5	lz4_decompress
++EXPORT_SYMBOL vmlinux 0x1b1e1088	sg_nents
++EXPORT_SYMBOL vmlinux 0x1b35af43	genl_notify
++EXPORT_SYMBOL vmlinux 0x1b3da4d3	console_stop
++EXPORT_SYMBOL vmlinux 0x1b4e9bd7	udp_seq_open
++EXPORT_SYMBOL vmlinux 0x1b507965	napi_get_frags
++EXPORT_SYMBOL vmlinux 0x1b6314fd	in_aton
++EXPORT_SYMBOL vmlinux 0x1b6f355b	get_io_context
++EXPORT_SYMBOL vmlinux 0x1b82fefa	md_unplug
++EXPORT_SYMBOL vmlinux 0x1b8b95ad	i8042_unlock_chip
++EXPORT_SYMBOL vmlinux 0x1b965e4c	inet_csk_init_xmit_timers
++EXPORT_SYMBOL vmlinux 0x1b9e0ff1	scsilun_to_int
++EXPORT_SYMBOL vmlinux 0x1bb42447	delete_from_page_cache
++EXPORT_SYMBOL vmlinux 0x1bb804f8	pci_dev_get
++EXPORT_SYMBOL vmlinux 0x1bbc75cf	devm_iounmap
++EXPORT_SYMBOL vmlinux 0x1bc06e33	__pagevec_release
++EXPORT_SYMBOL vmlinux 0x1bcbf056	pci_prepare_to_sleep
++EXPORT_SYMBOL vmlinux 0x1bdce474	x86_hyper_xen_hvm
++EXPORT_SYMBOL vmlinux 0x1c0c519a	inet_sendpage
++EXPORT_SYMBOL vmlinux 0x1c1414d0	agp_backend_release
++EXPORT_SYMBOL vmlinux 0x1c15c36e	pnp_find_card
++EXPORT_SYMBOL vmlinux 0x1c1a7ba7	sync_inode
++EXPORT_SYMBOL vmlinux 0x1c55943c	unregister_qdisc
++EXPORT_SYMBOL vmlinux 0x1c8a04b0	acpi_reset
++EXPORT_SYMBOL vmlinux 0x1c90d306	tcf_hash_search
++EXPORT_SYMBOL vmlinux 0x1cba7d35	cdrom_check_events
++EXPORT_SYMBOL vmlinux 0x1cd33e2f	__pagevec_lru_add
++EXPORT_SYMBOL vmlinux 0x1ce018c4	inet_csk_destroy_sock
++EXPORT_SYMBOL vmlinux 0x1d12d2d8	gnet_stats_copy_rate_est
++EXPORT_SYMBOL vmlinux 0x1d2b918e	mount_pseudo
++EXPORT_SYMBOL vmlinux 0x1d58933e	ip_mc_leave_group
++EXPORT_SYMBOL vmlinux 0x1d80a940	i2c_master_recv
++EXPORT_SYMBOL vmlinux 0x1d838858	xfrm6_rcv
++EXPORT_SYMBOL vmlinux 0x1d99644c	dma_release_from_coherent
++EXPORT_SYMBOL vmlinux 0x1d9b5e47	get_thermal_instance
++EXPORT_SYMBOL vmlinux 0x1db3bcf9	sk_stream_write_space
++EXPORT_SYMBOL vmlinux 0x1dc36131	fb_destroy_modedb
++EXPORT_SYMBOL vmlinux 0x1dd571e6	fb_copy_cmap
++EXPORT_SYMBOL vmlinux 0x1de4da54	fb_set_suspend
++EXPORT_SYMBOL vmlinux 0x1de8e908	mnt_unpin
++EXPORT_SYMBOL vmlinux 0x1e047854	warn_slowpath_fmt
++EXPORT_SYMBOL vmlinux 0x1e0c2be4	ioremap_wc
++EXPORT_SYMBOL vmlinux 0x1e26be3b	get_anon_bdev
++EXPORT_SYMBOL vmlinux 0x1e2f8241	jbd2_journal_blocks_per_page
++EXPORT_SYMBOL vmlinux 0x1e4c177b	mnt_drop_write_file
++EXPORT_SYMBOL vmlinux 0x1e6766c7	tty_kref_put
++EXPORT_SYMBOL vmlinux 0x1e6d26a8	strstr
++EXPORT_SYMBOL vmlinux 0x1e810b43	insert_inode_locked
++EXPORT_SYMBOL vmlinux 0x1e8dcd9c	kernel_bind
++EXPORT_SYMBOL vmlinux 0x1e8e7574	udp_disconnect
++EXPORT_SYMBOL vmlinux 0x1e9098a1	journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0x1e92bcca	swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL vmlinux 0x1e9a8310	ipv4_specific
++EXPORT_SYMBOL vmlinux 0x1e9edfb7	seq_hlist_start_head_rcu
++EXPORT_SYMBOL vmlinux 0x1eb65282	pci_bus_find_capability
++EXPORT_SYMBOL vmlinux 0x1ec3bed9	hdmi_audio_infoframe_init
++EXPORT_SYMBOL vmlinux 0x1ec4eb34	flex_array_prealloc
++EXPORT_SYMBOL vmlinux 0x1ecf4d67	scsi_free_command
++EXPORT_SYMBOL vmlinux 0x1ed80798	pci_request_region_exclusive
++EXPORT_SYMBOL vmlinux 0x1ee33250	pm_vt_switch_unregister
++EXPORT_SYMBOL vmlinux 0x1ee70a0e	try_to_release_page
++EXPORT_SYMBOL vmlinux 0x1eeab54b	security_path_truncate
++EXPORT_SYMBOL vmlinux 0x1eefece2	fbcon_set_tileops
++EXPORT_SYMBOL vmlinux 0x1f302b4f	pm860x_page_bulk_read
++EXPORT_SYMBOL vmlinux 0x1f4fc7bb	kmem_cache_alloc_trace
++EXPORT_SYMBOL vmlinux 0x1f5a6a5a	jbd2_journal_init_inode
++EXPORT_SYMBOL vmlinux 0x1f7340bc	d_add_ci
++EXPORT_SYMBOL vmlinux 0x1f7e807f	kstrtoint_from_user
++EXPORT_SYMBOL vmlinux 0x1fa0e93a	journal_forget
++EXPORT_SYMBOL vmlinux 0x1faf9d3c	inet_frag_maybe_warn_overflow
++EXPORT_SYMBOL vmlinux 0x1fbd16da	ip_tos2prio
++EXPORT_SYMBOL vmlinux 0x1fc969ce	nf_afinfo
++EXPORT_SYMBOL vmlinux 0x1fd07fff	kdb_grepping_flag
++EXPORT_SYMBOL vmlinux 0x1fe61095	dma_alloc_from_coherent
++EXPORT_SYMBOL vmlinux 0x1fe912f1	netdev_alloc_frag
++EXPORT_SYMBOL vmlinux 0x1fe9f800	unregister_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x1fedf0f4	__request_region
++EXPORT_SYMBOL vmlinux 0x1ff4a21a	phy_ethtool_set_eee
++EXPORT_SYMBOL vmlinux 0x1ffbd46c	remap_vmalloc_range
++EXPORT_SYMBOL vmlinux 0x20000329	simple_strtoul
++EXPORT_SYMBOL vmlinux 0x2005e68a	acpi_remove_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x200ba56d	sock_get_timestampns
++EXPORT_SYMBOL vmlinux 0x203e56f5	pnpacpi_protocol
++EXPORT_SYMBOL vmlinux 0x204c19f5	tcp_alloc_md5sig_pool
++EXPORT_SYMBOL vmlinux 0x2072ee9b	request_threaded_irq
++EXPORT_SYMBOL vmlinux 0x20799a9c	pci_unregister_driver
++EXPORT_SYMBOL vmlinux 0x207a306c	pci_enable_obff
++EXPORT_SYMBOL vmlinux 0x208739f6	acpi_load_table
++EXPORT_SYMBOL vmlinux 0x20a6c423	sock_common_recvmsg
++EXPORT_SYMBOL vmlinux 0x20a789ac	irq_set_chip_data
++EXPORT_SYMBOL vmlinux 0x20b8eb7e	d_path
++EXPORT_SYMBOL vmlinux 0x20c55ae0	sscanf
++EXPORT_SYMBOL vmlinux 0x20c6192f	intel_scu_ipc_ioread32
++EXPORT_SYMBOL vmlinux 0x20d1897f	blk_rq_map_integrity_sg
++EXPORT_SYMBOL vmlinux 0x20de2225	pci_enable_ido
++EXPORT_SYMBOL vmlinux 0x20e3da88	phy_ethtool_sset
++EXPORT_SYMBOL vmlinux 0x20ebd2fe	blk_run_queue_async
++EXPORT_SYMBOL vmlinux 0x2129f75b	sock_wake_async
++EXPORT_SYMBOL vmlinux 0x21315700	param_get_bool
++EXPORT_SYMBOL vmlinux 0x215ebd78	bitrev16
++EXPORT_SYMBOL vmlinux 0x217dda13	flex_array_get
++EXPORT_SYMBOL vmlinux 0x2184b831	phy_scan_fixups
++EXPORT_SYMBOL vmlinux 0x21991125	md_register_thread
++EXPORT_SYMBOL vmlinux 0x2199337a	down_timeout
++EXPORT_SYMBOL vmlinux 0x21b0c729	__neigh_create
++EXPORT_SYMBOL vmlinux 0x21baef2d	blk_queue_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0x21de412a	simple_unlink
++EXPORT_SYMBOL vmlinux 0x21e0ea22	acpi_get_id
++EXPORT_SYMBOL vmlinux 0x21f254b1	set_pages_array_wc
++EXPORT_SYMBOL vmlinux 0x21f654de	dquot_file_open
++EXPORT_SYMBOL vmlinux 0x21fb443e	_raw_spin_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x21fbe6f1	security_dentry_init_security
++EXPORT_SYMBOL vmlinux 0x21fc1e61	tcf_exts_dump_stats
++EXPORT_SYMBOL vmlinux 0x222e7ce2	sysfs_streq
++EXPORT_SYMBOL vmlinux 0x22346e85	md_flush_request
++EXPORT_SYMBOL vmlinux 0x225f1d33	uart_add_one_port
++EXPORT_SYMBOL vmlinux 0x22677b70	serio_unregister_port
++EXPORT_SYMBOL vmlinux 0x2276db98	kstrtoint
++EXPORT_SYMBOL vmlinux 0x22986884	read_cache_pages
++EXPORT_SYMBOL vmlinux 0x22ae25bf	ip6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0x22b325d5	kd_mksound
++EXPORT_SYMBOL vmlinux 0x22b4c19b	seq_bitmap_list
++EXPORT_SYMBOL vmlinux 0x22e45ca6	mmc_detect_card_removed
++EXPORT_SYMBOL vmlinux 0x22e740a5	__xfrm_policy_check
++EXPORT_SYMBOL vmlinux 0x2305b678	bio_endio
++EXPORT_SYMBOL vmlinux 0x2306635f	skb_abort_seq_read
++EXPORT_SYMBOL vmlinux 0x231d4001	fb_edid_add_monspecs
++EXPORT_SYMBOL vmlinux 0x233767f1	skb_checksum
++EXPORT_SYMBOL vmlinux 0x23532c4d	ftrace_print_flags_seq
++EXPORT_SYMBOL vmlinux 0x2378c2f7	pci_unmap_rom
++EXPORT_SYMBOL vmlinux 0x238bed9a	audit_log_start
++EXPORT_SYMBOL vmlinux 0x23917e46	alloc_netdev_mqs
++EXPORT_SYMBOL vmlinux 0x239642d8	flock_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x23a574fd	security_secmark_relabel_packet
++EXPORT_SYMBOL vmlinux 0x23b9d6e2	mangle_path
++EXPORT_SYMBOL vmlinux 0x23c8f257	slhc_uncompress
++EXPORT_SYMBOL vmlinux 0x23d2faf5	ab3100_event_register
++EXPORT_SYMBOL vmlinux 0x23fb0a19	devm_backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0x23fd3028	vmalloc_node
++EXPORT_SYMBOL vmlinux 0x240b5e7e	deactivate_locked_super
++EXPORT_SYMBOL vmlinux 0x240db273	genl_unregister_ops
++EXPORT_SYMBOL vmlinux 0x24212d86	__frontswap_invalidate_page
++EXPORT_SYMBOL vmlinux 0x2428736d	security_inode_init_security
++EXPORT_SYMBOL vmlinux 0x24428be5	strncpy_from_user
++EXPORT_SYMBOL vmlinux 0x2459bbcc	console_set_on_cmdline
++EXPORT_SYMBOL vmlinux 0x247d4ad1	splice_from_pipe_feed
++EXPORT_SYMBOL vmlinux 0x2482e688	vsprintf
++EXPORT_SYMBOL vmlinux 0x2490a4cc	ida_remove
++EXPORT_SYMBOL vmlinux 0x249ca332	unregister_console
++EXPORT_SYMBOL vmlinux 0x24bb974c	tcp_release_cb
++EXPORT_SYMBOL vmlinux 0x24d7b4eb	cancel_delayed_work_sync
++EXPORT_SYMBOL vmlinux 0x24f169fc	down_read_trylock
++EXPORT_SYMBOL vmlinux 0x24fdac79	wake_bit_function
++EXPORT_SYMBOL vmlinux 0x250113b4	memory_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x25277497	rfkill_register
++EXPORT_SYMBOL vmlinux 0x253bdb78	param_get_int
++EXPORT_SYMBOL vmlinux 0x254c8efa	pci_find_capability
++EXPORT_SYMBOL vmlinux 0x25820c64	fs_overflowuid
++EXPORT_SYMBOL vmlinux 0x259ab531	dquot_free_inode
++EXPORT_SYMBOL vmlinux 0x25c677c4	mac_pton
++EXPORT_SYMBOL vmlinux 0x25d8413b	pnp_start_dev
++EXPORT_SYMBOL vmlinux 0x25e9e053	tcf_exts_destroy
++EXPORT_SYMBOL vmlinux 0x25ee8f8a	tcp_make_synack
++EXPORT_SYMBOL vmlinux 0x25fb5c44	acpi_bus_hot_remove_device
++EXPORT_SYMBOL vmlinux 0x260d0169	padata_start
++EXPORT_SYMBOL vmlinux 0x260e1fad	__page_symlink
++EXPORT_SYMBOL vmlinux 0x26234cfe	pci_disable_device
++EXPORT_SYMBOL vmlinux 0x263beb75	ecryptfs_get_versions
++EXPORT_SYMBOL vmlinux 0x2650d835	sysctl_ip_early_demux
++EXPORT_SYMBOL vmlinux 0x26536af0	directly_mappable_cdev_bdi
++EXPORT_SYMBOL vmlinux 0x26584a60	cdrom_media_changed
++EXPORT_SYMBOL vmlinux 0x266f09a5	inet_recvmsg
++EXPORT_SYMBOL vmlinux 0x26852f8e	ida_simple_remove
++EXPORT_SYMBOL vmlinux 0x2685c3d7	__sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x268cc6a2	sys_close
++EXPORT_SYMBOL vmlinux 0x26bb950b	__kfifo_from_user_r
++EXPORT_SYMBOL vmlinux 0x26c8e0c5	pcim_iomap_table
++EXPORT_SYMBOL vmlinux 0x26d955d1	__ww_mutex_lock
++EXPORT_SYMBOL vmlinux 0x26e76fb8	sysctl_udp_wmem_min
++EXPORT_SYMBOL vmlinux 0x26eaf8b5	blk_sync_queue
++EXPORT_SYMBOL vmlinux 0x26f0453a	blk_set_default_limits
++EXPORT_SYMBOL vmlinux 0x26f7d977	__scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x26fd7046	d_alloc_name
++EXPORT_SYMBOL vmlinux 0x27092f2e	blk_queue_alignment_offset
++EXPORT_SYMBOL vmlinux 0x271cba95	acpi_bus_private_data_handler
++EXPORT_SYMBOL vmlinux 0x272a0df8	genl_unregister_mc_group
++EXPORT_SYMBOL vmlinux 0x272d394e	mtrr_del
++EXPORT_SYMBOL vmlinux 0x274a2121	sk_stream_kill_queues
++EXPORT_SYMBOL vmlinux 0x274d08dc	__kfifo_dma_out_prepare
++EXPORT_SYMBOL vmlinux 0x2766a21e	netif_carrier_off
++EXPORT_SYMBOL vmlinux 0x27810361	acpi_os_wait_events_complete
++EXPORT_SYMBOL vmlinux 0x27864d57	memparse
++EXPORT_SYMBOL vmlinux 0x278a66d3	pcix_set_mmrbc
++EXPORT_SYMBOL vmlinux 0x27ae7d0c	ec_transaction
++EXPORT_SYMBOL vmlinux 0x27bac655	generic_file_open
++EXPORT_SYMBOL vmlinux 0x27bbf221	disable_irq_nosync
++EXPORT_SYMBOL vmlinux 0x27c2197f	param_set_short
++EXPORT_SYMBOL vmlinux 0x27c7ff2a	dquot_quotactl_ops
++EXPORT_SYMBOL vmlinux 0x27d5d516	vfs_rmdir
++EXPORT_SYMBOL vmlinux 0x2801e24a	__inet6_hash
++EXPORT_SYMBOL vmlinux 0x28076dcc	security_path_mkdir
++EXPORT_SYMBOL vmlinux 0x281823c5	__kfifo_out_peek
++EXPORT_SYMBOL vmlinux 0x281cf5aa	tcp_seq_open
++EXPORT_SYMBOL vmlinux 0x282b7422	get_write_access
++EXPORT_SYMBOL vmlinux 0x283fc5b2	__get_user_pages
++EXPORT_SYMBOL vmlinux 0x284d2c3d	dev_kfree_skb_irq
++EXPORT_SYMBOL vmlinux 0x28594b50	pfifo_fast_ops
++EXPORT_SYMBOL vmlinux 0x2870fd4f	textsearch_register
++EXPORT_SYMBOL vmlinux 0x2898d7f3	journal_force_commit
++EXPORT_SYMBOL vmlinux 0x289da62c	blk_run_queue
++EXPORT_SYMBOL vmlinux 0x28a2ed02	scsi_build_sense_buffer
++EXPORT_SYMBOL vmlinux 0x28b715a6	isapnp_cfg_end
++EXPORT_SYMBOL vmlinux 0x28e1a6b9	nla_put
++EXPORT_SYMBOL vmlinux 0x290c785c	key_link
++EXPORT_SYMBOL vmlinux 0x291fbd8f	mmc_gpio_request_ro
++EXPORT_SYMBOL vmlinux 0x29537c9e	alloc_chrdev_region
++EXPORT_SYMBOL vmlinux 0x2956938d	journal_abort
++EXPORT_SYMBOL vmlinux 0x296f1b62	vfs_mkdir
++EXPORT_SYMBOL vmlinux 0x29736ac4	I_BDEV
++EXPORT_SYMBOL vmlinux 0x29745608	iw_handler_get_spy
++EXPORT_SYMBOL vmlinux 0x298cdafc	scsi_register_driver
++EXPORT_SYMBOL vmlinux 0x29ac066c	xfrm_stateonly_find
++EXPORT_SYMBOL vmlinux 0x29ed5099	phy_get_eee_err
++EXPORT_SYMBOL vmlinux 0x29fdda53	kstrtos8_from_user
++EXPORT_SYMBOL vmlinux 0x2a093a98	simple_transaction_read
++EXPORT_SYMBOL vmlinux 0x2a0edddb	wireless_send_event
++EXPORT_SYMBOL vmlinux 0x2a303d4d	check_signature
++EXPORT_SYMBOL vmlinux 0x2a37171e	jbd2_journal_flush
++EXPORT_SYMBOL vmlinux 0x2a37d074	dma_pool_free
++EXPORT_SYMBOL vmlinux 0x2a45a7f4	mmc_set_blocklen
++EXPORT_SYMBOL vmlinux 0x2a5053ad	agp_generic_insert_memory
++EXPORT_SYMBOL vmlinux 0x2a5dc25a	blk_alloc_queue
++EXPORT_SYMBOL vmlinux 0x2a5def2f	intel_scu_ipc_iowrite32
++EXPORT_SYMBOL vmlinux 0x2a72e562	build_skb
++EXPORT_SYMBOL vmlinux 0x2a79ac13	clkdev_add
++EXPORT_SYMBOL vmlinux 0x2a880797	tcp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x2aa0e4fc	strncasecmp
++EXPORT_SYMBOL vmlinux 0x2ace1b90	mb_cache_entry_release
++EXPORT_SYMBOL vmlinux 0x2b0ba2b0	scsi_sense_desc_find
++EXPORT_SYMBOL vmlinux 0x2b2ce78b	kstrtos8
++EXPORT_SYMBOL vmlinux 0x2b3b5db9	kill_anon_super
++EXPORT_SYMBOL vmlinux 0x2b3c163e	pnp_unregister_driver
++EXPORT_SYMBOL vmlinux 0x2b45fddc	agp_create_memory
++EXPORT_SYMBOL vmlinux 0x2b5cb4e4	bdget_disk
++EXPORT_SYMBOL vmlinux 0x2b76d554	tcp_shutdown
++EXPORT_SYMBOL vmlinux 0x2b9da7a4	genl_lock
++EXPORT_SYMBOL vmlinux 0x2ba707a8	sysctl_tcp_low_latency
++EXPORT_SYMBOL vmlinux 0x2bb55d6e	acpi_remove_notify_handler
++EXPORT_SYMBOL vmlinux 0x2bc95bd4	memset
++EXPORT_SYMBOL vmlinux 0x2bf31ddf	skb_copy_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x2bf710b3	simple_dir_operations
++EXPORT_SYMBOL vmlinux 0x2bf8d577	sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0x2bfeb410	acpi_get_handle
++EXPORT_SYMBOL vmlinux 0x2c14323a	kstrtol_from_user
++EXPORT_SYMBOL vmlinux 0x2c23359d	mmc_suspend_host
++EXPORT_SYMBOL vmlinux 0x2c256e1f	input_scancode_to_scalar
++EXPORT_SYMBOL vmlinux 0x2c3ed1ae	unregister_nls
++EXPORT_SYMBOL vmlinux 0x2c6c9dbe	__napi_complete
++EXPORT_SYMBOL vmlinux 0x2c7dccc5	generic_file_remap_pages
++EXPORT_SYMBOL vmlinux 0x2c81abab	pm8606_osc_disable
++EXPORT_SYMBOL vmlinux 0x2c85315a	xfrm_alloc_spi
++EXPORT_SYMBOL vmlinux 0x2c900d91	cpufreq_put_global_kobject
++EXPORT_SYMBOL vmlinux 0x2c904120	skb_add_rx_frag
++EXPORT_SYMBOL vmlinux 0x2c955a3c	sync_blockdev
++EXPORT_SYMBOL vmlinux 0x2c9ce6c1	file_ns_capable
++EXPORT_SYMBOL vmlinux 0x2ce0b1c7	sock_no_bind
++EXPORT_SYMBOL vmlinux 0x2ce558e2	inet_register_protosw
++EXPORT_SYMBOL vmlinux 0x2cf54446	__tty_alloc_driver
++EXPORT_SYMBOL vmlinux 0x2d140a58	genl_unlock
++EXPORT_SYMBOL vmlinux 0x2d1aa9c8	mdiobus_read
++EXPORT_SYMBOL vmlinux 0x2d1ebfa3	blk_queue_unprep_rq
++EXPORT_SYMBOL vmlinux 0x2d24b7a0	commit_creds
++EXPORT_SYMBOL vmlinux 0x2d2b5982	kernel_read
++EXPORT_SYMBOL vmlinux 0x2d3385d3	system_wq
++EXPORT_SYMBOL vmlinux 0x2d33cce2	nf_ip6_checksum
++EXPORT_SYMBOL vmlinux 0x2d37342e	cpu_online_mask
++EXPORT_SYMBOL vmlinux 0x2d5facbf	dev_add_offload
++EXPORT_SYMBOL vmlinux 0x2d67a88a	blk_queue_io_opt
++EXPORT_SYMBOL vmlinux 0x2d709f43	user_path_create
++EXPORT_SYMBOL vmlinux 0x2d89342a	scsi_show_sense_hdr
++EXPORT_SYMBOL vmlinux 0x2dd16564	arch_register_cpu
++EXPORT_SYMBOL vmlinux 0x2ddc6bf5	tty_do_resize
++EXPORT_SYMBOL vmlinux 0x2de0644d	sk_send_sigurg
++EXPORT_SYMBOL vmlinux 0x2deda4a1	security_sk_classify_flow
++EXPORT_SYMBOL vmlinux 0x2dedc4c2	acpi_format_exception
++EXPORT_SYMBOL vmlinux 0x2def7f76	rtc_cmos_write
++EXPORT_SYMBOL vmlinux 0x2e03ef6f	xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0x2e1ca751	clk_put
++EXPORT_SYMBOL vmlinux 0x2e2ce9e0	sysctl_tcp_syncookies
++EXPORT_SYMBOL vmlinux 0x2e464556	__getblk
++EXPORT_SYMBOL vmlinux 0x2e60bace	memcpy
++EXPORT_SYMBOL vmlinux 0x2e68d8f2	dev_uc_unsync
++EXPORT_SYMBOL vmlinux 0x2e713b1a	idr_init
++EXPORT_SYMBOL vmlinux 0x2eb5ae37	uart_update_timeout
++EXPORT_SYMBOL vmlinux 0x2ec524ad	__kfifo_in_r
++EXPORT_SYMBOL vmlinux 0x2edd779f	max8925_bulk_read
++EXPORT_SYMBOL vmlinux 0x2eeceb42	sk_chk_filter
++EXPORT_SYMBOL vmlinux 0x2ef1a2de	pci_bus_get
++EXPORT_SYMBOL vmlinux 0x2ef63ad6	scsi_dev_info_list_del_keyed
++EXPORT_SYMBOL vmlinux 0x2f03fc4b	security_secmark_refcount_inc
++EXPORT_SYMBOL vmlinux 0x2f064b55	allocate_resource
++EXPORT_SYMBOL vmlinux 0x2f12f4b2	kdb_current_task
++EXPORT_SYMBOL vmlinux 0x2f287f0d	copy_to_user
++EXPORT_SYMBOL vmlinux 0x2f2f9ab5	sk_stream_wait_close
++EXPORT_SYMBOL vmlinux 0x2f384db3	acpi_is_video_device
++EXPORT_SYMBOL vmlinux 0x2f4f3094	pcim_pin_device
++EXPORT_SYMBOL vmlinux 0x2f73157b	sg_miter_next
++EXPORT_SYMBOL vmlinux 0x2f99f287	dentry_unhash
++EXPORT_SYMBOL vmlinux 0x2faa31c1	give_up_console
++EXPORT_SYMBOL vmlinux 0x2fb6de5d	add_device_randomness
++EXPORT_SYMBOL vmlinux 0x2fe252cc	unregister_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x30001c06	simple_statfs
++EXPORT_SYMBOL vmlinux 0x300d90c5	inode_claim_rsv_space
++EXPORT_SYMBOL vmlinux 0x301acd39	bioset_free
++EXPORT_SYMBOL vmlinux 0x30226ddf	agp_device_command
++EXPORT_SYMBOL vmlinux 0x304f3aae	tty_port_destroy
++EXPORT_SYMBOL vmlinux 0x3054e0a8	pci_disable_msi
++EXPORT_SYMBOL vmlinux 0x305f0080	phy_init_eee
++EXPORT_SYMBOL vmlinux 0x30617a66	set_security_override_from_ctx
++EXPORT_SYMBOL vmlinux 0x30734084	tcf_em_unregister
++EXPORT_SYMBOL vmlinux 0x307504af	__blk_end_request_all
++EXPORT_SYMBOL vmlinux 0x307c2fd0	generic_check_addressable
++EXPORT_SYMBOL vmlinux 0x30950311	cpufreq_get_policy
++EXPORT_SYMBOL vmlinux 0x30a80826	__kfifo_from_user
++EXPORT_SYMBOL vmlinux 0x30b8804d	filemap_write_and_wait_range
++EXPORT_SYMBOL vmlinux 0x30cada8f	radix_tree_next_hole
++EXPORT_SYMBOL vmlinux 0x30d576d1	set_pages_uc
++EXPORT_SYMBOL vmlinux 0x30d98fe4	tcp_prequeue
++EXPORT_SYMBOL vmlinux 0x30e74134	tty_termios_copy_hw
++EXPORT_SYMBOL vmlinux 0x30f7466a	skb_seq_read
++EXPORT_SYMBOL vmlinux 0x3102d70b	frontswap_curr_pages
++EXPORT_SYMBOL vmlinux 0x310917fe	sort
++EXPORT_SYMBOL vmlinux 0x31253336	blkdev_issue_discard
++EXPORT_SYMBOL vmlinux 0x313ad274	bio_add_page
++EXPORT_SYMBOL vmlinux 0x3145216f	pci_dev_present
++EXPORT_SYMBOL vmlinux 0x3147857d	default_red
++EXPORT_SYMBOL vmlinux 0x3188bed3	qdisc_watchdog_cancel
++EXPORT_SYMBOL vmlinux 0x318a8422	sock_no_accept
++EXPORT_SYMBOL vmlinux 0x318b0ce2	dquot_release
++EXPORT_SYMBOL vmlinux 0x318cadb1	reciprocal_value
++EXPORT_SYMBOL vmlinux 0x3191f109	__krealloc
++EXPORT_SYMBOL vmlinux 0x31b7d120	skb_put
++EXPORT_SYMBOL vmlinux 0x31c08df0	__tcf_em_tree_match
++EXPORT_SYMBOL vmlinux 0x31c13c14	sk_release_kernel
++EXPORT_SYMBOL vmlinux 0x31da2fe8	skb_pull
++EXPORT_SYMBOL vmlinux 0x31e2bfb0	acpi_get_hp_hw_control_from_firmware
++EXPORT_SYMBOL vmlinux 0x31e76b57	recalibrate_cpu_khz
++EXPORT_SYMBOL vmlinux 0x31e893be	pci_biosrom_size
++EXPORT_SYMBOL vmlinux 0x31f0bb78	__kmap_atomic_idx
++EXPORT_SYMBOL vmlinux 0x3202435a	wrmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0x3212629e	agp_generic_type_to_mask_type
++EXPORT_SYMBOL vmlinux 0x32183ccf	set_create_files_as
++EXPORT_SYMBOL vmlinux 0x321ed522	bitmap_cond_end_sync
++EXPORT_SYMBOL vmlinux 0x322f48d4	abx500_dump_all_banks
++EXPORT_SYMBOL vmlinux 0x3233ecc3	_dev_info
++EXPORT_SYMBOL vmlinux 0x323968d8	__bforget
++EXPORT_SYMBOL vmlinux 0x3242e245	vfs_fsync
++EXPORT_SYMBOL vmlinux 0x3255972d	hdmi_vendor_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x326425ca	pci_unmap_biosrom
++EXPORT_SYMBOL vmlinux 0x3274b08e	hdmi_avi_infoframe_init
++EXPORT_SYMBOL vmlinux 0x32bb04c8	from_kqid
++EXPORT_SYMBOL vmlinux 0x32c1a931	inode_dio_wait
++EXPORT_SYMBOL vmlinux 0x32cea339	tcp_sockets_allocated
++EXPORT_SYMBOL vmlinux 0x32cf8a88	udp_poll
++EXPORT_SYMBOL vmlinux 0x32d1ed0a	iterate_mounts
++EXPORT_SYMBOL vmlinux 0x32d86b76	phy_device_register
++EXPORT_SYMBOL vmlinux 0x32e1bfeb	netlink_rcv_skb
++EXPORT_SYMBOL vmlinux 0x32eeaded	_raw_write_lock_bh
++EXPORT_SYMBOL vmlinux 0x32f5253b	skb_copy_datagram_from_iovec
++EXPORT_SYMBOL vmlinux 0x330cbdbe	dmam_alloc_noncoherent
++EXPORT_SYMBOL vmlinux 0x3319be88	udp6_csum_init
++EXPORT_SYMBOL vmlinux 0x33226cbc	wait_on_sync_kiocb
++EXPORT_SYMBOL vmlinux 0x33343c6d	tcp_init_sock
++EXPORT_SYMBOL vmlinux 0x333c9380	simple_dir_inode_operations
++EXPORT_SYMBOL vmlinux 0x333e8d31	pcibios_resource_to_bus
++EXPORT_SYMBOL vmlinux 0x333fa25b	dma_mmap_from_coherent
++EXPORT_SYMBOL vmlinux 0x33542f9c	dev_get_drvdata
++EXPORT_SYMBOL vmlinux 0x337cce46	put_cmsg
++EXPORT_SYMBOL vmlinux 0x3380756d	inet6_del_offload
++EXPORT_SYMBOL vmlinux 0x338eef6a	unregister_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x339d69b0	filemap_page_mkwrite
++EXPORT_SYMBOL vmlinux 0x339feb80	xfrm_find_acq
++EXPORT_SYMBOL vmlinux 0x33ab90a3	aio_put_req
++EXPORT_SYMBOL vmlinux 0x33ac417f	acpi_os_hotplug_execute
++EXPORT_SYMBOL vmlinux 0x33ac8944	submit_bh
++EXPORT_SYMBOL vmlinux 0x33c76dfd	crypto_sha1_update
++EXPORT_SYMBOL vmlinux 0x33dbfd93	tcp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x33eb0d83	mmc_can_secure_erase_trim
++EXPORT_SYMBOL vmlinux 0x33f0768c	cpufreq_quick_get_max
++EXPORT_SYMBOL vmlinux 0x34184afe	current_kernel_time
++EXPORT_SYMBOL vmlinux 0x341ec8ae	page_zero_new_buffers
++EXPORT_SYMBOL vmlinux 0x342f60fe	apm_info
++EXPORT_SYMBOL vmlinux 0x3437d4a9	proc_doulongvec_ms_jiffies_minmax
++EXPORT_SYMBOL vmlinux 0x344c9de4	dma_async_device_unregister
++EXPORT_SYMBOL vmlinux 0x344fb323	register_md_personality
++EXPORT_SYMBOL vmlinux 0x34530bd7	submit_bio_wait
++EXPORT_SYMBOL vmlinux 0x3469b3e7	get_super
++EXPORT_SYMBOL vmlinux 0x347013de	nla_validate
++EXPORT_SYMBOL vmlinux 0x347ba844	make_bad_inode
++EXPORT_SYMBOL vmlinux 0x34809b46	arp_xmit
++EXPORT_SYMBOL vmlinux 0x348ed22e	xfrm_spd_getinfo
++EXPORT_SYMBOL vmlinux 0x349cba85	strchr
++EXPORT_SYMBOL vmlinux 0x34b235ca	gnet_stats_copy_basic
++EXPORT_SYMBOL vmlinux 0x34b47ce6	agp_free_memory
++EXPORT_SYMBOL vmlinux 0x34c6cab7	generic_readlink
++EXPORT_SYMBOL vmlinux 0x34c7d676	tcp_timewait_state_process
++EXPORT_SYMBOL vmlinux 0x34e1f833	acpi_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0x34f3484e	security_tun_dev_attach_queue
++EXPORT_SYMBOL vmlinux 0x3517383e	register_reboot_notifier
++EXPORT_SYMBOL vmlinux 0x35445d53	kset_register
++EXPORT_SYMBOL vmlinux 0x35450249	mdiobus_scan
++EXPORT_SYMBOL vmlinux 0x35527339	blk_queue_start_tag
++EXPORT_SYMBOL vmlinux 0x3573bd31	init_buffer
++EXPORT_SYMBOL vmlinux 0x35b028de	blk_queue_dma_pad
++EXPORT_SYMBOL vmlinux 0x35b30d53	mmc_fixup_device
++EXPORT_SYMBOL vmlinux 0x35b35e15	pci_release_region
++EXPORT_SYMBOL vmlinux 0x35b6b772	param_ops_charp
++EXPORT_SYMBOL vmlinux 0x35cf8ea4	tcf_em_tree_dump
++EXPORT_SYMBOL vmlinux 0x35e9db4e	vlan_vid_add
++EXPORT_SYMBOL vmlinux 0x35f51849	fifo_create_dflt
++EXPORT_SYMBOL vmlinux 0x35f8ebf0	ipv6_dev_get_saddr
++EXPORT_SYMBOL vmlinux 0x35fba28a	sock_create_kern
++EXPORT_SYMBOL vmlinux 0x360b1afe	probe_irq_mask
++EXPORT_SYMBOL vmlinux 0x360b8d16	x86_cpu_to_apicid
++EXPORT_SYMBOL vmlinux 0x36164dc1	ps2_sendbyte
++EXPORT_SYMBOL vmlinux 0x3628efd3	xfrm_state_check_expire
++EXPORT_SYMBOL vmlinux 0x362d2645	jbd2_journal_init_dev
++EXPORT_SYMBOL vmlinux 0x362e49e1	mmc_add_host
++EXPORT_SYMBOL vmlinux 0x362ef408	_copy_from_user
++EXPORT_SYMBOL vmlinux 0x364a4c18	xfrm_register_km
++EXPORT_SYMBOL vmlinux 0x367c5531	gen_pool_destroy
++EXPORT_SYMBOL vmlinux 0x3686ea09	spi_print_msg
++EXPORT_SYMBOL vmlinux 0x36aad357	__wake_up_bit
++EXPORT_SYMBOL vmlinux 0x36c6af51	intel_scu_ipc_iowrite8
++EXPORT_SYMBOL vmlinux 0x36e360e3	__hw_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x36ecd6e1	idr_remove
++EXPORT_SYMBOL vmlinux 0x36f9cd94	rcu_is_cpu_idle
++EXPORT_SYMBOL vmlinux 0x371852cb	nlmsg_notify
++EXPORT_SYMBOL vmlinux 0x3721d9cc	__register_chrdev
++EXPORT_SYMBOL vmlinux 0x3744cf36	vmalloc_to_pfn
++EXPORT_SYMBOL vmlinux 0x374fe40c	cpufreq_global_kobject
++EXPORT_SYMBOL vmlinux 0x37544923	dma_common_get_sgtable
++EXPORT_SYMBOL vmlinux 0x37881567	mdiobus_free
++EXPORT_SYMBOL vmlinux 0x37977519	generic_write_checks
++EXPORT_SYMBOL vmlinux 0x37a3c3e7	scsi_set_medium_removal
++EXPORT_SYMBOL vmlinux 0x37a6e267	neigh_event_ns
++EXPORT_SYMBOL vmlinux 0x37b777df	param_set_copystring
++EXPORT_SYMBOL vmlinux 0x37befc70	jiffies_to_msecs
++EXPORT_SYMBOL vmlinux 0x37d56333	lro_flush_pkt
++EXPORT_SYMBOL vmlinux 0x37db8f19	dmi_get_date
++EXPORT_SYMBOL vmlinux 0x37e74642	get_jiffies_64
++EXPORT_SYMBOL vmlinux 0x37f4a7ce	netdev_has_upper_dev
++EXPORT_SYMBOL vmlinux 0x37f614b7	__kfifo_len_r
++EXPORT_SYMBOL vmlinux 0x37f842a5	vc_resize
++EXPORT_SYMBOL vmlinux 0x37ff4c06	copy_from_user_overflow
++EXPORT_SYMBOL vmlinux 0x381144a9	__tracepoint_module_get
++EXPORT_SYMBOL vmlinux 0x381697e8	get_phy_device
++EXPORT_SYMBOL vmlinux 0x381a798a	setup_max_cpus
++EXPORT_SYMBOL vmlinux 0x381ccc13	__kfifo_dma_in_prepare_r
++EXPORT_SYMBOL vmlinux 0x3823129a	xfrm4_rcv
++EXPORT_SYMBOL vmlinux 0x382fc7db	release_pages
++EXPORT_SYMBOL vmlinux 0x38321450	input_mt_report_finger_count
++EXPORT_SYMBOL vmlinux 0x38336f41	dentry_open
++EXPORT_SYMBOL vmlinux 0x38411ba9	search_binary_handler
++EXPORT_SYMBOL vmlinux 0x385e22cf	x86_hyper_ms_hyperv
++EXPORT_SYMBOL vmlinux 0x3868420d	tcp_v4_do_rcv
++EXPORT_SYMBOL vmlinux 0x386db3dd	sock_queue_rcv_skb
++EXPORT_SYMBOL vmlinux 0x3876533a	tty_pair_get_tty
++EXPORT_SYMBOL vmlinux 0x387ad1a4	iget5_locked
++EXPORT_SYMBOL vmlinux 0x38869d88	kstat
++EXPORT_SYMBOL vmlinux 0x388799f6	unregister_kmmio_probe
++EXPORT_SYMBOL vmlinux 0x388f9128	xfrm_state_walk_done
++EXPORT_SYMBOL vmlinux 0x38a71b7e	pci_free_resource_list
++EXPORT_SYMBOL vmlinux 0x38ba8f4a	acpi_gpiochip_free_interrupts
++EXPORT_SYMBOL vmlinux 0x38de35bc	nla_reserve
++EXPORT_SYMBOL vmlinux 0x38ee9269	alloc_disk
++EXPORT_SYMBOL vmlinux 0x3903e8e3	blk_start_queue
++EXPORT_SYMBOL vmlinux 0x3910f3d8	__invalidate_device
++EXPORT_SYMBOL vmlinux 0x39258b2c	netpoll_print_options
++EXPORT_SYMBOL vmlinux 0x39319a33	__dev_getfirstbyhwtype
++EXPORT_SYMBOL vmlinux 0x3939f8f0	rfkill_pause_polling
++EXPORT_SYMBOL vmlinux 0x394e0579	security_inode_notifysecctx
++EXPORT_SYMBOL vmlinux 0x39568d1b	__lock_page
++EXPORT_SYMBOL vmlinux 0x395e8620	ns_capable
++EXPORT_SYMBOL vmlinux 0x397aed53	kblockd_schedule_delayed_work
++EXPORT_SYMBOL vmlinux 0x397c832d	phy_register_fixup_for_uid
++EXPORT_SYMBOL vmlinux 0x3983eb5a	ll_rw_block
++EXPORT_SYMBOL vmlinux 0x39862508	kill_litter_super
++EXPORT_SYMBOL vmlinux 0x39871f22	blk_integrity_is_initialized
++EXPORT_SYMBOL vmlinux 0x3989e031	key_validate
++EXPORT_SYMBOL vmlinux 0x39a055f3	acpi_remove_gpe_handler
++EXPORT_SYMBOL vmlinux 0x39c98d3b	ip_mc_join_group
++EXPORT_SYMBOL vmlinux 0x39f44f71	dev_printk
++EXPORT_SYMBOL vmlinux 0x3a013b7d	remove_wait_queue
++EXPORT_SYMBOL vmlinux 0x3a08475f	platform_thermal_notify
++EXPORT_SYMBOL vmlinux 0x3a32839e	intel_gtt_chipset_flush
++EXPORT_SYMBOL vmlinux 0x3a54551e	__mmc_claim_host
++EXPORT_SYMBOL vmlinux 0x3a5702fc	ip6_expire_frag_queue
++EXPORT_SYMBOL vmlinux 0x3a6030ea	inet6_register_icmp_sender
++EXPORT_SYMBOL vmlinux 0x3a64c3fe	nf_log_unbind_pf
++EXPORT_SYMBOL vmlinux 0x3a866131	ether_setup
++EXPORT_SYMBOL vmlinux 0x3a89b4c5	register_framebuffer
++EXPORT_SYMBOL vmlinux 0x3a9b6fb9	blk_unregister_region
++EXPORT_SYMBOL vmlinux 0x3a9d6643	__free_pages
++EXPORT_SYMBOL vmlinux 0x3adf7157	xfrm_state_insert
++EXPORT_SYMBOL vmlinux 0x3ae81abc	unregister_filesystem
++EXPORT_SYMBOL vmlinux 0x3b1e8549	ppp_unregister_compressor
++EXPORT_SYMBOL vmlinux 0x3b201620	machine_real_restart
++EXPORT_SYMBOL vmlinux 0x3b3d48ac	inode_init_always
++EXPORT_SYMBOL vmlinux 0x3b7375b3	phy_connect
++EXPORT_SYMBOL vmlinux 0x3b76aab9	dquot_set_dqinfo
++EXPORT_SYMBOL vmlinux 0x3b812262	blk_rq_count_integrity_sg
++EXPORT_SYMBOL vmlinux 0x3bd1b1f6	msecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0x3bd3d9ed	input_event
++EXPORT_SYMBOL vmlinux 0x3bef03b9	flow_cache_lookup
++EXPORT_SYMBOL vmlinux 0x3bf85839	netlink_unicast
++EXPORT_SYMBOL vmlinux 0x3c0b31fb	pnp_stop_dev
++EXPORT_SYMBOL vmlinux 0x3c21dd4e	mfd_add_devices
++EXPORT_SYMBOL vmlinux 0x3c2a9824	blk_peek_request
++EXPORT_SYMBOL vmlinux 0x3c3cd6fd	clk_get
++EXPORT_SYMBOL vmlinux 0x3c46a929	tcp_v4_connect
++EXPORT_SYMBOL vmlinux 0x3c62fbf1	register_cdrom
++EXPORT_SYMBOL vmlinux 0x3c80c06c	kstrtoull
++EXPORT_SYMBOL vmlinux 0x3c950790	simple_empty
++EXPORT_SYMBOL vmlinux 0x3c9d1211	string_get_size
++EXPORT_SYMBOL vmlinux 0x3c9d5954	dev_set_allmulti
++EXPORT_SYMBOL vmlinux 0x3c9fe9e8	vga_tryget
++EXPORT_SYMBOL vmlinux 0x3cb3931b	sg_copy_to_buffer
++EXPORT_SYMBOL vmlinux 0x3cbf1970	netdev_features_change
++EXPORT_SYMBOL vmlinux 0x3cd4686a	devfreq_monitor_suspend
++EXPORT_SYMBOL vmlinux 0x3cd68b17	tty_set_operations
++EXPORT_SYMBOL vmlinux 0x3ce4ca6f	disable_irq
++EXPORT_SYMBOL vmlinux 0x3cf312b1	ip6_frag_match
++EXPORT_SYMBOL vmlinux 0x3cf868c1	inet_sk_rebuild_header
++EXPORT_SYMBOL vmlinux 0x3d0008ce	blk_rq_map_user_iov
++EXPORT_SYMBOL vmlinux 0x3d0028fb	uart_remove_one_port
++EXPORT_SYMBOL vmlinux 0x3d36fd5b	gen_pool_alloc
++EXPORT_SYMBOL vmlinux 0x3d3a0a4f	lookup_one_len
++EXPORT_SYMBOL vmlinux 0x3d70f8c7	may_umount_tree
++EXPORT_SYMBOL vmlinux 0x3d7c1ed7	msrs_alloc
++EXPORT_SYMBOL vmlinux 0x3da171f9	pci_mem_start
++EXPORT_SYMBOL vmlinux 0x3dada3d0	input_grab_device
++EXPORT_SYMBOL vmlinux 0x3db7ee18	inet_select_addr
++EXPORT_SYMBOL vmlinux 0x3dbebbb7	tcp_proc_register
++EXPORT_SYMBOL vmlinux 0x3dcb88a0	irq_set_handler_data
++EXPORT_SYMBOL vmlinux 0x3de4c488	tcp_sendmsg
++EXPORT_SYMBOL vmlinux 0x3dfc897c	seq_hlist_start_head
++EXPORT_SYMBOL vmlinux 0x3e0b1693	input_get_keycode
++EXPORT_SYMBOL vmlinux 0x3e294d93	inet_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x3e2ae3a8	acpi_release_global_lock
++EXPORT_SYMBOL vmlinux 0x3e361b28	page_put_link
++EXPORT_SYMBOL vmlinux 0x3e3a5c9e	i2c_smbus_read_word_data
++EXPORT_SYMBOL vmlinux 0x3e3c7be2	scsi_setup_blk_pc_cmnd
++EXPORT_SYMBOL vmlinux 0x3e5925c2	rtnl_set_sk_err
++EXPORT_SYMBOL vmlinux 0x3e60acce	inet6_unregister_protosw
++EXPORT_SYMBOL vmlinux 0x3e882943	pcibios_align_resource
++EXPORT_SYMBOL vmlinux 0x3e9110fa	__hw_addr_unsync
++EXPORT_SYMBOL vmlinux 0x3ea1a74e	tty_pair_get_pty
++EXPORT_SYMBOL vmlinux 0x3ea92af1	bitmap_unplug
++EXPORT_SYMBOL vmlinux 0x3eae292f	param_set_byte
++EXPORT_SYMBOL vmlinux 0x3eaf291d	param_get_string
++EXPORT_SYMBOL vmlinux 0x3ec16c3b	in_group_p
++EXPORT_SYMBOL vmlinux 0x3ed63055	zlib_inflateReset
++EXPORT_SYMBOL vmlinux 0x3ef78d80	vm_get_page_prot
++EXPORT_SYMBOL vmlinux 0x3eff5ac2	intel_scu_ipc_writev
++EXPORT_SYMBOL vmlinux 0x3f0546a8	ioread32_rep
++EXPORT_SYMBOL vmlinux 0x3f14568d	bdi_init
++EXPORT_SYMBOL vmlinux 0x3f1950a9	netdev_crit
++EXPORT_SYMBOL vmlinux 0x3f4547a7	put_unused_fd
++EXPORT_SYMBOL vmlinux 0x3f6880ab	__mutex_init
++EXPORT_SYMBOL vmlinux 0x3f6f6b0b	pagecache_write_begin
++EXPORT_SYMBOL vmlinux 0x3f879531	tcp_enter_memory_pressure
++EXPORT_SYMBOL vmlinux 0x3f9f868f	__percpu_counter_init
++EXPORT_SYMBOL vmlinux 0x3f9ff5f3	pci_disable_ltr
++EXPORT_SYMBOL vmlinux 0x3fa58ef8	wait_for_completion
++EXPORT_SYMBOL vmlinux 0x3fa8afc6	sk_stream_error
++EXPORT_SYMBOL vmlinux 0x3fc77aed	ida_pre_get
++EXPORT_SYMBOL vmlinux 0x3fd28096	idr_alloc_cyclic
++EXPORT_SYMBOL vmlinux 0x3fec048f	sg_next
++EXPORT_SYMBOL vmlinux 0x3ff52c1c	scsi_setup_fs_cmnd
++EXPORT_SYMBOL vmlinux 0x3ff62317	local_bh_disable
++EXPORT_SYMBOL vmlinux 0x3fffb2e2	dev_uc_sync_multiple
++EXPORT_SYMBOL vmlinux 0x402b8281	__request_module
++EXPORT_SYMBOL vmlinux 0x402d18c4	seq_release_private
++EXPORT_SYMBOL vmlinux 0x40332ca7	kern_unmount
++EXPORT_SYMBOL vmlinux 0x404a727b	follow_pfn
++EXPORT_SYMBOL vmlinux 0x404b8753	sock_no_ioctl
++EXPORT_SYMBOL vmlinux 0x404e4694	udp_proc_register
++EXPORT_SYMBOL vmlinux 0x4059792f	print_hex_dump
++EXPORT_SYMBOL vmlinux 0x405c1144	get_seconds
++EXPORT_SYMBOL vmlinux 0x406b7715	mb_cache_entry_find_first
++EXPORT_SYMBOL vmlinux 0x4089df1d	__skb_gso_segment
++EXPORT_SYMBOL vmlinux 0x40973662	sysctl_udp_mem
++EXPORT_SYMBOL vmlinux 0x4097fa45	acpi_read_bit_register
++EXPORT_SYMBOL vmlinux 0x409873e3	tty_termios_baud_rate
++EXPORT_SYMBOL vmlinux 0x40988927	journal_start_commit
++EXPORT_SYMBOL vmlinux 0x40a27c37	scsi_dev_info_remove_list
++EXPORT_SYMBOL vmlinux 0x40a2d1dd	dm_table_get_size
++EXPORT_SYMBOL vmlinux 0x40a9b349	vzalloc
++EXPORT_SYMBOL vmlinux 0x40acaad0	buffer_check_dirty_writeback
++EXPORT_SYMBOL vmlinux 0x40c01859	gen_pool_best_fit
++EXPORT_SYMBOL vmlinux 0x40c7247c	si_meminfo
++EXPORT_SYMBOL vmlinux 0x40c89d46	acpi_get_table_by_index
++EXPORT_SYMBOL vmlinux 0x40d04664	console_trylock
++EXPORT_SYMBOL vmlinux 0x40df8e61	cpu_info
++EXPORT_SYMBOL vmlinux 0x40f48c6d	x86_hyper
++EXPORT_SYMBOL vmlinux 0x40fdd28b	skb_copy_and_csum_dev
++EXPORT_SYMBOL vmlinux 0x410354cf	vfs_write
++EXPORT_SYMBOL vmlinux 0x411f1968	gen_pool_set_algo
++EXPORT_SYMBOL vmlinux 0x4121e0c6	revalidate_disk
++EXPORT_SYMBOL vmlinux 0x41283b44	skb_split
++EXPORT_SYMBOL vmlinux 0x413e264e	phy_driver_register
++EXPORT_SYMBOL vmlinux 0x41482d8b	strndup_user
++EXPORT_SYMBOL vmlinux 0x414c2217	agp_generic_free_by_type
++EXPORT_SYMBOL vmlinux 0x414f988b	mutex_unlock
++EXPORT_SYMBOL vmlinux 0x416e58b8	create_syslog_header
++EXPORT_SYMBOL vmlinux 0x4188d439	neigh_rand_reach_time
++EXPORT_SYMBOL vmlinux 0x418a72e8	pci_bus_assign_resources
++EXPORT_SYMBOL vmlinux 0x41d6cb07	wait_for_completion_io_timeout
++EXPORT_SYMBOL vmlinux 0x41da3530	devfreq_remove_governor
++EXPORT_SYMBOL vmlinux 0x41e06f33	sk_stream_wait_connect
++EXPORT_SYMBOL vmlinux 0x41e4254b	cfb_fillrect
++EXPORT_SYMBOL vmlinux 0x41e943cb	skb_unlink
++EXPORT_SYMBOL vmlinux 0x41f63530	dput
++EXPORT_SYMBOL vmlinux 0x42096e24	finish_open
++EXPORT_SYMBOL vmlinux 0x4211c3c1	zlib_inflateInit2
++EXPORT_SYMBOL vmlinux 0x42350e8d	ucs2_strlen
++EXPORT_SYMBOL vmlinux 0x42355b4f	dcb_getapp
++EXPORT_SYMBOL vmlinux 0x423b6e2b	invalidate_bdev
++EXPORT_SYMBOL vmlinux 0x42595e58	vgacon_text_force
++EXPORT_SYMBOL vmlinux 0x42623979	tty_driver_kref_put
++EXPORT_SYMBOL vmlinux 0x42645680	mmc_detect_change
++EXPORT_SYMBOL vmlinux 0x4265ae6f	netif_skb_features
++EXPORT_SYMBOL vmlinux 0x42831d47	unregister_md_personality
++EXPORT_SYMBOL vmlinux 0x428f24f9	posix_acl_create
++EXPORT_SYMBOL vmlinux 0x4292364c	schedule
++EXPORT_SYMBOL vmlinux 0x42977ad4	__hw_addr_del_multiple
++EXPORT_SYMBOL vmlinux 0x42a1b208	gen_pool_first_fit
++EXPORT_SYMBOL vmlinux 0x42b1cad7	in6_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x42c8de35	ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x42d1ee39	ip6_dst_hoplimit
++EXPORT_SYMBOL vmlinux 0x42e903f8	tty_port_hangup
++EXPORT_SYMBOL vmlinux 0x4302d0eb	free_pages
++EXPORT_SYMBOL vmlinux 0x430f97e3	try_to_writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0x4351577a	fb_parse_edid
++EXPORT_SYMBOL vmlinux 0x4358bc1c	mem_cgroup_subsys
++EXPORT_SYMBOL vmlinux 0x435e8922	sock_i_ino
++EXPORT_SYMBOL vmlinux 0x436c2179	iowrite32
++EXPORT_SYMBOL vmlinux 0x43852d82	mmc_resume_host
++EXPORT_SYMBOL vmlinux 0x438610bd	security_tun_dev_alloc_security
++EXPORT_SYMBOL vmlinux 0x43872a10	blk_end_request
++EXPORT_SYMBOL vmlinux 0x43c7077b	ip_queue_xmit
++EXPORT_SYMBOL vmlinux 0x43f23311	dm_table_get_md
++EXPORT_SYMBOL vmlinux 0x43f541c2	pm860x_reg_read
++EXPORT_SYMBOL vmlinux 0x44007961	vc_cons
++EXPORT_SYMBOL vmlinux 0x4411c503	prandom_seed
++EXPORT_SYMBOL vmlinux 0x44142262	uart_match_port
++EXPORT_SYMBOL vmlinux 0x44158877	bio_integrity_endio
++EXPORT_SYMBOL vmlinux 0x442cc590	dev_emerg
++EXPORT_SYMBOL vmlinux 0x44366cfc	simple_write_to_buffer
++EXPORT_SYMBOL vmlinux 0x44438b96	hex2bin
++EXPORT_SYMBOL vmlinux 0x445a90ed	serio_reconnect
++EXPORT_SYMBOL vmlinux 0x44644022	blkdev_issue_write_same
++EXPORT_SYMBOL vmlinux 0x4470a79b	param_ops_long
++EXPORT_SYMBOL vmlinux 0x44a31695	dquot_resume
++EXPORT_SYMBOL vmlinux 0x44a72311	cdev_del
++EXPORT_SYMBOL vmlinux 0x44aaf30f	tsc_khz
++EXPORT_SYMBOL vmlinux 0x44bf42c3	scsi_free_host_dev
++EXPORT_SYMBOL vmlinux 0x44d2722d	unmap_mapping_range
++EXPORT_SYMBOL vmlinux 0x44e9a829	match_token
++EXPORT_SYMBOL vmlinux 0x44eee430	tcp_close
++EXPORT_SYMBOL vmlinux 0x44f1606d	down_trylock
++EXPORT_SYMBOL vmlinux 0x4502ab8f	acpi_bus_get_device
++EXPORT_SYMBOL vmlinux 0x45081703	ec_get_handle
++EXPORT_SYMBOL vmlinux 0x451827f3	qdisc_reset
++EXPORT_SYMBOL vmlinux 0x453c8403	pci_msi_enabled
++EXPORT_SYMBOL vmlinux 0x454706be	__scm_destroy
++EXPORT_SYMBOL vmlinux 0x4558818a	sock_wmalloc
++EXPORT_SYMBOL vmlinux 0x455a0ae6	rtnl_create_link
++EXPORT_SYMBOL vmlinux 0x4577b0d2	kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x4578661a	_atomic_dec_and_lock
++EXPORT_SYMBOL vmlinux 0x4578f528	__kfifo_to_user
++EXPORT_SYMBOL vmlinux 0x4587efd7	mem_map
++EXPORT_SYMBOL vmlinux 0x4592b569	init_special_inode
++EXPORT_SYMBOL vmlinux 0x45a6be13	cpufreq_sysfs_remove_file
++EXPORT_SYMBOL vmlinux 0x45a765cf	pci_add_resource
++EXPORT_SYMBOL vmlinux 0x45be2211	__put_cred
++EXPORT_SYMBOL vmlinux 0x45c8cd86	ifla_policy
++EXPORT_SYMBOL vmlinux 0x45f681d1	alloc_file
++EXPORT_SYMBOL vmlinux 0x45fd04e4	serio_unregister_child_port
++EXPORT_SYMBOL vmlinux 0x46038d0b	blk_dump_rq_flags
++EXPORT_SYMBOL vmlinux 0x46097d44	jbd2_journal_clear_err
++EXPORT_SYMBOL vmlinux 0x460e7bd3	netdev_rx_csum_fault
++EXPORT_SYMBOL vmlinux 0x4623f571	__cleancache_invalidate_inode
++EXPORT_SYMBOL vmlinux 0x462a2e75	match_strlcpy
++EXPORT_SYMBOL vmlinux 0x465cab34	secure_ipv6_port_ephemeral
++EXPORT_SYMBOL vmlinux 0x46608fa0	getnstimeofday
++EXPORT_SYMBOL vmlinux 0x466c14a7	__delay
++EXPORT_SYMBOL vmlinux 0x466f334f	dcbnl_cee_notify
++EXPORT_SYMBOL vmlinux 0x467cfbd5	pnp_find_dev
++EXPORT_SYMBOL vmlinux 0x4697995b	no_llseek
++EXPORT_SYMBOL vmlinux 0x46b00e16	__get_page_tail
++EXPORT_SYMBOL vmlinux 0x46feb099	dm_read_arg
++EXPORT_SYMBOL vmlinux 0x4708e068	eth_prepare_mac_addr_change
++EXPORT_SYMBOL vmlinux 0x47260d89	cdrom_ioctl
++EXPORT_SYMBOL vmlinux 0x473c49a4	splice_direct_to_actor
++EXPORT_SYMBOL vmlinux 0x47416e14	cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x47478e9a	i2c_add_adapter
++EXPORT_SYMBOL vmlinux 0x475100c2	inet_get_local_port_range
++EXPORT_SYMBOL vmlinux 0x475f010b	acpi_purge_cached_objects
++EXPORT_SYMBOL vmlinux 0x47619d56	tcp_v4_send_check
++EXPORT_SYMBOL vmlinux 0x476593de	keyring_search
++EXPORT_SYMBOL vmlinux 0x478d10b2	ht_destroy_irq
++EXPORT_SYMBOL vmlinux 0x4792c572	down_interruptible
++EXPORT_SYMBOL vmlinux 0x47939e0d	__tasklet_hi_schedule
++EXPORT_SYMBOL vmlinux 0x479c3c86	find_next_zero_bit
++EXPORT_SYMBOL vmlinux 0x47b3f862	radix_tree_lookup_slot
++EXPORT_SYMBOL vmlinux 0x47b6a10f	ftrace_print_symbols_seq
++EXPORT_SYMBOL vmlinux 0x47d679ff	padata_register_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x47fbd964	pm860x_page_set_bits
++EXPORT_SYMBOL vmlinux 0x480f21b8	f_setown
++EXPORT_SYMBOL vmlinux 0x481222f7	ilookup5
++EXPORT_SYMBOL vmlinux 0x48193639	acpi_lid_open
++EXPORT_SYMBOL vmlinux 0x481cb9ab	acpi_enter_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x4827f704	udplite_prot
++EXPORT_SYMBOL vmlinux 0x4845c423	param_array_ops
++EXPORT_SYMBOL vmlinux 0x48512796	ip_ct_attach
++EXPORT_SYMBOL vmlinux 0x4859b8bb	rtc_year_days
++EXPORT_SYMBOL vmlinux 0x486d2f29	dqstats
++EXPORT_SYMBOL vmlinux 0x487d9343	param_ops_ushort
++EXPORT_SYMBOL vmlinux 0x48dccc03	twl6040_set_bits
++EXPORT_SYMBOL vmlinux 0x48fe8c6a	kmalloc_caches
++EXPORT_SYMBOL vmlinux 0x49045426	icmp_err_convert
++EXPORT_SYMBOL vmlinux 0x490bd70f	ip_generic_getfrag
++EXPORT_SYMBOL vmlinux 0x49191cad	genlmsg_multicast_allns
++EXPORT_SYMBOL vmlinux 0x492abe1c	nf_hook_slow
++EXPORT_SYMBOL vmlinux 0x49603fb8	security_sb_copy_data
++EXPORT_SYMBOL vmlinux 0x49721e4e	pci_request_regions
++EXPORT_SYMBOL vmlinux 0x4973936e	uart_register_driver
++EXPORT_SYMBOL vmlinux 0x49751b14	__frontswap_store
++EXPORT_SYMBOL vmlinux 0x49b07aec	tcp_select_initial_window
++EXPORT_SYMBOL vmlinux 0x49b163b8	acpi_bus_scan
++EXPORT_SYMBOL vmlinux 0x49b9e9a5	tcp_syn_ack_timeout
++EXPORT_SYMBOL vmlinux 0x49c51059	sock_common_getsockopt
++EXPORT_SYMBOL vmlinux 0x49d635b6	sk_free
++EXPORT_SYMBOL vmlinux 0x49da1cfd	set_pages_array_uc
++EXPORT_SYMBOL vmlinux 0x4a06d40d	register_filesystem
++EXPORT_SYMBOL vmlinux 0x4a0f7459	vlan_vid_del
++EXPORT_SYMBOL vmlinux 0x4a1c1491	__ht_create_irq
++EXPORT_SYMBOL vmlinux 0x4a1d435d	vga_put
++EXPORT_SYMBOL vmlinux 0x4a20919e	tty_lock_pair
++EXPORT_SYMBOL vmlinux 0x4a358252	__bitmap_subset
++EXPORT_SYMBOL vmlinux 0x4a39c704	inet_sendmsg
++EXPORT_SYMBOL vmlinux 0x4a4a2e0d	netif_stacked_transfer_operstate
++EXPORT_SYMBOL vmlinux 0x4a881179	pci_map_rom
++EXPORT_SYMBOL vmlinux 0x4aa61d3a	blk_requeue_request
++EXPORT_SYMBOL vmlinux 0x4aac232a	scsi_allocate_command
++EXPORT_SYMBOL vmlinux 0x4abbe3c2	vm_brk
++EXPORT_SYMBOL vmlinux 0x4acd93d3	release_resource
++EXPORT_SYMBOL vmlinux 0x4af2fbeb	phy_register_fixup
++EXPORT_SYMBOL vmlinux 0x4afe9a77	scsi_partsize
++EXPORT_SYMBOL vmlinux 0x4b061f88	audit_log
++EXPORT_SYMBOL vmlinux 0x4b085dbf	agp3_generic_configure
++EXPORT_SYMBOL vmlinux 0x4b157110	qdisc_class_hash_grow
++EXPORT_SYMBOL vmlinux 0x4b1e7c25	input_reset_device
++EXPORT_SYMBOL vmlinux 0x4b1ec3e2	kstrtoul_from_user
++EXPORT_SYMBOL vmlinux 0x4b2b76ad	pci_set_ltr
++EXPORT_SYMBOL vmlinux 0x4b34fbf5	block_all_signals
++EXPORT_SYMBOL vmlinux 0x4b4a94bd	__generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x4b51d4e2	scsi_device_get
++EXPORT_SYMBOL vmlinux 0x4b527013	dev_get_flags
++EXPORT_SYMBOL vmlinux 0x4b5324c2	alloc_fcdev
++EXPORT_SYMBOL vmlinux 0x4b590897	padata_alloc_possible
++EXPORT_SYMBOL vmlinux 0x4b5fd49e	dm_kcopyd_do_callback
++EXPORT_SYMBOL vmlinux 0x4b703618	ndisc_mc_map
++EXPORT_SYMBOL vmlinux 0x4b91a8f1	ipv6_setsockopt
++EXPORT_SYMBOL vmlinux 0x4bbfbc00	tty_unlock_pair
++EXPORT_SYMBOL vmlinux 0x4bc4d5a5	__cond_resched_lock
++EXPORT_SYMBOL vmlinux 0x4be85a03	memweight
++EXPORT_SYMBOL vmlinux 0x4bf55511	vmap
++EXPORT_SYMBOL vmlinux 0x4bf5e423	i2c_smbus_write_byte
++EXPORT_SYMBOL vmlinux 0x4bf7b27d	inode_sb_list_lock
++EXPORT_SYMBOL vmlinux 0x4bff4374	pci_disable_msix
++EXPORT_SYMBOL vmlinux 0x4c0c3ea7	km_policy_notify
++EXPORT_SYMBOL vmlinux 0x4c1182cb	bitmap_scnprintf
++EXPORT_SYMBOL vmlinux 0x4c158b84	netif_carrier_on
++EXPORT_SYMBOL vmlinux 0x4c2ae700	strnstr
++EXPORT_SYMBOL vmlinux 0x4c3c8d56	clear_inode
++EXPORT_SYMBOL vmlinux 0x4c41001a	tcp_hashinfo
++EXPORT_SYMBOL vmlinux 0x4c624fbe	generic_setlease
++EXPORT_SYMBOL vmlinux 0x4c6a38ca	dmam_free_coherent
++EXPORT_SYMBOL vmlinux 0x4c9941c4	ps2_handle_ack
++EXPORT_SYMBOL vmlinux 0x4c996cd2	phy_drivers_register
++EXPORT_SYMBOL vmlinux 0x4ca6f8b8	sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x4ca770d0	agp_generic_alloc_user
++EXPORT_SYMBOL vmlinux 0x4cbbd171	__bitmap_weight
++EXPORT_SYMBOL vmlinux 0x4cc2fbb6	journal_init_inode
++EXPORT_SYMBOL vmlinux 0x4cd35836	seq_put_decimal_ll
++EXPORT_SYMBOL vmlinux 0x4cdb2884	mmc_read_bkops_status
++EXPORT_SYMBOL vmlinux 0x4cdb3178	ns_to_timeval
++EXPORT_SYMBOL vmlinux 0x4cf00bd0	loop_register_transfer
++EXPORT_SYMBOL vmlinux 0x4d161e4a	crypto_sha256_update
++EXPORT_SYMBOL vmlinux 0x4d1b3ab3	read_cache_page
++EXPORT_SYMBOL vmlinux 0x4d3c153f	sigprocmask
++EXPORT_SYMBOL vmlinux 0x4d405db8	param_ops_string
++EXPORT_SYMBOL vmlinux 0x4d40d5fa	rtnl_link_get_net
++EXPORT_SYMBOL vmlinux 0x4d45d89e	udp_memory_allocated
++EXPORT_SYMBOL vmlinux 0x4d5596aa	jbd2_journal_set_triggers
++EXPORT_SYMBOL vmlinux 0x4d5c29f6	ip_route_input_noref
++EXPORT_SYMBOL vmlinux 0x4d8ee16e	seq_open
++EXPORT_SYMBOL vmlinux 0x4d974b9c	register_sysrq_key
++EXPORT_SYMBOL vmlinux 0x4d9b652b	rb_erase
++EXPORT_SYMBOL vmlinux 0x4daa360a	acpi_resource_to_address64
++EXPORT_SYMBOL vmlinux 0x4db46a8d	find_get_pages_contig
++EXPORT_SYMBOL vmlinux 0x4de34a07	cpu_rmap_put
++EXPORT_SYMBOL vmlinux 0x4de418f9	stop_tty
++EXPORT_SYMBOL vmlinux 0x4de76346	jbd2_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0x4dec2d1c	kthread_stop
++EXPORT_SYMBOL vmlinux 0x4df119fa	__bitmap_parse
++EXPORT_SYMBOL vmlinux 0x4e078e32	i2c_smbus_write_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x4e1732c0	dentry_path_raw
++EXPORT_SYMBOL vmlinux 0x4e3567f7	match_int
++EXPORT_SYMBOL vmlinux 0x4e3af489	blkdev_get
++EXPORT_SYMBOL vmlinux 0x4e537a6a	xfrm_policy_alloc
++EXPORT_SYMBOL vmlinux 0x4e64cbe5	register_sysctl_paths
++EXPORT_SYMBOL vmlinux 0x4e6cccb2	dst_alloc
++EXPORT_SYMBOL vmlinux 0x4e6e8ea7	fg_console
++EXPORT_SYMBOL vmlinux 0x4e71d87e	journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x4e830a3e	strnicmp
++EXPORT_SYMBOL vmlinux 0x4e855811	netdev_err
++EXPORT_SYMBOL vmlinux 0x4e8e4842	nf_unregister_hook
++EXPORT_SYMBOL vmlinux 0x4e92143c	eth_mac_addr
++EXPORT_SYMBOL vmlinux 0x4ea25709	dql_reset
++EXPORT_SYMBOL vmlinux 0x4eaa1798	mmc_try_claim_host
++EXPORT_SYMBOL vmlinux 0x4ebc9741	lease_get_mtime
++EXPORT_SYMBOL vmlinux 0x4ee06c53	sockfd_lookup
++EXPORT_SYMBOL vmlinux 0x4ef1163a	generic_listxattr
++EXPORT_SYMBOL vmlinux 0x4f092abf	kernel_write
++EXPORT_SYMBOL vmlinux 0x4f09d76b	mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x4f1cd128	security_tun_dev_create
++EXPORT_SYMBOL vmlinux 0x4f384082	mmc_register_driver
++EXPORT_SYMBOL vmlinux 0x4f391d0e	nla_parse
++EXPORT_SYMBOL vmlinux 0x4f476e96	init_cdrom_command
++EXPORT_SYMBOL vmlinux 0x4f68e5c9	do_gettimeofday
++EXPORT_SYMBOL vmlinux 0x4f6b0fc3	security_path_chmod
++EXPORT_SYMBOL vmlinux 0x4f6d4427	security_d_instantiate
++EXPORT_SYMBOL vmlinux 0x4f783f30	acpi_read
++EXPORT_SYMBOL vmlinux 0x4f866821	bio_map_kern
++EXPORT_SYMBOL vmlinux 0x4f9927e3	scsi_host_set_state
++EXPORT_SYMBOL vmlinux 0x4fa4691c	nobh_write_begin
++EXPORT_SYMBOL vmlinux 0x4fd7da64	mmc_can_discard
++EXPORT_SYMBOL vmlinux 0x4fdee897	i8042_command
++EXPORT_SYMBOL vmlinux 0x4ffd51e9	security_sb_set_mnt_opts
++EXPORT_SYMBOL vmlinux 0x50097088	security_tun_dev_free_security
++EXPORT_SYMBOL vmlinux 0x50192e45	padata_unregister_cpumask_notifier
++EXPORT_SYMBOL vmlinux 0x501d30a0	devm_gpio_free
++EXPORT_SYMBOL vmlinux 0x503b66a0	sk_run_filter
++EXPORT_SYMBOL vmlinux 0x50529870	acpi_get_gpe_status
++EXPORT_SYMBOL vmlinux 0x50540ff0	clocksource_register
++EXPORT_SYMBOL vmlinux 0x505b498c	input_close_device
++EXPORT_SYMBOL vmlinux 0x506f0802	dev_get_by_name
++EXPORT_SYMBOL vmlinux 0x50b6a010	sock_recvmsg
++EXPORT_SYMBOL vmlinux 0x50d68377	arch_phys_wc_del
++EXPORT_SYMBOL vmlinux 0x50eedeb8	printk
++EXPORT_SYMBOL vmlinux 0x5118c382	secure_dccp_sequence_number
++EXPORT_SYMBOL vmlinux 0x5124235a	do_sync_write
++EXPORT_SYMBOL vmlinux 0x5143c678	param_get_invbool
++EXPORT_SYMBOL vmlinux 0x5152e605	memcmp
++EXPORT_SYMBOL vmlinux 0x5162f714	softnet_data
++EXPORT_SYMBOL vmlinux 0x5183c1ad	neigh_seq_next
++EXPORT_SYMBOL vmlinux 0x5186518f	profile_pc
++EXPORT_SYMBOL vmlinux 0x5189d5d1	security_mmap_file
++EXPORT_SYMBOL vmlinux 0x518eb478	netdev_emerg
++EXPORT_SYMBOL vmlinux 0x51a43366	pci_bus_read_config_byte
++EXPORT_SYMBOL vmlinux 0x51ac945d	bio_init
++EXPORT_SYMBOL vmlinux 0x51b1c552	dma_sync_wait
++EXPORT_SYMBOL vmlinux 0x51cbf751	lock_sock_nested
++EXPORT_SYMBOL vmlinux 0x51d12d4e	acpi_pci_disabled
++EXPORT_SYMBOL vmlinux 0x51dce73b	xfrm_state_walk_init
++EXPORT_SYMBOL vmlinux 0x51dfd340	dev_alert
++EXPORT_SYMBOL vmlinux 0x51ef33b8	kstrndup
++EXPORT_SYMBOL vmlinux 0x51f57c23	ip6_route_output
++EXPORT_SYMBOL vmlinux 0x51fd3370	devfreq_resume_device
++EXPORT_SYMBOL vmlinux 0x52006d56	acpi_walk_resources
++EXPORT_SYMBOL vmlinux 0x52026cdf	security_sb_parse_opts_str
++EXPORT_SYMBOL vmlinux 0x5206459c	proc_dointvec_ms_jiffies
++EXPORT_SYMBOL vmlinux 0x52095e19	acpi_get_data
++EXPORT_SYMBOL vmlinux 0x5209ec62	__pskb_copy
++EXPORT_SYMBOL vmlinux 0x520d5193	rawv6_mh_filter_unregister
++EXPORT_SYMBOL vmlinux 0x521b36b5	qdisc_put_rtab
++EXPORT_SYMBOL vmlinux 0x522b18b2	__scsi_put_command
++EXPORT_SYMBOL vmlinux 0x5237835e	ipv6_skip_exthdr
++EXPORT_SYMBOL vmlinux 0x523a210d	ppp_unit_number
++EXPORT_SYMBOL vmlinux 0x52428cc8	parent_mem_cgroup
++EXPORT_SYMBOL vmlinux 0x525e026f	acpi_os_unmap_generic_address
++EXPORT_SYMBOL vmlinux 0x5267aed0	scsi_host_get
++EXPORT_SYMBOL vmlinux 0x527b11e4	quota_send_warning
++EXPORT_SYMBOL vmlinux 0x528c709d	simple_read_from_buffer
++EXPORT_SYMBOL vmlinux 0x52a4a98e	__register_binfmt
++EXPORT_SYMBOL vmlinux 0x52a5c0f4	clk_add_alias
++EXPORT_SYMBOL vmlinux 0x52d42c95	set_current_groups
++EXPORT_SYMBOL vmlinux 0x52d9632e	udp_ioctl
++EXPORT_SYMBOL vmlinux 0x52faeb59	noop_llseek
++EXPORT_SYMBOL vmlinux 0x530b1e4c	rdmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0x530b1e98	pm_suspend
++EXPORT_SYMBOL vmlinux 0x531b604e	__virt_addr_valid
++EXPORT_SYMBOL vmlinux 0x53326531	mempool_alloc_pages
++EXPORT_SYMBOL vmlinux 0x53329d05	do_splice_from
++EXPORT_SYMBOL vmlinux 0x5336d6bb	__scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0x5354befe	__sk_backlog_rcv
++EXPORT_SYMBOL vmlinux 0x535becdb	ip_check_defrag
++EXPORT_SYMBOL vmlinux 0x53787835	xfrm_init_replay
++EXPORT_SYMBOL vmlinux 0x5383f34b	_raw_spin_trylock
++EXPORT_SYMBOL vmlinux 0x5388407d	pnp_register_card_driver
++EXPORT_SYMBOL vmlinux 0x5392588a	journal_update_format
++EXPORT_SYMBOL vmlinux 0x53b0fbe8	single_open_size
++EXPORT_SYMBOL vmlinux 0x53bec2c1	pci_clear_mwi
++EXPORT_SYMBOL vmlinux 0x53f2ef10	wait_for_completion_interruptible
++EXPORT_SYMBOL vmlinux 0x5409775b	free_irq_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x54152e04	percpu_counter_compare
++EXPORT_SYMBOL vmlinux 0x5427b44a	nf_nat_decode_session_hook
++EXPORT_SYMBOL vmlinux 0x543ef284	seq_hlist_start
++EXPORT_SYMBOL vmlinux 0x544b0c11	acpi_lid_notifier_register
++EXPORT_SYMBOL vmlinux 0x54593eb7	brioctl_set
++EXPORT_SYMBOL vmlinux 0x5464538f	__idr_remove_all
++EXPORT_SYMBOL vmlinux 0x548c7dc5	pci_fixup_device
++EXPORT_SYMBOL vmlinux 0x54935666	acpi_os_read_port
++EXPORT_SYMBOL vmlinux 0x54a0cfd5	dev_mc_sync
++EXPORT_SYMBOL vmlinux 0x54a2c133	tcp_syn_flood_action
++EXPORT_SYMBOL vmlinux 0x54a9db5f	_kstrtoul
++EXPORT_SYMBOL vmlinux 0x54aca69c	inet_proto_csum_replace16
++EXPORT_SYMBOL vmlinux 0x54bb68af	cdrom_open
++EXPORT_SYMBOL vmlinux 0x54c5de33	scsi_register
++EXPORT_SYMBOL vmlinux 0x54dd9c96	inet_frag_destroy
++EXPORT_SYMBOL vmlinux 0x54e6fcdd	net_enable_timestamp
++EXPORT_SYMBOL vmlinux 0x54efb5d6	cpu_number
++EXPORT_SYMBOL vmlinux 0x54f21cff	__send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x5500261b	set_trace_device
++EXPORT_SYMBOL vmlinux 0x551bd071	__rb_erase_color
++EXPORT_SYMBOL vmlinux 0x55236365	scsi_report_device_reset
++EXPORT_SYMBOL vmlinux 0x5541ea93	on_each_cpu
++EXPORT_SYMBOL vmlinux 0x5567c227	kernel_cpustat
++EXPORT_SYMBOL vmlinux 0x55688fa2	ip_mc_rejoin_groups
++EXPORT_SYMBOL vmlinux 0x5594be03	bitmap_remap
++EXPORT_SYMBOL vmlinux 0x55a4efea	sk_reset_txq
++EXPORT_SYMBOL vmlinux 0x55c4a7ed	seq_path
++EXPORT_SYMBOL vmlinux 0x55e2857b	blk_rq_unmap_user
++EXPORT_SYMBOL vmlinux 0x5614b010	xfrm_policy_walk_done
++EXPORT_SYMBOL vmlinux 0x562269d8	blk_init_tags
++EXPORT_SYMBOL vmlinux 0x5625d3e9	blk_queue_dma_alignment
++EXPORT_SYMBOL vmlinux 0x5635a60a	vmalloc_user
++EXPORT_SYMBOL vmlinux 0x5641fbbb	path_get
++EXPORT_SYMBOL vmlinux 0x5642793a	radix_tree_tag_clear
++EXPORT_SYMBOL vmlinux 0x564405eb	pci_read_vpd
++EXPORT_SYMBOL vmlinux 0x566262f0	dmam_free_noncoherent
++EXPORT_SYMBOL vmlinux 0x56687ab8	elv_rb_del
++EXPORT_SYMBOL vmlinux 0x5676a3e5	intel_scu_ipc_ioread8
++EXPORT_SYMBOL vmlinux 0x5676f10e	simple_lookup
++EXPORT_SYMBOL vmlinux 0x56862f29	pnpbios_protocol
++EXPORT_SYMBOL vmlinux 0x569b3f61	ftrace_raw_output_prep
++EXPORT_SYMBOL vmlinux 0x56a98d64	kmem_cache_destroy
++EXPORT_SYMBOL vmlinux 0x56ae68db	dev_get_by_index_rcu
++EXPORT_SYMBOL vmlinux 0x56b53816	kill_pgrp
++EXPORT_SYMBOL vmlinux 0x56c8799d	scsi_kunmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x56e3215e	simple_release_fs
++EXPORT_SYMBOL vmlinux 0x56e612a4	dmam_pool_create
++EXPORT_SYMBOL vmlinux 0x56e765fe	xfrm_input
++EXPORT_SYMBOL vmlinux 0x5705088a	__vmalloc
++EXPORT_SYMBOL vmlinux 0x572e85d4	blk_lookup_devt
++EXPORT_SYMBOL vmlinux 0x57575f08	dmaengine_put
++EXPORT_SYMBOL vmlinux 0x575af70c	on_each_cpu_mask
++EXPORT_SYMBOL vmlinux 0x5762519f	datagram_poll
++EXPORT_SYMBOL vmlinux 0x57674fd7	__sw_hweight16
++EXPORT_SYMBOL vmlinux 0x576965f1	tty_register_device
++EXPORT_SYMBOL vmlinux 0x57831067	devfreq_suspend_device
++EXPORT_SYMBOL vmlinux 0x579fbcd2	cpu_possible_mask
++EXPORT_SYMBOL vmlinux 0x57aa793a	max8925_reg_read
++EXPORT_SYMBOL vmlinux 0x57cf10d1	sock_diag_put_filterinfo
++EXPORT_SYMBOL vmlinux 0x57d5f5d6	netif_set_xps_queue
++EXPORT_SYMBOL vmlinux 0x5813eb04	__nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0x582c08cc	skb_copy_and_csum_datagram_iovec
++EXPORT_SYMBOL vmlinux 0x5838f6c9	rtc_valid_tm
++EXPORT_SYMBOL vmlinux 0x583c1a93	security_sb_clone_mnt_opts
++EXPORT_SYMBOL vmlinux 0x58455dc8	unlink_framebuffer
++EXPORT_SYMBOL vmlinux 0x584738f9	rdmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x5857b225	ioread16_rep
++EXPORT_SYMBOL vmlinux 0x586103be	acpi_setup_gpe_for_wake
++EXPORT_SYMBOL vmlinux 0x5866555c	ppp_output_wakeup
++EXPORT_SYMBOL vmlinux 0x5889f5d3	nf_getsockopt
++EXPORT_SYMBOL vmlinux 0x588ae5c9	dquot_quota_on_mount
++EXPORT_SYMBOL vmlinux 0x5892d54c	acpi_remove_address_space_handler
++EXPORT_SYMBOL vmlinux 0x58db5ab0	kill_block_super
++EXPORT_SYMBOL vmlinux 0x58e34d7b	vlan_vids_add_by_dev
++EXPORT_SYMBOL vmlinux 0x58ead07a	netdev_notify_peers
++EXPORT_SYMBOL vmlinux 0x58fd6973	generic_file_buffered_write
++EXPORT_SYMBOL vmlinux 0x58fef6f8	ist_info
++EXPORT_SYMBOL vmlinux 0x59122a64	scsi_report_bus_reset
++EXPORT_SYMBOL vmlinux 0x592989cc	pci_reenable_device
++EXPORT_SYMBOL vmlinux 0x592b59af	acpi_evaluate_object_typed
++EXPORT_SYMBOL vmlinux 0x59335df9	__lru_cache_add
++EXPORT_SYMBOL vmlinux 0x593460b7	netif_rx
++EXPORT_SYMBOL vmlinux 0x593c7081	security_old_inode_init_security
++EXPORT_SYMBOL vmlinux 0x594bf15b	ioport_map
++EXPORT_SYMBOL vmlinux 0x595613a5	napi_complete
++EXPORT_SYMBOL vmlinux 0x59590ca6	bio_phys_segments
++EXPORT_SYMBOL vmlinux 0x596ac76d	put_page
++EXPORT_SYMBOL vmlinux 0x596b546f	vm_insert_pfn
++EXPORT_SYMBOL vmlinux 0x59791a5b	abx500_get_chip_id
++EXPORT_SYMBOL vmlinux 0x599d5935	scsi_host_lookup
++EXPORT_SYMBOL vmlinux 0x59bbe825	pcie_get_readrq
++EXPORT_SYMBOL vmlinux 0x59bc9609	acpi_write_bit_register
++EXPORT_SYMBOL vmlinux 0x5a2aa62e	__wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0x5a363ab0	blk_queue_bounce
++EXPORT_SYMBOL vmlinux 0x5a38cd16	iget_locked
++EXPORT_SYMBOL vmlinux 0x5a4896a8	__put_user_2
++EXPORT_SYMBOL vmlinux 0x5a5845a0	blk_integrity_unregister
++EXPORT_SYMBOL vmlinux 0x5a61efde	pnp_device_attach
++EXPORT_SYMBOL vmlinux 0x5a8c9da8	acpi_video_backlight_quirks
++EXPORT_SYMBOL vmlinux 0x5a906b0d	ilookup5_nowait
++EXPORT_SYMBOL vmlinux 0x5ab14c31	tcp_mtup_init
++EXPORT_SYMBOL vmlinux 0x5ac21822	irq_stat
++EXPORT_SYMBOL vmlinux 0x5ac376a5	acpi_install_fixed_event_handler
++EXPORT_SYMBOL vmlinux 0x5ad0004c	splice_from_pipe_begin
++EXPORT_SYMBOL vmlinux 0x5b0efa01	pci_enable_msix
++EXPORT_SYMBOL vmlinux 0x5b0f8ed8	set_pages_array_wb
++EXPORT_SYMBOL vmlinux 0x5b19634d	div_s64_rem
++EXPORT_SYMBOL vmlinux 0x5b271d86	acpi_video_dmi_promote_vendor
++EXPORT_SYMBOL vmlinux 0x5b334567	mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0x5b3c4eb7	ip6_xmit
++EXPORT_SYMBOL vmlinux 0x5b6c1afb	scsi_target_quiesce
++EXPORT_SYMBOL vmlinux 0x5b757f9e	lock_fb_info
++EXPORT_SYMBOL vmlinux 0x5b7c3c4c	ww_mutex_unlock
++EXPORT_SYMBOL vmlinux 0x5b7f7c15	da903x_query_status
++EXPORT_SYMBOL vmlinux 0x5ba18b86	pci_enable_device
++EXPORT_SYMBOL vmlinux 0x5ba53020	vfs_fstat
++EXPORT_SYMBOL vmlinux 0x5bb722e4	kmem_cache_shrink
++EXPORT_SYMBOL vmlinux 0x5bb82444	iw_handler_get_thrspy
++EXPORT_SYMBOL vmlinux 0x5bc4cc88	scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x5bf9204a	seq_write
++EXPORT_SYMBOL vmlinux 0x5c045cee	pci_set_dma_max_seg_size
++EXPORT_SYMBOL vmlinux 0x5c3edd59	_raw_write_unlock_bh
++EXPORT_SYMBOL vmlinux 0x5c49d9c1	ip_setsockopt
++EXPORT_SYMBOL vmlinux 0x5c545234	ucs2_strncmp
++EXPORT_SYMBOL vmlinux 0x5c6a7c3a	lock_may_read
++EXPORT_SYMBOL vmlinux 0x5c6e9939	frontswap_register_ops
++EXPORT_SYMBOL vmlinux 0x5ca90ef2	xfrm_state_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0x5cac2006	journal_stop
++EXPORT_SYMBOL vmlinux 0x5cb72483	__napi_schedule
++EXPORT_SYMBOL vmlinux 0x5cd07d36	elv_rq_merge_ok
++EXPORT_SYMBOL vmlinux 0x5cf53ce2	input_free_minor
++EXPORT_SYMBOL vmlinux 0x5cf5dc0f	dev_uc_sync
++EXPORT_SYMBOL vmlinux 0x5cf7059d	tty_port_open
++EXPORT_SYMBOL vmlinux 0x5d0b1892	param_set_invbool
++EXPORT_SYMBOL vmlinux 0x5d0b5414	journal_get_write_access
++EXPORT_SYMBOL vmlinux 0x5d327347	kthread_create_on_node
++EXPORT_SYMBOL vmlinux 0x5d418a63	udp_lib_get_port
++EXPORT_SYMBOL vmlinux 0x5d548945	cancel_dirty_page
++EXPORT_SYMBOL vmlinux 0x5d550c4d	scsi_sd_probe_domain
++EXPORT_SYMBOL vmlinux 0x5d57fe93	should_remove_suid
++EXPORT_SYMBOL vmlinux 0x5d5b5a16	radix_tree_delete
++EXPORT_SYMBOL vmlinux 0x5d5bc096	tcp_connect
++EXPORT_SYMBOL vmlinux 0x5d69d09a	contig_page_data
++EXPORT_SYMBOL vmlinux 0x5d6f34e5	redirty_page_for_writepage
++EXPORT_SYMBOL vmlinux 0x5d74dbcf	pnp_range_reserved
++EXPORT_SYMBOL vmlinux 0x5d90e086	default_llseek
++EXPORT_SYMBOL vmlinux 0x5d9840c3	phy_stop_interrupts
++EXPORT_SYMBOL vmlinux 0x5d9a7a85	cdev_init
++EXPORT_SYMBOL vmlinux 0x5da60abe	nf_register_hook
++EXPORT_SYMBOL vmlinux 0x5db2116a	unregister_cdrom
++EXPORT_SYMBOL vmlinux 0x5db35d7d	dev_trans_start
++EXPORT_SYMBOL vmlinux 0x5dc491b3	unlock_page
++EXPORT_SYMBOL vmlinux 0x5dcc426e	replace_mount_options
++EXPORT_SYMBOL vmlinux 0x5dce6b75	complete_and_exit
++EXPORT_SYMBOL vmlinux 0x5ddc8a81	lro_receive_frags
++EXPORT_SYMBOL vmlinux 0x5de6d674	first_ec
++EXPORT_SYMBOL vmlinux 0x5e3333ec	input_mt_assign_slots
++EXPORT_SYMBOL vmlinux 0x5e5ff465	key_payload_reserve
++EXPORT_SYMBOL vmlinux 0x5e7bd427	tcp_setsockopt
++EXPORT_SYMBOL vmlinux 0x5e7e82ab	agp_allocate_memory
++EXPORT_SYMBOL vmlinux 0x5e95b1cd	current_umask
++EXPORT_SYMBOL vmlinux 0x5e9687d5	pneigh_lookup
++EXPORT_SYMBOL vmlinux 0x5e99be61	__cleancache_get_page
++EXPORT_SYMBOL vmlinux 0x5eb24829	dm_shift_arg
++EXPORT_SYMBOL vmlinux 0x5ed040b0	pm_set_vt_switch
++EXPORT_SYMBOL vmlinux 0x5f005368	kstrtou8
++EXPORT_SYMBOL vmlinux 0x5f1a4ccf	intel_scu_ipc_update_register
++EXPORT_SYMBOL vmlinux 0x5f27544a	mempool_destroy
++EXPORT_SYMBOL vmlinux 0x5f347340	sdev_enable_disk_events
++EXPORT_SYMBOL vmlinux 0x5f3c8f5c	mmc_assume_removable
++EXPORT_SYMBOL vmlinux 0x5f476e44	inet_sk_rx_dst_set
++EXPORT_SYMBOL vmlinux 0x5f52eb1d	netdev_upper_dev_unlink
++EXPORT_SYMBOL vmlinux 0x5f58f676	flex_array_get_ptr
++EXPORT_SYMBOL vmlinux 0x5f7157f5	path_put
++EXPORT_SYMBOL vmlinux 0x5f96c741	i2c_get_adapter
++EXPORT_SYMBOL vmlinux 0x5f9e37cc	pci_dev_put
++EXPORT_SYMBOL vmlinux 0x5fa0c1a2	generic_pipe_buf_release
++EXPORT_SYMBOL vmlinux 0x5fa78f99	current_task
++EXPORT_SYMBOL vmlinux 0x5fb6a8e7	bio_integrity_tag_size
++EXPORT_SYMBOL vmlinux 0x5fc0ff7d	pci_enable_msi_block
++EXPORT_SYMBOL vmlinux 0x5fc329e3	tty_port_put
++EXPORT_SYMBOL vmlinux 0x5fdb6cbd	d_tmpfile
++EXPORT_SYMBOL vmlinux 0x5fe41fb6	percpu_counter_set
++EXPORT_SYMBOL vmlinux 0x5feb077b	filemap_flush
++EXPORT_SYMBOL vmlinux 0x5ff42b08	acpi_video_get_capabilities
++EXPORT_SYMBOL vmlinux 0x60060481	xfrm_state_alloc
++EXPORT_SYMBOL vmlinux 0x600683d3	do_unblank_screen
++EXPORT_SYMBOL vmlinux 0x601e62e0	inode_sub_bytes
++EXPORT_SYMBOL vmlinux 0x601f665f	dm_io_client_create
++EXPORT_SYMBOL vmlinux 0x602ed00d	acpi_current_gpe_count
++EXPORT_SYMBOL vmlinux 0x60352082	register_inet6addr_notifier
++EXPORT_SYMBOL vmlinux 0x606c89ba	dev_printk_emit
++EXPORT_SYMBOL vmlinux 0x606d0b09	secure_tcpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0x6071503d	pci_stop_and_remove_bus_device
++EXPORT_SYMBOL vmlinux 0x6073465c	__nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0x6082adec	pci_back_from_sleep
++EXPORT_SYMBOL vmlinux 0x609f1c7e	synchronize_net
++EXPORT_SYMBOL vmlinux 0x60a32ea9	pm_power_off
++EXPORT_SYMBOL vmlinux 0x60b2e38a	rwsem_down_write_failed
++EXPORT_SYMBOL vmlinux 0x60b86f61	sg_pcopy_to_buffer
++EXPORT_SYMBOL vmlinux 0x60d1d9b0	abx500_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0x611bcc76	bio_get_nr_vecs
++EXPORT_SYMBOL vmlinux 0x612390ad	netpoll_set_trap
++EXPORT_SYMBOL vmlinux 0x6128b5fc	__printk_ratelimit
++EXPORT_SYMBOL vmlinux 0x613eeec5	__serio_register_driver
++EXPORT_SYMBOL vmlinux 0x614122d4	__nlmsg_put
++EXPORT_SYMBOL vmlinux 0x614383c0	acpi_get_object_info
++EXPORT_SYMBOL vmlinux 0x61528b43	kobject_get
++EXPORT_SYMBOL vmlinux 0x61584e88	generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0x617643a2	param_set_long
++EXPORT_SYMBOL vmlinux 0x6190d7aa	xfrm_policy_byid
++EXPORT_SYMBOL vmlinux 0x6194c10d	ping_prot
++EXPORT_SYMBOL vmlinux 0x619b187b	add_wait_queue_exclusive
++EXPORT_SYMBOL vmlinux 0x61b203d6	max8998_update_reg
++EXPORT_SYMBOL vmlinux 0x61b455ce	set_security_override
++EXPORT_SYMBOL vmlinux 0x61b5ade0	down_write
++EXPORT_SYMBOL vmlinux 0x61b7b126	simple_strtoull
++EXPORT_SYMBOL vmlinux 0x61c426dc	simple_transaction_set
++EXPORT_SYMBOL vmlinux 0x61de5813	prepare_creds
++EXPORT_SYMBOL vmlinux 0x62049256	acpi_disable
++EXPORT_SYMBOL vmlinux 0x620da6c5	journal_clear_err
++EXPORT_SYMBOL vmlinux 0x62139c35	dev_addr_init
++EXPORT_SYMBOL vmlinux 0x6214aef2	cpufreq_unregister_notifier
++EXPORT_SYMBOL vmlinux 0x621d77a0	sleep_on
++EXPORT_SYMBOL vmlinux 0x6225637e	md5_transform
++EXPORT_SYMBOL vmlinux 0x6226b9fa	machine_to_phys_mapping
++EXPORT_SYMBOL vmlinux 0x6228c21f	smp_call_function_single
++EXPORT_SYMBOL vmlinux 0x622fa02a	prepare_to_wait
++EXPORT_SYMBOL vmlinux 0x623206ff	mb_cache_create
++EXPORT_SYMBOL vmlinux 0x6237f6b5	acpi_enable_event
++EXPORT_SYMBOL vmlinux 0x624198a9	dev_uc_del
++EXPORT_SYMBOL vmlinux 0x6241a2ab	__copy_from_user_ll_nocache
++EXPORT_SYMBOL vmlinux 0x624e1283	rtnl_configure_link
++EXPORT_SYMBOL vmlinux 0x626fe452	neigh_direct_output
++EXPORT_SYMBOL vmlinux 0x62737e1d	sock_unregister
++EXPORT_SYMBOL vmlinux 0x62822d05	iov_iter_single_seg_count
++EXPORT_SYMBOL vmlinux 0x62827bec	security_secctx_to_secid
++EXPORT_SYMBOL vmlinux 0x628364f2	scsi_remove_host
++EXPORT_SYMBOL vmlinux 0x62849ac7	dev_valid_name
++EXPORT_SYMBOL vmlinux 0x6294ae2c	bio_unmap_user
++EXPORT_SYMBOL vmlinux 0x62cb4cee	interruptible_sleep_on
++EXPORT_SYMBOL vmlinux 0x62d3ec3c	scsi_block_when_processing_errors
++EXPORT_SYMBOL vmlinux 0x62e749bf	kunmap
++EXPORT_SYMBOL vmlinux 0x62f9bdc0	i8042_remove_filter
++EXPORT_SYMBOL vmlinux 0x62fd6207	param_set_charp
++EXPORT_SYMBOL vmlinux 0x62fffac7	simple_getattr
++EXPORT_SYMBOL vmlinux 0x63187451	pcie_aspm_support_enabled
++EXPORT_SYMBOL vmlinux 0x631e7343	mount_bdev
++EXPORT_SYMBOL vmlinux 0x632b7d54	unlock_buffer
++EXPORT_SYMBOL vmlinux 0x632d8da2	jbd2_journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0x633d51e2	genl_register_ops
++EXPORT_SYMBOL vmlinux 0x634176e0	dm_get_mapinfo
++EXPORT_SYMBOL vmlinux 0x6355963a	dev_remove_offload
++EXPORT_SYMBOL vmlinux 0x636a5691	acpi_register_ioapic
++EXPORT_SYMBOL vmlinux 0x63847ec8	qdisc_create_dflt
++EXPORT_SYMBOL vmlinux 0x6384dc09	zero_fill_bio
++EXPORT_SYMBOL vmlinux 0x63922bbd	vfs_stat
++EXPORT_SYMBOL vmlinux 0x63980a80	kernel_sendpage
++EXPORT_SYMBOL vmlinux 0x63a01291	acpi_leave_sleep_state_prep
++EXPORT_SYMBOL vmlinux 0x63ae0138	intel_gtt_get
++EXPORT_SYMBOL vmlinux 0x63b1e44f	consume_skb
++EXPORT_SYMBOL vmlinux 0x63c182f0	udp_sendmsg
++EXPORT_SYMBOL vmlinux 0x63d6f18f	scsi_is_sdev_device
++EXPORT_SYMBOL vmlinux 0x63df5afc	journal_extend
++EXPORT_SYMBOL vmlinux 0x63eb9355	panic_blink
++EXPORT_SYMBOL vmlinux 0x63fc232f	strlen_user
++EXPORT_SYMBOL vmlinux 0x6403e338	tcp_memory_pressure
++EXPORT_SYMBOL vmlinux 0x6413f515	blk_init_queue
++EXPORT_SYMBOL vmlinux 0x64254c6b	kfree_skb_list
++EXPORT_SYMBOL vmlinux 0x6478134c	ec_burst_enable
++EXPORT_SYMBOL vmlinux 0x6487b7b2	unmap_underlying_metadata
++EXPORT_SYMBOL vmlinux 0x648e8853	twl6040_power
++EXPORT_SYMBOL vmlinux 0x64999478	congestion_wait
++EXPORT_SYMBOL vmlinux 0x64a4b84d	cpu_rmap_update
++EXPORT_SYMBOL vmlinux 0x64a52ade	block_write_begin
++EXPORT_SYMBOL vmlinux 0x64a99071	fsnotify_alloc_group
++EXPORT_SYMBOL vmlinux 0x64eae7ad	set_memory_array_wb
++EXPORT_SYMBOL vmlinux 0x650a6767	prandom_u32_state
++EXPORT_SYMBOL vmlinux 0x65125138	acpi_check_address_range
++EXPORT_SYMBOL vmlinux 0x6513a3fa	fb_get_color_depth
++EXPORT_SYMBOL vmlinux 0x651a4139	test_taint
++EXPORT_SYMBOL vmlinux 0x651a625c	inode_newsize_ok
++EXPORT_SYMBOL vmlinux 0x65408378	zlib_inflate_blob
++EXPORT_SYMBOL vmlinux 0x6546ac44	get_gendisk
++EXPORT_SYMBOL vmlinux 0x65557c97	__find_get_block
++EXPORT_SYMBOL vmlinux 0x655f1ab0	set_memory_array_wc
++EXPORT_SYMBOL vmlinux 0x6565d33f	scsi_kmap_atomic_sg
++EXPORT_SYMBOL vmlinux 0x657879ce	__init_rwsem
++EXPORT_SYMBOL vmlinux 0x657babe6	pci_find_bus
++EXPORT_SYMBOL vmlinux 0x6585e310	alloc_pages_exact_nid
++EXPORT_SYMBOL vmlinux 0x65a295bb	atomic64_xchg_cx8
++EXPORT_SYMBOL vmlinux 0x65af3b82	skb_mac_gso_segment
++EXPORT_SYMBOL vmlinux 0x65b75a17	tcp_child_process
++EXPORT_SYMBOL vmlinux 0x65d67a20	blk_start_plug
++EXPORT_SYMBOL vmlinux 0x65d9e877	cpufreq_register_notifier
++EXPORT_SYMBOL vmlinux 0x65dccf13	xz_dec_end
++EXPORT_SYMBOL vmlinux 0x65f3ad9a	fb_videomode_to_var
++EXPORT_SYMBOL vmlinux 0x6605f97f	flex_array_clear
++EXPORT_SYMBOL vmlinux 0x661e7874	__serio_register_port
++EXPORT_SYMBOL vmlinux 0x66309a90	input_alloc_absinfo
++EXPORT_SYMBOL vmlinux 0x66355efc	vprintk
++EXPORT_SYMBOL vmlinux 0x663f7cd0	acpi_install_table_handler
++EXPORT_SYMBOL vmlinux 0x667b90cf	vm_insert_page
++EXPORT_SYMBOL vmlinux 0x667e5c35	fddi_type_trans
++EXPORT_SYMBOL vmlinux 0x668da8d5	zlib_inflateIncomp
++EXPORT_SYMBOL vmlinux 0x66a47efa	kmalloc_dma_caches
++EXPORT_SYMBOL vmlinux 0x66a67dab	flex_array_shrink
++EXPORT_SYMBOL vmlinux 0x66a76224	tty_driver_flush_buffer
++EXPORT_SYMBOL vmlinux 0x66b7023b	d_instantiate_unique
++EXPORT_SYMBOL vmlinux 0x66bc4800	dquot_alloc_inode
++EXPORT_SYMBOL vmlinux 0x66c8b825	cpu_sibling_map
++EXPORT_SYMBOL vmlinux 0x66ca91ee	cdrom_number_of_slots
++EXPORT_SYMBOL vmlinux 0x66e40ee1	dquot_mark_dquot_dirty
++EXPORT_SYMBOL vmlinux 0x66e45217	eth_header_parse
++EXPORT_SYMBOL vmlinux 0x66ef3877	xfrm_garbage_collect
++EXPORT_SYMBOL vmlinux 0x66f24370	release_firmware
++EXPORT_SYMBOL vmlinux 0x66f3e7e2	dma_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0x67149966	security_task_getsecid
++EXPORT_SYMBOL vmlinux 0x6729d3df	__get_user_4
++EXPORT_SYMBOL vmlinux 0x673b9eb9	devm_free_irq
++EXPORT_SYMBOL vmlinux 0x673f815e	agp_bridges
++EXPORT_SYMBOL vmlinux 0x6752a618	bdev_read_only
++EXPORT_SYMBOL vmlinux 0x6777c327	blk_queue_logical_block_size
++EXPORT_SYMBOL vmlinux 0x6791e406	dev_open
++EXPORT_SYMBOL vmlinux 0x67a89074	generic_file_readonly_mmap
++EXPORT_SYMBOL vmlinux 0x67b27ec1	tty_std_termios
++EXPORT_SYMBOL vmlinux 0x67b78eb3	seq_hlist_next_rcu
++EXPORT_SYMBOL vmlinux 0x67ce6107	nf_unregister_sockopt
++EXPORT_SYMBOL vmlinux 0x67d4adf6	agp_copy_info
++EXPORT_SYMBOL vmlinux 0x67dcffb7	lg_lock_init
++EXPORT_SYMBOL vmlinux 0x67f62ff3	generic_block_fiemap
++EXPORT_SYMBOL vmlinux 0x67f7403e	_raw_spin_lock
++EXPORT_SYMBOL vmlinux 0x6813b5cb	fb_find_mode
++EXPORT_SYMBOL vmlinux 0x68171464	pid_task
++EXPORT_SYMBOL vmlinux 0x6852a3d1	key_reject_and_link
++EXPORT_SYMBOL vmlinux 0x6874e503	security_path_link
++EXPORT_SYMBOL vmlinux 0x687b6a16	kdbgetsymval
++EXPORT_SYMBOL vmlinux 0x687baa6b	inet_frags_init_net
++EXPORT_SYMBOL vmlinux 0x688137c5	journal_flush
++EXPORT_SYMBOL vmlinux 0x688c4710	kill_fasync
++EXPORT_SYMBOL vmlinux 0x68936bb1	ip_mc_inc_group
++EXPORT_SYMBOL vmlinux 0x689e25fe	find_get_pages_tag
++EXPORT_SYMBOL vmlinux 0x68dfc59f	__init_waitqueue_head
++EXPORT_SYMBOL vmlinux 0x68e05d57	getrawmonotonic
++EXPORT_SYMBOL vmlinux 0x69022c6f	dcb_setapp
++EXPORT_SYMBOL vmlinux 0x69057bc9	netdev_info
++EXPORT_SYMBOL vmlinux 0x695655c7	blk_queue_update_dma_alignment
++EXPORT_SYMBOL vmlinux 0x696e0b8f	scsi_nonblockable_ioctl
++EXPORT_SYMBOL vmlinux 0x6971447a	rtc_month_days
++EXPORT_SYMBOL vmlinux 0x6972f0c3	tty_port_free_xmit_buf
++EXPORT_SYMBOL vmlinux 0x698404d6	bmap
++EXPORT_SYMBOL vmlinux 0x6988d0ca	cpu_dr7
++EXPORT_SYMBOL vmlinux 0x69a0ca7d	iowrite16be
++EXPORT_SYMBOL vmlinux 0x69a358a6	iomem_resource
++EXPORT_SYMBOL vmlinux 0x69ad2f20	kstrtouint
++EXPORT_SYMBOL vmlinux 0x69cddc2c	scsicam_bios_param
++EXPORT_SYMBOL vmlinux 0x69d142e5	__skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x69d38ed9	__scsi_print_sense
++EXPORT_SYMBOL vmlinux 0x69e27c7a	bitmap_copy_le
++EXPORT_SYMBOL vmlinux 0x6a037cf1	mempool_kfree
++EXPORT_SYMBOL vmlinux 0x6a05a985	pcie_capability_clear_and_set_dword
++EXPORT_SYMBOL vmlinux 0x6a08f57b	__scsi_alloc_queue
++EXPORT_SYMBOL vmlinux 0x6a102bfc	sock_rfree
++EXPORT_SYMBOL vmlinux 0x6a27bfce	csum_partial_copy_generic
++EXPORT_SYMBOL vmlinux 0x6a2d1114	kunmap_high
++EXPORT_SYMBOL vmlinux 0x6a48e16b	percpu_counter_destroy
++EXPORT_SYMBOL vmlinux 0x6a5ecb18	unregister_module_notifier
++EXPORT_SYMBOL vmlinux 0x6a768740	jbd2_journal_update_sb_errno
++EXPORT_SYMBOL vmlinux 0x6a76f3ac	blk_iopoll_enable
++EXPORT_SYMBOL vmlinux 0x6a897ecc	mb_cache_shrink
++EXPORT_SYMBOL vmlinux 0x6acb973d	iowrite32be
++EXPORT_SYMBOL vmlinux 0x6ad85887	acpi_enable_gpe
++EXPORT_SYMBOL vmlinux 0x6add5c9a	dmi_find_device
++EXPORT_SYMBOL vmlinux 0x6af944de	inet_add_offload
++EXPORT_SYMBOL vmlinux 0x6afe41ed	netdev_warn
++EXPORT_SYMBOL vmlinux 0x6b042879	scsi_cmd_get_serial
++EXPORT_SYMBOL vmlinux 0x6b06fdce	delayed_work_timer_fn
++EXPORT_SYMBOL vmlinux 0x6b145ee1	elv_unregister_queue
++EXPORT_SYMBOL vmlinux 0x6b1b67d3	__bdevname
++EXPORT_SYMBOL vmlinux 0x6b1cd65c	phy_connect_direct
++EXPORT_SYMBOL vmlinux 0x6b22098c	pci_bus_set_ops
++EXPORT_SYMBOL vmlinux 0x6b2db8ae	vfs_lstat
++EXPORT_SYMBOL vmlinux 0x6b2dc060	dump_stack
++EXPORT_SYMBOL vmlinux 0x6b326f2f	mdio_bus_type
++EXPORT_SYMBOL vmlinux 0x6b374881	simple_transaction_get
++EXPORT_SYMBOL vmlinux 0x6b51bfc9	agp_bind_memory
++EXPORT_SYMBOL vmlinux 0x6b540aa5	dev_crit
++EXPORT_SYMBOL vmlinux 0x6b557411	md_write_end
++EXPORT_SYMBOL vmlinux 0x6b5cecde	dev_set_promiscuity
++EXPORT_SYMBOL vmlinux 0x6b5d624a	scsi_register_interface
++EXPORT_SYMBOL vmlinux 0x6b70a61b	x86_hyper_vmware
++EXPORT_SYMBOL vmlinux 0x6b7589f4	param_set_bool
++EXPORT_SYMBOL vmlinux 0x6b7cba49	rtnl_unicast
++EXPORT_SYMBOL vmlinux 0x6b81c17d	jbd2_journal_start_reserved
++EXPORT_SYMBOL vmlinux 0x6b8d51c8	ata_link_printk
++EXPORT_SYMBOL vmlinux 0x6b9f25ff	kmap_to_page
++EXPORT_SYMBOL vmlinux 0x6bbaf216	skb_append
++EXPORT_SYMBOL vmlinux 0x6bbb5c76	neigh_changeaddr
++EXPORT_SYMBOL vmlinux 0x6bc3fbc0	__unregister_chrdev
++EXPORT_SYMBOL vmlinux 0x6bdcfd99	qdisc_class_hash_remove
++EXPORT_SYMBOL vmlinux 0x6bed3b57	unlazy_fpu
++EXPORT_SYMBOL vmlinux 0x6c1ce5ce	strcspn
++EXPORT_SYMBOL vmlinux 0x6c2e3320	strncmp
++EXPORT_SYMBOL vmlinux 0x6c2f0e5e	mmc_of_parse
++EXPORT_SYMBOL vmlinux 0x6c389761	acpi_bus_get_private_data
++EXPORT_SYMBOL vmlinux 0x6c3d84eb	abx500_register_ops
++EXPORT_SYMBOL vmlinux 0x6c61ce70	num_registered_fb
++EXPORT_SYMBOL vmlinux 0x6c702af7	sysctl_udp_rmem_min
++EXPORT_SYMBOL vmlinux 0x6c7e379e	phy_start_interrupts
++EXPORT_SYMBOL vmlinux 0x6c8fa5f9	kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x6c93d13d	netpoll_rx_enable
++EXPORT_SYMBOL vmlinux 0x6cc2150f	pci_write_vpd
++EXPORT_SYMBOL vmlinux 0x6cdc5c6b	nla_strlcpy
++EXPORT_SYMBOL vmlinux 0x6ce9a576	bdev_stack_limits
++EXPORT_SYMBOL vmlinux 0x6d044c26	param_ops_uint
++EXPORT_SYMBOL vmlinux 0x6d0f1f89	dm_table_get_mode
++EXPORT_SYMBOL vmlinux 0x6d11e94b	__breadahead
++EXPORT_SYMBOL vmlinux 0x6d27ef64	__bitmap_empty
++EXPORT_SYMBOL vmlinux 0x6d294e43	clock_t_to_jiffies
++EXPORT_SYMBOL vmlinux 0x6d334118	__get_user_8
++EXPORT_SYMBOL vmlinux 0x6d340f64	tty_termios_input_baud_rate
++EXPORT_SYMBOL vmlinux 0x6d3c8977	mark_info_dirty
++EXPORT_SYMBOL vmlinux 0x6d4cce1c	inet_csk_prepare_forced_close
++EXPORT_SYMBOL vmlinux 0x6d5601af	tty_check_change
++EXPORT_SYMBOL vmlinux 0x6d5d9469	sk_wait_data
++EXPORT_SYMBOL vmlinux 0x6d634b7c	neigh_table_init
++EXPORT_SYMBOL vmlinux 0x6db8f248	fb_show_logo
++EXPORT_SYMBOL vmlinux 0x6dce8e66	i2c_smbus_read_i2c_block_data
++EXPORT_SYMBOL vmlinux 0x6def2db2	half_md4_transform
++EXPORT_SYMBOL vmlinux 0x6dfdab20	posix_lock_file_wait
++EXPORT_SYMBOL vmlinux 0x6e2cae27	scsi_target_resume
++EXPORT_SYMBOL vmlinux 0x6e51ac2e	_raw_spin_trylock_bh
++EXPORT_SYMBOL vmlinux 0x6e65f2dc	rtc_lock
++EXPORT_SYMBOL vmlinux 0x6e720ff2	rtnl_unlock
++EXPORT_SYMBOL vmlinux 0x6e799c4c	setup_new_exec
++EXPORT_SYMBOL vmlinux 0x6e8e36d9	remove_arg_zero
++EXPORT_SYMBOL vmlinux 0x6e9dd606	__symbol_put
++EXPORT_SYMBOL vmlinux 0x6eb9d2b9	cont_write_begin
++EXPORT_SYMBOL vmlinux 0x6ebeeab9	dev_mc_del_global
++EXPORT_SYMBOL vmlinux 0x6eda5bba	vlan_ioctl_set
++EXPORT_SYMBOL vmlinux 0x6f20960a	full_name_hash
++EXPORT_SYMBOL vmlinux 0x6f26f6ef	ihold
++EXPORT_SYMBOL vmlinux 0x6f4c6b71	lg_local_unlock
++EXPORT_SYMBOL vmlinux 0x6f556bdb	acpi_get_gpe_device
++EXPORT_SYMBOL vmlinux 0x6f677648	scsi_eh_restore_cmnd
++EXPORT_SYMBOL vmlinux 0x6fabf2a2	padata_stop
++EXPORT_SYMBOL vmlinux 0x6fbd8a7b	blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0x6fbec2cf	d_rehash
++EXPORT_SYMBOL vmlinux 0x6fcb87a1	touch_softlockup_watchdog
++EXPORT_SYMBOL vmlinux 0x6feb2039	acpi_write
++EXPORT_SYMBOL vmlinux 0x6ff552b6	pnp_get_resource
++EXPORT_SYMBOL vmlinux 0x6ffc2ce9	vfs_readlink
++EXPORT_SYMBOL vmlinux 0x702243d5	account_page_redirty
++EXPORT_SYMBOL vmlinux 0x7023bea8	unregister_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x7031f2b6	pci_dev_driver
++EXPORT_SYMBOL vmlinux 0x7032bff9	input_open_device
++EXPORT_SYMBOL vmlinux 0x703308a5	tcp_md5_hash_key
++EXPORT_SYMBOL vmlinux 0x703b4352	_raw_read_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0x7040dd71	mark_page_accessed
++EXPORT_SYMBOL vmlinux 0x70523a7a	__cond_resched_softirq
++EXPORT_SYMBOL vmlinux 0x7054a3e4	request_dma
++EXPORT_SYMBOL vmlinux 0x707a8fc3	writeback_in_progress
++EXPORT_SYMBOL vmlinux 0x707f43f6	__ctzdi2
++EXPORT_SYMBOL vmlinux 0x7082c0ea	generic_file_llseek
++EXPORT_SYMBOL vmlinux 0x70943ff9	kmap_atomic_prot
++EXPORT_SYMBOL vmlinux 0x709c7352	del_gendisk
++EXPORT_SYMBOL vmlinux 0x70bc17d7	inode_wait
++EXPORT_SYMBOL vmlinux 0x70c0dd06	devfreq_interval_update
++EXPORT_SYMBOL vmlinux 0x70c6c8c8	__ethtool_get_settings
++EXPORT_SYMBOL vmlinux 0x70d053fd	try_to_del_timer_sync
++EXPORT_SYMBOL vmlinux 0x70d1f8f3	strncat
++EXPORT_SYMBOL vmlinux 0x70d8ab82	acpi_acquire_global_lock
++EXPORT_SYMBOL vmlinux 0x70e2fcfe	udp_lib_getsockopt
++EXPORT_SYMBOL vmlinux 0x70e8729a	devfreq_monitor_resume
++EXPORT_SYMBOL vmlinux 0x70f0a051	sock_no_shutdown
++EXPORT_SYMBOL vmlinux 0x70ff9a39	scsi_device_lookup_by_target
++EXPORT_SYMBOL vmlinux 0x7114a71f	bit_waitqueue
++EXPORT_SYMBOL vmlinux 0x7115ddb7	pci_bus_type
++EXPORT_SYMBOL vmlinux 0x7129e5f8	hex_asc
++EXPORT_SYMBOL vmlinux 0x713afa7b	dquot_alloc
++EXPORT_SYMBOL vmlinux 0x71513946	security_path_rmdir
++EXPORT_SYMBOL vmlinux 0x7164f5a3	tty_port_raise_dtr_rts
++EXPORT_SYMBOL vmlinux 0x7169bdf6	blk_queue_resize_tags
++EXPORT_SYMBOL vmlinux 0x716a5285	pcim_iounmap
++EXPORT_SYMBOL vmlinux 0x7171121c	overflowgid
++EXPORT_SYMBOL vmlinux 0x7183de70	__inet6_lookup_established
++EXPORT_SYMBOL vmlinux 0x718ef08f	udp_push_pending_frames
++EXPORT_SYMBOL vmlinux 0x71a26c76	__brelse
++EXPORT_SYMBOL vmlinux 0x71a50dbc	register_blkdev
++EXPORT_SYMBOL vmlinux 0x71a672ef	dmam_pool_destroy
++EXPORT_SYMBOL vmlinux 0x71ae8e4c	fb_set_var
++EXPORT_SYMBOL vmlinux 0x71b30a49	iw_handler_set_thrspy
++EXPORT_SYMBOL vmlinux 0x71b79a5d	tty_port_tty_get
++EXPORT_SYMBOL vmlinux 0x71c5388d	processors
++EXPORT_SYMBOL vmlinux 0x71db4a43	netpoll_setup
++EXPORT_SYMBOL vmlinux 0x71f65175	hdmi_spd_infoframe_pack
++EXPORT_SYMBOL vmlinux 0x7201525e	dquot_enable
++EXPORT_SYMBOL vmlinux 0x723b9147	security_inode_permission
++EXPORT_SYMBOL vmlinux 0x723c6947	bdi_register_dev
++EXPORT_SYMBOL vmlinux 0x7240c1e0	acpi_bus_generate_proc_event
++EXPORT_SYMBOL vmlinux 0x72490b4b	acpi_gpiochip_request_interrupts
++EXPORT_SYMBOL vmlinux 0x7263c55c	vfs_rename
++EXPORT_SYMBOL vmlinux 0x726823f9	dcache_dir_lseek
++EXPORT_SYMBOL vmlinux 0x729e4875	seq_put_decimal_ull
++EXPORT_SYMBOL vmlinux 0x72ab78cd	bioset_create
++EXPORT_SYMBOL vmlinux 0x72abfa2c	locks_free_lock
++EXPORT_SYMBOL vmlinux 0x72b0a36c	kobject_set_name
++EXPORT_SYMBOL vmlinux 0x72b243d4	free_dma
++EXPORT_SYMBOL vmlinux 0x72bf2140	mtrr_add
++EXPORT_SYMBOL vmlinux 0x72c84b59	inet_release
++EXPORT_SYMBOL vmlinux 0x72ca2da7	__neigh_for_each_release
++EXPORT_SYMBOL vmlinux 0x72d58de9	kstrtou8_from_user
++EXPORT_SYMBOL vmlinux 0x72d5bb41	skb_push
++EXPORT_SYMBOL vmlinux 0x72df2f2a	up_read
++EXPORT_SYMBOL vmlinux 0x72ea7b2d	scsi_device_type
++EXPORT_SYMBOL vmlinux 0x72f04a2a	scsi_unregister
++EXPORT_SYMBOL vmlinux 0x72f3aa32	acpi_get_physical_device_location
++EXPORT_SYMBOL vmlinux 0x72fad2ab	pci_find_parent_resource
++EXPORT_SYMBOL vmlinux 0x7304ae0c	neigh_table_clear
++EXPORT_SYMBOL vmlinux 0x73255a27	intel_gmch_probe
++EXPORT_SYMBOL vmlinux 0x733c3b54	kasprintf
++EXPORT_SYMBOL vmlinux 0x733f76c8	generic_write_sync
++EXPORT_SYMBOL vmlinux 0x7349a89f	iw_handler_set_spy
++EXPORT_SYMBOL vmlinux 0x73548e8d	max8998_write_reg
++EXPORT_SYMBOL vmlinux 0x735a0bd5	native_io_delay
++EXPORT_SYMBOL vmlinux 0x736db1fe	elv_dispatch_sort
++EXPORT_SYMBOL vmlinux 0x737de5e9	radix_tree_tag_get
++EXPORT_SYMBOL vmlinux 0x738803e6	strnlen
++EXPORT_SYMBOL vmlinux 0x738e7752	ps2_begin_command
++EXPORT_SYMBOL vmlinux 0x73bbb72c	key_put
++EXPORT_SYMBOL vmlinux 0x73dc068f	ppp_dev_name
++EXPORT_SYMBOL vmlinux 0x73dd54eb	irq_fpu_usable
++EXPORT_SYMBOL vmlinux 0x73e086ff	netlink_broadcast
++EXPORT_SYMBOL vmlinux 0x73e20c1c	strlcpy
++EXPORT_SYMBOL vmlinux 0x7401e2c6	twl6040_get_pll
++EXPORT_SYMBOL vmlinux 0x7406f5c5	kobject_put
++EXPORT_SYMBOL vmlinux 0x740a1b95	reserve_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0x7413793a	EISA_bus
++EXPORT_SYMBOL vmlinux 0x74197d25	mmc_gpio_request_cd
++EXPORT_SYMBOL vmlinux 0x742260cb	sg_miter_start
++EXPORT_SYMBOL vmlinux 0x7426bb53	fixed_size_llseek
++EXPORT_SYMBOL vmlinux 0x742d3455	xfrm4_prepare_output
++EXPORT_SYMBOL vmlinux 0x7430712b	freeze_super
++EXPORT_SYMBOL vmlinux 0x743b2779	shrink_dcache_sb
++EXPORT_SYMBOL vmlinux 0x743b4ae3	atomic64_inc_not_zero_cx8
++EXPORT_SYMBOL vmlinux 0x7459089d	journal_errno
++EXPORT_SYMBOL vmlinux 0x7469fcfe	radix_tree_tagged
++EXPORT_SYMBOL vmlinux 0x7471312d	__alloc_skb
++EXPORT_SYMBOL vmlinux 0x7485e15e	unregister_chrdev_region
++EXPORT_SYMBOL vmlinux 0x74a49cd1	unregister_netdev
++EXPORT_SYMBOL vmlinux 0x74a90275	dev_close
++EXPORT_SYMBOL vmlinux 0x74b25ef6	serio_interrupt
++EXPORT_SYMBOL vmlinux 0x74bb2181	register_sysctl_table
++EXPORT_SYMBOL vmlinux 0x74c134b9	__sw_hweight32
++EXPORT_SYMBOL vmlinux 0x74cdaa24	inode_init_owner
++EXPORT_SYMBOL vmlinux 0x74ce05b8	flush_delayed_work
++EXPORT_SYMBOL vmlinux 0x74e5c98f	ucs2_strnlen
++EXPORT_SYMBOL vmlinux 0x74e5ff1a	udpv6_encap_enable
++EXPORT_SYMBOL vmlinux 0x74f2483b	remap_pfn_range
++EXPORT_SYMBOL vmlinux 0x75057c31	posix_acl_equiv_mode
++EXPORT_SYMBOL vmlinux 0x7505bdef	memchr_inv
++EXPORT_SYMBOL vmlinux 0x75072d5d	vfs_symlink
++EXPORT_SYMBOL vmlinux 0x750e54e2	input_register_handler
++EXPORT_SYMBOL vmlinux 0x75201b85	__skb_tx_hash
++EXPORT_SYMBOL vmlinux 0x75271716	save_processor_state
++EXPORT_SYMBOL vmlinux 0x7531e3dc	acpi_get_event_resources
++EXPORT_SYMBOL vmlinux 0x7538b132	agp_off
++EXPORT_SYMBOL vmlinux 0x753ffa62	seq_printf
++EXPORT_SYMBOL vmlinux 0x754dac78	blk_limits_io_min
++EXPORT_SYMBOL vmlinux 0x755df8ec	inode_init_once
++EXPORT_SYMBOL vmlinux 0x75656c1e	seq_putc
++EXPORT_SYMBOL vmlinux 0x7593d385	div64_s64
++EXPORT_SYMBOL vmlinux 0x75aaedf0	ppp_register_compressor
++EXPORT_SYMBOL vmlinux 0x75adbf11	dquot_set_dqblk
++EXPORT_SYMBOL vmlinux 0x75bb675a	finish_wait
++EXPORT_SYMBOL vmlinux 0x75bda77a	seq_hlist_next
++EXPORT_SYMBOL vmlinux 0x75bdea12	iommu_area_alloc
++EXPORT_SYMBOL vmlinux 0x75c055d1	con_set_default_unimap
++EXPORT_SYMBOL vmlinux 0x75cbcc4d	tcp_sendpage
++EXPORT_SYMBOL vmlinux 0x75d21809	vprintk_emit
++EXPORT_SYMBOL vmlinux 0x75edfad0	skb_dequeue_tail
++EXPORT_SYMBOL vmlinux 0x75fbd2bb	blkdev_issue_flush
++EXPORT_SYMBOL vmlinux 0x760a0f4f	yield
++EXPORT_SYMBOL vmlinux 0x7628f3c7	this_cpu_off
++EXPORT_SYMBOL vmlinux 0x762add85	atomic64_inc_return_cx8
++EXPORT_SYMBOL vmlinux 0x7630982a	__mark_inode_dirty
++EXPORT_SYMBOL vmlinux 0x7647726c	handle_sysrq
++EXPORT_SYMBOL vmlinux 0x764a1dc4	xfrm_state_flush
++EXPORT_SYMBOL vmlinux 0x764bd77c	request_resource
++EXPORT_SYMBOL vmlinux 0x7665d064	arp_find
++EXPORT_SYMBOL vmlinux 0x767c6f88	scsi_reset_provider
++EXPORT_SYMBOL vmlinux 0x767ddb02	set_memory_wc
++EXPORT_SYMBOL vmlinux 0x7685ff05	tty_insert_flip_string_flags
++EXPORT_SYMBOL vmlinux 0x769e06d7	smp_call_function_many
++EXPORT_SYMBOL vmlinux 0x76ac64fe	key_instantiate_and_link
++EXPORT_SYMBOL vmlinux 0x76bf656d	__bitmap_shift_left
++EXPORT_SYMBOL vmlinux 0x76d3cd60	laptop_mode
++EXPORT_SYMBOL vmlinux 0x76d451c4	add_taint
++EXPORT_SYMBOL vmlinux 0x77013650	vga_switcheroo_register_audio_client
++EXPORT_SYMBOL vmlinux 0x77073379	mmc_put_card
++EXPORT_SYMBOL vmlinux 0x770a0036	isapnp_cfg_begin
++EXPORT_SYMBOL vmlinux 0x770e0d1d	jbd2_journal_force_commit
++EXPORT_SYMBOL vmlinux 0x771cf835	dma_pool_alloc
++EXPORT_SYMBOL vmlinux 0x77275e40	ip4_datagram_connect
++EXPORT_SYMBOL vmlinux 0x772f9eec	__percpu_counter_add
++EXPORT_SYMBOL vmlinux 0x773a9c94	blk_iopoll_enabled
++EXPORT_SYMBOL vmlinux 0x773cf85e	dquot_claim_space_nodirty
++EXPORT_SYMBOL vmlinux 0x77456e0a	acpi_root_dir
++EXPORT_SYMBOL vmlinux 0x776850ed	skb_try_coalesce
++EXPORT_SYMBOL vmlinux 0x77780750	sock_get_timestamp
++EXPORT_SYMBOL vmlinux 0x77897936	simple_write_end
++EXPORT_SYMBOL vmlinux 0x77969395	__mod_zone_page_state
++EXPORT_SYMBOL vmlinux 0x779a18af	kstrtoll
++EXPORT_SYMBOL vmlinux 0x77a0dd1b	generic_removexattr
++EXPORT_SYMBOL vmlinux 0x77bc13a0	strim
++EXPORT_SYMBOL vmlinux 0x77c6d017	igrab
++EXPORT_SYMBOL vmlinux 0x77ce93b3	qid_lt
++EXPORT_SYMBOL vmlinux 0x77df0847	__set_personality
++EXPORT_SYMBOL vmlinux 0x77e0bf76	mmc_remove_host
++EXPORT_SYMBOL vmlinux 0x77ecac9f	zlib_inflateEnd
++EXPORT_SYMBOL vmlinux 0x77fa5aad	wait_iff_congested
++EXPORT_SYMBOL vmlinux 0x780c71c2	pci_get_subsys
++EXPORT_SYMBOL vmlinux 0x780fdfd1	intel_enable_gtt
++EXPORT_SYMBOL vmlinux 0x783b3563	wake_up_atomic_t
++EXPORT_SYMBOL vmlinux 0x783c526a	netdev_has_any_upper_dev
++EXPORT_SYMBOL vmlinux 0x7880c781	dm_kcopyd_prepare_callback
++EXPORT_SYMBOL vmlinux 0x7885bfb1	netdev_upper_dev_link
++EXPORT_SYMBOL vmlinux 0x7895bc7c	phy_detach
++EXPORT_SYMBOL vmlinux 0x789affb1	frontswap_tmem_exclusive_gets
++EXPORT_SYMBOL vmlinux 0x789be518	__wait_on_buffer
++EXPORT_SYMBOL vmlinux 0x78a491d0	agp3_generic_tlbflush
++EXPORT_SYMBOL vmlinux 0x78a8259d	inet_csk_reset_keepalive_timer
++EXPORT_SYMBOL vmlinux 0x78b82a51	scsi_ioctl
++EXPORT_SYMBOL vmlinux 0x78bb2011	dm_ratelimit_state
++EXPORT_SYMBOL vmlinux 0x78bd89e4	user_revoke
++EXPORT_SYMBOL vmlinux 0x78ca6dc2	phy_ethtool_get_wol
++EXPORT_SYMBOL vmlinux 0x78db38d3	proc_dointvec
++EXPORT_SYMBOL vmlinux 0x78dc0a62	inet6_protos
++EXPORT_SYMBOL vmlinux 0x78df6bd7	no_pci_devices
++EXPORT_SYMBOL vmlinux 0x79068fda	acpi_install_method
++EXPORT_SYMBOL vmlinux 0x79217b98	bio_alloc_bioset
++EXPORT_SYMBOL vmlinux 0x792ee52e	tty_port_close_end
++EXPORT_SYMBOL vmlinux 0x7936b062	genphy_resume
++EXPORT_SYMBOL vmlinux 0x79406451	mmc_gpio_free_ro
++EXPORT_SYMBOL vmlinux 0x7947fd2c	ioctl_by_bdev
++EXPORT_SYMBOL vmlinux 0x796fc5ce	scsi_get_sense_info_fld
++EXPORT_SYMBOL vmlinux 0x79829037	md_wait_for_blocked_rdev
++EXPORT_SYMBOL vmlinux 0x79aa04a2	get_random_bytes
++EXPORT_SYMBOL vmlinux 0x79d8619a	dev_mc_init
++EXPORT_SYMBOL vmlinux 0x79dd9ff5	scsi_remove_device
++EXPORT_SYMBOL vmlinux 0x79fc026a	ps2_handle_response
++EXPORT_SYMBOL vmlinux 0x7a188791	prandom_bytes
++EXPORT_SYMBOL vmlinux 0x7a27c184	ewma_init
++EXPORT_SYMBOL vmlinux 0x7a4497db	kzfree
++EXPORT_SYMBOL vmlinux 0x7a91726b	clkdev_alloc
++EXPORT_SYMBOL vmlinux 0x7a925833	cpufreq_get_global_kobject
++EXPORT_SYMBOL vmlinux 0x7a9bf88d	udplite_table
++EXPORT_SYMBOL vmlinux 0x7ab4717f	skb_recv_datagram
++EXPORT_SYMBOL vmlinux 0x7ab88a45	system_freezing_cnt
++EXPORT_SYMBOL vmlinux 0x7ad41bf9	posix_acl_valid
++EXPORT_SYMBOL vmlinux 0x7ae3022a	netlink_set_err
++EXPORT_SYMBOL vmlinux 0x7aec9089	clear_user
++EXPORT_SYMBOL vmlinux 0x7af6ff8f	phy_attach
++EXPORT_SYMBOL vmlinux 0x7afa89fc	vsnprintf
++EXPORT_SYMBOL vmlinux 0x7b03848a	verify_mem_not_deleted
++EXPORT_SYMBOL vmlinux 0x7b134ddf	acpi_get_name
++EXPORT_SYMBOL vmlinux 0x7b1aa02a	dcache_dir_close
++EXPORT_SYMBOL vmlinux 0x7b1cdd16	dev_driver_string
++EXPORT_SYMBOL vmlinux 0x7b48de83	dump_seek
++EXPORT_SYMBOL vmlinux 0x7b52a859	wrmsr_safe_on_cpu
++EXPORT_SYMBOL vmlinux 0x7b5c8440	vm_munmap
++EXPORT_SYMBOL vmlinux 0x7b7f519c	scsi_device_set_state
++EXPORT_SYMBOL vmlinux 0x7b8579d2	dst_cow_metrics_generic
++EXPORT_SYMBOL vmlinux 0x7b9a6116	intel_agp_enabled
++EXPORT_SYMBOL vmlinux 0x7ba4167d	locks_mandatory_area
++EXPORT_SYMBOL vmlinux 0x7c0ca4f0	vga_set_legacy_decoding
++EXPORT_SYMBOL vmlinux 0x7c1372e8	panic
++EXPORT_SYMBOL vmlinux 0x7c46233a	cpufreq_quick_get
++EXPORT_SYMBOL vmlinux 0x7c61340c	__release_region
++EXPORT_SYMBOL vmlinux 0x7c741b72	simple_open
++EXPORT_SYMBOL vmlinux 0x7c7df492	mark_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x7c99250e	skb_free_datagram_locked
++EXPORT_SYMBOL vmlinux 0x7c9df475	max8998_read_reg
++EXPORT_SYMBOL vmlinux 0x7cb1ae69	cpu_down
++EXPORT_SYMBOL vmlinux 0x7cd8f954	tty_flip_buffer_push
++EXPORT_SYMBOL vmlinux 0x7ce83365	acpi_remove_table_handler
++EXPORT_SYMBOL vmlinux 0x7cf2fe51	journal_release_buffer
++EXPORT_SYMBOL vmlinux 0x7d0db45c	jiffies_to_clock_t
++EXPORT_SYMBOL vmlinux 0x7d11c268	jiffies
++EXPORT_SYMBOL vmlinux 0x7d293408	tcf_exts_dump
++EXPORT_SYMBOL vmlinux 0x7d38584e	__kfree_skb
++EXPORT_SYMBOL vmlinux 0x7d3bb28e	arp_create
++EXPORT_SYMBOL vmlinux 0x7d47608c	ps2_drain
++EXPORT_SYMBOL vmlinux 0x7d4ad4fb	ip_fragment
++EXPORT_SYMBOL vmlinux 0x7d4fbb90	tty_name
++EXPORT_SYMBOL vmlinux 0x7d6c6863	dquot_commit
++EXPORT_SYMBOL vmlinux 0x7d7f3295	would_dump
++EXPORT_SYMBOL vmlinux 0x7d9614b5	acpi_device_set_power
++EXPORT_SYMBOL vmlinux 0x7da9231c	end_buffer_write_sync
++EXPORT_SYMBOL vmlinux 0x7db39b33	jbd2_journal_try_to_free_buffers
++EXPORT_SYMBOL vmlinux 0x7dbc2e57	mmiotrace_printk
++EXPORT_SYMBOL vmlinux 0x7deff673	dm_consume_args
++EXPORT_SYMBOL vmlinux 0x7dfb4cae	block_truncate_page
++EXPORT_SYMBOL vmlinux 0x7e358e3a	tty_hung_up_p
++EXPORT_SYMBOL vmlinux 0x7e394c4e	sysctl_local_reserved_ports
++EXPORT_SYMBOL vmlinux 0x7e3ea86c	uart_get_baud_rate
++EXPORT_SYMBOL vmlinux 0x7e57df34	pci_set_mwi
++EXPORT_SYMBOL vmlinux 0x7e6543f5	xfrm_policy_destroy
++EXPORT_SYMBOL vmlinux 0x7e7328ea	blkdev_put
++EXPORT_SYMBOL vmlinux 0x7e7d30b2	sock_no_setsockopt
++EXPORT_SYMBOL vmlinux 0x7eacdaf1	kernel_sock_shutdown
++EXPORT_SYMBOL vmlinux 0x7eb2bd6d	simple_setattr
++EXPORT_SYMBOL vmlinux 0x7eb34984	skb_tx_error
++EXPORT_SYMBOL vmlinux 0x7ec0fb65	blk_queue_find_tag
++EXPORT_SYMBOL vmlinux 0x7ecb001b	__per_cpu_offset
++EXPORT_SYMBOL vmlinux 0x7efbab97	tcp_read_sock
++EXPORT_SYMBOL vmlinux 0x7f24de73	jiffies_to_usecs
++EXPORT_SYMBOL vmlinux 0x7f24ee43	devm_ioremap_nocache
++EXPORT_SYMBOL vmlinux 0x7f3237cd	km_new_mapping
++EXPORT_SYMBOL vmlinux 0x7f390c6b	journal_destroy
++EXPORT_SYMBOL vmlinux 0x7f396162	keyring_alloc
++EXPORT_SYMBOL vmlinux 0x7f4bf534	balance_dirty_pages_ratelimited
++EXPORT_SYMBOL vmlinux 0x7f5293ae	xfrm_user_policy
++EXPORT_SYMBOL vmlinux 0x7f658e80	_raw_write_lock
++EXPORT_SYMBOL vmlinux 0x7fa43579	nf_log_packet
++EXPORT_SYMBOL vmlinux 0x7fa5def7	serio_unregister_driver
++EXPORT_SYMBOL vmlinux 0x7faecfaf	kmap_high
++EXPORT_SYMBOL vmlinux 0x7fcb6310	tcp_check_req
++EXPORT_SYMBOL vmlinux 0x7fe32873	rb_replace_node
++EXPORT_SYMBOL vmlinux 0x800322ca	generic_write_end
++EXPORT_SYMBOL vmlinux 0x8014c3d6	tty_unlock
++EXPORT_SYMBOL vmlinux 0x80335758	pcibios_bus_to_resource
++EXPORT_SYMBOL vmlinux 0x80337f11	call_usermodehelper_setup
++EXPORT_SYMBOL vmlinux 0x80454b76	inet_addr_type
++EXPORT_SYMBOL vmlinux 0x804745d9	__idr_pre_get
++EXPORT_SYMBOL vmlinux 0x80476431	bio_advance
++EXPORT_SYMBOL vmlinux 0x8057aed0	__dst_destroy_metrics_generic
++EXPORT_SYMBOL vmlinux 0x806cf547	xfrm_policy_insert
++EXPORT_SYMBOL vmlinux 0x809dec19	blk_rq_init
++EXPORT_SYMBOL vmlinux 0x80a45e80	journal_wipe
++EXPORT_SYMBOL vmlinux 0x80ca5026	_bin2bcd
++EXPORT_SYMBOL vmlinux 0x80d68d3e	fb_register_client
++EXPORT_SYMBOL vmlinux 0x810bc0b3	gnet_stats_copy_queue
++EXPORT_SYMBOL vmlinux 0x810cfbbf	journal_check_available_features
++EXPORT_SYMBOL vmlinux 0x8112b58c	pcie_capability_read_word
++EXPORT_SYMBOL vmlinux 0x81142e65	genphy_read_status
++EXPORT_SYMBOL vmlinux 0x81265b6f	__netlink_dump_start
++EXPORT_SYMBOL vmlinux 0x81338d29	jbd2_journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x81472677	acpi_get_table
++EXPORT_SYMBOL vmlinux 0x814a1d72	fput
++EXPORT_SYMBOL vmlinux 0x814e7730	nf_ct_destroy
++EXPORT_SYMBOL vmlinux 0x8150c0ba	mempool_resize
++EXPORT_SYMBOL vmlinux 0x815b5dd4	match_octal
++EXPORT_SYMBOL vmlinux 0x815c56d0	cpu_present_mask
++EXPORT_SYMBOL vmlinux 0x815f2897	empty_zero_page
++EXPORT_SYMBOL vmlinux 0x8171517f	kthread_bind
++EXPORT_SYMBOL vmlinux 0x8176b555	jbd2_log_start_commit
++EXPORT_SYMBOL vmlinux 0x819e1c25	acpi_evaluate_reference
++EXPORT_SYMBOL vmlinux 0x81a14cfc	pci_save_state
++EXPORT_SYMBOL vmlinux 0x81aa1488	inet6_getname
++EXPORT_SYMBOL vmlinux 0x81b9c1fc	arp_tbl
++EXPORT_SYMBOL vmlinux 0x81cabe28	dma_pool_create
++EXPORT_SYMBOL vmlinux 0x81cf6d58	tc_classify
++EXPORT_SYMBOL vmlinux 0x81d10f5f	trace_seq_putc
++EXPORT_SYMBOL vmlinux 0x81d1d094	end_buffer_read_sync
++EXPORT_SYMBOL vmlinux 0x81db6ebb	xz_dec_reset
++EXPORT_SYMBOL vmlinux 0x81e6b37f	dmi_get_system_info
++EXPORT_SYMBOL vmlinux 0x81e86ca7	phy_start_aneg
++EXPORT_SYMBOL vmlinux 0x81f5f3a9	input_release_device
++EXPORT_SYMBOL vmlinux 0x81fa5303	mmc_unregister_driver
++EXPORT_SYMBOL vmlinux 0x82072614	tasklet_kill
++EXPORT_SYMBOL vmlinux 0x8212721d	xenbus_dev_request_and_reply
++EXPORT_SYMBOL vmlinux 0x82297229	blk_integrity_merge_rq
++EXPORT_SYMBOL vmlinux 0x8235805b	memmove
++EXPORT_SYMBOL vmlinux 0x8246c09a	get_task_io_context
++EXPORT_SYMBOL vmlinux 0x8251bcc3	bitmap_release_region
++EXPORT_SYMBOL vmlinux 0x825efcef	generic_pipe_buf_confirm
++EXPORT_SYMBOL vmlinux 0x8260686f	bitmap_find_next_zero_area
++EXPORT_SYMBOL vmlinux 0x828062b1	__frontswap_init
++EXPORT_SYMBOL vmlinux 0x82838cac	cap_mmap_file
++EXPORT_SYMBOL vmlinux 0x82acfb70	blk_iopoll_sched
++EXPORT_SYMBOL vmlinux 0x82b47729	napi_gro_flush
++EXPORT_SYMBOL vmlinux 0x82bc177c	ipv6_chk_prefix
++EXPORT_SYMBOL vmlinux 0x82c5ad0d	__genl_register_family_with_ops
++EXPORT_SYMBOL vmlinux 0x82d48f57	do_sync_read
++EXPORT_SYMBOL vmlinux 0x82f9a74e	touch_atime
++EXPORT_SYMBOL vmlinux 0x830af7ed	dm_put_device
++EXPORT_SYMBOL vmlinux 0x830e547b	ioremap_prot
++EXPORT_SYMBOL vmlinux 0x833c03aa	acpi_enable_all_runtime_gpes
++EXPORT_SYMBOL vmlinux 0x83695c40	i2c_use_client
++EXPORT_SYMBOL vmlinux 0x837a73dd	agp_generic_free_gatt_table
++EXPORT_SYMBOL vmlinux 0x838746bb	sdev_disable_disk_events
++EXPORT_SYMBOL vmlinux 0x83a476ce	bitmap_scnlistprintf
++EXPORT_SYMBOL vmlinux 0x83acb497	i2c_del_adapter
++EXPORT_SYMBOL vmlinux 0x83bb8baf	pci_get_slot
++EXPORT_SYMBOL vmlinux 0x83c8a355	param_set_int
++EXPORT_SYMBOL vmlinux 0x83cf931a	tc_classify_compat
++EXPORT_SYMBOL vmlinux 0x83f60186	cdev_add
++EXPORT_SYMBOL vmlinux 0x83fa22a4	eth_header_cache
++EXPORT_SYMBOL vmlinux 0x84060081	xen_poll_irq_timeout
++EXPORT_SYMBOL vmlinux 0x8406ede2	tcf_hash_insert
++EXPORT_SYMBOL vmlinux 0x840d8233	skb_copy_expand
++EXPORT_SYMBOL vmlinux 0x84137104	copy_strings_kernel
++EXPORT_SYMBOL vmlinux 0x8417f512	acpi_update_all_gpes
++EXPORT_SYMBOL vmlinux 0x844774ce	pci_disable_ido
++EXPORT_SYMBOL vmlinux 0x846668fe	__i2c_transfer
++EXPORT_SYMBOL vmlinux 0x84be886f	completion_done
++EXPORT_SYMBOL vmlinux 0x84f1ea13	security_inode_listsecurity
++EXPORT_SYMBOL vmlinux 0x84fa2e6e	bio_integrity_prep
++EXPORT_SYMBOL vmlinux 0x84fd7379	inet_sock_destruct
++EXPORT_SYMBOL vmlinux 0x84ffea8b	idr_preload
++EXPORT_SYMBOL vmlinux 0x850a094f	devm_ioport_map
++EXPORT_SYMBOL vmlinux 0x852609bd	acpi_bus_unregister_driver
++EXPORT_SYMBOL vmlinux 0x8529e0ad	pm860x_reg_write
++EXPORT_SYMBOL vmlinux 0x853accc1	pcie_port_service_register
++EXPORT_SYMBOL vmlinux 0x85432601	iov_iter_copy_from_user_atomic
++EXPORT_SYMBOL vmlinux 0x85670f1d	rtnl_is_locked
++EXPORT_SYMBOL vmlinux 0x8599f25c	blk_fetch_request
++EXPORT_SYMBOL vmlinux 0x85b5e625	rfkill_set_states
++EXPORT_SYMBOL vmlinux 0x85df9b6c	strsep
++EXPORT_SYMBOL vmlinux 0x85e4a9a3	dump_write
++EXPORT_SYMBOL vmlinux 0x85e7deb2	iov_iter_fault_in_readable
++EXPORT_SYMBOL vmlinux 0x861fba98	wait_for_completion_io
++EXPORT_SYMBOL vmlinux 0x863002f5	free_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x86341410	tcf_hash_destroy
++EXPORT_SYMBOL vmlinux 0x8636ef3e	sock_alloc_file
++EXPORT_SYMBOL vmlinux 0x865029ac	__hw_addr_sync
++EXPORT_SYMBOL vmlinux 0x8658e355	finish_no_open
++EXPORT_SYMBOL vmlinux 0x865c0c52	end_buffer_async_write
++EXPORT_SYMBOL vmlinux 0x865df3f0	blk_make_request
++EXPORT_SYMBOL vmlinux 0x8664f62e	cpufreq_update_policy
++EXPORT_SYMBOL vmlinux 0x868acba5	get_options
++EXPORT_SYMBOL vmlinux 0x869358d3	dev_get_by_index
++EXPORT_SYMBOL vmlinux 0x869b4f01	udp_flush_pending_frames
++EXPORT_SYMBOL vmlinux 0x86a4889a	kmalloc_order_trace
++EXPORT_SYMBOL vmlinux 0x86b7d54d	tcf_em_register
++EXPORT_SYMBOL vmlinux 0x86b8e884	blk_queue_max_discard_sectors
++EXPORT_SYMBOL vmlinux 0x86c6c9ca	netdev_boot_setup_check
++EXPORT_SYMBOL vmlinux 0x86c8071b	tty_unregister_driver
++EXPORT_SYMBOL vmlinux 0x86d5255f	_raw_write_lock_irqsave
++EXPORT_SYMBOL vmlinux 0x86da4889	__cleancache_invalidate_page
++EXPORT_SYMBOL vmlinux 0x86ee748b	pnp_release_card_device
++EXPORT_SYMBOL vmlinux 0x86fb9b05	bitmap_parse_user
++EXPORT_SYMBOL vmlinux 0x870bf928	radix_tree_lookup
++EXPORT_SYMBOL vmlinux 0x871c0a7e	fiemap_check_flags
++EXPORT_SYMBOL vmlinux 0x87231603	jbd2__journal_restart
++EXPORT_SYMBOL vmlinux 0x87245750	devfreq_monitor_start
++EXPORT_SYMBOL vmlinux 0x8759df8b	security_path_unlink
++EXPORT_SYMBOL vmlinux 0x876aca16	pnp_unregister_card_driver
++EXPORT_SYMBOL vmlinux 0x876dafc3	ec_write
++EXPORT_SYMBOL vmlinux 0x878ab3ce	sysctl_tcp_adv_win_scale
++EXPORT_SYMBOL vmlinux 0x879451d4	bitmap_end_sync
++EXPORT_SYMBOL vmlinux 0x8798e453	__tracepoint_kfree
++EXPORT_SYMBOL vmlinux 0x879eaacd	kern_path
++EXPORT_SYMBOL vmlinux 0x87aaddf8	wrmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0x87becad5	dev_addr_add_multiple
++EXPORT_SYMBOL vmlinux 0x87e94fb5	dentry_update_name_case
++EXPORT_SYMBOL vmlinux 0x87f40a54	bh_submit_read
++EXPORT_SYMBOL vmlinux 0x881039d0	zlib_inflate
++EXPORT_SYMBOL vmlinux 0x882dab9d	sg_pcopy_from_buffer
++EXPORT_SYMBOL vmlinux 0x883397b7	tcf_action_exec
++EXPORT_SYMBOL vmlinux 0x8834396c	mod_timer
++EXPORT_SYMBOL vmlinux 0x883f18ae	read_dev_sector
++EXPORT_SYMBOL vmlinux 0x88537a21	scsi_scan_target
++EXPORT_SYMBOL vmlinux 0x88579707	qdisc_warn_nonwc
++EXPORT_SYMBOL vmlinux 0x887250ea	md_set_array_sectors
++EXPORT_SYMBOL vmlinux 0x88994ebf	rename_lock
++EXPORT_SYMBOL vmlinux 0x88b3be5a	xfrm_cfg_mutex
++EXPORT_SYMBOL vmlinux 0x88bb6882	i2c_smbus_write_block_data
++EXPORT_SYMBOL vmlinux 0x88bd8bc8	acpi_match_device_ids
++EXPORT_SYMBOL vmlinux 0x88d961a3	inet6_register_protosw
++EXPORT_SYMBOL vmlinux 0x88f060e0	scsi_bios_ptable
++EXPORT_SYMBOL vmlinux 0x892b26a0	set_memory_nx
++EXPORT_SYMBOL vmlinux 0x8953f8ff	__tracepoint_kmem_cache_alloc
++EXPORT_SYMBOL vmlinux 0x8961d707	address_space_init_once
++EXPORT_SYMBOL vmlinux 0x896c8cb6	vfs_link
++EXPORT_SYMBOL vmlinux 0x896e36e4	tty_throttle
++EXPORT_SYMBOL vmlinux 0x897473df	mktime
++EXPORT_SYMBOL vmlinux 0x89afe34e	__kfifo_dma_in_prepare
++EXPORT_SYMBOL vmlinux 0x89b336b6	inet_add_protocol
++EXPORT_SYMBOL vmlinux 0x89bd7021	proc_mkdir_mode
++EXPORT_SYMBOL vmlinux 0x89d5538d	fb_pad_aligned_buffer
++EXPORT_SYMBOL vmlinux 0x89d66811	build_ehash_secret
++EXPORT_SYMBOL vmlinux 0x89e6d95e	neigh_lookup
++EXPORT_SYMBOL vmlinux 0x8a066fb9	dma_async_device_register
++EXPORT_SYMBOL vmlinux 0x8a1ab4ee	timeval_to_jiffies
++EXPORT_SYMBOL vmlinux 0x8a490c90	rfkill_set_sw_state
++EXPORT_SYMBOL vmlinux 0x8a623588	x86_dma_fallback_dev
++EXPORT_SYMBOL vmlinux 0x8a7d1c31	high_memory
++EXPORT_SYMBOL vmlinux 0x8a9596cf	netdev_update_features
++EXPORT_SYMBOL vmlinux 0x8a99a016	mempool_free_slab
++EXPORT_SYMBOL vmlinux 0x8aa3f9ba	scsi_rescan_device
++EXPORT_SYMBOL vmlinux 0x8aafd4e7	elv_abort_queue
++EXPORT_SYMBOL vmlinux 0x8ab920f1	locks_copy_lock
++EXPORT_SYMBOL vmlinux 0x8ace8ca3	groups_alloc
++EXPORT_SYMBOL vmlinux 0x8ad05cf8	bdgrab
++EXPORT_SYMBOL vmlinux 0x8ad821bd	__blk_end_request
++EXPORT_SYMBOL vmlinux 0x8af29a2d	request_firmware
++EXPORT_SYMBOL vmlinux 0x8b08eed2	pci_scan_bridge
++EXPORT_SYMBOL vmlinux 0x8b18496f	__copy_to_user_ll
++EXPORT_SYMBOL vmlinux 0x8b1a7a66	pcie_aspm_enabled
++EXPORT_SYMBOL vmlinux 0x8b2037b8	wait_on_page_bit
++EXPORT_SYMBOL vmlinux 0x8b226a81	acpi_video_dmi_demote_vendor
++EXPORT_SYMBOL vmlinux 0x8b29d6b5	agp_collect_device_status
++EXPORT_SYMBOL vmlinux 0x8b35e873	sg_last
++EXPORT_SYMBOL vmlinux 0x8b3b27f8	skb_append_datato_frags
++EXPORT_SYMBOL vmlinux 0x8b43159b	register_cpu_notifier
++EXPORT_SYMBOL vmlinux 0x8b5f4a2e	IO_APIC_get_PCI_irq_vector
++EXPORT_SYMBOL vmlinux 0x8b618d08	overflowuid
++EXPORT_SYMBOL vmlinux 0x8b8278a4	remove_proc_subtree
++EXPORT_SYMBOL vmlinux 0x8b965476	swiotlb_sync_sg_for_device
++EXPORT_SYMBOL vmlinux 0x8b989cf9	acpi_bus_can_wakeup
++EXPORT_SYMBOL vmlinux 0x8b9f6c29	pci_pme_capable
++EXPORT_SYMBOL vmlinux 0x8bcae213	iterate_supers_type
++EXPORT_SYMBOL vmlinux 0x8be3ad62	gnet_stats_finish_copy
++EXPORT_SYMBOL vmlinux 0x8bfe8c57	param_set_uint
++EXPORT_SYMBOL vmlinux 0x8bffe338	task_tgid_nr_ns
++EXPORT_SYMBOL vmlinux 0x8c0e9938	udp_proc_unregister
++EXPORT_SYMBOL vmlinux 0x8c183cbe	iowrite16
++EXPORT_SYMBOL vmlinux 0x8c44e913	bio_pair_release
++EXPORT_SYMBOL vmlinux 0x8c5241a3	netdev_state_change
++EXPORT_SYMBOL vmlinux 0x8c637d43	irq_cpu_rmap_add
++EXPORT_SYMBOL vmlinux 0x8c840c6f	mount_ns
++EXPORT_SYMBOL vmlinux 0x8c9473e0	tcf_hash_new_index
++EXPORT_SYMBOL vmlinux 0x8c9730e1	proc_mkdir
++EXPORT_SYMBOL vmlinux 0x8c9df7de	read_code
++EXPORT_SYMBOL vmlinux 0x8ca62ee6	blk_init_queue_node
++EXPORT_SYMBOL vmlinux 0x8cc703b5	dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0x8cc79cab	iowrite16_rep
++EXPORT_SYMBOL vmlinux 0x8cda8029	xen_clear_irq_pending
++EXPORT_SYMBOL vmlinux 0x8d3fb6d0	complete_request_key
++EXPORT_SYMBOL vmlinux 0x8d551bef	sysctl_tcp_rmem
++EXPORT_SYMBOL vmlinux 0x8d5a9e28	idr_get_next
++EXPORT_SYMBOL vmlinux 0x8d61f847	mmc_stop_bkops
++EXPORT_SYMBOL vmlinux 0x8d6f81b4	__div64_32
++EXPORT_SYMBOL vmlinux 0x8d8d96c6	acpi_get_sleep_type_data
++EXPORT_SYMBOL vmlinux 0x8d950155	atomic_dec_and_mutex_lock
++EXPORT_SYMBOL vmlinux 0x8da1a3cb	acpi_remove_interface
++EXPORT_SYMBOL vmlinux 0x8da1b46a	twl6040_clear_bits
++EXPORT_SYMBOL vmlinux 0x8daf8c42	dql_init
++EXPORT_SYMBOL vmlinux 0x8dc57930	net_dma_find_channel
++EXPORT_SYMBOL vmlinux 0x8dc6e564	restore_processor_state
++EXPORT_SYMBOL vmlinux 0x8de1b3da	alloc_buffer_head
++EXPORT_SYMBOL vmlinux 0x8dfe1815	find_or_create_page
++EXPORT_SYMBOL vmlinux 0x8dfe5093	dev_get_by_flags_rcu
++EXPORT_SYMBOL vmlinux 0x8e002cda	acpi_remove_gpe_block
++EXPORT_SYMBOL vmlinux 0x8e00dbf7	ip_route_me_harder
++EXPORT_SYMBOL vmlinux 0x8e0d66f4	__tracepoint_kmalloc
++EXPORT_SYMBOL vmlinux 0x8e28cd42	in_egroup_p
++EXPORT_SYMBOL vmlinux 0x8e345c70	path_is_under
++EXPORT_SYMBOL vmlinux 0x8e34a087	__xfrm_init_state
++EXPORT_SYMBOL vmlinux 0x8e3ac926	fsnotify_destroy_mark
++EXPORT_SYMBOL vmlinux 0x8e4c804e	dcb_ieee_getapp_mask
++EXPORT_SYMBOL vmlinux 0x8e4e5cea	clear_page_dirty_for_io
++EXPORT_SYMBOL vmlinux 0x8e5db8dc	pci_release_selected_regions
++EXPORT_SYMBOL vmlinux 0x8e87aed4	idr_for_each
++EXPORT_SYMBOL vmlinux 0x8e888ec3	cpumask_next_and
++EXPORT_SYMBOL vmlinux 0x8e97c5ea	simple_fill_super
++EXPORT_SYMBOL vmlinux 0x8e9d7e17	cdrom_get_media_event
++EXPORT_SYMBOL vmlinux 0x8eaf2a5f	vga_switcheroo_unregister_handler
++EXPORT_SYMBOL vmlinux 0x8eb19025	page_symlink
++EXPORT_SYMBOL vmlinux 0x8f045d1c	cancel_delayed_work
++EXPORT_SYMBOL vmlinux 0x8f2703b7	wbinvd_on_all_cpus
++EXPORT_SYMBOL vmlinux 0x8f7014a1	param_set_ulong
++EXPORT_SYMBOL vmlinux 0x8f9c199c	__get_user_2
++EXPORT_SYMBOL vmlinux 0x8fbf294a	sk_reset_timer
++EXPORT_SYMBOL vmlinux 0x8fdb8453	page_readlink
++EXPORT_SYMBOL vmlinux 0x8ff4079b	pv_irq_ops
++EXPORT_SYMBOL vmlinux 0x8ffdb3b8	crc16
++EXPORT_SYMBOL vmlinux 0x901d28d0	bio_clone_bioset
++EXPORT_SYMBOL vmlinux 0x902900f2	con_is_bound
++EXPORT_SYMBOL vmlinux 0x90332ddc	nobh_write_end
++EXPORT_SYMBOL vmlinux 0x904409c6	acpi_set_firmware_waking_vector
++EXPORT_SYMBOL vmlinux 0x90596ab8	bh_uptodate_or_lock
++EXPORT_SYMBOL vmlinux 0x90800b0e	ps2_init
++EXPORT_SYMBOL vmlinux 0x90ac0619	inet_put_port
++EXPORT_SYMBOL vmlinux 0x90b59625	ethtool_op_get_ts_info
++EXPORT_SYMBOL vmlinux 0x90c5e819	kstrtoll_from_user
++EXPORT_SYMBOL vmlinux 0x90c71409	agp_backend_acquire
++EXPORT_SYMBOL vmlinux 0x90d7f6b8	i2c_smbus_xfer
++EXPORT_SYMBOL vmlinux 0x90e09485	input_mt_sync_frame
++EXPORT_SYMBOL vmlinux 0x90f1f873	inc_nlink
++EXPORT_SYMBOL vmlinux 0x91067b14	kill_bdev
++EXPORT_SYMBOL vmlinux 0x912ea6e0	create_empty_buffers
++EXPORT_SYMBOL vmlinux 0x9141ec9e	proc_doulongvec_minmax
++EXPORT_SYMBOL vmlinux 0x9144a8e2	ec_burst_disable
++EXPORT_SYMBOL vmlinux 0x91463b1d	kstrtos16
++EXPORT_SYMBOL vmlinux 0x9152875f	lz4_decompress_unknownoutputsize
++EXPORT_SYMBOL vmlinux 0x915a92c5	write_one_page
++EXPORT_SYMBOL vmlinux 0x91607d95	set_memory_wb
++EXPORT_SYMBOL vmlinux 0x91611b1e	eth_change_mtu
++EXPORT_SYMBOL vmlinux 0x91715312	sprintf
++EXPORT_SYMBOL vmlinux 0x9187a40f	dquot_transfer
++EXPORT_SYMBOL vmlinux 0x91967e8e	xen_selfballoon_init
++EXPORT_SYMBOL vmlinux 0x919e2ce8	input_mt_init_slots
++EXPORT_SYMBOL vmlinux 0x91b10268	pci_find_next_bus
++EXPORT_SYMBOL vmlinux 0x91c1f574	inet_stream_connect
++EXPORT_SYMBOL vmlinux 0x91c39222	scsi_command_normalize_sense
++EXPORT_SYMBOL vmlinux 0x91f5857b	tcp_prot
++EXPORT_SYMBOL vmlinux 0x91f8e2f4	i2c_put_adapter
++EXPORT_SYMBOL vmlinux 0x91ffc708	tcp_v4_md5_hash_skb
++EXPORT_SYMBOL vmlinux 0x9205953f	send_remote_softirq
++EXPORT_SYMBOL vmlinux 0x9234fc99	ata_ap_acpi_handle
++EXPORT_SYMBOL vmlinux 0x923b1276	dmaengine_get
++EXPORT_SYMBOL vmlinux 0x924516c9	freeze_bdev
++EXPORT_SYMBOL vmlinux 0x924b7948	tcp_create_openreq_child
++EXPORT_SYMBOL vmlinux 0x924ccba1	dquot_writeback_dquots
++EXPORT_SYMBOL vmlinux 0x92531393	tcp_md5_do_lookup
++EXPORT_SYMBOL vmlinux 0x9253f023	dma_async_memcpy_pg_to_pg
++EXPORT_SYMBOL vmlinux 0x92897e3d	default_idle
++EXPORT_SYMBOL vmlinux 0x92911b11	__seq_open_private
++EXPORT_SYMBOL vmlinux 0x92a9c60c	time_to_tm
++EXPORT_SYMBOL vmlinux 0x92b91f5e	scsi_prep_return
++EXPORT_SYMBOL vmlinux 0x92ba6305	tcp_md5_do_add
++EXPORT_SYMBOL vmlinux 0x92da9a0a	generic_make_request
++EXPORT_SYMBOL vmlinux 0x92fff6fe	swiotlb_map_sg
++EXPORT_SYMBOL vmlinux 0x9305f8e6	cpufreq_get
++EXPORT_SYMBOL vmlinux 0x93215e1d	__kfifo_skip_r
++EXPORT_SYMBOL vmlinux 0x9328e7a7	revert_creds
++EXPORT_SYMBOL vmlinux 0x93350a14	idr_find_slowpath
++EXPORT_SYMBOL vmlinux 0x93448c57	screen_info
++EXPORT_SYMBOL vmlinux 0x9345104e	splice_from_pipe_end
++EXPORT_SYMBOL vmlinux 0x934d0d44	framebuffer_alloc
++EXPORT_SYMBOL vmlinux 0x93635432	inet_getname
++EXPORT_SYMBOL vmlinux 0x937d2955	framebuffer_release
++EXPORT_SYMBOL vmlinux 0x937dc8af	blk_queue_bounce_limit
++EXPORT_SYMBOL vmlinux 0x938ddb28	tcf_hash_create
++EXPORT_SYMBOL vmlinux 0x938eb9c4	mpage_readpage
++EXPORT_SYMBOL vmlinux 0x9392c233	pipe_unlock
++EXPORT_SYMBOL vmlinux 0x939310ba	xfrm_state_lookup
++EXPORT_SYMBOL vmlinux 0x93a6e0b2	io_schedule
++EXPORT_SYMBOL vmlinux 0x93b3fc74	register_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x93c651be	acpi_info
++EXPORT_SYMBOL vmlinux 0x93d22b79	ndo_dflt_bridge_getlink
++EXPORT_SYMBOL vmlinux 0x93fca811	__get_free_pages
++EXPORT_SYMBOL vmlinux 0x940db8c5	mmc_wait_for_cmd
++EXPORT_SYMBOL vmlinux 0x940f786f	generic_show_options
++EXPORT_SYMBOL vmlinux 0x9415d833	jbd2_journal_clear_features
++EXPORT_SYMBOL vmlinux 0x941dd9d4	posix_lock_file
++EXPORT_SYMBOL vmlinux 0x942555b1	bdget
++EXPORT_SYMBOL vmlinux 0x9443b1c6	irq_set_chip
++EXPORT_SYMBOL vmlinux 0x9480cb8f	__bio_clone
++EXPORT_SYMBOL vmlinux 0x94961283	vunmap
++EXPORT_SYMBOL vmlinux 0x949d0f8f	__scsi_add_device
++EXPORT_SYMBOL vmlinux 0x94b541b5	cpu_active_mask
++EXPORT_SYMBOL vmlinux 0x94b56ffa	__generic_file_aio_write
++EXPORT_SYMBOL vmlinux 0x94be2ae2	scsi_mode_sense
++EXPORT_SYMBOL vmlinux 0x94e47fb6	rc5t583_ext_power_req_config
++EXPORT_SYMBOL vmlinux 0x94ebf35e	serial8250_do_pm
++EXPORT_SYMBOL vmlinux 0x94f0f77f	vfs_llseek
++EXPORT_SYMBOL vmlinux 0x950a52c2	journal_lock_updates
++EXPORT_SYMBOL vmlinux 0x950e286e	sget
++EXPORT_SYMBOL vmlinux 0x951a3347	alloc_xenballooned_pages
++EXPORT_SYMBOL vmlinux 0x951b5df3	qdisc_watchdog_init
++EXPORT_SYMBOL vmlinux 0x954488a4	syncookie_secret
++EXPORT_SYMBOL vmlinux 0x9545af6d	tasklet_init
++EXPORT_SYMBOL vmlinux 0x9559457e	phy_drivers_unregister
++EXPORT_SYMBOL vmlinux 0x957cf12a	register_netdevice
++EXPORT_SYMBOL vmlinux 0x95840b11	journal_ack_err
++EXPORT_SYMBOL vmlinux 0x95bf8b61	nf_log_register
++EXPORT_SYMBOL vmlinux 0x95d66147	netif_napi_del
++EXPORT_SYMBOL vmlinux 0x95e6184a	dev_graft_qdisc
++EXPORT_SYMBOL vmlinux 0x95e6e500	blk_stack_limits
++EXPORT_SYMBOL vmlinux 0x95f1a8ba	truncate_setsize
++EXPORT_SYMBOL vmlinux 0x95f2ce8d	pci_iomap
++EXPORT_SYMBOL vmlinux 0x95f89a33	_raw_write_lock_irq
++EXPORT_SYMBOL vmlinux 0x960b28f0	i2c_verify_client
++EXPORT_SYMBOL vmlinux 0x96116f81	netdev_alert
++EXPORT_SYMBOL vmlinux 0x96130f81	tcf_action_dump_1
++EXPORT_SYMBOL vmlinux 0x9622f415	generic_pipe_buf_unmap
++EXPORT_SYMBOL vmlinux 0x96573b80	__kfifo_dma_in_finish_r
++EXPORT_SYMBOL vmlinux 0x965a1422	update_devfreq
++EXPORT_SYMBOL vmlinux 0x965e7f04	pci_add_new_bus
++EXPORT_SYMBOL vmlinux 0x966219e4	set_page_dirty_lock
++EXPORT_SYMBOL vmlinux 0x9664f68a	fail_migrate_page
++EXPORT_SYMBOL vmlinux 0x96736f6e	__mem_cgroup_count_vm_event
++EXPORT_SYMBOL vmlinux 0x968871ba	dquot_drop
++EXPORT_SYMBOL vmlinux 0x96898769	sysfs_format_mac
++EXPORT_SYMBOL vmlinux 0x968d0ac8	flush_old_exec
++EXPORT_SYMBOL vmlinux 0x9691c077	tty_port_carrier_raised
++EXPORT_SYMBOL vmlinux 0x969bd37f	__set_page_dirty_nobuffers
++EXPORT_SYMBOL vmlinux 0x96bdf08d	set_pages_wb
++EXPORT_SYMBOL vmlinux 0x96cd2b04	scsi_sense_key_string
++EXPORT_SYMBOL vmlinux 0x96f5d386	scsi_device_resume
++EXPORT_SYMBOL vmlinux 0x970fb250	bio_uncopy_user
++EXPORT_SYMBOL vmlinux 0x9721b088	abx500_startup_irq_enabled
++EXPORT_SYMBOL vmlinux 0x9723c736	netdev_master_upper_dev_get_rcu
++EXPORT_SYMBOL vmlinux 0x973fa82e	register_acpi_notifier
++EXPORT_SYMBOL vmlinux 0x9754ec10	radix_tree_preload
++EXPORT_SYMBOL vmlinux 0x975521f0	page_address
++EXPORT_SYMBOL vmlinux 0x97566c24	phy_start
++EXPORT_SYMBOL vmlinux 0x97717b0a	request_key_with_auxdata
++EXPORT_SYMBOL vmlinux 0x97999817	rfkill_set_hw_state
++EXPORT_SYMBOL vmlinux 0x979bce15	shrink_dcache_parent
++EXPORT_SYMBOL vmlinux 0x97b4500c	__tracepoint_kmem_cache_free
++EXPORT_SYMBOL vmlinux 0x97b59586	lg_local_lock_cpu
++EXPORT_SYMBOL vmlinux 0x97c4870f	cdrom_release
++EXPORT_SYMBOL vmlinux 0x97c5bd0a	acpi_unload_parent_table
++EXPORT_SYMBOL vmlinux 0x97dcef29	acpi_processor_unregister_performance
++EXPORT_SYMBOL vmlinux 0x97de0ddd	acpi_install_gpe_block
++EXPORT_SYMBOL vmlinux 0x97e0477f	dcache_readdir
++EXPORT_SYMBOL vmlinux 0x97ef4863	alloc_etherdev_mqs
++EXPORT_SYMBOL vmlinux 0x97f3761a	blk_free_tags
++EXPORT_SYMBOL vmlinux 0x98018021	write_dirty_buffer
++EXPORT_SYMBOL vmlinux 0x98035751	inet_csk_clear_xmit_timers
++EXPORT_SYMBOL vmlinux 0x98154a79	register_tcf_proto_ops
++EXPORT_SYMBOL vmlinux 0x9820b644	warn_slowpath_fmt_taint
++EXPORT_SYMBOL vmlinux 0x98246989	d_set_d_op
++EXPORT_SYMBOL vmlinux 0x9835e74e	ip_options_compile
++EXPORT_SYMBOL vmlinux 0x9843eb02	pcix_get_mmrbc
++EXPORT_SYMBOL vmlinux 0x986e6135	fb_pad_unaligned_buffer
++EXPORT_SYMBOL vmlinux 0x98776490	page_follow_link_light
++EXPORT_SYMBOL vmlinux 0x988ed85d	set_memory_x
++EXPORT_SYMBOL vmlinux 0x98b8433d	__skb_checksum_complete_head
++EXPORT_SYMBOL vmlinux 0x98bb84b5	pci_scan_single_device
++EXPORT_SYMBOL vmlinux 0x98df2072	ata_scsi_cmd_error_handler
++EXPORT_SYMBOL vmlinux 0x98e2909c	max8925_bulk_write
++EXPORT_SYMBOL vmlinux 0x98e39ef6	remap_vmalloc_range_partial
++EXPORT_SYMBOL vmlinux 0x98fa21b0	mod_timer_pinned
++EXPORT_SYMBOL vmlinux 0x99052a84	acpi_os_write_port
++EXPORT_SYMBOL vmlinux 0x99504a62	inet_dgram_connect
++EXPORT_SYMBOL vmlinux 0x99517682	udp_encap_enable
++EXPORT_SYMBOL vmlinux 0x99591a7a	ipv6_ext_hdr
++EXPORT_SYMBOL vmlinux 0x99726fa7	__starget_for_each_device
++EXPORT_SYMBOL vmlinux 0x998a4bd3	input_allocate_device
++EXPORT_SYMBOL vmlinux 0x9994c0ca	ps2_is_keyboard_id
++EXPORT_SYMBOL vmlinux 0x999e8297	vfree
++EXPORT_SYMBOL vmlinux 0x99b0cbd5	put_tty_driver
++EXPORT_SYMBOL vmlinux 0x99bd68f7	pm860x_page_reg_read
++EXPORT_SYMBOL vmlinux 0x99ccd443	fb_blank
++EXPORT_SYMBOL vmlinux 0x99cdc86b	sysctl_tcp_reordering
++EXPORT_SYMBOL vmlinux 0x9a016da3	inet_confirm_addr
++EXPORT_SYMBOL vmlinux 0x9a0f45fa	md_unregister_thread
++EXPORT_SYMBOL vmlinux 0x9a11f9fc	kernel_accept
++EXPORT_SYMBOL vmlinux 0x9a1dfd65	strpbrk
++EXPORT_SYMBOL vmlinux 0x9a1fc4b4	jiffies_to_timeval
++EXPORT_SYMBOL vmlinux 0x9a38ce4d	blk_rq_map_sg
++EXPORT_SYMBOL vmlinux 0x9a3917d5	__qdisc_calculate_pkt_len
++EXPORT_SYMBOL vmlinux 0x9a3c663c	sk_common_release
++EXPORT_SYMBOL vmlinux 0x9a67d168	inet_del_offload
++EXPORT_SYMBOL vmlinux 0x9a6a83f9	cmos_lock
++EXPORT_SYMBOL vmlinux 0x9a6fd689	call_netdevice_notifiers_info
++EXPORT_SYMBOL vmlinux 0x9a822cbc	input_handler_for_each_handle
++EXPORT_SYMBOL vmlinux 0x9a82cdf9	vfs_path_lookup
++EXPORT_SYMBOL vmlinux 0x9a855c88	prepare_kernel_cred
++EXPORT_SYMBOL vmlinux 0x9a8bce2f	dev_kfree_skb_any
++EXPORT_SYMBOL vmlinux 0x9a91e5e2	xfrm_unregister_km
++EXPORT_SYMBOL vmlinux 0x9aa52698	agp_alloc_bridge
++EXPORT_SYMBOL vmlinux 0x9ad277ba	ip6_frag_init
++EXPORT_SYMBOL vmlinux 0x9ad71a5e	free_netdev
++EXPORT_SYMBOL vmlinux 0x9aec5a1f	agp_find_bridge
++EXPORT_SYMBOL vmlinux 0x9af9fc62	fib_default_rule_pref
++EXPORT_SYMBOL vmlinux 0x9b33e0d7	unregister_dcbevent_notifier
++EXPORT_SYMBOL vmlinux 0x9b388444	get_zeroed_page
++EXPORT_SYMBOL vmlinux 0x9b6eb137	ksize
++EXPORT_SYMBOL vmlinux 0x9b75cb81	_raw_read_trylock
++EXPORT_SYMBOL vmlinux 0x9b8f34a1	default_file_splice_read
++EXPORT_SYMBOL vmlinux 0x9b9e05f9	alloc_cpu_rmap
++EXPORT_SYMBOL vmlinux 0x9ba7089d	argv_split
++EXPORT_SYMBOL vmlinux 0x9babbc2a	ipv6_find_hdr
++EXPORT_SYMBOL vmlinux 0x9bda667a	dev_queue_xmit
++EXPORT_SYMBOL vmlinux 0x9bde2771	d_hash_and_lookup
++EXPORT_SYMBOL vmlinux 0x9be7bde4	security_tun_dev_attach
++EXPORT_SYMBOL vmlinux 0x9c077242	mmc_alloc_host
++EXPORT_SYMBOL vmlinux 0x9c1bd171	phy_ethtool_gset
++EXPORT_SYMBOL vmlinux 0x9c2199cd	__skb_dst_set_noref
++EXPORT_SYMBOL vmlinux 0x9c2c944a	__copy_from_user_ll_nocache_nozero
++EXPORT_SYMBOL vmlinux 0x9c3174e0	__module_get
++EXPORT_SYMBOL vmlinux 0x9c37073e	tcp_md5_hash_header
++EXPORT_SYMBOL vmlinux 0x9c3a5026	gen_pool_free
++EXPORT_SYMBOL vmlinux 0x9c491f60	sg_alloc_table
++EXPORT_SYMBOL vmlinux 0x9c583bc3	vga_switcheroo_unregister_client
++EXPORT_SYMBOL vmlinux 0x9c75d6d6	kernel_setsockopt
++EXPORT_SYMBOL vmlinux 0x9c760856	pcim_iomap_regions_request_all
++EXPORT_SYMBOL vmlinux 0x9c817cfd	scsi_report_opcode
++EXPORT_SYMBOL vmlinux 0x9c8ecd26	abort_exclusive_wait
++EXPORT_SYMBOL vmlinux 0x9c9fb40d	generic_file_direct_write
++EXPORT_SYMBOL vmlinux 0x9ca59d45	kblockd_schedule_work
++EXPORT_SYMBOL vmlinux 0x9cab34a6	rfkill_set_led_trigger_name
++EXPORT_SYMBOL vmlinux 0x9ceb163c	memcpy_toiovec
++EXPORT_SYMBOL vmlinux 0x9cfd56c5	scsi_print_status
++EXPORT_SYMBOL vmlinux 0x9d05f6c4	ktime_get_clocktai
++EXPORT_SYMBOL vmlinux 0x9d06c241	dev_add_pack
++EXPORT_SYMBOL vmlinux 0x9d0d6206	unregister_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0x9d2b0934	task_nice
++EXPORT_SYMBOL vmlinux 0x9d2c5a3f	mnt_set_expiry
++EXPORT_SYMBOL vmlinux 0x9d33ef5e	acpi_enable
++EXPORT_SYMBOL vmlinux 0x9d377668	netif_device_attach
++EXPORT_SYMBOL vmlinux 0x9d3aa376	blk_iopoll_init
++EXPORT_SYMBOL vmlinux 0x9d613223	register_gifconf
++EXPORT_SYMBOL vmlinux 0x9db9166d	tcf_generic_walker
++EXPORT_SYMBOL vmlinux 0x9dd628a6	get_fs_type
++EXPORT_SYMBOL vmlinux 0x9de9c819	serial8250_do_set_termios
++EXPORT_SYMBOL vmlinux 0x9e0b3055	proc_create_data
++EXPORT_SYMBOL vmlinux 0x9e0c711d	vzalloc_node
++EXPORT_SYMBOL vmlinux 0x9e1cabf2	init_task
++EXPORT_SYMBOL vmlinux 0x9e2000a7	memcpy_toiovecend
++EXPORT_SYMBOL vmlinux 0x9e21c711	linkwatch_fire_event
++EXPORT_SYMBOL vmlinux 0x9e22a4ea	tty_port_alloc_xmit_buf
++EXPORT_SYMBOL vmlinux 0x9e2b725a	block_commit_write
++EXPORT_SYMBOL vmlinux 0x9e2c7f05	in_dev_finish_destroy
++EXPORT_SYMBOL vmlinux 0x9e363b6b	acpi_disable_gpe
++EXPORT_SYMBOL vmlinux 0x9e4b3747	sg_copy_from_buffer
++EXPORT_SYMBOL vmlinux 0x9e4faeef	dm_io_client_destroy
++EXPORT_SYMBOL vmlinux 0x9e5da876	__devm_request_region
++EXPORT_SYMBOL vmlinux 0x9e61bb05	set_freezable
++EXPORT_SYMBOL vmlinux 0x9e630862	mdiobus_write
++EXPORT_SYMBOL vmlinux 0x9e64fbfe	rtc_cmos_read
++EXPORT_SYMBOL vmlinux 0x9e7741a9	padata_alloc
++EXPORT_SYMBOL vmlinux 0x9e7d6bd0	__udelay
++EXPORT_SYMBOL vmlinux 0x9e9f1714	__bitmap_andnot
++EXPORT_SYMBOL vmlinux 0x9ea0ad49	__sg_free_table
++EXPORT_SYMBOL vmlinux 0x9ebd4c04	adjust_resource
++EXPORT_SYMBOL vmlinux 0x9ed685ee	iov_iter_advance
++EXPORT_SYMBOL vmlinux 0x9ef2204f	pcie_port_service_unregister
++EXPORT_SYMBOL vmlinux 0x9f01b188	empty_aops
++EXPORT_SYMBOL vmlinux 0x9f12ba99	dquot_quota_on
++EXPORT_SYMBOL vmlinux 0x9f29c7cb	mfd_cell_disable
++EXPORT_SYMBOL vmlinux 0x9f2bdaac	__bitmap_or
++EXPORT_SYMBOL vmlinux 0x9f46ced8	__sw_hweight64
++EXPORT_SYMBOL vmlinux 0x9f491e5d	ftrace_print_symbols_seq_u64
++EXPORT_SYMBOL vmlinux 0x9f4f1d81	__cleancache_invalidate_fs
++EXPORT_SYMBOL vmlinux 0x9f51d58f	mutex_lock_killable
++EXPORT_SYMBOL vmlinux 0x9f529679	d_alloc_pseudo
++EXPORT_SYMBOL vmlinux 0x9f87fe10	i2c_smbus_write_byte_data
++EXPORT_SYMBOL vmlinux 0x9f889ef7	key_task_permission
++EXPORT_SYMBOL vmlinux 0x9f8c48b8	mmc_flush_cache
++EXPORT_SYMBOL vmlinux 0x9f984513	strrchr
++EXPORT_SYMBOL vmlinux 0x9fa69ba4	dev_notice
++EXPORT_SYMBOL vmlinux 0x9fb3b3d3	journal_unlock_updates
++EXPORT_SYMBOL vmlinux 0x9fb3dd30	memcpy_fromiovec
++EXPORT_SYMBOL vmlinux 0x9fdecc31	unregister_netdevice_many
++EXPORT_SYMBOL vmlinux 0x9ffa3a75	netdev_max_backlog
++EXPORT_SYMBOL vmlinux 0xa0061798	pci_bus_size_bridges
++EXPORT_SYMBOL vmlinux 0xa00aca2a	dql_completed
++EXPORT_SYMBOL vmlinux 0xa0186a03	read_cache_page_async
++EXPORT_SYMBOL vmlinux 0xa046360e	sock_no_sendpage
++EXPORT_SYMBOL vmlinux 0xa04a01bd	qdisc_class_hash_insert
++EXPORT_SYMBOL vmlinux 0xa05c03df	mempool_kmalloc
++EXPORT_SYMBOL vmlinux 0xa05d9362	fb_firmware_edid
++EXPORT_SYMBOL vmlinux 0xa05f946e	agp_generic_remove_memory
++EXPORT_SYMBOL vmlinux 0xa06df9e1	__kfifo_dma_out_finish_r
++EXPORT_SYMBOL vmlinux 0xa07ed110	xz_dec_init
++EXPORT_SYMBOL vmlinux 0xa0878f8b	inode_sub_rsv_space
++EXPORT_SYMBOL vmlinux 0xa097fd17	alloc_pci_dev
++EXPORT_SYMBOL vmlinux 0xa09dffdf	nf_log_unset
++EXPORT_SYMBOL vmlinux 0xa0b04675	vmalloc_32
++EXPORT_SYMBOL vmlinux 0xa0c82ce5	devfreq_add_device
++EXPORT_SYMBOL vmlinux 0xa0ceef51	out_of_line_wait_on_bit
++EXPORT_SYMBOL vmlinux 0xa0d00426	eisa_driver_unregister
++EXPORT_SYMBOL vmlinux 0xa0d01424	locks_init_lock
++EXPORT_SYMBOL vmlinux 0xa0d2fe2a	security_inode_getsecctx
++EXPORT_SYMBOL vmlinux 0xa0eeee6e	add_to_page_cache_locked
++EXPORT_SYMBOL vmlinux 0xa0fbac79	wake_up_bit
++EXPORT_SYMBOL vmlinux 0xa108eb4d	sysctl_optmem_max
++EXPORT_SYMBOL vmlinux 0xa1200562	devm_gpio_request_one
++EXPORT_SYMBOL vmlinux 0xa120d33c	tty_unregister_ldisc
++EXPORT_SYMBOL vmlinux 0xa121dd57	iput
++EXPORT_SYMBOL vmlinux 0xa1224d6a	pneigh_enqueue
++EXPORT_SYMBOL vmlinux 0xa12d50aa	mmc_power_save_host
++EXPORT_SYMBOL vmlinux 0xa13df78c	elv_dispatch_add_tail
++EXPORT_SYMBOL vmlinux 0xa144426e	seq_vprintf
++EXPORT_SYMBOL vmlinux 0xa14f3d8c	ewma_add
++EXPORT_SYMBOL vmlinux 0xa150d82e	ppp_unregister_channel
++EXPORT_SYMBOL vmlinux 0xa153857f	__inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xa18d92f5	dma_set_mask
++EXPORT_SYMBOL vmlinux 0xa1928fcf	udp_lib_unhash
++EXPORT_SYMBOL vmlinux 0xa1a59556	block_write_full_page
++EXPORT_SYMBOL vmlinux 0xa1a63c02	iterate_fd
++EXPORT_SYMBOL vmlinux 0xa1b759ce	fb_add_videomode
++EXPORT_SYMBOL vmlinux 0xa1bb17d4	elv_add_request
++EXPORT_SYMBOL vmlinux 0xa1c76e0a	_cond_resched
++EXPORT_SYMBOL vmlinux 0xa1cbe422	fb_get_buffer_offset
++EXPORT_SYMBOL vmlinux 0xa1e2bbb9	xen_biovec_phys_mergeable
++EXPORT_SYMBOL vmlinux 0xa20332dd	bitmap_start_sync
++EXPORT_SYMBOL vmlinux 0xa2090927	__sync_dirty_buffer
++EXPORT_SYMBOL vmlinux 0xa20aab1a	inetpeer_invalidate_tree
++EXPORT_SYMBOL vmlinux 0xa20ce1b8	net_msg_warn
++EXPORT_SYMBOL vmlinux 0xa226c337	unregister_exec_domain
++EXPORT_SYMBOL vmlinux 0xa22f9be7	blkdev_get_by_path
++EXPORT_SYMBOL vmlinux 0xa2359456	vfs_create
++EXPORT_SYMBOL vmlinux 0xa248bc9a	key_revoke
++EXPORT_SYMBOL vmlinux 0xa250c838	param_get_charp
++EXPORT_SYMBOL vmlinux 0xa25d16e6	sock_init_data
++EXPORT_SYMBOL vmlinux 0xa25efb6a	textsearch_prepare
++EXPORT_SYMBOL vmlinux 0xa267f408	pm_vt_switch_required
++EXPORT_SYMBOL vmlinux 0xa2683092	udp_lib_setsockopt
++EXPORT_SYMBOL vmlinux 0xa26cd883	skb_copy_datagram_const_iovec
++EXPORT_SYMBOL vmlinux 0xa27db39f	mount_single
++EXPORT_SYMBOL vmlinux 0xa2848c50	ecryptfs_get_auth_tok_key
++EXPORT_SYMBOL vmlinux 0xa28700bd	sock_alloc_send_skb
++EXPORT_SYMBOL vmlinux 0xa291d022	netdev_master_upper_dev_link
++EXPORT_SYMBOL vmlinux 0xa2a4160b	misc_deregister
++EXPORT_SYMBOL vmlinux 0xa2a5fd77	inet_ehash_secret
++EXPORT_SYMBOL vmlinux 0xa2b0f959	input_set_capability
++EXPORT_SYMBOL vmlinux 0xa2d1357e	qdisc_tree_decrease_qlen
++EXPORT_SYMBOL vmlinux 0xa2dbafbc	pnp_request_card_device
++EXPORT_SYMBOL vmlinux 0xa2dbd71b	install_exec_creds
++EXPORT_SYMBOL vmlinux 0xa2ddf379	qdisc_watchdog_schedule_ns
++EXPORT_SYMBOL vmlinux 0xa2ef34d7	rps_sock_flow_table
++EXPORT_SYMBOL vmlinux 0xa30844d5	mb_cache_entry_get
++EXPORT_SYMBOL vmlinux 0xa308c0a3	bio_add_pc_page
++EXPORT_SYMBOL vmlinux 0xa30ce6f0	ip_options_rcv_srr
++EXPORT_SYMBOL vmlinux 0xa32df36b	clear_nlink
++EXPORT_SYMBOL vmlinux 0xa33d9a48	acpi_decode_pld_buffer
++EXPORT_SYMBOL vmlinux 0xa34228a0	swiotlb_dma_supported
++EXPORT_SYMBOL vmlinux 0xa34ea22e	jbd2_journal_revoke
++EXPORT_SYMBOL vmlinux 0xa34f1ef5	crc32_le
++EXPORT_SYMBOL vmlinux 0xa3504378	rwsem_wake
++EXPORT_SYMBOL vmlinux 0xa350a8f8	set_memory_array_uc
++EXPORT_SYMBOL vmlinux 0xa352899c	sock_release
++EXPORT_SYMBOL vmlinux 0xa356d5e2	pci_match_id
++EXPORT_SYMBOL vmlinux 0xa35cdba3	input_mt_get_slot_by_key
++EXPORT_SYMBOL vmlinux 0xa35de80f	ipv4_config
++EXPORT_SYMBOL vmlinux 0xa363dab4	udp_table
++EXPORT_SYMBOL vmlinux 0xa376d510	security_inode_setsecctx
++EXPORT_SYMBOL vmlinux 0xa3a1945c	pci_pme_active
++EXPORT_SYMBOL vmlinux 0xa3b4148f	tcp_v4_conn_request
++EXPORT_SYMBOL vmlinux 0xa3b65c40	blk_queue_update_dma_pad
++EXPORT_SYMBOL vmlinux 0xa4082108	bfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xa40bd68d	block_page_mkwrite
++EXPORT_SYMBOL vmlinux 0xa42fe377	skb_queue_head
++EXPORT_SYMBOL vmlinux 0xa43b1297	vscnprintf
++EXPORT_SYMBOL vmlinux 0xa43b9539	memcpy_fromiovecend
++EXPORT_SYMBOL vmlinux 0xa43db615	xfrm_state_update
++EXPORT_SYMBOL vmlinux 0xa444eb1a	rawv6_mh_filter_register
++EXPORT_SYMBOL vmlinux 0xa45571e1	acpi_device_hid
++EXPORT_SYMBOL vmlinux 0xa455edad	netdev_notice
++EXPORT_SYMBOL vmlinux 0xa46822b2	poll_schedule_timeout
++EXPORT_SYMBOL vmlinux 0xa4701e9e	timekeeping_inject_offset
++EXPORT_SYMBOL vmlinux 0xa476026e	pci_scan_bus
++EXPORT_SYMBOL vmlinux 0xa49e9cbe	fget
++EXPORT_SYMBOL vmlinux 0xa49f6fd4	amd_northbridges
++EXPORT_SYMBOL vmlinux 0xa4b94fea	iowrite8_rep
++EXPORT_SYMBOL vmlinux 0xa4d4f0e6	global_cache_flush
++EXPORT_SYMBOL vmlinux 0xa4eb4eff	_raw_spin_lock_bh
++EXPORT_SYMBOL vmlinux 0xa4ee62c4	xfrm6_input_addr
++EXPORT_SYMBOL vmlinux 0xa4f0e2b1	tty_schedule_flip
++EXPORT_SYMBOL vmlinux 0xa50a111e	inet_peer_xrlim_allow
++EXPORT_SYMBOL vmlinux 0xa51cdfe8	__FIXADDR_TOP
++EXPORT_SYMBOL vmlinux 0xa54312c1	handle_edge_irq
++EXPORT_SYMBOL vmlinux 0xa5464c05	register_console
++EXPORT_SYMBOL vmlinux 0xa5526619	rb_insert_color
++EXPORT_SYMBOL vmlinux 0xa5568acd	mb_cache_entry_insert
++EXPORT_SYMBOL vmlinux 0xa568169c	register_nls
++EXPORT_SYMBOL vmlinux 0xa56bde51	write_cache_pages
++EXPORT_SYMBOL vmlinux 0xa57110a6	phy_print_status
++EXPORT_SYMBOL vmlinux 0xa577a850	param_get_short
++EXPORT_SYMBOL vmlinux 0xa578cbfa	fb_pan_display
++EXPORT_SYMBOL vmlinux 0xa579eedf	set_blocksize
++EXPORT_SYMBOL vmlinux 0xa598e29c	vesa_modes
++EXPORT_SYMBOL vmlinux 0xa5c11c65	__ip_dev_find
++EXPORT_SYMBOL vmlinux 0xa5da0abd	acpi_enter_sleep_state_s4bios
++EXPORT_SYMBOL vmlinux 0xa5dd45f3	prandom_bytes_state
++EXPORT_SYMBOL vmlinux 0xa5de7502	dev_change_flags
++EXPORT_SYMBOL vmlinux 0xa5fc6f1a	max8925_set_bits
++EXPORT_SYMBOL vmlinux 0xa61a1e3e	psched_ratecfg_precompute
++EXPORT_SYMBOL vmlinux 0xa62b3aa5	noop_qdisc
++EXPORT_SYMBOL vmlinux 0xa62e6e4f	acpi_get_table_with_size
++EXPORT_SYMBOL vmlinux 0xa633d0af	pci_alloc_dev
++EXPORT_SYMBOL vmlinux 0xa6368781	bdi_register
++EXPORT_SYMBOL vmlinux 0xa63d85ab	slhc_remember
++EXPORT_SYMBOL vmlinux 0xa63da86e	generic_error_remove_page
++EXPORT_SYMBOL vmlinux 0xa6468800	vlan_uses_dev
++EXPORT_SYMBOL vmlinux 0xa6498f25	__sk_dst_check
++EXPORT_SYMBOL vmlinux 0xa6529952	filemap_fdatawait_range
++EXPORT_SYMBOL vmlinux 0xa65422c1	__sk_mem_reclaim
++EXPORT_SYMBOL vmlinux 0xa6558568	journal_revoke
++EXPORT_SYMBOL vmlinux 0xa664fa08	mb_cache_entry_free
++EXPORT_SYMBOL vmlinux 0xa66751f0	__inet_stream_connect
++EXPORT_SYMBOL vmlinux 0xa6715115	do_settimeofday
++EXPORT_SYMBOL vmlinux 0xa675804c	utf8s_to_utf16s
++EXPORT_SYMBOL vmlinux 0xa67da660	mempool_alloc
++EXPORT_SYMBOL vmlinux 0xa67e2845	dq_data_lock
++EXPORT_SYMBOL vmlinux 0xa681fe88	generate_random_uuid
++EXPORT_SYMBOL vmlinux 0xa68b255a	netif_device_detach
++EXPORT_SYMBOL vmlinux 0xa6970398	__kfifo_to_user_r
++EXPORT_SYMBOL vmlinux 0xa69b6b6b	lookup_bdev
++EXPORT_SYMBOL vmlinux 0xa6b13658	__percpu_counter_sum
++EXPORT_SYMBOL vmlinux 0xa6bd9a25	pcibios_set_irq_routing
++EXPORT_SYMBOL vmlinux 0xa6d94c12	ps2_cmd_aborted
++EXPORT_SYMBOL vmlinux 0xa6e0b81d	nonseekable_open
++EXPORT_SYMBOL vmlinux 0xa70fabbe	release_evntsel_nmi
++EXPORT_SYMBOL vmlinux 0xa71e7463	__first_cpu
++EXPORT_SYMBOL vmlinux 0xa7223a5d	pnp_register_driver
++EXPORT_SYMBOL vmlinux 0xa72a2f0d	dquot_acquire
++EXPORT_SYMBOL vmlinux 0xa735db59	prandom_u32
++EXPORT_SYMBOL vmlinux 0xa762b4b5	d_drop
++EXPORT_SYMBOL vmlinux 0xa7726689	cdrom_mode_sense
++EXPORT_SYMBOL vmlinux 0xa7c8705b	pagecache_write_end
++EXPORT_SYMBOL vmlinux 0xa7ca3af0	i2c_register_driver
++EXPORT_SYMBOL vmlinux 0xa7cf6c2f	atomic64_dec_return_cx8
++EXPORT_SYMBOL vmlinux 0xa7f891cd	__scm_send
++EXPORT_SYMBOL vmlinux 0xa80171b6	send_sig
++EXPORT_SYMBOL vmlinux 0xa8232c78	strtobool
++EXPORT_SYMBOL vmlinux 0xa82495dd	mmc_gpio_get_cd
++EXPORT_SYMBOL vmlinux 0xa843805a	get_unused_fd_flags
++EXPORT_SYMBOL vmlinux 0xa85d6421	efi
++EXPORT_SYMBOL vmlinux 0xa85fb2e0	dm_kcopyd_zero
++EXPORT_SYMBOL vmlinux 0xa8721b97	system_state
++EXPORT_SYMBOL vmlinux 0xa87a6d28	kmap_atomic_to_page
++EXPORT_SYMBOL vmlinux 0xa8821b1c	inode_get_bytes
++EXPORT_SYMBOL vmlinux 0xa888cfa8	ppp_register_net_channel
++EXPORT_SYMBOL vmlinux 0xa8a201fc	open_exec
++EXPORT_SYMBOL vmlinux 0xa8a6f639	__check_region
++EXPORT_SYMBOL vmlinux 0xa8ad200b	vga_switcheroo_register_client
++EXPORT_SYMBOL vmlinux 0xa8ca81df	uart_resume_port
++EXPORT_SYMBOL vmlinux 0xa8d11b82	pci_disable_link_state
++EXPORT_SYMBOL vmlinux 0xa8d68abd	acpi_warning
++EXPORT_SYMBOL vmlinux 0xa8d69682	sock_no_poll
++EXPORT_SYMBOL vmlinux 0xa8fa7568	update_time
++EXPORT_SYMBOL vmlinux 0xa8fef7bb	security_unix_may_send
++EXPORT_SYMBOL vmlinux 0xa8ff5793	mmc_erase
++EXPORT_SYMBOL vmlinux 0xa91b5561	acpi_video_backlight_support
++EXPORT_SYMBOL vmlinux 0xa91d913f	skb_checksum_help
++EXPORT_SYMBOL vmlinux 0xa92f4f05	xfrm6_prepare_output
++EXPORT_SYMBOL vmlinux 0xa944e338	bdi_unregister
++EXPORT_SYMBOL vmlinux 0xa95ccaf8	kfree_skb
++EXPORT_SYMBOL vmlinux 0xa98c83d7	bio_integrity_enabled
++EXPORT_SYMBOL vmlinux 0xa9a8e17f	arch_phys_wc_add
++EXPORT_SYMBOL vmlinux 0xa9ab32a7	genphy_config_aneg
++EXPORT_SYMBOL vmlinux 0xa9abbaa3	netdev_change_features
++EXPORT_SYMBOL vmlinux 0xa9dde07d	pci_lost_interrupt
++EXPORT_SYMBOL vmlinux 0xaa0a92e1	dquot_quota_off
++EXPORT_SYMBOL vmlinux 0xaa20a514	release_sock
++EXPORT_SYMBOL vmlinux 0xaa294444	unload_nls
++EXPORT_SYMBOL vmlinux 0xaa33a3aa	proc_set_user
++EXPORT_SYMBOL vmlinux 0xaa33e8f7	unregister_framebuffer
++EXPORT_SYMBOL vmlinux 0xaa5e2a0d	vm_event_states
++EXPORT_SYMBOL vmlinux 0xaa6901ac	__kfifo_out_r
++EXPORT_SYMBOL vmlinux 0xaa6da8db	kernel_getsockname
++EXPORT_SYMBOL vmlinux 0xaa6f23ad	rfkill_get_led_trigger_name
++EXPORT_SYMBOL vmlinux 0xaa6f447b	mmc_can_trim
++EXPORT_SYMBOL vmlinux 0xaa8fea18	acpi_processor_register_performance
++EXPORT_SYMBOL vmlinux 0xaabcbc7c	serio_close
++EXPORT_SYMBOL vmlinux 0xaac8d0b1	journal_set_features
++EXPORT_SYMBOL vmlinux 0xaad6d92f	rfkill_init_sw_state
++EXPORT_SYMBOL vmlinux 0xaae8ab0e	acpi_bus_power_manageable
++EXPORT_SYMBOL vmlinux 0xaae9250d	vga_get
++EXPORT_SYMBOL vmlinux 0xaaf6c117	__dev_get_by_name
++EXPORT_SYMBOL vmlinux 0xaafd508f	km_state_expired
++EXPORT_SYMBOL vmlinux 0xaafdc258	strcasecmp
++EXPORT_SYMBOL vmlinux 0xab102bc7	mmc_get_card
++EXPORT_SYMBOL vmlinux 0xab1d6cc1	param_get_long
++EXPORT_SYMBOL vmlinux 0xab28271c	i8253_lock
++EXPORT_SYMBOL vmlinux 0xab3d9e62	genphy_update_link
++EXPORT_SYMBOL vmlinux 0xab469ec9	pci_bus_write_config_dword
++EXPORT_SYMBOL vmlinux 0xab48c1c8	__dynamic_netdev_dbg
++EXPORT_SYMBOL vmlinux 0xab56aee8	xfrm_find_acq_byseq
++EXPORT_SYMBOL vmlinux 0xab600421	probe_irq_off
++EXPORT_SYMBOL vmlinux 0xab65ed80	set_memory_uc
++EXPORT_SYMBOL vmlinux 0xab694444	bsearch
++EXPORT_SYMBOL vmlinux 0xab697306	neigh_parms_release
++EXPORT_SYMBOL vmlinux 0xab6bde28	sysctl_max_syn_backlog
++EXPORT_SYMBOL vmlinux 0xab6d350b	tcf_destroy_chain
++EXPORT_SYMBOL vmlinux 0xab770678	rdmsr_safe_regs_on_cpu
++EXPORT_SYMBOL vmlinux 0xab781570	fb_get_options
++EXPORT_SYMBOL vmlinux 0xabc6dd63	cpufreq_sysfs_create_file
++EXPORT_SYMBOL vmlinux 0xabcaa577	free_anon_bdev
++EXPORT_SYMBOL vmlinux 0xabd0c91c	rtc_time_to_tm
++EXPORT_SYMBOL vmlinux 0xabda1812	i2c_master_send
++EXPORT_SYMBOL vmlinux 0xac041770	tcp_gro_complete
++EXPORT_SYMBOL vmlinux 0xac0ba8c1	blk_iopoll_disable
++EXPORT_SYMBOL vmlinux 0xac1a55be	unregister_reboot_notifier
++EXPORT_SYMBOL vmlinux 0xac1c8563	user_path_at
++EXPORT_SYMBOL vmlinux 0xac2d2fb8	gen_pool_virt_to_phys
++EXPORT_SYMBOL vmlinux 0xac314bfe	vfs_unlink
++EXPORT_SYMBOL vmlinux 0xac58ea5e	acpi_unload_table_id
++EXPORT_SYMBOL vmlinux 0xac6e6cd3	devm_ioport_unmap
++EXPORT_SYMBOL vmlinux 0xac926e8f	blk_delay_queue
++EXPORT_SYMBOL vmlinux 0xaca22796	nf_reinject
++EXPORT_SYMBOL vmlinux 0xacab29b7	seq_hlist_start_percpu
++EXPORT_SYMBOL vmlinux 0xacb0c6d9	sock_create
++EXPORT_SYMBOL vmlinux 0xacb70dac	blk_queue_merge_bvec
++EXPORT_SYMBOL vmlinux 0xacc4e50c	get_disk
++EXPORT_SYMBOL vmlinux 0xaccabc6a	in4_pton
++EXPORT_SYMBOL vmlinux 0xacd7cbd5	tcf_exts_validate
++EXPORT_SYMBOL vmlinux 0xacf4d843	match_strdup
++EXPORT_SYMBOL vmlinux 0xacf65550	agp_generic_create_gatt_table
++EXPORT_SYMBOL vmlinux 0xacfc68fe	dev_vprintk_emit
++EXPORT_SYMBOL vmlinux 0xacffb1d7	generic_file_fsync
++EXPORT_SYMBOL vmlinux 0xad04137a	force_sig
++EXPORT_SYMBOL vmlinux 0xad0413d4	match_hex
++EXPORT_SYMBOL vmlinux 0xad1345f6	mmc_cache_ctrl
++EXPORT_SYMBOL vmlinux 0xad13c689	acpi_os_execute
++EXPORT_SYMBOL vmlinux 0xad2a8bd2	x86_bios_cpu_apicid
++EXPORT_SYMBOL vmlinux 0xad3adfe0	sk_stop_timer
++EXPORT_SYMBOL vmlinux 0xad3fe3fd	nobh_writepage
++EXPORT_SYMBOL vmlinux 0xad442722	acpi_bus_get_status
++EXPORT_SYMBOL vmlinux 0xad84bef8	dm_table_event
++EXPORT_SYMBOL vmlinux 0xadb402a4	add_disk
++EXPORT_SYMBOL vmlinux 0xadb5559d	param_ops_byte
++EXPORT_SYMBOL vmlinux 0xadbd9d58	ata_dev_printk
++EXPORT_SYMBOL vmlinux 0xadd367c2	tag_pages_for_writeback
++EXPORT_SYMBOL vmlinux 0xade2299b	generic_cont_expand_simple
++EXPORT_SYMBOL vmlinux 0xadedcec5	blk_integrity_register
++EXPORT_SYMBOL vmlinux 0xadf27d3a	block_read_full_page
++EXPORT_SYMBOL vmlinux 0xae0f0316	bioset_integrity_free
++EXPORT_SYMBOL vmlinux 0xae4ced2d	tcf_register_action
++EXPORT_SYMBOL vmlinux 0xae66b181	call_netdevice_notifiers
++EXPORT_SYMBOL vmlinux 0xae729e59	security_req_classify_flow
++EXPORT_SYMBOL vmlinux 0xae9f0023	__sock_create
++EXPORT_SYMBOL vmlinux 0xaea976a8	acpi_check_resource_conflict
++EXPORT_SYMBOL vmlinux 0xaeb3bd9d	pnp_disable_dev
++EXPORT_SYMBOL vmlinux 0xaec655c7	alloc_pages_exact
++EXPORT_SYMBOL vmlinux 0xaed377b8	tty_port_lower_dtr_rts
++EXPORT_SYMBOL vmlinux 0xaef462db	fs_bio_set
++EXPORT_SYMBOL vmlinux 0xaef6ebf6	generic_file_llseek_size
++EXPORT_SYMBOL vmlinux 0xaf35432a	arp_send
++EXPORT_SYMBOL vmlinux 0xaf354edc	kfree_skb_partial
++EXPORT_SYMBOL vmlinux 0xaf3dd7dc	scsi_logging_level
++EXPORT_SYMBOL vmlinux 0xaf4b1540	acpi_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xaf605240	module_layout
++EXPORT_SYMBOL vmlinux 0xaf611eac	amd_nb_misc_ids
++EXPORT_SYMBOL vmlinux 0xaf6c567d	register_netdev
++EXPORT_SYMBOL vmlinux 0xaf6e712c	journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xaf773eb2	mnt_pin
++EXPORT_SYMBOL vmlinux 0xaf8b2029	tcf_hash_check
++EXPORT_SYMBOL vmlinux 0xaf91d89f	__kernel_param_lock
++EXPORT_SYMBOL vmlinux 0xaf99a184	generic_getxattr
++EXPORT_SYMBOL vmlinux 0xaf9d9ecc	__register_nmi_handler
++EXPORT_SYMBOL vmlinux 0xafbea762	blk_get_backing_dev_info
++EXPORT_SYMBOL vmlinux 0xaff0c214	sched_autogroup_detach
++EXPORT_SYMBOL vmlinux 0xb0149f7d	pci_iounmap
++EXPORT_SYMBOL vmlinux 0xb01b1db8	intel_gtt_insert_sg_entries
++EXPORT_SYMBOL vmlinux 0xb0207ecf	___ratelimit
++EXPORT_SYMBOL vmlinux 0xb048af5c	lro_receive_skb
++EXPORT_SYMBOL vmlinux 0xb05bc6cd	tty_insert_flip_string_fixed_flag
++EXPORT_SYMBOL vmlinux 0xb05ee54d	netpoll_cleanup
++EXPORT_SYMBOL vmlinux 0xb05fc310	sysctl_rmem_max
++EXPORT_SYMBOL vmlinux 0xb06b8ec5	__dquot_alloc_space
++EXPORT_SYMBOL vmlinux 0xb077ef32	acpi_enter_sleep_state
++EXPORT_SYMBOL vmlinux 0xb07d30b1	__nla_put
++EXPORT_SYMBOL vmlinux 0xb08b2e81	inode_set_bytes
++EXPORT_SYMBOL vmlinux 0xb0a0da0c	rational_best_approximation
++EXPORT_SYMBOL vmlinux 0xb0b20152	splice_from_pipe_next
++EXPORT_SYMBOL vmlinux 0xb0b847ac	__bitmap_full
++EXPORT_SYMBOL vmlinux 0xb0e10781	get_option
++EXPORT_SYMBOL vmlinux 0xb0ffda2f	blk_limits_max_hw_sectors
++EXPORT_SYMBOL vmlinux 0xb121390a	probe_irq_on
++EXPORT_SYMBOL vmlinux 0xb12b6698	ata_print_version
++EXPORT_SYMBOL vmlinux 0xb12cbacb	fb_unregister_client
++EXPORT_SYMBOL vmlinux 0xb12fc103	migrate_page
++EXPORT_SYMBOL vmlinux 0xb141b21a	neigh_compat_output
++EXPORT_SYMBOL vmlinux 0xb14b200f	scsi_block_requests
++EXPORT_SYMBOL vmlinux 0xb14d5c4c	seq_puts
++EXPORT_SYMBOL vmlinux 0xb1589753	inode_needs_sync
++EXPORT_SYMBOL vmlinux 0xb15a9b1e	blk_cleanup_queue
++EXPORT_SYMBOL vmlinux 0xb1645a2e	sg_free_table
++EXPORT_SYMBOL vmlinux 0xb1914fb7	free_inode_nonrcu
++EXPORT_SYMBOL vmlinux 0xb19760c3	bitmap_onto
++EXPORT_SYMBOL vmlinux 0xb199b380	netlink_kernel_release
++EXPORT_SYMBOL vmlinux 0xb1b3d3df	blk_pre_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xb1bfffa3	scsi_put_command
++EXPORT_SYMBOL vmlinux 0xb1c3a01a	oops_in_progress
++EXPORT_SYMBOL vmlinux 0xb1cc0522	mmc_start_bkops
++EXPORT_SYMBOL vmlinux 0xb1cf0f93	agp_generic_alloc_page
++EXPORT_SYMBOL vmlinux 0xb1cf44df	fb_find_best_mode
++EXPORT_SYMBOL vmlinux 0xb1cfad22	rdmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xb1d9523e	wait_for_completion_timeout
++EXPORT_SYMBOL vmlinux 0xb219d56c	wbinvd_on_cpu
++EXPORT_SYMBOL vmlinux 0xb23c2fa2	generic_file_splice_read
++EXPORT_SYMBOL vmlinux 0xb24d8329	uart_get_divisor
++EXPORT_SYMBOL vmlinux 0xb2682405	utf8_to_utf32
++EXPORT_SYMBOL vmlinux 0xb2744b36	down_write_trylock
++EXPORT_SYMBOL vmlinux 0xb275cbd1	loop_backing_file
++EXPORT_SYMBOL vmlinux 0xb2b4b9f9	devm_clk_get
++EXPORT_SYMBOL vmlinux 0xb2b94674	__crc32c_le
++EXPORT_SYMBOL vmlinux 0xb2be6e92	netdev_stats_to_stats64
++EXPORT_SYMBOL vmlinux 0xb2c40745	file_update_time
++EXPORT_SYMBOL vmlinux 0xb2d307de	param_ops_short
++EXPORT_SYMBOL vmlinux 0xb2d48a2e	queue_work_on
++EXPORT_SYMBOL vmlinux 0xb2f545ef	nf_log_set
++EXPORT_SYMBOL vmlinux 0xb2f74fb6	intel_gmch_remove
++EXPORT_SYMBOL vmlinux 0xb2fd5ceb	__put_user_4
++EXPORT_SYMBOL vmlinux 0xb2ff94fc	tcp_simple_retransmit
++EXPORT_SYMBOL vmlinux 0xb30ee090	km_query
++EXPORT_SYMBOL vmlinux 0xb3155d6a	dev_deactivate
++EXPORT_SYMBOL vmlinux 0xb32612e0	dcb_ieee_delapp
++EXPORT_SYMBOL vmlinux 0xb3284531	acpi_dbg_layer
++EXPORT_SYMBOL vmlinux 0xb32ca0c1	dev_uc_add
++EXPORT_SYMBOL vmlinux 0xb34d4c2e	acpi_terminate
++EXPORT_SYMBOL vmlinux 0xb352177e	find_first_bit
++EXPORT_SYMBOL vmlinux 0xb356408f	netdev_printk
++EXPORT_SYMBOL vmlinux 0xb38a2b8f	isapnp_protocol
++EXPORT_SYMBOL vmlinux 0xb38dc28f	d_make_root
++EXPORT_SYMBOL vmlinux 0xb3ae6e2b	ipv6_getsockopt
++EXPORT_SYMBOL vmlinux 0xb3bc8680	neigh_seq_stop
++EXPORT_SYMBOL vmlinux 0xb3e0590d	acpi_set_current_resources
++EXPORT_SYMBOL vmlinux 0xb3f10fc4	textsearch_destroy
++EXPORT_SYMBOL vmlinux 0xb3f7646e	kthread_should_stop
++EXPORT_SYMBOL vmlinux 0xb423dba1	console_blanked
++EXPORT_SYMBOL vmlinux 0xb42462f3	inet_shutdown
++EXPORT_SYMBOL vmlinux 0xb42784d2	jbd2_journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xb4390f9a	mcount
++EXPORT_SYMBOL vmlinux 0xb439797e	invalidate_partition
++EXPORT_SYMBOL vmlinux 0xb45578b8	memscan
++EXPORT_SYMBOL vmlinux 0xb461ad17	skb_flow_dissect
++EXPORT_SYMBOL vmlinux 0xb467865c	dcache_dir_open
++EXPORT_SYMBOL vmlinux 0xb4709322	scsi_dev_info_add_list
++EXPORT_SYMBOL vmlinux 0xb4afb15b	kernel_sock_ioctl
++EXPORT_SYMBOL vmlinux 0xb4e19675	blk_pre_runtime_resume
++EXPORT_SYMBOL vmlinux 0xb502decd	vfs_mknod
++EXPORT_SYMBOL vmlinux 0xb50f1d2c	cfb_imageblit
++EXPORT_SYMBOL vmlinux 0xb52ee8be	intel_gtt_clear_range
++EXPORT_SYMBOL vmlinux 0xb54088a3	posix_acl_alloc
++EXPORT_SYMBOL vmlinux 0xb54533f7	usecs_to_jiffies
++EXPORT_SYMBOL vmlinux 0xb54935de	ht_create_irq
++EXPORT_SYMBOL vmlinux 0xb57343c2	frontswap_shrink
++EXPORT_SYMBOL vmlinux 0xb58280c8	fsync_bdev
++EXPORT_SYMBOL vmlinux 0xb586537e	eisa_driver_register
++EXPORT_SYMBOL vmlinux 0xb59e04b6	devm_ioremap
++EXPORT_SYMBOL vmlinux 0xb5a459dc	unregister_blkdev
++EXPORT_SYMBOL vmlinux 0xb5aa7165	dma_pool_destroy
++EXPORT_SYMBOL vmlinux 0xb5ca1c46	slhc_free
++EXPORT_SYMBOL vmlinux 0xb5d12910	pci_bus_alloc_resource
++EXPORT_SYMBOL vmlinux 0xb6117c33	set_anon_super
++EXPORT_SYMBOL vmlinux 0xb6148aed	scsi_track_queue_full
++EXPORT_SYMBOL vmlinux 0xb6244511	sg_init_one
++EXPORT_SYMBOL vmlinux 0xb6480703	bdi_setup_and_register
++EXPORT_SYMBOL vmlinux 0xb64937ea	drop_nlink
++EXPORT_SYMBOL vmlinux 0xb6576e56	neigh_for_each
++EXPORT_SYMBOL vmlinux 0xb65d49ab	iterate_dir
++EXPORT_SYMBOL vmlinux 0xb678366f	int_sqrt
++EXPORT_SYMBOL vmlinux 0xb6822a33	radix_tree_gang_lookup_tag
++EXPORT_SYMBOL vmlinux 0xb6896671	crc_t10dif
++EXPORT_SYMBOL vmlinux 0xb6936ffe	_bcd2bin
++EXPORT_SYMBOL vmlinux 0xb6a68816	find_last_bit
++EXPORT_SYMBOL vmlinux 0xb6c5a973	scsi_show_result
++EXPORT_SYMBOL vmlinux 0xb6ed1e53	strncpy
++EXPORT_SYMBOL vmlinux 0xb70aec0e	journal_force_commit_nested
++EXPORT_SYMBOL vmlinux 0xb7110993	pci_scan_slot
++EXPORT_SYMBOL vmlinux 0xb7396093	sk_filter
++EXPORT_SYMBOL vmlinux 0xb758b225	acpi_disable_event
++EXPORT_SYMBOL vmlinux 0xb7612c0f	i2c_smbus_write_word_data
++EXPORT_SYMBOL vmlinux 0xb7686f11	tcp_ioctl
++EXPORT_SYMBOL vmlinux 0xb77add1a	vfs_statfs
++EXPORT_SYMBOL vmlinux 0xb7ab1cde	udp_lib_rehash
++EXPORT_SYMBOL vmlinux 0xb7b61546	crc32_be
++EXPORT_SYMBOL vmlinux 0xb7d3fa46	__netlink_kernel_create
++EXPORT_SYMBOL vmlinux 0xb7f55ecc	atomic64_add_return_cx8
++EXPORT_SYMBOL vmlinux 0xb7f7ff24	__alloc_pages_nodemask
++EXPORT_SYMBOL vmlinux 0xb7f9dab9	textsearch_find_continuous
++EXPORT_SYMBOL vmlinux 0xb8039631	block_is_partially_uptodate
++EXPORT_SYMBOL vmlinux 0xb81960ca	snprintf
++EXPORT_SYMBOL vmlinux 0xb835b3e4	radix_tree_prev_hole
++EXPORT_SYMBOL vmlinux 0xb83bed07	key_type_keyring
++EXPORT_SYMBOL vmlinux 0xb874b87a	__clzsi2
++EXPORT_SYMBOL vmlinux 0xb87cc6b8	i2c_del_driver
++EXPORT_SYMBOL vmlinux 0xb8802210	swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL vmlinux 0xb8af5615	invalidate_inode_buffers
++EXPORT_SYMBOL vmlinux 0xb8d5ea7b	netif_napi_add
++EXPORT_SYMBOL vmlinux 0xb8e7ce2c	__put_user_8
++EXPORT_SYMBOL vmlinux 0xb8e877e7	kstrtouint_from_user
++EXPORT_SYMBOL vmlinux 0xb8f54350	register_xen_selfballooning
++EXPORT_SYMBOL vmlinux 0xb906a383	scsi_host_alloc
++EXPORT_SYMBOL vmlinux 0xb907513f	unpoison_memory
++EXPORT_SYMBOL vmlinux 0xb921d43b	pci_bus_put
++EXPORT_SYMBOL vmlinux 0xb924f5d3	tcp_v4_md5_lookup
++EXPORT_SYMBOL vmlinux 0xb9342045	blk_stop_queue
++EXPORT_SYMBOL vmlinux 0xb95158ab	jbd2_inode_cache
++EXPORT_SYMBOL vmlinux 0xb954402e	call_usermodehelper_exec
++EXPORT_SYMBOL vmlinux 0xb9631a38	scsi_calculate_bounce_limit
++EXPORT_SYMBOL vmlinux 0xb96c0af5	filemap_write_and_wait
++EXPORT_SYMBOL vmlinux 0xb973ec1d	ata_dev_acpi_handle
++EXPORT_SYMBOL vmlinux 0xb988d7d7	mutex_lock
++EXPORT_SYMBOL vmlinux 0xb98a0185	rtc_tm_to_time
++EXPORT_SYMBOL vmlinux 0xb99d6477	phy_disconnect
++EXPORT_SYMBOL vmlinux 0xb9a006ee	inet_dgram_ops
++EXPORT_SYMBOL vmlinux 0xb9a0651a	dm_get_device
++EXPORT_SYMBOL vmlinux 0xb9bd022b	bio_copy_user
++EXPORT_SYMBOL vmlinux 0xb9fd2205	add_efi_memmap
++EXPORT_SYMBOL vmlinux 0xba01fccf	km_state_notify
++EXPORT_SYMBOL vmlinux 0xba2d8594	ec_read
++EXPORT_SYMBOL vmlinux 0xba35cebb	wait_for_key_construction
++EXPORT_SYMBOL vmlinux 0xba497f13	loops_per_jiffy
++EXPORT_SYMBOL vmlinux 0xba4a76c8	simple_transaction_release
++EXPORT_SYMBOL vmlinux 0xba85c591	neigh_app_ns
++EXPORT_SYMBOL vmlinux 0xba8ea6ad	rwsem_downgrade_wake
++EXPORT_SYMBOL vmlinux 0xbaeffa05	qid_eq
++EXPORT_SYMBOL vmlinux 0xbaf5a234	pm860x_bulk_read
++EXPORT_SYMBOL vmlinux 0xbb002512	abx500_event_registers_startup_state_get
++EXPORT_SYMBOL vmlinux 0xbb189cad	disallow_signal
++EXPORT_SYMBOL vmlinux 0xbb4c26af	generic_fillattr
++EXPORT_SYMBOL vmlinux 0xbb5d343d	xfrm_get_acqseq
++EXPORT_SYMBOL vmlinux 0xbb62d1ab	dquot_initialize
++EXPORT_SYMBOL vmlinux 0xbb713e6d	sk_filter_release_rcu
++EXPORT_SYMBOL vmlinux 0xbb830658	devm_request_threaded_irq
++EXPORT_SYMBOL vmlinux 0xbb99125c	get_default_font
++EXPORT_SYMBOL vmlinux 0xbbba93be	__splice_from_pipe
++EXPORT_SYMBOL vmlinux 0xbc024dbd	posix_test_lock
++EXPORT_SYMBOL vmlinux 0xbc1afedf	up_write
++EXPORT_SYMBOL vmlinux 0xbc2031de	acpi_processor_get_bios_limit
++EXPORT_SYMBOL vmlinux 0xbc2d880b	have_submounts
++EXPORT_SYMBOL vmlinux 0xbc4bb07c	generic_writepages
++EXPORT_SYMBOL vmlinux 0xbc79a939	fsnotify_get_group
++EXPORT_SYMBOL vmlinux 0xbc801980	try_to_writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xbc8cef06	sync_mapping_buffers
++EXPORT_SYMBOL vmlinux 0xbcbec6bc	generic_setxattr
++EXPORT_SYMBOL vmlinux 0xbcc308bb	strnlen_user
++EXPORT_SYMBOL vmlinux 0xbce7c2c3	dev_mc_add_excl
++EXPORT_SYMBOL vmlinux 0xbceb5068	d_find_alias
++EXPORT_SYMBOL vmlinux 0xbcedf5c6	dev_load
++EXPORT_SYMBOL vmlinux 0xbcf021b4	blk_queue_end_tag
++EXPORT_SYMBOL vmlinux 0xbcf21a07	seq_read
++EXPORT_SYMBOL vmlinux 0xbcf65f71	scsi_dma_unmap
++EXPORT_SYMBOL vmlinux 0xbd086c6c	__sk_mem_schedule
++EXPORT_SYMBOL vmlinux 0xbd136f37	__vlan_find_dev_deep
++EXPORT_SYMBOL vmlinux 0xbd16d327	sg_miter_stop
++EXPORT_SYMBOL vmlinux 0xbd3b69d2	bio_split
++EXPORT_SYMBOL vmlinux 0xbd5b008c	vfs_getattr
++EXPORT_SYMBOL vmlinux 0xbd6693f5	pagevec_lookup
++EXPORT_SYMBOL vmlinux 0xbdb48b4c	sock_queue_err_skb
++EXPORT_SYMBOL vmlinux 0xbdba9828	hdmi_audio_infoframe_pack
++EXPORT_SYMBOL vmlinux 0xbdf73e50	cfb_copyarea
++EXPORT_SYMBOL vmlinux 0xbe035561	xfrm6_rcv_spi
++EXPORT_SYMBOL vmlinux 0xbe0e5118	nla_memcmp
++EXPORT_SYMBOL vmlinux 0xbe0ea992	blk_queue_stack_limits
++EXPORT_SYMBOL vmlinux 0xbe17234e	inode_add_rsv_space
++EXPORT_SYMBOL vmlinux 0xbe254e92	param_set_ushort
++EXPORT_SYMBOL vmlinux 0xbe2c0274	add_timer
++EXPORT_SYMBOL vmlinux 0xbe3765c6	ata_std_end_eh
++EXPORT_SYMBOL vmlinux 0xbe43dd8a	submit_bio
++EXPORT_SYMBOL vmlinux 0xbe525ef9	is_bad_inode
++EXPORT_SYMBOL vmlinux 0xbe6ec132	__neigh_event_send
++EXPORT_SYMBOL vmlinux 0xbe708ff8	kmem_cache_create
++EXPORT_SYMBOL vmlinux 0xbe7202fd	blk_put_request
++EXPORT_SYMBOL vmlinux 0xbe76886d	nf_register_hooks
++EXPORT_SYMBOL vmlinux 0xbe8c37d9	intel_scu_ipc_simple_command
++EXPORT_SYMBOL vmlinux 0xbe906dec	sock_update_classid
++EXPORT_SYMBOL vmlinux 0xbe98fef6	ilookup
++EXPORT_SYMBOL vmlinux 0xbea33af6	dmam_declare_coherent_memory
++EXPORT_SYMBOL vmlinux 0xbec30d05	x86_match_cpu
++EXPORT_SYMBOL vmlinux 0xbee5e29e	dev_err
++EXPORT_SYMBOL vmlinux 0xbee90f2f	__kfifo_out_peek_r
++EXPORT_SYMBOL vmlinux 0xbef263c2	scsi_prep_fn
++EXPORT_SYMBOL vmlinux 0xbef43296	console_conditional_schedule
++EXPORT_SYMBOL vmlinux 0xbf1f2c8d	sched_autogroup_create_attach
++EXPORT_SYMBOL vmlinux 0xbf2d4847	tcf_hash_lookup
++EXPORT_SYMBOL vmlinux 0xbf331b51	padata_add_cpu
++EXPORT_SYMBOL vmlinux 0xbf4bd614	scsi_cmd_ioctl
++EXPORT_SYMBOL vmlinux 0xbf4d4bb9	acpi_bios_error
++EXPORT_SYMBOL vmlinux 0xbf521954	block_invalidatepage
++EXPORT_SYMBOL vmlinux 0xbf5b8950	bio_copy_kern
++EXPORT_SYMBOL vmlinux 0xbf7b4f87	netdev_class_remove_file
++EXPORT_SYMBOL vmlinux 0xbf7fd2f5	schedule_timeout_killable
++EXPORT_SYMBOL vmlinux 0xbf8b39e9	isapnp_present
++EXPORT_SYMBOL vmlinux 0xbf9ac6c9	dev_warn
++EXPORT_SYMBOL vmlinux 0xbf9bcc8d	__cap_empty_set
++EXPORT_SYMBOL vmlinux 0xbfbda65e	posix_acl_from_xattr
++EXPORT_SYMBOL vmlinux 0xbfc177bc	iowrite32_rep
++EXPORT_SYMBOL vmlinux 0xbfc407b4	param_ops_bint
++EXPORT_SYMBOL vmlinux 0xbfee3ad5	loop_unregister_transfer
++EXPORT_SYMBOL vmlinux 0xc003bfc7	tcp_parse_options
++EXPORT_SYMBOL vmlinux 0xc017a754	jbd2_journal_check_available_features
++EXPORT_SYMBOL vmlinux 0xc01cf848	_raw_read_lock
++EXPORT_SYMBOL vmlinux 0xc01eed33	__copy_from_user_ll_nozero
++EXPORT_SYMBOL vmlinux 0xc02cf69b	clkdev_drop
++EXPORT_SYMBOL vmlinux 0xc068440e	__kfifo_alloc
++EXPORT_SYMBOL vmlinux 0xc070cc98	serial8250_register_8250_port
++EXPORT_SYMBOL vmlinux 0xc0763484	rfkill_blocked
++EXPORT_SYMBOL vmlinux 0xc087d917	filemap_fault
++EXPORT_SYMBOL vmlinux 0xc0885510	__pci_register_driver
++EXPORT_SYMBOL vmlinux 0xc0887f6d	pci_get_domain_bus_and_slot
++EXPORT_SYMBOL vmlinux 0xc08c5151	d_instantiate
++EXPORT_SYMBOL vmlinux 0xc08f7d0c	nla_put_nohdr
++EXPORT_SYMBOL vmlinux 0xc09fb2cf	tcp_v4_syn_recv_sock
++EXPORT_SYMBOL vmlinux 0xc0a3d105	find_next_bit
++EXPORT_SYMBOL vmlinux 0xc0a8ff16	acpi_evaluate_object
++EXPORT_SYMBOL vmlinux 0xc0adf077	tcp_rcv_state_process
++EXPORT_SYMBOL vmlinux 0xc0c34f4f	noop_fsync
++EXPORT_SYMBOL vmlinux 0xc0d71f2b	get_unmapped_area
++EXPORT_SYMBOL vmlinux 0xc0e8ca8b	dma_ops
++EXPORT_SYMBOL vmlinux 0xc0ef0136	backlight_device_register
++EXPORT_SYMBOL vmlinux 0xc112b35b	netif_set_real_num_rx_queues
++EXPORT_SYMBOL vmlinux 0xc11a2e52	agp_bridge
++EXPORT_SYMBOL vmlinux 0xc11d8093	iov_shorten
++EXPORT_SYMBOL vmlinux 0xc12ec3a6	dns_query
++EXPORT_SYMBOL vmlinux 0xc16563b6	dev_uc_init
++EXPORT_SYMBOL vmlinux 0xc16f96db	elevator_exit
++EXPORT_SYMBOL vmlinux 0xc17225a3	scsi_print_result
++EXPORT_SYMBOL vmlinux 0xc18400fb	dev_mc_add_global
++EXPORT_SYMBOL vmlinux 0xc1864fd2	dst_release
++EXPORT_SYMBOL vmlinux 0xc1ab0464	pci_vpd_truncate
++EXPORT_SYMBOL vmlinux 0xc1ade24f	mmc_power_restore_host
++EXPORT_SYMBOL vmlinux 0xc1c2dd09	__hw_addr_flush
++EXPORT_SYMBOL vmlinux 0xc1c3d65a	thermal_cdev_update
++EXPORT_SYMBOL vmlinux 0xc1eb75ec	follow_down
++EXPORT_SYMBOL vmlinux 0xc1f33493	phy_mac_interrupt
++EXPORT_SYMBOL vmlinux 0xc20fc969	generic_file_mmap
++EXPORT_SYMBOL vmlinux 0xc2125b1b	inode_add_bytes
++EXPORT_SYMBOL vmlinux 0xc22b50ad	param_set_bint
++EXPORT_SYMBOL vmlinux 0xc22ce009	padata_set_cpumasks
++EXPORT_SYMBOL vmlinux 0xc240b620	freezing_slow_path
++EXPORT_SYMBOL vmlinux 0xc2424641	agp3_generic_cleanup
++EXPORT_SYMBOL vmlinux 0xc2452f18	xfrm_register_type
++EXPORT_SYMBOL vmlinux 0xc256e762	__bitmap_equal
++EXPORT_SYMBOL vmlinux 0xc26f32c5	seq_bitmap
++EXPORT_SYMBOL vmlinux 0xc2708688	xfrm_unregister_mode
++EXPORT_SYMBOL vmlinux 0xc272009b	sk_alloc
++EXPORT_SYMBOL vmlinux 0xc280a525	__copy_from_user_ll
++EXPORT_SYMBOL vmlinux 0xc285b681	input_register_handle
++EXPORT_SYMBOL vmlinux 0xc293a804	proc_dointvec_minmax
++EXPORT_SYMBOL vmlinux 0xc29772c5	phy_stop
++EXPORT_SYMBOL vmlinux 0xc2a469ca	padata_do_parallel
++EXPORT_SYMBOL vmlinux 0xc2a5a7ab	mfd_remove_devices
++EXPORT_SYMBOL vmlinux 0xc2d0f355	eth_validate_addr
++EXPORT_SYMBOL vmlinux 0xc2d711e1	krealloc
++EXPORT_SYMBOL vmlinux 0xc2db4030	d_obtain_alias
++EXPORT_SYMBOL vmlinux 0xc2e587d1	reset_devices
++EXPORT_SYMBOL vmlinux 0xc2f0dee2	spi_attach_transport
++EXPORT_SYMBOL vmlinux 0xc2f9c045	timespec_to_jiffies
++EXPORT_SYMBOL vmlinux 0xc2fe1e41	d_validate
++EXPORT_SYMBOL vmlinux 0xc3107d00	arch_debugfs_dir
++EXPORT_SYMBOL vmlinux 0xc31c34bb	__scsi_iterate_devices
++EXPORT_SYMBOL vmlinux 0xc31ee0db	inet6_add_offload
++EXPORT_SYMBOL vmlinux 0xc3216911	mmc_interrupt_hpi
++EXPORT_SYMBOL vmlinux 0xc3258757	posix_unblock_lock
++EXPORT_SYMBOL vmlinux 0xc325e6e0	ipv6_select_ident
++EXPORT_SYMBOL vmlinux 0xc33b532b	acpi_bus_register_driver
++EXPORT_SYMBOL vmlinux 0xc3432185	devm_request_and_ioremap
++EXPORT_SYMBOL vmlinux 0xc374fa96	truncate_inode_pages_range
++EXPORT_SYMBOL vmlinux 0xc3aaf0a9	__put_user_1
++EXPORT_SYMBOL vmlinux 0xc3c7f7af	pci_choose_state
++EXPORT_SYMBOL vmlinux 0xc3d7d11c	neigh_lookup_nodev
++EXPORT_SYMBOL vmlinux 0xc3ea4220	agp_generic_mask_memory
++EXPORT_SYMBOL vmlinux 0xc3f456bf	__cleancache_put_page
++EXPORT_SYMBOL vmlinux 0xc3f7ff2f	input_free_device
++EXPORT_SYMBOL vmlinux 0xc3fa6a59	memchr
++EXPORT_SYMBOL vmlinux 0xc40f1844	pcie_capability_read_dword
++EXPORT_SYMBOL vmlinux 0xc41e8f7a	wait_for_completion_interruptible_timeout
++EXPORT_SYMBOL vmlinux 0xc41f0516	node_states
++EXPORT_SYMBOL vmlinux 0xc4455e95	pci_bus_read_dev_vendor_id
++EXPORT_SYMBOL vmlinux 0xc4478750	mmc_gpio_free_cd
++EXPORT_SYMBOL vmlinux 0xc4554217	up
++EXPORT_SYMBOL vmlinux 0xc499ae1e	kstrdup
++EXPORT_SYMBOL vmlinux 0xc4a506cb	grab_cache_page_write_begin
++EXPORT_SYMBOL vmlinux 0xc4b7cecd	bio_integrity_alloc
++EXPORT_SYMBOL vmlinux 0xc4becea5	sock_setsockopt
++EXPORT_SYMBOL vmlinux 0xc4cd09e9	blk_queue_io_min
++EXPORT_SYMBOL vmlinux 0xc504de8b	fsnotify_put_mark
++EXPORT_SYMBOL vmlinux 0xc51242ac	input_set_abs_params
++EXPORT_SYMBOL vmlinux 0xc52c76d7	pci_enable_ltr
++EXPORT_SYMBOL vmlinux 0xc5534d64	ioread16
++EXPORT_SYMBOL vmlinux 0xc55ec245	pnp_activate_dev
++EXPORT_SYMBOL vmlinux 0xc57ab7bc	proc_dostring
++EXPORT_SYMBOL vmlinux 0xc57cf5c6	phy_find_first
++EXPORT_SYMBOL vmlinux 0xc58f3af5	pfifo_qdisc_ops
++EXPORT_SYMBOL vmlinux 0xc5b76c69	rt6_lookup
++EXPORT_SYMBOL vmlinux 0xc5d74783	mmc_hw_reset_check
++EXPORT_SYMBOL vmlinux 0xc5d9c46c	agp_try_unsupported_boot
++EXPORT_SYMBOL vmlinux 0xc5fa52b4	phy_device_free
++EXPORT_SYMBOL vmlinux 0xc5fdef94	call_usermodehelper
++EXPORT_SYMBOL vmlinux 0xc5ffea74	tcf_exts_change
++EXPORT_SYMBOL vmlinux 0xc607565b	inc_zone_page_state
++EXPORT_SYMBOL vmlinux 0xc6085a59	registered_fb
++EXPORT_SYMBOL vmlinux 0xc60e917d	redraw_screen
++EXPORT_SYMBOL vmlinux 0xc62d4337	mmc_set_data_timeout
++EXPORT_SYMBOL vmlinux 0xc631580a	console_unlock
++EXPORT_SYMBOL vmlinux 0xc63cc125	prepare_to_wait_exclusive
++EXPORT_SYMBOL vmlinux 0xc64ea5f7	dmam_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xc657a0db	write_inode_now
++EXPORT_SYMBOL vmlinux 0xc65abeb7	agp3_generic_sizes
++EXPORT_SYMBOL vmlinux 0xc6645b42	mempool_create_node
++EXPORT_SYMBOL vmlinux 0xc6689028	elv_rb_find
++EXPORT_SYMBOL vmlinux 0xc684c2df	get_agp_version
++EXPORT_SYMBOL vmlinux 0xc6941a60	scsi_unblock_requests
++EXPORT_SYMBOL vmlinux 0xc6b18347	__d_drop
++EXPORT_SYMBOL vmlinux 0xc6b23120	intel_scu_ipc_iowrite16
++EXPORT_SYMBOL vmlinux 0xc6bf46a3	fb_set_cmap
++EXPORT_SYMBOL vmlinux 0xc6cbbc89	capable
++EXPORT_SYMBOL vmlinux 0xc6ff1eb1	thaw_super
++EXPORT_SYMBOL vmlinux 0xc702156b	param_get_ushort
++EXPORT_SYMBOL vmlinux 0xc70fb7ad	cdrom_mode_select
++EXPORT_SYMBOL vmlinux 0xc712064a	scsi_is_host_device
++EXPORT_SYMBOL vmlinux 0xc7208c3a	serial8250_resume_port
++EXPORT_SYMBOL vmlinux 0xc73ee2d7	scm_detach_fds
++EXPORT_SYMBOL vmlinux 0xc742ac7e	sk_receive_skb
++EXPORT_SYMBOL vmlinux 0xc743a3ab	generic_block_bmap
++EXPORT_SYMBOL vmlinux 0xc74c5f30	__skb_get_rxhash
++EXPORT_SYMBOL vmlinux 0xc768de19	cpu_all_bits
++EXPORT_SYMBOL vmlinux 0xc7773284	bio_integrity_clone
++EXPORT_SYMBOL vmlinux 0xc781bd9f	rfkill_resume_polling
++EXPORT_SYMBOL vmlinux 0xc7856a3d	inet6addr_notifier_call_chain
++EXPORT_SYMBOL vmlinux 0xc79a48f7	devfreq_add_governor
++EXPORT_SYMBOL vmlinux 0xc79bcd36	dm_vcalloc
++EXPORT_SYMBOL vmlinux 0xc79c8c2d	set_bdi_congested
++EXPORT_SYMBOL vmlinux 0xc7a4fbed	rtnl_lock
++EXPORT_SYMBOL vmlinux 0xc7b6e408	pci_disable_obff
++EXPORT_SYMBOL vmlinux 0xc7beeeeb	tcp_sync_mss
++EXPORT_SYMBOL vmlinux 0xc7cdabde	blk_start_request
++EXPORT_SYMBOL vmlinux 0xc7ec6c27	strspn
++EXPORT_SYMBOL vmlinux 0xc8181195	pci_remove_bus
++EXPORT_SYMBOL vmlinux 0xc8276a79	nf_hooks_needed
++EXPORT_SYMBOL vmlinux 0xc82ec97d	i2c_verify_adapter
++EXPORT_SYMBOL vmlinux 0xc8339e24	string_unescape
++EXPORT_SYMBOL vmlinux 0xc841aa81	padata_set_cpumask
++EXPORT_SYMBOL vmlinux 0xc84a0a7e	seq_hlist_start_rcu
++EXPORT_SYMBOL vmlinux 0xc85b4bd8	sock_tx_timestamp
++EXPORT_SYMBOL vmlinux 0xc864a632	d_genocide
++EXPORT_SYMBOL vmlinux 0xc8736359	scsi_init_io
++EXPORT_SYMBOL vmlinux 0xc897c382	sg_init_table
++EXPORT_SYMBOL vmlinux 0xc89c6a20	deactivate_super
++EXPORT_SYMBOL vmlinux 0xc89fa0aa	pci_bus_read_config_word
++EXPORT_SYMBOL vmlinux 0xc8b57c27	autoremove_wake_function
++EXPORT_SYMBOL vmlinux 0xc8ba16bb	unregister_netdevice_queue
++EXPORT_SYMBOL vmlinux 0xc8c031e1	led_blink_set_oneshot
++EXPORT_SYMBOL vmlinux 0xc8eb0721	inode_permission
++EXPORT_SYMBOL vmlinux 0xc9023fc2	neigh_sysctl_register
++EXPORT_SYMBOL vmlinux 0xc924a6f5	blk_queue_physical_block_size
++EXPORT_SYMBOL vmlinux 0xc94229ee	PDE_DATA
++EXPORT_SYMBOL vmlinux 0xc94a7fe4	scsi_cmd_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xc94b5828	__lock_buffer
++EXPORT_SYMBOL vmlinux 0xc974325b	truncate_pagecache
++EXPORT_SYMBOL vmlinux 0xc978e7b7	jbd2_log_wait_commit
++EXPORT_SYMBOL vmlinux 0xc996d097	del_timer
++EXPORT_SYMBOL vmlinux 0xc9ac78db	tty_lock
++EXPORT_SYMBOL vmlinux 0xc9cfb803	scsi_scan_host
++EXPORT_SYMBOL vmlinux 0xc9ec990c	vga_switcheroo_get_client_state
++EXPORT_SYMBOL vmlinux 0xc9f4200a	seq_lseek
++EXPORT_SYMBOL vmlinux 0xc9fb1770	pci_request_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xca29a246	setup_arg_pages
++EXPORT_SYMBOL vmlinux 0xca2c9d1b	__netif_schedule
++EXPORT_SYMBOL vmlinux 0xca365986	i2c_release_client
++EXPORT_SYMBOL vmlinux 0xca37547c	pnp_device_detach
++EXPORT_SYMBOL vmlinux 0xca5967e3	vm_stat
++EXPORT_SYMBOL vmlinux 0xca5dbc50	scsi_print_sense_hdr
++EXPORT_SYMBOL vmlinux 0xca5fcb0f	dev_set_group
++EXPORT_SYMBOL vmlinux 0xca725a9a	proto_register
++EXPORT_SYMBOL vmlinux 0xca792612	__insert_inode_hash
++EXPORT_SYMBOL vmlinux 0xca8acc78	acpi_dbg_level
++EXPORT_SYMBOL vmlinux 0xca8fd015	pipe_to_file
++EXPORT_SYMBOL vmlinux 0xca91a963	sock_alloc_send_pskb
++EXPORT_SYMBOL vmlinux 0xca9360b5	rb_next
++EXPORT_SYMBOL vmlinux 0xcabee95e	neigh_connected_output
++EXPORT_SYMBOL vmlinux 0xcacb5edd	nf_ct_attach
++EXPORT_SYMBOL vmlinux 0xcad36868	cad_pid
++EXPORT_SYMBOL vmlinux 0xcadb4104	km_report
++EXPORT_SYMBOL vmlinux 0xcae6ab79	inode_change_ok
++EXPORT_SYMBOL vmlinux 0xcae9b5f9	skb_copy
++EXPORT_SYMBOL vmlinux 0xcb0288ea	ledtrig_cpu
++EXPORT_SYMBOL vmlinux 0xcb07f41d	unregister_sysctl_table
++EXPORT_SYMBOL vmlinux 0xcb6b9639	pm860x_set_bits
++EXPORT_SYMBOL vmlinux 0xcb6c5ff0	vlan_dev_real_dev
++EXPORT_SYMBOL vmlinux 0xcb733bf2	acpi_bus_set_power
++EXPORT_SYMBOL vmlinux 0xcb97bbe1	iget_failed
++EXPORT_SYMBOL vmlinux 0xcbae6c7a	acpi_lid_notifier_unregister
++EXPORT_SYMBOL vmlinux 0xcbbf0a6f	audit_log_task_context
++EXPORT_SYMBOL vmlinux 0xcbc9557f	unregister_sysrq_key
++EXPORT_SYMBOL vmlinux 0xcbd7dbc3	tty_free_termios
++EXPORT_SYMBOL vmlinux 0xcbe4e87f	disk_stack_limits
++EXPORT_SYMBOL vmlinux 0xcc1f4c12	ethtool_op_get_link
++EXPORT_SYMBOL vmlinux 0xcc248d26	serial8250_suspend_port
++EXPORT_SYMBOL vmlinux 0xcc28dcff	lock_rename
++EXPORT_SYMBOL vmlinux 0xcc2a4e2b	netpoll_parse_options
++EXPORT_SYMBOL vmlinux 0xcc32a1e6	pcie_capability_write_word
++EXPORT_SYMBOL vmlinux 0xcc37f55c	blk_limits_io_opt
++EXPORT_SYMBOL vmlinux 0xcc3f8370	cdev_alloc
++EXPORT_SYMBOL vmlinux 0xcc4d1bfb	atomic64_read_cx8
++EXPORT_SYMBOL vmlinux 0xcc5005fe	msleep_interruptible
++EXPORT_SYMBOL vmlinux 0xcc52b423	__inode_permission
++EXPORT_SYMBOL vmlinux 0xcc5b27b5	acpi_extract_package
++EXPORT_SYMBOL vmlinux 0xcc6a6a50	elv_rb_latter_request
++EXPORT_SYMBOL vmlinux 0xcc7fa952	local_bh_enable_ip
++EXPORT_SYMBOL vmlinux 0xcc8cbec4	neigh_parms_alloc
++EXPORT_SYMBOL vmlinux 0xcc94cc28	load_nls
++EXPORT_SYMBOL vmlinux 0xcca5b63d	pnp_is_active
++EXPORT_SYMBOL vmlinux 0xccc21f5e	input_get_new_minor
++EXPORT_SYMBOL vmlinux 0xcccab9cc	km_policy_expired
++EXPORT_SYMBOL vmlinux 0xccdafda8	vfs_read
++EXPORT_SYMBOL vmlinux 0xccde9995	dquot_commit_info
++EXPORT_SYMBOL vmlinux 0xcce9c32e	genlmsg_put
++EXPORT_SYMBOL vmlinux 0xccf8e64d	agp_generic_destroy_pages
++EXPORT_SYMBOL vmlinux 0xcd279169	nla_find
++EXPORT_SYMBOL vmlinux 0xcd4b5984	led_set_brightness
++EXPORT_SYMBOL vmlinux 0xcd67dae3	acpi_pm_device_run_wake
++EXPORT_SYMBOL vmlinux 0xcd6c7a9b	bd_set_size
++EXPORT_SYMBOL vmlinux 0xcd88d472	register_exec_domain
++EXPORT_SYMBOL vmlinux 0xcdc1bcc6	pcim_iomap
++EXPORT_SYMBOL vmlinux 0xcdc39c9e	security_ismaclabel
++EXPORT_SYMBOL vmlinux 0xcdc40fae	panic_notifier_list
++EXPORT_SYMBOL vmlinux 0xcde172ac	radix_tree_gang_lookup_tag_slot
++EXPORT_SYMBOL vmlinux 0xcde31d9d	genl_register_mc_group
++EXPORT_SYMBOL vmlinux 0xce04e7c5	crypto_sha512_update
++EXPORT_SYMBOL vmlinux 0xce19f050	tty_port_block_til_ready
++EXPORT_SYMBOL vmlinux 0xce1f5873	kobject_add
++EXPORT_SYMBOL vmlinux 0xce20fc53	__pskb_pull_tail
++EXPORT_SYMBOL vmlinux 0xce2840e7	irq_set_irq_wake
++EXPORT_SYMBOL vmlinux 0xce42248a	simple_rmdir
++EXPORT_SYMBOL vmlinux 0xce4904a4	acpi_leave_sleep_state
++EXPORT_SYMBOL vmlinux 0xce5ac24f	zlib_inflate_workspacesize
++EXPORT_SYMBOL vmlinux 0xce5f0c3d	sk_stream_wait_memory
++EXPORT_SYMBOL vmlinux 0xce61f3d6	nobh_truncate_page
++EXPORT_SYMBOL vmlinux 0xce88efb4	boot_cpu_data
++EXPORT_SYMBOL vmlinux 0xce946043	find_get_page
++EXPORT_SYMBOL vmlinux 0xceb1340f	pci_enable_device_io
++EXPORT_SYMBOL vmlinux 0xcec71ef1	blk_bio_map_sg
++EXPORT_SYMBOL vmlinux 0xcecc1c78	new_inode
++EXPORT_SYMBOL vmlinux 0xced09fe3	sock_from_file
++EXPORT_SYMBOL vmlinux 0xced2be5d	xfrm_state_register_afinfo
++EXPORT_SYMBOL vmlinux 0xcef51982	kstrtou16
++EXPORT_SYMBOL vmlinux 0xcefcd99a	serial8250_unregister_port
++EXPORT_SYMBOL vmlinux 0xcf0139c6	poll_freewait
++EXPORT_SYMBOL vmlinux 0xcf07e5b6	proc_set_size
++EXPORT_SYMBOL vmlinux 0xcf1d28ab	acpi_error
++EXPORT_SYMBOL vmlinux 0xcf1dbc2f	tcp_rcv_established
++EXPORT_SYMBOL vmlinux 0xcf258c88	___pskb_trim
++EXPORT_SYMBOL vmlinux 0xcf33cc57	vmalloc_to_page
++EXPORT_SYMBOL vmlinux 0xcf381d58	pci_restore_state
++EXPORT_SYMBOL vmlinux 0xcf3dd60f	tcp_recvmsg
++EXPORT_SYMBOL vmlinux 0xcf3f6fb8	mb_cache_destroy
++EXPORT_SYMBOL vmlinux 0xcf410968	bitmap_endwrite
++EXPORT_SYMBOL vmlinux 0xcf6302cc	neigh_destroy
++EXPORT_SYMBOL vmlinux 0xcf6cfe1f	msrs_free
++EXPORT_SYMBOL vmlinux 0xcf791ace	jbd2_journal_wipe
++EXPORT_SYMBOL vmlinux 0xcf82197e	journal_load
++EXPORT_SYMBOL vmlinux 0xcf8a0e1d	pci_set_power_state
++EXPORT_SYMBOL vmlinux 0xcf93ce6c	jbd2_journal_destroy
++EXPORT_SYMBOL vmlinux 0xcfab1b63	skb_store_bits
++EXPORT_SYMBOL vmlinux 0xcfb2af41	napi_gro_receive
++EXPORT_SYMBOL vmlinux 0xcfb77765	console_start
++EXPORT_SYMBOL vmlinux 0xcfc02298	sock_register
++EXPORT_SYMBOL vmlinux 0xcfc1638c	mpage_readpages
++EXPORT_SYMBOL vmlinux 0xcfd77df9	file_open_root
++EXPORT_SYMBOL vmlinux 0xcfde263c	scsi_eh_prep_cmnd
++EXPORT_SYMBOL vmlinux 0xcfe05d4d	register_kmmio_probe
++EXPORT_SYMBOL vmlinux 0xd014251a	d_prune_aliases
++EXPORT_SYMBOL vmlinux 0xd0181f4f	__bitmap_xor
++EXPORT_SYMBOL vmlinux 0xd0720a17	on_each_cpu_cond
++EXPORT_SYMBOL vmlinux 0xd072d9c2	pci_enable_msi_block_auto
++EXPORT_SYMBOL vmlinux 0xd08197fa	acpi_load_tables
++EXPORT_SYMBOL vmlinux 0xd08299a4	read_cache_page_gfp
++EXPORT_SYMBOL vmlinux 0xd09705c3	__cleancache_init_fs
++EXPORT_SYMBOL vmlinux 0xd0a91bab	skip_spaces
++EXPORT_SYMBOL vmlinux 0xd0bc8722	pci_enable_bridges
++EXPORT_SYMBOL vmlinux 0xd0d42c42	mod_timer_pending
++EXPORT_SYMBOL vmlinux 0xd0d8621b	strlen
++EXPORT_SYMBOL vmlinux 0xd0dfa161	blk_complete_request
++EXPORT_SYMBOL vmlinux 0xd0e92c9e	set_pages_nx
++EXPORT_SYMBOL vmlinux 0xd0ee38b8	schedule_timeout_uninterruptible
++EXPORT_SYMBOL vmlinux 0xd0f0d945	down_read
++EXPORT_SYMBOL vmlinux 0xd0f36f0d	audit_log_format
++EXPORT_SYMBOL vmlinux 0xd0f38aae	simple_rename
++EXPORT_SYMBOL vmlinux 0xd0fb7cd4	__tasklet_hi_schedule_first
++EXPORT_SYMBOL vmlinux 0xd0fef3b2	agp_free_key
++EXPORT_SYMBOL vmlinux 0xd101bcec	dev_mc_unsync
++EXPORT_SYMBOL vmlinux 0xd11018f9	mmc_can_erase
++EXPORT_SYMBOL vmlinux 0xd11c0dc1	__kernel_param_unlock
++EXPORT_SYMBOL vmlinux 0xd13ec6d9	bio_reset
++EXPORT_SYMBOL vmlinux 0xd15c0bf0	dev_mc_sync_multiple
++EXPORT_SYMBOL vmlinux 0xd17a085c	find_lock_page
++EXPORT_SYMBOL vmlinux 0xd1816f32	frontswap_writethrough
++EXPORT_SYMBOL vmlinux 0xd18b6eb2	acpi_unmap_lsapic
++EXPORT_SYMBOL vmlinux 0xd196c9be	kstrtos16_from_user
++EXPORT_SYMBOL vmlinux 0xd1d19eb3	proc_symlink
++EXPORT_SYMBOL vmlinux 0xd1f3eae7	ipv6_chk_custom_prefix
++EXPORT_SYMBOL vmlinux 0xd1f6c5f3	smp_num_siblings
++EXPORT_SYMBOL vmlinux 0xd200a4ae	bio_sector_offset
++EXPORT_SYMBOL vmlinux 0xd20fa7e5	seq_open_private
++EXPORT_SYMBOL vmlinux 0xd219f212	scsi_device_lookup
++EXPORT_SYMBOL vmlinux 0xd220cf8a	jiffies_to_timespec
++EXPORT_SYMBOL vmlinux 0xd22a45da	inet_rtx_syn_ack
++EXPORT_SYMBOL vmlinux 0xd2329de3	wait_for_completion_killable_timeout
++EXPORT_SYMBOL vmlinux 0xd251d7b0	security_socket_getpeersec_dgram
++EXPORT_SYMBOL vmlinux 0xd2555f19	jiffies_64_to_clock_t
++EXPORT_SYMBOL vmlinux 0xd25d4f74	console_blank_hook
++EXPORT_SYMBOL vmlinux 0xd2636906	blkdev_issue_zeroout
++EXPORT_SYMBOL vmlinux 0xd266efe7	mempool_create
++EXPORT_SYMBOL vmlinux 0xd269840c	jbd2_complete_transaction
++EXPORT_SYMBOL vmlinux 0xd27b25dd	blk_check_plugged
++EXPORT_SYMBOL vmlinux 0xd2832c2d	inet_frags_fini
++EXPORT_SYMBOL vmlinux 0xd28b677e	jbd2_journal_get_write_access
++EXPORT_SYMBOL vmlinux 0xd28d67fa	security_path_rename
++EXPORT_SYMBOL vmlinux 0xd2af138b	reservation_ww_class
++EXPORT_SYMBOL vmlinux 0xd2af2e7f	pm860x_bulk_write
++EXPORT_SYMBOL vmlinux 0xd2bd8671	register_key_type
++EXPORT_SYMBOL vmlinux 0xd2bfc544	__break_lease
++EXPORT_SYMBOL vmlinux 0xd2ceb606	__dst_free
++EXPORT_SYMBOL vmlinux 0xd2da1048	register_netdevice_notifier
++EXPORT_SYMBOL vmlinux 0xd2e6a582	acpi_processor_preregister_performance
++EXPORT_SYMBOL vmlinux 0xd2fbb0ec	vfs_writev
++EXPORT_SYMBOL vmlinux 0xd2fd7af4	inet_frags_init
++EXPORT_SYMBOL vmlinux 0xd3060cd9	xfrm_state_lookup_byaddr
++EXPORT_SYMBOL vmlinux 0xd30fc3ef	__dquot_transfer
++EXPORT_SYMBOL vmlinux 0xd35e249a	_raw_read_lock_irq
++EXPORT_SYMBOL vmlinux 0xd35f712e	generic_pipe_buf_get
++EXPORT_SYMBOL vmlinux 0xd365a913	xfrm_policy_unregister_afinfo
++EXPORT_SYMBOL vmlinux 0xd3760122	__sb_start_write
++EXPORT_SYMBOL vmlinux 0xd3aaa68b	file_sb_list_del
++EXPORT_SYMBOL vmlinux 0xd3c81b11	jbd2_journal_init_jbd_inode
++EXPORT_SYMBOL vmlinux 0xd3d3a477	posix_acl_init
++EXPORT_SYMBOL vmlinux 0xd3d667a7	jbd2_journal_load
++EXPORT_SYMBOL vmlinux 0xd3dcab0b	flex_array_alloc
++EXPORT_SYMBOL vmlinux 0xd4129b7f	sock_edemux
++EXPORT_SYMBOL vmlinux 0xd4389446	__ip_select_ident
++EXPORT_SYMBOL vmlinux 0xd438bc9d	blk_queue_make_request
++EXPORT_SYMBOL vmlinux 0xd4724a87	max8998_bulk_write
++EXPORT_SYMBOL vmlinux 0xd4835ef8	dmi_check_system
++EXPORT_SYMBOL vmlinux 0xd4a2af8f	dev_set_mtu
++EXPORT_SYMBOL vmlinux 0xd4c3b174	printk_emit
++EXPORT_SYMBOL vmlinux 0xd4f30617	elv_register_queue
++EXPORT_SYMBOL vmlinux 0xd4ffa484	acpi_initialize_subsystem
++EXPORT_SYMBOL vmlinux 0xd50fef48	acpi_detach_data
++EXPORT_SYMBOL vmlinux 0xd51d0bbc	set_bh_page
++EXPORT_SYMBOL vmlinux 0xd522ce18	dev_mc_add
++EXPORT_SYMBOL vmlinux 0xd54a70a2	from_kqid_munged
++EXPORT_SYMBOL vmlinux 0xd5838157	find_vma
++EXPORT_SYMBOL vmlinux 0xd590a29f	pci_enable_device_mem
++EXPORT_SYMBOL vmlinux 0xd59be6b5	mutex_trylock
++EXPORT_SYMBOL vmlinux 0xd5a7428d	bio_copy_data
++EXPORT_SYMBOL vmlinux 0xd5b1376d	register_shrinker
++EXPORT_SYMBOL vmlinux 0xd5b95811	journal_trans_will_send_data_barrier
++EXPORT_SYMBOL vmlinux 0xd5c14b4f	md_done_sync
++EXPORT_SYMBOL vmlinux 0xd5c58784	module_put
++EXPORT_SYMBOL vmlinux 0xd5cb292f	kernel_recvmsg
++EXPORT_SYMBOL vmlinux 0xd5e0c636	inet_stream_ops
++EXPORT_SYMBOL vmlinux 0xd5f2172f	del_timer_sync
++EXPORT_SYMBOL vmlinux 0xd60002ba	ps2_end_command
++EXPORT_SYMBOL vmlinux 0xd611f50c	load_nls_default
++EXPORT_SYMBOL vmlinux 0xd61608a5	__xfrm_state_destroy
++EXPORT_SYMBOL vmlinux 0xd616683a	ecryptfs_fill_auth_tok
++EXPORT_SYMBOL vmlinux 0xd626faca	generic_splice_sendpage
++EXPORT_SYMBOL vmlinux 0xd628cc9d	jbd2_journal_release_jbd_inode
++EXPORT_SYMBOL vmlinux 0xd62c833f	schedule_timeout
++EXPORT_SYMBOL vmlinux 0xd62c9791	set_device_ro
++EXPORT_SYMBOL vmlinux 0xd6373411	locks_remove_posix
++EXPORT_SYMBOL vmlinux 0xd639ccb5	touch_buffer
++EXPORT_SYMBOL vmlinux 0xd648e564	fb_match_mode
++EXPORT_SYMBOL vmlinux 0xd651dd08	scsi_host_put
++EXPORT_SYMBOL vmlinux 0xd654e524	abx500_mask_and_set_register_interruptible
++EXPORT_SYMBOL vmlinux 0xd67067c2	xfrm6_find_1stfragopt
++EXPORT_SYMBOL vmlinux 0xd675a76e	rfkill_alloc
++EXPORT_SYMBOL vmlinux 0xd688716b	dm_kcopyd_client_create
++EXPORT_SYMBOL vmlinux 0xd6b33026	cpu_khz
++EXPORT_SYMBOL vmlinux 0xd6bfd75f	dev_uc_flush
++EXPORT_SYMBOL vmlinux 0xd6c781ff	inet_proto_csum_replace4
++EXPORT_SYMBOL vmlinux 0xd6c8abbe	lease_modify
++EXPORT_SYMBOL vmlinux 0xd6e56a4d	backlight_device_unregister
++EXPORT_SYMBOL vmlinux 0xd6ee688f	vmalloc
++EXPORT_SYMBOL vmlinux 0xd6f44d74	fsnotify_init_mark
++EXPORT_SYMBOL vmlinux 0xd713acb3	vga_switcheroo_register_handler
++EXPORT_SYMBOL vmlinux 0xd7237751	md_check_recovery
++EXPORT_SYMBOL vmlinux 0xd724438a	xfrm4_rcv_encap
++EXPORT_SYMBOL vmlinux 0xd7391556	journal_init_dev
++EXPORT_SYMBOL vmlinux 0xd73facaf	dev_change_carrier
++EXPORT_SYMBOL vmlinux 0xd748313f	skb_insert
++EXPORT_SYMBOL vmlinux 0xd748fdc8	neigh_resolve_output
++EXPORT_SYMBOL vmlinux 0xd75c79df	smp_call_function
++EXPORT_SYMBOL vmlinux 0xd76500e0	d_delete
++EXPORT_SYMBOL vmlinux 0xd77a5aa5	__bitmap_and
++EXPORT_SYMBOL vmlinux 0xd79b5a02	allow_signal
++EXPORT_SYMBOL vmlinux 0xd7a8ea05	ip_mc_dec_group
++EXPORT_SYMBOL vmlinux 0xd7bd3af2	add_wait_queue
++EXPORT_SYMBOL vmlinux 0xd7dd777b	reserve_perfctr_nmi
++EXPORT_SYMBOL vmlinux 0xd7e56a4e	simple_strtoll
++EXPORT_SYMBOL vmlinux 0xd7ea7094	nf_unregister_queue_handler
++EXPORT_SYMBOL vmlinux 0xd83e1aeb	dm_io
++EXPORT_SYMBOL vmlinux 0xd8522f08	__elv_add_request
++EXPORT_SYMBOL vmlinux 0xd85833cb	__kfifo_dma_out_prepare_r
++EXPORT_SYMBOL vmlinux 0xd85a0e93	nf_register_queue_handler
++EXPORT_SYMBOL vmlinux 0xd863b093	textsearch_unregister
++EXPORT_SYMBOL vmlinux 0xd86db7e4	setattr_copy
++EXPORT_SYMBOL vmlinux 0xd87599af	__devm_release_region
++EXPORT_SYMBOL vmlinux 0xd8777bbc	set_disk_ro
++EXPORT_SYMBOL vmlinux 0xd89da37f	movable_zone
++EXPORT_SYMBOL vmlinux 0xd8a03365	devm_input_allocate_device
++EXPORT_SYMBOL vmlinux 0xd8b19466	__ww_mutex_lock_interruptible
++EXPORT_SYMBOL vmlinux 0xd8e0e63e	end_page_writeback
++EXPORT_SYMBOL vmlinux 0xd8e35485	udp_prot
++EXPORT_SYMBOL vmlinux 0xd8e484f0	register_chrdev_region
++EXPORT_SYMBOL vmlinux 0xd908a0a9	vfs_open
++EXPORT_SYMBOL vmlinux 0xd9091363	acpi_install_notify_handler
++EXPORT_SYMBOL vmlinux 0xd9132aa8	ioc_lookup_icq
++EXPORT_SYMBOL vmlinux 0xd92afabe	bitmap_clear
++EXPORT_SYMBOL vmlinux 0xd9401422	pcie_capability_clear_and_set_word
++EXPORT_SYMBOL vmlinux 0xd9453d11	thaw_bdev
++EXPORT_SYMBOL vmlinux 0xd95e32dc	iunique
++EXPORT_SYMBOL vmlinux 0xd9606540	inet6_add_protocol
++EXPORT_SYMBOL vmlinux 0xd969b2c7	amd_e400_c1e_detected
++EXPORT_SYMBOL vmlinux 0xd979038e	jbd2_journal_begin_ordered_truncate
++EXPORT_SYMBOL vmlinux 0xd985dc99	mempool_free_pages
++EXPORT_SYMBOL vmlinux 0xd990546c	lg_local_unlock_cpu
++EXPORT_SYMBOL vmlinux 0xd9987994	wake_up_process
++EXPORT_SYMBOL vmlinux 0xd998bbac	pci_target_state
++EXPORT_SYMBOL vmlinux 0xd9a54e6c	send_sig_info
++EXPORT_SYMBOL vmlinux 0xd9a9bb30	getname
++EXPORT_SYMBOL vmlinux 0xd9b5d514	unregister_binfmt
++EXPORT_SYMBOL vmlinux 0xd9e61fcb	qid_valid
++EXPORT_SYMBOL vmlinux 0xda0828b6	security_file_permission
++EXPORT_SYMBOL vmlinux 0xda08c0d7	pcibios_get_irq_routing_table
++EXPORT_SYMBOL vmlinux 0xda0a6b0e	acpi_map_lsapic
++EXPORT_SYMBOL vmlinux 0xda0c3849	idr_destroy
++EXPORT_SYMBOL vmlinux 0xda3d10a8	security_tun_dev_open
++EXPORT_SYMBOL vmlinux 0xda4ae743	xfrm_register_mode
++EXPORT_SYMBOL vmlinux 0xda63c9cd	phy_driver_unregister
++EXPORT_SYMBOL vmlinux 0xda7ca6cb	fb_mode_is_equal
++EXPORT_SYMBOL vmlinux 0xda83cb55	clocksource_unregister
++EXPORT_SYMBOL vmlinux 0xda8af7ad	fb_find_nearest_mode
++EXPORT_SYMBOL vmlinux 0xda8fd495	isapnp_write_byte
++EXPORT_SYMBOL vmlinux 0xda90721d	update_region
++EXPORT_SYMBOL vmlinux 0xdaa57ec3	totalhigh_pages
++EXPORT_SYMBOL vmlinux 0xdac2bef0	dev_uc_add_excl
++EXPORT_SYMBOL vmlinux 0xdac57839	__dev_get_by_index
++EXPORT_SYMBOL vmlinux 0xdad471f5	skb_queue_purge
++EXPORT_SYMBOL vmlinux 0xdadd8b35	audit_log_task_info
++EXPORT_SYMBOL vmlinux 0xdaf00d45	i2c_transfer
++EXPORT_SYMBOL vmlinux 0xdaf85ece	agp_generic_alloc_pages
++EXPORT_SYMBOL vmlinux 0xdb006441	dev_loopback_xmit
++EXPORT_SYMBOL vmlinux 0xdb3c71be	__blk_run_queue
++EXPORT_SYMBOL vmlinux 0xdb4740dc	tty_vhangup
++EXPORT_SYMBOL vmlinux 0xdb68bbad	rfkill_destroy
++EXPORT_SYMBOL vmlinux 0xdb6be91f	mapping_tagged
++EXPORT_SYMBOL vmlinux 0xdb760f52	__kfifo_free
++EXPORT_SYMBOL vmlinux 0xdb88e4d1	dquot_scan_active
++EXPORT_SYMBOL vmlinux 0xdbae6244	mdiobus_alloc_size
++EXPORT_SYMBOL vmlinux 0xdbcd416e	sysctl_ip_nonlocal_bind
++EXPORT_SYMBOL vmlinux 0xdbea89e3	grab_cache_page_nowait
++EXPORT_SYMBOL vmlinux 0xdbf91dc1	ida_init
++EXPORT_SYMBOL vmlinux 0xdc047fc4	scsi_dev_info_list_add_keyed
++EXPORT_SYMBOL vmlinux 0xdc14eda7	pci_pci_problems
++EXPORT_SYMBOL vmlinux 0xdc271a38	dma_supported
++EXPORT_SYMBOL vmlinux 0xdc3fcbc9	__sw_hweight8
++EXPORT_SYMBOL vmlinux 0xdc49baaa	pci_bus_write_config_byte
++EXPORT_SYMBOL vmlinux 0xdc49e813	sock_wfree
++EXPORT_SYMBOL vmlinux 0xdc570f62	lg_global_unlock
++EXPORT_SYMBOL vmlinux 0xdc57f532	acpi_install_gpe_handler
++EXPORT_SYMBOL vmlinux 0xdc636d29	inet_dev_addr_type
++EXPORT_SYMBOL vmlinux 0xdc6d41cf	vfs_fstatat
++EXPORT_SYMBOL vmlinux 0xdc8a07b5	mmc_request_done
++EXPORT_SYMBOL vmlinux 0xdc96ce13	blk_queue_max_segment_size
++EXPORT_SYMBOL vmlinux 0xdca28ee1	pci_bus_write_config_word
++EXPORT_SYMBOL vmlinux 0xdd0a2ba2	strlcat
++EXPORT_SYMBOL vmlinux 0xdd1a2871	down
++EXPORT_SYMBOL vmlinux 0xdd44bae4	dcb_ieee_setapp
++EXPORT_SYMBOL vmlinux 0xdd4748b3	filp_open
++EXPORT_SYMBOL vmlinux 0xdd4a5569	param_get_byte
++EXPORT_SYMBOL vmlinux 0xddbf14b5	inet6_del_protocol
++EXPORT_SYMBOL vmlinux 0xddc1bc47	tcp_getsockopt
++EXPORT_SYMBOL vmlinux 0xddc5b3b7	do_splice_to
++EXPORT_SYMBOL vmlinux 0xddc62b91	inet_del_protocol
++EXPORT_SYMBOL vmlinux 0xde16dc16	tboot
++EXPORT_SYMBOL vmlinux 0xde301442	ndo_dflt_fdb_add
++EXPORT_SYMBOL vmlinux 0xde4b4147	pv_cpu_ops
++EXPORT_SYMBOL vmlinux 0xde60c762	ppp_input
++EXPORT_SYMBOL vmlinux 0xde68863d	netpoll_rx_disable
++EXPORT_SYMBOL vmlinux 0xde8a1f7e	pm8606_osc_enable
++EXPORT_SYMBOL vmlinux 0xde9360ba	totalram_pages
++EXPORT_SYMBOL vmlinux 0xde9b17ed	agp3_generic_fetch_size
++EXPORT_SYMBOL vmlinux 0xdea83675	vm_iomap_memory
++EXPORT_SYMBOL vmlinux 0xdeaccb9f	phy_ethtool_set_wol
++EXPORT_SYMBOL vmlinux 0xdee4b8f2	blk_queue_invalidate_tags
++EXPORT_SYMBOL vmlinux 0xdef24b87	check_disk_change
++EXPORT_SYMBOL vmlinux 0xdf0da3cc	acpi_get_devices
++EXPORT_SYMBOL vmlinux 0xdf13b6b2	sock_no_listen
++EXPORT_SYMBOL vmlinux 0xdf2c2742	rb_last
++EXPORT_SYMBOL vmlinux 0xdf34f5e2	irq_to_desc
++EXPORT_SYMBOL vmlinux 0xdf48a0eb	flex_array_put
++EXPORT_SYMBOL vmlinux 0xdf4f00bd	rps_may_expire_flow
++EXPORT_SYMBOL vmlinux 0xdf54a8f7	netlink_unregister_notifier
++EXPORT_SYMBOL vmlinux 0xdf60cc27	__print_symbol
++EXPORT_SYMBOL vmlinux 0xdf85e1d8	pci_map_biosrom
++EXPORT_SYMBOL vmlinux 0xdf8c695a	__ndelay
++EXPORT_SYMBOL vmlinux 0xdf929370	fs_overflowgid
++EXPORT_SYMBOL vmlinux 0xdfa1d074	tty_port_close
++EXPORT_SYMBOL vmlinux 0xdfc4bd1c	twl6040_get_vibralr_status
++EXPORT_SYMBOL vmlinux 0xdfc5169b	slhc_init
++EXPORT_SYMBOL vmlinux 0xe0267bf5	ip_getsockopt
++EXPORT_SYMBOL vmlinux 0xe04f7caa	dm_read_arg_group
++EXPORT_SYMBOL vmlinux 0xe05eb849	simple_write_begin
++EXPORT_SYMBOL vmlinux 0xe06141e9	security_sk_clone
++EXPORT_SYMBOL vmlinux 0xe075d6eb	iter_div_u64_rem
++EXPORT_SYMBOL vmlinux 0xe08ffe26	blk_alloc_queue_node
++EXPORT_SYMBOL vmlinux 0xe097dcc8	dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xe0a16a20	intel_scu_ipc_i2c_cntrl
++EXPORT_SYMBOL vmlinux 0xe0ac8bd2	acpi_bus_generate_netlink_event
++EXPORT_SYMBOL vmlinux 0xe0b13336	argv_free
++EXPORT_SYMBOL vmlinux 0xe0c1fa3c	icmpv6_send
++EXPORT_SYMBOL vmlinux 0xe1082b79	tcp_poll
++EXPORT_SYMBOL vmlinux 0xe10bafe3	__task_pid_nr_ns
++EXPORT_SYMBOL vmlinux 0xe11cfaa8	fbcon_set_bitops
++EXPORT_SYMBOL vmlinux 0xe13cd8a7	dmi_name_in_vendors
++EXPORT_SYMBOL vmlinux 0xe14cf9bf	xfrm_lookup
++EXPORT_SYMBOL vmlinux 0xe1761617	security_inet_conn_request
++EXPORT_SYMBOL vmlinux 0xe1ba538c	d_alloc
++EXPORT_SYMBOL vmlinux 0xe1bbd970	kern_path_create
++EXPORT_SYMBOL vmlinux 0xe1c70127	sock_no_getsockopt
++EXPORT_SYMBOL vmlinux 0xe1d45d3e	seq_release
++EXPORT_SYMBOL vmlinux 0xe1fa85cd	vfsmount_lock
++EXPORT_SYMBOL vmlinux 0xe200d2d5	param_get_uint
++EXPORT_SYMBOL vmlinux 0xe200f872	secure_dccpv6_sequence_number
++EXPORT_SYMBOL vmlinux 0xe2034333	acpi_evaluate_hotplug_ost
++EXPORT_SYMBOL vmlinux 0xe2112e5d	pci_setup_cardbus
++EXPORT_SYMBOL vmlinux 0xe21d0bd7	blk_queue_max_write_same_sectors
++EXPORT_SYMBOL vmlinux 0xe23ae481	blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe24d3a97	jiffies_64
++EXPORT_SYMBOL vmlinux 0xe25aef64	swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL vmlinux 0xe25efccd	sk_page_frag_refill
++EXPORT_SYMBOL vmlinux 0xe26d27cd	jbd2_journal_invalidatepage
++EXPORT_SYMBOL vmlinux 0xe282d856	__blk_end_request_cur
++EXPORT_SYMBOL vmlinux 0xe29095c6	inet_frag_kill
++EXPORT_SYMBOL vmlinux 0xe29e1d0e	out_of_line_wait_on_atomic_t
++EXPORT_SYMBOL vmlinux 0xe29e68d9	dquot_disable
++EXPORT_SYMBOL vmlinux 0xe2aba04c	follow_up
++EXPORT_SYMBOL vmlinux 0xe2d5255a	strcmp
++EXPORT_SYMBOL vmlinux 0xe2d841e2	__sb_end_write
++EXPORT_SYMBOL vmlinux 0xe2e8065e	memdup_user
++EXPORT_SYMBOL vmlinux 0xe2fae716	kmemdup
++EXPORT_SYMBOL vmlinux 0xe319eb24	acpi_pci_osc_control_set
++EXPORT_SYMBOL vmlinux 0xe31eee75	tty_devnum
++EXPORT_SYMBOL vmlinux 0xe3500b35	devm_backlight_device_register
++EXPORT_SYMBOL vmlinux 0xe3786139	tty_register_driver
++EXPORT_SYMBOL vmlinux 0xe3c25942	flush_signals
++EXPORT_SYMBOL vmlinux 0xe3c799fd	genphy_suspend
++EXPORT_SYMBOL vmlinux 0xe3d6f284	fb_find_mode_cvt
++EXPORT_SYMBOL vmlinux 0xe3e51745	uart_write_wakeup
++EXPORT_SYMBOL vmlinux 0xe3e9ec45	scsi_test_unit_ready
++EXPORT_SYMBOL vmlinux 0xe40a629c	pci_get_class
++EXPORT_SYMBOL vmlinux 0xe40f2eb1	generic_pipe_buf_steal
++EXPORT_SYMBOL vmlinux 0xe41cabf8	scsi_finish_command
++EXPORT_SYMBOL vmlinux 0xe42526cb	dma_release_declared_memory
++EXPORT_SYMBOL vmlinux 0xe426a771	tcp_gro_receive
++EXPORT_SYMBOL vmlinux 0xe45e3107	skb_clone
++EXPORT_SYMBOL vmlinux 0xe45f60d8	__wake_up
++EXPORT_SYMBOL vmlinux 0xe46960e9	rtnetlink_put_metrics
++EXPORT_SYMBOL vmlinux 0xe479681a	aio_complete
++EXPORT_SYMBOL vmlinux 0xe47be791	mb_cache_entry_find_next
++EXPORT_SYMBOL vmlinux 0xe484e35f	ioread32
++EXPORT_SYMBOL vmlinux 0xe496b391	poll_initwait
++EXPORT_SYMBOL vmlinux 0xe4d6f107	pci_platform_rom
++EXPORT_SYMBOL vmlinux 0xe4df06be	dev_mc_flush
++EXPORT_SYMBOL vmlinux 0xe4e319c0	tcp_splice_read
++EXPORT_SYMBOL vmlinux 0xe5050557	kernel_connect
++EXPORT_SYMBOL vmlinux 0xe507af6d	blk_queue_init_tags
++EXPORT_SYMBOL vmlinux 0xe50f904f	intel_scu_ipc_ioread16
++EXPORT_SYMBOL vmlinux 0xe5122890	flow_cache_genid
++EXPORT_SYMBOL vmlinux 0xe5208918	acpi_gbl_FADT
++EXPORT_SYMBOL vmlinux 0xe5225e8c	bio_put
++EXPORT_SYMBOL vmlinux 0xe523ad75	synchronize_irq
++EXPORT_SYMBOL vmlinux 0xe530d757	acpi_clear_gpe
++EXPORT_SYMBOL vmlinux 0xe534f28d	keyring_clear
++EXPORT_SYMBOL vmlinux 0xe54712f2	dquot_get_dqblk
++EXPORT_SYMBOL vmlinux 0xe57878a1	in6_pton
++EXPORT_SYMBOL vmlinux 0xe5867808	dlci_ioctl_set
++EXPORT_SYMBOL vmlinux 0xe59a0119	proc_dointvec_userhz_jiffies
++EXPORT_SYMBOL vmlinux 0xe59d222d	truncate_pagecache_range
++EXPORT_SYMBOL vmlinux 0xe59d6e5a	__skb_warn_lro_forwarding
++EXPORT_SYMBOL vmlinux 0xe5c78a99	do_blank_screen
++EXPORT_SYMBOL vmlinux 0xe5cfa083	pci_release_regions
++EXPORT_SYMBOL vmlinux 0xe5d862f5	ps2_command
++EXPORT_SYMBOL vmlinux 0xe5d95985	param_ops_ulong
++EXPORT_SYMBOL vmlinux 0xe5ed5467	xfrm_policy_walk_init
++EXPORT_SYMBOL vmlinux 0xe60073fc	nf_ip_checksum
++EXPORT_SYMBOL vmlinux 0xe6024c73	xfrm_policy_flush
++EXPORT_SYMBOL vmlinux 0xe603202e	eth_header
++EXPORT_SYMBOL vmlinux 0xe609abff	scsi_is_target_device
++EXPORT_SYMBOL vmlinux 0xe61087f6	sb_set_blocksize
++EXPORT_SYMBOL vmlinux 0xe61728a3	tcp_get_md5sig_pool
++EXPORT_SYMBOL vmlinux 0xe61978bd	agp_put_bridge
++EXPORT_SYMBOL vmlinux 0xe623f655	sock_kfree_s
++EXPORT_SYMBOL vmlinux 0xe631d933	scsi_prep_state_check
++EXPORT_SYMBOL vmlinux 0xe64d1601	follow_down_one
++EXPORT_SYMBOL vmlinux 0xe64d98fe	rdmsr_safe_regs
++EXPORT_SYMBOL vmlinux 0xe6685042	fddi_change_mtu
++EXPORT_SYMBOL vmlinux 0xe6837b2c	bio_alloc_pages
++EXPORT_SYMBOL vmlinux 0xe68ece7f	lock_may_write
++EXPORT_SYMBOL vmlinux 0xe697d108	__blk_iopoll_complete
++EXPORT_SYMBOL vmlinux 0xe6b3fe21	interruptible_sleep_on_timeout
++EXPORT_SYMBOL vmlinux 0xe6c2766e	key_unlink
++EXPORT_SYMBOL vmlinux 0xe6ebc016	key_create_or_update
++EXPORT_SYMBOL vmlinux 0xe6fbe430	can_do_mlock
++EXPORT_SYMBOL vmlinux 0xe7150c80	nf_setsockopt
++EXPORT_SYMBOL vmlinux 0xe716baed	acpi_unregister_ioapic
++EXPORT_SYMBOL vmlinux 0xe749ed89	scsi_eh_finish_cmd
++EXPORT_SYMBOL vmlinux 0xe74bd9b0	blk_get_request
++EXPORT_SYMBOL vmlinux 0xe75af56b	__block_write_begin
++EXPORT_SYMBOL vmlinux 0xe769e402	set_pages_x
++EXPORT_SYMBOL vmlinux 0xe7722171	flex_array_free
++EXPORT_SYMBOL vmlinux 0xe781b5f6	intel_scu_ipc_readv
++EXPORT_SYMBOL vmlinux 0xe7844dd7	arp_invalidate
++EXPORT_SYMBOL vmlinux 0xe797526a	kmap_atomic
++EXPORT_SYMBOL vmlinux 0xe798d71c	cpu_core_map
++EXPORT_SYMBOL vmlinux 0xe79c2954	log_start_commit
++EXPORT_SYMBOL vmlinux 0xe7a664c4	nf_hooks
++EXPORT_SYMBOL vmlinux 0xe7a81967	audit_log_secctx
++EXPORT_SYMBOL vmlinux 0xe7d0052e	blk_get_queue
++EXPORT_SYMBOL vmlinux 0xe7d4daac	seq_list_next
++EXPORT_SYMBOL vmlinux 0xe7dc73c8	do_truncate
++EXPORT_SYMBOL vmlinux 0xe7fba873	generic_ro_fops
++EXPORT_SYMBOL vmlinux 0xe80ce219	sysctl_tcp_dma_copybreak
++EXPORT_SYMBOL vmlinux 0xe8315547	fasync_helper
++EXPORT_SYMBOL vmlinux 0xe851b97a	secpath_dup
++EXPORT_SYMBOL vmlinux 0xe851bb05	queue_delayed_work_on
++EXPORT_SYMBOL vmlinux 0xe85dab51	dev_addr_flush
++EXPORT_SYMBOL vmlinux 0xe8794ce1	slhc_toss
++EXPORT_SYMBOL vmlinux 0xe88e7a93	lg_global_lock
++EXPORT_SYMBOL vmlinux 0xe8a4335c	save_mount_options
++EXPORT_SYMBOL vmlinux 0xe8a5d0aa	security_inode_readlink
++EXPORT_SYMBOL vmlinux 0xe8b30c58	vfs_follow_link
++EXPORT_SYMBOL vmlinux 0xe8b63ace	radix_tree_range_tag_if_tagged
++EXPORT_SYMBOL vmlinux 0xe8b68849	wrmsr_on_cpus
++EXPORT_SYMBOL vmlinux 0xe8bea3bc	qdisc_put_stab
++EXPORT_SYMBOL vmlinux 0xe8d92d91	xfrm_policy_bysel_ctx
++EXPORT_SYMBOL vmlinux 0xe8dbfd04	twl6040_set_pll
++EXPORT_SYMBOL vmlinux 0xe8e1fbf2	tty_mutex
++EXPORT_SYMBOL vmlinux 0xe8efc5e1	init_net
++EXPORT_SYMBOL vmlinux 0xe8fdc253	skb_copy_bits
++EXPORT_SYMBOL vmlinux 0xe90f3214	phy_mii_ioctl
++EXPORT_SYMBOL vmlinux 0xe914e41e	strcpy
++EXPORT_SYMBOL vmlinux 0xe92d59cf	ip6_route_me_harder
++EXPORT_SYMBOL vmlinux 0xe935e548	spi_schedule_dv_device
++EXPORT_SYMBOL vmlinux 0xe941397e	sock_no_mmap
++EXPORT_SYMBOL vmlinux 0xe94ff054	skb_queue_tail
++EXPORT_SYMBOL vmlinux 0xe9503674	swiotlb_alloc_coherent
++EXPORT_SYMBOL vmlinux 0xe95274d5	dqget
++EXPORT_SYMBOL vmlinux 0xe953b21f	get_next_ino
++EXPORT_SYMBOL vmlinux 0xe9702f4a	genl_unregister_family
++EXPORT_SYMBOL vmlinux 0xe997667b	wrmsr_on_cpu
++EXPORT_SYMBOL vmlinux 0xe99daf3d	mark_buffer_dirty_inode
++EXPORT_SYMBOL vmlinux 0xe9a9c6f5	register_quota_format
++EXPORT_SYMBOL vmlinux 0xe9ab8b23	ip_cmsg_recv
++EXPORT_SYMBOL vmlinux 0xe9b58d03	bio_integrity_advance
++EXPORT_SYMBOL vmlinux 0xe9c4dbd7	neigh_seq_start
++EXPORT_SYMBOL vmlinux 0xe9cd5f4a	vga_switcheroo_client_fb_set
++EXPORT_SYMBOL vmlinux 0xe9e953ac	jbd2_journal_restart
++EXPORT_SYMBOL vmlinux 0xe9fe14eb	twl6040_reg_read
++EXPORT_SYMBOL vmlinux 0xea0376ae	pci_bus_read_config_dword
++EXPORT_SYMBOL vmlinux 0xea054b22	nla_policy_len
++EXPORT_SYMBOL vmlinux 0xea10212a	int_to_scsilun
++EXPORT_SYMBOL vmlinux 0xea10655a	__bitmap_intersects
++EXPORT_SYMBOL vmlinux 0xea2df64c	mfd_cell_enable
++EXPORT_SYMBOL vmlinux 0xea4295aa	xfrm_policy_walk
++EXPORT_SYMBOL vmlinux 0xea7987f1	key_update
++EXPORT_SYMBOL vmlinux 0xea7b8a44	acpi_install_interface
++EXPORT_SYMBOL vmlinux 0xea90bdd3	acpi_attach_data
++EXPORT_SYMBOL vmlinux 0xeaa56736	mount_nodev
++EXPORT_SYMBOL vmlinux 0xead52ef2	bio_integrity_set_tag
++EXPORT_SYMBOL vmlinux 0xeae3dfd6	__const_udelay
++EXPORT_SYMBOL vmlinux 0xeae88332	generic_file_splice_write
++EXPORT_SYMBOL vmlinux 0xeb0fb2ef	generic_permission
++EXPORT_SYMBOL vmlinux 0xeb14d315	mmc_start_req
++EXPORT_SYMBOL vmlinux 0xeb37101c	audit_log_end
++EXPORT_SYMBOL vmlinux 0xeb55a931	__kfifo_max_r
++EXPORT_SYMBOL vmlinux 0xeb93d091	__dec_zone_page_state
++EXPORT_SYMBOL vmlinux 0xeba32221	sync_inode_metadata
++EXPORT_SYMBOL vmlinux 0xebacb83e	iov_iter_copy_from_user
++EXPORT_SYMBOL vmlinux 0xebae4be2	dev_set_mac_address
++EXPORT_SYMBOL vmlinux 0xebb62ad6	elevator_change
++EXPORT_SYMBOL vmlinux 0xebbab6f5	i8042_install_filter
++EXPORT_SYMBOL vmlinux 0xebbf67ff	agp_unbind_memory
++EXPORT_SYMBOL vmlinux 0xebc1a303	agp_generic_enable
++EXPORT_SYMBOL vmlinux 0xebdbe48c	radix_tree_gang_lookup
++EXPORT_SYMBOL vmlinux 0xebe3fbd0	serio_rescan
++EXPORT_SYMBOL vmlinux 0xebe77c7a	seq_escape
++EXPORT_SYMBOL vmlinux 0xebe7ac84	inet_csk_delete_keepalive_timer
++EXPORT_SYMBOL vmlinux 0xebefab5d	dump_trace
++EXPORT_SYMBOL vmlinux 0xebeffade	phy_register_fixup_for_id
++EXPORT_SYMBOL vmlinux 0xebf09885	gnet_stats_start_copy_compat
++EXPORT_SYMBOL vmlinux 0xebfa1015	bioset_integrity_create
++EXPORT_SYMBOL vmlinux 0xec11776d	md_integrity_register
++EXPORT_SYMBOL vmlinux 0xec1a895a	dma_async_memcpy_buf_to_buf
++EXPORT_SYMBOL vmlinux 0xec22cd90	tty_port_tty_set
++EXPORT_SYMBOL vmlinux 0xec3e7753	genphy_restart_aneg
++EXPORT_SYMBOL vmlinux 0xec43abb9	bitmap_startwrite
++EXPORT_SYMBOL vmlinux 0xec4680d8	fsnotify_put_group
++EXPORT_SYMBOL vmlinux 0xec4d9e3a	clk_get_sys
++EXPORT_SYMBOL vmlinux 0xec6392e9	pcim_iomap_regions
++EXPORT_SYMBOL vmlinux 0xec672924	eth_header_cache_update
++EXPORT_SYMBOL vmlinux 0xecb721f1	try_wait_for_completion
++EXPORT_SYMBOL vmlinux 0xeccabd10	security_path_mknod
++EXPORT_SYMBOL vmlinux 0xeccd3e0c	acpi_handle_printk
++EXPORT_SYMBOL vmlinux 0xecd1b178	blk_queue_segment_boundary
++EXPORT_SYMBOL vmlinux 0xecd3d34e	scsi_adjust_queue_depth
++EXPORT_SYMBOL vmlinux 0xecdbd1ac	jbd2_journal_errno
++EXPORT_SYMBOL vmlinux 0xece784c2	rb_first
++EXPORT_SYMBOL vmlinux 0xece89291	abx500_remove_ops
++EXPORT_SYMBOL vmlinux 0xed0553e5	devfreq_monitor_stop
++EXPORT_SYMBOL vmlinux 0xed056fa3	mark_buffer_dirty
++EXPORT_SYMBOL vmlinux 0xed116e2e	pci_claim_resource
++EXPORT_SYMBOL vmlinux 0xed21e97f	fb_get_mode
++EXPORT_SYMBOL vmlinux 0xed4dbda8	get_super_thawed
++EXPORT_SYMBOL vmlinux 0xed548a12	scsi_device_put
++EXPORT_SYMBOL vmlinux 0xed54c1c2	start_tty
++EXPORT_SYMBOL vmlinux 0xed563c07	mmc_wait_for_req
++EXPORT_SYMBOL vmlinux 0xed597524	qdisc_get_rtab
++EXPORT_SYMBOL vmlinux 0xed5f68cd	dcbnl_ieee_notify
++EXPORT_SYMBOL vmlinux 0xed7e1295	gen_pool_create
++EXPORT_SYMBOL vmlinux 0xed800f25	input_mt_report_slot_state
++EXPORT_SYMBOL vmlinux 0xed93f29e	__kunmap_atomic
++EXPORT_SYMBOL vmlinux 0xed9f9a20	__ctzsi2
++EXPORT_SYMBOL vmlinux 0xedbaee5e	nla_strcmp
++EXPORT_SYMBOL vmlinux 0xedc03953	iounmap
++EXPORT_SYMBOL vmlinux 0xee08b3fe	ab3100_event_unregister
++EXPORT_SYMBOL vmlinux 0xee19f163	pci_wake_from_d3
++EXPORT_SYMBOL vmlinux 0xee1bbfe1	qdisc_destroy
++EXPORT_SYMBOL vmlinux 0xee2861f5	scsi_cmd_blk_ioctl
++EXPORT_SYMBOL vmlinux 0xee2d0fc7	_local_bh_enable
++EXPORT_SYMBOL vmlinux 0xee353287	jbd2_journal_stop
++EXPORT_SYMBOL vmlinux 0xee4e33dd	skb_trim
++EXPORT_SYMBOL vmlinux 0xee5a720e	__nla_reserve
++EXPORT_SYMBOL vmlinux 0xee7eb9e1	pnp_platform_devices
++EXPORT_SYMBOL vmlinux 0xee7f371d	sock_no_recvmsg
++EXPORT_SYMBOL vmlinux 0xee7fa9d6	jbd2_journal_ack_err
++EXPORT_SYMBOL vmlinux 0xee856cfb	rtmsg_ifinfo
++EXPORT_SYMBOL vmlinux 0xee941644	nla_reserve_nohdr
++EXPORT_SYMBOL vmlinux 0xee95a2ed	posix_acl_from_mode
++EXPORT_SYMBOL vmlinux 0xee9b1f52	eisa_bus_type
++EXPORT_SYMBOL vmlinux 0xee9cc18d	pci_request_region
++EXPORT_SYMBOL vmlinux 0xeea9dbaf	bitmap_bitremap
++EXPORT_SYMBOL vmlinux 0xeec05be0	pcix_get_max_mmrbc
++EXPORT_SYMBOL vmlinux 0xeed396b6	dev_get_by_name_rcu
++EXPORT_SYMBOL vmlinux 0xeed6ecb5	dma_find_channel
++EXPORT_SYMBOL vmlinux 0xef058593	__frontswap_test
++EXPORT_SYMBOL vmlinux 0xef1d35b7	acpi_install_address_space_handler
++EXPORT_SYMBOL vmlinux 0xef2eb068	cleancache_register_ops
++EXPORT_SYMBOL vmlinux 0xef2fd737	xfrm_sad_getinfo
++EXPORT_SYMBOL vmlinux 0xef35d613	alloc_disk_node
++EXPORT_SYMBOL vmlinux 0xef853217	tty_write_room
++EXPORT_SYMBOL vmlinux 0xef9496d2	ipv6_push_nfrag_opts
++EXPORT_SYMBOL vmlinux 0xef9aedfc	boot_option_idle_override
++EXPORT_SYMBOL vmlinux 0xef9daaf4	swiotlb_sync_single_for_device
++EXPORT_SYMBOL vmlinux 0xefafbd46	put_io_context
++EXPORT_SYMBOL vmlinux 0xefb58323	skb_dequeue
++EXPORT_SYMBOL vmlinux 0xefb67e8b	i2c_clients_command
++EXPORT_SYMBOL vmlinux 0xefc00add	insert_inode_locked4
++EXPORT_SYMBOL vmlinux 0xefdb2625	mmc_release_host
++EXPORT_SYMBOL vmlinux 0xefdd70ce	security_secid_to_secctx
++EXPORT_SYMBOL vmlinux 0xefe099c3	acpi_get_event_status
++EXPORT_SYMBOL vmlinux 0xefe9b3bd	may_umount
++EXPORT_SYMBOL vmlinux 0xf0009fee	put_pages_list
++EXPORT_SYMBOL vmlinux 0xf002d270	devfreq_remove_device
++EXPORT_SYMBOL vmlinux 0xf0040079	rwsem_down_read_failed
++EXPORT_SYMBOL vmlinux 0xf0187927	__sg_page_iter_next
++EXPORT_SYMBOL vmlinux 0xf0188f2a	neigh_sysctl_unregister
++EXPORT_SYMBOL vmlinux 0xf041f3c0	vfs_setpos
++EXPORT_SYMBOL vmlinux 0xf0430ad1	rtnl_notify
++EXPORT_SYMBOL vmlinux 0xf04dd3e8	sock_create_lite
++EXPORT_SYMBOL vmlinux 0xf056c0ff	inet_frag_find
++EXPORT_SYMBOL vmlinux 0xf05ffa15	fb_var_to_videomode
++EXPORT_SYMBOL vmlinux 0xf0619801	timekeeping_clocktai
++EXPORT_SYMBOL vmlinux 0xf064c2a4	tcf_unregister_action
++EXPORT_SYMBOL vmlinux 0xf065f629	ioread16be
++EXPORT_SYMBOL vmlinux 0xf0814fed	ipv6_chk_addr
++EXPORT_SYMBOL vmlinux 0xf087137d	__dynamic_pr_debug
++EXPORT_SYMBOL vmlinux 0xf08a2cf3	uart_unregister_driver
++EXPORT_SYMBOL vmlinux 0xf08f636d	inode_dio_done
++EXPORT_SYMBOL vmlinux 0xf09de776	get_random_int
++EXPORT_SYMBOL vmlinux 0xf0af0296	kiocb_set_cancel_fn
++EXPORT_SYMBOL vmlinux 0xf0b68ac8	__blockdev_direct_IO
++EXPORT_SYMBOL vmlinux 0xf0ccc1e8	bitmap_close_sync
++EXPORT_SYMBOL vmlinux 0xf0ce7d50	proc_dointvec_jiffies
++EXPORT_SYMBOL vmlinux 0xf0d68ed6	clk_register_clkdevs
++EXPORT_SYMBOL vmlinux 0xf0e5f5f2	unlock_rename
++EXPORT_SYMBOL vmlinux 0xf0ef15b4	list_sort
++EXPORT_SYMBOL vmlinux 0xf0f1246c	kvasprintf
++EXPORT_SYMBOL vmlinux 0xf0fbd8ac	journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xf0fdf6cb	__stack_chk_fail
++EXPORT_SYMBOL vmlinux 0xf100416a	remove_conflicting_framebuffers
++EXPORT_SYMBOL vmlinux 0xf10c9b1b	pm860x_page_reg_write
++EXPORT_SYMBOL vmlinux 0xf10de535	ioread8
++EXPORT_SYMBOL vmlinux 0xf11543ff	find_first_zero_bit
++EXPORT_SYMBOL vmlinux 0xf127a736	sg_alloc_table_from_pages
++EXPORT_SYMBOL vmlinux 0xf12d331c	lg_local_lock
++EXPORT_SYMBOL vmlinux 0xf13feb57	radix_tree_next_chunk
++EXPORT_SYMBOL vmlinux 0xf147dcb2	hdmi_spd_infoframe_init
++EXPORT_SYMBOL vmlinux 0xf1572525	xfrm_dst_ifdown
++EXPORT_SYMBOL vmlinux 0xf15cf6ca	inet_bind
++EXPORT_SYMBOL vmlinux 0xf18242e1	atomic64_set_cx8
++EXPORT_SYMBOL vmlinux 0xf195c682	fb_invert_cmaps
++EXPORT_SYMBOL vmlinux 0xf1984066	pagevec_lookup_tag
++EXPORT_SYMBOL vmlinux 0xf1a64be6	mb_cache_entry_alloc
++EXPORT_SYMBOL vmlinux 0xf1bda690	override_creds
++EXPORT_SYMBOL vmlinux 0xf1cd141c	skb_copy_and_csum_bits
++EXPORT_SYMBOL vmlinux 0xf1cf855d	log_wait_commit
++EXPORT_SYMBOL vmlinux 0xf1db1704	nla_memcpy
++EXPORT_SYMBOL vmlinux 0xf1deabf2	div64_u64
++EXPORT_SYMBOL vmlinux 0xf1e72511	__xfrm_state_delete
++EXPORT_SYMBOL vmlinux 0xf1e98c74	avenrun
++EXPORT_SYMBOL vmlinux 0xf1faac3a	_raw_spin_lock_irq
++EXPORT_SYMBOL vmlinux 0xf202c5cb	radix_tree_insert
++EXPORT_SYMBOL vmlinux 0xf2033374	blk_post_runtime_suspend
++EXPORT_SYMBOL vmlinux 0xf20d5219	dm_unregister_target
++EXPORT_SYMBOL vmlinux 0xf20dabd8	free_irq
++EXPORT_SYMBOL vmlinux 0xf2357254	acpi_evaluate_integer
++EXPORT_SYMBOL vmlinux 0xf23ef922	dst_discard
++EXPORT_SYMBOL vmlinux 0xf23fcb99	__kfifo_in
++EXPORT_SYMBOL vmlinux 0xf2459098	netif_set_real_num_tx_queues
++EXPORT_SYMBOL vmlinux 0xf249421c	journal_create
++EXPORT_SYMBOL vmlinux 0xf250aaa0	jbd2_journal_dirty_metadata
++EXPORT_SYMBOL vmlinux 0xf2570bf4	input_set_keycode
++EXPORT_SYMBOL vmlinux 0xf2678337	d_move
++EXPORT_SYMBOL vmlinux 0xf26eb6cc	pci_assign_resource
++EXPORT_SYMBOL vmlinux 0xf28ed6e2	machine_to_phys_nr
++EXPORT_SYMBOL vmlinux 0xf2997713	tty_termios_hw_change
++EXPORT_SYMBOL vmlinux 0xf2ababeb	mmc_can_reset
++EXPORT_SYMBOL vmlinux 0xf2b1ac8e	__getnstimeofday
++EXPORT_SYMBOL vmlinux 0xf2c3a674	kill_pid
++EXPORT_SYMBOL vmlinux 0xf2cbfea1	misc_register
++EXPORT_SYMBOL vmlinux 0xf2d10c12	scsi_release_buffers
++EXPORT_SYMBOL vmlinux 0xf2fa5dc2	lro_flush_all
++EXPORT_SYMBOL vmlinux 0xf306043f	mmc_hw_reset
++EXPORT_SYMBOL vmlinux 0xf312cb9d	ucs2_strsize
++EXPORT_SYMBOL vmlinux 0xf313da4e	sha_transform
++EXPORT_SYMBOL vmlinux 0xf31a1e30	kernel_getsockopt
++EXPORT_SYMBOL vmlinux 0xf31dbda2	inet_ioctl
++EXPORT_SYMBOL vmlinux 0xf32055e7	dev_base_lock
++EXPORT_SYMBOL vmlinux 0xf323f5bc	proc_remove
++EXPORT_SYMBOL vmlinux 0xf326e882	vm_insert_mixed
++EXPORT_SYMBOL vmlinux 0xf3341268	__clear_user
++EXPORT_SYMBOL vmlinux 0xf33c4933	filemap_fdatawrite_range
++EXPORT_SYMBOL vmlinux 0xf346231f	seq_list_start_head
++EXPORT_SYMBOL vmlinux 0xf347b8a5	register_qdisc
++EXPORT_SYMBOL vmlinux 0xf3509733	dquot_destroy
++EXPORT_SYMBOL vmlinux 0xf353a698	register_module_notifier
++EXPORT_SYMBOL vmlinux 0xf37260ab	_raw_read_unlock_bh
++EXPORT_SYMBOL vmlinux 0xf389fe60	__hw_addr_init
++EXPORT_SYMBOL vmlinux 0xf38fd8a4	bio_integrity_trim
++EXPORT_SYMBOL vmlinux 0xf3916987	global_cursor_default
++EXPORT_SYMBOL vmlinux 0xf396cd21	tcp_parse_md5sig_option
++EXPORT_SYMBOL vmlinux 0xf3986b06	acpi_os_map_generic_address
++EXPORT_SYMBOL vmlinux 0xf3b17cdc	set_page_dirty
++EXPORT_SYMBOL vmlinux 0xf3bf0bce	__bitmap_complement
++EXPORT_SYMBOL vmlinux 0xf3efa15c	eth_type_trans
++EXPORT_SYMBOL vmlinux 0xf4073847	dma_mark_declared_memory_occupied
++EXPORT_SYMBOL vmlinux 0xf418c7ba	pnp_possible_config
++EXPORT_SYMBOL vmlinux 0xf43c4c7c	devm_ioremap_resource
++EXPORT_SYMBOL vmlinux 0xf441ac43	ioread8_rep
++EXPORT_SYMBOL vmlinux 0xf445b9f9	wireless_spy_update
++EXPORT_SYMBOL vmlinux 0xf4590ad9	agp_enable
++EXPORT_SYMBOL vmlinux 0xf45a4e52	posix_acl_chmod
++EXPORT_SYMBOL vmlinux 0xf46c4efb	__secpath_destroy
++EXPORT_SYMBOL vmlinux 0xf4819fea	bdevname
++EXPORT_SYMBOL vmlinux 0xf4877e4e	get_tz_trend
++EXPORT_SYMBOL vmlinux 0xf492b401	blk_queue_softirq_done
++EXPORT_SYMBOL vmlinux 0xf49a9c59	pci_get_device
++EXPORT_SYMBOL vmlinux 0xf49efb57	bio_integrity_split
++EXPORT_SYMBOL vmlinux 0xf4a5c213	avail_to_resrv_perfctr_nmi_bit
++EXPORT_SYMBOL vmlinux 0xf4b754fd	acpi_resources_are_enforced
++EXPORT_SYMBOL vmlinux 0xf4bdbeb9	__frontswap_invalidate_area
++EXPORT_SYMBOL vmlinux 0xf4c031ee	journal_get_undo_access
++EXPORT_SYMBOL vmlinux 0xf4f14de6	rtnl_trylock
++EXPORT_SYMBOL vmlinux 0xf4f19e51	downgrade_write
++EXPORT_SYMBOL vmlinux 0xf4fb387f	scsi_execute
++EXPORT_SYMBOL vmlinux 0xf502d273	acpi_get_current_resources
++EXPORT_SYMBOL vmlinux 0xf506382c	qdisc_list_del
++EXPORT_SYMBOL vmlinux 0xf51ae235	touch_nmi_watchdog
++EXPORT_SYMBOL vmlinux 0xf52038ad	netdev_class_create_file
++EXPORT_SYMBOL vmlinux 0xf52cea27	icmp_send
++EXPORT_SYMBOL vmlinux 0xf536d22e	acpi_set_gpe_wake_mask
++EXPORT_SYMBOL vmlinux 0xf53d4c26	qdisc_class_hash_destroy
++EXPORT_SYMBOL vmlinux 0xf557ca5c	kobject_del
++EXPORT_SYMBOL vmlinux 0xf573491c	phy_ethtool_get_eee
++EXPORT_SYMBOL vmlinux 0xf5b10e67	acpi_install_global_event_handler
++EXPORT_SYMBOL vmlinux 0xf5c05914	generic_segment_checks
++EXPORT_SYMBOL vmlinux 0xf5dd6622	jbd2_journal_set_features
++EXPORT_SYMBOL vmlinux 0xf5e36857	jbd2_journal_abort
++EXPORT_SYMBOL vmlinux 0xf5eb86ea	blk_verify_command
++EXPORT_SYMBOL vmlinux 0xf5f70696	check_disk_size_change
++EXPORT_SYMBOL vmlinux 0xf60120c2	sock_i_uid
++EXPORT_SYMBOL vmlinux 0xf607d5f0	sock_no_getname
++EXPORT_SYMBOL vmlinux 0xf618728c	dma_common_mmap
++EXPORT_SYMBOL vmlinux 0xf6293c92	pci_try_set_mwi
++EXPORT_SYMBOL vmlinux 0xf63545a0	fget_light
++EXPORT_SYMBOL vmlinux 0xf6388c56	sysctl_ip_default_ttl
++EXPORT_SYMBOL vmlinux 0xf63cf832	input_unregister_device
++EXPORT_SYMBOL vmlinux 0xf661aade	tty_register_ldisc
++EXPORT_SYMBOL vmlinux 0xf661f6a2	set_binfmt
++EXPORT_SYMBOL vmlinux 0xf674678e	journal_start
++EXPORT_SYMBOL vmlinux 0xf68285c0	register_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xf68687be	__sg_page_iter_start
++EXPORT_SYMBOL vmlinux 0xf68ec3ac	ppp_register_channel
++EXPORT_SYMBOL vmlinux 0xf69a3c93	dquot_quota_sync
++EXPORT_SYMBOL vmlinux 0xf6a86000	alloc_fddidev
++EXPORT_SYMBOL vmlinux 0xf6bb4729	color_table
++EXPORT_SYMBOL vmlinux 0xf6c85c91	elv_rb_former_request
++EXPORT_SYMBOL vmlinux 0xf6d4ca73	dev_disable_lro
++EXPORT_SYMBOL vmlinux 0xf6ebc03b	net_ratelimit
++EXPORT_SYMBOL vmlinux 0xf726d02f	atomic64_add_unless_cx8
++EXPORT_SYMBOL vmlinux 0xf72794b2	jbd2_journal_extend
++EXPORT_SYMBOL vmlinux 0xf739ba6c	alloc_mdio_bitbang
++EXPORT_SYMBOL vmlinux 0xf73cd809	inet6_release
++EXPORT_SYMBOL vmlinux 0xf745cb16	atomic64_sub_return_cx8
++EXPORT_SYMBOL vmlinux 0xf7584a9c	find_font
++EXPORT_SYMBOL vmlinux 0xf75bc434	files_lglock
++EXPORT_SYMBOL vmlinux 0xf76e4efb	sock_sendmsg
++EXPORT_SYMBOL vmlinux 0xf79fbe11	dm_register_target
++EXPORT_SYMBOL vmlinux 0xf7a96400	inode_owner_or_capable
++EXPORT_SYMBOL vmlinux 0xf7ba98a0	dev_alloc_name
++EXPORT_SYMBOL vmlinux 0xf7c64290	xfrm_input_resume
++EXPORT_SYMBOL vmlinux 0xf7e37635	__wait_on_bit
++EXPORT_SYMBOL vmlinux 0xf7f1706f	simple_pin_fs
++EXPORT_SYMBOL vmlinux 0xf7f1bbbd	request_key
++EXPORT_SYMBOL vmlinux 0xf7fca6f2	free_task
++EXPORT_SYMBOL vmlinux 0xf7fdebe0	phy_device_create
++EXPORT_SYMBOL vmlinux 0xf803fe39	bitmap_set
++EXPORT_SYMBOL vmlinux 0xf80c7eaa	bio_integrity_free
++EXPORT_SYMBOL vmlinux 0xf811e69d	scsi_eh_flush_done_q
++EXPORT_SYMBOL vmlinux 0xf819b87d	dma_async_memcpy_buf_to_pg
++EXPORT_SYMBOL vmlinux 0xf822cb6a	d_splice_alias
++EXPORT_SYMBOL vmlinux 0xf827cb83	free_reserved_area
++EXPORT_SYMBOL vmlinux 0xf82abc1d	isa_dma_bridge_buggy
++EXPORT_SYMBOL vmlinux 0xf82cd0cc	writeback_inodes_sb
++EXPORT_SYMBOL vmlinux 0xf82e3d47	acpi_initialize_objects
++EXPORT_SYMBOL vmlinux 0xf82ec573	rb_prev
++EXPORT_SYMBOL vmlinux 0xf8364d66	jbd2_journal_forget
++EXPORT_SYMBOL vmlinux 0xf84e3c7c	tty_wait_until_sent
++EXPORT_SYMBOL vmlinux 0xf87ceea7	tty_port_close_start
++EXPORT_SYMBOL vmlinux 0xf880155b	cookie_check_timestamp
++EXPORT_SYMBOL vmlinux 0xf88e0ee2	acpi_get_table_header
++EXPORT_SYMBOL vmlinux 0xf8a01146	dev_addr_add
++EXPORT_SYMBOL vmlinux 0xf8b0194b	mdiobus_register
++EXPORT_SYMBOL vmlinux 0xf8bc30bb	i8042_check_port_owner
++EXPORT_SYMBOL vmlinux 0xf8bf2870	sock_common_setsockopt
++EXPORT_SYMBOL vmlinux 0xf8d39c5c	agp_free_page_array
++EXPORT_SYMBOL vmlinux 0xf8f06361	netif_rx_ni
++EXPORT_SYMBOL vmlinux 0xf9348cbc	xz_dec_run
++EXPORT_SYMBOL vmlinux 0xf940a328	__next_cpu
++EXPORT_SYMBOL vmlinux 0xf9461e5e	gen_replace_estimator
++EXPORT_SYMBOL vmlinux 0xf953ce9e	writeback_inodes_sb_nr
++EXPORT_SYMBOL vmlinux 0xf96f7795	xfrm_unregister_type
++EXPORT_SYMBOL vmlinux 0xf97056c8	bio_integrity_add_page
++EXPORT_SYMBOL vmlinux 0xf97456ea	_raw_spin_unlock_irqrestore
++EXPORT_SYMBOL vmlinux 0xf97f0807	block_write_end
++EXPORT_SYMBOL vmlinux 0xf99225cc	d_lookup
++EXPORT_SYMBOL vmlinux 0xf9a482f9	msleep
++EXPORT_SYMBOL vmlinux 0xf9d608a6	generic_read_dir
++EXPORT_SYMBOL vmlinux 0xf9dd5243	abx500_get_register_page_interruptible
++EXPORT_SYMBOL vmlinux 0xf9e73082	scnprintf
++EXPORT_SYMBOL vmlinux 0xf9fd9f37	vm_map_ram
++EXPORT_SYMBOL vmlinux 0xf9fdff3a	__destroy_inode
++EXPORT_SYMBOL vmlinux 0xfa0d9b95	vm_mmap
++EXPORT_SYMBOL vmlinux 0xfa19f967	swiotlb_free_coherent
++EXPORT_SYMBOL vmlinux 0xfa30957c	mempool_free
++EXPORT_SYMBOL vmlinux 0xfa4cd761	__netdev_alloc_skb
++EXPORT_SYMBOL vmlinux 0xfa599bb2	netlink_register_notifier
++EXPORT_SYMBOL vmlinux 0xfa5d9530	mount_subtree
++EXPORT_SYMBOL vmlinux 0xfa7f3156	wl12xx_get_platform_data
++EXPORT_SYMBOL vmlinux 0xfa8e2628	input_unregister_handler
++EXPORT_SYMBOL vmlinux 0xfa9231c1	pci_bus_add_devices
++EXPORT_SYMBOL vmlinux 0xfaa2d331	jbd2_journal_check_used_features
++EXPORT_SYMBOL vmlinux 0xfac8865f	sysctl_wmem_max
++EXPORT_SYMBOL vmlinux 0xfae3c421	napi_gro_frags
++EXPORT_SYMBOL vmlinux 0xfae4a53c	__cleancache_init_shared_fs
++EXPORT_SYMBOL vmlinux 0xfae67b1f	cap_mmap_addr
++EXPORT_SYMBOL vmlinux 0xfaf98462	bitrev32
++EXPORT_SYMBOL vmlinux 0xfb0443fb	acpi_get_parent
++EXPORT_SYMBOL vmlinux 0xfb0e674c	input_unregister_handle
++EXPORT_SYMBOL vmlinux 0xfb20df3f	scsi_execute_req_flags
++EXPORT_SYMBOL vmlinux 0xfb2334a5	clocksource_change_rating
++EXPORT_SYMBOL vmlinux 0xfb40093e	try_module_get
++EXPORT_SYMBOL vmlinux 0xfb48d72d	inet_listen
++EXPORT_SYMBOL vmlinux 0xfb550f6a	account_page_writeback
++EXPORT_SYMBOL vmlinux 0xfb6af58d	recalc_sigpending
++EXPORT_SYMBOL vmlinux 0xfb80c7a0	acpi_walk_namespace
++EXPORT_SYMBOL vmlinux 0xfb906fd9	inet6_ioctl
++EXPORT_SYMBOL vmlinux 0xfb94103e	__clzdi2
++EXPORT_SYMBOL vmlinux 0xfba0cc69	cdrom_get_last_written
++EXPORT_SYMBOL vmlinux 0xfbaaf01e	console_lock
++EXPORT_SYMBOL vmlinux 0xfbc82a0d	blk_rq_map_user
++EXPORT_SYMBOL vmlinux 0xfbd7416f	blk_init_allocated_queue
++EXPORT_SYMBOL vmlinux 0xfc02b7ad	sysctl_tcp_wmem
++EXPORT_SYMBOL vmlinux 0xfc39e32f	ioport_unmap
++EXPORT_SYMBOL vmlinux 0xfc562165	acpi_run_osc
++EXPORT_SYMBOL vmlinux 0xfc5fd44c	pci_disable_link_state_locked
++EXPORT_SYMBOL vmlinux 0xfc65459a	kstrtoull_from_user
++EXPORT_SYMBOL vmlinux 0xfc72d5da	__dquot_free_space
++EXPORT_SYMBOL vmlinux 0xfc73362a	skb_kill_datagram
++EXPORT_SYMBOL vmlinux 0xfc872fd1	get_ibs_caps
++EXPORT_SYMBOL vmlinux 0xfcaa04a0	out_of_line_wait_on_bit_lock
++EXPORT_SYMBOL vmlinux 0xfcac0d40	acpi_install_interface_handler
++EXPORT_SYMBOL vmlinux 0xfcc2a43c	utf32_to_utf8
++EXPORT_SYMBOL vmlinux 0xfcec0987	enable_irq
++EXPORT_SYMBOL vmlinux 0xfcfa03ff	fb_videomode_to_modelist
++EXPORT_SYMBOL vmlinux 0xfd138dd0	scsi_add_device
++EXPORT_SYMBOL vmlinux 0xfd142da1	kset_unregister
++EXPORT_SYMBOL vmlinux 0xfd1afa6e	md_integrity_add_rdev
++EXPORT_SYMBOL vmlinux 0xfd4a2550	pcim_iounmap_regions
++EXPORT_SYMBOL vmlinux 0xfd59e2ec	mmc_erase_group_aligned
++EXPORT_SYMBOL vmlinux 0xfd6293c2	boot_tvec_bases
++EXPORT_SYMBOL vmlinux 0xfd62990d	__pci_enable_wake
++EXPORT_SYMBOL vmlinux 0xfd694f4b	netlink_broadcast_filtered
++EXPORT_SYMBOL vmlinux 0xfd7d7713	acpi_exception
++EXPORT_SYMBOL vmlinux 0xfd99623a	ip_frag_ecn_table
++EXPORT_SYMBOL vmlinux 0xfd99e722	pci_request_selected_regions_exclusive
++EXPORT_SYMBOL vmlinux 0xfda0dbe8	ftrace_print_hex_seq
++EXPORT_SYMBOL vmlinux 0xfda2a90f	bio_integrity_get_tag
++EXPORT_SYMBOL vmlinux 0xfda87bac	blk_post_runtime_resume
++EXPORT_SYMBOL vmlinux 0xfdb9b629	ioread32be
++EXPORT_SYMBOL vmlinux 0xfdba7971	backlight_force_update
++EXPORT_SYMBOL vmlinux 0xfdbe0288	pci_add_resource_offset
++EXPORT_SYMBOL vmlinux 0xfdbeb0f1	i2c_smbus_read_byte_data
++EXPORT_SYMBOL vmlinux 0xfdc94eab	sock_no_sendmsg
++EXPORT_SYMBOL vmlinux 0xfdcf522c	bdi_destroy
++EXPORT_SYMBOL vmlinux 0xfdd3fb71	buffer_migrate_page
++EXPORT_SYMBOL vmlinux 0xfdee7d42	_raw_read_lock_bh
++EXPORT_SYMBOL vmlinux 0xfdfc0b3b	fiemap_fill_next_extent
++EXPORT_SYMBOL vmlinux 0xfe029963	unregister_inetaddr_notifier
++EXPORT_SYMBOL vmlinux 0xfe06e0f1	dqput
++EXPORT_SYMBOL vmlinux 0xfe27daff	tcp_initialize_rcv_mss
++EXPORT_SYMBOL vmlinux 0xfe5023cc	__dev_remove_pack
++EXPORT_SYMBOL vmlinux 0xfe5d4bb2	sys_tz
++EXPORT_SYMBOL vmlinux 0xfe789a53	blk_register_region
++EXPORT_SYMBOL vmlinux 0xfe7c12ab	twl6040_get_sysclk
++EXPORT_SYMBOL vmlinux 0xfe7c4287	nr_cpu_ids
++EXPORT_SYMBOL vmlinux 0xfe89a9a2	pci_select_bars
++EXPORT_SYMBOL vmlinux 0xfe8d5a49	dev_addr_del
++EXPORT_SYMBOL vmlinux 0xfe960b25	netif_receive_skb
++EXPORT_SYMBOL vmlinux 0xfe9e271c	clear_bdi_congested
++EXPORT_SYMBOL vmlinux 0xfeaec66f	mntget
++EXPORT_SYMBOL vmlinux 0xfeb47dca	eth_rebuild_header
++EXPORT_SYMBOL vmlinux 0xfedcdb60	seq_hlist_next_percpu
++EXPORT_SYMBOL vmlinux 0xfeea882e	dev_activate
++EXPORT_SYMBOL vmlinux 0xfef96e23	__scsi_print_command
++EXPORT_SYMBOL vmlinux 0xff1e9dd8	seq_list_start
++EXPORT_SYMBOL vmlinux 0xff2bbad1	elevator_init
++EXPORT_SYMBOL vmlinux 0xff325313	led_blink_set
++EXPORT_SYMBOL vmlinux 0xff381de3	kernel_listen
++EXPORT_SYMBOL vmlinux 0xff3ceec5	security_path_symlink
++EXPORT_SYMBOL vmlinux 0xff480992	dump_fpu
++EXPORT_SYMBOL vmlinux 0xff4ed081	elv_rb_add
++EXPORT_SYMBOL vmlinux 0xff6878cf	fb_default_cmap
++EXPORT_SYMBOL vmlinux 0xff7559e4	ioport_resource
++EXPORT_SYMBOL vmlinux 0xff7de7d8	jbd2_journal_lock_updates
++EXPORT_SYMBOL vmlinux 0xff989997	fb_class
++EXPORT_SYMBOL vmlinux 0xff9ca065	fb_edid_to_monspecs
++EXPORT_SYMBOL vmlinux 0xffc163f2	fd_install
++EXPORT_SYMBOL vmlinux 0xffc91cb0	tcp_v4_destroy_sock
++EXPORT_SYMBOL vmlinux 0xffd5a395	default_wake_function
++EXPORT_SYMBOL vmlinux 0xffdcf1cb	set_nlink
++EXPORT_SYMBOL vmlinux 0xffe5095d	groups_free
++EXPORT_SYMBOL vmlinux 0xfff5b473	__bread
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x115c3420	ablk_decrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x374e810f	ablk_init_common
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0x43a87167	ablk_init
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xb05e0834	ablk_encrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xbfa70a54	__ablk_encrypt
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xdea5fb6f	ablk_set_key
++EXPORT_SYMBOL_GPL arch/x86/crypto/ablk_helper 0xe24a5d62	ablk_exit
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0x7060bf0a	crypto_aes_encrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/aes-i586 0xe409b491	crypto_aes_decrypt_x86
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x2ea7435d	glue_ecb_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x7e4c4e42	glue_cbc_encrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x8f02ac4d	glue_xts_crypt_128bit_one
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0x9b1750c3	glue_xts_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xb691869a	glue_ctr_crypt_final_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xe4a4f8fd	glue_ctr_crypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/glue_helper 0xe623940c	glue_cbc_decrypt_128bit
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x28afd262	twofish_enc_blk
++EXPORT_SYMBOL_GPL arch/x86/crypto/twofish-i586 0x6f068d90	twofish_dec_blk
++EXPORT_SYMBOL_GPL arch/x86/kernel/microcode 0xdf66ca81	ucode_cpu_info
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00aaf935	kvm_disable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x00ab0667	kvm_read_guest_page_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x02d7b4e2	kvm_inject_realmode_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x07cd92da	kvm_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0950eecd	kvm_set_cr4
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0a798649	x86_emulate_instruction
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x0f883b76	kvm_mmu_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x13005c9e	kvm_lmsw
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x16bcd162	kvm_apic_write_nodecode
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x18e257ab	__tracepoint_kvm_nested_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1908a849	kvm_x86_ops
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x199d1f1e	kvm_after_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1a4342a5	__tracepoint_kvm_invlpga
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1b176dda	gfn_to_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1b363800	handle_mmio_page_fault_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1cfe78d1	kvm_release_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1d19337d	kvm_mmu_get_spte_hierarchy
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x1f2cdfae	kvm_set_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x20de5193	kvm_disable_largepages
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2433d6fd	__tracepoint_kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x24470b77	kvm_set_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x25f5e603	kvm_get_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2624c1dc	kvm_mmu_invlpg
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x27046576	kvm_exit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2956c01f	kvm_set_dr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2c3de22b	kvm_find_cpuid_entry
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2ddee214	kvm_write_tsc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x2f636c31	kvm_spurious_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x317f9e6b	kvm_enable_efer_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x34f59028	kvm_requeue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x397fc3c8	kvm_read_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3a5d15ee	kvm_valid_efer
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3c47acc6	kvm_before_handle_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3de08404	kvm_set_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3ee59a92	__tracepoint_kvm_skinit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x3fcecf26	kvm_get_rflags
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x41b5d634	kvm_queue_exception
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x44c56224	kvm_vcpu_uninit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x45e58487	kvm_gfn_to_hva_cache_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x46dd7dc3	__kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x485cd7f6	kvm_rebooting
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4947a7f2	kvm_mmu_unprotect_page_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x49a6d2ff	kvm_mmu_unprotect_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4ab5282d	kvm_require_cpl
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4c0c18f4	kvm_get_msr_common
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x4efb2e89	kvm_set_cr8
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x52ce256e	kvm_queue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x54725c4c	kvm_vcpu_kick
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5ba5f207	kvm_init_shadow_mmu
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5bdac471	kvm_write_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x5edb1534	kvm_task_switch
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x600418d4	kvm_read_guest_virt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x606b249a	kvm_requeue_exception_e
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x60e9e748	kvm_lapic_set_eoi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x61bbdcf1	load_pdptrs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x647b869e	kvm_rdpmc
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x64b93f18	gfn_to_pfn_prot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x669da1fd	kvm_set_pfn_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x68387a9f	kvm_read_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6b7b37e8	kvm_clear_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x6e533b5f	kvm_inject_pending_timer_irqs
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x714d5bab	kvm_read_guest
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x73825228	fx_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x743554bd	kvm_emulate_hypercall
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7a8cf62a	kvm_write_guest_virt_system
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aa64803	kvm_release_pfn_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7aba9514	kvm_irq_has_notifier
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x7eedf818	kvm_get_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x82e6acce	kvm_set_cr0
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x831327da	kvm_max_guest_tsc_khz
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x84ceb28c	__tracepoint_kvm_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8878367b	kvm_fast_pio_out
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8b1f2cdb	kvm_release_page_clean
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8bb03e6e	__tracepoint_kvm_write_tsc_offset
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8ce4f3ab	kvm_enable_tdp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8da01274	kvm_get_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x8e1cd06f	kvm_set_pfn_accessed
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x90150d69	kvm_emulate_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x930c5cdf	kvm_set_cr3
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9534105d	kvm_mmu_unload
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9a216313	kvm_define_shared_msr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9d334f47	kvm_vcpu_init
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9dffb280	kvm_emulate_wbinvd
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0x9efdaa49	kvm_vcpu_yield_to
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa0ec3a0a	gfn_to_hva_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa1b47585	gfn_to_pfn_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xa39750ef	kvm_write_guest_cached
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaa373a32	kvm_emulate_halt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaac7c868	__tracepoint_kvm_nested_intr_vmexit
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xaaefbd7e	kvm_is_linear_rip
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xab042358	kvm_get_cs_db_l_bits
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xacf7f97c	gfn_to_pfn_memslot_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb1b79f6a	gfn_to_pfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb284eed4	__tracepoint_kvm_nested_vmexit_inject
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb2a65cca	__tracepoint_kvm_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb4583f00	kvm_cpu_has_interrupt
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xb975d89e	kvm_set_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xba9ed435	kvm_mmu_set_mmio_spte_mask
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbb3e13c1	kvm_apic_update_irr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbc2b538e	__tracepoint_kvm_nested_vmrun
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbf05ab76	__tracepoint_kvm_inj_virq
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xbf44aeb1	kvm_get_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc0d0a62f	kvm_set_apic_base
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc5483173	kvm_vcpu_cache
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xc69e8de1	kvm_put_kvm
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcaf2b741	gfn_to_page_many_atomic
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcb67ce10	__tracepoint_kvm_nested_intercepts
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcd42d353	kvm_resched
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcd917f4a	kvm_cpuid
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xcf612510	kvm_complete_insn_gp
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0459e67	kvm_has_tsc_control
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0b2727a	kvm_mmu_set_mask_ptes
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd0caa28f	kvm_mmu_reset_context
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd137755e	kvm_vcpu_on_spin
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd4558b90	gfn_to_hva
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd49dc44a	kvm_apic_set_eoi_accelerated
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xd93f9e4b	kvm_release_page_dirty
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdb144a14	kvm_inject_nmi
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xdfd44658	kvm_set_memory_region
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe4f17f54	kvm_mmu_load
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe4fa6cee	gfn_to_memslot
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xe9790e86	__tracepoint_kvm_cr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xecc046a9	gfn_to_pfn_async
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xefaed39b	kvm_inject_page_fault
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xefd880e9	kvm_is_visible_gfn
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf0509687	kvm_set_xcr
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf0904841	kvm_clear_guest_page
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf4186119	kvm_get_guest_memory_type
++EXPORT_SYMBOL_GPL arch/x86/kvm/kvm 0xf6402f5c	kvm_get_cr8
++EXPORT_SYMBOL_GPL crypto/af_alg 0x71db132c	af_alg_accept
++EXPORT_SYMBOL_GPL crypto/af_alg 0x72ecd946	af_alg_complete
++EXPORT_SYMBOL_GPL crypto/af_alg 0x7e7cde9c	af_alg_wait_for_completion
++EXPORT_SYMBOL_GPL crypto/af_alg 0x81b114ff	af_alg_unregister_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0x93957c0c	af_alg_cmsg_send
++EXPORT_SYMBOL_GPL crypto/af_alg 0x9cb25ecf	af_alg_register_type
++EXPORT_SYMBOL_GPL crypto/af_alg 0xa10ee33d	af_alg_make_sg
++EXPORT_SYMBOL_GPL crypto/af_alg 0xd5685a17	af_alg_release
++EXPORT_SYMBOL_GPL crypto/af_alg 0xf3880e49	af_alg_free_sg
++EXPORT_SYMBOL_GPL crypto/async_tx/async_memcpy 0x4be12b45	async_memcpy
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x89ef4b19	async_gen_syndrome
++EXPORT_SYMBOL_GPL crypto/async_tx/async_pq 0x913b6584	async_syndrome_val
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x701d9dd3	async_raid6_2data_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_raid6_recov 0x7c28baf1	async_raid6_datap_recov
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x104d98ef	__async_tx_find_channel
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x5126af05	async_tx_quiesce
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x60da77c1	async_tx_submit
++EXPORT_SYMBOL_GPL crypto/async_tx/async_tx 0x86a7bfb8	async_trigger_callback
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0x381792fa	async_xor
++EXPORT_SYMBOL_GPL crypto/async_tx/async_xor 0xfa61c907	async_xor_val
++EXPORT_SYMBOL_GPL crypto/blowfish_common 0xeebc3a13	blowfish_setkey
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x27278ca9	__cast5_encrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0x4a2a3ca6	__cast5_decrypt
++EXPORT_SYMBOL_GPL crypto/cast5_generic 0xebe4824a	cast5_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1291971c	__cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x1e2c961f	__cast6_decrypt
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x4d22ee1f	cast6_setkey
++EXPORT_SYMBOL_GPL crypto/cast6_generic 0x8f04034a	__cast6_encrypt
++EXPORT_SYMBOL_GPL crypto/cast_common 0x08aa6fb7	cast_s1
++EXPORT_SYMBOL_GPL crypto/cast_common 0x0c5fbf8a	cast_s3
++EXPORT_SYMBOL_GPL crypto/cast_common 0xe39dd4b4	cast_s2
++EXPORT_SYMBOL_GPL crypto/cast_common 0xee83a4f3	cast_s4
++EXPORT_SYMBOL_GPL crypto/cryptd 0x18f4df94	cryptd_alloc_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x19c952aa	cryptd_alloc_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0x4ae00ac9	cryptd_shash_desc
++EXPORT_SYMBOL_GPL crypto/cryptd 0x5685c6a6	cryptd_alloc_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0x65a35196	cryptd_free_ahash
++EXPORT_SYMBOL_GPL crypto/cryptd 0x88c7c00f	cryptd_free_aead
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc13d314e	cryptd_free_ablkcipher
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc79fec4e	cryptd_ablkcipher_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xc9d763b2	cryptd_aead_child
++EXPORT_SYMBOL_GPL crypto/cryptd 0xd7b40178	cryptd_ahash_child
++EXPORT_SYMBOL_GPL crypto/des_generic 0xcfd9a2c0	des_ekey
++EXPORT_SYMBOL_GPL crypto/lrw 0x3864eb66	lrw_free_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xcd074900	lrw_init_table
++EXPORT_SYMBOL_GPL crypto/lrw 0xed6ebaea	lrw_crypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x37997173	serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x5ddb33e9	__serpent_encrypt
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x77b39cb4	__serpent_setkey
++EXPORT_SYMBOL_GPL crypto/serpent_generic 0x8a1a99ad	__serpent_decrypt
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x4b74c766	twofish_setkey
++EXPORT_SYMBOL_GPL crypto/twofish_common 0x6c3229bb	__twofish_setkey
++EXPORT_SYMBOL_GPL crypto/xts 0x97ad5d47	xts_crypt
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x1c8984c7	acpi_smbus_unregister_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0x87bd07bd	acpi_smbus_register_callback
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xb9a141b0	acpi_smbus_read
++EXPORT_SYMBOL_GPL drivers/acpi/sbshc 0xe1372311	acpi_smbus_write
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1baf497d	ahci_print_info
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x1ccf5613	ahci_reset_em
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x33eea4b7	ahci_stop_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x39cc743e	ahci_save_initial_config
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5ab31121	ahci_sdev_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x5eacba1f	ahci_interrupt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x66d0ce60	ahci_set_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x694f923e	ahci_thread_fn
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x6e05c4e7	ahci_hw_interrupt
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x7e51cdd0	ahci_port_resume
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x84ceb7ad	ahci_start_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x862fac95	ahci_init_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x8bd698a4	ahci_check_ready
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0x92c3e7a0	ahci_reset_controller
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xcb97fe36	ahci_kick_engine
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdd5fa3e4	ahci_pmp_retry_srst_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xdf16cf8d	ahci_dev_classify
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe30c8bb7	ahci_shost_attrs
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe6b1e3b2	ahci_ops
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xe7358a49	ahci_do_softreset
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xea50dad3	ahci_ignore_sss
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xf6464980	ahci_em_messages
++EXPORT_SYMBOL_GPL drivers/ata/libahci 0xfe13d83c	ahci_fill_cmd_slot
++EXPORT_SYMBOL_GPL drivers/ata/pata_platform 0x87c27d22	__pata_platform_probe
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x02ff9464	cfag12864b_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x0ecb2e5d	cfag12864b_disable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x305dc3c6	cfag12864b_isenabled
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x3389f926	cfag12864b_enable
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0x9522a342	cfag12864b_getrate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/cfag12864b 0xc48e9d95	cfag12864b_buffer
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x14102f23	ks0108_displaystate
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x48a70518	ks0108_writedata
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x4f506333	ks0108_startline
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0x6edae968	ks0108_isinited
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xbf4774db	ks0108_writecontrol
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xedde6df2	ks0108_page
++EXPORT_SYMBOL_GPL drivers/auxdisplay/ks0108 0xfee8ef7b	ks0108_address
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x062b7afc	bcma_pmu_get_bus_clock
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x2851d985	bcma_chipco_chipctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x32b1d215	bcma_core_pll_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x343d7bb2	bcma_core_is_enabled
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x392b3a01	bcma_core_pci_extend_L1timer
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6a381568	bcma_chipco_gpio_outen
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x6d0e339a	bcma_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8267ac7d	bcma_core_enable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x8c30dc55	bcma_chipco_gpio_control
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x99e468df	bcma_core_disable
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9bc4c9e8	bcma_chipco_pll_read
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0x9e09255d	__bcma_driver_register
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xa58ce204	bcma_chipco_regctl_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xb7687753	bcma_core_set_clockmode
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xd7a9ca7b	bcma_chipco_pll_write
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe089023d	bcma_chipco_pll_maskset
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe09ca830	bcma_core_pci_irq_ctl
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xe92cc455	bcma_find_core
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf1a4b295	bcma_chipco_gpio_out
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xf6b5216d	bcma_driver_unregister
++EXPORT_SYMBOL_GPL drivers/bcma/bcma 0xfcb4d032	bcma_chipco_get_alp_clock
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x00d6919d	btmrvl_register_hdev
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2013c4d5	btmrvl_check_evtpkt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x2ecd637d	btmrvl_remove_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x384c131c	btmrvl_send_module_cfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x4929558d	btmrvl_enable_hs
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0x84e44381	btmrvl_send_hscfg_cmd
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xbb1c1313	btmrvl_enable_ps
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xcde72738	btmrvl_add_card
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdda51350	btmrvl_interrupt
++EXPORT_SYMBOL_GPL drivers/bluetooth/btmrvl 0xdf166b17	btmrvl_process_event
++EXPORT_SYMBOL_GPL drivers/char/scx200_gpio 0x5ff4e234	scx200_gpio_ops
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x01a33ab9	dca_unregister_notify
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x2b304542	dca_remove_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x315b1658	free_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x31a2c8df	dca_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x32d42c65	register_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x42b6fc42	dca_add_requester
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x5258c20f	unregister_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x64e1d647	alloc_dca_provider
++EXPORT_SYMBOL_GPL drivers/dca/dca 0x7d6ae53f	dca3_get_tag
++EXPORT_SYMBOL_GPL drivers/dca/dca 0xac34ecec	dca_register_notify
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x11e07fe8	dw_dma_shutdown
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x3b58c305	dw_dma_suspend
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x6053ca47	dw_dma_resume
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0x9f013e82	dw_dma_remove
++EXPORT_SYMBOL_GPL drivers/dma/dw/dw_dmac_core 0xe6fed91d	dw_dma_probe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x04be61b9	edac_pci_handle_npe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c32ff8a	edac_pci_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x0c3c46d9	edac_pci_handle_pe
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x124789e7	edac_device_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x23490ef0	edac_mc_alloc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x285f3046	edac_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x3e7bee70	edac_pci_release_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x4f4f59a9	edac_device_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5167ea67	edac_mc_add_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x5dab63fb	edac_raw_mc_handle_error
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x69259f22	edac_mem_types
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x6e3ff83a	edac_device_alloc_index
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x761cdfb1	edac_mc_free
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x830a0fde	edac_pci_create_generic_ctl
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x885d91d3	edac_pci_free_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x8b239186	edac_device_handle_ue
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9728e18b	edac_device_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0x9f88f21f	edac_pci_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xabd9bec2	edac_pci_reset_delay_period
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xb432afaa	edac_device_add_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc0dcb59e	edac_layer_name
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xc9ef113a	edac_pci_alloc_ctl_info
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd04548cc	edac_device_handle_ce
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xd7cccb82	edac_mc_find_csrow_by_page
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xe7b4c11e	edac_pci_del_device
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf1f224bc	edac_mc_del_mc
++EXPORT_SYMBOL_GPL drivers/edac/edac_core 0xf2341a4d	find_mci_by_dev
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x14878009	amd_report_gart_errors
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x1d34e996	pp_msgs
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x21626132	amd_register_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0x737912b3	amd_unregister_ecc_decoder
++EXPORT_SYMBOL_GPL drivers/edac/edac_mce_amd 0xb30b7e56	amd_decode_mce
++EXPORT_SYMBOL_GPL drivers/firewire/firewire-core 0xf4ade51f	fw_card_release
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x013fbdac	cs5535_gpio_set
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0x93f8fe67	cs5535_gpio_set_irq
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xc0bb404a	cs5535_gpio_setup_event
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xd3bd9300	cs5535_gpio_isset
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-cs5535 0xe07c0954	cs5535_gpio_clear
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x425fb1fe	bgpio_remove
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-generic 0x747295fd	bgpio_init
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x0212c0f8	__max730x_probe
++EXPORT_SYMBOL_GPL drivers/gpio/gpio-max730x 0x45be98a4	__max730x_remove
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x131cb8ce	drm_vm_open_locked
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0x63713b8d	drm_class_device_register
++EXPORT_SYMBOL_GPL drivers/gpu/drm/drm 0xb7a61a88	drm_class_device_unregister
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x05876c69	i915_gpu_busy
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x08a7896d	i915_gpu_raise
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x2b2c59ae	i915_release_power_well
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x402468e9	i915_gpu_lower
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x500858b9	i915_read_mch_val
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0x96108893	i915_request_power_well
++EXPORT_SYMBOL_GPL drivers/gpu/drm/i915/i915 0xe7237b0b	i915_gpu_turbo_disable
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x135e14f5	ttm_dma_page_alloc_debugfs
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x4227c7c5	ttm_dma_populate
++EXPORT_SYMBOL_GPL drivers/gpu/drm/ttm/ttm 0x86e43ea6	ttm_dma_unpopulate
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x02c7978c	hid_validate_values
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x05495392	hid_debug
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0a44ff3d	hidraw_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x0db19de6	hidinput_find_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x22e422f5	hid_destroy_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x2e5ebce4	hid_report_raw_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x30df166c	hid_add_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x32e97b4e	hid_open_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3357c54f	hid_dump_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x3be84f9a	hid_resolv_usage
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x41dd5e65	hid_parse_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x4906a967	hid_snto32
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x52d572a1	hidraw_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x564729a1	__hid_register_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5750dd0a	hid_allocate_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x5cf811fd	hidraw_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x65063fa3	hid_dump_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x6f235287	hid_set_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x7e47f35c	hid_input_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x851b201d	hid_dump_device
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x874c72ae	hid_alloc_report_buf
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x87c0dfd1	hidinput_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x925d0c6e	hid_ignore
++EXPORT_SYMBOL_GPL drivers/hid/hid 0x9de48729	hid_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xa45378e7	hidinput_calc_abs_res
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xb9670f93	hidinput_count_leds
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xbc1eba29	hid_output_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xc9013277	hid_dump_input
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xcacea96b	hidinput_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xd4beb44b	hid_register_report
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xda0e4a31	hid_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xdd0a0611	hid_check_keys_pressed
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xe322d419	hidinput_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xef543207	hidinput_get_led_field
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf1afe93c	hid_debug_event
++EXPORT_SYMBOL_GPL drivers/hid/hid 0xf89a65eb	hid_unregister_driver
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x2f622ea1	roccat_disconnect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x710c5d84	roccat_connect
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat 0x8c4181ec	roccat_report_event
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x2308fed4	roccat_common2_receive
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0x529b8ee2	roccat_common2_send
++EXPORT_SYMBOL_GPL drivers/hid/hid-roccat-common 0xd359f3cf	roccat_common2_send_with_status
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x09f0643f	sensor_hub_remove_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x1715008a	sensor_hub_register_callback
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5afb6f5c	sensor_hub_set_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x5fada2f1	sensor_hub_input_attr_get_raw_value
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0x948c1e65	sensor_hub_get_feature
++EXPORT_SYMBOL_GPL drivers/hid/hid-sensor-hub 0xa2c928ec	sensor_hub_input_get_attribute_info
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x01fd453e	usbhid_lookup_quirk
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0x510f4ecf	hiddev_hid_event
++EXPORT_SYMBOL_GPL drivers/hid/usbhid/usbhid 0xd29b374f	usbhid_set_leds
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x12b23e19	hsi_release_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x355fa679	hsi_unregister_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x365c5782	hsi_claim_port
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x40051ec2	hsi_register_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x4b2cb649	hsi_unregister_port_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x5ff8a4e8	hsi_alloc_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0x67f3256c	hsi_register_client_driver
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa092d4eb	hsi_free_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa21978d8	hsi_put_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xa771a38f	hsi_alloc_msg
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe0bcff9a	hsi_event
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe26bd06a	hsi_register_controller
++EXPORT_SYMBOL_GPL drivers/hsi/hsi 0xe2c7bf71	hsi_async
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x12027872	vmbus_establish_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x18310035	vmbus_sendpacket_multipagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x1fb5258f	vmbus_open
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x285addcf	vmbus_recvpacket_raw
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x2d25dc02	vmbus_get_outgoing_channel
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x358fafa5	vmbus_prep_negotiate_resp
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x46a417ca	vmbus_proto_version
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x6a78e57f	__vmbus_driver_register
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0x92844f52	vmbus_set_sc_create_callback
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xb5ff2042	vmbus_sendpacket_pagebuffer
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xc82efdff	vmbus_driver_unregister
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xcb75f7e6	vmbus_teardown_gpadl
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xcbacd19f	vmbus_are_subchannels_present
++EXPORT_SYMBOL_GPL drivers/hv/hv_vmbus 0xefb83553	vmbus_close
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0x3ce4e374	adt7x10_dev_pm_ops
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xb43f3972	adt7x10_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/adt7x10 0xea55feb8	adt7x10_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x192b08e0	pmbus_clear_cache
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x1df06801	pmbus_check_word_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x22441953	pmbus_read_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x53010c49	pmbus_do_remove
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0x6ee5a88d	pmbus_set_page
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xa7e1669c	pmbus_get_driver_info
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xae607086	pmbus_do_probe
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xcbd4ff5e	pmbus_clear_faults
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xd265786a	pmbus_check_byte_register
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xda066865	pmbus_write_word_data
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xf5a9a2f2	pmbus_write_byte
++EXPORT_SYMBOL_GPL drivers/hwmon/pmbus/pmbus_core 0xfc2665f2	pmbus_read_byte_data
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x34323855	i2c_dw_disable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x4c34387a	i2c_dw_is_enabled
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x5bb1170b	i2c_dw_isr
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x77110be6	i2c_dw_func
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0x8b4e1032	i2c_dw_xfer
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xa7a4fde0	i2c_dw_enable
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xaa3f830c	i2c_dw_init
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xbe5e2fc2	i2c_dw_read_comp_param
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xea36ed7c	i2c_dw_clear_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-designware-core 0xf57721d7	i2c_dw_disable_int
++EXPORT_SYMBOL_GPL drivers/i2c/busses/i2c-nforce2 0x85ce9a34	nforce2_smbus
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x2a20d835	i2c_add_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-mux 0x3efad914	i2c_del_mux_adapter
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0x90f53a2e	i2c_setup_smbus_alert
++EXPORT_SYMBOL_GPL drivers/i2c/i2c-smbus 0xce26e23c	i2c_handle_smbus_alert
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x09f91e3d	ad_sd_init
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x47dfd4bd	ad_sd_validate_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x6095ea90	ad_sd_calibrate_all
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x6bef5f58	ad_sd_set_comm
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x8180bdc9	ad_sd_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x85c7e2a5	ad_sigma_delta_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0x9aa653e1	ad_sd_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xc7352d1f	ad_sd_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/adc/ad_sigma_delta 0xe01064fd	ad_sd_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2741be5f	adis_check_status
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x2b9cd987	adis_write_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x382096e0	adis_probe_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x3b64ee6a	adis_initial_startup
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x512028ed	adis_single_conversion
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x5e50d3a4	adis_read_reg
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x619e5d0a	adis_update_scan_mode
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x784f4088	adis_remove_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x82a13077	adis_cleanup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x87798173	adis_reset
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0x8b92bf4a	adis_init
++EXPORT_SYMBOL_GPL drivers/iio/imu/adis_lib 0xfde3274c	adis_setup_buffer_and_trigger
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x09ea19b8	iio_validate_scan_mask_onehot
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x0a76c04a	iio_push_to_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x14671aba	iio_dealloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x1c252ed8	iio_map_array_unregister
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x267c0508	iio_channel_release_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x26f6b499	iio_str_to_fixpoint
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a1fab3c	iio_channel_stop_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x2a2e2cb9	iio_map_array_register
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3924fce7	iio_enum_write
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x3daa2ee2	iio_channel_get_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x4ec940a2	iio_update_buffers
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x59e3abdf	iio_scan_mask_set
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x5d1e9605	iio_update_demux
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x67f0d0cf	iio_read_channel_raw
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x71818b22	iio_channel_release_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7a711aef	iio_channel_start_all_cb
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x7d8c1a7e	iio_scan_mask_query
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x826a6ad2	iio_convert_raw_to_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x956165af	iio_channel_get_all
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0x9a74e420	iio_enum_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb24acf75	iio_read_channel_processed
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xb6d28a39	iio_channel_cb_get_channels
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xc1b0e038	iio_alloc_pollfunc
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xca93406f	iio_read_channel_scale
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xce52fede	iio_channel_release
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xe0166113	iio_enum_available_read
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf313fa0e	iio_get_channel_type
++EXPORT_SYMBOL_GPL drivers/iio/industrialio 0xf82d22e2	iio_channel_get
++EXPORT_SYMBOL_GPL drivers/infiniband/core/ib_core 0xdbd019c4	ib_wq
++EXPORT_SYMBOL_GPL drivers/input/ff-memless 0x92ec0127	input_ff_create_memless
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x02d70395	adxl34x_probe
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x49a4fcbd	adxl34x_remove
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0x66535a18	adxl34x_suspend
++EXPORT_SYMBOL_GPL drivers/input/misc/adxl34x 0xe4586827	adxl34x_resume
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0x2d243d09	cyttsp4_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xf6fc472d	cyttsp4_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp4_core 0xfd7b8380	cyttsp4_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0x188f399c	cyttsp_pm_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xa9f604e2	cyttsp_remove
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_core 0xec462df1	cyttsp_probe
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x40296129	cyttsp_i2c_write_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/cyttsp_i2c_common 0x6756695f	cyttsp_i2c_read_block_data
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x1aa946d9	wm97xx_reg_read
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x36b08b66	wm97xx_config_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x383a870a	wm97xx_unregister_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x3d4056fe	wm97xx_get_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x550ac843	wm97xx_set_suspend_mode
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x63ba140b	wm97xx_set_gpio
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x6744f52b	wm9712_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x7afae871	wm9705_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0x932df18a	wm97xx_reg_write
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xa93db514	wm97xx_register_mach_ops
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xabeef5b5	wm9713_codec
++EXPORT_SYMBOL_GPL drivers/input/touchscreen/wm97xx-ts 0xbf76c524	wm97xx_read_aux_adc
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x4fb5ca34	ipack_driver_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x549cff76	ipack_device_add
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x81e8c827	ipack_driver_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x865bcb88	ipack_get_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x897e22e9	ipack_bus_unregister
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x8a946ee7	ipack_device_del
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0x94e9e9d5	ipack_put_device
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xabbedb6c	ipack_bus_register
++EXPORT_SYMBOL_GPL drivers/ipack/ipack 0xbf6f8c30	ipack_device_init
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0x23359aff	unregister_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/capi/kernelcapi 0xce1414b2	register_capictr_notifier
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1099fd60	gigaset_fill_inbuf
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1504dd84	gigaset_start
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x1f6c62e7	gigaset_stop
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x2f2612b0	gigaset_handle_modem_response
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x3804855f	gigaset_add_event
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x4414bfcf	gigaset_m10x_send_skb
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x454aa44f	gigaset_debuglevel
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x48c61943	gigaset_blockdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x5a36ed72	gigaset_initdriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x65e97466	gigaset_freedriver
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x672ed0cd	gigaset_initcs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x70ffa136	gigaset_freecs
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x7527b89e	gigaset_if_receive
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8d2078a9	gigaset_skb_sent
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0x8eff32df	gigaset_dbg_buffer
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xc709094c	gigaset_shutdown
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xca4fd012	gigaset_isdn_rcv_err
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xd50d742b	gigaset_skb_rcvd
++EXPORT_SYMBOL_GPL drivers/isdn/gigaset/gigaset 0xdd79387e	gigaset_m10x_input
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x03268b78	lp55xx_unregister_leds
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x0c118981	lp55xx_deinit_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x2265c002	lp55xx_of_populate_pdata
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x472fc4ab	lp55xx_init_device
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x6251d7cf	lp55xx_read
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x767712c0	lp55xx_register_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0x9a96bc40	lp55xx_write
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xa3d46da7	lp55xx_update_bits
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xbcd3c01f	lp55xx_unregister_sysfs
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xde2a0835	lp55xx_is_extclk_used
++EXPORT_SYMBOL_GPL drivers/leds/leds-lp55xx-common 0xe51a0bb3	lp55xx_register_leds
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x749e05f2	ledtrig_flash_ctrl
++EXPORT_SYMBOL_GPL drivers/leds/trigger/ledtrig-camera 0x7903e46e	ledtrig_torch_ctrl
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x10e06e97	__tracepoint_bcache_btree_set_root
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x155ea9c7	__tracepoint_bcache_bypass_sequential
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1822fd23	__tracepoint_bcache_btree_gc_coalesce
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x1f2ba9ac	__tracepoint_bcache_journal_entry_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2265c1bf	closure_sub
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x260d47cf	__tracepoint_bcache_btree_cache_cannibalize
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x27831e89	__tracepoint_bcache_journal_full
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x2dec45e0	__tracepoint_bcache_btree_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x347aebe1	__tracepoint_bcache_btree_node_free
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x41c861f0	__tracepoint_bcache_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x49856e5a	__tracepoint_bcache_btree_node_compact
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x50e8c39f	__tracepoint_bcache_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x53ba2273	__closure_delay
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x574ba881	__tracepoint_bcache_btree_node_alloc
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x628eb712	__tracepoint_bcache_btree_insert_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6770a402	__tracepoint_bcache_gc_copy_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x68a21775	closure_wait
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x6a9010d7	closure_queue
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x785cfc9f	__tracepoint_bcache_gc_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x78cab4a7	__closure_flush
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7b488fb1	__tracepoint_bcache_alloc_invalidate
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x7bb6adb6	do_closure_timer_init
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x91f2af34	__tracepoint_bcache_btree_node_alloc_fail
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0x96979249	closure_put
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa09069a3	__tracepoint_bcache_writeback_collision
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa591c5d6	__tracepoint_bcache_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xa6890b59	__tracepoint_bcache_btree_read
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xaf60c34b	__tracepoint_bcache_journal_write
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb5e2aa5e	closure_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xb950d2ae	__tracepoint_bcache_request_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xbd4b89b6	__tracepoint_bcache_btree_node_split
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xc829d4d4	__closure_lock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xce0e6218	__tracepoint_bcache_gc_copy
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xd40fba32	__tracepoint_bcache_gc_start
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xdc5ea5a5	__tracepoint_bcache_cache_insert
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xe3c17af1	__closure_wake_up
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xed27fbac	closure_trylock
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf58ce244	__tracepoint_bcache_journal_replay_key
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf5bcbdc7	__tracepoint_bcache_read_retry
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xf7ac953b	__closure_flush_sync
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfc1d5275	__tracepoint_bcache_writeback
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xfcdf28c9	__tracepoint_bcache_request_end
++EXPORT_SYMBOL_GPL drivers/md/bcache/bcache 0xffc308e4	__tracepoint_bcache_bypass_congested
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x02133f3b	dm_cell_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x04f76094	dm_bio_detain
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x17dd39d6	dm_deferred_set_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x1a070fff	dm_bio_prison_alloc_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x2eb01e04	dm_deferred_set_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x4a346d36	dm_get_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x658b4540	dm_cell_error
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x6791a44e	dm_deferred_entry_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0x7b8b6c8c	dm_cell_release_no_holder
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb6d5c65d	dm_deferred_set_add_work
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xb70b342a	dm_bio_prison_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xca2e3a88	dm_deferred_entry_inc
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xe928459e	dm_bio_prison_free_cell
++EXPORT_SYMBOL_GPL drivers/md/dm-bio-prison 0xebd06eaf	dm_bio_prison_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x0ad0dc4f	dm_bufio_mark_buffer_dirty
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x22163b69	dm_bufio_release_move
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x3909d3a8	dm_bufio_prefetch
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x594952bd	dm_bufio_read
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x62a23587	dm_bufio_get_device_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x6d3f57bd	dm_bufio_get_client
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x74dcd98c	dm_bufio_get_aux_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x7c381a76	dm_bufio_get_block_size
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x86b97cce	dm_bufio_client_create
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0x9b2b253a	dm_bufio_get
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xa82b2066	dm_bufio_write_dirty_buffers
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xc9a3422d	dm_bufio_write_dirty_buffers_async
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xd4bddf5c	dm_bufio_issue_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xdc69e37a	dm_bufio_get_block_number
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe004ee92	dm_bufio_new
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xe6024e59	dm_bufio_release
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xebcc64a4	dm_bufio_get_block_data
++EXPORT_SYMBOL_GPL drivers/md/dm-bufio 0xeca7949e	dm_bufio_client_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x07d886fe	dm_cache_policy_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x3a3dc854	dm_cache_policy_get_hint_size
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x408a7a1c	dm_cache_policy_unregister
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x4dc9508f	dm_cache_policy_get_name
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0x7612d272	dm_cache_policy_create
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xe3bdbbdd	dm_cache_policy_get_version
++EXPORT_SYMBOL_GPL drivers/md/dm-cache 0xf4d47d5a	dm_cache_policy_register
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x25b43607	dm_unregister_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-multipath 0x3e39009c	dm_register_path_selector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x01d2f9ac	dm_rh_recovery_start
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x09472122	dm_rh_dec
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x38efaf5a	dm_region_hash_destroy
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x3a18389a	dm_rh_update_states
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x472fb7bc	dm_rh_bio_to_region
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x6ae9f014	dm_region_hash_create
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7774620f	dm_rh_stop_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x7d053fc5	dm_rh_start_recovery
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0x8906af4d	dm_rh_dirty_log
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa53387c7	dm_rh_flush
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa83588eb	dm_rh_recovery_end
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8489ba4	dm_rh_mark_nosync
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xa8813ad6	dm_rh_region_to_sector
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xae3b1ffa	dm_rh_delay
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xbe38a431	dm_rh_recovery_prepare
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xc66ce277	dm_rh_get_region_size
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xcab63c3d	dm_rh_get_state
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xd8aa4284	dm_rh_region_context
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xdb3d00b0	dm_rh_inc_pending
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xf37a3cfe	dm_rh_get_region_key
++EXPORT_SYMBOL_GPL drivers/md/dm-region-hash 0xfd93482e	dm_rh_recovery_in_flight
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x0054f69d	dm_tm_pre_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x01445176	dm_btree_find_highest_key
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x11eab9fe	dm_bm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x150c85ce	dm_tm_open_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1cac81ac	dm_bitset_clear_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x1e3f728d	dm_block_data
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2025e954	dm_array_info_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2c112836	dm_block_location
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2e730a21	dm_bm_checksum
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x2f74609d	dm_bitset_test_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x32b5f546	dm_array_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x33c03da6	dm_sm_disk_open
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x371fd72c	dm_bm_flush_and_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x38c75c44	dm_bitset_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x40f7bd91	dm_tm_inc
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x5e6aea80	dm_btree_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x619701dc	dm_sm_disk_create
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x62c1b9ee	dm_array_walk
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x688d422d	dm_bm_block_size
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x68fae9d2	dm_disk_bitset_init
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x72289260	dm_block_manager_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7ade1071	dm_tm_destroy
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x7b047bd9	dm_tm_create_non_blocking_clone
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x80c89b3d	dm_tm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x832bf228	dm_array_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x858c8d94	dm_array_set_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x89f1e1cc	dm_btree_insert_notify
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x966a8838	dm_btree_lookup
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9b4b5b29	dm_bm_write_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0x9e798e22	dm_bm_set_read_only
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa0bbbb49	dm_bitset_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa13861b4	dm_bitset_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa2507774	dm_tm_shadow_block
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xa87c5b4d	dm_array_resize
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xaee02382	dm_btree_empty
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb7bad799	dm_bm_unlock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xb9a6ecf8	dm_tm_dec
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbcfdc290	dm_tm_read_lock
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbd50ebbb	dm_btree_del
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xbe0497aa	dm_tm_create_with_sm
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xca40abd5	dm_btree_insert
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd041d62b	dm_array_get_value
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xd163cade	dm_tm_commit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xe44b4b9b	dm_bitset_set_bit
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xead1e727	dm_bm_write_lock_zero
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xed1e1f96	dm_btree_remove
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf475af48	dm_bitset_flush
++EXPORT_SYMBOL_GPL drivers/md/persistent-data/dm-persistent-data 0xf91dea7f	dm_block_manager_create
++EXPORT_SYMBOL_GPL drivers/md/raid1 0x6635efcd	md_raid1_congested
++EXPORT_SYMBOL_GPL drivers/md/raid10 0xee0dc63b	md_raid10_congested
++EXPORT_SYMBOL_GPL drivers/md/raid456 0xbf3ab0ee	md_raid5_congested
++EXPORT_SYMBOL_GPL drivers/media/common/b2c2/b2c2-flexcop 0x66c0289a	b2c2_flexcop_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x22c8e6ff	saa7146_pgtable_alloc
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x28eacd5f	saa7146_wait_for_debi_done
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x3ec3a4d2	saa7146_pgtable_build_single
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x40c34edc	saa7146_vmalloc_build_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x582fb259	saa7146_unregister_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x6adfab73	saa7146_vfree_destroy_pgtable
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0x7fe0b0d5	saa7146_pgtable_free
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xbca09379	saa7146_setgpio
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3a0c85e	saa7146_i2c_adapter_prepare
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xe3cd9b5c	saa7146_debug
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146 0xf6f3aa66	saa7146_register_extension
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x0c648dfb	saa7146_vv_release
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x62fd8203	saa7146_start_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x69d9d1ec	saa7146_stop_preview
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x980248f2	saa7146_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0x9db25d9b	saa7146_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xbf0d524f	saa7146_vv_init
++EXPORT_SYMBOL_GPL drivers/media/common/saa7146/saa7146_vv 0xe9170467	saa7146_set_hps_source_and_sync
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x0f2ff736	smscore_unregister_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x1da5164e	smscore_start_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x21e36bf2	smscore_registry_getmode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x2c0db93a	smscore_register_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x37d91069	smsendian_handle_tx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x421722dd	smscore_get_device_mode
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x44471210	sms_board_power
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x44536a01	sms_board_setup
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x45284ae9	smsendian_handle_rx_message
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x63222b29	smsclient_sendrequest
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x6ce74a93	sms_board_lna_control
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x73354cf2	smscore_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x74ee9098	sms_board_load_modules
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x7c576277	smsendian_handle_message_header
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x831822bc	smscore_get_board_id
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x844539ae	sms_get_board
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9a041c2b	smscore_onresponse
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9bd6087d	smscore_getbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9c2225ed	smscore_translate_msg
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0x9da79713	smscore_register_hotplug
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xaf269c80	smscore_register_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xbbdb5c42	smscore_unregister_client
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd2f34a55	sms_board_event
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xd4d78ab9	sms_board_led_feedback
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xe47480ac	smscore_putbuffer
++EXPORT_SYMBOL_GPL drivers/media/common/siano/smsmdtv 0xf8e1d611	smscore_set_board_id
++EXPORT_SYMBOL_GPL drivers/media/dvb-frontends/tda18271c2dd 0xaa595eac	tda18271c2dd_attach
++EXPORT_SYMBOL_GPL drivers/media/pci/cx88/cx88xx 0xa3781eb5	cx88_setup_xc3028
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x04ca3b4b	mantis_get_mac
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x1b04bd78	mantis_uart_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x20403350	mantis_stream_control
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x2d191fad	mantis_frontend_soft_reset
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x30c8acd2	mantis_dvb_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x41a2055a	mantis_i2c_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x44ea88fd	mantis_ca_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5a000c0f	mantis_dma_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x5ac77f52	mantis_gpio_set_bits
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x775a5c4a	mantis_pci_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8d9699cb	mantis_frontend_power
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x8ee81f2b	mantis_dma_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0x954a167e	mantis_i2c_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xadac91e8	mantis_pci_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xd99d06c9	mantis_uart_init
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xe420bff6	mantis_dvb_exit
++EXPORT_SYMBOL_GPL drivers/media/pci/mantis/mantis_core 0xeef41c0c	mantis_ca_init
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x3e080c61	saa7134_ts_qops
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x4f47a9db	saa7134_s_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x805b6581	saa7134_s_std_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0x8f84096c	saa7134_g_ctrl_internal
++EXPORT_SYMBOL_GPL drivers/media/pci/saa7134/saa7134 0xf4f1b09d	saa7134_queryctrl
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x180ad682	ttpci_budget_debiread
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x333888cc	ttpci_budget_init
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x7948c222	budget_debug
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0x9e1a8679	ttpci_budget_irq10_handler
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xb9ef168d	ttpci_budget_set_video_port
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xba6d5bb5	ttpci_budget_debiwrite
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd6c9b1ea	ttpci_budget_deinit
++EXPORT_SYMBOL_GPL drivers/media/pci/ttpci/budget-core 0xd86181ef	ttpci_budget_init_hooks
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x4d5a44df	radio_isa_pnp_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x5df3dfb5	radio_isa_pnp_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0x5f0674d2	radio_isa_remove
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0xeb27915e	radio_isa_match
++EXPORT_SYMBOL_GPL drivers/media/radio/radio-isa 0xee3abfd9	radio_isa_probe
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x38ec5b64	radio_tea5777_init
++EXPORT_SYMBOL_GPL drivers/media/radio/shark2 0x989a007b	radio_tea5777_exit
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x051cd812	rc_map_get
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x2bca3792	rc_repeat
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x3b172519	ir_raw_event_store_edge
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x45b80357	rc_map_register
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x553efb91	rc_core_debug
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x5786ab40	rc_keydown_notimeout
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x616ed5e7	rc_keydown
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x826edbc8	ir_raw_event_store_with_filter
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x840b4385	rc_keyup
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0x98a30e03	rc_free_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xad8ea39f	rc_allocate_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb3cfe17c	rc_g_keycode_from_table
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xb9e89563	ir_raw_event_handle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xc4c5bfee	rc_unregister_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xda884324	ir_raw_event_set_idle
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf2a445d5	rc_map_unregister
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xf860f8ce	rc_register_device
++EXPORT_SYMBOL_GPL drivers/media/rc/rc-core 0xfa18d6f2	ir_raw_event_store
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt2063 0x54df8dac	mt2063_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mt20xx 0x87240d77	microtune_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/mxl5007t 0x0cc5284a	mxl5007t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/r820t 0xacd0f80e	r820t_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda18271 0xa55b2e7c	tda18271_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda827x 0xc363a5b7	tda827x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xc82ef082	tda829x_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda8290 0xf1dd7a16	tda829x_probe
++EXPORT_SYMBOL_GPL drivers/media/tuners/tda9887 0x3d2a5669	tda9887_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x4a40c0c7	tea5761_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5761 0x892ba676	tea5761_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0x420cb7be	tea5767_autodetection
++EXPORT_SYMBOL_GPL drivers/media/tuners/tea5767 0xd4a993f8	tea5767_attach
++EXPORT_SYMBOL_GPL drivers/media/tuners/tuner-simple 0xc366cc49	simple_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x017ea7c7	cx231xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x1b95e120	cx231xx_send_usb_command
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x21191ea6	cx231xx_demod_reset
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x36f1e95d	cx231xx_init_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x380138ad	cx231xx_set_alt_setting
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x5c64ada0	cx231xx_enable_i2c_port_3
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x737d97be	is_fw_load
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x803a5e9a	cx231xx_uninit_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x8ed14b65	cx231xx_init_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0x9e9202fe	cx231xx_dev_init
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xa7a220df	cx231xx_dev_uninit
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb2969a51	cx231xx_unmute_audio
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xb686e3bc	cx231xx_init_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xbf91ba66	cx231xx_uninit_vbi_isoc
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xc504aff9	cx231xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xcdb3669b	cx231xx_uninit_bulk
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xd3152390	cx231xx_enable656
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xdf29e82d	cx231xx_send_gpio_cmd
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xe138d9ad	cx231xx_capture_start
++EXPORT_SYMBOL_GPL drivers/media/usb/cx231xx/cx231xx 0xf4a3565b	cx231xx_disable656
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-demod 0x40e199b6	mxl111sf_demod_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/dvb-usb-v2/mxl111sf-tuner 0x7fe19090	mxl111sf_tuner_attach
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x2f300c64	em28xx_write_reg_bits
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x35e47778	em28xx_gpio_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x419b411c	em28xx_read_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x53f860f5	em28xx_init_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5438f9d7	em28xx_read_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x5446b55d	em28xx_alloc_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x7fc8652c	em28xx_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x815b4a07	em28xx_set_mode
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x8d2f03b5	em28xx_write_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0x91e255ac	em28xx_audio_setup
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xca519c43	em28xx_write_regs
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe85b717a	em28xx_uninit_usb_xfer
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xe8c1ef6e	em28xx_audio_analog_set
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xea303763	em28xx_write_ac97
++EXPORT_SYMBOL_GPL drivers/media/usb/em28xx/em28xx 0xed16a245	em28xx_stop_urbs
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2309a6d6	tm6000_xc5000_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x2ee33de0	tm6000_set_audio_bitrate
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x85b6d733	tm6000_get_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0x89b611dd	tm6000_debug
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xdff8e89d	tm6000_tuner_callback
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xe25665dc	tm6000_set_reg
++EXPORT_SYMBOL_GPL drivers/media/usb/tm6000/tm6000 0xee5433d1	tm6000_set_reg_mask
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x01c483a9	v4l2_get_timestamp
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x07e2e098	v4l2_i2c_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x19a966c8	v4l2_i2c_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x1ace7949	v4l2_i2c_subdev_addr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x53105839	v4l2_detect_cvt
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x5d9d3491	v4l_match_dv_timings
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x6f344bb9	v4l2_calc_aspect_ratio
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x7eaf8e7a	v4l2_detect_gtf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0x813f3de4	v4l2_find_nearest_format
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xaf6886b3	v4l2_spi_subdev_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf2a353ac	v4l2_i2c_tuner_addrs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xf5ef842e	v4l_bound_align_image
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xfd74754a	v4l2_i2c_new_subdev_board
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-common 0xfe936e78	v4l2_spi_new_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x3797131d	v4l2_int_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0x4efdb371	v4l2_int_ioctl_1
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xa5228b24	v4l2_int_device_try_attach_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xd40e885c	v4l2_int_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-int-device 0xf2d233cd	v4l2_int_ioctl_0
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x17eb0eee	v4l2_m2m_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x2285ca75	v4l2_m2m_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x23084fa7	v4l2_m2m_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3657fb12	v4l2_m2m_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x3e7b1417	v4l2_m2m_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x41fc8d4a	v4l2_m2m_buf_queue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x48206c35	v4l2_m2m_buf_remove
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5123f034	v4l2_m2m_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5862c1ff	v4l2_m2m_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x5eed8bad	v4l2_m2m_next_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0x67fe57c4	v4l2_m2m_ctx_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc387f464	v4l2_m2m_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc583a3bd	v4l2_m2m_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xc6fca5ad	v4l2_m2m_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xd8ae349e	v4l2_m2m_ctx_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/v4l2-mem2mem 0xe841c599	v4l2_m2m_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x0e985113	videobuf_read_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x2a19320f	videobuf_queue_to_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3aeabc31	videobuf_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3e2e2272	videobuf_read_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x3ef9dec7	videobuf_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x43a1707c	videobuf_queue_cancel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x463df3f6	videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x474320bc	videobuf_read_one
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x49a5a68c	__videobuf_mmap_setup
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x4f1beefb	videobuf_alloc_vb
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x550be219	videobuf_iolock
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x57455eec	videobuf_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x76d9a27f	videobuf_read_start
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x86f31d30	videobuf_poll_stream
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x8789eccc	videobuf_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0x96759602	videobuf_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xb5a7aa4a	videobuf_next_field
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd56c65e0	videobuf_waiton
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xd9b701b9	videobuf_queue_is_busy
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe1b0029b	videobuf_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe202c1a6	videobuf_mmap_mapper
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xe7580b1b	videobuf_queue_core_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xed1d1175	videobuf_stop
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-core 0xff4d3446	videobuf_mmap_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0x4ea0d80f	videobuf_dma_contig_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xb6a55379	videobuf_queue_dma_contig_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-contig 0xd3b05285	videobuf_to_dma_contig
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x05506a11	videobuf_dma_init_kernel
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x0be333c7	videobuf_dma_map
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x48dd5659	videobuf_dma_init_user
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x65396914	videobuf_dma_init_overlay
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0x6d1153e5	videobuf_queue_sg_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa825c75b	videobuf_sg_alloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xa969c97f	videobuf_dma_unmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xd74b2dba	videobuf_to_dma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xf232ed9f	videobuf_dma_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-dma-sg 0xfe84273c	videobuf_dma_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x8189bd62	videobuf_to_vmalloc
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0x94dda002	videobuf_queue_vmalloc_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf-vmalloc 0xfc72b9b6	videobuf_vmalloc_free
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x01819136	vb2_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x036dd122	vb2_ops_wait_prepare
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x04779a23	vb2_ioctl_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x05da88b0	vb2_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1320bccd	vb2_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x1fc020d4	vb2_queue_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x2d65e8d1	vb2_ioctl_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x306db44d	vb2_ioctl_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x52bf7fce	vb2_plane_cookie
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x52c3afae	vb2_wait_for_all_buffers
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x55d08da3	vb2_streamoff
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7db976b1	vb2_fop_write
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7f9d956c	vb2_ioctl_querybuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x7ff9e070	vb2_ioctl_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x8a6046e6	vb2_queue_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x98630984	vb2_ioctl_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9971a52d	vb2_dqbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x99ce8b4c	vb2_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0x9fdb7d56	vb2_buffer_done
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xa5cd7f89	vb2_fop_read
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbbd39e95	vb2_fop_poll
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xbdaa0dc8	vb2_ioctl_streamon
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xca4f4975	vb2_fop_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd4240e7b	vb2_fop_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xd977046d	vb2_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdc5bf7b1	vb2_mmap
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xdf3f05b8	vb2_prepare_buf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe35dd0ab	vb2_qbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe383e633	vb2_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xe70abb64	vb2_create_bufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xea7d0cd0	vb2_ops_wait_finish
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xeacc368e	vb2_ioctl_reqbufs
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfacf52d6	vb2_ioctl_expbuf
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-core 0xfe603363	vb2_plane_vaddr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x15dbe3fa	vb2_dma_contig_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0x95d91466	vb2_dma_contig_init_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-contig 0xe57f0426	vb2_dma_contig_cleanup_ctx
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-dma-sg 0x66e06189	vb2_dma_sg_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x49663f86	vb2_put_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x939fc919	vb2_get_contig_userptr
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x97f306b7	vb2_get_vma
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-memops 0x99a41bdf	vb2_common_vm_ops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videobuf2-vmalloc 0xeddfa1d8	vb2_vmalloc_memops
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x068b2b4c	v4l2_event_subdev_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x09fd6ede	v4l2_fh_exit
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x0af38d8a	v4l2_event_subscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x10fe0c6e	v4l2_fh_release
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x180c07a1	v4l2_fh_is_singular
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x25465f6e	v4l2_fh_del
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x2d76dad0	v4l2_fh_init
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x48ac6580	v4l2_device_unregister
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x6f2e0e0e	v4l2_device_disconnect
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7a128b39	v4l2_device_put
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x7e0194fc	v4l2_device_unregister_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x830014aa	v4l2_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8700ac57	v4l2_fh_add
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0x8acd0884	v4l2_device_register
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xae6a4794	v4l2_device_register_subdev_nodes
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xafa5061b	v4l2_device_register_subdev
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb28aecf3	v4l2_fh_open
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xb5e36475	v4l2_event_queue_fh
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xbc672c68	v4l2_event_unsubscribe_all
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xd064a352	v4l2_device_set_name
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xda8e1e87	v4l2_event_dequeue
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xe10b6d61	v4l2_event_pending
++EXPORT_SYMBOL_GPL drivers/media/v4l2-core/videodev 0xff52b1cd	v4l2_event_queue
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x009ff665	i2o_dma_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x4b7b7f6b	i2o_sg_tablesize
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x5e6d37a9	i2o_dma_map_single
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x62ee97ad	i2o_dma_free
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0x93a926f4	i2o_dma_map_sg
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xd40ee961	i2o_pool_alloc
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xed17ce87	i2o_pool_free
++EXPORT_SYMBOL_GPL drivers/message/i2o/i2o_core 0xef5eec11	i2o_dma_realloc
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x620389bf	pm80x_regmap_config
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0x6afc1126	pm80x_pm_ops
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xbe6bb0b0	pm80x_init
++EXPORT_SYMBOL_GPL drivers/mfd/88pm80x 0xd99fd720	pm80x_deinit
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x0f7ba180	kempld_read32
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x54121df9	kempld_release_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x63bb21ef	kempld_write16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0x8808cffe	kempld_read16
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xbb14f599	kempld_read8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xe7d60a59	kempld_get_mutex
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xea898411	kempld_write8
++EXPORT_SYMBOL_GPL drivers/mfd/kempld-core 0xfe84414f	kempld_write32
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x48c8b647	lm3533_read
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0x6ce83ccf	lm3533_update
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-core 0xbc60e32e	lm3533_write
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x14409789	lm3533_ctrlbank_get_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x21ad3b4b	lm3533_ctrlbank_set_pwm
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x2dde42c2	lm3533_ctrlbank_set_max_current
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x43b6c26f	lm3533_ctrlbank_set_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x706d1857	lm3533_ctrlbank_disable
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0x7a61c998	lm3533_ctrlbank_get_brightness
++EXPORT_SYMBOL_GPL drivers/mfd/lm3533-ctrlbank 0xb87e2fe2	lm3533_ctrlbank_enable
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x2f2e2cba	mc13xxx_common_cleanup
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x7f8f5977	mc13xxx_adc_do_conversion
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0x9fde9198	mc13xxx_variant_mc13892
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xcd6b2fd0	mc13xxx_variant_mc34708
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xdf64dab8	mc13xxx_variant_mc13783
++EXPORT_SYMBOL_GPL drivers/mfd/mc13xxx-core 0xe73c95b5	mc13xxx_common_init
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x0d936bbd	pcf50633_irq_mask_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x242fb4d9	pcf50633_read_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x3186ce44	pcf50633_irq_unmask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x38476b2f	pcf50633_irq_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0x8dbe9331	pcf50633_register_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xa496f4ad	pcf50633_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xbeaddcd0	pcf50633_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xe223558e	pcf50633_reg_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfb18ce43	pcf50633_free_irq
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfca5d751	pcf50633_write_block
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633 0xfeefb8cd	pcf50633_reg_set_bit_mask
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0x14ed648e	pcf50633_adc_async_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-adc 0xf6fb596a	pcf50633_adc_sync_read
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x17b94443	pcf50633_gpio_invert_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x1bf15427	pcf50633_gpio_invert_get
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0x52cc186c	pcf50633_gpio_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xba0afadd	pcf50633_gpio_power_supply_set
++EXPORT_SYMBOL_GPL drivers/mfd/pcf50633-gpio 0xfb42f052	pcf50633_gpio_get
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x01a33234	retu_write
++EXPORT_SYMBOL_GPL drivers/mfd/retu-mfd 0x4fca3918	retu_read
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x00d73b8a	rtsx_pci_add_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x02308f57	rtsx_pci_start_run
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0c40507b	rtsx_pci_write_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0c43a8e8	rtsx_pci_card_exist
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x0fee66a6	rtsx_pci_card_pull_ctl_disable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x1eea0d46	rtsx_pci_card_power_on
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x22938ebf	rtsx_pci_read_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x38e6b548	rtsx_pci_complete_unfinished_transfer
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x422fdd62	rtsx_pci_send_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x6ad0d587	rtsx_pci_card_pull_ctl_enable
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7ad50583	rtsx_pci_write_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0x7cd52309	rtsx_pci_read_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xa63b542e	rtsx_pci_send_cmd_no_wait
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xb6328455	rtsx_pci_read_phy_register
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xbc2e65ba	rtsx_pci_transfer_data
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdb6fa14e	rtsx_pci_card_exclusive_check
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdef96d0f	rtsx_pci_stop_cmd
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xdf8862ab	rtsx_pci_switch_output_voltage
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xe9aec46b	rtsx_pci_card_power_off
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xed83923a	rtsx_pci_write_ppbuf
++EXPORT_SYMBOL_GPL drivers/mfd/rtsx_pci 0xfed7e549	rtsx_pci_switch_clock
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x0526ac16	si476x_core_has_am
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x139635c6	si476x_core_cmd_get_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x1f9666c4	si476x_core_cmd_fm_phase_div_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x2f94ddcc	si476x_core_set_power_state
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x312532e0	si476x_core_i2c_xfer
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x32d916b9	si476x_core_stop
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x37d35a36	si476x_core_cmd_power_down
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x45e59770	si476x_core_cmd_intb_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x4687c7f3	si476x_core_has_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x56e02766	si476x_core_cmd_am_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x58d29334	si476x_core_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x594437aa	si476x_core_is_in_am_receiver_mode
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x5f39e2fb	si476x_core_cmd_power_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x75785a05	si476x_core_cmd_fm_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x7aa0f60b	si476x_core_cmd_fm_rds_blockcount
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x853c4f96	si476x_core_cmd_agc_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8919f7e8	si476x_core_cmd_am_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8a5aceb4	si476x_core_cmd_func_info
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8b760feb	si476x_core_cmd_ic_link_gpo_ctl_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x8cf252ad	si476x_core_cmd_fm_tune_freq
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x99d3bc59	si476x_core_cmd_am_seek_start
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0x9d69de26	si476x_core_cmd_fm_rds_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb055eb12	si476x_core_cmd_set_property
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb5c64148	si476x_core_cmd_fm_phase_diversity
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xb8579bf3	si476x_core_cmd_fm_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbb03540f	si476x_core_is_a_secondary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xbe2b80ae	si476x_core_cmd_dig_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xc9caed58	si476x_core_cmd_zif_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xdb063919	si476x_core_is_a_primary_tuner
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf04fa06a	si476x_core_cmd_fm_rsq_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf4dabef6	si476x_core_cmd_am_acf_status
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xf778c53f	devm_regmap_init_si476x
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfb51b740	si476x_core_is_powered_up
++EXPORT_SYMBOL_GPL drivers/mfd/si476x-core 0xfee1a42d	si476x_core_cmd_ana_audio_pin_cfg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x0397379f	sm501_set_clock
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0x5e0b8195	sm501_misc_control
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xcd11c445	sm501_modify_reg
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xd85fb1a7	sm501_unit_power
++EXPORT_SYMBOL_GPL drivers/mfd/sm501 0xff6e6b6d	sm501_find_clock
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x10f70255	am335x_tsc_se_update
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x2b9f645d	am335x_tsc_se_clr
++EXPORT_SYMBOL_GPL drivers/mfd/ti_am335x_tscadc 0x72cefa1f	am335x_tsc_se_set
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x32186e9b	tps65217_reg_read
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0x90d53be8	tps65217_set_bits
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0xd4997290	tps65217_reg_write
++EXPORT_SYMBOL_GPL drivers/mfd/tps65217 0xfb7a799a	tps65217_clear_bits
++EXPORT_SYMBOL_GPL drivers/mfd/ucb1400_core 0xc8e59fe0	ucb1400_adc_read
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x5494ad5b	cb710_sg_dwiter_write_next_block
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0x9fae6154	cb710_set_irq_handler
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xddf92b45	cb710_pci_update_config_reg
++EXPORT_SYMBOL_GPL drivers/misc/cb710/cb710 0xdf2f8262	cb710_sg_dwiter_read_next_block
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x27cb133b	eeprom_93cx6_multiread
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x63d2ff63	eeprom_93cx6_wren
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x822222db	eeprom_93cx6_write
++EXPORT_SYMBOL_GPL drivers/misc/eeprom/eeprom_93cx6 0x98bb5a22	eeprom_93cx6_read
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x322c5a4c	enclosure_find
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x3e13a05c	enclosure_component_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x5207abda	enclosure_register
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0x543b1c89	enclosure_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xd90f6899	enclosure_unregister
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xe0df7e27	enclosure_add_device
++EXPORT_SYMBOL_GPL drivers/misc/enclosure 0xf9102c62	enclosure_for_each_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x461b5e8c	lis3_dev
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x56b9144f	lis3lv02d_init_dt
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7c7d069a	lis3lv02d_joystick_enable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x7f9562dd	lis3lv02d_poweron
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x94aaeacc	lis3lv02d_init_device
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0x9b6bcdd5	lis3lv02d_poweroff
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe1682e46	lis3lv02d_joystick_disable
++EXPORT_SYMBOL_GPL drivers/misc/lis3lv02d/lis3lv02d 0xe6ca98ab	lis3lv02d_remove_fs
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x008f8187	mei_irq_read_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x02e47a16	mei_cl_recv
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x03b80ded	mei_cl_send
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x2961188d	mei_irq_compl_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x39eb513c	mei_cl_remove_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x4c1658fe	mei_cl_enable_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x4c57869f	mei_deregister
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x651814f4	mei_cl_set_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x66850798	mei_irq_write_handler
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x683a90e8	__mei_cl_driver_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x7225b12b	mei_cl_register_event_cb
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x91803a84	mei_start
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0x9c2c4b58	mei_stop
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xb2162dd8	mei_cl_get_drvdata
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xc5939869	mei_cl_disable_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xc728996f	mei_register
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xd6de6f61	mei_cl_add_device
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xee449ed6	mei_reset
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xf83c3fd5	mei_device_init
++EXPORT_SYMBOL_GPL drivers/misc/mei/mei 0xfbd9c3ce	mei_cl_driver_unregister
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x19f09b98	pti_release_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x23bde487	pti_request_masterchannel
++EXPORT_SYMBOL_GPL drivers/misc/pti 0x52a78e81	pti_writedata
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0x9dcdd96e	st_unregister
++EXPORT_SYMBOL_GPL drivers/misc/ti-st/st_drv 0xe573fed8	st_register
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x0f6680ea	vmci_qpair_produce_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1152e318	vmci_qpair_get_produce_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x13aa5a5d	vmci_datagram_create_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1872c7af	vmci_qpair_produce_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x1a195863	vmci_context_get_priv_flags
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x2e30d970	vmci_qpair_dequeue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x3ef56cd5	vmci_qpair_alloc
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4b630dac	vmci_get_context_id
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4c498e60	vmci_qpair_peekv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x4ea2ccbc	vmci_qpair_peek
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x50a255c9	vmci_doorbell_create
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x612df9ae	vmci_qpair_detach
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x69ef87ff	vmci_datagram_destroy_handle
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6bfa603a	vmci_qpair_dequev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x6cc1a5f7	vmci_datagram_create_handle_priv
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x722d488a	vmci_event_unsubscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x76f1d5c5	vmci_is_context_owner
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x7d540b50	vmci_qpair_consume_free_space
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x8b8ad67a	vmci_qpair_enqueue
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9624c58c	vmci_datagram_send
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9973b9b2	vmci_qpair_consume_buf_ready
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0x9d16164a	vmci_send_datagram
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xbbcb4c48	vmci_qpair_enquev
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xccbb53d1	vmci_doorbell_notify
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xcf5ed7ef	vmci_event_subscribe
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xdac94780	vmci_qpair_get_consume_indexes
++EXPORT_SYMBOL_GPL drivers/misc/vmw_vmci/vmw_vmci 0xe7e7c107	vmci_doorbell_destroy
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x10a51a2c	sdhci_remove_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x396f3e35	sdhci_add_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4385982e	sdhci_runtime_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x4d212fbe	sdhci_free_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x73e29114	sdhci_resume_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7c980f9f	sdhci_runtime_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0x7eb73618	sdhci_enable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xb40224ad	sdhci_alloc_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xbaa4b124	sdhci_suspend_host
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci 0xfa92685b	sdhci_disable_irq_wakeups
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x031decec	sdhci_pltfm_pmops
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x1030e50c	sdhci_pltfm_free
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x1550d7bc	sdhci_get_of_property
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x64a0b881	sdhci_pltfm_register
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0x7e6a0e0b	sdhci_pltfm_clk_get_max_clock
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xc94b6ab7	sdhci_pltfm_init
++EXPORT_SYMBOL_GPL drivers/mmc/host/sdhci-pltfm 0xd02f9615	sdhci_pltfm_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x658ad08e	cfi_cmdset_0200
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0x9894f518	cfi_cmdset_0003
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0001 0xa7bdd0f0	cfi_cmdset_0001
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x2e7a7e92	cfi_cmdset_0006
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0x50283542	cfi_cmdset_0002
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0002 0xa3d1fac4	cfi_cmdset_0701
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_cmdset_0020 0x16c7016b	cfi_cmdset_0020
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x21c89489	cfi_qry_present
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x44857628	cfi_qry_mode_off
++EXPORT_SYMBOL_GPL drivers/mtd/chips/cfi_util 0x8a365bbd	cfi_qry_mode_on
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0231c3b1	mtd_get_unmapped_area
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x0a1c464b	mtd_device_parse_register
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x17cabdb8	mtd_device_unregister
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x38625bc5	mtd_get_device_size
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x3e956c52	mtd_is_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x40dd57eb	mtd_kmalloc_up_to
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x532f8ac1	register_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5717685e	mtd_lock_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x5dd33aec	mtd_get_user_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6a6c9512	unregister_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x6aa35f35	mtd_del_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x76fc34c0	mtd_writev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x77ca388d	mtd_read
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7a3ac319	mtd_add_partition
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x7b6097ea	mtd_read_oob
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8a66e973	mtd_unlock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8a708053	mtd_read_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8c4cd314	put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x8f1e0379	get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x905ef029	mtd_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x919fed08	mtd_erase
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x99e3f407	mtd_table_mutex
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0x9b29dc5a	get_mtd_device_nm
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa23b9ca0	mtd_point
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa34ad8e7	mount_mtd
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xa699df88	__put_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xaa61e5df	mtd_unpoint
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xc41767d6	deregister_mtd_parser
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcb8d6afe	mtd_write_user_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcd28a216	mtd_read_fact_prot_reg
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xcef7bce3	mtd_get_fact_prot_info
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd0f45bb8	__get_mtd_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd329f196	mtd_lock
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd5ca0791	mtd_block_markbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd6b525e6	register_mtd_user
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xd7784d3e	mtd_block_isbad
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdcd7d64a	mtd_panic_write
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xdf4a4ecf	kill_mtd_super
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xe27c30e0	mtd_is_locked
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf337177c	mtd_erase_callback
++EXPORT_SYMBOL_GPL drivers/mtd/mtd 0xf4b30dfb	__mtd_next_device
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x1070a63e	deregister_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x6bc5c164	mtd_blktrans_cease_background
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0x6cdac767	add_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xb46b548f	del_mtd_blktrans_dev
++EXPORT_SYMBOL_GPL drivers/mtd/mtd_blkdevs 0xf4589476	register_mtd_blktrans
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x64c52d5e	nand_update_bbt
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0x836fde53	nand_wait_ready
++EXPORT_SYMBOL_GPL drivers/mtd/nand/nand 0xcf72bf7c	nand_release
++EXPORT_SYMBOL_GPL drivers/mtd/nand/sm_common 0xda1cd2de	sm_register_device
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xdf72cb7d	onenand_release
++EXPORT_SYMBOL_GPL drivers/mtd/onenand/onenand 0xf5ae9eae	onenand_scan
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x01621bfd	ubi_open_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x08325044	ubi_leb_unmap
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x0c19b252	ubi_open_volume_nm
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x146b50ac	ubi_do_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x214bb855	ubi_leb_map
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x2353b989	ubi_leb_erase
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x3743338c	ubi_leb_read
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x38e10c1d	ubi_flush
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x42801d20	ubi_sync
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x4bcbea35	ubi_close_volume
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x56c51f85	ubi_leb_change
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x5cfdd22d	ubi_get_device_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x85a8ee76	ubi_unregister_volume_notifier
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0x871087ed	ubi_open_volume_path
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xb8fea96e	ubi_get_volume_info
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xbe005706	ubi_is_mapped
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xce7fe586	ubi_leb_write
++EXPORT_SYMBOL_GPL drivers/mtd/ubi/ubi 0xf5ee9ba8	ubi_register_volume_notifier
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x6171426e	unregister_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x717e4605	c_can_power_up
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0x73726335	free_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xc645f2dd	register_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xf8590af1	alloc_c_can_dev
++EXPORT_SYMBOL_GPL drivers/net/can/c_can/c_can 0xf8fe69ee	c_can_power_down
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x0b50ba63	alloc_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x222c295a	can_len2dlc
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x39adcb7d	safe_candev_priv
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5b011193	free_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x5f19b16f	can_led_event
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x8defc070	can_put_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0x9f145f61	alloc_can_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xa6b97b40	can_get_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xab1069ad	devm_can_led_init
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xaf6e424b	close_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xb346573b	can_dlc2len
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xbedf0a6a	open_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc449a362	register_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc4a831ef	unregister_candev
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xc610eda6	alloc_can_err_skb
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xca1f1662	can_bus_off
++EXPORT_SYMBOL_GPL drivers/net/can/can-dev 0xee6b4cee	can_free_echo_skb
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x084e43df	register_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x5bd8913b	unregister_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0x9d8c3187	alloc_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/cc770/cc770 0xef109a62	free_cc770dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x141263f0	alloc_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x3e330088	unregister_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x49ebd0d2	sja1000_interrupt
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0x6cfcd60e	register_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/can/sja1000/sja1000 0xc2988bd5	free_sja1000dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x0db58456	macb_get_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x24746bc9	macb_get_stats
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x30063266	macb_set_rx_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0x5513d079	macb_ethtool_ops
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xb91eeb2e	macb_set_hwaddr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xcb16fb82	macb_ioctl
++EXPORT_SYMBOL_GPL drivers/net/ethernet/cadence/macb 0xd97dd7a1	macb_mii_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x01e838b0	mlx4_bf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x02519b7c	mlx4_get_vf_config
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x10fa43a3	mlx4_xrcd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x12a12653	mlx4_cq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x15155fb0	mlx4_srq_arm
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x18a978b9	mlx4_pd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1d15d4e6	mlx4_flow_steer_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x1de21a27	mlx4_unicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23d94369	mlx4_qp_release_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x23daac28	mlx4_mw_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x253195b0	mlx4_unregister_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x27970ebe	mlx4_qp_reserve_range
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2bc70f49	mlx4_SYNC_TPT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2c55a579	mlx4_flow_steer_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f7a7c1f	mlx4_CLOSE_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x2f7e9823	mlx4_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x30850427	mlx4_wol_read
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3374a961	mlx4_mw_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x390157d5	mlx4_INIT_PORT
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x39399234	mlx4_qp_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3ab34589	mlx4_cq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3b325de9	mlx4_cq_resize
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x3def86c9	mlx4_srq_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x474a3299	mlx4_fmr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x47eb23c3	mlx4_mtt_addr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x48bdc007	mlx4_fmr_unmap
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4bdb811a	mlx4_unicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x4d56ab46	mlx4_uar_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x519e8c90	mlx4_find_cached_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x536da30d	mlx4_alloc_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x54961164	mlx4_buf_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x5adfbb51	mlx4_register_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6a81eda1	mlx4_multicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6c27130f	mlx4_counter_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x6fdb401f	mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x771c7719	mlx4_srq_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78830fcc	__mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x78e68010	mlx4_srq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7a0a54b3	__mlx4_cmd
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7bb65bbb	mlx4_hw_rule_sz
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7cf1fd5b	mlx4_mr_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x7f463db6	mlx4_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81a8c389	mlx4_set_vf_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x81f6f0c8	mlx4_read_clock
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x82cc506d	mlx4_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x832d272d	mlx4_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x83766c8d	mlx4_get_protocol_dev
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x85c57ad3	mlx4_flow_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x883a9d3b	mlx4_unicast_promisc_add
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x89fe0d2c	mlx4_write_mtt
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8c33a48a	mlx4_multicast_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x8eb4a7e6	__mlx4_replace_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x94a772eb	mlx4_set_vf_spoofchk
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9bc7dc53	mlx4_wol_write
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9cdc5248	mlx4_map_sw_to_hw_steering_mode
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0x9db68b45	mlx4_qp_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa00e06be	mlx4_fmr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa1eb38c6	mlx4_pd_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xa4f7f95e	mlx4_mr_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xab67c7ae	mlx4_uar_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xac59fa5b	mlx4_map_sw_to_hw_steering_id
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb13b7a1c	mlx4_fmr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb22d63f3	mlx4_set_vf_link_state
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb3e68b89	mlx4_get_base_qpn
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb7fa7ae7	mlx4_mw_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xb96effcb	mlx4_unregister_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbaec8973	mlx4_mr_enable
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbb1be210	mlx4_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbc6a4536	mlx4_cq_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf17cbcb	mlx4_free_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xbf2fa96e	mlx4_set_vf_vlan
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc03da347	mlx4_map_phys_fmr
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc2aa9eae	mlx4_qp_to_ready
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc50cd670	mlx4_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xc8d3af2c	mlx4_multicast_promisc_remove
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xcb7b8a2e	mlx4_flow_attach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xce6b7deb	mlx4_bf_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd7db122f	mlx4_mtt_init
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xd8e90a1b	mlx4_register_interface
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe1846efd	mlx4_qp_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe3cfd3ad	mlx4_free_cmd_mailbox
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe599d129	mlx4_srq_lookup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6543b05	mlx4_unicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xe6b89d8d	mlx4_counter_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xece1b1dc	mlx4_multicast_detach
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf03a6a12	mlx4_alloc_hwq_res
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf1541dd2	__mlx4_register_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xf829fc95	mlx4_mtt_cleanup
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xfad73b69	mlx4_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx4/mlx4_core 0xff23e5c7	mlx4_unregister_mac
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2c81165b	mlx5_set_port_caps
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2dc9bc83	mlx5_buf_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x2f86e8aa	mlx5_core_qp_modify
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x346d4c31	mlx5_core_access_reg
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x3f3e5702	mlx5_destroy_unmap_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x485c4385	mlx5_core_eq_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x53274f99	mlx5_core_xrcd_dealloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x555e087a	mlx5_db_free
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x5ad07503	mlx5_core_create_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0x91435523	mlx5_core_qp_query
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb0ad58b4	mlx5_core_xrcd_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xb5412949	mlx5_db_alloc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcb138843	mlx5_create_map_eq
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xce01c2b7	mlx5_core_mad_ifc
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xcfe6478d	mlx5_core_destroy_qp
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xd6c4ef56	mlx5_fill_page_array
++EXPORT_SYMBOL_GPL drivers/net/ethernet/mellanox/mlx5/core/mlx5_core 0xee4b6455	mlx5_buf_alloc
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x231f0a77	macvlan_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x591fdf46	macvlan_common_setup
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0x81a33de4	macvlan_common_newlink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xc9278acf	macvlan_dellink
++EXPORT_SYMBOL_GPL drivers/net/macvlan 0xda474bb3	macvlan_link_register
++EXPORT_SYMBOL_GPL drivers/net/macvtap 0x78f46962	macvtap_get_socket
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0x628c6d58	usbnet_generic_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xa8b78b22	usbnet_cdc_status
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xc75449ac	usbnet_cdc_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ether 0xf02c099e	usbnet_cdc_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x17ddcc83	cdc_ncm_rx_verify_nth16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x2d07e5d0	cdc_ncm_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x3354253c	cdc_ncm_rx_verify_ndp16
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x4c50ce82	cdc_ncm_fill_tx_frame
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0x8146ddda	cdc_ncm_bind_common
++EXPORT_SYMBOL_GPL drivers/net/usb/cdc_ncm 0xc9147e43	cdc_ncm_select_altsetting
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x0a4ccb54	generic_rndis_bind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x5344caa3	rndis_rx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0x713b806d	rndis_tx_fixup
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xc294498e	rndis_unbind
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd078a6a7	rndis_command
++EXPORT_SYMBOL_GPL drivers/net/usb/rndis_host 0xd4ba63da	rndis_status
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x013006f3	usbnet_set_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0177c1d5	usbnet_write_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0dc6c715	usbnet_get_link
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x0f918275	usbnet_read_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x144f8cff	usbnet_get_endpoints
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x14b09045	usbnet_skb_return
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x2079bb08	usbnet_disconnect
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x21453c88	usbnet_nway_reset
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x226e5b2d	usbnet_get_msglevel
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3aad13df	usbnet_tx_timeout
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x3d69a8e1	usbnet_resume
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x5f0d1207	usbnet_purge_paused_rxq
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x66a25cce	usbnet_probe
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x67bcd723	usbnet_suspend
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x685770dd	usbnet_read_cmd
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x75fb0ce8	usbnet_get_ethernet_addr
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7b08fb32	usbnet_get_drvinfo
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7b46f918	usbnet_start_xmit
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7ba9f75f	usbnet_get_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x7fc4c85a	usbnet_resume_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x88cce7b2	usbnet_write_cmd_nopm
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9135727d	usbnet_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0x9d00c5e2	usbnet_defer_kevent
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xaa53fb00	usbnet_unlink_rx_urbs
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xb45b11b6	usbnet_set_settings
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xbffc0aca	usbnet_write_cmd_async
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xc2fa5d6d	usbnet_pause_rx
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xcef545e3	usbnet_status_stop
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xdb66a289	usbnet_status_start
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf2287b39	usbnet_open
++EXPORT_SYMBOL_GPL drivers/net/usb/usbnet 0xf5c03cb1	usbnet_change_mtu
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x08bbd464	i2400m_tx_msg_sent
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x58543a62	i2400m_rx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5baca1f1	i2400m_tx_msg_get
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x5f9a34fa	i2400m_init
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x851bd824	i2400m_error_recovery
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x888881cd	i2400m_is_boot_barker
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0x987636e0	i2400m_pre_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa317cd47	i2400m_post_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xa7463a06	i2400m_cmd_enter_powersave
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xafc7fa46	i2400m_dev_reset_handle
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb00b793c	i2400m_bm_cmd_prepare
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xb5759c4d	i2400m_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xbe7634e2	i2400m_release
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc113e7b1	i2400m_netdev_setup
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xc8b75425	i2400m_reset
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xce1ed3c6	i2400m_tx
++EXPORT_SYMBOL_GPL drivers/net/wimax/i2400m/i2400m 0xd9d864fd	i2400m_dev_bootstrap
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x1eedcd5a	cw1200_core_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x5f1bb891	cw1200_can_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x6a1d501b	cw1200_core_release
++EXPORT_SYMBOL_GPL drivers/net/wireless/cw1200/cw1200_core 0x8b3e89ae	cw1200_irq_handler
++EXPORT_SYMBOL_GPL drivers/net/wireless/ipw2x00/libipw 0x8efc57b8	libipw_rx_any
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x1f1f978c	il_mac_tx_last_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0x4f9c80b0	il_remove_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xb66c8c8d	il_prep_station
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xd50c7cfc	il_dealloc_bcast_stations
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlegacy/iwlegacy 0xffbfcb4e	_il_grab_nic_access
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x0f7c8b4a	__iwl_warn
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1418c854	__iwl_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x14ef36a6	iwl_clear_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x1ad388de	iwl_poll_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x215daec5	iwl_abort_notification_waits
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x225cc9f3	iwl_read_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x35033c81	iwl_phy_db_free
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3e0dc6e3	iwl_notification_wait_notify
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x3ecb0240	iwl_set_bits_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4dfe091a	iwl_parse_nvm_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x4e119bad	iwl_set_bits_mask_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a04e855	iwl_nvm_check_version
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5a339924	__iwl_err
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5c52e109	iwl_opmode_deregister
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5d0a212e	iwlwifi_mod_params
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x5fe37fd7	iwl_read_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x60236ff5	__iwl_crit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x6101306b	iwl_init_notification_wait
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x73041f51	iwl_poll_direct_bit
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x730cd234	iwl_parse_eeprom_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x776221bf	iwl_send_phy_db_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x77d7af6f	iwl_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x7b10ebd7	iwl_notification_wait_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8c5d5ab3	iwl_phy_db_set_section
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0x8caceb62	iwl_wait_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xa60912ef	iwl_phy_db_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xcea0b361	iwl_remove_notification
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xd2a0e1ef	iwl_write_prph
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe4896d71	__iwl_dbg
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xe74c9dfb	iwl_opmode_register
++EXPORT_SYMBOL_GPL drivers/net/wireless/iwlwifi/iwlwifi 0xf0a1e170	iwl_write_direct32
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x08b005a2	lbs_start_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x0bb0a92d	lbs_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x337311a8	lbs_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x57b12e1b	lbs_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5f9b3c09	lbs_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x5fdf38b8	lbs_disablemesh
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x720ac0b2	lbs_notify_command_response
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x74989d93	__lbs_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x7ef55c2f	lbs_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x838a8db8	lbs_queue_event
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0x97c1fb4d	lbs_get_firmware_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa60195b0	lbs_get_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xa7971dbc	lbs_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xbb61975a	lbs_process_rxed_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xe511e519	lbs_host_to_card_done
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xeed74006	lbs_host_sleep_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf5aca983	lbs_stop_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas/libertas 0xf64277de	lbs_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x1c0d0540	lbtf_bcn_sent
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x3cc4231f	lbtf_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x51d8ce9c	lbtf_cmd_response_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x80108041	lbtf_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x820ab170	__lbtf_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0x9b3c64ac	lbtf_cmd_copyback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xba362cf1	lbtf_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xc85e6899	lbtf_debug
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf 0xddd48e40	lbtf_send_tx_feedback
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0x721d41cb	if_usb_prog_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/libertas_tf/libertas_tf_usb 0xf8d33277	if_usb_reset_device
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x063c7651	mwifiex_add_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x217d7ebb	mwifiex_handle_rx_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x267dbac6	mwifiex_main_process
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x51ec0ed7	mwifiex_remove_card
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x608936fb	mwifiex_deauthenticate
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x6c012279	mwifiex_write_data_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x928c6441	mwifiex_del_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0x930d66c2	mwifiex_process_sleep_confirm_resp
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xa351020e	mwifiex_enable_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xa8e15714	mwifiex_process_hs_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbcf1b7d8	mwifiex_init_shutdown_fw
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xbdb86def	mwifiex_cancel_hs
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xe849a974	mwifiex_add_virtual_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/mwifiex/mwifiex 0xf4c3c382	mwifiex_disable_auto_ds
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x05b89de7	p54_unregister_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x12873f0c	p54_free_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x279f3b1a	p54_rx
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x38c613e3	p54_read_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x5e203932	p54_register_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x67286006	p54_init_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0x8eb6281c	p54_parse_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xd16f5e4a	p54_free_common
++EXPORT_SYMBOL_GPL drivers/net/wireless/p54/p54common 0xdbc9a4b7	p54_parse_eeprom
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0b5c706b	rt2800_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x0e2d4afe	rt2800_config_ant
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x13d97fdc	rt2800_enable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x18887976	rt2800_get_survey
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1999326f	rt2800_check_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1aef735d	rt2800_get_tsf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1b1bb1b2	rt2800_read_eeprom_efuse
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x1ec62ba8	rt2800_get_tkip_seq
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x2769489a	rt2800_write_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3e2250ca	rt2800_disable_wpdma
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x3f797360	rt2800_reset_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x4153de30	rt2800_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x44e3952a	rt2800_process_rxwi
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x464057f1	rt2800_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x46851b94	rt2800_load_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x48d0692d	rt2800_mcu_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x49f57e69	rt2800_config_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x50a3217f	rt2800_write_tx_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x58f77a69	rt2800_probe_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5aa0d191	rt2800_efuse_detect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5e738a3b	rt2800_wait_csr_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x5faeb588	rt2800_vco_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x63329232	rt2800_config_pairwise_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x6f2ae6b7	rt2800_set_rts_threshold
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x761adb75	rt2800_link_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7aa88e89	rt2800_wait_wpdma_ready
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x7aad090a	rt2800_gain_calibration
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8272c380	rt2800_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x8beb04a1	rt2800_clear_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9595e5d3	rt2800_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9a840a6c	rt2800_txdone_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0x9b2f0b51	rt2800_config_erp
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xa0c958de	rt2800_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xb7439d50	rt2800_link_tuner
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd3eabfc5	rt2800_ampdu_action
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xd76c3ee8	rt2800_config_shared_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2800lib 0xffa71ed4	rt2800_config_intf
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0c2e74b3	rt2x00queue_start_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x0c8b9669	rt2x00queue_start_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x130ea770	rt2x00mac_set_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1375a6f8	rt2x00lib_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x16c02149	rt2x00lib_beacondone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x16c1d7aa	rt2x00mac_rfkill_poll
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x1f4fce9b	rt2x00queue_for_each_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x250de92c	rt2x00queue_pause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x28bd98c7	rt2x00mac_set_tim
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2c27bb2e	rt2x00mac_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x2e7e0a77	rt2x00lib_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x30cd0275	rt2x00mac_sw_scan_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x38b7274a	rt2x00mac_add_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x4effe6b5	rt2x00lib_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x52188403	rt2x00queue_flush_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x56260a9b	rt2x00queue_stop_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x59d2437e	rt2x00mac_get_ringparam
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5c835c5f	rt2x00mac_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5d228075	rt2x00queue_unpause_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x5fc74a1f	rt2x00queue_stop_queues
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7b5d808b	rt2x00mac_bss_info_changed
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x7bd099f1	rt2x00mac_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x8800f477	rt2x00lib_dmadone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x89ca8c24	rt2x00lib_dmastart
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x930edbfe	rt2x00mac_sta_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0x9b8f306c	rt2x00queue_get_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xa425add2	rt2x00lib_txdone_noinfo
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xaa5e8631	rt2x00mac_start
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb2432218	rt2x00queue_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb6f2125d	rt2x00queue_map_txskb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb8a317a6	rt2x00lib_pretbtt
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xb8f078da	rt2x00mac_get_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xba10edc7	rt2x00mac_get_antenna
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xbd5d8e1f	rt2x00mac_sw_scan_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xc24aa3d1	rt2x00mac_conf_tx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcb2c8131	rt2x00mac_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xcba44a0e	rt2x00mac_remove_interface
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd1347a8d	rt2x00lib_txdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xd2ee9220	rt2x00queue_unmap_skb
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xde79d04c	rt2x00mac_configure_filter
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe27e582c	rt2x00mac_sta_add
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xe36f40cb	rt2x00mac_stop
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xf567c50a	rt2x00mac_tx_frames_pending
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfb5669b8	rt2x00lib_get_bssidx
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xfde2e544	rt2x00lib_remove_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00lib 0xffe80a80	rt2x00lib_probe_dev
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x4a716061	rt2x00mmio_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x5ec09ed2	rt2x00mmio_rxdone
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x619d63c2	rt2x00mmio_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0x7baf8e18	rt2x00mmio_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00mmio 0xd4e0cb24	rt2x00mmio_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x147ccd5c	rt2x00pci_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x4d706eb5	rt2x00pci_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0x99158625	rt2x00pci_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00pci 0xc01a7f66	rt2x00pci_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0f3fa2b9	rt2x00usb_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x0fdc38f1	rt2x00usb_vendor_request_buff
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x16186c35	rt2x00usb_vendor_request
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x34f22d14	rt2x00usb_kick_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x43d73a70	rt2x00usb_resume
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x65cea44a	rt2x00usb_suspend
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x6b8d5759	rt2x00usb_register_read_async
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0x9e43bc6a	rt2x00usb_disconnect
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xa1028ff7	rt2x00usb_watchdog
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xb719235e	rt2x00usb_regbusy_read
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd075d5f1	rt2x00usb_disable_radio
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xd84f194d	rt2x00usb_initialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xdee06c2f	rt2x00usb_clear_entry
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xe55a015f	rt2x00usb_uninitialize
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xee89a239	rt2x00usb_flush_queue
++EXPORT_SYMBOL_GPL drivers/net/wireless/rt2x00/rt2x00usb 0xf3b01980	rt2x00usb_vendor_req_buff_lock
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtl8192c/rtl8192c-common 0x45e2abff	rtl92c_set_p2p_ps_offload_cmd
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x241dedc1	rtl_tid_to_ac
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x2ba1bc2a	rtl_ips_nic_on
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x48e2dc62	read_efuse_byte
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x4c517b19	rtl_is_special_data
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x5da36231	rtl_beacon_statistic
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x613e9f2b	rtl_global_var
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x66e85ebc	rtl_action_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x67d4c0cb	rtl_ops
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x7197e7e5	rtl_deinit_rfkill
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x743f8a74	rtl_deinit_deferred_work
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x7a8c15ef	rtl_dbgp_flag_init
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x7bce096b	rtl_swlps_beacon
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x91e159c0	rtl_p2p_info
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0x95175589	rtl_tx_mgmt_proc
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xa4dd6969	rtl_init_rx_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xcce3adca	rtl_recognize_peer
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xd06840bc	rtl_deinit_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xd4649e90	rtl_init_core
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xf8ff6add	rtl_lps_change_work_callback
++EXPORT_SYMBOL_GPL drivers/net/wireless/rtlwifi/rtlwifi 0xfdceab5e	rtl_attribute_group
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x4ec014fe	wl1251_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0x8796f8c5	wl1251_init_ieee80211
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wl1251/wl1251 0xafdbfbc1	wl1251_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x05294fba	wl1271_format_buffer
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x1869f730	wlcore_event_rssi_trigger
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x21b4d8b0	wlcore_event_soft_gemini_sense
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x28ded173	wlcore_boot_upload_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x2f5ca7c3	wlcore_translate_addr
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x30307e07	wlcore_event_inactive_sta
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x33c92a2a	wl1271_acx_pm_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3b54fcfb	wlcore_cmd_wait_for_event_or_timeout
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x3dcd60d6	wlcore_event_max_tx_failure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x41ed6d25	wlcore_enable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x474475fe	wlcore_alloc_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x4d786ca3	wl1271_cmd_data_path
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x53dff67d	wl12xx_debug_level
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x58082557	wlcore_synchronize_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x5efddc21	wlcore_event_dummy_packet
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x64070234	wl1271_tx_flush
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x76600a14	wlcore_remove
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x78af3034	wl12xx_cmd_build_probe_req
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x83fd004a	wl1271_cmd_test
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x862e7b46	wlcore_free_hw
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8867c8e8	wlcore_boot_upload_nvs
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8d60c049	wlcore_disable_interrupts_nosync
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8dd32b80	wl1271_acx_init_mem_config
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x8e03f535	wl1271_acx_set_ht_capabilities
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x994aff3e	wlcore_scan_sched_scan_ssid_list
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0x99acdb01	wl1271_debugfs_update_stats
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa023f3e6	wlcore_event_beacon_loss
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa165acd6	wlcore_boot_run_firmware
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xa7c6c8ff	wlcore_disable_interrupts
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb05883b2	wlcore_event_channel_switch
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xb4be5182	wl1271_cmd_configure
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xbc55a9be	wlcore_probe
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc4fb7a6e	wl1271_acx_sleep_auth
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xc6d81565	wlcore_set_partition
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd46c0b0c	wlcore_scan_sched_scan_results
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xd59a2369	wlcore_event_ba_rx_constraint
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdb58a7e0	wlcore_event_sched_scan_completed
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xdc624139	wlcore_set_key
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe410992b	wl1271_tx_min_rate_get
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xe836d897	wl1271_cmd_send
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xeec190bc	wl12xx_acx_mem_cfg
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xf97bd0a9	wlcore_event_roc_complete
++EXPORT_SYMBOL_GPL drivers/net/wireless/ti/wlcore/wlcore 0xfdeaf0ff	wlcore_set_scan_chan_params
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x3b577068	nfc_mei_phy_disable
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x6e22f29d	mei_phy_ops
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0x8b4e7b3b	nfc_mei_event_cb
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xcad34158	nfc_mei_phy_free
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xe2506b38	nfc_mei_phy_alloc
++EXPORT_SYMBOL_GPL drivers/nfc/mei_phy 0xe82e19a5	nfc_mei_phy_enable
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x591661a5	asus_wmi_unregister_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/asus-wmi 0x5af59c68	asus_wmi_register_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/intel_ips 0x46809fa9	ips_link_to_i915_driver
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x232b5238	mxm_wmi_supported
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0x61cdf799	mxm_wmi_call_mxds
++EXPORT_SYMBOL_GPL drivers/platform/x86/mxm-wmi 0xe26032eb	mxm_wmi_call_mxmx
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x3ecf6cfc	wmi_install_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0x64ebe677	wmi_query_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xa9b7afd8	wmi_set_block
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xb5a6ebe2	wmi_remove_notify_handler
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc5e3dddf	wmi_get_event_data
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xc9d4d6d1	wmi_has_guid
++EXPORT_SYMBOL_GPL drivers/platform/x86/wmi 0xe2426710	wmi_evaluate_method
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x1b1b4d61	pcf50633_mbc_get_usb_online_status
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x8f825476	pcf50633_mbc_usb_curlim_set
++EXPORT_SYMBOL_GPL drivers/power/pcf50633-charger 0x9f51676a	pcf50633_mbc_get_status
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0x56ab0e26	mc13xxx_fixed_regulator_set_voltage
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xd39b1ad6	mc13xxx_fixed_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/mc13xxx-regulator-core 0xdaef4c50	mc13xxx_regulator_ops
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x272a71bf	wm8350_dcdc_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x2ecad097	wm8350_dcdc25_set_mode
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x6e8a8510	wm8350_register_led
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0x73fa7525	wm8350_ldo_set_slot
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xb4aeec96	wm8350_register_regulator
++EXPORT_SYMBOL_GPL drivers/regulator/wm8350-regulator 0xb5678a66	wm8350_isink_set_flash
++EXPORT_SYMBOL_GPL drivers/regulator/wm8400-regulator 0x3f939196	wm8400_register_regulator
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x00439d34	cxgbi_get_conn_stats
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x026f0e50	cxgbi_iscsi_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0f6974c2	cxgbi_device_portmap_create
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x0fd9151a	cxgbi_device_register
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1a70a638	cxgbi_ep_connect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x1e5cd5c3	cxgbi_get_ep_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x215d55f4	cxgbi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x28823d20	cxgbi_sock_closed
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x2a1f1802	cxgbi_sock_rcv_close_conn_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x30277ad4	cxgbi_hbas_add
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3296d930	cxgbi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3a5c4389	cxgbi_ddp_page_size_factor
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x3df003d6	cxgbi_sock_rcv_wr_ack
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x445e5587	cxgbi_sock_select_mss
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4be7c97c	cxgbi_iscsi_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x4c546ffa	cxgbi_device_portmap_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x513760a0	cxgbi_device_find_by_lldev
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x51651b9a	cxgbi_ddp_init
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x5de4c033	cxgbi_sock_skb_entail
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x61616f87	cxgbi_get_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6b55f8d5	cxgbi_sock_free_cpl_skbs
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6e9a6e69	cxgbi_set_host_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x6f5f7d70	cxgbi_sock_rcv_peer_close
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x71c8e16b	cxgbi_conn_alloc_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x79bb5459	cxgbi_sock_fail_act_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7ec1c8e5	cxgbi_device_unregister
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x7fdb6004	cxgbi_device_unregister_all
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x827ab026	cxgbi_conn_init_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8353a936	cxgbi_hbas_remove
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x83a7f8f4	cxgbi_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x897f9421	cxgbi_sock_established
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8a12a2c4	cxgbi_sock_check_wr_invariants
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x8c2ba369	cxgbi_ddp_ppod_clear
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x95b7504e	cxgbi_conn_pdu_ready
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9a35ba0e	cxgbi_ep_disconnect
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9bd4e986	cxgbi_ddp_cleanup
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0x9f11bcf4	cxgbi_sock_rcv_abort_rpl
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xa4ed0609	cxgbi_parse_pdu_itt
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xad7edbd2	cxgbi_ddp_ppod_set
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xc70f8fc0	cxgbi_set_conn_param
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xd0aba285	cxgbi_conn_xmit_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xda6b54a8	cxgbi_conn_tx_open
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xded8d21a	cxgbi_sock_act_open_req_arp_failure
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe10a49e9	cxgbi_ep_poll
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe64a7dfb	cxgbi_bind_conn
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe7f06710	cxgbi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xe89fd4eb	cxgbi_sock_purge_wr_queue
++EXPORT_SYMBOL_GPL drivers/scsi/cxgbi/libcxgbi 0xef346615	cxgbi_attr_is_visible
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x593a36c2	scsi_dh_handler_exist
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x5cd5e742	scsi_dh_set_params
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x6d096ced	scsi_unregister_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x7c07b04e	scsi_dh_detach
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0x8b1f0951	scsi_dh_attached_handler_name
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xbef29b7f	scsi_register_device_handler
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xef3f90cd	scsi_dh_activate
++EXPORT_SYMBOL_GPL drivers/scsi/device_handler/scsi_dh 0xf09c3ec9	scsi_dh_attach
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x0fb51275	fcoe_queue_timer
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x1d08308b	fcoe_ctlr_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x2a829dc5	fcoe_ctlr_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x371652be	fcoe_link_speed_update
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x374c1e1c	fcoe_wwn_from_mac
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x43fc774a	fcoe_get_wwn
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4b3867e2	fcoe_validate_vport_create
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x4b56168c	fcoe_fcf_device_delete
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x5daf4af9	fcoe_clean_pending_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x7f2fd27c	fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x84b3d915	fcoe_wwn_to_str
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x8db77ac2	__fcoe_get_lesb
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x92efa338	fcoe_fc_crc
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0x99062e2d	fcoe_libfc_config
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xae13b416	fcoe_check_wait_queue
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xbe01b521	fcoe_ctlr_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xc44f056e	fcoe_get_paged_crc_eof
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xcecf0c74	fcoe_start_io
++EXPORT_SYMBOL_GPL drivers/scsi/fcoe/libfcoe 0xedb96a5e	fcoe_fcf_device_add
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x0aeb8ce4	iscsi_boot_create_target
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x58904f84	iscsi_boot_create_host_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x678aa4fa	iscsi_boot_create_ethernet
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0x71db3963	iscsi_boot_destroy_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xb9a68010	iscsi_boot_create_kset
++EXPORT_SYMBOL_GPL drivers/scsi/iscsi_boot_sysfs 0xe8f475ae	iscsi_boot_create_initiator
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x02c60225	iscsi_session_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x08d42e5a	iscsi_conn_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0d7696a3	iscsi_itt_to_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x0ec7edb0	iscsi_session_recovery_timedout
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x12b2ad06	iscsi_switch_str_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x19b4a946	iscsi_session_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x1c8e040c	iscsi_conn_start
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x20cefb31	iscsi_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x259a8f10	iscsi_host_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x2eb88f8b	iscsi_pool_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x36b2d418	iscsi_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x3fa43aac	iscsi_update_cmdsn
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4298254b	iscsi_conn_get_addr_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x432393d1	iscsi_host_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x4ce77328	iscsi_session_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x52125295	iscsi_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x5683ff26	iscsi_requeue_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x63ac0101	iscsi_itt_to_ctask
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x66f463b8	iscsi_host_remove
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x6b6078e8	iscsi_eh_target_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x71704a5d	iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x7aaeeb62	iscsi_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x889c4ad2	iscsi_host_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x9083767d	iscsi_host_add
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x930b38ad	iscsi_eh_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0x95061e1a	iscsi_complete_scsi_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa05eadab	iscsi_verify_itt
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4832cf0	iscsi_pool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa4e134a5	iscsi_suspend_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa5921e1f	iscsi_set_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xa6e60392	iscsi_session_failure
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xb17afbfa	iscsi_conn_queue_work
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xbbecdc37	iscsi_conn_bind
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xc9b4465f	iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xce6e3c47	iscsi_conn_send_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xce733d84	__iscsi_put_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xdffdef39	iscsi_eh_recover_target
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe2e65cbe	iscsi_conn_stop
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xe5cf82cb	iscsi_conn_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xeb9148c1	iscsi_host_get_param
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xecd58afa	iscsi_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xef74ac22	iscsi_suspend_tx
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf349cbfd	iscsi_eh_session_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xf845c2d5	__iscsi_get_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfd798d08	iscsi_eh_device_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xfe7192d7	iscsi_prep_data_out_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi 0xff2d0580	__iscsi_complete_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x1405f8a9	iscsi_tcp_segment_unmap
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x2b5a8897	iscsi_tcp_recv_segment_is_hdr
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x3dbf172d	iscsi_tcp_recv_skb
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x4d4d0204	iscsi_tcp_conn_teardown
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6a4d55e8	iscsi_segment_seek_sg
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x6cd256a6	iscsi_segment_init_linear
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x702b9c65	iscsi_tcp_conn_get_stats
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x71fb83c8	iscsi_tcp_conn_setup
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0x99edc7c4	iscsi_tcp_dgst_header
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xac518278	iscsi_tcp_cleanup_task
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xc2eae208	iscsi_tcp_r2tpool_free
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xca4842b0	iscsi_tcp_set_max_r2t
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xdfada068	iscsi_tcp_r2tpool_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe44efdf6	iscsi_tcp_task_xmit
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe4eec901	iscsi_tcp_segment_done
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xe91ae692	iscsi_tcp_task_init
++EXPORT_SYMBOL_GPL drivers/scsi/libiscsi_tcp 0xf6553714	iscsi_tcp_hdr_recv_prep
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x09ae389b	sas_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x138a03a4	sas_request_addr
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x155b5d74	sas_change_queue_depth
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x180d88b9	sas_phy_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x22f7d5a4	sas_bios_param
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x29ee8f6f	sas_ata_schedule_reset
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x57994f4e	sas_domain_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x74482f86	sas_drain_work
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x844d2f6c	sas_task_abort
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x8aef63e7	sas_eh_bus_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x908ef6d7	sas_alloc_slow_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x96ab7259	sas_free_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9bf9ae07	sas_queuecommand
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0x9f60f00b	sas_eh_device_reset_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb13f03cf	sas_register_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xb9ed58eb	sas_ioctl
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xca76f303	sas_eh_abort_handler
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xd9d43c42	sas_change_queue_type
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xdaa3e9c0	sas_get_local_phy
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf14cec7a	sas_alloc_task
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xf48c6f51	sas_domain_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfc527064	sas_ssp_task_response
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfcd51e50	sas_slave_configure
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfe046718	sas_unregister_ha
++EXPORT_SYMBOL_GPL drivers/scsi/libsas/libsas 0xfea33a55	sas_target_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x4aa15157	srp_target_alloc
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x5af77e03	srp_target_free
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x6d2a0be3	srp_cmd_queue
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0x91bac7a3	srp_iu_get
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xd8cbb71b	srp_transfer_data
++EXPORT_SYMBOL_GPL drivers/scsi/libsrp 0xef6438bb	srp_iu_put
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x01c17761	scsi_tgt_tsk_mgmt_request
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x2b2a7583	scsi_tgt_alloc_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x415416d6	scsi_tgt_free_queue
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x6d927904	scsi_tgt_queue_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0x84a2bc71	scsi_host_put_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xac5c8327	scsi_tgt_it_nexus_destroy
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xb1556325	scsi_tgt_cmd_to_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xd55eb13e	scsi_tgt_it_nexus_create
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_tgt 0xde5c527f	scsi_host_get_command
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x07a4bb58	iscsi_conn_error_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x109950ab	iscsi_is_session_online
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x1e52f2ef	iscsi_destroy_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2059d6f8	iscsi_is_session_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x22e127fc	iscsi_offload_mesg
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x231f67e5	iscsi_destroy_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x282d1f7d	iscsi_session_chkready
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x2e90d121	iscsi_unblock_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x37f814e9	iscsi_find_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x40cb7a50	iscsi_ping_comp_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4479e5b9	iscsi_host_for_each_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x48202bd6	iscsi_create_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4ab870d4	iscsi_recv_pdu
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4ade6308	iscsi_create_iface
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4d71b1d3	iscsi_post_host_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4e288516	iscsi_create_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x4ffa1d23	iscsi_lookup_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x50e2e397	iscsi_destroy_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x585aade0	iscsi_remove_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x5a8521a7	iscsi_register_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x602c2a27	iscsi_scan_finished
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x615ed934	iscsi_get_port_speed_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x61a028d6	iscsi_is_flashnode_conn_dev
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x699fe53e	iscsi_get_discovery_parent_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x71dc6b90	iscsi_create_flashnode_sess
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x740c1083	iscsi_free_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x82df5420	iscsi_destroy_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x836d8df3	iscsi_session_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x85b613f9	iscsi_destroy_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0x907f9558	iscsi_get_port_state_name
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa3622aea	iscsi_block_scsi_eh
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa5084081	iscsi_alloc_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xa9478b84	iscsi_create_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xacf4232d	iscsi_conn_login_event
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb35b5420	iscsi_unregister_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xb71ee5bb	iscsi_block_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xc1454c3e	iscsi_add_session
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xcfe2ec6d	iscsi_create_endpoint
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xebca2860	iscsi_flashnode_bus_match
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf0c44d14	iscsi_find_flashnode_conn
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_iscsi 0xf8b48da8	iscsi_destroy_all_flashnode
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x34a3759c	sas_is_tlr_enabled
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x3d9da089	sas_enable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0x8c6dfb56	sas_disable_tlr
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_sas 0xacfad15a	sas_tlr_supported
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x2e53320b	srp_release_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x6308652b	srp_rport_add
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0x74095312	srp_attach_transport
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xa240b4e8	srp_remove_host
++EXPORT_SYMBOL_GPL drivers/scsi/scsi_transport_srp 0xb41f810f	srp_rport_del
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x135565f9	ufshcd_init
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0x85842482	ufshcd_remove
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xb565a7fc	ufshcd_suspend
++EXPORT_SYMBOL_GPL drivers/scsi/ufs/ufshcd 0xf8f51e37	ufshcd_resume
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x088d24a0	spi_bitbang_start
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x19c17e1c	spi_bitbang_setup_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x26152f73	spi_bitbang_setup
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x29960d27	spi_bitbang_transfer
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0x42967152	spi_bitbang_stop
++EXPORT_SYMBOL_GPL drivers/spi/spi-bitbang 0xcf5fc6ef	spi_bitbang_cleanup
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x0ecd2b0a	dw_spi_remove_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0x4909b33a	dw_spi_resume_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xe25afd6b	dw_spi_suspend_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xe80677ed	dw_spi_add_host
++EXPORT_SYMBOL_GPL drivers/spi/spi-dw 0xec1982b2	dw_spi_xfer_done
++EXPORT_SYMBOL_GPL drivers/ssb/ssb 0xe8240b16	ssb_pmu_spuravoid_pllupdate
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x03d8557c	comedi_pci_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x06d30a3b	comedi_dev_from_minor
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0964e2a2	comedi_buf_get
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0cd330f4	range_unknown
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0dcdd5d8	comedi_usb_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x0e73e64b	comedi_buf_read_n_available
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x195ddd54	comedi_to_pci_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x21102f87	range_0_32mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x218d4068	comedi_buf_write_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2cb88690	comedi_buf_put
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x2f0ad9d3	range_bipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x31e738f7	comedi_pcmcia_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x36440a52	comedi_pci_enable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x3e9b1823	comedi_pci_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4236eaaf	range_4_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x431ceb9b	comedi_buf_memcpy_to
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x49388f64	comedi_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x4fe634f3	range_bipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x50d305b1	comedi_pcmcia_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x558b41bf	comedi_event
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x58f49f20	comedi_alloc_subdevices
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x5f71c9e6	__comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x6c1d0630	comedi_buf_memcpy_from
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x7f477220	comedi_set_hw_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8113872c	range_unipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x82255aed	comedi_legacy_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8580639e	comedi_alloc_spriv
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x8da0475c	comedi_pcmcia_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x942406c8	comedi_pci_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x943243f9	comedi_pcmcia_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0x9d7be5e3	comedi_pcmcia_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa43a6417	comedi_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xa59088be	comedi_error
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xad4de9dc	comedi_buf_read_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xae27a2fb	comedi_request_region
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaec4be03	comedi_is_subdevice_running
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xaffcc45d	comedi_load_firmware
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb0dcba34	comedi_usb_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xb679cebc	range_0_20mA
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbb52fc7f	range_bipolar10
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbd7aad4d	comedi_pci_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xbdbe75c6	range_unipolar2_5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xc8dd2843	comedi_pcmcia_disable
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xcc2be8f4	comedi_to_usb_interface
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xdb2044b2	range_unipolar5
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe0578bee	comedi_auto_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe69a2571	comedi_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe76e3ecb	comedi_pci_driver_register
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xe9d095e1	comedi_usb_auto_unconfig
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xeadba404	comedi_buf_read_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf1eef094	comedi_to_pcmcia_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf655f69d	comedi_check_chanlist
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf90ee35a	comedi_buf_write_free
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xf9959275	comedi_usb_driver_unregister
++EXPORT_SYMBOL_GPL drivers/staging/comedi/comedi 0xfbfeaf36	comedi_to_usb_dev
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x5bd86b0c	subdev_8255_init_irq
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0x837df8d5	subdev_8255_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/8255 0xed405a8f	subdev_8255_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0x79f4a6cf	addi_watchdog_reset
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/addi_watchdog 0xf4066c49	addi_watchdog_init
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x22456c32	amplc_dio200_set_enhance
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x74803d2c	amplc_dio200_common_detach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/amplc_dio200_common 0x984b51ab	amplc_dio200_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0xa9a61d70	cfc_read_array_from_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0xae6a5e8f	cfc_write_array_to_buffer
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/comedi_fc 0xfcb6bd0d	cfc_handle_events
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/das08 0x853e549b	das08_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x02ed1068	mite_free_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x09756af1	mite_dma_tcr
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x1890bbbd	mite_unsetup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x2086e871	mite_bytes_written_to_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x320edee2	mite_bytes_read_from_memory_lb
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x3256667d	mite_setup
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x59757bdd	mite_release_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x65755f8d	mite_request_channel_in_range
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6c088bb5	mite_get_status
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x6e3273f6	mite_dma_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x85eb8741	mite_prep_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x86ff3c9c	mite_dma_disarm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x92b8c897	mite_sync_output_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0x93f504d8	mite_buf_change
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xbf12db93	mite_sync_input_dma
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xc6cd08d9	mite_bytes_in_transit
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xd6c1eba6	mite_setup2
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xdfcbe70c	mite_alloc_ring
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe0364fdb	mite_done
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe164992b	mite_alloc
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xe4925453	mite_bytes_written_to_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/mite 0xf61a62c0	mite_bytes_read_from_memory_ub
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_labpc 0x9659e546	labpc_common_attach
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x183ad89c	ni_tio_set_gate_src
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x29281622	ni_tio_arm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0x30c586b9	ni_tio_winsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xa64414fc	ni_gpct_device_destroy
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xabecaf46	ni_gpct_device_construct
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xb315106e	ni_tio_insn_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xbcefeb24	ni_tio_init_counter
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tio 0xe6b57953	ni_tio_rinsn
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x3b087e90	ni_tio_acknowledge_and_confirm
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x3cb10e5c	ni_tio_cmdtest
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x52385e67	ni_tio_handle_interrupt
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0x9afda570	ni_tio_cmd
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xd6d03664	ni_tio_cancel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/drivers/ni_tiocmd 0xf38ded27	ni_tio_set_mite_channel
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x055e2887	comedi_dio_config
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x21d8a761	comedi_dio_bitfield
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x25bf2307	comedi_find_subdevice_by_type
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0x6b43b20c	comedi_get_n_channels
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xc9cfae56	comedi_close
++EXPORT_SYMBOL_GPL drivers/staging/comedi/kcomedilib/kcomedilib 0xe2b6ea68	comedi_open
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x07cf130a	dwc2_hcd_remove
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x2206b003	dwc2_handle_common_intr
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0x70d58bb3	dwc2_hcd_init
++EXPORT_SYMBOL_GPL drivers/staging/dwc2/dwc2 0xa8514446	dwc2_set_all_params
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x1a1b5249	oslec_flush
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x2feda75b	oslec_hpf_tx
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x3227a28e	oslec_snapshot
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0x7dc9dddd	oslec_adaption_mode
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xb2c66001	oslec_create
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xc8b5a524	oslec_free
++EXPORT_SYMBOL_GPL drivers/staging/echo/echo 0xd370f679	oslec_update
++EXPORT_SYMBOL_GPL drivers/staging/iio/addac/adt7316 0x70d2679c	adt7316_pm_ops
++EXPORT_SYMBOL_GPL drivers/staging/rts5139/rts5139 0xbd5a0e51	rts5139_usb_ids
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x02a50259	synth_remove
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x042ea578	spk_do_catch_up
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x0e81c76d	spk_serial_out
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x14f06fe7	spk_serial_in_nowait
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x2a69e80a	spk_var_store
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x30dbca29	spk_var_show
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x41a160e5	synth_buffer_empty
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4449e1dd	synth_buffer_clear
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x475e158a	synth_request_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x4909dcd9	synth_add
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x5f23a9c8	speakup_event
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8e146195	synth_release_region
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x8fbdbbe2	spk_synth_flush
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x95c77e04	spk_serial_synth_probe
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0x9a888082	synth_buffer_getc
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xb48956f8	synth_buffer_peek
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xbbd15a51	speakup_start_ttys
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xc766ae09	synth_printf
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xcc0a408f	spk_synth_is_alive_restart
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xcce88dca	spk_synth_immediate
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xce56e8c5	speakup_info
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xd1b551a2	spk_get_var
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7cd4558	spk_serial_release
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xe7e810f8	spk_serial_in
++EXPORT_SYMBOL_GPL drivers/staging/speakup/speakup 0xf224788e	spk_synth_is_alive_nop
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x0ca06395	usbip_start_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x20cba9d0	usbip_recv_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x3df0d22b	usbip_alloc_iso_desc_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x496c4ad3	usbip_stop_eh
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x58e3c1ca	usbip_event_happened
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x653b3baa	usbip_recv_xbuff
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x7222e265	sockfd_to_socket
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x78b72f44	usbip_debug_flag
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x7b1d6767	usbip_dump_urb
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x8563a7e9	usbip_event_add
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0x89a60fb4	dev_attr_usbip_debug
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xb389930a	usbip_pad_iso
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xb6ddc64f	usbip_recv
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd02753dc	usbip_header_correct_endian
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xd3855a52	usbip_pack_pdu
++EXPORT_SYMBOL_GPL drivers/staging/usbip/usbip-core 0xe1ea0586	usbip_dump_header
++EXPORT_SYMBOL_GPL drivers/tty/n_tracesink 0x585ebaac	n_tracesink_datadrain
++EXPORT_SYMBOL_GPL drivers/uio/uio 0x168023b4	uio_event_notify
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xb273e1b2	uio_unregister_device
++EXPORT_SYMBOL_GPL drivers/uio/uio 0xf0fd47a1	__uio_register_device
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0x8980b104	usbatm_usb_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/atm/usbatm 0xe3151a0f	usbatm_usb_probe
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xbf4d8f8b	ci_hdrc_remove_device
++EXPORT_SYMBOL_GPL drivers/usb/chipidea/ci_hdrc 0xf9d4b1d0	ci_hdrc_add_device
++EXPORT_SYMBOL_GPL drivers/usb/dwc3/dwc3-omap 0x4db92025	dwc3_omap_mailbox
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x069030fb	config_ep_by_speed
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x074d7d80	usb_function_deactivate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x20407ba2	usb_add_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2b57e0a0	usb_add_config
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x2e09263f	usb_copy_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x37bdc33a	usb_assign_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x3faee7ce	usb_function_activate
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x4da78c88	usb_string_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x529fb20d	usb_free_all_descriptors
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5976de5b	usb_interface_id
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5b857260	usb_add_config_only
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x5cb780eb	usb_put_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x81dc6b05	usb_ep_autoconfig_ss
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x84a1e731	usb_remove_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x91957134	usb_function_register
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x94d7075a	usb_gadget_get_string
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x953d3806	usb_composite_setup_continue
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0x9d02d0d9	usb_composite_probe
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xa4873a48	usb_get_function
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xbf90a46e	usb_function_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xcd3b3774	usb_string_ids_n
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd2ea2134	usb_descriptor_fillbuf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd8a42e88	usb_ep_autoconfig_reset
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xd9b014d5	usb_composite_overwrite_options
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xda154e64	usb_ep_autoconfig
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe026e642	usb_string_ids_tab
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe304c7d2	usb_put_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xe39c8094	usb_gstrings_attach
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf474a207	usb_gadget_config_buf
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf64b5a09	usb_get_function_instance
++EXPORT_SYMBOL_GPL drivers/usb/gadget/libcomposite 0xf7e2a9e0	usb_composite_unregister
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x0881f894	gserial_connect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x2395ce04	gserial_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x33bfdca2	gserial_alloc_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0x8e27d6de	gs_alloc_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xb6652875	gserial_free_line
++EXPORT_SYMBOL_GPL drivers/usb/gadget/u_serial 0xf1981607	gs_free_req
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x24726e8e	usb_gadget_map_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x643023e6	usb_add_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x7589f33d	usb_del_gadget_udc
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x787f721e	usb_gadget_probe_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0x7a32e065	usb_gadget_unregister_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xb172ccc3	usb_gadget_unmap_request
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xba1ab67b	usb_gadget_set_state
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xbdb61458	udc_attach_driver
++EXPORT_SYMBOL_GPL drivers/usb/gadget/udc-core 0xd4b7cca7	usb_add_gadget_udc_release
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0x952a26e3	ezusb_fx1_ihex_firmware_download
++EXPORT_SYMBOL_GPL drivers/usb/misc/ezusb 0xe636d683	ezusb_fx1_set_reset
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x198c0824	usb_ftdi_elan_edset_empty
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x49cd7a20	usb_ftdi_elan_read_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x4b93d45f	ftdi_elan_gone_away
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x7d90f16d	usb_ftdi_elan_edset_output
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x818e1a6a	usb_ftdi_elan_edset_flush
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0x9a95c2d2	usb_ftdi_elan_write_pcimem
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xd36ed9e2	usb_ftdi_elan_edset_single
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xe360ecd2	usb_ftdi_elan_edset_input
++EXPORT_SYMBOL_GPL drivers/usb/misc/ftdi-elan 0xf3f67ad6	usb_ftdi_elan_edset_setup
++EXPORT_SYMBOL_GPL drivers/usb/musb/musb_hdrc 0xe2468134	musb_interrupt
++EXPORT_SYMBOL_GPL drivers/usb/musb/tusb6010 0xf23d7784	tusb_get_revision
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-isp1301 0x20b6184f	isp1301_get_client
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0x08d249a5	omap_get_control_dev
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0xa41c0d64	omap_control_usb_phy_power
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0xb1a6b73a	omap_control_usb3_phy_power
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-omap-control 0xc77a3a41	omap_control_usb_set_mode
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x36556390	samsung_usbphy_rate_to_clksel_4x12
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x5a6830a8	samsung_usbphy_rate_to_clksel_64xx
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x69c4bd57	samsung_usbphy_cfg_sel
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0x7387d979	samsung_usbphy_set_isolation_4210
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xb5611964	samsung_usbphy_set_type
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xc6859437	samsung_usbphy_parse_dt
++EXPORT_SYMBOL_GPL drivers/usb/phy/phy-samsung-usb 0xf3496bb8	samsung_usbphy_get_refclk_freq
++EXPORT_SYMBOL_GPL drivers/usb/serial/usb_wwan 0x593d1eef	usb_wwan_port_probe
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x1a0b7fd4	usb_serial_deregister_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2955fabe	usb_serial_register_drivers
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x2bfd93f5	usb_serial_generic_open
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x312cfc61	usb_serial_generic_tiocmiwait
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x41db5bf3	usb_serial_generic_read_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x6c6497a5	usb_serial_handle_sysrq_char
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7a495ec9	usb_serial_generic_wait_until_sent
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7cdb45ba	usb_serial_generic_write_bulk_callback
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0x7d65ff81	usb_serial_generic_process_read_urb
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xab40fe53	usb_serial_port_softint
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc60f97a3	usb_serial_generic_chars_in_buffer
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xc9a15618	usb_serial_generic_get_icount
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcc34cb6e	usb_serial_generic_write
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xcc92b562	usb_serial_handle_dcd_change
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd34471f2	usb_serial_generic_unthrottle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd48363fb	usb_serial_handle_break
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xd4a4ca5b	usb_serial_generic_submit_read_urbs
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe22f48c3	usb_serial_generic_close
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xe59c78f5	usb_serial_generic_throttle
++EXPORT_SYMBOL_GPL drivers/usb/serial/usbserial 0xf0b1c5a9	usb_serial_generic_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x014d87a3	usb_stor_ctrl_transfer
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1a30e294	usb_stor_transparent_scsi_command
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x1bc3edc2	usb_stor_sense_invalidCDB
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x20f57ebc	usb_stor_CB_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3c88586c	usb_stor_probe2
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x3c8f49b1	fill_inquiry_response
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x604f22c4	usb_stor_CB_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x6c9eefb4	usb_stor_pre_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x73617875	usb_stor_control_msg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x82aa9445	usb_stor_bulk_srb
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x837fed0f	usb_stor_Bulk_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x876c2ae8	usb_stor_set_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0x90b7225b	usb_stor_Bulk_transport
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xa5a373d8	usb_stor_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xaafe9ed4	usb_stor_reset_resume
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb35269a4	usb_stor_bulk_transfer_sg
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xb4b6476c	usb_stor_suspend
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbb7b89b8	usb_stor_probe1
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xbc9e3bcd	usb_stor_access_xfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xc0d6d5fe	usb_stor_clear_halt
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xd9409512	usb_stor_post_reset
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xea65299b	usb_stor_disconnect
++EXPORT_SYMBOL_GPL drivers/usb/storage/usb-storage 0xf1207631	usb_stor_bulk_transfer_buf
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0x47a10d0e	__wa_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xa0376b3e	wa_urb_enqueue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xa2c1be96	wa_urb_dequeue
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xb94a5b09	wa_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xc17fafe1	rpipe_ep_disable
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xcb55ad58	rpipe_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusb-wa 0xf4654c3f	wa_urb_enqueue_run
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x080baad5	wusbhc_reset_all
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0bb6bf5e	wusb_cluster_id_get
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x0cfa70ee	wusbhc_mmcie_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x240224a0	wusbhc_chid_set
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x3c286d6f	wusbhc_b_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x4ea79286	__wusb_dev_get_by_usb_dev
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x6235b0f4	wusbhc_giveback_urb
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x70d4b8f1	wusbhc_rh_control
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7513a372	wusbhc_b_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x7f0b7631	wusb_dev_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0x98551f50	wusbhc_handle_dn
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xa940d969	wusbhc_destroy
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb01ddff3	wusbhc_mmcie_rm
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb725d128	wusb_cluster_id_put
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xb7ca5505	wusbhc_rh_start_port_reset
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xcc848b4f	wusbhc_rh_status_data
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xe1ff82e4	wusbhc_create
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xf770a6b4	wusbd
++EXPORT_SYMBOL_GPL drivers/usb/wusbcore/wusbcore 0xfe2e17d7	wusb_et_name
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0x2f387f78	i1480_rceb_check
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xb5ee0dc2	i1480_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/i1480/dfu/i1480-dfu-usb 0xcfdbd083	i1480_fw_upload
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x149d1472	umc_bus_type
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x1af5a786	umc_device_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x2c1d21fb	umc_driver_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x61c497f7	umc_device_create
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0x6ea10648	umc_match_pci_id
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xb3584bd8	__umc_driver_register
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xda09b5d4	umc_device_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/umc 0xea709f6f	umc_controller_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x001b11cb	uwb_rc_reset_all
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b6e97ff	uwb_rc_neh_grok
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0b8aad57	uwb_est_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x0cc5fb4c	uwb_rc_vcmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x193a589a	uwb_rc_cmd_async
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2d8ea2aa	uwb_rc_cmd
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x2e59ce49	uwb_rc_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3071e78a	uwb_rc_post_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x34606970	uwb_rc_put
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3643e4ce	uwb_rsv_create
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x3ee1d30b	uwb_rc_get_by_dev
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x40bdddea	uwb_notifs_deregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x461e18f8	uwb_rc_pre_reset
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4b8217a0	uwb_rc_dev_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4bc196ad	__uwb_rc_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x4d57ae3c	uwb_rsv_type_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x515f87b9	uwb_rc_alloc
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x52e04160	uwb_rc_neh_error
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x58f90a94	uwb_dev_for_each
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x5e4bc088	__uwb_addr_print
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x6ed1dd69	uwb_radio_start
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7bf0636c	uwb_notifs_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7c9b3112	uwb_pal_unregister
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x7dcfcd23	uwb_ie_next
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x850e2b1f	uwb_rsv_accept
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x98413234	uwb_rsv_state_str
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0x9ac7df0f	uwb_rsv_terminate
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xa4113b9a	uwb_dev_try_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xad92d263	uwb_pal_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb18ecdef	uwb_est_find_size
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb1afc34e	uwb_rsv_establish
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xb9355aa4	uwb_rsv_get_usable_mas
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc5a66855	uwb_rsv_modify
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xc6b8a9e4	uwb_pal_init
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd8848fd4	uwb_radio_stop
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xd9234c6d	uwb_rc_ie_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xde7f572a	uwb_rc_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe1716f06	uwb_est_register
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe393c2e6	uwb_rc_mac_addr_get
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe4243458	uwb_rc_add
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xe8066751	uwb_rc_ie_rm
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf541cebf	uwb_rsv_destroy
++EXPORT_SYMBOL_GPL drivers/uwb/uwb 0xf6f9a949	uwb_rc_get_by_grandpa
++EXPORT_SYMBOL_GPL drivers/uwb/whci 0x54164808	whci_wait_for
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x241ca8af	vfio_register_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x32a2217e	vfio_device_get_from_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x4a10f9ec	vfio_unregister_iommu_driver
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x72e151ac	vfio_add_group_dev
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x95258207	vfio_device_data
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0x969c73d9	vfio_device_put
++EXPORT_SYMBOL_GPL drivers/vfio/vfio 0xa6343185	vfio_del_group_dev
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x0198c49e	vhost_add_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x193d1ca0	vhost_add_used_and_signal_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x227132a0	vhost_dev_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x251868b2	vhost_dev_has_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x269f7a09	vhost_dev_reset_owner_prepare
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x3053e410	vhost_poll_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x45c2b736	vhost_work_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4c8131c7	vhost_work_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4dc54ae6	vhost_add_used_n
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x4fdb3b5e	vhost_discard_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x5906272d	vhost_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x792e7ea3	vhost_poll_start
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x8bac64b1	vhost_log_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9268c6f0	vhost_dev_reset_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x947e4c50	vhost_log_write
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9ba90f32	vhost_disable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9cd70ae0	vhost_poll_flush
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9de584de	vhost_poll_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0x9f4bfc06	vhost_work_queue
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xc67d2fde	vhost_get_vq_desc
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xced7bdde	vhost_init_used
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xcf85b4d6	vhost_dev_check_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd3b48657	vhost_dev_cleanup
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xd3f0e4da	vhost_dev_init
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xdb93f528	vhost_poll_stop
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe39dfea7	vhost_dev_set_owner
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe51981f1	vhost_enable_notify
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xe879694e	vhost_dev_ioctl
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf260c156	vhost_vq_access_ok
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xf3413dcf	vhost_add_used_and_signal
++EXPORT_SYMBOL_GPL drivers/vhost/vhost 0xff59dcb3	vhost_vring_ioctl
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x21c42105	auok190x_common_remove
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x45b62ba8	auok190x_send_cmdargs_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x726e738e	auok190x_send_cmdargs_pixels
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x8c1b1489	auok190x_send_cmdargs_pixels_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x9a94a726	auok190x_send_command_nowait
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0x9d828301	auok190x_read_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xa416f1a7	auok190x_send_command
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xb773c155	auok190x_common_probe
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xcc8c8325	auok190x_pm
++EXPORT_SYMBOL_GPL drivers/video/auo_k190x 0xd2663f26	auok190x_send_cmdargs
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0x2c63e051	apple_bl_register
++EXPORT_SYMBOL_GPL drivers/video/backlight/apple_bl 0xdab0f892	apple_bl_unregister
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x0ea51490	ili9320_remove
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x57185da9	ili9320_shutdown
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x87913747	ili9320_resume
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9d60e196	ili9320_write
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0x9d7b08d0	ili9320_write_regs
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xaa29b017	ili9320_suspend
++EXPORT_SYMBOL_GPL drivers/video/backlight/ili9320 0xb91cafe6	ili9320_probe_spi
++EXPORT_SYMBOL_GPL drivers/video/fb_ddc 0x1dc3db07	fb_ddc_read
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x3fbc5c95	fb_sys_write
++EXPORT_SYMBOL_GPL drivers/video/fb_sys_fops 0x6772e2ac	fb_sys_read
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0xa6fcdeb1	sis_malloc_new
++EXPORT_SYMBOL_GPL drivers/video/sis/sisfb 0xa9227d1b	sis_free_new
++EXPORT_SYMBOL_GPL drivers/video/vermilion/vmlfb 0x016e6c20	vmlfb_unregister_subsys
++EXPORT_SYMBOL_GPL drivers/video/vermilion/vmlfb 0x90c018c6	vmlfb_register_subsys
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x046067f7	viafb_find_i2c_adapter
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x22a7af24	viafb_dma_copy_out_sg
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x292da7a2	viafb_irq_enable
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x30cc9311	viafb_request_dma
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x31469540	viafb_pm_unregister
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0x79e6190a	viafb_irq_disable
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xb4f863e6	viafb_pm_register
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xcaefb732	viafb_release_dma
++EXPORT_SYMBOL_GPL drivers/video/via/viafb 0xfff2dfd2	viafb_gpio_lookup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x09324840	w1_write_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x2e55640a	w1_reset_resume_command
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x54255a60	w1_read_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7c2f2afb	w1_calc_crc8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7d49f525	w1_reset_bus
++EXPORT_SYMBOL_GPL drivers/w1/wire 0x7d89f42f	w1_next_pullup
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xbe2d5587	w1_reset_select_slave
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc1f7dff8	w1_touch_block
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xc4e9036c	w1_read_8
++EXPORT_SYMBOL_GPL drivers/w1/wire 0xf810082e	w1_write_block
++EXPORT_SYMBOL_GPL drivers/xen/xen-privcmd 0xeb58561f	xen_privcmd_fops
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x306bbed0	dlm_posix_unlock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x9321df95	dlm_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0x99fa69d8	dlm_posix_get
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xb72642d3	dlm_posix_lock
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xc6dc8c2f	dlm_new_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xcf9f3328	dlm_release_lockspace
++EXPORT_SYMBOL_GPL fs/dlm/dlm 0xdc583c08	dlm_unlock
++EXPORT_SYMBOL_GPL fs/fscache/fscache 0x092cf98e	fscache_object_sleep_till_congested
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x17ce645d	locks_end_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x1bec9c4b	locks_start_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x283ed2b9	nlmclnt_proc
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x2becb824	lockd_up
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x5719b3e5	locks_in_grace
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x77e35ccc	nlmsvc_unlock_all_by_ip
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0x87b96fac	nlmsvc_ops
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb583bee2	lockd_down
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xb761d6c2	nlmclnt_done
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xebbb60d5	nlmclnt_init
++EXPORT_SYMBOL_GPL fs/lockd/lockd 0xef24fd0b	nlmsvc_unlock_all_by_sb
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x00bb8b1b	nfs_file_splice_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x017a8f56	nfs_zap_acl_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x06a6a567	nfs_permission
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x07fd78ee	nfs_create_rpc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x08cbdbcc	nfs_initiate_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0953c63b	nfs_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x0a10f99c	nfs_remount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x10828f6e	nfs_try_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1269dc08	nfs_fscache_set_inode_cookie
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x186afc38	nfs_getattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x19adf522	nfs_commitdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1b13b549	nfs_put_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1dae5056	nfs_pgheader_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1dd5c18f	nfs_readdata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x1e5d7a07	nfs_file_mmap
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x23c4c4bd	nfs_link
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x246b5ffc	nfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x250bbbe7	nfs_alloc_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x25a3aeee	nfs_file_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x26884ff7	nfs_alloc_fhandle
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x2892f02d	nfs_commitdata_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x28dc07b7	nfs_file_splice_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x29440a92	nfs_close_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3978a67b	nfs_destroy_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x39e05ac3	nfs_idmap_cache_timeout
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3ca31f35	nfs_net_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x3f2690f2	nfs_check_flags
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4101b8b8	nfs_request_remove_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x42f2c81f	nfs4_client_id_uniquifier
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4567f389	nfs_readhdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x46f1753a	nfs_init_cinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x493636f3	nfs_pageio_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4a367838	nfs4_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x4aed3da5	nfs_fhget
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x513499bf	nfs_pageio_reset_read_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x514974fd	nfs_pageio_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51892d61	nfs_callback_set_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x51b3a4ee	alloc_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x529284bd	nfs_setattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5760d050	get_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5af22b9a	nfs_clone_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5b5ab173	nfs_show_stats
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5c52f45f	nfs_request_add_commit_list
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5c65a272	nfs_revalidate_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e1d863a	nfs_sockaddr_match_ipaddr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5e44be03	nfs_server_insert_lists
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5ebdfe37	nfs_lock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x5f852148	nfs_initiate_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x63a5b5cb	nfs_probe_fsinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x63ef4770	nfs_do_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x64d6a307	nfs_fs_mount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6d779e39	nfs_sb_active
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6db875c2	nfs_alloc_fattr
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x6e8b3f6f	nfs_free_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x72cb49f4	nfs_pageio_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7307b64b	nfs_clear_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x74c978e8	nfs_pageio_add_request
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7505f848	nfs_force_lookup_revalidate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x75142049	nfs_create
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7a845ad4	nfs_kill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7ca16900	nfs_retry_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d47b947	nfs_alloc_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7d83305d	nfs_atomic_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x7f697732	nfs_rmdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x809060b6	nfs_access_set_mask
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x821d2e6a	nfs_file_write
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x85a95d41	nfs_show_devname
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89b5b5b9	nfs_generic_pagein
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x89bc5a64	nfs_wait_bit_killable
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8b083ecf	nfs_writedata_release
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x8e15c04b	nfs_drop_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x90a5530f	nfsiod_workqueue
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x91d1fe52	max_session_slots
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9290cd18	nfs_writehdr_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x92b87383	nfs_create_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x936b9da5	nfs_alloc_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9394508f	nfs_fs_mount_common
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x946d007e	nfs_wb_all
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x953f59fb	nfs_statfs
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x96783c5d	nfs_post_op_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x97f74782	nfs_file_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9802405d	nfs_access_add_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x99d7e57f	nfs_setsecurity
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9b4c9fc2	nfs_instantiate
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9c4bc66b	nfs_mknod
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0x9d228625	nfs_fs_type
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa41e321a	nfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa7180d81	nfs_flock
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa7e46cb2	put_nfs_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8d2d1ce	nfs_callback_tcpport
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa8e9e1ae	send_implementation_id
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa9d83cbe	nfs_refresh_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xa9f05560	nfs_server_copy_userdata
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaa0438b4	nfs_init_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xaaa14361	nfs_dreq_bytes_left
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xad42fd1a	nfs_free_server
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb11bc589	nfs_wait_client_init_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb2e2da24	nfs_mark_client_ready
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb6e2e545	nfs_file_fsync_commit
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xb708a18b	nfs_access_zap_cache
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbacfc8fe	nfs_file_llseek
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbd1b5d03	nfs_write_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xbebbd161	register_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc0f64736	nfs_lookup
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc25f7f3d	nfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc33df035	nfs_get_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc5ef47d5	nfs_init_timeout_values
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc60ecbb5	nfs_init_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc66604b4	nfs_invalidate_atime
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xc66ee5bb	nfs_file_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xcc4e37ee	nfs_pageio_complete
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xccb1bc63	nfs_show_path
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd19975f0	nfs_generic_flush
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd1d8adda	nfs_sb_deactive
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd3b3a437	nfs_rename
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd3d183c6	nfs_unlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd6b45d91	nfs_pageio_reset_write_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd6ce18b0	unregister_nfs_version
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xd7f21c38	nfs_clone_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdae9b5d7	nfs4_disable_idmapping
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb78e184	nfs_sops
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdb99995f	nfs_may_open
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd0c5984	nfs_init_server_rpcclient
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xdd447ca2	nfs_submount
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe0dec1da	nfs_file_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe3b1219a	nfs_post_op_update_inode_force_wcc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xe835dac9	nfs_symlink
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea1cc07d	nfs_setlease
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea8741b1	nfs_fill_super
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xea90b1ee	nfs_setattr_update_inode
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeab58d2a	nfs_commit_free
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xebec43b2	nfs_initiate_read
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeda42b1a	nfs4_label_alloc
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee3136dd	nfs_set_sb_security
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xee794369	nfs4_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xeeceb206	nfs_fattr_init
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf111318b	nfs_show_options
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf203c63f	nfs_file_set_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf4432f18	nfs_put_client
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf4b9513d	nfs_umount_begin
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xf8232bc5	nfs_mkdir
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xfb0a9a7c	nfs_dentry_operations
++EXPORT_SYMBOL_GPL fs/nfs/nfs 0xffa0cb35	nfs_inode_attach_open_context
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0362636e	pnfs_readhdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0418be68	nfs4_schedule_lease_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x0e67ccbe	pnfs_ld_write_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x114a8030	nfs4_init_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x170f3ed6	nfs41_maxgetdevinfo_overhead
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x1bc79bf5	pnfs_generic_pg_writepages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2154692e	pnfs_set_layoutcommit
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x2b91439f	pnfs_set_lo_fail
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3a2a37c4	nfs4_find_get_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3ae4801b	nfs4_test_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x3d54b0c0	nfs4_set_ds_client
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x457e718c	nfs4_mark_deviceid_unavailable
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x502194d6	nfs4_proc_getdevicelist
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5adb6aac	pnfs_writehdr_free
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5b1324db	pnfs_unregister_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x5cc3e291	pnfs_generic_pg_readpages
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6839348b	nfs_remove_bad_delegation
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x69a48fce	pnfs_ld_read_done
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x6c5628da	pnfs_put_lseg
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x7d174eb3	nfs4_schedule_stateid_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8995fe07	nfs4_insert_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0x8bcc3ac3	nfs4_init_ds_session
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xa16e47d3	nfs4_delete_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb17bf22e	pnfs_register_layoutdriver
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xb67a601d	pnfs_read_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xbd544b8b	pnfs_generic_pg_init_read
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xc688ac15	pnfs_update_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xd56ad700	pnfs_write_done_resend_to_mds
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xddb7cb0a	nfs4_set_rw_stateid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe04a5580	pnfs_generic_pg_init_write
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe6ac2fdc	nfs4_put_deviceid_node
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xe93582eb	pnfs_destroy_layout
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xed15fb41	nfs4_print_deviceid
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xf74a494a	nfs41_setup_sequence
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcbb9f62	pnfs_generic_pg_test
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfcde8d22	nfs4_schedule_session_recovery
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfe85169d	nfs4_proc_getdeviceinfo
++EXPORT_SYMBOL_GPL fs/nfs/nfsv4 0xfecae27c	_pnfs_return_layout
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0x9b696021	nfsacl_decode
++EXPORT_SYMBOL_GPL fs/nfs_common/nfs_acl 0xb9e3dc1d	nfsacl_encode
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x00065f71	o2nm_node_put
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x00b513f6	o2nm_node_get
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1b89c6ee	o2hb_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1cb231d0	mlog_not_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x1d747ce3	o2hb_check_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x2cffedfd	o2nm_get_node_by_num
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x36418553	o2net_send_message
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x4900035b	o2hb_stop_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x684d495d	o2hb_register_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x687f6251	mlog_and_bits
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0x78835e16	o2hb_unregister_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa82a8645	o2nm_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa87bc9e7	o2nm_configured_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xa9f5379a	o2net_send_message_vec
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xae808bac	o2net_register_handler
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xbaeb4700	o2hb_check_node_heartbeating_from_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc04639e8	o2hb_setup_callback
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xc3679d7b	o2hb_get_all_regions
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd60f2c6c	o2hb_check_local_node_heartbeating
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xd859ac8c	o2net_fill_node_map
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf1a5611d	o2net_unregister_handler_list
++EXPORT_SYMBOL_GPL fs/ocfs2/cluster/ocfs2_nodemanager 0xf30ce3a5	o2nm_get_node_by_ip
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x6263cbd1	dlm_print_one_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7385b4ef	dlm_register_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0x7a1211f8	dlm_setup_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xb00ef456	dlm_unregister_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xc2a26d8c	dlmunlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd7ba575e	dlm_errmsg
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xd8fa57a6	dlm_unregister_eviction_cb
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xebe5c997	dlmlock
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xef7b4e33	dlm_register_domain
++EXPORT_SYMBOL_GPL fs/ocfs2/dlm/ocfs2_dlm 0xfb86b96f	dlm_errname
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x025e2d69	ocfs2_cluster_connect_agnostic
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x0562c415	ocfs2_cluster_this_node
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x11ba6a13	ocfs2_stack_glue_unregister
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x16b2e575	ocfs2_dlm_unlock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x1a61ebc7	ocfs2_plock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x4d3af7fa	ocfs2_cluster_hangup
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x5469ce31	ocfs2_dlm_lvb_valid
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x6d0a3475	ocfs2_stack_glue_register
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x7083dbd5	ocfs2_dlm_dump_lksb
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0x89502fe7	ocfs2_cluster_connect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xb4bd060c	ocfs2_dlm_lock_status
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xbbc4ef97	ocfs2_stack_supports_plocks
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xdc823ea4	ocfs2_cluster_disconnect
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe2bd47db	ocfs2_dlm_lock
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe40cffce	ocfs2_stack_glue_set_max_proto_version
++EXPORT_SYMBOL_GPL fs/ocfs2/ocfs2_stackglue 0xe417d940	ocfs2_dlm_lvb
++EXPORT_SYMBOL_GPL lib/bch 0x231d70fc	encode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x6b770f49	decode_bch
++EXPORT_SYMBOL_GPL lib/bch 0x9463ff71	init_bch
++EXPORT_SYMBOL_GPL lib/bch 0xbdf512de	free_bch
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x2a991386	notifier_err_inject_init
++EXPORT_SYMBOL_GPL lib/notifier-error-inject 0x95c4f529	notifier_err_inject_dir
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x021957e1	raid6_datap_recov
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x05513b71	raid6_call
++EXPORT_SYMBOL_GPL lib/raid6/raid6_pq 0x0f8a2742	raid6_2data_recov
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x201d8ea3	encode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x29fa419f	decode_rs8
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x300d7e57	free_rs
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0x6fbb3bd9	init_rs_non_canonical
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xabda1e2e	decode_rs16
++EXPORT_SYMBOL_GPL lib/reed_solomon/reed_solomon 0xb050f329	init_rs
++EXPORT_SYMBOL_GPL net/802/garp 0x19596ca3	garp_init_applicant
++EXPORT_SYMBOL_GPL net/802/garp 0x3d68afc8	garp_register_application
++EXPORT_SYMBOL_GPL net/802/garp 0x6d263884	garp_request_join
++EXPORT_SYMBOL_GPL net/802/garp 0x78c2188c	garp_unregister_application
++EXPORT_SYMBOL_GPL net/802/garp 0xad4d3b41	garp_request_leave
++EXPORT_SYMBOL_GPL net/802/garp 0xc6b5e7b7	garp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0x216544e8	mrp_request_leave
++EXPORT_SYMBOL_GPL net/802/mrp 0x7d601391	mrp_register_application
++EXPORT_SYMBOL_GPL net/802/mrp 0x93b5acad	mrp_uninit_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xab5a0e73	mrp_unregister_application
++EXPORT_SYMBOL_GPL net/802/mrp 0xb921576a	mrp_init_applicant
++EXPORT_SYMBOL_GPL net/802/mrp 0xde2175c2	mrp_request_join
++EXPORT_SYMBOL_GPL net/802/stp 0xb775a32f	stp_proto_unregister
++EXPORT_SYMBOL_GPL net/802/stp 0xdc7b06a4	stp_proto_register
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x815e54e4	p9_client_xattrcreate
++EXPORT_SYMBOL_GPL net/9p/9pnet 0x9b484738	p9_client_xattrwalk
++EXPORT_SYMBOL_GPL net/atm/atm 0xb09faf79	register_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/atm/atm 0xcfb6a3da	unregister_atmdevice_notifier
++EXPORT_SYMBOL_GPL net/ax25/ax25 0x46720f40	ax25_register_pid
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xac93ae05	ax25_bcast
++EXPORT_SYMBOL_GPL net/ax25/ax25 0xaeb7451e	ax25_defaddr
++EXPORT_SYMBOL_GPL net/bluetooth/bluetooth 0x1d236db4	bt_debugfs
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x0be78427	dccp_init_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1911537c	dccp_death_row
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x19299605	dccp_reqsk_init
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x1d99d49a	dccp_timestamp
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x2436b3fc	dccp_done
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x29efd14b	dccp_create_openreq_child
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4831f73a	dccp_feat_nn_get
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x48fbc080	dccp_recvmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4cdd391d	dccp_feat_list_purge
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ec35231	dccp_ackvec_parsed_add
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x4ef1cc15	dccp_destroy_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x563824f9	dccp_set_state
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x57fda065	dccp_parse_options
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x59f9d1ac	dccp_insert_option_elapsed_time
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x5f59040e	dccp_check_req
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x628443c1	dccp_send_sync
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x63625a7a	dccp_rcv_state_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x685b69d7	dccp_ioctl
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x70610fb8	dccp_close
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x760a3c68	dccp_child_process
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x7f29e47c	dccp_reqsk_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x848b1a03	dccp_sync_mss
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x86be7924	dccp_packet_name
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8bf09b35	dccp_send_ack
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x8eb68a86	dccp_orphan_count
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x934a25b3	dccp_setsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9598d24d	dccp_ackvec_parsed_cleanup
++EXPORT_SYMBOL_GPL net/dccp/dccp 0x9ad165de	dccp_insert_option
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa01d8c4c	inet_dccp_listen
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa04d17ff	dccp_poll
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa21cd501	dccp_make_response
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa2a109a2	dccp_feat_signal_nn_change
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xa5219129	dccp_hashinfo
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb51f8f08	dccp_connect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xb80758fa	dccp_getsockopt
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xcb04a9a6	dccp_rcv_established
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd03eca41	dccp_disconnect
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xd58724ee	dccp_sendmsg
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xe13e76d8	dccp_shutdown
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xf3017e21	dccp_statistics
++EXPORT_SYMBOL_GPL net/dccp/dccp 0xfc6ba229	dccp_ctl_make_reset
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x10ed0045	dccp_v4_do_rcv
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x125a79cc	dccp_invalid_packet
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x349e58bc	dccp_v4_send_check
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8531d4e5	dccp_v4_request_recv_sock
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0x8e55c6f6	dccp_v4_conn_request
++EXPORT_SYMBOL_GPL net/dccp/dccp_ipv4 0xaa66f58f	dccp_v4_connect
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0x9e7ee241	unregister_switch_driver
++EXPORT_SYMBOL_GPL net/dsa/dsa_core 0xbc37b42a	register_switch_driver
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x2223daf4	gre_add_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x3302c56a	gre_cisco_register
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x4875f0cb	gre_cisco_unregister
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x5ff57826	gre_del_protocol
++EXPORT_SYMBOL_GPL net/ipv4/gre 0x7a100028	gre_build_header
++EXPORT_SYMBOL_GPL net/ipv4/gre 0xe54b8cde	gre_handle_offloads
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0x8f4db35d	inet_diag_bc_sk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xba885283	inet_sk_diag_fill
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xc84d3aa2	inet_diag_register
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xcd5a8628	inet_diag_unregister
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xecfcae8b	inet_diag_dump_one_icsk
++EXPORT_SYMBOL_GPL net/ipv4/inet_diag 0xf56c91f0	inet_diag_dump_icsk
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0a2cc484	ip_tunnel_uninit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x0c96ffac	ip_tunnel_rcv
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x470ef723	ip_tunnel_lookup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x58425e99	ip_tunnel_ioctl
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x75d06e90	ip_tunnel_init_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x75d53f64	ip_tunnel_xmit
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8bc04d70	ip_tunnel_change_mtu
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0x8c3002f5	ip_tunnel_changelink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb356c794	ip_tunnel_delete_net
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xb57775e9	ip_tunnel_dellink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xbea24d31	ip_tunnel_newlink
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc3c758c7	ip_tunnel_setup
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xc9a354d7	ip_tunnel_init
++EXPORT_SYMBOL_GPL net/ipv4/ip_tunnel 0xdbd25a45	ip_tunnel_get_stats64
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/arp_tables 0xe91508cc	arpt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/ip_tables 0x88f2572e	ipt_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_conntrack_ipv4 0x6d40a921	need_ipv4_conntrack
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_defrag_ipv4 0x6b6c3d10	nf_defrag_ipv4_enable
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_ipv4 0xc74ac200	nf_nat_icmp_reply_translation
++EXPORT_SYMBOL_GPL net/ipv4/netfilter/nf_nat_proto_gre 0x636b12c8	nf_nat_need_gre
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0x53b81c4d	tcp_vegas_cwnd_event
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xa5610a57	tcp_vegas_init
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xbd82c108	tcp_vegas_pkts_acked
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xd84059a4	tcp_vegas_get_info
++EXPORT_SYMBOL_GPL net/ipv4/tcp_vegas 0xdb665c22	tcp_vegas_state
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x62f65bf4	xfrm4_mode_tunnel_input_deregister
++EXPORT_SYMBOL_GPL net/ipv4/xfrm4_mode_tunnel 0x6bcd7430	xfrm4_mode_tunnel_input_register
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x2b054fc2	ip6_tnl_dst_store
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5cc8f220	ip6_tnl_rcv_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5f412a73	ip6_tnl_dst_reset
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0x5fc225fe	ip6_tnl_xmit_ctl
++EXPORT_SYMBOL_GPL net/ipv6/ip6_tunnel 0xccb95456	ip6_tnl_dst_check
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/ip6_tables 0x4d273cd0	ip6t_alloc_initial_table
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_defrag_ipv6 0x6eb85693	nf_defrag_ipv6_enable
++EXPORT_SYMBOL_GPL net/ipv6/netfilter/nf_nat_ipv6 0x2cc6f334	nf_nat_icmpv6_reply_translation
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x0e1b7033	l2tp_session_find_by_ifname
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x225db2ce	l2tp_udp_encap_recv
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x2f507066	l2tp_tunnel_sock_put
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x3080473c	l2tp_tunnel_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x34120cee	l2tp_tunnel_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x4bfaeae0	l2tp_tunnel_sock_lookup
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x67dc641d	l2tp_xmit_skb
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7854de16	l2tp_tunnel_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x7f59ac03	l2tp_tunnel_closeall
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0x9b3ecf9d	l2tp_session_free
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xb6f9f208	l2tp_session_find
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xbace31ed	l2tp_session_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xcd50ee68	l2tp_session_create
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xd75a347b	l2tp_session_queue_purge
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xde437ba3	l2tp_session_find_nth
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xe576b79a	l2tp_tunnel_delete
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_core 0xedf26db1	__l2tp_session_unhash
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x337f2432	l2tp_nl_unregister_ops
++EXPORT_SYMBOL_GPL net/l2tp/l2tp_netlink 0x98db8ee1	l2tp_nl_register_ops
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x14ef2870	ieee80211_iterate_active_interfaces
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x291cbceb	ieee80211_ready_on_channel
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x46f077b1	ieee80211_find_sta_by_ifaddr
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x59032fb4	ieee80211_request_smps
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x6a48b38b	ieee80211_gtk_rekey_notify
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0x988b781f	ieee80211_remain_on_channel_expired
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xb1a9a731	ieee80211_iterate_active_interfaces_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xbd1b8ca1	ieee80211_iter_chan_contexts_atomic
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc6188f67	ieee80211_ave_rssi
++EXPORT_SYMBOL_GPL net/mac80211/mac80211 0xc94b2d8c	ieee80211_resume_disconnect
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x10047c49	ip_set_get_extensions
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3802d7e5	ip_set_type_unregister
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x397f6231	ip_set_free
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x3a047ce3	ip_set_test
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x4646a49e	ip_set_add
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x5aee11b2	ip_set_get_byname
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6344eaf6	ip_set_alloc
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6524bcf5	ip_set_get_ip6_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x6601d2ab	ip_set_get_ip4_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7762965e	ip_set_nfnl_put
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x7924b6de	ip_set_hostmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x80ee118c	ip_set_nfnl_get
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x81fff2d1	ip_set_netmask_map
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x883d6572	ip_set_name_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0x9e98722b	ip_set_get_ipaddr6
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa293f8a6	ip_set_get_ipaddr4
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2a8492a	ip_set_del
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa2d623f3	ip_set_range_to_cidr
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xa5366137	ip_set_get_ip_port
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xc3b062db	ip_set_nfnl_get_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xe0ae6788	ip_set_type_register
++EXPORT_SYMBOL_GPL net/netfilter/ipset/ip_set 0xfda3ec7a	ip_set_put_byindex
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x0a026a5c	unregister_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0x7aa307af	ip_vs_conn_in_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xa1c225ad	ip_vs_conn_out_get_proto
++EXPORT_SYMBOL_GPL net/netfilter/ipvs/ip_vs 0xb02c4d52	register_ip_vs_pe
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x03188e52	nf_ct_helper_expectfn_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0390d5b1	nf_conntrack_alter_reply
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x045072cd	nf_ct_port_nla_policy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x062138fa	__nf_ct_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x07a4e3a5	nf_conntrack_helper_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x07cd2876	nf_conntrack_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x08ec11f5	nf_ct_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x090f173c	nf_ct_remove_expectations
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x0a5f92fc	nf_ct_port_tuple_to_nlattr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x183b60f5	nf_conntrack_l4proto_tcp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x250c2f09	__nf_ct_kill_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x289c3714	nf_ct_alloc_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2933a8bf	nf_ct_l4proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2a0d0277	nf_conntrack_l4proto_tcp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x2c4982b2	nf_conntrack_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32267c0c	nf_ct_timeout_find_get_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x32a67462	__nf_ct_refresh_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x37386cac	nf_conntrack_hash_rnd
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3ce0b0ed	nf_conntrack_tuple_taken
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3e05104f	__nf_ct_expect_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x3f5b1415	nf_ct_port_nlattr_to_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4071abb5	nf_ct_helper_expectfn_find_by_symbol
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x421f8d75	nf_conntrack_helper_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4aa61ad1	nf_conntrack_flush_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4ba9376a	nf_ct_l3proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x4f7e91b0	nf_ct_l4proto_pernet_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x545750e1	nf_ct_expect_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x569b6493	nf_ct_helper_ext_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5b672c62	nf_ct_iterate_cleanup
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x5eb4f56a	nf_conntrack_in
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x62813e5c	nf_ct_port_nlattr_tuple_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x633013d3	nf_connlabels_replace
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x646e7760	nf_conntrack_helper_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x688122a2	nf_conntrack_free
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x69363cfc	__nf_conntrack_helper_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x693c3961	nf_ct_helper_hash
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6a188a07	nf_ct_l3proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x6e224a7a	need_conntrack
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7078835e	nf_ct_helper_expectfn_find_by_name
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x717c0c73	nf_ct_dying_timeout
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x73189fb5	nf_connlabel_set
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x747abeff	nf_ct_extend_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x786d3e35	nf_ct_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x78f9b710	nf_ct_l3proto_try_module_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7a889be4	nf_conntrack_lock
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7d5dea0a	seq_print_acct
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x7e5b1101	nf_ct_unlink_expect_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8823317f	nf_conntrack_hash_check_insert
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x887244f3	nf_ct_unexpect_related
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8bcef273	nf_ct_helper_expectfn_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ec15a9a	nf_ct_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x8ffe7e89	nf_conntrack_htable_size
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x90ff6c9f	nf_ct_invert_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9427cc98	nf_conntrack_l4proto_udp6
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x9568fed2	nf_ct_expect_unregister_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0x98383be7	nf_nat_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa0ceedc6	nf_ct_get_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa22e426d	nf_ct_l3proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa40da7e8	nf_ct_expect_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa4feea3c	nf_ct_expect_init
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xa611ae1a	nf_conntrack_l4proto_udp4
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xab3d1f95	nf_ct_untracked_status_or
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xad1bb027	nf_ct_free_hashtable
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xaf8f8ca4	nf_ct_nat_offset
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb04205ca	nf_ct_delete_from_lists
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb13dfbb3	nf_ct_timeout_put_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb17e29c7	nf_conntrack_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb602c57e	nf_ct_l3proto_module_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb75284fe	nf_conntrack_register_notifier
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xb784ecd0	nf_ct_expect_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbbc88a86	__nf_conntrack_confirm
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbcf9cabf	__nf_ct_try_assign_helper
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xbf036a52	nf_ct_expect_related_report
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc0240dd4	nf_conntrack_set_hashsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc18ac88d	nf_ct_expect_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc1af0337	nf_conntrack_l3proto_generic
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc300bd91	nf_ct_deliver_cached_events
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc40f284c	nf_ct_helper_hsize
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xc7fc80ff	nf_ct_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcecea839	nf_ct_extend_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xcee07a3a	nf_ct_l3protos
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd261cb93	nfnetlink_parse_nat_setup_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xd395b449	__nf_conntrack_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xe2455653	nf_ct_l4proto_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xeadc31ab	nf_ct_l3proto_pernet_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xee1fa1ec	nf_ct_helper_log
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xef6fa54c	nf_ct_invert_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf38bcdf3	nf_conntrack_max
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf777c3e9	nf_connlabel_match
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf86ee9ee	nf_ct_get_tuplepr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xf987d583	nf_ct_expect_alloc
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack 0xfb8be1d5	nf_ct_l4proto_put
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_amanda 0x2baf51d1	nf_nat_amanda_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_broadcast 0xf1fd72ea	nf_conntrack_broadcast_help
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_ftp 0x8febd99d	nf_nat_ftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x049efbb7	nat_callforwarding_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x2f56c831	nat_q931_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x3b8e6796	set_ras_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x6ad09fee	nat_h245_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0x83d915c3	set_h225_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xbc879394	get_h225_addr
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xc5cb2df1	nat_rtp_rtcp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd33182f3	set_sig_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xd71fc24f	nat_t120_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_h323 0xf5de17be	set_h245_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_irc 0xb5987593	nf_nat_irc_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x1f38d54f	nf_nat_pptp_hook_outbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0x87a140d2	nf_nat_pptp_hook_inbound
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xa6fbf85e	nf_nat_pptp_hook_expectfn
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_pptp 0xc7ea1708	nf_nat_pptp_hook_exp_gre
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0x3c0a72fb	nf_ct_gre_keymap_destroy
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_proto_gre 0xa6635d76	nf_ct_gre_keymap_add
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x08cdcefa	nf_nat_sdp_media_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2814fe7e	ct_sip_get_sdp_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2ebe4b6f	ct_sip_get_header
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x2fb89f34	ct_sip_parse_address_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x412e75a2	ct_sip_parse_request
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x6f9b9a35	nf_nat_sip_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x76991e7a	nf_nat_sdp_port_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0x87d7b9c7	nf_nat_sdp_session_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xa74e1206	nf_nat_sip_expect_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xc1fa9301	nf_nat_sdp_addr_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xd89c3680	ct_sip_parse_numerical_param
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xf75395e1	ct_sip_parse_header_uri
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_sip 0xffca8343	nf_nat_sip_seq_adjust_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_snmp 0xf7bd6888	nf_nat_snmp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_conntrack_tftp 0xda869e3b	nf_nat_tftp_hook
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x0d9bae4b	nf_nat_l4proto_nlattr_to_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x131f636c	nf_nat_l4proto_in_range
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4734ed32	nf_nat_l4proto_unique_tuple
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x4c68f398	nf_nat_l3proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x58205729	__nf_nat_l4proto_find
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x5ce5da3c	nf_nat_l4proto_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x7521e822	nf_nat_packet
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x91bd65af	nf_nat_l3proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0x93370ed7	nf_nat_set_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xc62ddbcd	nf_nat_tcp_seq_adjust
++EXPORT_SYMBOL_GPL net/netfilter/nf_nat 0xedc80127	nf_nat_l4proto_register
++EXPORT_SYMBOL_GPL net/netfilter/nf_tproxy_core 0x0a46c77d	nf_tproxy_assign_sock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x2b7304ce	nfnetlink_set_err
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x553f768f	nfnetlink_subsys_unregister
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x5ce3b588	nfnl_lock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0x64e32b6d	nfnetlink_alloc_skb
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc1049a4d	nfnetlink_has_listeners
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xc54f8b95	nfnetlink_send
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xdb065657	nfnl_unlock
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xeb18ad86	nfnetlink_unicast
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink 0xfc6fe4b2	nfnetlink_subsys_register
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0x21f6bba6	nfnl_acct_find_get
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xbecf5d14	nfnl_acct_put
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_acct 0xe188d92d	nfnl_acct_update
++EXPORT_SYMBOL_GPL net/netfilter/nfnetlink_log 0x736360b2	nfulnl_log_packet
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0427c2b8	xt_hook_link
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x05fa96bc	xt_request_find_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x066cf2a0	xt_check_match
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x072490a4	xt_register_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x0f88f289	xt_unregister_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x28338847	xt_table_unlock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x40728a63	xt_find_revision
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x48c33667	xt_proto_fini
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x74082442	xt_hook_unlink
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x807d2b2c	xt_recseq
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x8ed832ea	xt_request_find_target
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0x998f77be	xt_find_table_lock
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xb6abb5eb	xt_replace_table
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xc9f3c932	xt_proto_init
++EXPORT_SYMBOL_GPL net/netfilter/x_tables 0xf2687486	xt_check_target
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0x3a099777	xt_rateest_put
++EXPORT_SYMBOL_GPL net/netfilter/xt_RATEEST 0xf4e9cb5d	xt_rateest_lookup
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x0ad44856	nci_spi_recv_frame
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x61e44a25	nci_spi_allocate_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0x7568a3e4	nci_spi_unregister_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xe5d56a23	nci_spi_register_device
++EXPORT_SYMBOL_GPL net/nfc/nci/nci 0xfa832f29	nci_spi_free_device
++EXPORT_SYMBOL_GPL net/rds/rds 0x00a467af	rds_wq
++EXPORT_SYMBOL_GPL net/rds/rds 0x0587eeff	rds_info_deregister_func
++EXPORT_SYMBOL_GPL net/rds/rds 0x187e2ac1	rds_conn_destroy
++EXPORT_SYMBOL_GPL net/rds/rds 0x19b36011	rds_page_copy_user
++EXPORT_SYMBOL_GPL net/rds/rds 0x1f76055b	rds_for_each_conn_info
++EXPORT_SYMBOL_GPL net/rds/rds 0x243748ed	rds_trans_register
++EXPORT_SYMBOL_GPL net/rds/rds 0x2c5c5514	rds_message_add_rdma_dest_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3101936e	rds_message_add_extension
++EXPORT_SYMBOL_GPL net/rds/rds 0x3b4fc0fc	rds_page_remainder_alloc
++EXPORT_SYMBOL_GPL net/rds/rds 0x40c9a326	rds_conn_connect_if_down
++EXPORT_SYMBOL_GPL net/rds/rds 0x438c415e	rds_connect_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0x50cbe7b3	rds_stats
++EXPORT_SYMBOL_GPL net/rds/rds 0x566d6e48	rds_send_get_message
++EXPORT_SYMBOL_GPL net/rds/rds 0x6204fec1	rds_conn_create
++EXPORT_SYMBOL_GPL net/rds/rds 0x73aac73d	rds_message_populate_header
++EXPORT_SYMBOL_GPL net/rds/rds 0x747390f7	rds_message_unmapped
++EXPORT_SYMBOL_GPL net/rds/rds 0x7941f1ee	rds_recv_incoming
++EXPORT_SYMBOL_GPL net/rds/rds 0x96fafe85	rds_stats_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0x97deb61e	rds_cong_map_updated
++EXPORT_SYMBOL_GPL net/rds/rds 0xa63b26c2	rds_trans_unregister
++EXPORT_SYMBOL_GPL net/rds/rds 0xab932648	rds_conn_drop
++EXPORT_SYMBOL_GPL net/rds/rds 0xb2ebde5f	rds_info_register_func
++EXPORT_SYMBOL_GPL net/rds/rds 0xbfc03a4d	rds_send_drop_acked
++EXPORT_SYMBOL_GPL net/rds/rds 0xc2dab779	rds_info_copy
++EXPORT_SYMBOL_GPL net/rds/rds 0xcc798062	rds_atomic_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xd6bb6fd5	rds_rdma_send_complete
++EXPORT_SYMBOL_GPL net/rds/rds 0xd86ef284	rds_inc_init
++EXPORT_SYMBOL_GPL net/rds/rds 0xdc8f1a4c	rds_conn_create_outgoing
++EXPORT_SYMBOL_GPL net/rds/rds 0xdd8296e4	rds_message_addref
++EXPORT_SYMBOL_GPL net/rds/rds 0xddb030f5	rds_inc_put
++EXPORT_SYMBOL_GPL net/rds/rds 0xf968ca20	rds_message_put
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0x2baab78d	rxrpc_unregister_security
++EXPORT_SYMBOL_GPL net/rxrpc/af-rxrpc 0xf275a536	rxrpc_register_security
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x00c52ef5	g_make_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x3bd92103	gss_mech_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x60f268f6	svcauth_gss_flavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0x8d1a827e	svcauth_gss_register_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xb5dea7ef	g_token_size
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xc11174d5	gss_mech_register
++EXPORT_SYMBOL_GPL net/sunrpc/auth_gss/auth_rpcgss 0xf8b2ff6e	g_verify_token_header
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x012deb03	svc_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0140f350	rpc_killall_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x02ed7383	rpcauth_lookup_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x032c3417	rpc_task_reset_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x045834e9	rpcauth_get_pseudoflavor
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x05e807a9	xdr_encode_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x065994f1	xdr_encode_opaque_fixed
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x066d2af4	rpc_print_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x067c5cdb	xdr_buf_trim
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x071adee1	rpc_bind_new_program
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x07e13331	sunrpc_cache_unregister_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x09746d7d	svc_recv
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0980acde	svc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0a80ead0	cache_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c56f098	xprt_lock_and_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c780138	rpc_uaddr2sockaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0c7e047f	rpc_d_lookup_sb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0cf88874	svc_xprt_names
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x0f668ba9	svc_auth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x118b4972	xprt_wait_for_buffer_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x12971c5a	rpc_unlink
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x131fd1d6	xdr_enter_page
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1445bb83	rpc_release_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x14c49b3c	rpc_destroy_pipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1537c6fc	xdr_decode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1723ca2a	rpcauth_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x17e54d16	svc_prepare_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1889b696	rpcauth_destroy_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x18a8e316	xprt_set_retrans_timeout_def
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1c1ba551	rpc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x1ca85c2a	xdr_encode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x221f9c57	rpc_pton
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x232b5258	__rpc_wait_for_completion_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x24959a00	svc_reg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x277622ae	xprt_write_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x28dadba7	xprt_release_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2919b156	xdr_decode_string_inplace
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x29792974	rpcb_getport_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2b4318b8	cache_check
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2e145a49	svcauth_unix_purge
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2eec63c9	xdr_encode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x2f8ebbe0	rpc_ntop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x30abdda1	auth_domain_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x31a89d59	rpc_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3332f3da	xprt_complete_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x355179e5	rpc_get_timeout
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x382df977	auth_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x387e1639	rpc_pipefs_notifier_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x38fc6965	svc_rpcb_setup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39109f9f	xdr_shift_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x39d27d71	svc_xprt_init
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3a3ca908	cache_register_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3e26bb7f	rpc_pipe_generic_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f149823	xprt_destroy_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x3f6fdab7	sunrpc_cache_update
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4083f35f	rpc_call_start
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x430d97d8	rpcauth_init_credcache
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x43792203	svc_print_addr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x445e3d5d	rpc_force_rebind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x44a2fbe6	_copy_from_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x475557d9	svc_xprt_copy_addrs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48164af0	rpc_sleep_on
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48ec16ad	xdr_decode_word
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x48f60ead	rpc_net_ns
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4957c3ca	svc_drop
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x49ad331e	sunrpc_cache_pipe_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4d3d7c07	rpc_free_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4e222312	rpc_create
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4edb61e0	rpc_wake_up_first
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x4f66f9d4	xdr_skb_read_bits
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x53445f68	nlm_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5429c084	xdr_buf_from_iov
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x560d2d45	rpc_put_task_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5720fc0b	svc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x59241d63	rpc_delay
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e29e27e	rpc_mkpipe_dentry
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5e987001	sunrpc_cache_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x5eb00fe8	sunrpc_cache_register_pipefs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x615c0fbf	rpc_put_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x61c02465	xdr_init_encode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6523248c	svc_unreg_xprt_class
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x65c71639	rpc_wake_up_status
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x66b9e9d7	rpc_localaddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x67ceeed1	rpc_sleep_on_priority
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x69010908	svc_proc_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x694ac832	rpcauth_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6dee6149	xdr_reserve_space
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6e455624	rpc_rmdir
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x6ead1c75	xdr_inline_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x71fa908a	cache_flush
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7218e1d2	xs_swapper
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x72ccc836	rpc_alloc_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x77a0f9ef	cache_destroy_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x78296065	xprt_reserve_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7b51ae63	xdr_buf_read_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7ba8fd19	rpc_shutdown_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7d6799c8	rpc_run_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7de53067	rpc_init_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e310644	rpc_lookup_machine_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7e856d70	xdr_init_decode
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x7f5028c1	xprt_set_retrans_timeout_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x80951b28	rpcauth_get_gssinfo
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x814558f6	svc_xprt_put
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8264d3a6	rpc_malloc
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82f112af	svc_create_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x82f32858	xdr_terminate_string
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x830f12cf	unix_domain_find
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x835cdf25	svc_destroy
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8435e2be	svc_sock_update_bufs
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8863a7c1	svc_addsock
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8b2e9039	svc_close_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x8e659e28	cache_unregister_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x90b27eab	rpcauth_generic_bind_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x915f903c	xprt_alloc_slot
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x929e6d22	xprt_release_rqst_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9456f5bb	xdr_inline_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x945d23c7	xprt_unregister_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x94b65a93	cache_create_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x98b75d64	rpcauth_list_flavors
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9a842a33	xdr_init_decode_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9c62dca3	rpc_lookup_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9c6d7289	rpcauth_init_cred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9c806eb5	rpc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9ca355ee	xprt_disconnect_done
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0x9d8bcfd9	rpc_proc_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa0300e3c	xprt_lookup_rqst
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa22cd0ec	svc_create_pooled
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa2ab7470	rpc_setbufsize
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa3c46d05	rpc_restart_call_prepare
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa47d0fe5	xdr_set_scratch_buffer
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa48db19c	xdr_read_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa55e3dbd	write_bytes_to_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa5c194f9	rpcauth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa6fc1148	svc_bind
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa73b3f7d	xprt_reserve_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xa858204c	xprt_adjust_cwnd
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaa7266e9	rpc_queue_upcall
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xacacd65c	xdr_stream_pos
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaeb5bf54	rpc_protocol
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xaf5bf6ef	nfs_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xafa12b51	put_rpccred
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb0116611	rpc_destroy_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb206ddab	xprt_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb44334dd	xdr_write_pages
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb51a3724	rpc_pipefs_notifier_unregister
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb54c92c5	bc_svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb56ea9d5	rpc_count_iostats
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xb817ee33	sunrpc_init_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbb54c81d	xdr_encode_array2
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf2a0a51	rpc_wake_up_queued_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xbf9d1b96	nfsd_debug
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc12435e3	rpc_calc_rto
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc1a03229	svc_exit_thread
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3880471	xdr_decode_netobj
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc3fe3bd8	read_bytes_from_xdr_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc47319f9	rpc_call_async
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc5c4ec31	xprt_wake_pending_tasks
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc67f4697	svcauth_unix_set_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc70475f5	csum_partial_copy_to_xdr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc80ec561	rpc_peeraddr2str
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xc8e96dea	qword_addhex
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xca1ca07a	svc_authenticate
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xca5a4464	rpc_clone_client_set_auth
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcc089d0c	svc_auth_register
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xccb6c796	xdr_buf_subsegment
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcd08f192	rpc_wake_up_next
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xcee467f3	xprt_load_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd1d3c830	rpc_peeraddr
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd23d1310	xdr_process_buf
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd320dd17	xprt_register_transport
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd3fadf5c	svc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd4417ab3	svc_shutdown_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd49b5d25	rpc_put_task
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xd5504347	rpc_init_priority_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdc030e63	svc_process
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdcd7e5be	rpc_exit
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf40dcc3	svc_xprt_enqueue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdf6f6b9a	rpc_get_sb_net
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xdfb4a8a0	xdr_partial_copy_from_skb
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe0c1187a	svc_reserve
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe1ac2bb8	sunrpc_net_id
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe33e8f00	svc_max_payload
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe3e212f4	sunrpc_destroy_cache_detail
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe40732e7	rpc_restart_call
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe5919cb1	xdr_encode_opaque
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xe97f4ce5	qword_get
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xecc838a2	auth_domain_lookup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf5a94	rpc_clone_client
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xedcf6be4	qword_add
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xeeacab69	rpc_update_rtt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef29f5e2	svc_set_num_threads
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xef59f6e8	rpc_call_null
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf4963bf3	svc_rpcb_cleanup
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf64aefe1	xprt_release_xprt_cong
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf66ec251	rpc_call_sync
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf72c4464	rpc_init_wait_queue
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf81a9236	svc_find_xprt
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xf9d1164c	rpc_free
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfb5ae9bd	rpc_mkpipe_data
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfbb737cf	rpc_wake_up
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfbc28d34	svc_seq_show
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfce8ee82	xprt_setup_backchannel
++EXPORT_SYMBOL_GPL net/sunrpc/sunrpc 0xfd5f5340	xprt_alloc
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x017b4587	vsock_insert_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x08bd735a	vsock_enqueue_accept
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x0c79d5ef	vm_sockets_get_local_cid
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x13fe5941	vsock_stream_has_space
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15912600	__vsock_create
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x15c0c57c	vsock_addr_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x16301d1c	vsock_find_bound_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x2663cb64	vsock_addr_equals_addr
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x32a00798	vsock_remove_pending
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x3d96ff81	vsock_stream_has_data
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x53ffb6bf	vsock_for_each_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x74e91915	vsock_addr_cast
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x751ff010	vsock_addr_unbind
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x7f730c80	vsock_core_exit
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x998b7e97	vsock_find_connected_socket
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0x9da91de5	vsock_core_init
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbd0f699d	vsock_addr_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xbec6acaf	vsock_remove_bound
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xca47fbd0	vsock_remove_connected
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xd95ac116	vsock_addr_validate
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf593c40a	vsock_pending_work
++EXPORT_SYMBOL_GPL net/vmw_vsock/vsock 0xf834df19	vsock_add_pending
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x11a8f733	wimax_msg_data
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x14f77d89	wimax_state_change
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x36f4ac83	wimax_report_rfkill_hw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x3a3aede0	wimax_dev_init
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x47e73cb6	wimax_msg_send
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x66404b29	wimax_state_get
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x95c16344	wimax_msg_alloc
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x994396eb	wimax_msg_data_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0x9f9e8c87	wimax_msg_len
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xa88efc6f	wimax_report_rfkill_sw
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xca27ca40	wimax_dev_add
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xf03a962f	wimax_dev_rm
++EXPORT_SYMBOL_GPL net/wimax/wimax 0xfa77ebab	wimax_msg
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x1426453f	cfg80211_wext_giwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x6fd2e698	cfg80211_wext_giwname
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7d4b26de	cfg80211_wext_giwrange
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x7d8831c1	cfg80211_wext_giwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0x85f30dfc	cfg80211_wext_siwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xa5152e45	cfg80211_wext_giwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xb36b37bc	cfg80211_wext_siwmode
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbad61744	cfg80211_wext_siwscan
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xbe36ade7	cfg80211_wext_giwfrag
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xd608e2e1	cfg80211_wext_siwrts
++EXPORT_SYMBOL_GPL net/wireless/cfg80211 0xe7dd1e9f	cfg80211_wext_giwretry
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x00778770	xfrm_ealg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x056bb269	xfrm_ealg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0a575945	xfrm_count_pfkey_auth_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x0b9e5852	xfrm_aead_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x28e23139	xfrm_probe_algs
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x74e1a843	xfrm_aalg_get_byidx
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7a8ca627	xfrm_count_pfkey_enc_supported
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x7c30b8c7	xfrm_calg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0x92dbc6c1	xfrm_aalg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xbc8b0f41	xfrm_calg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xc0a7bbf9	pskb_put
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xce7a55c1	xfrm_ealg_get_byid
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_algo 0xe122af95	xfrm_aalg_get_byname
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x30b51692	ipcomp_output
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0x5031483b	ipcomp_destroy
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xe6d6cc42	ipcomp_init_state
++EXPORT_SYMBOL_GPL net/xfrm/xfrm_ipcomp 0xf51c79eb	ipcomp_input
++EXPORT_SYMBOL_GPL sound/core/snd 0x1d032592	snd_kctl_jack_new
++EXPORT_SYMBOL_GPL sound/core/snd 0x2270f8a0	snd_ctl_activate_id
++EXPORT_SYMBOL_GPL sound/core/snd 0x23ea603b	snd_ctl_sync_vmaster
++EXPORT_SYMBOL_GPL sound/core/snd 0x3ca17104	__snd_printk
++EXPORT_SYMBOL_GPL sound/core/snd 0x4341a9fb	snd_ctl_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/core/snd 0x9ef756d9	snd_kctl_jack_report
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x5a11a268	snd_compress_deregister
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0x85cdd4b0	snd_compress_new
++EXPORT_SYMBOL_GPL sound/core/snd-compress 0xa869ba3b	snd_compress_register
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x04e1b99f	snd_pcm_std_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x09e913c1	snd_pcm_alt_chmaps
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x3e6b0506	snd_pcm_lib_default_mmap
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0x49a40ecd	snd_pcm_add_chmap_ctls
++EXPORT_SYMBOL_GPL sound/core/snd-pcm 0xa286a234	snd_pcm_format_name
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x09e498f6	snd_ak4113_check_rate_and_errors
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x25dc3d70	snd_ak4113_build
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x4866b0ad	snd_ak4113_external_rate
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x4a35e7c3	snd_ak4113_create
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0x607d0fd4	snd_ak4113_reinit
++EXPORT_SYMBOL_GPL sound/i2c/other/snd-ak4113 0xe5042983	snd_ak4113_reg_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x033d357b	snd_hda_get_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x03528f16	snd_hda_gen_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x036e331d	snd_hda_jack_tbl_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x04d84b32	snd_hda_codec_configure
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0631505e	snd_hda_mixer_amp_volume_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0676f5ac	snd_hda_get_input_pin_attr
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x07268d35	snd_hda_multi_out_dig_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0b0120f8	snd_hda_multi_out_dig_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0c2bf595	snd_hda_codec_get_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x0e5d505f	snd_hda_jack_tbl_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1113ea96	snd_hda_query_supported_pcm
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x12c9ec48	snd_hda_correct_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x136e2654	snd_hda_add_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x13786827	snd_hda_gen_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x162e341b	snd_hda_mixer_bind_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1a2ad584	snd_hda_codec_set_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x1d1ece43	snd_hda_shutup_pins
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x212d5b36	snd_hda_gen_spec_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x225dd41a	snd_hda_bus_reboot_notify
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x22ade029	snd_hda_gen_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x230e59c9	snd_hda_mixer_bind_ctls_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x2323add7	snd_hda_codec_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x27eb078d	snd_hda_override_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x31262cd7	snd_hda_jack_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x32e87ce5	snd_hda_query_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3531c40a	snd_hda_detach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3600b4ea	snd_hda_is_supported_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x375cacd5	snd_hda_input_mux_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x386487c3	snd_hda_get_path_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3a028cc2	snd_hda_create_dig_out_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d455d5d	snd_hda_ch_mode_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d4f281f	snd_hda_add_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x3d839e4a	snd_hda_apply_pincfgs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x43c89109	snd_hda_codec_update_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44977473	snd_hda_gen_add_kctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x44aedadf	snd_hda_get_bool_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x457fc9a8	snd_hda_enum_helper_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x45bda783	snd_hda_get_path_from_idx
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x465ce4ec	snd_hda_gen_hp_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x46c4423b	snd_hda_jack_set_dirty_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4da33bf3	snd_hda_add_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4dab1f60	snd_hda_add_imux_item
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4e55ad4e	snd_hda_build_pcms
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4f360879	snd_hda_codec_eapd_power_filter
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x4f82d675	snd_hda_multi_out_dig_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x53440242	snd_hda_codec_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x53ac66ec	snd_hda_codec_resume_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x55d75a65	snd_hda_suspend
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x56285d02	query_amp_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a0b48d7	snd_hda_codec_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a200900	snd_hda_codec_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5a812832	snd_hda_jack_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5b50e5c1	snd_hda_check_amp_list_power
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5bf358ed	snd_hda_parse_generic_codec
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5cfcc462	snd_hda_gen_line_automute
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x5f12182a	snd_hda_codec_set_pincfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6038f051	snd_hda_multi_out_analog_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x61e8196c	snd_hda_ch_mode_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x657aa4b2	snd_hda_bus_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x664661c1	snd_hda_mixer_amp_switch_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x679cf0f1	snd_hda_gen_check_power_status
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67bb7422	_snd_hda_set_pin_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x67eb4619	snd_hda_jack_detect_enable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x684c2560	snd_hda_mixer_amp_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6a1e22e3	snd_hda_jack_tbl_get_from_tag
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x6b49970c	snd_hda_lock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x71df24ec	snd_hda_mixer_amp_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x76dc6871	hda_main_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x798fed17	snd_hda_multi_out_dig_close
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x79aba85e	snd_hda_codec_amp_read
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7a100c63	snd_hda_codec_flush_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7d40b8a5	snd_hda_spdif_ctls_assign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x7db9b758	snd_hda_mixer_amp_switch_put_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x80dcc2b6	snd_hda_sequence_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x82054e63	snd_hda_codec_write_cache
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x82404be3	snd_hda_enable_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x843d8abb	snd_hda_codec_prepare
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8686aaa8	snd_hda_codec_setup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x871a6e44	hda_extra_out_badness
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8858256a	snd_hda_codec_amp_stereo
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x88622176	snd_hda_gen_spec_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x88823613	snd_hda_check_board_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x88e726ca	snd_hda_add_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x890c2a27	snd_hda_gen_mic_autoswitch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8ae114bd	snd_hda_jack_report_sync
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x8e4c6826	snd_hda_calc_stream_format
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x92133670	snd_hda_ch_mode_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x95c43559	snd_hda_jack_set_gating_jack
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x966a32d7	snd_hda_pin_sense
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9955fd43	snd_hda_override_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a8b6077	snd_hda_sync_vmaster_hook
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9a8e1877	snd_array_free
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0x9c84f0a1	snd_hda_codec_set_power_to_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa0d66383	snd_hda_get_conn_index
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa1699acf	snd_hda_add_new_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa21b347d	snd_hda_jack_detect_enable_callback
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa2827d76	snd_hda_get_jack_location
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa4977d73	snd_hda_activate_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa66bd370	snd_hda_mixer_amp_switch_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa945f978	snd_hda_get_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xa97f2275	snd_hda_get_pin_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xab0fd9db	snd_hda_mixer_bind_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xab650cca	snd_hda_find_mixer_ctl
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xac2f8d30	snd_hda_get_conn_list
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb1d83991	snd_hda_create_spdif_in_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb36b9e8a	snd_hda_bind_vol
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb58ae21b	snd_hda_multi_out_analog_open
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xb9cb1616	snd_hda_get_connections
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbbf94479	snd_hda_unlock_devices
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xbe7dd7dc	snd_array_new
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc05954cf	hda_get_autocfg_input_label
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc11e6985	is_jack_detectable
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc355a245	snd_hda_create_spdif_share_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc4197f1b	snd_hda_codec_amp_update
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc5910353	snd_hda_jack_detect
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc61ce2ef	snd_hda_mixer_amp_volume_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc652fd69	snd_hda_get_jack_connectivity
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc6c4bd8b	snd_hda_gen_parse_auto_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc816a64e	snd_hda_mixer_amp_volume_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc85afc6d	__snd_hda_codec_cleanup_stream
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc98aa07e	snd_hda_apply_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xc9eec3f7	snd_hda_get_default_vref
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb301b6e	snd_hda_get_jack_type
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcb6e7640	snd_hda_ctl_add
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xcf237837	snd_hda_gen_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd0965ada	snd_hda_input_mux_put
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2525572	snd_hda_codec_update_widgets
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd2aa1282	snd_hda_override_pin_caps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd76d08fe	snd_hda_apply_verbs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd809c20b	snd_hda_mixer_bind_switch_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xd8a4bd72	snd_hda_codec_get_pin_target
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdab7b38d	snd_hda_pick_fixup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdd0d86d7	snd_hda_resume
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdf1d9cff	snd_hda_codec_amp_init
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdf79ef3b	snd_hda_power_save
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xdffebc48	__snd_hda_add_vmaster
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe118de5d	snd_pcm_2_1_chmaps
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe192b3f5	snd_hda_set_vmaster_tlv
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe288c63f	snd_hda_jack_poll_all
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe323eb78	snd_hda_mixer_bind_ctls_info
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe32a318e	snd_hda_codec_resume_amp
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe3320c1a	snd_hda_sequence_write
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe4d0ccc4	snd_hda_build_controls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe835a62f	snd_hda_parse_nid_path
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe8898c64	snd_hda_load_patch
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe8c341cb	snd_hda_multi_out_analog_cleanup
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xe97aabbc	snd_hda_mixer_amp_switch_get_beep
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xea7ce0ef	snd_hda_jack_add_kctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeb85cb32	snd_hda_delete_codec_preset
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xed29afd9	snd_hda_mixer_bind_ctls_get
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xeda3a721	snd_print_pcm_bits
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xee09f2d3	snd_hda_attach_beep_device
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xee8ba4ba	snd_hda_add_new_ctls
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xef45502d	snd_hda_spdif_out_of_nid
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1804f77	snd_hda_queue_unsol_event
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf18bfa02	snd_hda_check_board_codec_sid_config
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf1cd0ab1	snd_hda_spdif_ctls_unassign
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf93483f7	snd_hda_bind_sw
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xf9fd1196	snd_hda_gen_update_outputs
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfabc6d00	snd_hda_parse_pin_defcfg
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfadaf55a	snd_hda_get_int_hint
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfb92ff2e	snd_hda_get_sub_nodes
++EXPORT_SYMBOL_GPL sound/pci/hda/snd-hda-codec 0xfe9f8d93	snd_hda_codec_amp_init_stereo
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x064c82ab	atmel_pcm_free
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0x2c10360d	atmel_pcm_mmap
++EXPORT_SYMBOL_GPL sound/soc/atmel/snd-soc-atmel-pcm 0xd74bfcb1	atmel_pcm_new
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0x897d5b0f	pm860x_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-88pm860x 0xb072abb1	pm860x_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0x5dc2d76d	ab8500_audio_set_ear_cmv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-ab8500-codec 0xc0efc9b4	ab8500_audio_setup_mics
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x000d6c72	arizona_simple_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x05ddbf0f	arizona_lhpf4_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x12ecde17	arizona_out_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x196694e3	arizona_ng_hold
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x206e3ddf	arizona_in_vi_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x2a3fdbb4	arizona_set_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3ded58b2	arizona_in_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3f0adea1	arizona_init_dai
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x3f429d4c	arizona_isrc_fsl
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x41b95c1f	arizona_in_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x525683a8	arizona_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x547a7178	arizona_rate_val
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x57e590a8	arizona_lhpf1_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x660d8a35	arizona_lhpf2_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x733bbfd7	arizona_out_vd_ramp
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x7f59c962	arizona_init_spk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8c821bc2	arizona_rate_text
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0x8dd35bf2	arizona_mixer_values
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xa2b79364	arizona_hp_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xab6861be	arizona_mixer_texts
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc07a8181	arizona_lhpf3_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xc9c29637	arizona_mixer_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xcaea0929	arizona_init_fll
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xcba804ac	arizona_dai_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xdbe190ed	arizona_set_fll_refclk
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xe0e305e1	arizona_out_ev
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-arizona 0xeb5bf52c	arizona_set_output_mode
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-cx20442 0x3fd1323a	v253_ops
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-l3 0x78c84c7e	l3_write
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98090 0x2be6ba23	max98090_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max98095 0x17900cca	max98095_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-max9877 0x6eefd820	max9877_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-sn95031 0x084e0871	sn95031_jack_detection
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x582e1621	tpa6130a2_stereo_enable
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-tpa6130a2 0x8c9625a9	tpa6130a2_add_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x5c3eae05	twl6040_get_clk_id
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x81b768a0	twl6040_get_dl1_gain
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0x948a2ca5	twl6040_get_hs_step_size
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xd0c1d5ad	twl6040_get_trim_value
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-twl6040 0xeabf09cb	twl6040_hs_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wl1273 0x7438c0c0	wl1273_get_format
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x1dd0506a	wm_adsp2_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x2c667a2a	wm_adsp1_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x36b61bb1	wm_adsp2_event
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x636dd459	wm_adsp1_init
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x78c7475a	wm_adsp2_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-adsp 0x92419a38	wm_adsp1_fw_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x22373472	wm_hubs_update_class_w
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x32799d73	wm_hubs_handle_analogue_pdata
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x5cd7eb9b	wm_hubs_dcs_done
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x6555994f	wm_hubs_set_bias_level
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x757206d5	wm_hubs_spkmix_tlv
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0x983502a9	wm_hubs_hpr_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xa1e96142	wm_hubs_hpl_mux
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xa69fffd3	wm_hubs_vmid_ena
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xd2513a3a	wm_hubs_add_analogue_controls
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm-hubs 0xe5295ae2	wm_hubs_add_analogue_routes
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0x91177319	wm8350_hp_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8350 0xc01461d2	wm8350_mic_jack_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8903 0x305a23e3	wm8903_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8962 0xb865d8a2	wm8962_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0x079e8006	wm8994_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8994 0xe2af40ee	wm8958_mic_detect
++EXPORT_SYMBOL_GPL sound/soc/codecs/snd-soc-wm8996 0x5dd85e65	wm8996_detect
++EXPORT_SYMBOL_GPL sound/soc/mid-x86/snd-soc-sst-platform 0xa1bc13a5	sst_unregister_dsp
++EXPORT_SYMBOL_GPL sound/soc/mid-x86/snd-soc-sst-platform 0xcf0ab00d	sst_register_dsp
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x004a5337	snd_soc_register_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x007be04c	snd_soc_info_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x009411aa	snd_soc_dpcm_be_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x04d89a1c	snd_soc_register_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x06410c7f	snd_soc_dai_set_fmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x06dceffb	snd_soc_of_parse_daifmt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x07228f06	snd_soc_codec_set_cache_io
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x08ab1d20	snd_soc_put_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0b61f373	snd_soc_dapm_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d03f43f	snd_soc_unregister_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0d04611e	snd_soc_jack_add_pins
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x0f674773	snd_soc_get_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11320a62	snd_soc_new_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x11668a76	snd_soc_info_enum_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1252dfcd	snd_soc_get_pcm_runtime
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18657c4f	snd_soc_codec_writable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x18fd2f1f	snd_soc_jack_add_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1990dae3	snd_soc_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x19baa6d7	snd_soc_set_runtime_hwparams
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1c4cc7c9	snd_soc_dai_digital_mute
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1c96dd8b	snd_soc_codec_readable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1ee4ad09	snd_soc_put_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x1fdd8243	snd_soc_default_readable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x21433d05	snd_soc_pm_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x22ce27b8	snd_soc_bytes_get
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2437e3a1	snd_soc_platform_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2541a979	snd_soc_calc_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x25b3204c	snd_soc_dapm_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2729afd1	snd_soc_dpcm_be_get_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2822b695	snd_soc_dpcm_can_be_free_stop
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2d53d812	snd_soc_resume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x2ef569b7	snd_soc_dapm_new_widgets
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x31b574f2	snd_soc_dapm_mux_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32514a04	snd_soc_add_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x32a09947	dapm_mark_io_dirty
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3872aab7	snd_soc_dpcm_can_be_params
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x38e527a8	snd_soc_jack_free_gpios
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x395b17a4	snd_soc_dai_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3c82b315	snd_soc_info_volsw_ext
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x3dd17765	snd_soc_platform_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x402db07c	snd_soc_of_parse_audio_routing
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x428d135f	snd_soc_info_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b3ee05b	snd_soc_info_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5b6241fb	snd_soc_of_parse_card_name
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5c7b66dc	snd_soc_dai_set_channel_map
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5d8e5e2f	snd_soc_test_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x5dd6ffba	snd_soc_codec_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x62fcfcdb	snd_soc_dpcm_be_set_state
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x66e773a1	snd_soc_get_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6716f824	snd_soc_dapm_get_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x69b488b5	snd_soc_free_ac97_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6a1d85ba	snd_soc_cnew
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6bf78a93	snd_soc_dai_set_tdm_slot
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6ca3bf0b	dapm_clock_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x6e0a46f8	snd_soc_dapm_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x715bc61b	snd_soc_dapm_info_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x75df451b	snd_soc_default_volatile_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x78563bca	snd_soc_unregister_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x788dd67c	snd_soc_put_strobe
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7b013080	snd_soc_info_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7c63b0e1	snd_soc_dapm_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7da438d5	snd_soc_jack_report
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e606130	snd_soc_calc_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x7e69b20d	snd_soc_dai_set_clkdiv
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x825f1cb7	snd_soc_cache_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8341f915	snd_soc_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x84358eff	snd_soc_get_volsw_range
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x88dd7c6e	dpcm_be_dai_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8aacde2d	snd_soc_get_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b4a65c3	soc_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8b7fa0be	snd_soc_default_writable_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8c83f945	snd_soc_codec_volatile_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8caac39c	snd_soc_get_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8d5d2dbb	snd_soc_jack_add_zones
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x8e94e7c4	snd_soc_dpcm_get_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x92de0bcc	snd_soc_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x936837ee	snd_soc_dapm_add_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9519cf52	snd_soc_dapm_get_pin_status
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x97f529f5	snd_soc_platform_trigger
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x99a97c64	snd_soc_set_ac97_ops
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9a81ef7f	snd_soc_get_volsw_s8
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9c965ad7	snd_soc_add_platform_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9d4db52c	snd_soc_put_volsw_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9e8b9637	snd_soc_register_component
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f660200	snd_soc_remove_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0x9f8c9a17	snd_soc_dapm_free
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa138774b	snd_soc_limit_volume
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa15d52c1	snd_soc_dai_set_sysclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa38cca1d	snd_soc_cache_sync
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa797beac	snd_soc_debugfs_root
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xa8b6b859	snd_soc_jack_new
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xab0b5bf1	snd_soc_add_codec_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xac5308c3	snd_soc_get_dai_substream
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xad941f37	snd_soc_jack_notifier_unregister
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb1d33217	snd_soc_add_dai_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xb37021e6	snd_soc_dapm_put_enum_virt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbb3947fd	snd_soc_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xbc5f8ca1	snd_soc_codec_set_pll
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc0cd7efb	snd_soc_bytes_info
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc1be48fb	snd_soc_get_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc24b80de	snd_soc_register_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc30795df	dapm_regulator_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc3940781	snd_soc_dapm_get_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc3ee25c2	snd_soc_dapm_put_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc46d3635	snd_soc_dapm_disable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc664d1c8	snd_soc_add_card_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xc8269f94	snd_soc_params_to_frame_size
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xca2ea0d5	snd_soc_poweroff
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xcba99ec5	snd_soc_info_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd071b54b	dapm_reg_event
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd07e615c	snd_soc_cache_write
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd1a59364	snd_soc_read
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd4095e3c	snd_soc_dapm_put_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd52cd92a	snd_soc_bytes_put
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd7847c2c	snd_soc_dapm_put_pin_switch
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd845f078	snd_soc_dapm_ignore_suspend
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd9625efa	snd_soc_jack_notifier_register
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xd98f2da0	snd_soc_jack_get_type
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xda62448a	snd_soc_dapm_get_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdceaabbd	snd_soc_dapm_weak_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xde791af3	snd_soc_dapm_new_controls
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xdfc36e9c	snd_soc_update_bits_locked
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe00db07a	snd_soc_unregister_codec
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe177ae68	snd_soc_dapm_mixer_update_power
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe1fb6bbf	snd_soc_put_xr_sx
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe3f3f662	snd_soc_dai_set_tristate
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe7fd760e	snd_soc_put_volsw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xe888a49b	snd_soc_update_bits
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xea7804f1	snd_soc_put_value_enum_double
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xeb711ae7	snd_soc_params_to_bclk
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xee96175a	snd_soc_dapm_del_routes
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xefec4761	snd_soc_lookup_platform
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf16c0b9c	snd_soc_dapm_get_enum_virt
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf42aa4cb	snd_soc_unregister_card
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf4925d40	snd_soc_dapm_force_enable_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xf5ddd9c7	snd_soc_dapm_nc_pin
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfabac96e	snd_soc_dpcm_fe_can_update
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfabd5de8	snd_soc_bulk_write_raw
++EXPORT_SYMBOL_GPL sound/soc/snd-soc-core 0xfc014576	dapm_mark_dirty
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x041431fc	lib_ring_buffer_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x0c860291	lib_ring_buffer_read_cstr
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x0cf7307a	channel_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x13a128c3	lib_ring_buffer_ioctl
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1710f8a5	lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x17933fa1	__lib_ring_buffer_copy_to_user
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x196d677d	channel_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1c067ce3	channel_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x1d8b49af	_lib_ring_buffer_copy_from_user_inatomic
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x34ddf71f	vfs_lib_ring_buffer_no_llseek
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x38106cf8	lib_ring_buffer_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x3a992279	channel_payload_file_operations
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4a8114a0	lib_ring_buffer_get_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x4afb7bbe	channel_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x51eb325d	lib_ring_buffer_switch_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x5811b86e	channel_get_ring_buffer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x68d7e196	lib_ring_buffer_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x70dfc440	lib_ring_buffer_read_get_page
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x78887e54	lib_ring_buffer_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x80e2d98e	lib_ring_buffer_poll
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x959e51fd	lib_ring_buffer_reserve_slow
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0x9f6d615f	lib_ring_buffer_reset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xab46b26d	lib_ring_buffer_iterator_release
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xae8face1	vfs_lib_ring_buffer_splice_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xba46c952	lib_ring_buffer_read_offset_address
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xbb5d8510	lib_ring_buffer_release_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xbd6cf86e	lib_ring_buffer_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc2057f2f	lib_ring_buffer_put_subbuf
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc3a0fb3a	lib_ring_buffer_open_read
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xc4e855b2	lib_ring_buffer_get_next_record
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xd73cb7db	channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xda4d3da9	lib_ring_buffer_iterator_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe085fac4	lib_ring_buffer_snapshot
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe52e49fe	lib_ring_buffer_switch_remote
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe57a555a	lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xe7bec510	lib_ring_buffer_open
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xef753aec	vfs_lib_ring_buffer_mmap
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xefd13f7d	_lib_ring_buffer_memset
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xf4a85b73	lib_ring_buffer_move_consumer
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xfdcdc59a	channel_create
++EXPORT_SYMBOL_GPL ubuntu/lttng/lib/lttng-lib-ring-buffer 0xfe277bc1	_lib_ring_buffer_write
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-statedump 0x01ed560e	lttng_statedump_start
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x0d2ab26b	lttng_remove_context_field
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x1d54bcb5	lttng_event_get
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x1feeb8f3	lttng_add_vpid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x23db28f1	lttng_add_procname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x4c80ebce	lttng_event_put
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x4ec283ba	lttng_append_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x5baf66c6	lttng_add_prio_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x668f130c	lttng_probe_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x6a01275b	lttng_add_ppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x709a84f5	lttng_add_tid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x8d7a0eba	lttng_add_vtid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0x953123ec	lttng_add_nice_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xad21e6b3	lttng_probe_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xbf2a0563	lttng_add_vppid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xc2d55a7f	lttng_add_hostname_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xc80b5be5	lttng_metadata_channel_destroy
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xe15f3fba	lttng_find_context
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xe20e32bc	lttng_add_pid_to_ctx
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xf233a8e9	lttng_transport_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/lttng-tracer 0xf383458f	lttng_transport_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0x5d557d6b	lttng_ftrace_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0x66ad1aea	lttng_ftrace_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-ftrace 0xbf887809	lttng_ftrace_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x6be97947	lttng_kprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0x8fd650dc	lttng_kprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kprobes 0xae6b5d2a	lttng_kprobes_destroy_private
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0x7507757d	lttng_kretprobes_register
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xbe90067d	lttng_kretprobes_unregister
++EXPORT_SYMBOL_GPL ubuntu/lttng/probes/lttng-kretprobes 0xd1c92f42	lttng_kretprobes_destroy_private
++EXPORT_SYMBOL_GPL vmlinux 0x00332a97	pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x0039e4f2	regulator_register
++EXPORT_SYMBOL_GPL vmlinux 0x00632780	work_busy
++EXPORT_SYMBOL_GPL vmlinux 0x0067df75	ata_tf_from_fis
++EXPORT_SYMBOL_GPL vmlinux 0x007deb8d	efivars_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x00c4dc87	timecounter_init
++EXPORT_SYMBOL_GPL vmlinux 0x00ebcb5d	ata_id_string
++EXPORT_SYMBOL_GPL vmlinux 0x01010c6d	klist_add_before
++EXPORT_SYMBOL_GPL vmlinux 0x011cf028	regulator_suspend_finish
++EXPORT_SYMBOL_GPL vmlinux 0x0134b5f6	usb_register_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0170cb6c	efivar_work
++EXPORT_SYMBOL_GPL vmlinux 0x01715676	__mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x0177244d	crypto_shash_final
++EXPORT_SYMBOL_GPL vmlinux 0x01848a8e	local_apic_timer_c2_ok
++EXPORT_SYMBOL_GPL vmlinux 0x019b2d7c	ata_acpi_stm
++EXPORT_SYMBOL_GPL vmlinux 0x01b7fd6a	led_trigger_rename_static
++EXPORT_SYMBOL_GPL vmlinux 0x01d11a05	wakeup_source_register
++EXPORT_SYMBOL_GPL vmlinux 0x01e1a8de	kgdb_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x02090887	ata_host_activate
++EXPORT_SYMBOL_GPL vmlinux 0x026211e2	memory_failure_queue
++EXPORT_SYMBOL_GPL vmlinux 0x0269869f	mnt_want_write_file
++EXPORT_SYMBOL_GPL vmlinux 0x027016ca	crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x02726a37	device_bind_driver
++EXPORT_SYMBOL_GPL vmlinux 0x02a6357a	print_context_stack_bp
++EXPORT_SYMBOL_GPL vmlinux 0x02bd601f	uart_insert_char
++EXPORT_SYMBOL_GPL vmlinux 0x02c02436	blkg_prfill_stat
++EXPORT_SYMBOL_GPL vmlinux 0x02c103e3	acpi_subsys_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x02c4c3dd	dequeue_signal
++EXPORT_SYMBOL_GPL vmlinux 0x02f7c59c	pci_hp_create_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x03324263	fat_alloc_new_dir
++EXPORT_SYMBOL_GPL vmlinux 0x0343bdf1	__i2c_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x034ca059	adp5520_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x03702029	usb_hcd_pci_remove
++EXPORT_SYMBOL_GPL vmlinux 0x0379efcc	tcp_slow_start
++EXPORT_SYMBOL_GPL vmlinux 0x03b38a91	evm_verifyxattr
++EXPORT_SYMBOL_GPL vmlinux 0x03e3686c	ata_timing_cycle2mode
++EXPORT_SYMBOL_GPL vmlinux 0x041452cf	__netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0x04152314	vfs_listxattr
++EXPORT_SYMBOL_GPL vmlinux 0x041fd6fc	pcie_port_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x04341bd3	blkcipher_walk_virt_block
++EXPORT_SYMBOL_GPL vmlinux 0x04486e88	rcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x0465a073	regmap_reg_in_ranges
++EXPORT_SYMBOL_GPL vmlinux 0x046cba6d	ata_sff_tf_read
++EXPORT_SYMBOL_GPL vmlinux 0x0487ad27	usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x04bf26af	ioremap_page_range
++EXPORT_SYMBOL_GPL vmlinux 0x04c3f2c1	gnttab_empty_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x04c4f603	mpi_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x04d8b0b4	sdio_writeb_readb
++EXPORT_SYMBOL_GPL vmlinux 0x04f4f6e0	wm8400_reset_codec_reg_cache
++EXPORT_SYMBOL_GPL vmlinux 0x05011875	crypto_larval_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x051401d2	pci_max_pasids
++EXPORT_SYMBOL_GPL vmlinux 0x0527ad46	cpuidle_get_driver
++EXPORT_SYMBOL_GPL vmlinux 0x052cadc0	rio_request_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x0531dcb8	ata_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x05338c5d	ata_sff_data_xfer32
++EXPORT_SYMBOL_GPL vmlinux 0x0549bc00	kobject_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x054e550b	kernel_halt
++EXPORT_SYMBOL_GPL vmlinux 0x0551f0ce	tick_nohz_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x056a36af	set_cpus_allowed_ptr
++EXPORT_SYMBOL_GPL vmlinux 0x058b582a	vt_get_leds
++EXPORT_SYMBOL_GPL vmlinux 0x05963ea8	da9052_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x05dcff2d	dev_pm_qos_expose_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0x05fb06f9	scsi_nl_sock
++EXPORT_SYMBOL_GPL vmlinux 0x060d1064	set_memory_ro
++EXPORT_SYMBOL_GPL vmlinux 0x0626da5f	od_unregister_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x062e2202	ata_scsi_simulate
++EXPORT_SYMBOL_GPL vmlinux 0x062fc169	xen_hvm_resume_frames
++EXPORT_SYMBOL_GPL vmlinux 0x063be8e4	swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x064db9a5	mark_mounts_for_expiry
++EXPORT_SYMBOL_GPL vmlinux 0x0659c3bd	ata_link_abort
++EXPORT_SYMBOL_GPL vmlinux 0x066cbb11	i2c_new_dummy
++EXPORT_SYMBOL_GPL vmlinux 0x067c9a91	simple_attr_write
++EXPORT_SYMBOL_GPL vmlinux 0x067d9ecc	ata_pci_bmdma_clear_simplex
++EXPORT_SYMBOL_GPL vmlinux 0x06963c36	intel_msic_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x069f4a2d	__rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x06bc28bd	sata_set_spd
++EXPORT_SYMBOL_GPL vmlinux 0x06bd96cb	dev_change_net_namespace
++EXPORT_SYMBOL_GPL vmlinux 0x06beee13	devres_add
++EXPORT_SYMBOL_GPL vmlinux 0x06e9d649	device_attach
++EXPORT_SYMBOL_GPL vmlinux 0x06f2a4ab	__fat_fs_error
++EXPORT_SYMBOL_GPL vmlinux 0x06f97ec0	adp5520_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x07142ea9	perf_event_disable
++EXPORT_SYMBOL_GPL vmlinux 0x0723ddbb	napi_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x0736a528	scsi_eh_ready_devs
++EXPORT_SYMBOL_GPL vmlinux 0x0762403c	edac_put_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x07675cfb	regulator_set_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x078c0137	btree_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x07b21f85	kdb_get_kbd_char
++EXPORT_SYMBOL_GPL vmlinux 0x07b52e38	rtnl_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x07b8dfb4	skb_scrub_packet
++EXPORT_SYMBOL_GPL vmlinux 0x07cdde10	apei_get_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0x07cf3227	clk_fixed_rate_ops
++EXPORT_SYMBOL_GPL vmlinux 0x07f300c3	smp_call_function_any
++EXPORT_SYMBOL_GPL vmlinux 0x07fc478e	acpi_dev_resource_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x081f3f01	__rio_local_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x0837ef35	cpufreq_frequency_table_target
++EXPORT_SYMBOL_GPL vmlinux 0x0856a524	get_task_mm
++EXPORT_SYMBOL_GPL vmlinux 0x086aaa18	dma_buf_map_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x086c7a11	setup_irq
++EXPORT_SYMBOL_GPL vmlinux 0x08793c20	crypto_alloc_ablkcipher
++EXPORT_SYMBOL_GPL vmlinux 0x08dcdeae	ohci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x08f17ee7	cpci_hp_register_bus
++EXPORT_SYMBOL_GPL vmlinux 0x09002b77	fuse_conn_put
++EXPORT_SYMBOL_GPL vmlinux 0x091eb9b4	round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0x092f7401	cpuidle_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x09422a86	driver_find
++EXPORT_SYMBOL_GPL vmlinux 0x09437748	ring_buffer_read_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x09469482	kfree_call_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x095286c9	ata_link_online
++EXPORT_SYMBOL_GPL vmlinux 0x09578eab	usb_init_urb
++EXPORT_SYMBOL_GPL vmlinux 0x0960d914	elv_register
++EXPORT_SYMBOL_GPL vmlinux 0x0962d0e8	irq_set_affinity_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x097f906a	sata_link_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x09b1d009	device_rename
++EXPORT_SYMBOL_GPL vmlinux 0x09bb2601	tcp_unregister_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x09dd63d8	sec_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x0a6053f3	pm_generic_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x0a8b7455	__inet_lookup_established
++EXPORT_SYMBOL_GPL vmlinux 0x0a920c65	da9052_disable_irq
++EXPORT_SYMBOL_GPL vmlinux 0x0adce468	pci_cleanup_aer_uncorrect_error_status
++EXPORT_SYMBOL_GPL vmlinux 0x0adef2f3	regulator_list_voltage_table
++EXPORT_SYMBOL_GPL vmlinux 0x0ae31757	sysfs_create_group
++EXPORT_SYMBOL_GPL vmlinux 0x0ae49685	usb_hcd_unmap_urb_setup_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0afc28eb	blk_execute_rq_nowait
++EXPORT_SYMBOL_GPL vmlinux 0x0afd4610	zs_malloc
++EXPORT_SYMBOL_GPL vmlinux 0x0b05509d	kern_mount_data
++EXPORT_SYMBOL_GPL vmlinux 0x0b06e4cb	xfrm_inner_extract_output
++EXPORT_SYMBOL_GPL vmlinux 0x0b07abe2	unshare_fs_struct
++EXPORT_SYMBOL_GPL vmlinux 0x0b0a6846	acpi_subsys_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x0b138203	usb_put_dev
++EXPORT_SYMBOL_GPL vmlinux 0x0b19ed7c	apei_estatus_check_header
++EXPORT_SYMBOL_GPL vmlinux 0x0b33ea99	ata_sff_queue_pio_task
++EXPORT_SYMBOL_GPL vmlinux 0x0b52e502	apei_resources_add
++EXPORT_SYMBOL_GPL vmlinux 0x0b581a8c	serial8250_tx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x0b59390b	__tracepoint_rpm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x0b719433	inet6_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x0b84b56b	usb_interrupt_msg
++EXPORT_SYMBOL_GPL vmlinux 0x0b98e2eb	posix_timer_event
++EXPORT_SYMBOL_GPL vmlinux 0x0bac4ecb	ip6_dst_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x0bae62b1	ktime_get_monotonic_offset
++EXPORT_SYMBOL_GPL vmlinux 0x0bfa3a19	rcu_idle_exit
++EXPORT_SYMBOL_GPL vmlinux 0x0c0c015e	ring_buffer_swap_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x0c2cdbf1	synchronize_sched
++EXPORT_SYMBOL_GPL vmlinux 0x0c57c939	pm_runtime_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0c5a0ae9	crypto_init_shash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x0c6bc0df	acpi_dma_request_slave_chan_by_index
++EXPORT_SYMBOL_GPL vmlinux 0x0c74ff7b	aead_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x0c805f93	clflush_cache_range
++EXPORT_SYMBOL_GPL vmlinux 0x0c80e3fe	efivar_init
++EXPORT_SYMBOL_GPL vmlinux 0x0cb5a51f	cgroup_taskset_cur_cgroup
++EXPORT_SYMBOL_GPL vmlinux 0x0cc1e40f	crypto_it_tab
++EXPORT_SYMBOL_GPL vmlinux 0x0cdab6c9	dev_pm_qos_add_ancestor_request
++EXPORT_SYMBOL_GPL vmlinux 0x0cdadff4	pm_generic_freeze_late
++EXPORT_SYMBOL_GPL vmlinux 0x0ce8e0a3	dma_buf_kmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0x0d01409f	ip4_datagram_release_cb
++EXPORT_SYMBOL_GPL vmlinux 0x0d34727c	serial8250_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x0d3b4e8c	perf_event_refresh
++EXPORT_SYMBOL_GPL vmlinux 0x0d50c9aa	blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x0e13cb4d	apei_resources_release
++EXPORT_SYMBOL_GPL vmlinux 0x0e15d8cb	devm_regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x0e21544f	wm8994_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x0e3705c9	pci_user_read_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x0e53f8ce	acpi_dev_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x0e95fee4	regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x0ea394c1	tty_ldisc_ref
++EXPORT_SYMBOL_GPL vmlinux 0x0ef06974	spi_populate_ppr_msg
++EXPORT_SYMBOL_GPL vmlinux 0x0f019611	shash_ahash_update
++EXPORT_SYMBOL_GPL vmlinux 0x0f2d7d87	mce_unregister_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0x0f3b88c9	usb_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x0f5fe39a	cpuidle_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0x0f682fe8	pci_restore_msi_state
++EXPORT_SYMBOL_GPL vmlinux 0x0f751aea	input_event_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x0f938bfa	locks_release_private
++EXPORT_SYMBOL_GPL vmlinux 0x0fa138de	xen_hvm_need_lapic
++EXPORT_SYMBOL_GPL vmlinux 0x0fb01905	fat_attach
++EXPORT_SYMBOL_GPL vmlinux 0x0fb0f21d	rtc_update_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x0fc01e9f	static_key_slow_inc
++EXPORT_SYMBOL_GPL vmlinux 0x0fcc1969	copy_from_user_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x0fd0cef3	subsys_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x0fdfd63e	btree_insert
++EXPORT_SYMBOL_GPL vmlinux 0x0fe2d570	xenbus_directory
++EXPORT_SYMBOL_GPL vmlinux 0x100a6252	register_hotplug_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0x10138352	tracing_on
++EXPORT_SYMBOL_GPL vmlinux 0x10291853	devm_regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0x1051cbc5	crypto_register_alg
++EXPORT_SYMBOL_GPL vmlinux 0x1061befc	pci_intx
++EXPORT_SYMBOL_GPL vmlinux 0x108843ec	ata_pci_bmdma_init
++EXPORT_SYMBOL_GPL vmlinux 0x1091233c	cgroup_add_cftypes
++EXPORT_SYMBOL_GPL vmlinux 0x10d51782	usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x10ecc52c	usb_amd_quirk_pll_enable
++EXPORT_SYMBOL_GPL vmlinux 0x110106c1	cper_severity_to_aer
++EXPORT_SYMBOL_GPL vmlinux 0x1128f3e3	cgroup_load_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x112b820c	cpufreq_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x116b935a	fat_get_dotdot_entry
++EXPORT_SYMBOL_GPL vmlinux 0x1172ce54	rtc_ktime_to_tm
++EXPORT_SYMBOL_GPL vmlinux 0x117c7305	hwpoison_filter_dev_major
++EXPORT_SYMBOL_GPL vmlinux 0x11835d16	default_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x11af98b0	ata_std_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x11b645bd	pci_enable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x11bb17fc	register_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x11eacd1c	uart_console_write
++EXPORT_SYMBOL_GPL vmlinux 0x11f17e15	crypto_register_template
++EXPORT_SYMBOL_GPL vmlinux 0x11f19a6a	rt_mutex_timed_lock
++EXPORT_SYMBOL_GPL vmlinux 0x11f447ce	__gpio_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x11f59b39	wakeup_source_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x120de808	tpm_gen_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x121d958a	unregister_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x121ed3f3	add_timer_on
++EXPORT_SYMBOL_GPL vmlinux 0x124a17c3	modify_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x124f2056	crypto_get_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0x1256af65	ping_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x1258d9d9	regulator_disable
++EXPORT_SYMBOL_GPL vmlinux 0x125fffbe	ata_dev_pair
++EXPORT_SYMBOL_GPL vmlinux 0x126018be	inet6_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0x1268f357	resume_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0x12764a92	tty_init_termios
++EXPORT_SYMBOL_GPL vmlinux 0x12db3064	rio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x12fd7308	usb_match_id
++EXPORT_SYMBOL_GPL vmlinux 0x131a5ed7	regmap_del_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x131be820	pwmchip_remove
++EXPORT_SYMBOL_GPL vmlinux 0x131db64a	system_long_wq
++EXPORT_SYMBOL_GPL vmlinux 0x1326eae3	class_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x13762696	__inet_inherit_port
++EXPORT_SYMBOL_GPL vmlinux 0x13849261	tty_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1385df28	debugfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x138aff76	gnttab_init
++EXPORT_SYMBOL_GPL vmlinux 0x13d4ea57	fat_detach
++EXPORT_SYMBOL_GPL vmlinux 0x13f3e3fb	klist_init
++EXPORT_SYMBOL_GPL vmlinux 0x14220e75	crypto_unregister_alg
++EXPORT_SYMBOL_GPL vmlinux 0x1447dd6c	find_vpid
++EXPORT_SYMBOL_GPL vmlinux 0x144fd3ed	netlink_add_tap
++EXPORT_SYMBOL_GPL vmlinux 0x145784d1	gdt_page
++EXPORT_SYMBOL_GPL vmlinux 0x145e53e4	blk_queue_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x145f3b15	efivars_register
++EXPORT_SYMBOL_GPL vmlinux 0x148b57c7	fat_build_inode
++EXPORT_SYMBOL_GPL vmlinux 0x14b1ba00	net_ns_type_operations
++EXPORT_SYMBOL_GPL vmlinux 0x14b46599	ata_port_abort
++EXPORT_SYMBOL_GPL vmlinux 0x14c3db12	ata_sff_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x14d79396	efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x14f875ce	devm_regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0x14fc0c63	atomic_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x15010e1f	arbitrary_virt_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0x153a0c91	usb_anchor_empty
++EXPORT_SYMBOL_GPL vmlinux 0x153da23d	cm_notify_event
++EXPORT_SYMBOL_GPL vmlinux 0x154dc8de	module_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x1554a2c3	sec_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x15568631	lookup_address
++EXPORT_SYMBOL_GPL vmlinux 0x15729d83	sysfs_schedule_callback
++EXPORT_SYMBOL_GPL vmlinux 0x15892417	async_synchronize_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x15b0606e	e820_any_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x15e2f511	sk_unattached_filter_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x16000a3c	dm_device_name
++EXPORT_SYMBOL_GPL vmlinux 0x1607bfe7	relay_switch_subbuf
++EXPORT_SYMBOL_GPL vmlinux 0x1650bf27	rcutorture_record_progress
++EXPORT_SYMBOL_GPL vmlinux 0x165c2efb	clk_get_rate
++EXPORT_SYMBOL_GPL vmlinux 0x16637b26	ohci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x16a05b65	dm_set_device_limits
++EXPORT_SYMBOL_GPL vmlinux 0x16d35273	usb_hcd_link_urb_to_ep
++EXPORT_SYMBOL_GPL vmlinux 0x16d9d2db	ata_sff_data_xfer
++EXPORT_SYMBOL_GPL vmlinux 0x16e82aef	stmpe_enable
++EXPORT_SYMBOL_GPL vmlinux 0x16edbcd8	netdev_set_default_ethtool_ops
++EXPORT_SYMBOL_GPL vmlinux 0x16f00d44	sdio_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x16f8d9a3	xenbus_register_frontend
++EXPORT_SYMBOL_GPL vmlinux 0x16fde19e	gnttab_map_refs
++EXPORT_SYMBOL_GPL vmlinux 0x1720ca4b	anon_inode_getfd
++EXPORT_SYMBOL_GPL vmlinux 0x1721bc66	usb_poison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x172275eb	tpm_show_temp_deactivated
++EXPORT_SYMBOL_GPL vmlinux 0x172e72d4	vdso_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x1730dbfb	platform_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x1746f98e	__srcu_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x17479cd0	ipv6_dup_options
++EXPORT_SYMBOL_GPL vmlinux 0x17482ea0	pci_cfg_access_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1748d1f8	inet_csk_get_port
++EXPORT_SYMBOL_GPL vmlinux 0x174d5d32	add_to_page_cache_lru
++EXPORT_SYMBOL_GPL vmlinux 0x175946d5	md_rdev_clear
++EXPORT_SYMBOL_GPL vmlinux 0x17614bf3	apei_resources_sub
++EXPORT_SYMBOL_GPL vmlinux 0x17628247	xenbus_switch_state
++EXPORT_SYMBOL_GPL vmlinux 0x17a7b3bc	cpufreq_frequency_table_verify
++EXPORT_SYMBOL_GPL vmlinux 0x17a7fd1f	noop_backing_dev_info
++EXPORT_SYMBOL_GPL vmlinux 0x17cee9a3	sdio_f0_readb
++EXPORT_SYMBOL_GPL vmlinux 0x17e9347c	xfrm_audit_state_delete
++EXPORT_SYMBOL_GPL vmlinux 0x1804e8ad	rio_mport_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x180e9e46	wm8350_device_exit
++EXPORT_SYMBOL_GPL vmlinux 0x1822a715	securityfs_create_dir
++EXPORT_SYMBOL_GPL vmlinux 0x1829b9ed	hwpoison_filter_memcg
++EXPORT_SYMBOL_GPL vmlinux 0x1853653c	btree_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x18582826	amd_pmu_disable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x1866cec2	ring_buffer_size
++EXPORT_SYMBOL_GPL vmlinux 0x1878f62b	edac_err_assert
++EXPORT_SYMBOL_GPL vmlinux 0x187c3366	adp5520_write
++EXPORT_SYMBOL_GPL vmlinux 0x187fbd81	irq_domain_xlate_onetwocell
++EXPORT_SYMBOL_GPL vmlinux 0x188aa133	xattr_getsecurity
++EXPORT_SYMBOL_GPL vmlinux 0x188d6922	xenbus_register_driver_common
++EXPORT_SYMBOL_GPL vmlinux 0x18923cd4	device_register
++EXPORT_SYMBOL_GPL vmlinux 0x1899d486	pm_runtime_autosuspend_expiration
++EXPORT_SYMBOL_GPL vmlinux 0x18a27f34	jump_label_rate_limit
++EXPORT_SYMBOL_GPL vmlinux 0x18be8536	__efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0x18ca8c5e	wakeup_source_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x18cd888f	tps65912_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x18d9a7b0	acpi_pci_find_root
++EXPORT_SYMBOL_GPL vmlinux 0x18f83fab	gnttab_grant_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0x19259fc3	__rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0x193d48e0	trace_current_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x19496284	tcp_orphan_count
++EXPORT_SYMBOL_GPL vmlinux 0x196614ce	hw_breakpoint_restore
++EXPORT_SYMBOL_GPL vmlinux 0x196ab0ec	crypto_register_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x197c96ab	rio_mport_chk_dev_access
++EXPORT_SYMBOL_GPL vmlinux 0x1986b559	subsys_system_register
++EXPORT_SYMBOL_GPL vmlinux 0x19a304ba	usb_disabled
++EXPORT_SYMBOL_GPL vmlinux 0x19bc2412	inet_csk_listen_start
++EXPORT_SYMBOL_GPL vmlinux 0x19cc6999	acpi_bind_one
++EXPORT_SYMBOL_GPL vmlinux 0x19fc7f60	regulator_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0x1a082d69	max77693_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0x1a156e14	md_stop
++EXPORT_SYMBOL_GPL vmlinux 0x1a323362	__ftrace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x1a3c6846	tcp_death_row
++EXPORT_SYMBOL_GPL vmlinux 0x1a5e0a44	inet_hash
++EXPORT_SYMBOL_GPL vmlinux 0x1a7bec6e	ipv6_recv_error
++EXPORT_SYMBOL_GPL vmlinux 0x1a98f40a	cpuidle_disable_device
++EXPORT_SYMBOL_GPL vmlinux 0x1ab3e769	rtc_initialize_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x1ad83009	trace_seq_vprintf
++EXPORT_SYMBOL_GPL vmlinux 0x1adc04da	usb_create_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x1b1f2bda	speedstep_get_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x1b3d273e	bus_register
++EXPORT_SYMBOL_GPL vmlinux 0x1b52db1c	probe_kernel_read
++EXPORT_SYMBOL_GPL vmlinux 0x1b670076	blocking_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0x1b6dd440	devm_pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0x1b8a7c00	inet_csk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1b970fba	arizona_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x1b9aca3f	jprobe_return
++EXPORT_SYMBOL_GPL vmlinux 0x1ba0d4ff	usb_match_one_id
++EXPORT_SYMBOL_GPL vmlinux 0x1bb60b69	ata_pci_sff_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0x1bd06aab	cpufreq_frequency_table_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1bd6a1d7	sysfs_remove_files
++EXPORT_SYMBOL_GPL vmlinux 0x1bf1a39f	cgroup_next_descendant_pre
++EXPORT_SYMBOL_GPL vmlinux 0x1bf785ee	devm_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x1bfee4ad	ata_sas_slave_configure
++EXPORT_SYMBOL_GPL vmlinux 0x1c4200f0	usb_enable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x1c585524	tty_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x1c5b1f28	irq_free_descs
++EXPORT_SYMBOL_GPL vmlinux 0x1c5e2b75	inet_hashinfo_init
++EXPORT_SYMBOL_GPL vmlinux 0x1c7415cf	debugfs_create_x64
++EXPORT_SYMBOL_GPL vmlinux 0x1c80d27d	btree_geo128
++EXPORT_SYMBOL_GPL vmlinux 0x1c87a811	__round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x1c8e1af6	rio_request_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x1c8f26cf	unix_outq_len
++EXPORT_SYMBOL_GPL vmlinux 0x1c8fa122	usb_mon_register
++EXPORT_SYMBOL_GPL vmlinux 0x1cc916f1	platform_device_add_resources
++EXPORT_SYMBOL_GPL vmlinux 0x1cc9dd6d	ata_std_sched_eh
++EXPORT_SYMBOL_GPL vmlinux 0x1ce98df1	atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x1cf75bae	put_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x1cffc4df	RSA_public_key_algorithm
++EXPORT_SYMBOL_GPL vmlinux 0x1d00cf71	dev_get_gen_pool
++EXPORT_SYMBOL_GPL vmlinux 0x1d13bb2a	usb_enable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x1d319f09	virtqueue_get_buf
++EXPORT_SYMBOL_GPL vmlinux 0x1d349344	__class_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d459685	xstate_size
++EXPORT_SYMBOL_GPL vmlinux 0x1d543bee	i2c_new_probed_device
++EXPORT_SYMBOL_GPL vmlinux 0x1d54c5c1	__pci_hp_register
++EXPORT_SYMBOL_GPL vmlinux 0x1d58ae14	lpddr2_jedec_timings
++EXPORT_SYMBOL_GPL vmlinux 0x1d5c9136	sata_pmp_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x1d739e1c	xen_set_callback_via
++EXPORT_SYMBOL_GPL vmlinux 0x1d77b0f8	unix_socket_table
++EXPORT_SYMBOL_GPL vmlinux 0x1d8fb3bb	acpi_dev_resource_address_space
++EXPORT_SYMBOL_GPL vmlinux 0x1d9ebb74	rio_mport_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x1db53d24	rio_lock_device
++EXPORT_SYMBOL_GPL vmlinux 0x1dc67278	wm8994_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x1dca9d96	vfs_truncate
++EXPORT_SYMBOL_GPL vmlinux 0x1e000879	hwpoison_filter_enable
++EXPORT_SYMBOL_GPL vmlinux 0x1e08ecae	fat_fill_super
++EXPORT_SYMBOL_GPL vmlinux 0x1e314b21	regulator_use_dummy_regulator
++EXPORT_SYMBOL_GPL vmlinux 0x1e3a88fb	trace_seq_printf
++EXPORT_SYMBOL_GPL vmlinux 0x1e3e0923	__class_create
++EXPORT_SYMBOL_GPL vmlinux 0x1e59d66e	ping_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x1e5b03dc	pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x1e7bbcb3	kernel_restart
++EXPORT_SYMBOL_GPL vmlinux 0x1e7ed8d2	sdio_memcpy_fromio
++EXPORT_SYMBOL_GPL vmlinux 0x1eb9516e	round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x1ebe52a3	ata_sas_port_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x1ebf6c2a	pci_power_names
++EXPORT_SYMBOL_GPL vmlinux 0x1ecce7a6	netdev_rx_handler_register
++EXPORT_SYMBOL_GPL vmlinux 0x1edc21cb	hwpoison_filter_flags_mask
++EXPORT_SYMBOL_GPL vmlinux 0x1edf91ef	iommu_domain_set_attr
++EXPORT_SYMBOL_GPL vmlinux 0x1f17c272	wm8350_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0x1f1988f7	hwpoison_filter_flags_value
++EXPORT_SYMBOL_GPL vmlinux 0x1f54f1b4	do_trace_rcu_torture_read
++EXPORT_SYMBOL_GPL vmlinux 0x1f5aee98	ata_eh_thaw_port
++EXPORT_SYMBOL_GPL vmlinux 0x1f7f6fac	register_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x1f8544b8	panic_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x1f8db7f9	ring_buffer_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x1f8e0bb3	regulator_set_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x1f9c60c6	dev_pm_qos_expose_flags
++EXPORT_SYMBOL_GPL vmlinux 0x1fb54011	__mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0x1fcece42	inet_twdr_twcal_tick
++EXPORT_SYMBOL_GPL vmlinux 0x200a3ccc	bus_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x20129e16	spi_master_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x2025ac24	rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x20331b77	usb_driver_release_interface
++EXPORT_SYMBOL_GPL vmlinux 0x20582c82	class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x205cb5ae	extcon_dev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x20671650	call_srcu
++EXPORT_SYMBOL_GPL vmlinux 0x20872c61	dev_pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x209ec764	xen_event_channel_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0x20a96aad	od_register_powersave_bias_handler
++EXPORT_SYMBOL_GPL vmlinux 0x20bc3470	orderly_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0x20c213ec	device_create
++EXPORT_SYMBOL_GPL vmlinux 0x20cb9263	transport_setup_device
++EXPORT_SYMBOL_GPL vmlinux 0x20ce5aef	ahash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x20ddf6d1	wm8350_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x20e9b36c	crypto_unregister_shashes
++EXPORT_SYMBOL_GPL vmlinux 0x21269a2e	m2p_remove_override
++EXPORT_SYMBOL_GPL vmlinux 0x2144e7cd	tps6586x_update
++EXPORT_SYMBOL_GPL vmlinux 0x21511271	blkcg_activate_policy
++EXPORT_SYMBOL_GPL vmlinux 0x217a52eb	gpiochip_add
++EXPORT_SYMBOL_GPL vmlinux 0x219a9f55	i2c_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x219fbaab	sdio_memcpy_toio
++EXPORT_SYMBOL_GPL vmlinux 0x21a3ecc2	scsi_mode_select
++EXPORT_SYMBOL_GPL vmlinux 0x21ac8b77	iommu_group_get_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x21ad9459	__rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x21b39d76	fat_scan
++EXPORT_SYMBOL_GPL vmlinux 0x21d2256d	public_key_subtype
++EXPORT_SYMBOL_GPL vmlinux 0x220b43a3	pm_runtime_allow
++EXPORT_SYMBOL_GPL vmlinux 0x223f3090	raw_hash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x227b034c	debugfs_create_symlink
++EXPORT_SYMBOL_GPL vmlinux 0x228ebb65	transport_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0x2296c00d	crypto_attr_u32
++EXPORT_SYMBOL_GPL vmlinux 0x22c07787	pm_runtime_forbid
++EXPORT_SYMBOL_GPL vmlinux 0x22ed2b03	unregister_dock_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x22f65e18	ata_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x2300d344	sysfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x23359113	pci_store_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x2366a2c0	errata
++EXPORT_SYMBOL_GPL vmlinux 0x23679939	__iowrite32_copy
++EXPORT_SYMBOL_GPL vmlinux 0x2373352a	clk_fixed_factor_ops
++EXPORT_SYMBOL_GPL vmlinux 0x23864ce7	cpuset_mem_spread_node
++EXPORT_SYMBOL_GPL vmlinux 0x238e0d5b	regmap_add_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0x2392bc6e	pm_qos_request_active
++EXPORT_SYMBOL_GPL vmlinux 0x2399bb88	__pm_runtime_idle
++EXPORT_SYMBOL_GPL vmlinux 0x23a3da37	pm_runtime_set_memalloc_noio
++EXPORT_SYMBOL_GPL vmlinux 0x23dc3429	rio_mport_write_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x240580a9	xenbus_probe
++EXPORT_SYMBOL_GPL vmlinux 0x2447533c	ktime_get_real
++EXPORT_SYMBOL_GPL vmlinux 0x2452269a	arizona_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0x24752461	crypto_blkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x247ef831	kdb_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x24a0f964	regmap_init
++EXPORT_SYMBOL_GPL vmlinux 0x24aac4d9	crypto_aes_expand_key
++EXPORT_SYMBOL_GPL vmlinux 0x24c7698a	xenbus_write
++EXPORT_SYMBOL_GPL vmlinux 0x24d5b6cd	usb_get_urb
++EXPORT_SYMBOL_GPL vmlinux 0x24dc08ba	n_tty_inherit_ops
++EXPORT_SYMBOL_GPL vmlinux 0x24eb7e32	leds_list
++EXPORT_SYMBOL_GPL vmlinux 0x24f2d831	regulator_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x24f39c39	reset_control_reset
++EXPORT_SYMBOL_GPL vmlinux 0x24fc46b6	regulator_bulk_free
++EXPORT_SYMBOL_GPL vmlinux 0x2545c170	unregister_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x25b3f743	reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x25c4b892	led_trigger_blink
++EXPORT_SYMBOL_GPL vmlinux 0x25c8681c	i2c_lock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x25ca0d2c	subsys_find_device_by_id
++EXPORT_SYMBOL_GPL vmlinux 0x25cc945c	efivar_entry_size
++EXPORT_SYMBOL_GPL vmlinux 0x25d44af1	print_context_stack
++EXPORT_SYMBOL_GPL vmlinux 0x25e6848c	pci_num_vf
++EXPORT_SYMBOL_GPL vmlinux 0x25e917f6	device_show_bool
++EXPORT_SYMBOL_GPL vmlinux 0x26095d10	scsi_autopm_put_device
++EXPORT_SYMBOL_GPL vmlinux 0x261e3fee	inet6_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x2624ecfc	__put_net
++EXPORT_SYMBOL_GPL vmlinux 0x262f20a8	local_clock
++EXPORT_SYMBOL_GPL vmlinux 0x26520970	vm_memory_committed
++EXPORT_SYMBOL_GPL vmlinux 0x2664764c	cpuidle_enable_device
++EXPORT_SYMBOL_GPL vmlinux 0x26965721	slow_virt_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0x26acbb22	task_current_syscall
++EXPORT_SYMBOL_GPL vmlinux 0x26b1a721	subsys_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x26b71fb4	ring_buffer_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x26bdc816	rio_unlock_device
++EXPORT_SYMBOL_GPL vmlinux 0x26c90ea4	scsi_eh_get_sense
++EXPORT_SYMBOL_GPL vmlinux 0x26ec3ee2	fsnotify
++EXPORT_SYMBOL_GPL vmlinux 0x27046456	i2c_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x27178c53	__pci_reset_function_locked
++EXPORT_SYMBOL_GPL vmlinux 0x27284d76	iommu_present
++EXPORT_SYMBOL_GPL vmlinux 0x2735afd0	ata_timing_compute
++EXPORT_SYMBOL_GPL vmlinux 0x2742fa90	pm_runtime_irq_safe
++EXPORT_SYMBOL_GPL vmlinux 0x27529bc2	thermal_zone_get_temp
++EXPORT_SYMBOL_GPL vmlinux 0x27680501	tpm_show_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x277d0600	ata_do_eh
++EXPORT_SYMBOL_GPL vmlinux 0x2787db00	vbin_printf
++EXPORT_SYMBOL_GPL vmlinux 0x278ec596	firmware_kobj
++EXPORT_SYMBOL_GPL vmlinux 0x279aee43	regmap_exit
++EXPORT_SYMBOL_GPL vmlinux 0x279c091d	devm_regulator_get
++EXPORT_SYMBOL_GPL vmlinux 0x279cb985	apei_exec_pre_map_gars
++EXPORT_SYMBOL_GPL vmlinux 0x27ac9ab9	preempt_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x27b6f085	devm_usb_get_phy_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x27c1e63f	usb_amd_find_chipset_info
++EXPORT_SYMBOL_GPL vmlinux 0x27c8e919	balloon_page_enqueue
++EXPORT_SYMBOL_GPL vmlinux 0x27ddb33d	acpi_dev_resource_io
++EXPORT_SYMBOL_GPL vmlinux 0x27e09448	regmap_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x27f4f029	ftrace_set_global_filter
++EXPORT_SYMBOL_GPL vmlinux 0x27fa66e1	nr_free_buffer_pages
++EXPORT_SYMBOL_GPL vmlinux 0x280e4516	kobject_get_path
++EXPORT_SYMBOL_GPL vmlinux 0x282f88a0	skb_partial_csum_set
++EXPORT_SYMBOL_GPL vmlinux 0x28508366	iommu_group_get
++EXPORT_SYMBOL_GPL vmlinux 0x285de34a	pci_cfg_access_trylock
++EXPORT_SYMBOL_GPL vmlinux 0x2869ebaf	regulator_bulk_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2884f229	blkdev_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x28a82da4	snmp_mib_init
++EXPORT_SYMBOL_GPL vmlinux 0x28a903c8	timerqueue_add
++EXPORT_SYMBOL_GPL vmlinux 0x28c081e8	crypto_aead_setauthsize
++EXPORT_SYMBOL_GPL vmlinux 0x28d25b64	regmap_write
++EXPORT_SYMBOL_GPL vmlinux 0x29059b53	__wake_up_locked_key
++EXPORT_SYMBOL_GPL vmlinux 0x2905ee69	gpiochip_find
++EXPORT_SYMBOL_GPL vmlinux 0x290ac3c0	ata_dev_set_feature
++EXPORT_SYMBOL_GPL vmlinux 0x291dc9b9	shmem_read_mapping_page_gfp
++EXPORT_SYMBOL_GPL vmlinux 0x29341ad8	pci_hp_change_slot_info
++EXPORT_SYMBOL_GPL vmlinux 0x293d1435	bus_sort_breadthfirst
++EXPORT_SYMBOL_GPL vmlinux 0x293f073e	vrtc_cmos_write
++EXPORT_SYMBOL_GPL vmlinux 0x2968b3be	ata_cable_unknown
++EXPORT_SYMBOL_GPL vmlinux 0x2979fecd	ata_sff_softreset
++EXPORT_SYMBOL_GPL vmlinux 0x297e656f	ata_wait_register
++EXPORT_SYMBOL_GPL vmlinux 0x2a00b3ca	sysfs_rename_link
++EXPORT_SYMBOL_GPL vmlinux 0x2a045efb	device_create_with_groups
++EXPORT_SYMBOL_GPL vmlinux 0x2a0c96d6	pm_runtime_set_autosuspend_delay
++EXPORT_SYMBOL_GPL vmlinux 0x2a1d25ec	dma_buf_begin_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x2a2dfb09	tty_prepare_flip_string_flags
++EXPORT_SYMBOL_GPL vmlinux 0x2a5535ef	devm_rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x2a678a13	__suspend_report_result
++EXPORT_SYMBOL_GPL vmlinux 0x2aae5d2e	platform_device_add
++EXPORT_SYMBOL_GPL vmlinux 0x2ac36de7	btree_last
++EXPORT_SYMBOL_GPL vmlinux 0x2ad09a13	subsys_virtual_register
++EXPORT_SYMBOL_GPL vmlinux 0x2ad1ece4	zs_get_total_size_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x2b57bde8	sdio_writeb
++EXPORT_SYMBOL_GPL vmlinux 0x2b67f096	speedstep_get_frequency
++EXPORT_SYMBOL_GPL vmlinux 0x2b7a6de8	syscon_regmap_lookup_by_phandle
++EXPORT_SYMBOL_GPL vmlinux 0x2b85a682	inet_twsk_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x2bd97f9a	usb_get_status
++EXPORT_SYMBOL_GPL vmlinux 0x2bdfb79e	tcp_init_congestion_ops
++EXPORT_SYMBOL_GPL vmlinux 0x2becaa28	scsi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x2bfee9da	iommu_domain_has_cap
++EXPORT_SYMBOL_GPL vmlinux 0x2c0d72d3	relay_reset
++EXPORT_SYMBOL_GPL vmlinux 0x2c208607	power_supply_is_system_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x2c3bd5d1	xenbus_dev_fatal
++EXPORT_SYMBOL_GPL vmlinux 0x2c474254	wm8350_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x2c495a54	usb_free_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2c519e4f	__page_file_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c6a0410	xen_set_domain_pte
++EXPORT_SYMBOL_GPL vmlinux 0x2c7d9c64	xen_store_interface
++EXPORT_SYMBOL_GPL vmlinux 0x2c7db649	irq_dispose_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x2c9fe9e4	md_stop_writes
++EXPORT_SYMBOL_GPL vmlinux 0x2ca4ebcd	regulator_set_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x2ca53884	ping_rcv
++EXPORT_SYMBOL_GPL vmlinux 0x2caa7b95	clockevents_unbind
++EXPORT_SYMBOL_GPL vmlinux 0x2cbe0d3c	fb_deferred_io_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x2cd576d5	unregister_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0x2cd9f6d3	virtqueue_notify
++EXPORT_SYMBOL_GPL vmlinux 0x2ce98559	kcrypto_wq
++EXPORT_SYMBOL_GPL vmlinux 0x2cea32ee	unregister_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0x2d17a0e1	cgroup_taskset_size
++EXPORT_SYMBOL_GPL vmlinux 0x2d18233a	ata_bmdma_dumb_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x2d1b02d2	usermodehelper_read_lock_wait
++EXPORT_SYMBOL_GPL vmlinux 0x2d376ffc	usb_driver_set_configuration
++EXPORT_SYMBOL_GPL vmlinux 0x2d3af2a8	rio_mport_get_feature
++EXPORT_SYMBOL_GPL vmlinux 0x2d41e6f5	__trace_puts
++EXPORT_SYMBOL_GPL vmlinux 0x2d59c954	edac_handlers
++EXPORT_SYMBOL_GPL vmlinux 0x2d617fd5	usb_unpoison_urb
++EXPORT_SYMBOL_GPL vmlinux 0x2d6c6ae2	blkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x2d9f2ce3	sched_clock_idle_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2dc2413f	ip6_route_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x2df5e85c	pwm_disable
++EXPORT_SYMBOL_GPL vmlinux 0x2e099480	device_show_int
++EXPORT_SYMBOL_GPL vmlinux 0x2e136684	css_id
++EXPORT_SYMBOL_GPL vmlinux 0x2e2360b1	ftrace_set_global_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x2e2f1740	ring_buffer_record_disable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x2e45e488	rcu_note_context_switch
++EXPORT_SYMBOL_GPL vmlinux 0x2e7bbd18	ip_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x2e8b6c8c	__pm_wakeup_event
++EXPORT_SYMBOL_GPL vmlinux 0x2e8c92b1	ata_host_start
++EXPORT_SYMBOL_GPL vmlinux 0x2e9e59a2	sdio_enable_func
++EXPORT_SYMBOL_GPL vmlinux 0x2ebe3135	cpu_is_hotpluggable
++EXPORT_SYMBOL_GPL vmlinux 0x2ecfb11d	spi_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0x2edd0ed0	ata_pio_need_iordy
++EXPORT_SYMBOL_GPL vmlinux 0x2f04323f	crypto_aes_set_key
++EXPORT_SYMBOL_GPL vmlinux 0x2f0d9053	usb_otg_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x2f1867ec	ablkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x2f4113a2	dcookie_register
++EXPORT_SYMBOL_GPL vmlinux 0x2f44d4bc	virtqueue_add_outbuf
++EXPORT_SYMBOL_GPL vmlinux 0x2f4fb3f0	bmp085_detect
++EXPORT_SYMBOL_GPL vmlinux 0x2f525bc8	xenbus_dev_remove
++EXPORT_SYMBOL_GPL vmlinux 0x2f64415f	unregister_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x2f857551	machine_check_poll
++EXPORT_SYMBOL_GPL vmlinux 0x2fa3455d	irq_create_strict_mappings
++EXPORT_SYMBOL_GPL vmlinux 0x2fbfc1e7	ata_sff_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x2fd69013	pci_rescan_bus
++EXPORT_SYMBOL_GPL vmlinux 0x2fd8cba9	freeze_wake
++EXPORT_SYMBOL_GPL vmlinux 0x2fea80b5	skb_pull_rcsum
++EXPORT_SYMBOL_GPL vmlinux 0x2ff32112	balloon_page_dequeue
++EXPORT_SYMBOL_GPL vmlinux 0x2ffef205	adp5520_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3008f297	agp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x3013ab7a	rtnl_af_register
++EXPORT_SYMBOL_GPL vmlinux 0x30482739	ip_build_and_send_pkt
++EXPORT_SYMBOL_GPL vmlinux 0x30574135	blk_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x308b733a	getboottime
++EXPORT_SYMBOL_GPL vmlinux 0x3097481a	ping_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0x309ccfb7	cpufreq_cpu_put
++EXPORT_SYMBOL_GPL vmlinux 0x309f8466	xenbus_dev_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x30a4f4ca	bstr_printf
++EXPORT_SYMBOL_GPL vmlinux 0x31071285	tty_standard_install
++EXPORT_SYMBOL_GPL vmlinux 0x3109b751	cpu_clock
++EXPORT_SYMBOL_GPL vmlinux 0x310a473c	tpm_bios_log_teardown
++EXPORT_SYMBOL_GPL vmlinux 0x31232548	tcp_is_cwnd_limited
++EXPORT_SYMBOL_GPL vmlinux 0x31266931	con_debug_leave
++EXPORT_SYMBOL_GPL vmlinux 0x313fabc0	find_module
++EXPORT_SYMBOL_GPL vmlinux 0x314b2f2e	ipv4_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x315bb54e	__atomic_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x31689784	wm5110_patch
++EXPORT_SYMBOL_GPL vmlinux 0x316be323	usb_get_current_frame_number
++EXPORT_SYMBOL_GPL vmlinux 0x317d59a6	atomic_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x31c0c2d1	dm_put
++EXPORT_SYMBOL_GPL vmlinux 0x31c7970f	pciserial_suspend_ports
++EXPORT_SYMBOL_GPL vmlinux 0x31d508fa	sdio_readb
++EXPORT_SYMBOL_GPL vmlinux 0x31e1b025	devm_acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0x31f01877	wm8350_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x323c6448	dev_set_name
++EXPORT_SYMBOL_GPL vmlinux 0x32469838	spi_alloc_device
++EXPORT_SYMBOL_GPL vmlinux 0x3252e9cf	extcon_get_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x3256f216	smpboot_register_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0x325d13fa	irq_domain_associate_many
++EXPORT_SYMBOL_GPL vmlinux 0x325e677c	gnttab_grant_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x328995b5	tracing_generic_entry_update
++EXPORT_SYMBOL_GPL vmlinux 0x328d7bf2	xen_swiotlb_sync_single_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x32924a4d	scatterwalk_copychunks
++EXPORT_SYMBOL_GPL vmlinux 0x329bbbde	timerqueue_del
++EXPORT_SYMBOL_GPL vmlinux 0x329e1aa5	crypto_ablkcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x32b31a8c	ktime_get_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x32b9923a	intel_scu_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x32c3cb4e	class_compat_register
++EXPORT_SYMBOL_GPL vmlinux 0x32c4ef92	__pm_runtime_set_status
++EXPORT_SYMBOL_GPL vmlinux 0x32d85001	cpufreq_cooling_register
++EXPORT_SYMBOL_GPL vmlinux 0x32e46de0	queue_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x32fd447a	monotonic_to_bootbased
++EXPORT_SYMBOL_GPL vmlinux 0x32fd4b62	__wake_up_sync
++EXPORT_SYMBOL_GPL vmlinux 0x333228ec	intel_msic_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x3343b9dd	security_inode_setattr
++EXPORT_SYMBOL_GPL vmlinux 0x3349b9e3	scsi_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x335c570f	enable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0x336154ca	rcutorture_record_test_transition
++EXPORT_SYMBOL_GPL vmlinux 0x33655159	xen_pcpu_hotplug_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3379b344	user_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x337a567f	__clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x33883929	clk_divider_ops
++EXPORT_SYMBOL_GPL vmlinux 0x3393c5fc	ata_acpi_cbl_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x33b96e5d	apei_exec_write_register
++EXPORT_SYMBOL_GPL vmlinux 0x33f49ae3	sk_set_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x3441c3d6	gpio_set_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x34436101	bus_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x346df946	crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x347fd4b3	eventfd_ctx_get
++EXPORT_SYMBOL_GPL vmlinux 0x34809c9a	pm_generic_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x34a10296	regmap_update_bits_check
++EXPORT_SYMBOL_GPL vmlinux 0x34ac50a4	visitorl
++EXPORT_SYMBOL_GPL vmlinux 0x34cae435	ata_port_desc
++EXPORT_SYMBOL_GPL vmlinux 0x34d5e280	tpm_add_ppi
++EXPORT_SYMBOL_GPL vmlinux 0x34db736c	regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x34ed0019	pm_schedule_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x35102d83	ata_sff_dev_classify
++EXPORT_SYMBOL_GPL vmlinux 0x35159579	device_set_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0x352650ee	gnttab_batch_map
++EXPORT_SYMBOL_GPL vmlinux 0x354028fa	__lock_page_killable
++EXPORT_SYMBOL_GPL vmlinux 0x355741c9	platform_get_resource
++EXPORT_SYMBOL_GPL vmlinux 0x35584a7b	usb_driver_claim_interface
++EXPORT_SYMBOL_GPL vmlinux 0x3581f995	enable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x3593f9bd	uhci_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x35db968f	pwmchip_add
++EXPORT_SYMBOL_GPL vmlinux 0x35f0b1e0	dbs_check_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x35f165f1	devm_reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x35f3ae51	unix_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0x36075bb5	iommu_group_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x3617b26d	ata_pci_sff_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x361e2bcc	save_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0x369a9ace	usb_sg_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x369d60ef	ata_sff_pause
++EXPORT_SYMBOL_GPL vmlinux 0x369fcd70	tracing_snapshot
++EXPORT_SYMBOL_GPL vmlinux 0x36a079d4	ata_pci_device_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x36a0b9e3	fuse_get_req
++EXPORT_SYMBOL_GPL vmlinux 0x36b5497e	intel_iommu_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x36ba2551	intel_scu_devices_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x36f71104	tc3589x_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x3700154c	pkey_hash_algo
++EXPORT_SYMBOL_GPL vmlinux 0x3716f6d9	blk_rq_unprep_clone
++EXPORT_SYMBOL_GPL vmlinux 0x3726b5ab	ata_msleep
++EXPORT_SYMBOL_GPL vmlinux 0x37384455	virtqueue_detach_unused_buf
++EXPORT_SYMBOL_GPL vmlinux 0x373c514d	usb_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x3756927a	irq_alloc_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x375696c1	device_store_ulong
++EXPORT_SYMBOL_GPL vmlinux 0x376b1ff3	scsi_internal_device_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x376ff6a7	tps6586x_read
++EXPORT_SYMBOL_GPL vmlinux 0x37c3b7ce	tty_port_register_device
++EXPORT_SYMBOL_GPL vmlinux 0x37e94f51	usb_create_shared_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x37ff8476	usb_hcd_unlink_urb_from_ep
++EXPORT_SYMBOL_GPL vmlinux 0x38620e38	gnttab_grant_foreign_access_trans_ref
++EXPORT_SYMBOL_GPL vmlinux 0x38843994	acpi_dev_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0x389074e1	ata_dummy_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x38a9c2c7	input_ff_effect_from_user
++EXPORT_SYMBOL_GPL vmlinux 0x38f49605	gov_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0x39270d14	synchronize_srcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x3931337e	usb_deregister_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x39328883	dev_attr_unload_heads
++EXPORT_SYMBOL_GPL vmlinux 0x39470404	blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x39823687	usb_alloc_streams
++EXPORT_SYMBOL_GPL vmlinux 0x3986f8f4	ata_scsi_port_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x39b0fdfa	get_dcookie
++EXPORT_SYMBOL_GPL vmlinux 0x39d9514b	skcipher_geniv_init
++EXPORT_SYMBOL_GPL vmlinux 0x39e02cf1	bitmap_load
++EXPORT_SYMBOL_GPL vmlinux 0x39e670aa	kset_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x39ed33cb	unregister_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x3a18bd11	sock_diag_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3a26ed11	sched_clock
++EXPORT_SYMBOL_GPL vmlinux 0x3a29344b	rio_request_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x3a2abdbf	clk_disable
++EXPORT_SYMBOL_GPL vmlinux 0x3a3025bb	devm_rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x3a38dc65	memory_failure
++EXPORT_SYMBOL_GPL vmlinux 0x3a4f6a32	ata_sff_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x3a536bd7	ring_buffer_read_finish
++EXPORT_SYMBOL_GPL vmlinux 0x3a953f21	class_dev_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x3ad1d619	xen_swiotlb_map_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x3aec6873	dev_attr_sw_activity
++EXPORT_SYMBOL_GPL vmlinux 0x3b32f0e3	sdio_claim_host
++EXPORT_SYMBOL_GPL vmlinux 0x3b3e996f	ata_sff_drain_fifo
++EXPORT_SYMBOL_GPL vmlinux 0x3b4ec679	class_compat_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x3b65f45d	debugfs_remove_recursive
++EXPORT_SYMBOL_GPL vmlinux 0x3b679d17	ata_sff_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x3b7145bb	apei_exec_read_register_value
++EXPORT_SYMBOL_GPL vmlinux 0x3b8ab4bc	get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x3b8e7dd6	devres_remove
++EXPORT_SYMBOL_GPL vmlinux 0x3b9c3aa6	efivar_entry_set_get_size
++EXPORT_SYMBOL_GPL vmlinux 0x3bb00094	usb_altnum_to_altsetting
++EXPORT_SYMBOL_GPL vmlinux 0x3bca5ecb	__hvc_resize
++EXPORT_SYMBOL_GPL vmlinux 0x3bd452ac	pci_find_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x3be6f5a2	xenbus_dev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x3c100d23	fb_deferred_io_init
++EXPORT_SYMBOL_GPL vmlinux 0x3c3c6056	class_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x3c49a982	acpi_bus_trim
++EXPORT_SYMBOL_GPL vmlinux 0x3c4a05ad	device_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x3c5cdfee	tcp_cong_avoid_ai
++EXPORT_SYMBOL_GPL vmlinux 0x3c7991f6	ata_noop_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0x3c9390db	pci_vpd_find_tag
++EXPORT_SYMBOL_GPL vmlinux 0x3ca0c1e8	sata_scr_valid
++EXPORT_SYMBOL_GPL vmlinux 0x3cac21b9	regulator_sync_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x3cbce90c	class_compat_create_link
++EXPORT_SYMBOL_GPL vmlinux 0x3cc9d6c6	wm8350_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x3cd06035	add_input_randomness
++EXPORT_SYMBOL_GPL vmlinux 0x3cd1d3d4	ata_bmdma_status
++EXPORT_SYMBOL_GPL vmlinux 0x3cf04db4	hrtimer_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x3d13c02f	blk_abort_request
++EXPORT_SYMBOL_GPL vmlinux 0x3d388324	dpm_resume_end
++EXPORT_SYMBOL_GPL vmlinux 0x3d457297	led_classdev_register
++EXPORT_SYMBOL_GPL vmlinux 0x3d7ea99a	gnttab_grant_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x3d8dde20	dev_forward_skb
++EXPORT_SYMBOL_GPL vmlinux 0x3d90fdb2	rio_register_mport
++EXPORT_SYMBOL_GPL vmlinux 0x3db5bda2	sdio_align_size
++EXPORT_SYMBOL_GPL vmlinux 0x3dc916b6	crypto_fl_tab
++EXPORT_SYMBOL_GPL vmlinux 0x3dd4d3a7	bprintf
++EXPORT_SYMBOL_GPL vmlinux 0x3ddba1c3	rt_mutex_unlock
++EXPORT_SYMBOL_GPL vmlinux 0x3de41f9a	pci_pri_stopped
++EXPORT_SYMBOL_GPL vmlinux 0x3de9cae1	crypto_remove_final
++EXPORT_SYMBOL_GPL vmlinux 0x3e0b8dd0	driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3e110ea6	mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x3e2fa31f	wm8997_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e441d8c	find_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x3e480ff4	regmap_check_range_table
++EXPORT_SYMBOL_GPL vmlinux 0x3e7080cb	mpi_read_from_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x3e757637	cpu_bit_bitmap
++EXPORT_SYMBOL_GPL vmlinux 0x3e7f0dfc	__wake_up_sync_key
++EXPORT_SYMBOL_GPL vmlinux 0x3e9a6d87	irq_gc_ack_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x3ea5196d	apei_osc_setup
++EXPORT_SYMBOL_GPL vmlinux 0x3ea89c28	usb_enable_intel_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0x3eb3d6eb	device_create_vargs
++EXPORT_SYMBOL_GPL vmlinux 0x3eb44e31	put_pid
++EXPORT_SYMBOL_GPL vmlinux 0x3ee8158f	ehci_init_driver
++EXPORT_SYMBOL_GPL vmlinux 0x3efb35c9	get_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0x3f0b6748	clk_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x3f13c689	spi_sync_locked
++EXPORT_SYMBOL_GPL vmlinux 0x3f229c4c	oops_begin
++EXPORT_SYMBOL_GPL vmlinux 0x3f2d356b	arizona_set_irq_wake
++EXPORT_SYMBOL_GPL vmlinux 0x3f325e01	fat_dir_empty
++EXPORT_SYMBOL_GPL vmlinux 0x3f59ec82	posix_clock_register
++EXPORT_SYMBOL_GPL vmlinux 0x3f664e30	seq_open_net
++EXPORT_SYMBOL_GPL vmlinux 0x3f6a9640	sata_pmp_qc_defer_cmd_switch
++EXPORT_SYMBOL_GPL vmlinux 0x3f783ac9	cpci_hp_register_controller
++EXPORT_SYMBOL_GPL vmlinux 0x3f84d4c9	gnttab_release_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x3f9c87a9	user_update
++EXPORT_SYMBOL_GPL vmlinux 0x3fa09f9b	debugfs_create_u16
++EXPORT_SYMBOL_GPL vmlinux 0x3fc2339f	spi_sync
++EXPORT_SYMBOL_GPL vmlinux 0x3fdd2f9e	debugfs_create_x32
++EXPORT_SYMBOL_GPL vmlinux 0x400a024b	acpi_scan_lock_release
++EXPORT_SYMBOL_GPL vmlinux 0x4025e87e	xen_swiotlb_unmap_page
++EXPORT_SYMBOL_GPL vmlinux 0x403e9b3a	raw_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0x403f9529	gpio_request_one
++EXPORT_SYMBOL_GPL vmlinux 0x4045c494	filter_match_preds
++EXPORT_SYMBOL_GPL vmlinux 0x4054f37e	ping_bind
++EXPORT_SYMBOL_GPL vmlinux 0x4065d168	pm_print_active_wakeup_sources
++EXPORT_SYMBOL_GPL vmlinux 0x40671067	__rio_local_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x4071384c	ata_port_pbar_desc
++EXPORT_SYMBOL_GPL vmlinux 0x4078585f	pci_bus_max_busnr
++EXPORT_SYMBOL_GPL vmlinux 0x40a48ae3	ata_std_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x40af0dec	ata_xfer_mode2mask
++EXPORT_SYMBOL_GPL vmlinux 0x40c3202b	__clk_get_name
++EXPORT_SYMBOL_GPL vmlinux 0x40d46b21	crypto_ft_tab
++EXPORT_SYMBOL_GPL vmlinux 0x40e5e8f4	cgroup_is_descendant
++EXPORT_SYMBOL_GPL vmlinux 0x40f0683e	reset_control_put
++EXPORT_SYMBOL_GPL vmlinux 0x4114cb51	tc3589x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x414a71a5	mddev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x41700667	ata_qc_complete_multiple
++EXPORT_SYMBOL_GPL vmlinux 0x41814cb8	dirty_writeback_interval
++EXPORT_SYMBOL_GPL vmlinux 0x418c51f4	rdev_set_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x41938a12	cpufreq_notify_transition
++EXPORT_SYMBOL_GPL vmlinux 0x41c0d3f4	usb_set_interface
++EXPORT_SYMBOL_GPL vmlinux 0x41c72c10	disk_map_sector_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x41cc1fba	__blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0x41da11f9	device_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x41e1064f	acpi_get_gpio
++EXPORT_SYMBOL_GPL vmlinux 0x41e68e9a	fuse_conn_get
++EXPORT_SYMBOL_GPL vmlinux 0x4205ad24	cancel_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x4213a51a	efivar_entry_set_safe
++EXPORT_SYMBOL_GPL vmlinux 0x42160169	flush_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x424acc6d	scatterwalk_done
++EXPORT_SYMBOL_GPL vmlinux 0x42769c09	scsi_autopm_get_device
++EXPORT_SYMBOL_GPL vmlinux 0x427e8468	dev_pm_put_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0x42825ce2	rcu_scheduler_active
++EXPORT_SYMBOL_GPL vmlinux 0x42a5029b	xen_find_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x42aa0c6f	usb_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0x42ba8a13	__ata_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0x42bb7666	device_schedule_callback_owner
++EXPORT_SYMBOL_GPL vmlinux 0x42bd96e3	_submit_bh
++EXPORT_SYMBOL_GPL vmlinux 0x42c989ff	iomap_atomic_prot_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x432fd7f6	__gpio_set_value
++EXPORT_SYMBOL_GPL vmlinux 0x435e6c6e	crypto_alg_sem
++EXPORT_SYMBOL_GPL vmlinux 0x438fca82	rdev_clear_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x4390c490	pci_check_and_mask_intx
++EXPORT_SYMBOL_GPL vmlinux 0x43a53735	__alloc_workqueue_key
++EXPORT_SYMBOL_GPL vmlinux 0x43c6d231	unix_peer_get
++EXPORT_SYMBOL_GPL vmlinux 0x43f408db	pci_hp_deregister
++EXPORT_SYMBOL_GPL vmlinux 0x43f56e82	ata_xfer_mode2shift
++EXPORT_SYMBOL_GPL vmlinux 0x4405a595	xen_register_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x4408d896	cgroup_attach_task_all
++EXPORT_SYMBOL_GPL vmlinux 0x442780c9	tpm_pm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x44404f11	kdb_register_repeat
++EXPORT_SYMBOL_GPL vmlinux 0x4455e1b3	regulator_disable_deferred
++EXPORT_SYMBOL_GPL vmlinux 0x4484a5a4	wait_for_device_probe
++EXPORT_SYMBOL_GPL vmlinux 0x44c2a5d4	virtqueue_enable_cb
++EXPORT_SYMBOL_GPL vmlinux 0x44cc9c55	klist_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x44e3a216	xfrm_audit_policy_add
++EXPORT_SYMBOL_GPL vmlinux 0x4512b086	intel_scu_devices_create
++EXPORT_SYMBOL_GPL vmlinux 0x45159e32	key_type_user
++EXPORT_SYMBOL_GPL vmlinux 0x451a652f	dev_pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x451d32db	ata_sas_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x452aa53f	platform_get_irq
++EXPORT_SYMBOL_GPL vmlinux 0x4541fe0d	mtrr_state
++EXPORT_SYMBOL_GPL vmlinux 0x4544cdc6	regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0x4570db6e	unregister_net_sysctl_table
++EXPORT_SYMBOL_GPL vmlinux 0x457594fa	crypto_alg_list
++EXPORT_SYMBOL_GPL vmlinux 0x45801e8b	cred_to_ucred
++EXPORT_SYMBOL_GPL vmlinux 0x4582bf38	fuse_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0x4584940b	wm831x_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x4586f5d2	xenbus_register_backend
++EXPORT_SYMBOL_GPL vmlinux 0x45a4cb22	register_dock_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x45bf1ff3	crypto_inc
++EXPORT_SYMBOL_GPL vmlinux 0x45d14bdf	hypercall_page
++EXPORT_SYMBOL_GPL vmlinux 0x4604b817	wm8994_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x46074c17	sdev_evt_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x460a44a0	map_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x460f31aa	rodata_test_data
++EXPORT_SYMBOL_GPL vmlinux 0x460f7531	wait_rcu_gp
++EXPORT_SYMBOL_GPL vmlinux 0x46388af4	ehci_setup
++EXPORT_SYMBOL_GPL vmlinux 0x464fcb4c	sata_sff_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x4672e88b	__crypto_dequeue_request
++EXPORT_SYMBOL_GPL vmlinux 0x4688d7ec	pvclock_gtod_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x468a27f8	unix_inq_len
++EXPORT_SYMBOL_GPL vmlinux 0x46adb2fd	rtnl_put_cacheinfo
++EXPORT_SYMBOL_GPL vmlinux 0x46eb6544	inode_sb_list_add
++EXPORT_SYMBOL_GPL vmlinux 0x4701cd2a	ata_wait_after_reset
++EXPORT_SYMBOL_GPL vmlinux 0x47229b5c	gpio_request
++EXPORT_SYMBOL_GPL vmlinux 0x473372e0	scsi_unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x47485538	ping_err
++EXPORT_SYMBOL_GPL vmlinux 0x475414c6	__udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4758cc76	bitmap_resize
++EXPORT_SYMBOL_GPL vmlinux 0x4761f17c	register_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x476c2e6d	blk_trace_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4774cce3	wait_for_tpm_stat
++EXPORT_SYMBOL_GPL vmlinux 0x477a6ec6	cpufreq_frequency_get_table
++EXPORT_SYMBOL_GPL vmlinux 0x47884890	system_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0x47aad3b9	have_governor_per_policy
++EXPORT_SYMBOL_GPL vmlinux 0x47ab30e4	pci_test_config_bits
++EXPORT_SYMBOL_GPL vmlinux 0x47ec7290	usb_kill_urb
++EXPORT_SYMBOL_GPL vmlinux 0x47f5cee2	pm_generic_thaw_early
++EXPORT_SYMBOL_GPL vmlinux 0x47ff399f	regulator_is_supported_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x481c60aa	fuse_do_open
++EXPORT_SYMBOL_GPL vmlinux 0x48222050	inet6_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x4828e77b	acpi_scan_lock_acquire
++EXPORT_SYMBOL_GPL vmlinux 0x482bafcc	devm_clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4850e272	ata_sas_port_init
++EXPORT_SYMBOL_GPL vmlinux 0x48682db9	perf_guest_get_msrs
++EXPORT_SYMBOL_GPL vmlinux 0x48ab5da7	pkey_algo
++EXPORT_SYMBOL_GPL vmlinux 0x48b823da	devm_kzalloc
++EXPORT_SYMBOL_GPL vmlinux 0x48ca8947	pm_qos_add_request
++EXPORT_SYMBOL_GPL vmlinux 0x48d587b8	wakeup_source_add
++EXPORT_SYMBOL_GPL vmlinux 0x48ee3f37	usb_unanchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x48efd718	usb_acpi_power_manageable
++EXPORT_SYMBOL_GPL vmlinux 0x490a8df6	x86_platform
++EXPORT_SYMBOL_GPL vmlinux 0x4940a6bc	usb_put_hcd
++EXPORT_SYMBOL_GPL vmlinux 0x49545e34	pm_generic_poweroff_late
++EXPORT_SYMBOL_GPL vmlinux 0x496dce72	usb_hcd_check_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0x4972b7cb	pci_find_next_ht_capability
++EXPORT_SYMBOL_GPL vmlinux 0x4982a57f	probe_kernel_write
++EXPORT_SYMBOL_GPL vmlinux 0x498d293a	trace_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0x499043d3	crypto_init_queue
++EXPORT_SYMBOL_GPL vmlinux 0x49c676d3	irq_create_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x4a1c7276	fat_time_unix2fat
++EXPORT_SYMBOL_GPL vmlinux 0x4a28d31f	xfrm_output_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4a338f51	spi_register_master
++EXPORT_SYMBOL_GPL vmlinux 0x4a3c3cf9	microcode_sanity_check
++EXPORT_SYMBOL_GPL vmlinux 0x4a60c85c	serial8250_rx_chars
++EXPORT_SYMBOL_GPL vmlinux 0x4a6960d1	acpi_subsys_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x4a8d0bce	wm8400_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x4aadeb9a	ring_buffer_alloc_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x4ac4a771	sock_diag_unregister_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x4ad39ac6	fuse_request_send
++EXPORT_SYMBOL_GPL vmlinux 0x4afb573b	vrtc_cmos_read
++EXPORT_SYMBOL_GPL vmlinux 0x4b070f8e	inet6_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4b35cef0	devm_reset_control_get
++EXPORT_SYMBOL_GPL vmlinux 0x4b3a6554	wait_for_stable_page
++EXPORT_SYMBOL_GPL vmlinux 0x4b47aeb8	skb_copy_ubufs
++EXPORT_SYMBOL_GPL vmlinux 0x4b555de8	ping_getfrag
++EXPORT_SYMBOL_GPL vmlinux 0x4b60ed38	ata_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4b7d74a8	pci_renumber_slot
++EXPORT_SYMBOL_GPL vmlinux 0x4bc62a81	audit_enabled
++EXPORT_SYMBOL_GPL vmlinux 0x4bca7b8c	register_ftrace_event
++EXPORT_SYMBOL_GPL vmlinux 0x4bea2db3	mmu_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x4bfbd732	ata_pci_bmdma_init_one
++EXPORT_SYMBOL_GPL vmlinux 0x4bff1ad9	regmap_async_complete
++EXPORT_SYMBOL_GPL vmlinux 0x4c10d14d	__wake_up_locked
++EXPORT_SYMBOL_GPL vmlinux 0x4c16f764	btree_remove
++EXPORT_SYMBOL_GPL vmlinux 0x4c2a472b	__static_cpu_has_safe
++EXPORT_SYMBOL_GPL vmlinux 0x4c586dd0	dm_get_rq_mapinfo
++EXPORT_SYMBOL_GPL vmlinux 0x4c602bf1	__blkg_release_rcu
++EXPORT_SYMBOL_GPL vmlinux 0x4c671962	napi_hash_del
++EXPORT_SYMBOL_GPL vmlinux 0x4c759827	byte_rev_table
++EXPORT_SYMBOL_GPL vmlinux 0x4ce298b6	tpm_pm_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4d324ba6	crypto_alloc_shash
++EXPORT_SYMBOL_GPL vmlinux 0x4d7e195a	tpm_calc_ordinal_duration
++EXPORT_SYMBOL_GPL vmlinux 0x4db0507a	crypto_alg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x4dcb1d13	xen_swiotlb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x4dce5d69	ata_host_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4de17ab3	usb_state_string
++EXPORT_SYMBOL_GPL vmlinux 0x4dff5362	pci_load_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x4e02a515	__get_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x4e098fb0	xenbus_dev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x4e109192	ring_buffer_entries
++EXPORT_SYMBOL_GPL vmlinux 0x4e156122	pm_generic_restore_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x4e242f5f	pstore_cannot_block_path
++EXPORT_SYMBOL_GPL vmlinux 0x4e2e1e8b	xfrm_audit_state_notfound
++EXPORT_SYMBOL_GPL vmlinux 0x4e402814	usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0x4e57723d	apei_read
++EXPORT_SYMBOL_GPL vmlinux 0x4e64c91c	page_mkclean
++EXPORT_SYMBOL_GPL vmlinux 0x4e68c4a5	pm_generic_poweroff_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x4e74e625	gnttab_batch_copy
++EXPORT_SYMBOL_GPL vmlinux 0x4ef5bcf4	perf_swevent_get_recursion_context
++EXPORT_SYMBOL_GPL vmlinux 0x4f0df885	xfrm_audit_state_replay_overflow
++EXPORT_SYMBOL_GPL vmlinux 0x4f0f92cb	aead_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x4f2868ab	ata_bmdma_qc_issue
++EXPORT_SYMBOL_GPL vmlinux 0x4f2c2e60	alloc_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x4f30f82b	subsys_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0x4f3dbb12	pwm_can_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x4f5672dc	sdio_disable_func
++EXPORT_SYMBOL_GPL vmlinux 0x4f6ff1a4	ata_sas_port_async_resume
++EXPORT_SYMBOL_GPL vmlinux 0x4fcd77a3	tty_perform_flush
++EXPORT_SYMBOL_GPL vmlinux 0x4fd4b385	dm_path_uevent
++EXPORT_SYMBOL_GPL vmlinux 0x4fd4e89d	ring_buffer_empty_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x4fdc945d	sata_deb_timing_normal
++EXPORT_SYMBOL_GPL vmlinux 0x4fe1eddf	unregister_netevent_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x4febe332	blkio_subsys
++EXPORT_SYMBOL_GPL vmlinux 0x5026585c	xen_irq_from_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x502f00aa	vfs_cancel_lock
++EXPORT_SYMBOL_GPL vmlinux 0x5039c146	rtc_read_time
++EXPORT_SYMBOL_GPL vmlinux 0x5059615f	tpm_do_selftest
++EXPORT_SYMBOL_GPL vmlinux 0x505ab52d	clk_round_rate
++EXPORT_SYMBOL_GPL vmlinux 0x506691f1	sock_diag_check_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x506cc085	tracepoint_iter_stop
++EXPORT_SYMBOL_GPL vmlinux 0x5086ac3a	alg_test
++EXPORT_SYMBOL_GPL vmlinux 0x5087363a	elv_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5091b823	ring_buffer_read_start
++EXPORT_SYMBOL_GPL vmlinux 0x5098eecb	tps65912_clear_bits
++EXPORT_SYMBOL_GPL vmlinux 0x50a50a7b	arizona_request_irq
++EXPORT_SYMBOL_GPL vmlinux 0x50c89f23	__alloc_percpu
++EXPORT_SYMBOL_GPL vmlinux 0x50d7f892	pci_create_slot
++EXPORT_SYMBOL_GPL vmlinux 0x50dcbda2	acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x50e7193a	__i2c_first_dynamic_bus_num
++EXPORT_SYMBOL_GPL vmlinux 0x50fad434	round_jiffies_up
++EXPORT_SYMBOL_GPL vmlinux 0x51073425	cpuidle_get_cpu_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5108b3fc	acpi_os_map_memory
++EXPORT_SYMBOL_GPL vmlinux 0x515363b6	iommu_set_fault_handler
++EXPORT_SYMBOL_GPL vmlinux 0x516b42a7	cpufreq_unregister_governor
++EXPORT_SYMBOL_GPL vmlinux 0x5187ac4b	xen_store_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x518c2fc6	hpet_rtc_dropped_irq
++EXPORT_SYMBOL_GPL vmlinux 0x51a52562	regmap_raw_write_async
++EXPORT_SYMBOL_GPL vmlinux 0x51a8b990	register_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x51d38456	usb_disable_ltm
++EXPORT_SYMBOL_GPL vmlinux 0x51d785ce	set_task_ioprio
++EXPORT_SYMBOL_GPL vmlinux 0x51f603ff	platform_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x520f3540	pci_user_write_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0x5210a5bf	hsi_board_list
++EXPORT_SYMBOL_GPL vmlinux 0x5217e4c1	__rt_mutex_init
++EXPORT_SYMBOL_GPL vmlinux 0x52212010	__tracepoint_block_bio_remap
++EXPORT_SYMBOL_GPL vmlinux 0x52574d04	irq_gc_mask_clr_bit
++EXPORT_SYMBOL_GPL vmlinux 0x525cbf07	alarm_start
++EXPORT_SYMBOL_GPL vmlinux 0x52b7b99a	rio_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0x52c68357	nf_queue_entry_release_refs
++EXPORT_SYMBOL_GPL vmlinux 0x52e2381b	__blkg_prfill_u64
++EXPORT_SYMBOL_GPL vmlinux 0x52edcab1	ata_acpi_gtm
++EXPORT_SYMBOL_GPL vmlinux 0x53408419	pci_user_write_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0x5358fc36	ring_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0x53614269	get_cpu_idle_time_us
++EXPORT_SYMBOL_GPL vmlinux 0x536d1f07	power_supply_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x5391b3b0	srcu_batches_completed
++EXPORT_SYMBOL_GPL vmlinux 0x5395f8d4	xen_swiotlb_unmap_sg_attrs
++EXPORT_SYMBOL_GPL vmlinux 0x539f157b	pci_xen_swiotlb_init_late
++EXPORT_SYMBOL_GPL vmlinux 0x53a3e486	regulator_get_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0x53cb0091	devres_for_each_res
++EXPORT_SYMBOL_GPL vmlinux 0x53eabb9b	rtc_irq_set_state
++EXPORT_SYMBOL_GPL vmlinux 0x53ecb908	rt_mutex_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x53ed9b3d	init_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x53f8415f	debugfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0x53fd654d	aead_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x541bd60a	irq_work_run
++EXPORT_SYMBOL_GPL vmlinux 0x543db4ce	cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x5460c8d8	fsnotify_get_cookie
++EXPORT_SYMBOL_GPL vmlinux 0x54703d11	rtc_class_close
++EXPORT_SYMBOL_GPL vmlinux 0x54740eb7	get_cpu_idle_time
++EXPORT_SYMBOL_GPL vmlinux 0x5484aa8e	blk_rq_check_limits
++EXPORT_SYMBOL_GPL vmlinux 0x5488ff7f	screen_glyph
++EXPORT_SYMBOL_GPL vmlinux 0x549525ef	handle_nested_irq
++EXPORT_SYMBOL_GPL vmlinux 0x54ac9a32	extcon_unregister_interest
++EXPORT_SYMBOL_GPL vmlinux 0x54b8ac68	gen_pool_avail
++EXPORT_SYMBOL_GPL vmlinux 0x54cb76b0	irq_get_domain_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0x54d735db	scsi_target_block
++EXPORT_SYMBOL_GPL vmlinux 0x54edb686	rtc_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55417264	unregister_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x55526907	xen_features
++EXPORT_SYMBOL_GPL vmlinux 0x557510d0	regulator_list_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x55784228	regmap_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x558896b2	md_do_sync
++EXPORT_SYMBOL_GPL vmlinux 0x558e7e3a	fuse_file_poll
++EXPORT_SYMBOL_GPL vmlinux 0x55987b3c	sock_diag_register_inet_compat
++EXPORT_SYMBOL_GPL vmlinux 0x55b9c432	tc3589x_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x55ba8ccf	thermal_zone_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x55bdb7e6	dma_buf_kmap
++EXPORT_SYMBOL_GPL vmlinux 0x55edd53d	unregister_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x56310925	regulator_mode_to_status
++EXPORT_SYMBOL_GPL vmlinux 0x56398615	mark_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5641485b	tty_termios_encode_baud_rate
++EXPORT_SYMBOL_GPL vmlinux 0x564f1dca	klist_add_after
++EXPORT_SYMBOL_GPL vmlinux 0x5654f836	erst_get_record_id_next
++EXPORT_SYMBOL_GPL vmlinux 0x565b6892	uuid_le_gen
++EXPORT_SYMBOL_GPL vmlinux 0x56631cca	usb_remove_phy
++EXPORT_SYMBOL_GPL vmlinux 0x56886b19	scatterwalk_map
++EXPORT_SYMBOL_GPL vmlinux 0x56945918	ata_cable_40wire
++EXPORT_SYMBOL_GPL vmlinux 0x56947347	dmi_walk
++EXPORT_SYMBOL_GPL vmlinux 0x56b63670	lzo1x_1_compress
++EXPORT_SYMBOL_GPL vmlinux 0x56d697ce	cpu_up
++EXPORT_SYMBOL_GPL vmlinux 0x56e4a390	pid_vnr
++EXPORT_SYMBOL_GPL vmlinux 0x56e75d47	klist_node_attached
++EXPORT_SYMBOL_GPL vmlinux 0x57231f45	ring_buffer_record_on
++EXPORT_SYMBOL_GPL vmlinux 0x57374399	pci_get_hp_params
++EXPORT_SYMBOL_GPL vmlinux 0x5758c7f4	get_cpu_device
++EXPORT_SYMBOL_GPL vmlinux 0x5775799d	rio_mport_write_config_8
++EXPORT_SYMBOL_GPL vmlinux 0x5779d445	xenbus_exists
++EXPORT_SYMBOL_GPL vmlinux 0x579cbded	pci_disable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0x579e0bf5	rtnl_unregister_all
++EXPORT_SYMBOL_GPL vmlinux 0x57af481b	ata_sff_thaw
++EXPORT_SYMBOL_GPL vmlinux 0x57d0950e	pwm_set_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x580d57da	devm_add_action
++EXPORT_SYMBOL_GPL vmlinux 0x580ddc7c	ata_cable_ignore
++EXPORT_SYMBOL_GPL vmlinux 0x5839fc62	gen_pool_size
++EXPORT_SYMBOL_GPL vmlinux 0x58413099	ipv6_fixup_options
++EXPORT_SYMBOL_GPL vmlinux 0x585704ab	aer_recover_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5859a97a	blk_queue_dma_drain
++EXPORT_SYMBOL_GPL vmlinux 0x58709d5f	ftrace_set_filter_ip
++EXPORT_SYMBOL_GPL vmlinux 0x58743f66	pci_assign_unassigned_bridge_resources
++EXPORT_SYMBOL_GPL vmlinux 0x58843e36	pciserial_init_ports
++EXPORT_SYMBOL_GPL vmlinux 0x589e4569	syscon_regmap_lookup_by_pdevname
++EXPORT_SYMBOL_GPL vmlinux 0x58b77930	acpi_dma_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0x58ce2273	dma_wait_for_async_tx
++EXPORT_SYMBOL_GPL vmlinux 0x58d03cbe	zap_vma_ptes
++EXPORT_SYMBOL_GPL vmlinux 0x58fe9409	rio_inb_pwrite_handler
++EXPORT_SYMBOL_GPL vmlinux 0x590a1b0e	skcipher_geniv_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x590bdc4b	regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x591b3650	dma_buf_fd
++EXPORT_SYMBOL_GPL vmlinux 0x591e6b27	cgroup_next_descendant_post
++EXPORT_SYMBOL_GPL vmlinux 0x59208945	scsi_flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x59355079	devm_usb_get_phy
++EXPORT_SYMBOL_GPL vmlinux 0x594300ef	platform_get_resource_byname
++EXPORT_SYMBOL_GPL vmlinux 0x5947abbe	max77693_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0x5977b715	extcon_get_extcon_dev
++EXPORT_SYMBOL_GPL vmlinux 0x59e2743e	call_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0x59eae699	ring_buffer_read_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x5a2b1b67	gnttab_free_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5a441ebd	efi_query_variable_store
++EXPORT_SYMBOL_GPL vmlinux 0x5a48534a	regulator_count_voltages
++EXPORT_SYMBOL_GPL vmlinux 0x5a516a6f	dma_buf_end_cpu_access
++EXPORT_SYMBOL_GPL vmlinux 0x5a689560	sata_async_notification
++EXPORT_SYMBOL_GPL vmlinux 0x5a7bfe41	crypto_probing_notify
++EXPORT_SYMBOL_GPL vmlinux 0x5a8a5340	get_net_ns_by_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5ab95fe9	debugfs_create_blob
++EXPORT_SYMBOL_GPL vmlinux 0x5ad32297	__audit_inode_child
++EXPORT_SYMBOL_GPL vmlinux 0x5af03a28	gnttab_claim_grant_reference
++EXPORT_SYMBOL_GPL vmlinux 0x5b0e2181	swiotlb_tbl_sync_single
++EXPORT_SYMBOL_GPL vmlinux 0x5b1d1d83	inet_csk_reqsk_queue_hash_add
++EXPORT_SYMBOL_GPL vmlinux 0x5b216f49	udp4_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x5b38d9ab	sysfs_create_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x5b51125b	part_round_stats
++EXPORT_SYMBOL_GPL vmlinux 0x5b5124f5	__inet_lookup_listener
++EXPORT_SYMBOL_GPL vmlinux 0x5b61a6ee	devm_acpi_dma_controller_free
++EXPORT_SYMBOL_GPL vmlinux 0x5b682e37	extcon_set_cable_state_
++EXPORT_SYMBOL_GPL vmlinux 0x5b7e486d	tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x5b841cd2	rtc_alarm_irq_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5ba3bf62	bsg_register_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5babf842	register_jprobes
++EXPORT_SYMBOL_GPL vmlinux 0x5baca0f8	sock_prot_inuse_add
++EXPORT_SYMBOL_GPL vmlinux 0x5baccad7	iommu_domain_window_enable
++EXPORT_SYMBOL_GPL vmlinux 0x5bb5d3b3	xen_unmap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0x5bcb22f3	find_get_pid
++EXPORT_SYMBOL_GPL vmlinux 0x5beb8921	isa_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x5bec2576	xen_unregister_device_domain_owner
++EXPORT_SYMBOL_GPL vmlinux 0x5c067044	sysfs_remove_link_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x5c5260cf	subsys_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0x5c66e90c	efivar_run_worker
++EXPORT_SYMBOL_GPL vmlinux 0x5c86dabf	xen_swiotlb_sync_sg_for_device
++EXPORT_SYMBOL_GPL vmlinux 0x5c91cfd6	ip6_local_out
++EXPORT_SYMBOL_GPL vmlinux 0x5cabdced	dev_pm_qos_remove_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x5cc021a3	devres_get
++EXPORT_SYMBOL_GPL vmlinux 0x5cc63382	blk_lld_busy
++EXPORT_SYMBOL_GPL vmlinux 0x5ceb6d9e	rdev_get_id
++EXPORT_SYMBOL_GPL vmlinux 0x5cf602a4	tcp_twsk_destructor
++EXPORT_SYMBOL_GPL vmlinux 0x5d12e48f	input_event_to_user
++EXPORT_SYMBOL_GPL vmlinux 0x5d366dec	gnttab_cancel_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0x5d461da1	device_reprobe
++EXPORT_SYMBOL_GPL vmlinux 0x5d48a650	m2p_find_override_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x5d66dcf7	acpi_dev_get_resources
++EXPORT_SYMBOL_GPL vmlinux 0x5d69543b	bsg_unregister_queue
++EXPORT_SYMBOL_GPL vmlinux 0x5d889c8c	ata_bmdma_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x5da9593a	thermal_notify_framework
++EXPORT_SYMBOL_GPL vmlinux 0x5dc991bc	regulator_map_voltage_linear
++EXPORT_SYMBOL_GPL vmlinux 0x5dd18380	regulator_get_init_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x5df3a4fd	input_ff_create
++EXPORT_SYMBOL_GPL vmlinux 0x5e03ffbe	bus_for_each_drv
++EXPORT_SYMBOL_GPL vmlinux 0x5e0f303b	usb_hcd_end_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0x5e191fbd	shmem_truncate_range
++EXPORT_SYMBOL_GPL vmlinux 0x5e51cd74	swiotlb_nr_tbl
++EXPORT_SYMBOL_GPL vmlinux 0x5e5b735e	usb_control_msg
++EXPORT_SYMBOL_GPL vmlinux 0x5e7631ec	find_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x5e821b74	tty_ldisc_ref_wait
++EXPORT_SYMBOL_GPL vmlinux 0x5e8a0e8a	led_trigger_blink_oneshot
++EXPORT_SYMBOL_GPL vmlinux 0x5ea9e92b	skb_complete_wifi_ack
++EXPORT_SYMBOL_GPL vmlinux 0x5f08a1b0	acpiphp_unregister_attention
++EXPORT_SYMBOL_GPL vmlinux 0x5f0d8923	usb_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0x5f248f72	set_timer_slack
++EXPORT_SYMBOL_GPL vmlinux 0x5f2da8c4	check_tsc_unstable
++EXPORT_SYMBOL_GPL vmlinux 0x5f33f20c	pci_bus_resource_n
++EXPORT_SYMBOL_GPL vmlinux 0x5f5c7198	wm831x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x5f6b569b	da903x_reads
++EXPORT_SYMBOL_GPL vmlinux 0x5f6ba45b	ata_bmdma_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x5f74b849	sync_filesystem
++EXPORT_SYMBOL_GPL vmlinux 0x5f977df4	crypto_larval_kill
++EXPORT_SYMBOL_GPL vmlinux 0x5fa72da5	usb_put_intf
++EXPORT_SYMBOL_GPL vmlinux 0x5fb49dbb	tasklet_hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x5fc27be9	acpi_dev_irq_flags
++EXPORT_SYMBOL_GPL vmlinux 0x5fd5e843	led_trigger_register_simple
++EXPORT_SYMBOL_GPL vmlinux 0x5fdfa2c1	amd_pmu_enable_virt
++EXPORT_SYMBOL_GPL vmlinux 0x5ff2c5d8	stmpe_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x602277fe	device_for_each_child
++EXPORT_SYMBOL_GPL vmlinux 0x604f2727	usb_reset_endpoint
++EXPORT_SYMBOL_GPL vmlinux 0x60506751	unmap_kernel_range_noflush
++EXPORT_SYMBOL_GPL vmlinux 0x6097c23f	ata_pci_sff_activate_host
++EXPORT_SYMBOL_GPL vmlinux 0x60a13e90	rcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x60cd73ed	pv_apic_ops
++EXPORT_SYMBOL_GPL vmlinux 0x61024fd3	replace_page_cache_page
++EXPORT_SYMBOL_GPL vmlinux 0x611006d5	apic
++EXPORT_SYMBOL_GPL vmlinux 0x6114d8a4	regulator_force_disable
++EXPORT_SYMBOL_GPL vmlinux 0x6129f4da	pci_pasid_features
++EXPORT_SYMBOL_GPL vmlinux 0x61439622	sysfs_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0x616b7f9c	__mrst_cpu_chip
++EXPORT_SYMBOL_GPL vmlinux 0x61dd559d	pm_runtime_no_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0x61f6d4c8	nfq_ct_hook
++EXPORT_SYMBOL_GPL vmlinux 0x62085a5c	led_trigger_set
++EXPORT_SYMBOL_GPL vmlinux 0x622c33bc	cpuidle_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x622c7922	register_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x622dacba	tick_nohz_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x623803c8	hest_disable
++EXPORT_SYMBOL_GPL vmlinux 0x623c4853	crypto_unregister_instance
++EXPORT_SYMBOL_GPL vmlinux 0x6248b5be	__clk_get_flags
++EXPORT_SYMBOL_GPL vmlinux 0x624a6406	hwrng_register
++EXPORT_SYMBOL_GPL vmlinux 0x624b38eb	rio_release_outb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x626f2397	vring_del_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0x62954086	thermal_zone_device_update
++EXPORT_SYMBOL_GPL vmlinux 0x629da8f9	of_pwm_xlate_with_flags
++EXPORT_SYMBOL_GPL vmlinux 0x62cdfd5d	sysfs_create_files
++EXPORT_SYMBOL_GPL vmlinux 0x62d37c3b	blkg_rwstat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0x6308893c	unregister_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x63205de1	ata_scsi_unlock_native_capacity
++EXPORT_SYMBOL_GPL vmlinux 0x635adf4a	ata_do_dev_read_id
++EXPORT_SYMBOL_GPL vmlinux 0x635ec980	apei_exec_post_unmap_gars
++EXPORT_SYMBOL_GPL vmlinux 0x635f40d4	usb_hcd_unmap_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0x63743249	dev_pm_qos_flags
++EXPORT_SYMBOL_GPL vmlinux 0x63bc16e5	spi_get_next_queued_message
++EXPORT_SYMBOL_GPL vmlinux 0x63bd6ec9	alarm_expires_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x63c1ae9e	pm_generic_restore
++EXPORT_SYMBOL_GPL vmlinux 0x63fd0e6b	tps65912_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x640d4376	iommu_detach_device
++EXPORT_SYMBOL_GPL vmlinux 0x641d24a8	xen_swiotlb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0x64256424	visitor32
++EXPORT_SYMBOL_GPL vmlinux 0x6449732a	anon_transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0x644ef907	ata_sff_prereset
++EXPORT_SYMBOL_GPL vmlinux 0x645974e6	ata_host_register
++EXPORT_SYMBOL_GPL vmlinux 0x6459a31c	usb_store_new_id
++EXPORT_SYMBOL_GPL vmlinux 0x646edfbe	crypto_spawn_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x64aff771	generic_fh_to_dentry
++EXPORT_SYMBOL_GPL vmlinux 0x64c33cf4	md_ack_all_badblocks
++EXPORT_SYMBOL_GPL vmlinux 0x64c68ed1	fuse_do_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x64ca0f44	usb_find_interface
++EXPORT_SYMBOL_GPL vmlinux 0x64db6d28	iommu_map
++EXPORT_SYMBOL_GPL vmlinux 0x64e6e309	simple_attr_read
++EXPORT_SYMBOL_GPL vmlinux 0x64f344f7	ip6_datagram_connect
++EXPORT_SYMBOL_GPL vmlinux 0x651ab014	attribute_container_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x6521bb4b	__init_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x6527a231	dbgp_external_startup
++EXPORT_SYMBOL_GPL vmlinux 0x65399fd7	__rtnl_link_register
++EXPORT_SYMBOL_GPL vmlinux 0x653cb02d	intel_msic_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x6546f61f	ata_eh_qc_complete
++EXPORT_SYMBOL_GPL vmlinux 0x6567a2f2	wm831x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6580254a	ftrace_set_filter
++EXPORT_SYMBOL_GPL vmlinux 0x658c8186	amd_get_nb_id
++EXPORT_SYMBOL_GPL vmlinux 0x65bbbc78	schedule_hrtimeout_range
++EXPORT_SYMBOL_GPL vmlinux 0x65c57d5c	platform_device_register_full
++EXPORT_SYMBOL_GPL vmlinux 0x65ccb6f0	call_netevent_notifiers
++EXPORT_SYMBOL_GPL vmlinux 0x65d2afa1	tpm_remove_ppi
++EXPORT_SYMBOL_GPL vmlinux 0x65d6d0f0	gpio_direction_input
++EXPORT_SYMBOL_GPL vmlinux 0x65e2858a	inet_ctl_sock_create
++EXPORT_SYMBOL_GPL vmlinux 0x65fa533b	usb_unpoison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x65ff2579	get_matching_microcode
++EXPORT_SYMBOL_GPL vmlinux 0x661601de	sprint_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x6627eec6	cleanup_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x6633d346	__srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x663c16d6	gnttab_grant_foreign_access_subpage_ref
++EXPORT_SYMBOL_GPL vmlinux 0x66742e3f	__netpoll_setup
++EXPORT_SYMBOL_GPL vmlinux 0x66834a62	pci_bus_sem
++EXPORT_SYMBOL_GPL vmlinux 0x668402aa	crypto_put_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x66885c56	debugfs_create_size_t
++EXPORT_SYMBOL_GPL vmlinux 0x66c202c2	ata_host_alloc_pinfo
++EXPORT_SYMBOL_GPL vmlinux 0x66ca4d50	pci_slots_kset
++EXPORT_SYMBOL_GPL vmlinux 0x66d3b166	acpi_unbind_one
++EXPORT_SYMBOL_GPL vmlinux 0x66d87d38	symbol_put_addr
++EXPORT_SYMBOL_GPL vmlinux 0x66e21ea2	xen_swiotlb_sync_single_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0x66f7f60d	wm8997_aod
++EXPORT_SYMBOL_GPL vmlinux 0x670560b6	xenbus_map_ring_valloc
++EXPORT_SYMBOL_GPL vmlinux 0x6710ce81	bsg_job_done
++EXPORT_SYMBOL_GPL vmlinux 0x6714de4f	ablkcipher_walk_phys
++EXPORT_SYMBOL_GPL vmlinux 0x6724a57a	driver_register
++EXPORT_SYMBOL_GPL vmlinux 0x6739a503	balloon_set_new_target
++EXPORT_SYMBOL_GPL vmlinux 0x674e13e1	public_key_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x67557667	usb_debug_root
++EXPORT_SYMBOL_GPL vmlinux 0x67643d26	pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0x676cdc5b	da9052_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x67756a29	rio_get_asm
++EXPORT_SYMBOL_GPL vmlinux 0x67955ce6	profile_hits
++EXPORT_SYMBOL_GPL vmlinux 0x6812cf8d	__tracepoint_rpm_idle
++EXPORT_SYMBOL_GPL vmlinux 0x682905ba	crypto_drop_spawn
++EXPORT_SYMBOL_GPL vmlinux 0x683f0f33	irq_gc_mask_set_bit
++EXPORT_SYMBOL_GPL vmlinux 0x684168d5	tun_get_socket
++EXPORT_SYMBOL_GPL vmlinux 0x6844c3fa	swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x684dac0b	pm_generic_resume_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x68956406	static_key_slow_dec
++EXPORT_SYMBOL_GPL vmlinux 0x689c4813	sysfs_update_group
++EXPORT_SYMBOL_GPL vmlinux 0x689cda52	disk_part_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x68cc3cd7	ata_sff_error_handler
++EXPORT_SYMBOL_GPL vmlinux 0x68d15a90	device_find_child
++EXPORT_SYMBOL_GPL vmlinux 0x68e2deaa	cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x68f74ce4	ata_pci_device_do_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x690bf5fe	sock_diag_put_meminfo
++EXPORT_SYMBOL_GPL vmlinux 0x6923ce63	irq_work_sync
++EXPORT_SYMBOL_GPL vmlinux 0x69447467	ring_buffer_write
++EXPORT_SYMBOL_GPL vmlinux 0x6945725e	mpi_read_raw_data
++EXPORT_SYMBOL_GPL vmlinux 0x695eae25	devres_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0x696c829b	rtc_set_mmss
++EXPORT_SYMBOL_GPL vmlinux 0x69787660	tty_ldisc_deref
++EXPORT_SYMBOL_GPL vmlinux 0x697c5d0d	tracing_snapshot_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x698a899f	ring_buffer_peek
++EXPORT_SYMBOL_GPL vmlinux 0x698be398	regulator_get_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x69a19375	kobject_init_and_add
++EXPORT_SYMBOL_GPL vmlinux 0x69b610f4	usb_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x69b80ba0	dev_pm_qos_hide_flags
++EXPORT_SYMBOL_GPL vmlinux 0x69c79dc0	tpm_write
++EXPORT_SYMBOL_GPL vmlinux 0x69caf2fe	da903x_read
++EXPORT_SYMBOL_GPL vmlinux 0x69e9a2cb	ata_scsi_slave_config
++EXPORT_SYMBOL_GPL vmlinux 0x69f6a3d8	usb_root_hub_lost_power
++EXPORT_SYMBOL_GPL vmlinux 0x6a1733eb	iommu_group_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6a2859e6	watchdog_init_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x6a2a6a19	disable_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6a2f3e4a	acpi_dev_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x6a329617	cn_add_callback
++EXPORT_SYMBOL_GPL vmlinux 0x6a41e541	rtc_set_time
++EXPORT_SYMBOL_GPL vmlinux 0x6a5fb566	rcu_sched_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x6a8441be	cpci_hp_start
++EXPORT_SYMBOL_GPL vmlinux 0x6a887361	shake_page
++EXPORT_SYMBOL_GPL vmlinux 0x6a8ca2d9	virtqueue_kick
++EXPORT_SYMBOL_GPL vmlinux 0x6aaf579d	ata_port_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x6ab03754	usb_alloc_urb
++EXPORT_SYMBOL_GPL vmlinux 0x6ab77430	wm5110_aod
++EXPORT_SYMBOL_GPL vmlinux 0x6ab922b2	regulator_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0x6aba167a	regulator_list_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x6acad21f	acpi_get_cpuid
++EXPORT_SYMBOL_GPL vmlinux 0x6ad129eb	led_classdev_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6b0594f9	subsys_dev_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x6b152875	efivar_entry_get
++EXPORT_SYMBOL_GPL vmlinux 0x6b179d71	__blk_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x6b29a1fa	ring_buffer_event_length
++EXPORT_SYMBOL_GPL vmlinux 0x6b3b4043	crypto_lookup_aead
++EXPORT_SYMBOL_GPL vmlinux 0x6b519ba6	pwm_get_chip_data
++EXPORT_SYMBOL_GPL vmlinux 0x6b653d80	ip6_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x6b8bb4d4	free_vm_area
++EXPORT_SYMBOL_GPL vmlinux 0x6ba1fa10	__rio_local_read_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x6ba36c9f	disk_get_part
++EXPORT_SYMBOL_GPL vmlinux 0x6be8e468	regulator_get_exclusive
++EXPORT_SYMBOL_GPL vmlinux 0x6bf45254	regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x6bfe3e8d	ata_eh_analyze_ncq_error
++EXPORT_SYMBOL_GPL vmlinux 0x6c04d9c2	ftrace_set_notrace
++EXPORT_SYMBOL_GPL vmlinux 0x6c1251fd	apei_exec_read_register
++EXPORT_SYMBOL_GPL vmlinux 0x6c1c7c5c	__clocksource_register_scale
++EXPORT_SYMBOL_GPL vmlinux 0x6c49c4f2	clockevents_notify
++EXPORT_SYMBOL_GPL vmlinux 0x6c4b6684	reset_control_assert
++EXPORT_SYMBOL_GPL vmlinux 0x6c655913	register_acpi_hed_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x6c749afe	__tracepoint_block_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x6c8934e2	shash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d5ae8	__gpio_get_value
++EXPORT_SYMBOL_GPL vmlinux 0x6c8d7bf1	mddev_init
++EXPORT_SYMBOL_GPL vmlinux 0x6ca4bf88	async_synchronize_full_domain
++EXPORT_SYMBOL_GPL vmlinux 0x6d18f3a3	ohci_resume
++EXPORT_SYMBOL_GPL vmlinux 0x6d2fc5a6	net_namespace_list
++EXPORT_SYMBOL_GPL vmlinux 0x6d31e93b	tracepoint_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0x6d374fa5	wm8350_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x6d48ff91	debugfs_create_bool
++EXPORT_SYMBOL_GPL vmlinux 0x6d994f66	ata_link_offline
++EXPORT_SYMBOL_GPL vmlinux 0x6dcdceaa	ref_module
++EXPORT_SYMBOL_GPL vmlinux 0x6ddb3575	tps6586x_irq_get_virq
++EXPORT_SYMBOL_GPL vmlinux 0x6dddb1a0	regmap_field_read
++EXPORT_SYMBOL_GPL vmlinux 0x6dec388e	serial8250_clear_and_reinit_fifos
++EXPORT_SYMBOL_GPL vmlinux 0x6dfeeddf	bsg_setup_queue
++EXPORT_SYMBOL_GPL vmlinux 0x6e02ef11	inet_twsk_purge
++EXPORT_SYMBOL_GPL vmlinux 0x6e04a077	usb_bind_phy
++EXPORT_SYMBOL_GPL vmlinux 0x6e098f14	register_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0x6e261ae6	led_stop_software_blink
++EXPORT_SYMBOL_GPL vmlinux 0x6e38cea0	crypto_create_tfm
++EXPORT_SYMBOL_GPL vmlinux 0x6e58ddf0	gnttab_end_foreign_transfer_ref
++EXPORT_SYMBOL_GPL vmlinux 0x6e6cce8f	__get_user_pages_fast
++EXPORT_SYMBOL_GPL vmlinux 0x6e782c23	iomap_create_wc
++EXPORT_SYMBOL_GPL vmlinux 0x6e7943ec	iommu_group_id
++EXPORT_SYMBOL_GPL vmlinux 0x6e85b00b	local_touch_nmi
++EXPORT_SYMBOL_GPL vmlinux 0x6e89a560	regmap_irq_chip_get_base
++EXPORT_SYMBOL_GPL vmlinux 0x6eb88ed3	iommu_unmap
++EXPORT_SYMBOL_GPL vmlinux 0x6ebba051	ata_sff_check_status
++EXPORT_SYMBOL_GPL vmlinux 0x6ec2eb90	pci_load_and_free_saved_state
++EXPORT_SYMBOL_GPL vmlinux 0x6ec35bcd	bdi_writeout_inc
++EXPORT_SYMBOL_GPL vmlinux 0x6ef420c7	con_debug_enter
++EXPORT_SYMBOL_GPL vmlinux 0x6f1b2f7a	fl6_merge_options
++EXPORT_SYMBOL_GPL vmlinux 0x6f1ee69e	kgdb_unregister_io_module
++EXPORT_SYMBOL_GPL vmlinux 0x6f5141ba	irq_find_host
++EXPORT_SYMBOL_GPL vmlinux 0x6f71eaa2	nfq_ct_nat_hook
++EXPORT_SYMBOL_GPL vmlinux 0x6fe3d8cf	ktime_add_safe
++EXPORT_SYMBOL_GPL vmlinux 0x6fe92d72	usb_bulk_msg
++EXPORT_SYMBOL_GPL vmlinux 0x6fee6383	task_active_pid_ns
++EXPORT_SYMBOL_GPL vmlinux 0x6ff607b6	crypto_get_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x70007118	led_classdev_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x70201233	unregister_jprobe
++EXPORT_SYMBOL_GPL vmlinux 0x703189d7	regulator_get_mode
++EXPORT_SYMBOL_GPL vmlinux 0x703a38a8	key_type_logon
++EXPORT_SYMBOL_GPL vmlinux 0x704c9717	rio_set_port_lockout
++EXPORT_SYMBOL_GPL vmlinux 0x70516e45	dm_suspended
++EXPORT_SYMBOL_GPL vmlinux 0x70528c2b	irq_domain_associate
++EXPORT_SYMBOL_GPL vmlinux 0x707ff1bb	ata_xfer_mask2mode
++EXPORT_SYMBOL_GPL vmlinux 0x70825112	srcu_barrier
++EXPORT_SYMBOL_GPL vmlinux 0x70958478	skb_gro_receive
++EXPORT_SYMBOL_GPL vmlinux 0x70a38362	ata_pci_device_do_resume
++EXPORT_SYMBOL_GPL vmlinux 0x70bb651d	__tracepoint_block_rq_remap
++EXPORT_SYMBOL_GPL vmlinux 0x70cf032f	usb_hcd_irq
++EXPORT_SYMBOL_GPL vmlinux 0x70d58999	serial8250_modem_status
++EXPORT_SYMBOL_GPL vmlinux 0x70d71a76	ping_unhash
++EXPORT_SYMBOL_GPL vmlinux 0x70f1dae1	blkcg_root
++EXPORT_SYMBOL_GPL vmlinux 0x710c73b6	crypto_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x710d3f79	balloon_mapping_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x71203365	regulator_disable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x71277cba	debugfs_print_regs32
++EXPORT_SYMBOL_GPL vmlinux 0x713b0781	pci_dev_run_wake
++EXPORT_SYMBOL_GPL vmlinux 0x716265c7	debugfs_initialized
++EXPORT_SYMBOL_GPL vmlinux 0x716e4b9e	usb_hc_died
++EXPORT_SYMBOL_GPL vmlinux 0x71a2f90c	devm_regmap_field_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x71a83a01	__module_address
++EXPORT_SYMBOL_GPL vmlinux 0x71aa9889	stmpe_set_altfunc
++EXPORT_SYMBOL_GPL vmlinux 0x71b2f9dc	ip6_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x71d5b9a5	fib_rules_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x71dc9998	crypto_il_tab
++EXPORT_SYMBOL_GPL vmlinux 0x721d6ed8	stmpe_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0x724953a8	ip6_push_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0x7267db00	hwrng_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x72695242	spi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x72741f25	trace_vbprintk
++EXPORT_SYMBOL_GPL vmlinux 0x7278d328	all_vm_events
++EXPORT_SYMBOL_GPL vmlinux 0x72a9b93f	register_mce_write_callback
++EXPORT_SYMBOL_GPL vmlinux 0x72b212ff	regulator_bulk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x72c09f38	stmpe_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0x72e954b0	adp5520_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x73013896	xenbus_printf
++EXPORT_SYMBOL_GPL vmlinux 0x73056d81	regulator_get_linear_step
++EXPORT_SYMBOL_GPL vmlinux 0x731dba7a	xen_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0x73387703	usb_get_from_anchor
++EXPORT_SYMBOL_GPL vmlinux 0x735b1cd6	btree_grim_visitor
++EXPORT_SYMBOL_GPL vmlinux 0x7368dfc4	user_describe
++EXPORT_SYMBOL_GPL vmlinux 0x738b363a	mmc_send_ext_csd
++EXPORT_SYMBOL_GPL vmlinux 0x738fd248	intel_msic_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0x739c8603	ata_sas_port_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x73a3e9be	dev_get_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x73a48b4a	ata_sff_std_ports
++EXPORT_SYMBOL_GPL vmlinux 0x73d69364	ring_buffer_change_overwrite
++EXPORT_SYMBOL_GPL vmlinux 0x73e037d8	skcipher_geniv_free
++EXPORT_SYMBOL_GPL vmlinux 0x74006323	cgroup_taskset_next
++EXPORT_SYMBOL_GPL vmlinux 0x7402c697	sdio_writew
++EXPORT_SYMBOL_GPL vmlinux 0x743129be	ata_sff_exec_command
++EXPORT_SYMBOL_GPL vmlinux 0x743a165e	ata_pack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0x74457e56	apei_resources_fini
++EXPORT_SYMBOL_GPL vmlinux 0x744a279b	devm_regmap_init_spi
++EXPORT_SYMBOL_GPL vmlinux 0x7452adff	user_return_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0x74597033	device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x7464ea38	dev_pm_qos_add_global_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x748c0e7c	security_inode_create
++EXPORT_SYMBOL_GPL vmlinux 0x748d801a	pcap_adc_sync
++EXPORT_SYMBOL_GPL vmlinux 0x7493e10b	da9052_free_irq
++EXPORT_SYMBOL_GPL vmlinux 0x74954462	timecounter_read
++EXPORT_SYMBOL_GPL vmlinux 0x74baf17a	tracing_is_on
++EXPORT_SYMBOL_GPL vmlinux 0x74c08941	kvm_async_pf_task_wake
++EXPORT_SYMBOL_GPL vmlinux 0x74d9fac3	flush_kthread_work
++EXPORT_SYMBOL_GPL vmlinux 0x74deb10c	used_vectors
++EXPORT_SYMBOL_GPL vmlinux 0x74dff0d2	inet6_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x750e6d65	user_match
++EXPORT_SYMBOL_GPL vmlinux 0x7517c47a	debugfs_rename
++EXPORT_SYMBOL_GPL vmlinux 0x7521afb6	leave_mm
++EXPORT_SYMBOL_GPL vmlinux 0x7522f3ba	irq_modify_status
++EXPORT_SYMBOL_GPL vmlinux 0x753d2586	ping_seq_fops
++EXPORT_SYMBOL_GPL vmlinux 0x7545e5fb	shash_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0x7549b728	rio_get_comptag
++EXPORT_SYMBOL_GPL vmlinux 0x7561b7bd	__mmu_notifier_invalidate_range_end
++EXPORT_SYMBOL_GPL vmlinux 0x756e0a15	usb_anchor_urb
++EXPORT_SYMBOL_GPL vmlinux 0x757c1799	ata_bmdma_start
++EXPORT_SYMBOL_GPL vmlinux 0x757eab8f	spi_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x758a782e	blk_fill_rwbs
++EXPORT_SYMBOL_GPL vmlinux 0x75c2b9f1	memalloc_socks
++EXPORT_SYMBOL_GPL vmlinux 0x75c8a11c	inet_twdr_twkill_work
++EXPORT_SYMBOL_GPL vmlinux 0x75d4af9b	sk_clear_memalloc
++EXPORT_SYMBOL_GPL vmlinux 0x75f7de59	xenbus_dev_changed
++EXPORT_SYMBOL_GPL vmlinux 0x765e1a4f	power_supply_set_battery_charged
++EXPORT_SYMBOL_GPL vmlinux 0x7681946c	unregister_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x7688280c	crypto_larval_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7696ab3f	inet_csk_listen_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7698dc69	md_new_event
++EXPORT_SYMBOL_GPL vmlinux 0x76b61b46	trace_event_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x76fa6c79	sata_std_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0x770cf981	tpm_send
++EXPORT_SYMBOL_GPL vmlinux 0x7712771a	unbind_from_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x77214cea	sprint_OID
++EXPORT_SYMBOL_GPL vmlinux 0x7729cbdd	task_handoff_register
++EXPORT_SYMBOL_GPL vmlinux 0x775a6ef5	kvm_read_and_reset_pf_reason
++EXPORT_SYMBOL_GPL vmlinux 0x7761c378	fsstack_copy_attr_all
++EXPORT_SYMBOL_GPL vmlinux 0x7790adc0	aout_dump_debugregs
++EXPORT_SYMBOL_GPL vmlinux 0x77b4d581	rtc_update_irq
++EXPORT_SYMBOL_GPL vmlinux 0x77b5793e	crypto_alloc_base
++EXPORT_SYMBOL_GPL vmlinux 0x77e65040	spi_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x77e78218	regulator_allow_bypass
++EXPORT_SYMBOL_GPL vmlinux 0x781c6eca	hrtimer_init
++EXPORT_SYMBOL_GPL vmlinux 0x782ad0b0	thermal_zone_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x782adb74	hpet_rtc_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0x78586a56	bus_find_device_by_name
++EXPORT_SYMBOL_GPL vmlinux 0x785b4956	rio_route_clr_table
++EXPORT_SYMBOL_GPL vmlinux 0x789a54fc	xenbus_bind_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x78b05081	ata_cable_sata
++EXPORT_SYMBOL_GPL vmlinux 0x78e73665	unregister_ftrace_function
++EXPORT_SYMBOL_GPL vmlinux 0x78fc2f01	lp8788_update_bits
++EXPORT_SYMBOL_GPL vmlinux 0x793cb3d1	crypto_alloc_aead
++EXPORT_SYMBOL_GPL vmlinux 0x793f0aca	pci_disable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x7944e0fc	tracing_off
++EXPORT_SYMBOL_GPL vmlinux 0x7946801c	uprobe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x794816b1	usb_submit_urb
++EXPORT_SYMBOL_GPL vmlinux 0x7965c3df	rtc_set_alarm
++EXPORT_SYMBOL_GPL vmlinux 0x796c2d48	dm_get_md
++EXPORT_SYMBOL_GPL vmlinux 0x79763252	trace_buffer_unlock_commit_regs
++EXPORT_SYMBOL_GPL vmlinux 0x7983c4b0	nf_unregister_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0x7991fd8d	crash_vmclear_loaded_vmcss
++EXPORT_SYMBOL_GPL vmlinux 0x79990927	ata_ehi_clear_desc
++EXPORT_SYMBOL_GPL vmlinux 0x799eaf51	page_cache_sync_readahead
++EXPORT_SYMBOL_GPL vmlinux 0x79a0c429	fuse_direct_io
++EXPORT_SYMBOL_GPL vmlinux 0x79a71c48	kernel_stack_pointer
++EXPORT_SYMBOL_GPL vmlinux 0x79acf39e	xenbus_map_ring
++EXPORT_SYMBOL_GPL vmlinux 0x79b7e208	xenbus_dev_is_online
++EXPORT_SYMBOL_GPL vmlinux 0x79c4f3c9	__pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0x79cc1f2e	mmc_regulator_set_ocr
++EXPORT_SYMBOL_GPL vmlinux 0x79d77a97	devres_release
++EXPORT_SYMBOL_GPL vmlinux 0x79e274a4	shash_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0x79e69460	intel_iommu_gfx_mapped
++EXPORT_SYMBOL_GPL vmlinux 0x79f783dd	ipv4_sk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x79f8d708	tpm_open
++EXPORT_SYMBOL_GPL vmlinux 0x79fb95d2	dev_attr_link_power_management_policy
++EXPORT_SYMBOL_GPL vmlinux 0x7a19403c	blkg_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x7a2e4b44	ezx_pcap_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0x7a3bcfea	ata_sas_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0x7a4c1438	pv_info
++EXPORT_SYMBOL_GPL vmlinux 0x7a6172cd	crypto_givcipher_type
++EXPORT_SYMBOL_GPL vmlinux 0x7a6502b8	gpiochip_is_requested
++EXPORT_SYMBOL_GPL vmlinux 0x7a6d7008	hvc_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7a6e0b61	vma_kernel_pagesize
++EXPORT_SYMBOL_GPL vmlinux 0x7a76cc84	ip6_sk_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0x7a8674c9	devres_release_group
++EXPORT_SYMBOL_GPL vmlinux 0x7a86d2f0	ata_bmdma_irq_clear
++EXPORT_SYMBOL_GPL vmlinux 0x7a933c98	clk_enable
++EXPORT_SYMBOL_GPL vmlinux 0x7a944007	rcu_idle_enter
++EXPORT_SYMBOL_GPL vmlinux 0x7aae2504	irq_set_default_host
++EXPORT_SYMBOL_GPL vmlinux 0x7ab3ca18	eventfd_ctx_read
++EXPORT_SYMBOL_GPL vmlinux 0x7ac77a51	hvc_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x7ac8e5b0	acpi_gsi_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7acc418e	efivar_entry_remove
++EXPORT_SYMBOL_GPL vmlinux 0x7ad1ba26	bus_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0x7ae1ae8e	cpufreq_frequency_table_put_attr
++EXPORT_SYMBOL_GPL vmlinux 0x7b02e834	perf_event_create_kernel_counter
++EXPORT_SYMBOL_GPL vmlinux 0x7b0a1ad6	pm_generic_suspend_noirq
++EXPORT_SYMBOL_GPL vmlinux 0x7b0f1ab3	ring_buffer_free_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b1d544d	edac_handler_set
++EXPORT_SYMBOL_GPL vmlinux 0x7b1e074f	uhci_check_and_reset_hc
++EXPORT_SYMBOL_GPL vmlinux 0x7b2e03c1	devm_regmap_field_free
++EXPORT_SYMBOL_GPL vmlinux 0x7b494c55	usb_autopm_put_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0x7b68c3df	sysfs_remove_file_from_group
++EXPORT_SYMBOL_GPL vmlinux 0x7b7fbfdd	xen_swiotlb_map_page
++EXPORT_SYMBOL_GPL vmlinux 0x7b90d1a9	bind_virq_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x7bcb48d1	pci_hp_remove_module_link
++EXPORT_SYMBOL_GPL vmlinux 0x7bce6a84	ata_bmdma_stop
++EXPORT_SYMBOL_GPL vmlinux 0x7bddeb19	pm_generic_freeze
++EXPORT_SYMBOL_GPL vmlinux 0x7bed4a35	__dma_request_channel
++EXPORT_SYMBOL_GPL vmlinux 0x7bff4171	unregister_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7c2274c1	raw_seq_start
++EXPORT_SYMBOL_GPL vmlinux 0x7c303840	dio_end_io
++EXPORT_SYMBOL_GPL vmlinux 0x7c3a8825	spi_unregister_master
++EXPORT_SYMBOL_GPL vmlinux 0x7c966d1c	agp_remove_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x7c991352	sdio_writel
++EXPORT_SYMBOL_GPL vmlinux 0x7cc1b7fd	max77693_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x7cc5d3b7	device_release_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cd6f042	cpufreq_get_current_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7cea5d06	usb_register_device_driver
++EXPORT_SYMBOL_GPL vmlinux 0x7ceaf0d5	generic_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0x7d4444fe	sdio_get_host_pm_caps
++EXPORT_SYMBOL_GPL vmlinux 0x7d44b25b	regmap_async_complete_cb
++EXPORT_SYMBOL_GPL vmlinux 0x7d59dd46	pm_wq
++EXPORT_SYMBOL_GPL vmlinux 0x7dab26b6	wm831x_isinkv_values
++EXPORT_SYMBOL_GPL vmlinux 0x7dac9b08	inet_csk_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0x7dadae0c	register_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x7e2d6023	usb_free_streams
++EXPORT_SYMBOL_GPL vmlinux 0x7e54c331	rt_mutex_lock
++EXPORT_SYMBOL_GPL vmlinux 0x7e64181d	usb_calc_bus_time
++EXPORT_SYMBOL_GPL vmlinux 0x7e9093fb	uart_set_options
++EXPORT_SYMBOL_GPL vmlinux 0x7eadc111	sysfs_add_file_to_group
++EXPORT_SYMBOL_GPL vmlinux 0x7eb898ed	platform_device_del
++EXPORT_SYMBOL_GPL vmlinux 0x7ec22f9a	apei_estatus_check
++EXPORT_SYMBOL_GPL vmlinux 0x7ecdb9e9	attribute_container_classdev_to_container
++EXPORT_SYMBOL_GPL vmlinux 0x7ee226e5	spi_new_device
++EXPORT_SYMBOL_GPL vmlinux 0x7ef00721	sata_scr_write
++EXPORT_SYMBOL_GPL vmlinux 0x7f1022e7	split_page
++EXPORT_SYMBOL_GPL vmlinux 0x7f15a841	dma_buf_attach
++EXPORT_SYMBOL_GPL vmlinux 0x7f2271ed	devres_close_group
++EXPORT_SYMBOL_GPL vmlinux 0x7f60eef4	acpi_dev_pm_add_dependent
++EXPORT_SYMBOL_GPL vmlinux 0x7f7c840d	get_kernel_pages
++EXPORT_SYMBOL_GPL vmlinux 0x7f8287a2	mmc_regulator_get_supply
++EXPORT_SYMBOL_GPL vmlinux 0x7f86d4b1	fpu_finit
++EXPORT_SYMBOL_GPL vmlinux 0x7fa4a2fd	regmap_field_write
++EXPORT_SYMBOL_GPL vmlinux 0x7fac9787	blkg_conf_prep
++EXPORT_SYMBOL_GPL vmlinux 0x7fb94686	i2c_probe_func_quick_read
++EXPORT_SYMBOL_GPL vmlinux 0x7fe6b6cb	key_set_timeout
++EXPORT_SYMBOL_GPL vmlinux 0x7ffc8718	gpio_set_debounce
++EXPORT_SYMBOL_GPL vmlinux 0x800808d5	wm8997_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8017b7a1	ata_cable_80wire
++EXPORT_SYMBOL_GPL vmlinux 0x803fd0c1	usb_unlink_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x805992d4	sdio_set_host_pm_flags
++EXPORT_SYMBOL_GPL vmlinux 0x806f9b87	__blk_end_request_err
++EXPORT_SYMBOL_GPL vmlinux 0x808a274a	debugfs_create_u32
++EXPORT_SYMBOL_GPL vmlinux 0x808a52af	of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0x808ec1a3	crypto_alg_tested
++EXPORT_SYMBOL_GPL vmlinux 0x80abce7d	stmpe_block_write
++EXPORT_SYMBOL_GPL vmlinux 0x80d5e57a	mpi_free
++EXPORT_SYMBOL_GPL vmlinux 0x80f3268f	__trace_printk
++EXPORT_SYMBOL_GPL vmlinux 0x80f7974f	debugfs_create_x16
++EXPORT_SYMBOL_GPL vmlinux 0x80ffeda3	wm8350_gpio_config
++EXPORT_SYMBOL_GPL vmlinux 0x811dc334	usb_unregister_notify
++EXPORT_SYMBOL_GPL vmlinux 0x8149ea54	ata_timing_find_mode
++EXPORT_SYMBOL_GPL vmlinux 0x81987948	md_rdev_init
++EXPORT_SYMBOL_GPL vmlinux 0x819c43f1	tty_port_link_device
++EXPORT_SYMBOL_GPL vmlinux 0x81a4155b	max8997_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x81b413e0	led_trigger_set_default
++EXPORT_SYMBOL_GPL vmlinux 0x81e4d30c	hrtimer_cancel
++EXPORT_SYMBOL_GPL vmlinux 0x81ffaee1	mddev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x8203af88	ohci_restart
++EXPORT_SYMBOL_GPL vmlinux 0x82149ea6	usb_get_intf
++EXPORT_SYMBOL_GPL vmlinux 0x8226642f	__gpio_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x82561294	scsi_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0x826dded4	rio_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x8278e20d	crypto_unregister_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0x82939ebd	rcu_batches_completed_sched
++EXPORT_SYMBOL_GPL vmlinux 0x82bf1d70	__clocksource_updatefreq_scale
++EXPORT_SYMBOL_GPL vmlinux 0x82d79b51	sysctl_vfs_cache_pressure
++EXPORT_SYMBOL_GPL vmlinux 0x82dbec19	erst_write
++EXPORT_SYMBOL_GPL vmlinux 0x82f89884	wakeup_source_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x82fda110	tpm_show_pubek
++EXPORT_SYMBOL_GPL vmlinux 0x832512b8	pcie_update_link_speed
++EXPORT_SYMBOL_GPL vmlinux 0x832bf2c6	__sock_recv_ts_and_drops
++EXPORT_SYMBOL_GPL vmlinux 0x833732fe	usb_autopm_get_interface_no_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8376c9af	da903x_write
++EXPORT_SYMBOL_GPL vmlinux 0x8384e07b	key_type_trusted
++EXPORT_SYMBOL_GPL vmlinux 0x838b13e7	ring_buffer_free
++EXPORT_SYMBOL_GPL vmlinux 0x83a5ae2e	__tracepoint_rpm_resume
++EXPORT_SYMBOL_GPL vmlinux 0x83c98026	wm8350_block_read
++EXPORT_SYMBOL_GPL vmlinux 0x83d8c479	attribute_container_find_class_device
++EXPORT_SYMBOL_GPL vmlinux 0x83eaca88	power_supply_powers
++EXPORT_SYMBOL_GPL vmlinux 0x83ef0ec0	ipv4_redirect
++EXPORT_SYMBOL_GPL vmlinux 0x8407a3fe	da903x_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x84169c88	pwm_request
++EXPORT_SYMBOL_GPL vmlinux 0x843d70ef	acpi_is_root_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x844e0f4d	fuse_get_req_for_background
++EXPORT_SYMBOL_GPL vmlinux 0x8456f58f	flush_kthread_worker
++EXPORT_SYMBOL_GPL vmlinux 0x84796acb	regmap_can_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0x849f0ee1	__irq_domain_add
++EXPORT_SYMBOL_GPL vmlinux 0x84c0f4f8	ata_dev_next
++EXPORT_SYMBOL_GPL vmlinux 0x84c4adb3	sysfs_chmod_file
++EXPORT_SYMBOL_GPL vmlinux 0x85050965	__irq_alloc_descs
++EXPORT_SYMBOL_GPL vmlinux 0x850be8a1	ata_eh_freeze_port
++EXPORT_SYMBOL_GPL vmlinux 0x85216155	ezx_pcap_read
++EXPORT_SYMBOL_GPL vmlinux 0x852cdf00	sysfs_unmerge_group
++EXPORT_SYMBOL_GPL vmlinux 0x85478a0b	inet6_hash_frag
++EXPORT_SYMBOL_GPL vmlinux 0x854ff3a9	tty_port_register_device_attr
++EXPORT_SYMBOL_GPL vmlinux 0x85526eef	usb_show_dynids
++EXPORT_SYMBOL_GPL vmlinux 0x856629e7	__tracepoint_rpm_return_int
++EXPORT_SYMBOL_GPL vmlinux 0x8574ca6c	gpio_request_array
++EXPORT_SYMBOL_GPL vmlinux 0x8576dfda	hrtimer_get_remaining
++EXPORT_SYMBOL_GPL vmlinux 0x8590c745	__mnt_is_readonly
++EXPORT_SYMBOL_GPL vmlinux 0x859b8f4d	crypto_spawn_tfm2
++EXPORT_SYMBOL_GPL vmlinux 0x85c10896	rcu_batches_completed_bh
++EXPORT_SYMBOL_GPL vmlinux 0x85c7f674	ring_buffer_normalize_time_stamp
++EXPORT_SYMBOL_GPL vmlinux 0x85d7edfd	hpet_set_periodic_freq
++EXPORT_SYMBOL_GPL vmlinux 0x85edeca0	dma_buf_vunmap
++EXPORT_SYMBOL_GPL vmlinux 0x8611f167	__rio_local_read_config_32
++EXPORT_SYMBOL_GPL vmlinux 0x861adbf4	irq_alloc_domain_generic_chips
++EXPORT_SYMBOL_GPL vmlinux 0x862cc635	raw_seq_open
++EXPORT_SYMBOL_GPL vmlinux 0x862e35ae	tpm_show_caps_1_2
++EXPORT_SYMBOL_GPL vmlinux 0x862f98a3	xen_create_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0x86623fd7	notify_remote_via_irq
++EXPORT_SYMBOL_GPL vmlinux 0x86685d78	ftrace_event_reg
++EXPORT_SYMBOL_GPL vmlinux 0x8682b7dc	acpi_get_pci_dev
++EXPORT_SYMBOL_GPL vmlinux 0x868784cb	__symbol_get
++EXPORT_SYMBOL_GPL vmlinux 0x86992a9b	ata_sff_irq_on
++EXPORT_SYMBOL_GPL vmlinux 0x86a51007	gnttab_end_foreign_transfer
++EXPORT_SYMBOL_GPL vmlinux 0x86aa16e6	klist_iter_init
++EXPORT_SYMBOL_GPL vmlinux 0x86e1a9ed	relay_file_operations
++EXPORT_SYMBOL_GPL vmlinux 0x86f6b99d	synchronize_rcu_expedited
++EXPORT_SYMBOL_GPL vmlinux 0x86f8c910	pcap_set_ts_bits
++EXPORT_SYMBOL_GPL vmlinux 0x86fd60b5	usb_add_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x8704cf27	rio_request_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0x870e16b7	xen_test_irq_shared
++EXPORT_SYMBOL_GPL vmlinux 0x871b1174	init_dummy_netdev
++EXPORT_SYMBOL_GPL vmlinux 0x872f0705	usb_disable_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x873fbaea	edac_atomic_assert_error
++EXPORT_SYMBOL_GPL vmlinux 0x874d8513	regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0x8753247e	usb_hub_clear_tt_buffer
++EXPORT_SYMBOL_GPL vmlinux 0x875fdd38	led_trigger_remove
++EXPORT_SYMBOL_GPL vmlinux 0x8775ac98	ata_bmdma_port_start32
++EXPORT_SYMBOL_GPL vmlinux 0x8778382a	power_supply_am_i_supplied
++EXPORT_SYMBOL_GPL vmlinux 0x87984b16	__tracepoint_cpu_idle
++EXPORT_SYMBOL_GPL vmlinux 0x87a7f9dc	arizona_dev_init
++EXPORT_SYMBOL_GPL vmlinux 0x87bbce1d	ehci_handshake
++EXPORT_SYMBOL_GPL vmlinux 0x87bfd6f3	driver_find_device
++EXPORT_SYMBOL_GPL vmlinux 0x87c61465	hvc_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x87d4343a	__fsnotify_parent
++EXPORT_SYMBOL_GPL vmlinux 0x87dfa56a	tty_port_tty_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0x87f1fbd0	pci_set_pcie_reset_state
++EXPORT_SYMBOL_GPL vmlinux 0x8810ad5e	crypto_xor
++EXPORT_SYMBOL_GPL vmlinux 0x882882fe	driver_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0x88289a85	css_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x8831f8b1	kmap_atomic_pfn
++EXPORT_SYMBOL_GPL vmlinux 0x887dd76c	use_mm
++EXPORT_SYMBOL_GPL vmlinux 0x889fcaf2	unregister_kretprobes
++EXPORT_SYMBOL_GPL vmlinux 0x88a511d0	cpufreq_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x88ab6fe3	kgdb_active
++EXPORT_SYMBOL_GPL vmlinux 0x88b0844e	btree_init_mempool
++EXPORT_SYMBOL_GPL vmlinux 0x88b5647c	trace_clock_local
++EXPORT_SYMBOL_GPL vmlinux 0x88b9d484	inet_hash_connect
++EXPORT_SYMBOL_GPL vmlinux 0x88d6dff1	clk_get_parent
++EXPORT_SYMBOL_GPL vmlinux 0x88f9a8cc	dm_disk
++EXPORT_SYMBOL_GPL vmlinux 0x891a5a7f	gnttab_max_grant_frames
++EXPORT_SYMBOL_GPL vmlinux 0x8924eb1e	rcu_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0x89485687	iommu_group_put
++EXPORT_SYMBOL_GPL vmlinux 0x89502f0c	gnttab_subpage_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0x8956aeae	apei_exec_ctx_init
++EXPORT_SYMBOL_GPL vmlinux 0x89737214	pci_add_dynid
++EXPORT_SYMBOL_GPL vmlinux 0x898aa97a	register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0x89a282d7	ata_sff_busy_sleep
++EXPORT_SYMBOL_GPL vmlinux 0x89af23b4	max8997_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0x89b16f63	scsi_target_unblock
++EXPORT_SYMBOL_GPL vmlinux 0x89bbafc6	usb_register_notify
++EXPORT_SYMBOL_GPL vmlinux 0x89e686c9	driver_create_file
++EXPORT_SYMBOL_GPL vmlinux 0x8a04b9fe	tracepoint_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0x8a141af5	regcache_cache_only
++EXPORT_SYMBOL_GPL vmlinux 0x8a462ef0	device_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x8a50538c	ata_bmdma_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0x8a5c7a80	regulator_enable
++EXPORT_SYMBOL_GPL vmlinux 0x8a6fa828	spi_master_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8a78989f	irq_from_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0x8a7cb9c4	platform_thermal_package_rate_control
++EXPORT_SYMBOL_GPL vmlinux 0x8a8660aa	spi_bus_lock
++EXPORT_SYMBOL_GPL vmlinux 0x8abacc47	get_max_files
++EXPORT_SYMBOL_GPL vmlinux 0x8acd6091	key_type_asymmetric
++EXPORT_SYMBOL_GPL vmlinux 0x8b04668e	bind_interdomain_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0x8b66f9e0	xen_platform_pci_unplug
++EXPORT_SYMBOL_GPL vmlinux 0x8b752ac1	ata_tf_to_fis
++EXPORT_SYMBOL_GPL vmlinux 0x8bb47560	crypto_default_rng
++EXPORT_SYMBOL_GPL vmlinux 0x8bb475e5	ata_bmdma_setup
++EXPORT_SYMBOL_GPL vmlinux 0x8bcb6500	__inet_twsk_hashdance
++EXPORT_SYMBOL_GPL vmlinux 0x8beff54c	bus_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8c03d20c	destroy_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0x8c06a108	xenbus_transaction_start
++EXPORT_SYMBOL_GPL vmlinux 0x8c3419a6	ata_base_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0x8c488ae8	wm5110_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8c4b7d55	__efivar_entry_iter
++EXPORT_SYMBOL_GPL vmlinux 0x8c4db1b5	usb_kill_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x8c5e7907	md_run
++EXPORT_SYMBOL_GPL vmlinux 0x8c874957	ata_pci_device_resume
++EXPORT_SYMBOL_GPL vmlinux 0x8cc4646a	efivar_entry_find
++EXPORT_SYMBOL_GPL vmlinux 0x8cd74837	da903x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0x8cd9f935	setup_APIC_eilvt
++EXPORT_SYMBOL_GPL vmlinux 0x8cddc133	br_fdb_test_addr_hook
++EXPORT_SYMBOL_GPL vmlinux 0x8d09d37b	extcon_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bb58	iommu_group_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8d22bc2e	pci_intx_mask_supported
++EXPORT_SYMBOL_GPL vmlinux 0x8d950772	pci_configure_slot
++EXPORT_SYMBOL_GPL vmlinux 0x8db4712a	sdio_claim_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8dcf4de3	acpi_dev_pm_attach
++EXPORT_SYMBOL_GPL vmlinux 0x8df043af	iommu_domain_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x8e050d6b	wm8997_patch
++EXPORT_SYMBOL_GPL vmlinux 0x8e170a9f	remove_irq
++EXPORT_SYMBOL_GPL vmlinux 0x8e584b27	irq_find_mapping
++EXPORT_SYMBOL_GPL vmlinux 0x8e6ba3c8	ahash_attr_alg
++EXPORT_SYMBOL_GPL vmlinux 0x8e8b3971	rio_release_dma
++EXPORT_SYMBOL_GPL vmlinux 0x8e9414ef	crypto_hash_walk_first
++EXPORT_SYMBOL_GPL vmlinux 0x8ea960cb	blocking_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x8eac1381	rio_mport_send_doorbell
++EXPORT_SYMBOL_GPL vmlinux 0x8ed04cfb	led_trigger_event
++EXPORT_SYMBOL_GPL vmlinux 0x8ed6a532	rio_register_scan
++EXPORT_SYMBOL_GPL vmlinux 0x8edfb574	injectm
++EXPORT_SYMBOL_GPL vmlinux 0x8effebd3	pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0x8f6cee77	__round_jiffies_relative
++EXPORT_SYMBOL_GPL vmlinux 0x8f87ecdf	sata_scr_read
++EXPORT_SYMBOL_GPL vmlinux 0x8f93bf52	crypto_unregister_algs
++EXPORT_SYMBOL_GPL vmlinux 0x8f9b169a	tcp_register_congestion_control
++EXPORT_SYMBOL_GPL vmlinux 0x8fa77abf	free_css_id
++EXPORT_SYMBOL_GPL vmlinux 0x8fb576b8	usb_scuttle_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0x8fd134a5	inet_putpeer
++EXPORT_SYMBOL_GPL vmlinux 0x8fda855b	crypto_unregister_shash
++EXPORT_SYMBOL_GPL vmlinux 0x9009602a	acpi_bus_get_ejd
++EXPORT_SYMBOL_GPL vmlinux 0x90150178	tcp_twsk_unique
++EXPORT_SYMBOL_GPL vmlinux 0x902410ca	dma_buf_vmap
++EXPORT_SYMBOL_GPL vmlinux 0x9050103d	virtqueue_add_inbuf
++EXPORT_SYMBOL_GPL vmlinux 0x9053c05f	simple_attr_release
++EXPORT_SYMBOL_GPL vmlinux 0x9062c322	ring_buffer_consume
++EXPORT_SYMBOL_GPL vmlinux 0x90663e1d	sis_info133_for_sata
++EXPORT_SYMBOL_GPL vmlinux 0x90705b7f	syscon_node_to_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x90986c89	netdev_rx_handler_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x90991d6a	perf_event_release_kernel
++EXPORT_SYMBOL_GPL vmlinux 0x90a1004a	crypto_has_alg
++EXPORT_SYMBOL_GPL vmlinux 0x90bb1817	raw_unhash_sk
++EXPORT_SYMBOL_GPL vmlinux 0x90c84a29	pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0x90de0452	platform_thermal_package_notify
++EXPORT_SYMBOL_GPL vmlinux 0x90e9bf3a	put_device
++EXPORT_SYMBOL_GPL vmlinux 0x90f85092	blkcipher_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0x910c1e6a	rio_enable_rx_tx_port
++EXPORT_SYMBOL_GPL vmlinux 0x9111b005	platform_bus
++EXPORT_SYMBOL_GPL vmlinux 0x91131ece	dm_set_target_max_io_len
++EXPORT_SYMBOL_GPL vmlinux 0x911d85e4	tcp_peer_is_proven
++EXPORT_SYMBOL_GPL vmlinux 0x915e285d	pci_user_write_config_word
++EXPORT_SYMBOL_GPL vmlinux 0x918ad429	ring_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0x918d2243	blk_add_driver_data
++EXPORT_SYMBOL_GPL vmlinux 0x91adc546	crypto_init_spawn2
++EXPORT_SYMBOL_GPL vmlinux 0x91b5ba50	iptunnel_pull_header
++EXPORT_SYMBOL_GPL vmlinux 0x91be78e7	blk_queue_rq_timed_out
++EXPORT_SYMBOL_GPL vmlinux 0x91c6e5b0	pcap_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0x91d8bc6b	sysfs_remove_link
++EXPORT_SYMBOL_GPL vmlinux 0x91e09d0d	__pm_runtime_use_autosuspend
++EXPORT_SYMBOL_GPL vmlinux 0x92221838	vga_default_device
++EXPORT_SYMBOL_GPL vmlinux 0x922a99c5	md_is_badblock
++EXPORT_SYMBOL_GPL vmlinux 0x924c46f8	zs_unmap_object
++EXPORT_SYMBOL_GPL vmlinux 0x926530d7	fib_table_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9278ac02	ehci_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x927e74bf	xenbus_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0x929c0965	user_instantiate
++EXPORT_SYMBOL_GPL vmlinux 0x929c467f	btree_get_prev
++EXPORT_SYMBOL_GPL vmlinux 0x92b49de8	__pneigh_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x92b57248	flush_work
++EXPORT_SYMBOL_GPL vmlinux 0x92d31cfb	fixed_phy_add
++EXPORT_SYMBOL_GPL vmlinux 0x92eb3685	pid_nr_ns
++EXPORT_SYMBOL_GPL vmlinux 0x92f160a9	skb_cow_data
++EXPORT_SYMBOL_GPL vmlinux 0x9310908b	extcon_dev_register
++EXPORT_SYMBOL_GPL vmlinux 0x9312d80e	evtchn_put
++EXPORT_SYMBOL_GPL vmlinux 0x9324e78e	acpi_dev_resource_memory
++EXPORT_SYMBOL_GPL vmlinux 0x934b196f	sysfs_notify
++EXPORT_SYMBOL_GPL vmlinux 0x937b2b3a	pci_enable_ats
++EXPORT_SYMBOL_GPL vmlinux 0x9395ad8c	da903x_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x93b27864	iommu_domain_free
++EXPORT_SYMBOL_GPL vmlinux 0x93c67c2d	crypto_mod_get
++EXPORT_SYMBOL_GPL vmlinux 0x93d2422d	snmp_mib_free
++EXPORT_SYMBOL_GPL vmlinux 0x93fbd005	__cpufreq_driver_getavg
++EXPORT_SYMBOL_GPL vmlinux 0x94081587	tty_set_termios
++EXPORT_SYMBOL_GPL vmlinux 0x941f2aaa	eventfd_ctx_put
++EXPORT_SYMBOL_GPL vmlinux 0x943fc708	xen_setup_shutdown_event
++EXPORT_SYMBOL_GPL vmlinux 0x94904fbf	crypto_alloc_instance2
++EXPORT_SYMBOL_GPL vmlinux 0x949f709d	device_pm_wait_for_dev
++EXPORT_SYMBOL_GPL vmlinux 0x94a68723	ata_scsi_slave_destroy
++EXPORT_SYMBOL_GPL vmlinux 0x94abb745	sprint_oid
++EXPORT_SYMBOL_GPL vmlinux 0x94c318be	apei_exec_collect_resources
++EXPORT_SYMBOL_GPL vmlinux 0x94c49beb	irq_domain_xlate_twocell
++EXPORT_SYMBOL_GPL vmlinux 0x94d42570	irq_set_chip_and_handler_name
++EXPORT_SYMBOL_GPL vmlinux 0x94e86070	vfs_setlease
++EXPORT_SYMBOL_GPL vmlinux 0x94ef4d05	cpci_hp_stop
++EXPORT_SYMBOL_GPL vmlinux 0x951436d5	crypto_register_ahash
++EXPORT_SYMBOL_GPL vmlinux 0x952664c5	do_exit
++EXPORT_SYMBOL_GPL vmlinux 0x955b0e2e	kthread_worker_fn
++EXPORT_SYMBOL_GPL vmlinux 0x956a91ba	gpio_get_value_cansleep
++EXPORT_SYMBOL_GPL vmlinux 0x958df3ac	zs_free
++EXPORT_SYMBOL_GPL vmlinux 0x95bc9078	btree_free
++EXPORT_SYMBOL_GPL vmlinux 0x95cb878e	xenbus_dev_probe
++EXPORT_SYMBOL_GPL vmlinux 0x95cefdab	dma_buf_unmap_attachment
++EXPORT_SYMBOL_GPL vmlinux 0x95d11a64	__root_device_register
++EXPORT_SYMBOL_GPL vmlinux 0x9607ebfe	pci_find_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0x961ddef8	tcp_reno_cong_avoid
++EXPORT_SYMBOL_GPL vmlinux 0x961e4910	vfs_lock_file
++EXPORT_SYMBOL_GPL vmlinux 0x9621849f	ring_buffer_event_data
++EXPORT_SYMBOL_GPL vmlinux 0x962a4125	thermal_cooling_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x963b7b96	fuse_put_request
++EXPORT_SYMBOL_GPL vmlinux 0x964add15	xenbus_scanf
++EXPORT_SYMBOL_GPL vmlinux 0x96554810	register_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x96a22790	vmcore_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0x96b2b616	tpm_bios_log_setup
++EXPORT_SYMBOL_GPL vmlinux 0x96d2d176	device_del
++EXPORT_SYMBOL_GPL vmlinux 0x96de7df9	debugfs_create_regset32
++EXPORT_SYMBOL_GPL vmlinux 0x96ec0e2c	cpufreq_freq_attr_scaling_available_freqs
++EXPORT_SYMBOL_GPL vmlinux 0x96f10cfb	pci_bus_add_device
++EXPORT_SYMBOL_GPL vmlinux 0x976b1092	fuse_sync_release
++EXPORT_SYMBOL_GPL vmlinux 0x977c9667	pwm_free
++EXPORT_SYMBOL_GPL vmlinux 0x97813baf	regcache_sync_region
++EXPORT_SYMBOL_GPL vmlinux 0x97a3ec56	ata_sff_queue_delayed_work
++EXPORT_SYMBOL_GPL vmlinux 0x97b093dd	btree_update
++EXPORT_SYMBOL_GPL vmlinux 0x97b8cbd9	usb_acpi_set_power_state
++EXPORT_SYMBOL_GPL vmlinux 0x97de2b83	debug_locks_silent
++EXPORT_SYMBOL_GPL vmlinux 0x97fac849	vring_transport_features
++EXPORT_SYMBOL_GPL vmlinux 0x981b1e03	single_release_net
++EXPORT_SYMBOL_GPL vmlinux 0x9833bc0c	hvc_kick
++EXPORT_SYMBOL_GPL vmlinux 0x983c6ba4	usb_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x98503a63	mpi_alloc
++EXPORT_SYMBOL_GPL vmlinux 0x9879932b	crypto_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x98896a09	wm831x_device_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0x98a545a8	rio_mport_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0x98cc564a	regulator_set_voltage
++EXPORT_SYMBOL_GPL vmlinux 0x98d9e571	usb_ep0_reinit
++EXPORT_SYMBOL_GPL vmlinux 0x98fbab57	show_class_attr_string
++EXPORT_SYMBOL_GPL vmlinux 0x98ff762c	xenbus_match
++EXPORT_SYMBOL_GPL vmlinux 0x9924c496	__usb_get_extra_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0x995d1071	prof_on
++EXPORT_SYMBOL_GPL vmlinux 0x99965954	srcu_init_notifier_head
++EXPORT_SYMBOL_GPL vmlinux 0x99bdfc5d	dma_buf_detach
++EXPORT_SYMBOL_GPL vmlinux 0x99c0f352	gnttab_unmap_refs
++EXPORT_SYMBOL_GPL vmlinux 0x99da3363	input_ff_erase
++EXPORT_SYMBOL_GPL vmlinux 0x99df7a91	unregister_wide_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x9a11a0fc	crypto_attr_alg_name
++EXPORT_SYMBOL_GPL vmlinux 0x9a2c56be	tty_port_install
++EXPORT_SYMBOL_GPL vmlinux 0x9a5da420	usb_hcd_poll_rh_status
++EXPORT_SYMBOL_GPL vmlinux 0x9a60ff73	blk_add_request_payload
++EXPORT_SYMBOL_GPL vmlinux 0x9a627a11	dpm_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9a89dbf7	lpddr2_jedec_min_tck
++EXPORT_SYMBOL_GPL vmlinux 0x9a8e8e99	pstore_register
++EXPORT_SYMBOL_GPL vmlinux 0x9a95242e	da9055_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0x9a9824ef	btree_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9aab0c09	kallsyms_on_each_symbol
++EXPORT_SYMBOL_GPL vmlinux 0x9ab303df	i2c_unlock_adapter
++EXPORT_SYMBOL_GPL vmlinux 0x9ac11b74	suspend_set_ops
++EXPORT_SYMBOL_GPL vmlinux 0x9aca444b	get_monotonic_boottime
++EXPORT_SYMBOL_GPL vmlinux 0x9ad8d263	pci_enable_pri
++EXPORT_SYMBOL_GPL vmlinux 0x9aeacb87	ring_buffer_iter_empty
++EXPORT_SYMBOL_GPL vmlinux 0x9b0f2b8e	__fib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9b279511	unregister_acpi_bus_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9b35a147	devm_usb_get_phy_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9b3ef580	device_set_wakeup_capable
++EXPORT_SYMBOL_GPL vmlinux 0x9b49bc4b	cpufreq_get_measured_perf
++EXPORT_SYMBOL_GPL vmlinux 0x9b6b24aa	exportfs_encode_fh
++EXPORT_SYMBOL_GPL vmlinux 0x9b6f0fc6	wm831x_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0x9b8d9503	hv_register_vmbus_handler
++EXPORT_SYMBOL_GPL vmlinux 0x9b9f3648	pcibios_scan_specific_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9babf390	wakeup_source_create
++EXPORT_SYMBOL_GPL vmlinux 0x9bbb0ae8	pci_sriov_set_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0x9bbdd282	__cpufreq_driver_target
++EXPORT_SYMBOL_GPL vmlinux 0x9bd1e6ad	usb_hcd_giveback_urb
++EXPORT_SYMBOL_GPL vmlinux 0x9bd72b78	apei_write
++EXPORT_SYMBOL_GPL vmlinux 0x9bdaf092	cgroup_rightmost_descendant
++EXPORT_SYMBOL_GPL vmlinux 0x9be1d3cd	__module_text_address
++EXPORT_SYMBOL_GPL vmlinux 0x9be704ee	acpi_match_device
++EXPORT_SYMBOL_GPL vmlinux 0x9bece81b	mpi_cmp_ui
++EXPORT_SYMBOL_GPL vmlinux 0x9c122243	mnt_clone_write
++EXPORT_SYMBOL_GPL vmlinux 0x9c2e4b66	acpi_unregister_gsi
++EXPORT_SYMBOL_GPL vmlinux 0x9c771364	tpm_read
++EXPORT_SYMBOL_GPL vmlinux 0x9c860aa2	usb_autopm_get_interface
++EXPORT_SYMBOL_GPL vmlinux 0x9c8e6d39	__udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0x9c9af7c8	regmap_irq_get_domain
++EXPORT_SYMBOL_GPL vmlinux 0x9cbcf69d	cpci_hp_unregister_controller
++EXPORT_SYMBOL_GPL vmlinux 0x9cc4f70a	register_pm_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9cd0184d	init_srcu_struct
++EXPORT_SYMBOL_GPL vmlinux 0x9cec5694	pm_generic_suspend
++EXPORT_SYMBOL_GPL vmlinux 0x9ced55a3	regmap_get_val_bytes
++EXPORT_SYMBOL_GPL vmlinux 0x9cf6d0d6	ata_platform_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0x9d030b99	stop_machine
++EXPORT_SYMBOL_GPL vmlinux 0x9d06688b	register_xenbus_watch
++EXPORT_SYMBOL_GPL vmlinux 0x9d0ca2a4	btree_merge
++EXPORT_SYMBOL_GPL vmlinux 0x9d1fd0f3	pci_disable_pasid
++EXPORT_SYMBOL_GPL vmlinux 0x9d2fa99c	crypto_rng_type
++EXPORT_SYMBOL_GPL vmlinux 0x9d3850e1	gnttab_alloc_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0x9d452106	dev_pm_qos_add_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9d62c898	unregister_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0x9d8331c0	ring_buffer_read_page
++EXPORT_SYMBOL_GPL vmlinux 0x9d87ccba	sdio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0x9d884449	sg_scsi_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0x9d8b1bac	regulator_enable_regmap
++EXPORT_SYMBOL_GPL vmlinux 0x9d8f9bb6	mnt_drop_write
++EXPORT_SYMBOL_GPL vmlinux 0x9dba0dd3	task_cgroup_path
++EXPORT_SYMBOL_GPL vmlinux 0x9dc2f202	rio_release_inb_dbell
++EXPORT_SYMBOL_GPL vmlinux 0x9dcfaf53	perf_trace_buf_prepare
++EXPORT_SYMBOL_GPL vmlinux 0x9df77a94	ping_close
++EXPORT_SYMBOL_GPL vmlinux 0x9dfdf722	gpio_free_array
++EXPORT_SYMBOL_GPL vmlinux 0x9e22d71c	pm_generic_suspend_late
++EXPORT_SYMBOL_GPL vmlinux 0x9e4b6c6a	unregister_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0x9e6de090	rtc_irq_register
++EXPORT_SYMBOL_GPL vmlinux 0x9e83aa68	fat_free_clusters
++EXPORT_SYMBOL_GPL vmlinux 0x9e95983e	event_storage_mutex
++EXPORT_SYMBOL_GPL vmlinux 0x9eb536f1	debugfs_create_u32_array
++EXPORT_SYMBOL_GPL vmlinux 0x9ebe4a33	blkg_conf_finish
++EXPORT_SYMBOL_GPL vmlinux 0x9ebff902	start_thread
++EXPORT_SYMBOL_GPL vmlinux 0x9ec9139e	rtc_class_open
++EXPORT_SYMBOL_GPL vmlinux 0x9ec93b3e	__put_task_struct
++EXPORT_SYMBOL_GPL vmlinux 0x9ed554b3	unregister_keyboard_notifier
++EXPORT_SYMBOL_GPL vmlinux 0x9ef3dea5	iommu_group_for_each_dev
++EXPORT_SYMBOL_GPL vmlinux 0x9f0664bf	dm_get_queue_limits
++EXPORT_SYMBOL_GPL vmlinux 0x9f26aa65	pci_hp_add_bridge
++EXPORT_SYMBOL_GPL vmlinux 0x9f587ace	inet6_csk_xmit
++EXPORT_SYMBOL_GPL vmlinux 0x9f5fe3c9	class_interface_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9f750692	ping_queue_rcv_skb
++EXPORT_SYMBOL_GPL vmlinux 0x9f93fe36	yield_to
++EXPORT_SYMBOL_GPL vmlinux 0x9fb427a9	cpci_hp_unregister_bus
++EXPORT_SYMBOL_GPL vmlinux 0x9fce80db	fb_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0x9fe18f22	platform_driver_unregister
++EXPORT_SYMBOL_GPL vmlinux 0x9fe939e1	mpi_powm
++EXPORT_SYMBOL_GPL vmlinux 0x9ffafca4	devm_clk_register
++EXPORT_SYMBOL_GPL vmlinux 0x9fffcebd	hvc_poll
++EXPORT_SYMBOL_GPL vmlinux 0xa00d359a	ip6_flush_pending_frames
++EXPORT_SYMBOL_GPL vmlinux 0xa0206376	irq_setup_alt_chip
++EXPORT_SYMBOL_GPL vmlinux 0xa0208e02	irq_set_affinity_hint
++EXPORT_SYMBOL_GPL vmlinux 0xa0311466	usb_autopm_get_interface_async
++EXPORT_SYMBOL_GPL vmlinux 0xa04d70ca	fsstack_copy_inode_size
++EXPORT_SYMBOL_GPL vmlinux 0xa0619a60	xfrm_local_error
++EXPORT_SYMBOL_GPL vmlinux 0xa0829c2f	usb_add_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xa0831caa	apply_to_page_range
++EXPORT_SYMBOL_GPL vmlinux 0xa0993f0a	usb_ifnum_to_if
++EXPORT_SYMBOL_GPL vmlinux 0xa09f82ce	usb_clear_halt
++EXPORT_SYMBOL_GPL vmlinux 0xa0c71dac	spi_populate_sync_msg
++EXPORT_SYMBOL_GPL vmlinux 0xa0de5a07	ata_port_wait_eh
++EXPORT_SYMBOL_GPL vmlinux 0xa0e15817	xenbus_dev_error
++EXPORT_SYMBOL_GPL vmlinux 0xa0f54941	usb_autopm_put_interface
++EXPORT_SYMBOL_GPL vmlinux 0xa0ff6bf8	sec_reg_update
++EXPORT_SYMBOL_GPL vmlinux 0xa11216be	xen_store_domain_type
++EXPORT_SYMBOL_GPL vmlinux 0xa12903d9	get_device
++EXPORT_SYMBOL_GPL vmlinux 0xa147d5df	blk_queue_bio
++EXPORT_SYMBOL_GPL vmlinux 0xa14ed592	fat_sync_inode
++EXPORT_SYMBOL_GPL vmlinux 0xa156a1f2	erst_get_record_id_end
++EXPORT_SYMBOL_GPL vmlinux 0xa177db8c	devres_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xa1b81dde	iommu_domain_get_attr
++EXPORT_SYMBOL_GPL vmlinux 0xa1bd7822	__tracepoint_block_bio_complete
++EXPORT_SYMBOL_GPL vmlinux 0xa1dbac7f	ata_host_detach
++EXPORT_SYMBOL_GPL vmlinux 0xa1f04093	tty_get_pgrp
++EXPORT_SYMBOL_GPL vmlinux 0xa2045898	tpm_get_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xa20d2119	max8997_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa26d9b4f	workqueue_congested
++EXPORT_SYMBOL_GPL vmlinux 0xa28b198d	file_ra_state_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2ad1265	wm8994_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xa2b019cf	trace_event_raw_init
++EXPORT_SYMBOL_GPL vmlinux 0xa2be00e9	regmap_bulk_read
++EXPORT_SYMBOL_GPL vmlinux 0xa2c46da9	vfs_kern_mount
++EXPORT_SYMBOL_GPL vmlinux 0xa2e67f08	acpi_bus_generate_proc_event4
++EXPORT_SYMBOL_GPL vmlinux 0xa302a776	rio_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xa3231d1b	debugfs_create_u64
++EXPORT_SYMBOL_GPL vmlinux 0xa353fffc	xenbus_rm
++EXPORT_SYMBOL_GPL vmlinux 0xa35de213	ping_seq_next
++EXPORT_SYMBOL_GPL vmlinux 0xa3684af3	crypto_shash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xa38602cd	drain_workqueue
++EXPORT_SYMBOL_GPL vmlinux 0xa389a49a	profile_event_register
++EXPORT_SYMBOL_GPL vmlinux 0xa3a04602	btree_geo64
++EXPORT_SYMBOL_GPL vmlinux 0xa3bac75c	regcache_drop_region
++EXPORT_SYMBOL_GPL vmlinux 0xa3dd88b9	rio_dev_get
++EXPORT_SYMBOL_GPL vmlinux 0xa3e7c113	ring_buffer_iter_peek
++EXPORT_SYMBOL_GPL vmlinux 0xa3fead0a	tcp_reno_min_cwnd
++EXPORT_SYMBOL_GPL vmlinux 0xa402b790	pci_scan_child_bus
++EXPORT_SYMBOL_GPL vmlinux 0xa406f6b3	pwm_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa452c297	hpet_mask_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa452f2a4	xen_pirq_from_irq
++EXPORT_SYMBOL_GPL vmlinux 0xa466de38	acpi_processor_ffh_cstate_enter
++EXPORT_SYMBOL_GPL vmlinux 0xa468c104	edac_get_sysfs_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xa47046a6	ip6_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xa48196c8	kdb_poll_idx
++EXPORT_SYMBOL_GPL vmlinux 0xa49f99eb	register_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xa4d58669	math_state_restore
++EXPORT_SYMBOL_GPL vmlinux 0xa50b0a56	xfrm_audit_state_add
++EXPORT_SYMBOL_GPL vmlinux 0xa50d5ae1	unuse_mm
++EXPORT_SYMBOL_GPL vmlinux 0xa50d8bdf	invalidate_inode_pages2_range
++EXPORT_SYMBOL_GPL vmlinux 0xa53bc248	da9052_adc_manual_read
++EXPORT_SYMBOL_GPL vmlinux 0xa54364c4	acpi_dma_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xa549523b	skb_segment
++EXPORT_SYMBOL_GPL vmlinux 0xa54dbdd7	irq_generic_chip_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa588c54c	dev_attr_em_message
++EXPORT_SYMBOL_GPL vmlinux 0xa5efbf4c	async_synchronize_full
++EXPORT_SYMBOL_GPL vmlinux 0xa603740f	crypto_lookup_template
++EXPORT_SYMBOL_GPL vmlinux 0xa61b1477	tracepoint_iter_start
++EXPORT_SYMBOL_GPL vmlinux 0xa625110d	kmsg_dump_rewind
++EXPORT_SYMBOL_GPL vmlinux 0xa62892c6	efivar_sysfs_list
++EXPORT_SYMBOL_GPL vmlinux 0xa6a04d29	sysfs_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xa6a0a273	max77693_write_reg
++EXPORT_SYMBOL_GPL vmlinux 0xa6b21ef2	dpm_suspend_end
++EXPORT_SYMBOL_GPL vmlinux 0xa6bce056	ping_recvmsg
++EXPORT_SYMBOL_GPL vmlinux 0xa6d13cf1	i2c_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xa6d52eaf	aead_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xa6da6666	device_reset
++EXPORT_SYMBOL_GPL vmlinux 0xa6e1a69d	kick_all_cpus_sync
++EXPORT_SYMBOL_GPL vmlinux 0xa6fbea45	xen_xenbus_fops
++EXPORT_SYMBOL_GPL vmlinux 0xa724257f	init_uts_ns
++EXPORT_SYMBOL_GPL vmlinux 0xa7471953	sysfs_put
++EXPORT_SYMBOL_GPL vmlinux 0xa75312bc	call_rcu_sched
++EXPORT_SYMBOL_GPL vmlinux 0xa75c32b2	clk_register
++EXPORT_SYMBOL_GPL vmlinux 0xa75c9974	iommu_detach_group
++EXPORT_SYMBOL_GPL vmlinux 0xa75e419c	usb_hcd_start_port_resume
++EXPORT_SYMBOL_GPL vmlinux 0xa76a9176	sk_setup_caps
++EXPORT_SYMBOL_GPL vmlinux 0xa790ca8d	wm5102_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xa7aae053	mm_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xa7b1ebb4	arizona_clk32k_enable
++EXPORT_SYMBOL_GPL vmlinux 0xa7cadadf	fat_search_long
++EXPORT_SYMBOL_GPL vmlinux 0xa7ccbbe6	ata_bmdma_post_internal_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xa7e20df3	clk_mux_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa7f92105	add_uevent_var
++EXPORT_SYMBOL_GPL vmlinux 0xa801b359	efivar_entry_iter_begin
++EXPORT_SYMBOL_GPL vmlinux 0xa8079233	usb_hcd_pci_probe
++EXPORT_SYMBOL_GPL vmlinux 0xa8294115	spi_setup
++EXPORT_SYMBOL_GPL vmlinux 0xa851973a	raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xa85b49c0	posix_timers_register_clock
++EXPORT_SYMBOL_GPL vmlinux 0xa8618ab5	add_page_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xa87de165	balloon_devinfo_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xa8a157b5	regulator_map_voltage_ascend
++EXPORT_SYMBOL_GPL vmlinux 0xa8ac4e5e	register_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xa8b82a53	xen_destroy_contiguous_region
++EXPORT_SYMBOL_GPL vmlinux 0xa8c015e8	inet6_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xa8e77071	ata_sff_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xa8ee6041	da903x_update
++EXPORT_SYMBOL_GPL vmlinux 0xa8f59416	gpio_direction_output
++EXPORT_SYMBOL_GPL vmlinux 0xa8f85471	perf_tp_event
++EXPORT_SYMBOL_GPL vmlinux 0xa9126bff	hpet_set_rtc_irq_bit
++EXPORT_SYMBOL_GPL vmlinux 0xa9397708	crypto_mod_put
++EXPORT_SYMBOL_GPL vmlinux 0xa96116ca	pci_disable_pri
++EXPORT_SYMBOL_GPL vmlinux 0xa96f804b	uart_handle_cts_change
++EXPORT_SYMBOL_GPL vmlinux 0xa9773cd8	pingv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa9a82042	gnttab_trans_grants_available
++EXPORT_SYMBOL_GPL vmlinux 0xa9b26a68	netlink_remove_tap
++EXPORT_SYMBOL_GPL vmlinux 0xa9bfd9a9	xenbus_alloc_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xa9c5b522	acpi_dma_request_slave_chan_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xa9d2f669	__rio_local_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xa9d427de	usb_hcd_pci_pm_ops
++EXPORT_SYMBOL_GPL vmlinux 0xa9e18049	task_handoff_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xa9fc3f54	gnttab_grant_foreign_access_trans
++EXPORT_SYMBOL_GPL vmlinux 0xaa29010d	__scsi_get_command
++EXPORT_SYMBOL_GPL vmlinux 0xaa2a72bf	__iowrite64_copy
++EXPORT_SYMBOL_GPL vmlinux 0xaa308ec7	da903x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xaa9ebfa9	rtnl_link_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xaaa918c9	ftrace_dump
++EXPORT_SYMBOL_GPL vmlinux 0xaab763fc	acpi_processor_get_performance_info
++EXPORT_SYMBOL_GPL vmlinux 0xaadc8b87	tpm_store_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xab01acbe	gnttab_request_free_callback
++EXPORT_SYMBOL_GPL vmlinux 0xab27466c	inet_csk_reqsk_queue_prune
++EXPORT_SYMBOL_GPL vmlinux 0xab5b34cb	crypto_shash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xab6babaf	pm_qos_request
++EXPORT_SYMBOL_GPL vmlinux 0xab788a03	ata_sff_qc_fill_rtf
++EXPORT_SYMBOL_GPL vmlinux 0xab865975	bmp085_regmap_config
++EXPORT_SYMBOL_GPL vmlinux 0xaba29ce3	crypto_alloc_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xabd69a15	tty_port_tty_hangup
++EXPORT_SYMBOL_GPL vmlinux 0xac0182d7	usb_remove_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xac0afad7	x86_hyper_kvm
++EXPORT_SYMBOL_GPL vmlinux 0xac13ffe9	inet_csk_route_req
++EXPORT_SYMBOL_GPL vmlinux 0xac7d4843	securityfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xac9ce195	kvm_async_pf_task_wait
++EXPORT_SYMBOL_GPL vmlinux 0xaca10f58	regmap_reinit_cache
++EXPORT_SYMBOL_GPL vmlinux 0xacafa8e7	vector_used_by_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xace5c0fc	usb_bus_list
++EXPORT_SYMBOL_GPL vmlinux 0xace662db	virtqueue_disable_cb
++EXPORT_SYMBOL_GPL vmlinux 0xad3da672	securityfs_remove
++EXPORT_SYMBOL_GPL vmlinux 0xad5a6715	clk_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xad8d8ab0	xen_physdev_op_compat
++EXPORT_SYMBOL_GPL vmlinux 0xada38534	regulator_bulk_disable
++EXPORT_SYMBOL_GPL vmlinux 0xadab691b	led_trigger_show
++EXPORT_SYMBOL_GPL vmlinux 0xadc785ec	kgdb_register_io_module
++EXPORT_SYMBOL_GPL vmlinux 0xadebf144	i2c_new_device
++EXPORT_SYMBOL_GPL vmlinux 0xadf6aa4d	tpm_pcr_read
++EXPORT_SYMBOL_GPL vmlinux 0xae011b03	bus_rescan_devices
++EXPORT_SYMBOL_GPL vmlinux 0xae0f6b4e	regulator_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xae1f8947	driver_attach
++EXPORT_SYMBOL_GPL vmlinux 0xae51de8d	crypto_alg_mod_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xae69b1c1	usermodehelper_read_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xae6eaf93	hwpoison_filter_dev_minor
++EXPORT_SYMBOL_GPL vmlinux 0xae7c231d	mpi_cmp
++EXPORT_SYMBOL_GPL vmlinux 0xae7c5411	ms_hyperv
++EXPORT_SYMBOL_GPL vmlinux 0xae83fe16	regulator_get_voltage_sel_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xaeacb52e	inet_csk_search_req
++EXPORT_SYMBOL_GPL vmlinux 0xaed6450a	iommu_iova_to_phys
++EXPORT_SYMBOL_GPL vmlinux 0xaeefcb75	eventfd_fget
++EXPORT_SYMBOL_GPL vmlinux 0xaefa856c	watchdog_unregister_device
++EXPORT_SYMBOL_GPL vmlinux 0xaf245e60	ohci_setup
++EXPORT_SYMBOL_GPL vmlinux 0xaf61f485	usb_hcd_pci_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xafa2b7b9	leds_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xafbd6199	sdio_release_host
++EXPORT_SYMBOL_GPL vmlinux 0xafce98ba	isa_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb0045e6c	pwm_set_polarity
++EXPORT_SYMBOL_GPL vmlinux 0xb028b3b1	i2c_add_numbered_adapter
++EXPORT_SYMBOL_GPL vmlinux 0xb02ac411	register_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb09120a1	crypto_shash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xb097b086	get_task_pid
++EXPORT_SYMBOL_GPL vmlinux 0xb09d5640	__sock_recv_timestamp
++EXPORT_SYMBOL_GPL vmlinux 0xb0a741f4	devm_kfree
++EXPORT_SYMBOL_GPL vmlinux 0xb0b85f47	ring_buffer_iter_reset
++EXPORT_SYMBOL_GPL vmlinux 0xb10d55bc	cn_netlink_send
++EXPORT_SYMBOL_GPL vmlinux 0xb11eb1f0	alloc_page_buffers
++EXPORT_SYMBOL_GPL vmlinux 0xb140d14c	ring_buffer_read
++EXPORT_SYMBOL_GPL vmlinux 0xb1425b32	dm_table_add_target_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb1551bae	clockevents_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xb172ffac	efivars_sysfs_init
++EXPORT_SYMBOL_GPL vmlinux 0xb1831ea5	scsi_register_acpi_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xb18429eb	suspend_device_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xb1a40cea	cgroup_unload_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xb1acbcce	rcu_barrier_sched
++EXPORT_SYMBOL_GPL vmlinux 0xb1b8cdb4	inverse_translate
++EXPORT_SYMBOL_GPL vmlinux 0xb1bed25d	dpm_resume_start
++EXPORT_SYMBOL_GPL vmlinux 0xb1c0c1c2	async_schedule_domain
++EXPORT_SYMBOL_GPL vmlinux 0xb1e09f82	dev_attr_em_message_type
++EXPORT_SYMBOL_GPL vmlinux 0xb1e25684	__trace_bputs
++EXPORT_SYMBOL_GPL vmlinux 0xb1e28c8c	acpi_pci_check_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xb1ebf760	tpm_show_pcrs
++EXPORT_SYMBOL_GPL vmlinux 0xb1f91e78	sysfs_get_dirent
++EXPORT_SYMBOL_GPL vmlinux 0xb2210d64	reset_control_deassert
++EXPORT_SYMBOL_GPL vmlinux 0xb22d956a	usb_free_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xb23409da	bus_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xb2467c26	rio_release_outb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xb24c2e04	acpi_dev_pm_detach
++EXPORT_SYMBOL_GPL vmlinux 0xb2523503	sched_setscheduler
++EXPORT_SYMBOL_GPL vmlinux 0xb2699792	ata_sff_data_xfer_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xb26a1b8b	acpi_subsys_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xb2760f1b	__sock_recv_wifi_status
++EXPORT_SYMBOL_GPL vmlinux 0xb2927536	virtqueue_enable_cb_delayed
++EXPORT_SYMBOL_GPL vmlinux 0xb29d4da7	iommu_group_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xb2c22377	xfrm_audit_state_icvfail
++EXPORT_SYMBOL_GPL vmlinux 0xb2e764e8	suspend_valid_only_mem
++EXPORT_SYMBOL_GPL vmlinux 0xb2f9a77b	ata_sas_sync_probe
++EXPORT_SYMBOL_GPL vmlinux 0xb30c88b0	ip_route_output_flow
++EXPORT_SYMBOL_GPL vmlinux 0xb3163599	ipv6_find_tlv
++EXPORT_SYMBOL_GPL vmlinux 0xb3253ed9	hpet_rtc_timer_init
++EXPORT_SYMBOL_GPL vmlinux 0xb3326ecf	usb_autopm_put_interface_no_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb3366d8e	spi_async
++EXPORT_SYMBOL_GPL vmlinux 0xb350f190	clk_set_parent
++EXPORT_SYMBOL_GPL vmlinux 0xb37d8a48	tpm_show_caps
++EXPORT_SYMBOL_GPL vmlinux 0xb39276e6	dm_requeue_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0xb3b16953	blk_trace_setup
++EXPORT_SYMBOL_GPL vmlinux 0xb3cf84e1	blk_unprep_request
++EXPORT_SYMBOL_GPL vmlinux 0xb3fda5ce	rio_register_driver
++EXPORT_SYMBOL_GPL vmlinux 0xb3fdbe42	crypto_find_alg
++EXPORT_SYMBOL_GPL vmlinux 0xb4267f64	__pm_runtime_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xb43b8239	dm_underlying_device_busy
++EXPORT_SYMBOL_GPL vmlinux 0xb44887c3	efivars_kobject
++EXPORT_SYMBOL_GPL vmlinux 0xb4498066	ata_slave_link_init
++EXPORT_SYMBOL_GPL vmlinux 0xb44effdb	sk_attach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xb467b133	usb_find_alt_setting
++EXPORT_SYMBOL_GPL vmlinux 0xb47d2c12	tty_mode_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb484721f	tpm_register_hardware
++EXPORT_SYMBOL_GPL vmlinux 0xb4b97c90	pvclock_gtod_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb4e14553	gnttab_query_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb4ea7cf7	kgdb_connected
++EXPORT_SYMBOL_GPL vmlinux 0xb519dd55	inet_peer_base_init
++EXPORT_SYMBOL_GPL vmlinux 0xb51fbd64	edac_op_state
++EXPORT_SYMBOL_GPL vmlinux 0xb53620d1	pci_vpd_find_info_keyword
++EXPORT_SYMBOL_GPL vmlinux 0xb55dc460	ping_proc_register
++EXPORT_SYMBOL_GPL vmlinux 0xb57345f7	spi_bus_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xb58dcfa2	synchronize_sched_expedited
++EXPORT_SYMBOL_GPL vmlinux 0xb5a0e11e	lpddr2_jedec_addressing_table
++EXPORT_SYMBOL_GPL vmlinux 0xb5c78e34	platform_device_add_data
++EXPORT_SYMBOL_GPL vmlinux 0xb5c81488	need_load_eval
++EXPORT_SYMBOL_GPL vmlinux 0xb5cb8145	hrtimer_get_res
++EXPORT_SYMBOL_GPL vmlinux 0xb5e896fb	tpm_get_random
++EXPORT_SYMBOL_GPL vmlinux 0xb5f17edf	perf_register_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xb6164a85	smpboot_unregister_percpu_thread
++EXPORT_SYMBOL_GPL vmlinux 0xb616f157	__blkdev_driver_ioctl
++EXPORT_SYMBOL_GPL vmlinux 0xb6212caa	alarm_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xb6230f1f	gnttab_grant_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xb6261484	register_die_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xb6382274	rdev_get_drvdata
++EXPORT_SYMBOL_GPL vmlinux 0xb67b2219	cm_suspend_again
++EXPORT_SYMBOL_GPL vmlinux 0xb67c64fd	__tracepoint_kfree_skb
++EXPORT_SYMBOL_GPL vmlinux 0xb6877384	xenbus_unmap_ring
++EXPORT_SYMBOL_GPL vmlinux 0xb6aeb661	ata_id_c_string
++EXPORT_SYMBOL_GPL vmlinux 0xb6bc49a9	__supported_pte_mask
++EXPORT_SYMBOL_GPL vmlinux 0xb6c635af	wm5110_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xb6e6be5e	led_trigger_unregister_simple
++EXPORT_SYMBOL_GPL vmlinux 0xb7044627	pci_find_next_capability
++EXPORT_SYMBOL_GPL vmlinux 0xb709e339	efivar_validate
++EXPORT_SYMBOL_GPL vmlinux 0xb718f2f9	sfi_table_parse
++EXPORT_SYMBOL_GPL vmlinux 0xb71a94c6	dma_get_required_mask
++EXPORT_SYMBOL_GPL vmlinux 0xb7217a15	sock_update_netprioidx
++EXPORT_SYMBOL_GPL vmlinux 0xb729da4d	xenbus_dev_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xb73e244e	ip6_dst_lookup_flow
++EXPORT_SYMBOL_GPL vmlinux 0xb7779e73	idr_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xb77f9e99	thermal_generate_netlink_event
++EXPORT_SYMBOL_GPL vmlinux 0xb78fa9b6	iommu_group_remove_device
++EXPORT_SYMBOL_GPL vmlinux 0xb7a325c3	unregister_asymmetric_key_parser
++EXPORT_SYMBOL_GPL vmlinux 0xb7c5e157	fat_setattr
++EXPORT_SYMBOL_GPL vmlinux 0xb7d7c12e	hpet_set_alarm_time
++EXPORT_SYMBOL_GPL vmlinux 0xb7dda1fd	rio_mport_get_efb
++EXPORT_SYMBOL_GPL vmlinux 0xb7f77027	rtc_tm_to_ktime
++EXPORT_SYMBOL_GPL vmlinux 0xb84dd9b1	crypto_grab_aead
++EXPORT_SYMBOL_GPL vmlinux 0xb86bcceb	klist_next
++EXPORT_SYMBOL_GPL vmlinux 0xb8712b8a	bmp085_probe
++EXPORT_SYMBOL_GPL vmlinux 0xb87991ea	sb800_prefetch
++EXPORT_SYMBOL_GPL vmlinux 0xb892df87	__ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xb8a26d88	sdio_readsb
++EXPORT_SYMBOL_GPL vmlinux 0xb8ab8ca8	rtnl_register
++EXPORT_SYMBOL_GPL vmlinux 0xb8b2b1f7	mce_register_decode_chain
++EXPORT_SYMBOL_GPL vmlinux 0xb8f21983	console_drivers
++EXPORT_SYMBOL_GPL vmlinux 0xb9024c63	clockevents_config_and_register
++EXPORT_SYMBOL_GPL vmlinux 0xb903674c	scatterwalk_map_and_copy
++EXPORT_SYMBOL_GPL vmlinux 0xb9176155	asn1_ber_decoder
++EXPORT_SYMBOL_GPL vmlinux 0xb92d09f5	platform_driver_probe
++EXPORT_SYMBOL_GPL vmlinux 0xb950efae	class_dev_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xb9585792	crypto_alloc_instance
++EXPORT_SYMBOL_GPL vmlinux 0xb973f247	irq_domain_add_simple
++EXPORT_SYMBOL_GPL vmlinux 0xb97b26af	ata_sas_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xb989c145	pwm_request_from_chip
++EXPORT_SYMBOL_GPL vmlinux 0xb999f00c	alarm_restart
++EXPORT_SYMBOL_GPL vmlinux 0xb99d5837	xenbus_read
++EXPORT_SYMBOL_GPL vmlinux 0xb9b09973	__efivar_entry_delete
++EXPORT_SYMBOL_GPL vmlinux 0xb9b73034	exportfs_decode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xb9b9df41	usb_amd_dev_put
++EXPORT_SYMBOL_GPL vmlinux 0xb9c425de	register_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xb9d025c9	llist_del_first
++EXPORT_SYMBOL_GPL vmlinux 0xb9da2997	snmp_fold_field64
++EXPORT_SYMBOL_GPL vmlinux 0xb9e5c444	ata_sff_wait_ready
++EXPORT_SYMBOL_GPL vmlinux 0xb9f257a7	regmap_register_patch
++EXPORT_SYMBOL_GPL vmlinux 0xba116bae	disk_part_iter_exit
++EXPORT_SYMBOL_GPL vmlinux 0xba39066d	mmc_app_cmd
++EXPORT_SYMBOL_GPL vmlinux 0xba4dc1e5	crypto_init_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xba561e3e	sdev_evt_send
++EXPORT_SYMBOL_GPL vmlinux 0xbaad5004	devm_remove_action
++EXPORT_SYMBOL_GPL vmlinux 0xbaae71a1	ata_pci_remove_one
++EXPORT_SYMBOL_GPL vmlinux 0xbab7993c	fixed_phy_set_link_update
++EXPORT_SYMBOL_GPL vmlinux 0xbab92236	virtqueue_enable_cb_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xbae5959c	disk_part_iter_next
++EXPORT_SYMBOL_GPL vmlinux 0xbb038ce4	perf_unregister_guest_info_callbacks
++EXPORT_SYMBOL_GPL vmlinux 0xbb0a2666	key_type_encrypted
++EXPORT_SYMBOL_GPL vmlinux 0xbb0ab47b	debug_locks
++EXPORT_SYMBOL_GPL vmlinux 0xbb2380c2	dev_pm_qos_remove_request
++EXPORT_SYMBOL_GPL vmlinux 0xbb2dbf1e	input_ff_event
++EXPORT_SYMBOL_GPL vmlinux 0xbb31b5d4	perf_event_read_value
++EXPORT_SYMBOL_GPL vmlinux 0xbb58b814	iomap_free
++EXPORT_SYMBOL_GPL vmlinux 0xbb6730f3	rio_dma_prep_slave_sg
++EXPORT_SYMBOL_GPL vmlinux 0xbb7c537a	adp5520_read
++EXPORT_SYMBOL_GPL vmlinux 0xbb8311ac	xenbus_read_otherend_details
++EXPORT_SYMBOL_GPL vmlinux 0xbb93b716	regulator_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xbbb16273	sock_diag_register
++EXPORT_SYMBOL_GPL vmlinux 0xbbb98859	edid_info
++EXPORT_SYMBOL_GPL vmlinux 0xbbbdaaa5	dma_buf_kunmap
++EXPORT_SYMBOL_GPL vmlinux 0xbbc265a8	dm_noflush_suspending
++EXPORT_SYMBOL_GPL vmlinux 0xbbc8d896	pcie_bus_configure_settings
++EXPORT_SYMBOL_GPL vmlinux 0xbbd4f657	xen_pcpu_id
++EXPORT_SYMBOL_GPL vmlinux 0xbc61e372	debugfs_create_x8
++EXPORT_SYMBOL_GPL vmlinux 0xbc901958	devm_of_pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xbca0201a	sfi_mrtc_array
++EXPORT_SYMBOL_GPL vmlinux 0xbcac6160	pm_qos_remove_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbcb838a1	amd_flush_garts
++EXPORT_SYMBOL_GPL vmlinux 0xbccf2478	__ablkcipher_walk_complete
++EXPORT_SYMBOL_GPL vmlinux 0xbccfd4d8	register_oldmem_pfn_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xbcd62016	shash_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xbcdd5b99	iommu_group_set_name
++EXPORT_SYMBOL_GPL vmlinux 0xbcf5be47	gpiochip_remove
++EXPORT_SYMBOL_GPL vmlinux 0xbcf6f2b1	extcon_register_interest
++EXPORT_SYMBOL_GPL vmlinux 0xbd36d1be	sdio_writesb
++EXPORT_SYMBOL_GPL vmlinux 0xbd4da8b0	led_trigger_register
++EXPORT_SYMBOL_GPL vmlinux 0xbd506a46	unregister_hotplug_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0xbd5cb8b9	ring_buffer_resize
++EXPORT_SYMBOL_GPL vmlinux 0xbda786e6	usb_deregister_dev
++EXPORT_SYMBOL_GPL vmlinux 0xbdb257ba	hrtimer_start
++EXPORT_SYMBOL_GPL vmlinux 0xbdb773b8	sysfs_remove_group
++EXPORT_SYMBOL_GPL vmlinux 0xbdb960a8	task_user_regset_view
++EXPORT_SYMBOL_GPL vmlinux 0xbdd295f0	trace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xbdd2f42a	rcu_bh_force_quiescent_state
++EXPORT_SYMBOL_GPL vmlinux 0xbdd49223	tps6586x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xbdd5f10f	apei_hest_parse
++EXPORT_SYMBOL_GPL vmlinux 0xbddfb08f	__fsnotify_inode_delete
++EXPORT_SYMBOL_GPL vmlinux 0xbdfb276e	clockevent_delta2ns
++EXPORT_SYMBOL_GPL vmlinux 0xbe1887e4	ata_unpack_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xbe1efefe	anon_inode_getfile
++EXPORT_SYMBOL_GPL vmlinux 0xbe21f6a2	fat_add_entries
++EXPORT_SYMBOL_GPL vmlinux 0xbe420b99	rtc_irq_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbe72cb02	ata_eh_qc_retry
++EXPORT_SYMBOL_GPL vmlinux 0xbe86465f	i2c_adapter_type
++EXPORT_SYMBOL_GPL vmlinux 0xbe90583b	crypto_register_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xbe98086e	clk_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xbf041102	register_vt_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xbf0dd46c	tpm_show_durations
++EXPORT_SYMBOL_GPL vmlinux 0xbf15334d	dev_pm_qos_update_request
++EXPORT_SYMBOL_GPL vmlinux 0xbf21953e	crypto_unregister_template
++EXPORT_SYMBOL_GPL vmlinux 0xbf3293d4	dma_buf_get
++EXPORT_SYMBOL_GPL vmlinux 0xbf6f39d5	d_materialise_unique
++EXPORT_SYMBOL_GPL vmlinux 0xbf719c21	platform_device_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xbfbc5434	pciserial_resume_ports
++EXPORT_SYMBOL_GPL vmlinux 0xbfc60796	kobject_uevent_env
++EXPORT_SYMBOL_GPL vmlinux 0xbfef8032	wm8350_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xbffcb3b7	acpi_os_get_iomem
++EXPORT_SYMBOL_GPL vmlinux 0xc00131cf	visitor64
++EXPORT_SYMBOL_GPL vmlinux 0xc019d4d3	extcon_register_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc0607625	ata_bmdma32_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc06133e3	input_ff_upload
++EXPORT_SYMBOL_GPL vmlinux 0xc08647ff	ring_buffer_bytes_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc0a6123d	xenbus_watch_pathfmt
++EXPORT_SYMBOL_GPL vmlinux 0xc0bed677	dm_kill_unmapped_request
++EXPORT_SYMBOL_GPL vmlinux 0xc0bf6ead	timecounter_cyc2time
++EXPORT_SYMBOL_GPL vmlinux 0xc0cc7fd6	reset_controller_register
++EXPORT_SYMBOL_GPL vmlinux 0xc0d26387	kmsg_dump_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc0e68cf1	regcache_cache_bypass
++EXPORT_SYMBOL_GPL vmlinux 0xc0e75cec	visitor128
++EXPORT_SYMBOL_GPL vmlinux 0xc0f51949	blkcipher_walk_virt
++EXPORT_SYMBOL_GPL vmlinux 0xc1123d0a	alarm_start_relative
++EXPORT_SYMBOL_GPL vmlinux 0xc11b4470	balloon_stats
++EXPORT_SYMBOL_GPL vmlinux 0xc11bd00f	tracepoint_probe_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xc1260a55	xenbus_probe_node
++EXPORT_SYMBOL_GPL vmlinux 0xc1317707	transport_class_register
++EXPORT_SYMBOL_GPL vmlinux 0xc13ec3b7	rio_request_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xc15c1355	ata_common_sdev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xc160cdfd	tty_find_polling_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc164642e	xenbus_otherend_changed
++EXPORT_SYMBOL_GPL vmlinux 0xc169e819	extcon_get_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xc17515d7	usb_hcds_loaded
++EXPORT_SYMBOL_GPL vmlinux 0xc18578ed	process_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc191d9c2	ping_init_sock
++EXPORT_SYMBOL_GPL vmlinux 0xc195b7c8	devm_regmap_init_i2c
++EXPORT_SYMBOL_GPL vmlinux 0xc1990403	register_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xc1a0df50	sysfs_create_link
++EXPORT_SYMBOL_GPL vmlinux 0xc1dc0d5d	acpi_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xc1ee65d2	usb_set_device_state
++EXPORT_SYMBOL_GPL vmlinux 0xc1fff29e	fuse_request_send_background
++EXPORT_SYMBOL_GPL vmlinux 0xc205fa4e	synchronize_srcu
++EXPORT_SYMBOL_GPL vmlinux 0xc22a3091	vm_unmap_aliases
++EXPORT_SYMBOL_GPL vmlinux 0xc23688eb	pci_user_read_config_dword
++EXPORT_SYMBOL_GPL vmlinux 0xc2416577	crypto_destroy_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xc26351f8	bind_evtchn_to_irq
++EXPORT_SYMBOL_GPL vmlinux 0xc26a136e	tpm_show_timeouts
++EXPORT_SYMBOL_GPL vmlinux 0xc280fb46	kdb_register
++EXPORT_SYMBOL_GPL vmlinux 0xc2935451	rio_release_inb_pwrite
++EXPORT_SYMBOL_GPL vmlinux 0xc295c2a3	inet_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xc2b5f7fb	netlink_alloc_skb
++EXPORT_SYMBOL_GPL vmlinux 0xc2e09c36	ata_bmdma_qc_prep
++EXPORT_SYMBOL_GPL vmlinux 0xc2edd2c5	tpm_show_active
++EXPORT_SYMBOL_GPL vmlinux 0xc2f1ab53	extcon_update_state
++EXPORT_SYMBOL_GPL vmlinux 0xc2f57162	tcp_reno_ssthresh
++EXPORT_SYMBOL_GPL vmlinux 0xc303a81a	inet_csk_bind_conflict
++EXPORT_SYMBOL_GPL vmlinux 0xc31f6c74	xen_swiotlb_dma_supported
++EXPORT_SYMBOL_GPL vmlinux 0xc341ae6d	zs_map_object
++EXPORT_SYMBOL_GPL vmlinux 0xc34efe27	snmp_fold_field
++EXPORT_SYMBOL_GPL vmlinux 0xc37226a5	tpm_pcr_extend
++EXPORT_SYMBOL_GPL vmlinux 0xc3944bf8	wm8350_read_auxadc
++EXPORT_SYMBOL_GPL vmlinux 0xc3a457a0	get_kernel_page
++EXPORT_SYMBOL_GPL vmlinux 0xc3aef871	crypto_hash_walk_done
++EXPORT_SYMBOL_GPL vmlinux 0xc3bb9ac1	sdio_f0_writeb
++EXPORT_SYMBOL_GPL vmlinux 0xc3cf3206	bd_link_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xc3dab2ce	thermal_zone_unbind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xc3e16ca3	pci_check_and_unmask_intx
++EXPORT_SYMBOL_GPL vmlinux 0xc414b1ca	dm_send_uevents
++EXPORT_SYMBOL_GPL vmlinux 0xc4246444	pci_reset_pri
++EXPORT_SYMBOL_GPL vmlinux 0xc428068d	sata_deb_timing_long
++EXPORT_SYMBOL_GPL vmlinux 0xc43e0590	device_store_int
++EXPORT_SYMBOL_GPL vmlinux 0xc45389c4	dev_pm_get_subsys_data
++EXPORT_SYMBOL_GPL vmlinux 0xc45899c9	serial8250_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xc45d79dd	m2p_add_override
++EXPORT_SYMBOL_GPL vmlinux 0xc4656ca1	__page_file_index
++EXPORT_SYMBOL_GPL vmlinux 0xc47485eb	fl6_sock_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xc47a992c	verify_signature
++EXPORT_SYMBOL_GPL vmlinux 0xc48b7ccf	ata_mode_string
++EXPORT_SYMBOL_GPL vmlinux 0xc4c98f48	generic_fh_to_parent
++EXPORT_SYMBOL_GPL vmlinux 0xc5014951	rdev_get_dev
++EXPORT_SYMBOL_GPL vmlinux 0xc5190ab2	regcache_sync
++EXPORT_SYMBOL_GPL vmlinux 0xc521fd39	do_unregister_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xc5365bad	wm831x_auxadc_read_uv
++EXPORT_SYMBOL_GPL vmlinux 0xc5397da6	xenbus_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xc5503ac8	pm_generic_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc55de14e	led_classdev_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xc575c737	debug_locks_off
++EXPORT_SYMBOL_GPL vmlinux 0xc5950546	pci_enable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xc5bab3fe	btree_init
++EXPORT_SYMBOL_GPL vmlinux 0xc5ca9757	sk_detach_filter
++EXPORT_SYMBOL_GPL vmlinux 0xc5d37180	ping_common_sendmsg
++EXPORT_SYMBOL_GPL vmlinux 0xc5f1895b	cpufreq_cpu_get
++EXPORT_SYMBOL_GPL vmlinux 0xc5f6cdad	regulator_map_voltage_iterate
++EXPORT_SYMBOL_GPL vmlinux 0xc60f75ec	__ftrace_vprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc617f82c	unregister_oom_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xc65d3eed	ring_buffer_entries_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc66b77b1	iommu_group_set_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xc6711f44	crypto_chain
++EXPORT_SYMBOL_GPL vmlinux 0xc675f427	pci_reset_function
++EXPORT_SYMBOL_GPL vmlinux 0xc68aa090	mod_delayed_work_on
++EXPORT_SYMBOL_GPL vmlinux 0xc690866c	irq_work_queue
++EXPORT_SYMBOL_GPL vmlinux 0xc69b7ee5	zs_destroy_pool
++EXPORT_SYMBOL_GPL vmlinux 0xc6a28f33	ata_dev_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc6f048a9	each_symbol_section
++EXPORT_SYMBOL_GPL vmlinux 0xc6f898d5	xen_pci_frontend
++EXPORT_SYMBOL_GPL vmlinux 0xc7002ac4	evtchn_make_refcounted
++EXPORT_SYMBOL_GPL vmlinux 0xc70b4f97	cpuidle_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xc72e1233	__trace_bprintk
++EXPORT_SYMBOL_GPL vmlinux 0xc73192b2	acpi_i2c_register_devices
++EXPORT_SYMBOL_GPL vmlinux 0xc736f4e0	pci_set_cacheline_size
++EXPORT_SYMBOL_GPL vmlinux 0xc73c5d03	dev_pm_qos_hide_latency_limit
++EXPORT_SYMBOL_GPL vmlinux 0xc7638f84	lp8788_read_multi_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xc76eed60	do_take_over_console
++EXPORT_SYMBOL_GPL vmlinux 0xc7952023	get_pid_task
++EXPORT_SYMBOL_GPL vmlinux 0xc7a1840e	llist_add_batch
++EXPORT_SYMBOL_GPL vmlinux 0xc7c6391c	mpi_set_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xc7e39bca	ring_buffer_dropped_events_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xc7eb8c66	sata_scr_write_flush
++EXPORT_SYMBOL_GPL vmlinux 0xc835d515	kill_pid_info_as_cred
++EXPORT_SYMBOL_GPL vmlinux 0xc8657357	watchdog_register_device
++EXPORT_SYMBOL_GPL vmlinux 0xc87c1f84	ktime_get
++EXPORT_SYMBOL_GPL vmlinux 0xc87e487a	sched_clock_idle_sleep_event
++EXPORT_SYMBOL_GPL vmlinux 0xc88e09b0	ehci_resume
++EXPORT_SYMBOL_GPL vmlinux 0xc8add232	ring_buffer_record_disable
++EXPORT_SYMBOL_GPL vmlinux 0xc8e0eb6a	crypto_init_ahash_spawn
++EXPORT_SYMBOL_GPL vmlinux 0xc8eb1b8a	pingv6_prot
++EXPORT_SYMBOL_GPL vmlinux 0xc90eee27	bsg_request_fn
++EXPORT_SYMBOL_GPL vmlinux 0xc91277a1	kgdb_schedule_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xc91f48e9	fuse_request_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xc9561772	fb_destroy_modelist
++EXPORT_SYMBOL_GPL vmlinux 0xc95f889b	transport_configure_device
++EXPORT_SYMBOL_GPL vmlinux 0xc975efa4	ata_sas_async_probe
++EXPORT_SYMBOL_GPL vmlinux 0xc97d1140	cpufreq_cooling_get_level
++EXPORT_SYMBOL_GPL vmlinux 0xc98b5639	kick_process
++EXPORT_SYMBOL_GPL vmlinux 0xc996bb17	trace_define_field
++EXPORT_SYMBOL_GPL vmlinux 0xc9bbcc13	pwm_get
++EXPORT_SYMBOL_GPL vmlinux 0xc9c3f176	hpet_register_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xc9e4221b	smp_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc9ec4e21	free_percpu
++EXPORT_SYMBOL_GPL vmlinux 0xc9ecee44	irq_domain_simple_ops
++EXPORT_SYMBOL_GPL vmlinux 0xc9fdb4e8	ata_host_init
++EXPORT_SYMBOL_GPL vmlinux 0xca0aeec9	scsi_internal_device_block
++EXPORT_SYMBOL_GPL vmlinux 0xca11c6fc	ata_bmdma_port_start
++EXPORT_SYMBOL_GPL vmlinux 0xca407995	iommu_domain_window_disable
++EXPORT_SYMBOL_GPL vmlinux 0xca7b4480	simple_attr_open
++EXPORT_SYMBOL_GPL vmlinux 0xca7d8764	kthread_freezable_should_stop
++EXPORT_SYMBOL_GPL vmlinux 0xca81ea9a	xenbus_transaction_end
++EXPORT_SYMBOL_GPL vmlinux 0xca83f8c6	usb_bus_list_lock
++EXPORT_SYMBOL_GPL vmlinux 0xca85d8cf	tracepoint_probe_update_all
++EXPORT_SYMBOL_GPL vmlinux 0xca8e312d	rio_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xcabe04de	cpuidle_resume_and_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xcac56c5a	crypto_ahash_type
++EXPORT_SYMBOL_GPL vmlinux 0xcae984ef	root_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcb100647	lp8788_write_byte
++EXPORT_SYMBOL_GPL vmlinux 0xcb15eee9	sdhci_pci_get_data
++EXPORT_SYMBOL_GPL vmlinux 0xcb469d2b	ddebug_add_module
++EXPORT_SYMBOL_GPL vmlinux 0xcb5ebe46	bus_get_kset
++EXPORT_SYMBOL_GPL vmlinux 0xcb6171fd	irq_create_direct_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xcb804f14	__netpoll_free_async
++EXPORT_SYMBOL_GPL vmlinux 0xcbba54d2	virtqueue_kick_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xcbed092e	sysfs_notify_dirent
++EXPORT_SYMBOL_GPL vmlinux 0xcbee20b2	get_cpu_iowait_time_us
++EXPORT_SYMBOL_GPL vmlinux 0xcc170b96	ping_proc_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc1f1c3d	inet_twdr_hangman
++EXPORT_SYMBOL_GPL vmlinux 0xcc253894	usb_unlink_urb
++EXPORT_SYMBOL_GPL vmlinux 0xcc316df4	xenbus_probe_devices
++EXPORT_SYMBOL_GPL vmlinux 0xcc44ab1c	vfs_getxattr
++EXPORT_SYMBOL_GPL vmlinux 0xcc49ac3c	arizona_dev_exit
++EXPORT_SYMBOL_GPL vmlinux 0xcc6ab305	is_dock_device
++EXPORT_SYMBOL_GPL vmlinux 0xcc7a2142	cpufreq_cooling_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xcc7e4c23	tcp_done
++EXPORT_SYMBOL_GPL vmlinux 0xcc7eb2e2	ata_pci_bmdma_prepare_host
++EXPORT_SYMBOL_GPL vmlinux 0xcc85fcb6	async_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xcc8b6106	__pm_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xcc8e4fc3	stmpe_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xcc99e308	ata_host_resume
++EXPORT_SYMBOL_GPL vmlinux 0xccc85673	attribute_container_register
++EXPORT_SYMBOL_GPL vmlinux 0xcccfb2fa	sata_deb_timing_hotplug
++EXPORT_SYMBOL_GPL vmlinux 0xccd175dc	tty_put_char
++EXPORT_SYMBOL_GPL vmlinux 0xccdd4c75	fuse_conn_init
++EXPORT_SYMBOL_GPL vmlinux 0xccea4e34	perf_get_x86_pmu_capability
++EXPORT_SYMBOL_GPL vmlinux 0xccf13256	relay_open
++EXPORT_SYMBOL_GPL vmlinux 0xcd1516df	register_kprobe
++EXPORT_SYMBOL_GPL vmlinux 0xcd211b96	fs_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xcd2b81fc	pci_enable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xcd575a1f	spi_finalize_current_message
++EXPORT_SYMBOL_GPL vmlinux 0xcd5e60ec	usb_hcd_resume_root_hub
++EXPORT_SYMBOL_GPL vmlinux 0xcd6d2ad7	bio_alloc_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xcd72b7ae	of_reset_simple_xlate
++EXPORT_SYMBOL_GPL vmlinux 0xcd91b127	system_highpri_wq
++EXPORT_SYMBOL_GPL vmlinux 0xcd933c46	ata_sas_port_stop
++EXPORT_SYMBOL_GPL vmlinux 0xcd97b5a7	usb_sg_wait
++EXPORT_SYMBOL_GPL vmlinux 0xcdab13c9	rio_unregister_scan
++EXPORT_SYMBOL_GPL vmlinux 0xcdba0371	pm_generic_poweroff
++EXPORT_SYMBOL_GPL vmlinux 0xcdca3691	nr_irqs
++EXPORT_SYMBOL_GPL vmlinux 0xcdd0c2e4	pwm_put
++EXPORT_SYMBOL_GPL vmlinux 0xcde84e99	shash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xce06c538	dummy_irq_chip
++EXPORT_SYMBOL_GPL vmlinux 0xce0b9b59	max77693_read_reg
++EXPORT_SYMBOL_GPL vmlinux 0xce456165	pm_generic_runtime_resume
++EXPORT_SYMBOL_GPL vmlinux 0xce46e140	ktime_get_ts
++EXPORT_SYMBOL_GPL vmlinux 0xce637c7f	ata_sff_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xce692503	irq_domain_remove
++EXPORT_SYMBOL_GPL vmlinux 0xce6a9d9a	trace_current_buffer_discard_commit
++EXPORT_SYMBOL_GPL vmlinux 0xce74a34b	serial8250_handle_irq
++EXPORT_SYMBOL_GPL vmlinux 0xcec5c1c8	pci_ats_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xcec7283e	thermal_zone_get_zone_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xcecbee23	ata_pci_sff_init_host
++EXPORT_SYMBOL_GPL vmlinux 0xced23cf8	blk_trace_startstop
++EXPORT_SYMBOL_GPL vmlinux 0xcedc42c6	blkg_lookup_create
++EXPORT_SYMBOL_GPL vmlinux 0xcee1641c	kgdb_unregister_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xcef1dd0e	perf_check_microcode
++EXPORT_SYMBOL_GPL vmlinux 0xcf083eda	tcp_get_info
++EXPORT_SYMBOL_GPL vmlinux 0xcf208b2d	usb_unlocked_disable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xcf3186b9	mmc_switch
++EXPORT_SYMBOL_GPL vmlinux 0xcf47ad63	tpm_dev_vendor_release
++EXPORT_SYMBOL_GPL vmlinux 0xcf54ea93	async_unregister_domain
++EXPORT_SYMBOL_GPL vmlinux 0xcf7b77a3	__pci_complete_power_transition
++EXPORT_SYMBOL_GPL vmlinux 0xcf7c1b75	clk_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xcfa23bb6	sysfs_get
++EXPORT_SYMBOL_GPL vmlinux 0xcfaaf45a	__trace_note_message
++EXPORT_SYMBOL_GPL vmlinux 0xcfc32474	sata_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xcfc62f27	xen_start_info
++EXPORT_SYMBOL_GPL vmlinux 0xcfc68341	synchronize_rcu_bh
++EXPORT_SYMBOL_GPL vmlinux 0xcfca2554	serial8250_rx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xcfcc72a3	ata_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xcfda55cb	wm8400_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xcfeeae43	unregister_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xcffa2aff	spi_populate_width_msg
++EXPORT_SYMBOL_GPL vmlinux 0xd03c7700	secure_ipv4_port_ephemeral
++EXPORT_SYMBOL_GPL vmlinux 0xd0458ccb	xenbus_strstate
++EXPORT_SYMBOL_GPL vmlinux 0xd0630310	crypto_shoot_alg
++EXPORT_SYMBOL_GPL vmlinux 0xd06524ba	raw_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd067d3c5	system_freezable_power_efficient_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd06f8525	xenbus_watch_path
++EXPORT_SYMBOL_GPL vmlinux 0xd084ef0e	sync_page_io
++EXPORT_SYMBOL_GPL vmlinux 0xd0853924	__crypto_alloc_tfm
++EXPORT_SYMBOL_GPL vmlinux 0xd0c05159	emergency_restart
++EXPORT_SYMBOL_GPL vmlinux 0xd0d0ebc7	bus_unregister_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd13f6384	tcp_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xd146071b	clone_private_mount
++EXPORT_SYMBOL_GPL vmlinux 0xd14bc4d9	sock_diag_save_cookie
++EXPORT_SYMBOL_GPL vmlinux 0xd14d1540	class_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd1507e59	erst_clear
++EXPORT_SYMBOL_GPL vmlinux 0xd16712f3	crypto_check_attr_type
++EXPORT_SYMBOL_GPL vmlinux 0xd1b2db37	tracepoint_probe_register_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xd1c0ee82	da903x_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xd1ceaa5e	ata_host_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xd1f78129	pci_disable_sriov
++EXPORT_SYMBOL_GPL vmlinux 0xd205c76a	spi_async_locked
++EXPORT_SYMBOL_GPL vmlinux 0xd20bf6ba	dcookie_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd20d08ab	blk_queue_rq_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xd21161a3	__blocking_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd217ce9f	wakeup_source_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd217e9e6	trace_set_clr_event
++EXPORT_SYMBOL_GPL vmlinux 0xd217f942	acpi_subsys_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xd2394c72	rio_route_get_entry
++EXPORT_SYMBOL_GPL vmlinux 0xd254d4cc	fuse_dev_operations
++EXPORT_SYMBOL_GPL vmlinux 0xd273b1b1	__round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xd2790b6d	crypto_enqueue_request
++EXPORT_SYMBOL_GPL vmlinux 0xd2a82682	skb_to_sgvec
++EXPORT_SYMBOL_GPL vmlinux 0xd2aaeb4e	kmsg_dump_get_buffer
++EXPORT_SYMBOL_GPL vmlinux 0xd2b24246	tpm_show_owned
++EXPORT_SYMBOL_GPL vmlinux 0xd2c58ab2	apei_exec_noop
++EXPORT_SYMBOL_GPL vmlinux 0xd2d4dac8	__pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xd2de7f92	nl_table
++EXPORT_SYMBOL_GPL vmlinux 0xd2f27cd1	dma_request_slave_channel
++EXPORT_SYMBOL_GPL vmlinux 0xd2f7891c	xfrm_audit_state_replay
++EXPORT_SYMBOL_GPL vmlinux 0xd2f7f259	device_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xd304dca2	crypto_ahash_setkey
++EXPORT_SYMBOL_GPL vmlinux 0xd31ccdc8	rtc_read_alarm
++EXPORT_SYMBOL_GPL vmlinux 0xd32121c6	single_open_net
++EXPORT_SYMBOL_GPL vmlinux 0xd32dbb21	get_current_tty
++EXPORT_SYMBOL_GPL vmlinux 0xd32fe193	ata_scsi_change_queue_depth
++EXPORT_SYMBOL_GPL vmlinux 0xd372be35	input_class
++EXPORT_SYMBOL_GPL vmlinux 0xd372d0bc	device_move
++EXPORT_SYMBOL_GPL vmlinux 0xd3739521	extcon_set_cable_state
++EXPORT_SYMBOL_GPL vmlinux 0xd37e13b4	regulator_set_optimum_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd39d04f4	device_store_bool
++EXPORT_SYMBOL_GPL vmlinux 0xd3b2d005	bus_set_iommu
++EXPORT_SYMBOL_GPL vmlinux 0xd3bcddbb	regulator_is_enabled_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xd3bf6c1d	sec_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xd3d4f729	mmput
++EXPORT_SYMBOL_GPL vmlinux 0xd3e152ad	register_net_sysctl
++EXPORT_SYMBOL_GPL vmlinux 0xd3e6528f	hypervisor_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xd3fbc638	dma_buf_export_named
++EXPORT_SYMBOL_GPL vmlinux 0xd4034828	system_freezable_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd405e615	platform_get_irq_byname
++EXPORT_SYMBOL_GPL vmlinux 0xd434cb9a	md_allow_write
++EXPORT_SYMBOL_GPL vmlinux 0xd441d91f	transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xd44a5eac	kgdb_register_nmi_console
++EXPORT_SYMBOL_GPL vmlinux 0xd456c767	lp8788_read_byte
++EXPORT_SYMBOL_GPL vmlinux 0xd47f1de7	mnt_want_write
++EXPORT_SYMBOL_GPL vmlinux 0xd47f9302	ata_dummy_port_info
++EXPORT_SYMBOL_GPL vmlinux 0xd4a942a1	ata_sff_tf_load
++EXPORT_SYMBOL_GPL vmlinux 0xd4adf016	ata_do_set_mode
++EXPORT_SYMBOL_GPL vmlinux 0xd4c14632	system_unbound_wq
++EXPORT_SYMBOL_GPL vmlinux 0xd4d699a7	crypto_ahash_finup
++EXPORT_SYMBOL_GPL vmlinux 0xd4f1e87e	xenbus_unmap_ring_vfree
++EXPORT_SYMBOL_GPL vmlinux 0xd50b6dda	tpm_remove_hardware
++EXPORT_SYMBOL_GPL vmlinux 0xd5324bf3	sysfs_merge_group
++EXPORT_SYMBOL_GPL vmlinux 0xd540f438	init_fpu
++EXPORT_SYMBOL_GPL vmlinux 0xd544e902	pgprot_writecombine
++EXPORT_SYMBOL_GPL vmlinux 0xd5498894	pm_generic_freeze_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xd550560f	__pm_relax
++EXPORT_SYMBOL_GPL vmlinux 0xd55ad93b	iommu_group_get_iommudata
++EXPORT_SYMBOL_GPL vmlinux 0xd569c7f0	security_inode_mkdir
++EXPORT_SYMBOL_GPL vmlinux 0xd5bd7dac	ring_buffer_record_enable_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd5c438c9	platform_device_put
++EXPORT_SYMBOL_GPL vmlinux 0xd5e5811f	xfrm_audit_state_notfound_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd6418630	rt_mutex_lock_interruptible
++EXPORT_SYMBOL_GPL vmlinux 0xd67364f7	eventfd_ctx_fdget
++EXPORT_SYMBOL_GPL vmlinux 0xd67f5217	btree_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xd69a2ce3	relay_flush
++EXPORT_SYMBOL_GPL vmlinux 0xd6bc6b16	ata_ehi_push_desc
++EXPORT_SYMBOL_GPL vmlinux 0xd6c2e04b	__tracepoint_napi_poll
++EXPORT_SYMBOL_GPL vmlinux 0xd6caba8e	ata_std_bios_param
++EXPORT_SYMBOL_GPL vmlinux 0xd6d7f262	bio_clone_mddev
++EXPORT_SYMBOL_GPL vmlinux 0xd6e1b5cf	blk_queue_flush
++EXPORT_SYMBOL_GPL vmlinux 0xd6ed3a8e	cper_next_record_id
++EXPORT_SYMBOL_GPL vmlinux 0xd6feefa5	agp_num_entries
++EXPORT_SYMBOL_GPL vmlinux 0xd705b4c7	schedule_hrtimeout
++EXPORT_SYMBOL_GPL vmlinux 0xd72feba2	xenbus_read_driver_state
++EXPORT_SYMBOL_GPL vmlinux 0xd736b94b	PageHuge
++EXPORT_SYMBOL_GPL vmlinux 0xd7399d2a	efivar_entry_iter_end
++EXPORT_SYMBOL_GPL vmlinux 0xd763df9c	usb_alloc_coherent
++EXPORT_SYMBOL_GPL vmlinux 0xd7669969	usb_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xd7686cf7	usb_wakeup_notification
++EXPORT_SYMBOL_GPL vmlinux 0xd768e985	regulator_has_full_constraints
++EXPORT_SYMBOL_GPL vmlinux 0xd7710a4f	ata_sff_hsm_move
++EXPORT_SYMBOL_GPL vmlinux 0xd7728387	wm8350_device_init
++EXPORT_SYMBOL_GPL vmlinux 0xd77c0bc8	klist_remove
++EXPORT_SYMBOL_GPL vmlinux 0xd7ab2c0c	speedstep_detect_processor
++EXPORT_SYMBOL_GPL vmlinux 0xd7aecbf3	sdev_evt_send_simple
++EXPORT_SYMBOL_GPL vmlinux 0xd7b2056c	pm_generic_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xd7cca362	crypto_register_instance
++EXPORT_SYMBOL_GPL vmlinux 0xd7d79132	put_online_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xd808989e	usb_poison_anchored_urbs
++EXPORT_SYMBOL_GPL vmlinux 0xd81953e0	digsig_verify
++EXPORT_SYMBOL_GPL vmlinux 0xd81d72c3	pci_vfs_assigned
++EXPORT_SYMBOL_GPL vmlinux 0xd81de62c	ring_buffer_record_enable
++EXPORT_SYMBOL_GPL vmlinux 0xd820c283	eventfd_ctx_remove_wait_queue
++EXPORT_SYMBOL_GPL vmlinux 0xd8250a5c	iounmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xd8268d5d	register_acpi_bus_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xd8338050	cpufreq_frequency_table_cpuinfo
++EXPORT_SYMBOL_GPL vmlinux 0xd836390f	virtio_check_driver_offered_feature
++EXPORT_SYMBOL_GPL vmlinux 0xd838bebc	napi_by_id
++EXPORT_SYMBOL_GPL vmlinux 0xd84fe718	pci_pri_status
++EXPORT_SYMBOL_GPL vmlinux 0xd8525ea7	fl6_update_dst
++EXPORT_SYMBOL_GPL vmlinux 0xd8592cde	cpuidle_register
++EXPORT_SYMBOL_GPL vmlinux 0xd85ac634	regulator_put
++EXPORT_SYMBOL_GPL vmlinux 0xd86de94a	pci_destroy_slot
++EXPORT_SYMBOL_GPL vmlinux 0xd87601cc	ring_buffer_unlock_commit
++EXPORT_SYMBOL_GPL vmlinux 0xd87ea5f7	pm_runtime_barrier
++EXPORT_SYMBOL_GPL vmlinux 0xd89df03f	usb_queue_reset_device
++EXPORT_SYMBOL_GPL vmlinux 0xd8c6d530	wm831x_reg_lock
++EXPORT_SYMBOL_GPL vmlinux 0xd919806a	amd_cache_northbridges
++EXPORT_SYMBOL_GPL vmlinux 0xd92b2a3d	tty_ldisc_flush
++EXPORT_SYMBOL_GPL vmlinux 0xd92dd39c	exportfs_encode_inode_fh
++EXPORT_SYMBOL_GPL vmlinux 0xd935f263	class_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xd93d94b6	xen_swiotlb_sync_sg_for_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xd942d353	ring_buffer_record_off
++EXPORT_SYMBOL_GPL vmlinux 0xd94b737e	erst_read
++EXPORT_SYMBOL_GPL vmlinux 0xd95e85f4	uart_handle_dcd_change
++EXPORT_SYMBOL_GPL vmlinux 0xd9610c80	skb_tstamp_tx
++EXPORT_SYMBOL_GPL vmlinux 0xd9898320	platform_add_devices
++EXPORT_SYMBOL_GPL vmlinux 0xd989dff5	srcu_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xd9d46b64	user_read
++EXPORT_SYMBOL_GPL vmlinux 0xd9d7f623	pkey_id_type
++EXPORT_SYMBOL_GPL vmlinux 0xd9ecb670	ring_buffer_overruns
++EXPORT_SYMBOL_GPL vmlinux 0xda2610dd	input_ff_destroy
++EXPORT_SYMBOL_GPL vmlinux 0xda3a7ca9	regulator_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xda430958	filter_current_check_discard
++EXPORT_SYMBOL_GPL vmlinux 0xda44cb37	setup_charger_manager
++EXPORT_SYMBOL_GPL vmlinux 0xda44f415	udp6_lib_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xda6e764d	class_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xda8540a7	ata_sff_dev_select
++EXPORT_SYMBOL_GPL vmlinux 0xda95ad51	spi_write_then_read
++EXPORT_SYMBOL_GPL vmlinux 0xdaa6973f	xen_swiotlb_dma_mapping_error
++EXPORT_SYMBOL_GPL vmlinux 0xdae4b3ce	tps6586x_writes
++EXPORT_SYMBOL_GPL vmlinux 0xdaf4dfb3	fb_mode_option
++EXPORT_SYMBOL_GPL vmlinux 0xdb04cacc	tracepoint_probe_unregister_noupdate
++EXPORT_SYMBOL_GPL vmlinux 0xdb076625	arizona_clk32k_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdb342ac9	crypto_nivaead_type
++EXPORT_SYMBOL_GPL vmlinux 0xdb591c82	register_virtio_driver
++EXPORT_SYMBOL_GPL vmlinux 0xdb8a1b3f	usermodehelper_read_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xdb9c5120	fat_flush_inodes
++EXPORT_SYMBOL_GPL vmlinux 0xdba4ad93	static_key_slow_dec_deferred
++EXPORT_SYMBOL_GPL vmlinux 0xdbcfddd1	uprobe_register
++EXPORT_SYMBOL_GPL vmlinux 0xdbe31bb0	efivar_entry_add
++EXPORT_SYMBOL_GPL vmlinux 0xdbe6e7df	proc_mkdir_data
++EXPORT_SYMBOL_GPL vmlinux 0xdbefcd64	hrtimer_start_range_ns
++EXPORT_SYMBOL_GPL vmlinux 0xdbf7cb70	mpi_get_nbits
++EXPORT_SYMBOL_GPL vmlinux 0xdc14a211	xen_hvm_evtchn_do_upcall
++EXPORT_SYMBOL_GPL vmlinux 0xdc1db9f1	thermal_zone_bind_cooling_device
++EXPORT_SYMBOL_GPL vmlinux 0xdc2bedef	xen_remap_domain_mfn_range
++EXPORT_SYMBOL_GPL vmlinux 0xdc59a32f	wakeup_source_drop
++EXPORT_SYMBOL_GPL vmlinux 0xdc6699cb	acpi_dev_free_resource_list
++EXPORT_SYMBOL_GPL vmlinux 0xdc76527b	blkg_stat_recursive_sum
++EXPORT_SYMBOL_GPL vmlinux 0xdc78e9a5	device_add
++EXPORT_SYMBOL_GPL vmlinux 0xdc825d6c	usb_amd_quirk_pll_disable
++EXPORT_SYMBOL_GPL vmlinux 0xdc97af2e	syscore_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xdc9fa232	raw_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xdcacf611	fb_deferred_io_fsync
++EXPORT_SYMBOL_GPL vmlinux 0xdcc055b2	alarm_try_to_cancel
++EXPORT_SYMBOL_GPL vmlinux 0xdcc09520	blkg_prfill_rwstat
++EXPORT_SYMBOL_GPL vmlinux 0xdce57037	apei_estatus_print
++EXPORT_SYMBOL_GPL vmlinux 0xdd0002e3	debugfs_create_u8
++EXPORT_SYMBOL_GPL vmlinux 0xdd2efc0f	ring_buffer_reset_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xdd391eff	profile_event_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdd64acab	crypto_remove_spawns
++EXPORT_SYMBOL_GPL vmlinux 0xdd794d33	phys_wc_to_mtrr_index
++EXPORT_SYMBOL_GPL vmlinux 0xddd58dc0	ring_buffer_reset
++EXPORT_SYMBOL_GPL vmlinux 0xddd74be8	fib_rules_register
++EXPORT_SYMBOL_GPL vmlinux 0xde4c19b2	fuse_conn_kill
++EXPORT_SYMBOL_GPL vmlinux 0xde59bb2f	max8997_update_reg
++EXPORT_SYMBOL_GPL vmlinux 0xde747356	intel_msic_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xde76c6af	blk_queue_bypass_start
++EXPORT_SYMBOL_GPL vmlinux 0xde7fe711	class_interface_register
++EXPORT_SYMBOL_GPL vmlinux 0xde8f877f	kernel_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xde8fa094	sec_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xdeb9c55d	rio_mport_read_config_8
++EXPORT_SYMBOL_GPL vmlinux 0xded0f371	edac_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xdf0f75c6	eventfd_signal
++EXPORT_SYMBOL_GPL vmlinux 0xdf16d38f	hwpoison_filter
++EXPORT_SYMBOL_GPL vmlinux 0xdf1882af	dbgp_reset_prep
++EXPORT_SYMBOL_GPL vmlinux 0xdf220f97	__rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xdf2af64c	alarm_forward
++EXPORT_SYMBOL_GPL vmlinux 0xdf357686	dm_dispatch_request
++EXPORT_SYMBOL_GPL vmlinux 0xdf41bfc8	fanout_mutex
++EXPORT_SYMBOL_GPL vmlinux 0xdf443906	device_init_wakeup
++EXPORT_SYMBOL_GPL vmlinux 0xdfa1fd06	klist_iter_init_node
++EXPORT_SYMBOL_GPL vmlinux 0xdfb675b3	handle_level_irq
++EXPORT_SYMBOL_GPL vmlinux 0xdfd372bd	crypto_register_algs
++EXPORT_SYMBOL_GPL vmlinux 0xdff36d5d	unregister_virtio_device
++EXPORT_SYMBOL_GPL vmlinux 0xdff4241b	relay_close
++EXPORT_SYMBOL_GPL vmlinux 0xe007de41	kallsyms_lookup_name
++EXPORT_SYMBOL_GPL vmlinux 0xe02eb6d0	ring_buffer_commit_overrun_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xe05e6910	devres_find
++EXPORT_SYMBOL_GPL vmlinux 0xe0627334	crypto_aead_type
++EXPORT_SYMBOL_GPL vmlinux 0xe06d6d4d	tpm_dev_release
++EXPORT_SYMBOL_GPL vmlinux 0xe089cfcc	agp_memory_reserved
++EXPORT_SYMBOL_GPL vmlinux 0xe0a74f55	sata_pmp_port_ops
++EXPORT_SYMBOL_GPL vmlinux 0xe0c33496	tps6586x_clr_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe0c77bb5	mce_notify_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe0f31b68	rtc_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe10cd6ad	erst_get_record_id_begin
++EXPORT_SYMBOL_GPL vmlinux 0xe118a4bc	alloc_acpi_hp_work
++EXPORT_SYMBOL_GPL vmlinux 0xe11946b5	usb_block_urb
++EXPORT_SYMBOL_GPL vmlinux 0xe1358ce8	dma_buf_mmap
++EXPORT_SYMBOL_GPL vmlinux 0xe13dba85	pci_cfg_access_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xe155b751	spi_busnum_to_master
++EXPORT_SYMBOL_GPL vmlinux 0xe1865989	bus_find_device
++EXPORT_SYMBOL_GPL vmlinux 0xe187d1be	preempt_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xe1964dd9	device_wakeup_disable
++EXPORT_SYMBOL_GPL vmlinux 0xe1a2d09e	tps6586x_reads
++EXPORT_SYMBOL_GPL vmlinux 0xe1a719d6	regmap_read
++EXPORT_SYMBOL_GPL vmlinux 0xe1bd6c99	rio_init_mports
++EXPORT_SYMBOL_GPL vmlinux 0xe1c05c33	dma_release_channel
++EXPORT_SYMBOL_GPL vmlinux 0xe1e11499	crypto_register_shash
++EXPORT_SYMBOL_GPL vmlinux 0xe2196a25	bmp085_remove
++EXPORT_SYMBOL_GPL vmlinux 0xe220075e	ata_scsi_queuecmd
++EXPORT_SYMBOL_GPL vmlinux 0xe2337dc0	irq_domain_xlate_onecell
++EXPORT_SYMBOL_GPL vmlinux 0xe23fe12d	pci_pri_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe26e46f0	acpi_dev_resource_ext_address_space
++EXPORT_SYMBOL_GPL vmlinux 0xe295c0ff	is_hpet_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe2a5bf42	sdio_release_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe2dd67e5	regulator_set_current_limit
++EXPORT_SYMBOL_GPL vmlinux 0xe2e7840d	regmap_init_mmio_clk
++EXPORT_SYMBOL_GPL vmlinux 0xe2e82caf	inet_csk_route_child_sock
++EXPORT_SYMBOL_GPL vmlinux 0xe2eacdb3	sata_link_hardreset
++EXPORT_SYMBOL_GPL vmlinux 0xe3043ff9	request_any_context_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe31c0766	devm_regulator_bulk_get
++EXPORT_SYMBOL_GPL vmlinux 0xe31e634e	tc3589x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xe31fe6d4	crypto_alloc_pcomp
++EXPORT_SYMBOL_GPL vmlinux 0xe34dec49	sata_link_scr_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xe3603cb0	acpiphp_register_attention
++EXPORT_SYMBOL_GPL vmlinux 0xe3614932	pci_sriov_get_totalvfs
++EXPORT_SYMBOL_GPL vmlinux 0xe384a102	usb_speed_string
++EXPORT_SYMBOL_GPL vmlinux 0xe38d32f6	tps65912_set_bits
++EXPORT_SYMBOL_GPL vmlinux 0xe3bc7fd4	hpet_unregister_irq_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe3c63739	get_task_comm
++EXPORT_SYMBOL_GPL vmlinux 0xe3c92ed1	blkcg_print_blkgs
++EXPORT_SYMBOL_GPL vmlinux 0xe3cbba95	fat_remove_entries
++EXPORT_SYMBOL_GPL vmlinux 0xe41534ce	bind_evtchn_to_irqhandler
++EXPORT_SYMBOL_GPL vmlinux 0xe4309905	syscore_resume
++EXPORT_SYMBOL_GPL vmlinux 0xe439815c	erst_get_record_count
++EXPORT_SYMBOL_GPL vmlinux 0xe4875dbd	irq_get_irq_data
++EXPORT_SYMBOL_GPL vmlinux 0xe49081ac	ip6_append_data
++EXPORT_SYMBOL_GPL vmlinux 0xe4958e57	ip6_sk_redirect
++EXPORT_SYMBOL_GPL vmlinux 0xe49fdd0c	irq_remove_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xe4a80bc1	wm5102_i2c_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xe4ad4e22	ata_sff_port_intr
++EXPORT_SYMBOL_GPL vmlinux 0xe4b97365	evm_inode_init_security
++EXPORT_SYMBOL_GPL vmlinux 0xe4ba70a5	ata_link_next
++EXPORT_SYMBOL_GPL vmlinux 0xe4c331b6	acpi_os_unmap_memory
++EXPORT_SYMBOL_GPL vmlinux 0xe4e032eb	ata_sff_lost_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe4e2e52d	hwmon_device_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe4e68bc8	apei_map_generic_address
++EXPORT_SYMBOL_GPL vmlinux 0xe53ac38f	alarm_forward_now
++EXPORT_SYMBOL_GPL vmlinux 0xe549297c	thermal_cooling_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xe586ce4e	rtc_irq_set_freq
++EXPORT_SYMBOL_GPL vmlinux 0xe5883bd9	class_compat_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe58fb452	aer_irq
++EXPORT_SYMBOL_GPL vmlinux 0xe5d8091e	__mmu_notifier_register
++EXPORT_SYMBOL_GPL vmlinux 0xe5e25fd6	vfs_setxattr
++EXPORT_SYMBOL_GPL vmlinux 0xe6005ed5	xfrm_audit_policy_delete
++EXPORT_SYMBOL_GPL vmlinux 0xe632f89d	srcu_notifier_chain_register
++EXPORT_SYMBOL_GPL vmlinux 0xe64ad8ea	unregister_nmi_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe651f76e	selinux_is_enabled
++EXPORT_SYMBOL_GPL vmlinux 0xe65503ca	pm_stay_awake
++EXPORT_SYMBOL_GPL vmlinux 0xe6646878	srcu_notifier_chain_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe680be6a	power_supply_register
++EXPORT_SYMBOL_GPL vmlinux 0xe6b10661	virtqueue_add_sgs
++EXPORT_SYMBOL_GPL vmlinux 0xe6c68334	ddebug_remove_module
++EXPORT_SYMBOL_GPL vmlinux 0xe6dd04af	init_user_ns
++EXPORT_SYMBOL_GPL vmlinux 0xe6e1c5fe	uuid_be_gen
++EXPORT_SYMBOL_GPL vmlinux 0xe70f6671	max8997_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xe7232e0f	user_return_notifier_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe769232e	sprint_symbol_no_offset
++EXPORT_SYMBOL_GPL vmlinux 0xe77e94ef	cgroup_next_sibling
++EXPORT_SYMBOL_GPL vmlinux 0xe79e7975	serial8250_tx_dma
++EXPORT_SYMBOL_GPL vmlinux 0xe7a15d13	acpi_ec_add_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe7bccd64	page_cache_async_readahead
++EXPORT_SYMBOL_GPL vmlinux 0xe7d19c70	nf_register_afinfo
++EXPORT_SYMBOL_GPL vmlinux 0xe7d9a95c	dma_run_dependencies
++EXPORT_SYMBOL_GPL vmlinux 0xe7fcabcd	hrtimer_init_sleeper
++EXPORT_SYMBOL_GPL vmlinux 0xe7ffe877	pcpu_base_addr
++EXPORT_SYMBOL_GPL vmlinux 0xe80d2f44	spi_alloc_master
++EXPORT_SYMBOL_GPL vmlinux 0xe818b32b	ata_bmdma_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xe8244161	tcp_fetch_timewait_stamp
++EXPORT_SYMBOL_GPL vmlinux 0xe8312b22	xenbus_free_evtchn
++EXPORT_SYMBOL_GPL vmlinux 0xe84f6e5c	pciserial_remove_ports
++EXPORT_SYMBOL_GPL vmlinux 0xe85a4de3	acpi_ec_remove_query_handler
++EXPORT_SYMBOL_GPL vmlinux 0xe862c4b7	dpm_suspend_start
++EXPORT_SYMBOL_GPL vmlinux 0xe8676a79	blkcg_policy_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe8691569	class_for_each_device
++EXPORT_SYMBOL_GPL vmlinux 0xe86a6a77	clk_set_rate
++EXPORT_SYMBOL_GPL vmlinux 0xe88350c1	sock_prot_inuse_get
++EXPORT_SYMBOL_GPL vmlinux 0xe8a4345f	crypto_tfm_in_queue
++EXPORT_SYMBOL_GPL vmlinux 0xe90cb20d	blk_rq_prep_clone
++EXPORT_SYMBOL_GPL vmlinux 0xe93e49c3	devres_free
++EXPORT_SYMBOL_GPL vmlinux 0xe950474e	fib_rules_lookup
++EXPORT_SYMBOL_GPL vmlinux 0xe9b95068	anon_transport_class_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe9c9b82e	posix_clock_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xe9ca4eac	skcipher_geniv_exit
++EXPORT_SYMBOL_GPL vmlinux 0xe9d1b7cf	irq_to_pcap
++EXPORT_SYMBOL_GPL vmlinux 0xe9ed6d2e	sysfs_add_link_to_group
++EXPORT_SYMBOL_GPL vmlinux 0xea03d087	blocking_notifier_chain_cond_register
++EXPORT_SYMBOL_GPL vmlinux 0xea0a4ab5	blk_rq_err_bytes
++EXPORT_SYMBOL_GPL vmlinux 0xea124bd1	gcd
++EXPORT_SYMBOL_GPL vmlinux 0xea288498	usb_get_descriptor
++EXPORT_SYMBOL_GPL vmlinux 0xea418e0f	atapi_cmd_type
++EXPORT_SYMBOL_GPL vmlinux 0xea4d2b8a	handle_simple_irq
++EXPORT_SYMBOL_GPL vmlinux 0xea5baeac	debugfs_create_atomic_t
++EXPORT_SYMBOL_GPL vmlinux 0xea6a4610	extcon_find_cable_index
++EXPORT_SYMBOL_GPL vmlinux 0xea6e64c8	rio_local_get_device_id
++EXPORT_SYMBOL_GPL vmlinux 0xea75f9ac	sdio_readl
++EXPORT_SYMBOL_GPL vmlinux 0xea8e5a8d	vfs_test_lock
++EXPORT_SYMBOL_GPL vmlinux 0xeaaef7cc	pci_disable_rom
++EXPORT_SYMBOL_GPL vmlinux 0xeb1c3628	nf_ipv6_ops
++EXPORT_SYMBOL_GPL vmlinux 0xeb24babe	power_supply_changed
++EXPORT_SYMBOL_GPL vmlinux 0xeb370805	__apei_exec_run
++EXPORT_SYMBOL_GPL vmlinux 0xeb3be3ce	transport_add_device
++EXPORT_SYMBOL_GPL vmlinux 0xeb53869b	power_supply_class
++EXPORT_SYMBOL_GPL vmlinux 0xeb58b4c7	acpi_debugfs_dir
++EXPORT_SYMBOL_GPL vmlinux 0xeb5b7dea	iommu_attach_device
++EXPORT_SYMBOL_GPL vmlinux 0xeb78b4fc	usb_get_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xeb9abbee	ata_sff_queue_work
++EXPORT_SYMBOL_GPL vmlinux 0xebd20bfe	regulator_set_voltage_time_sel
++EXPORT_SYMBOL_GPL vmlinux 0xebde92c0	pci_msi_off
++EXPORT_SYMBOL_GPL vmlinux 0xebec57c4	ring_buffer_oldest_event_ts
++EXPORT_SYMBOL_GPL vmlinux 0xebfe43ff	ata_sas_port_async_suspend
++EXPORT_SYMBOL_GPL vmlinux 0xec1b043e	regulator_suspend_prepare
++EXPORT_SYMBOL_GPL vmlinux 0xec25f967	klist_del
++EXPORT_SYMBOL_GPL vmlinux 0xec282dcc	dma_buf_kunmap_atomic
++EXPORT_SYMBOL_GPL vmlinux 0xec404491	perf_pmu_migrate_context
++EXPORT_SYMBOL_GPL vmlinux 0xec44e3c0	regmap_raw_write
++EXPORT_SYMBOL_GPL vmlinux 0xec4f9153	tty_prepare_flip_string
++EXPORT_SYMBOL_GPL vmlinux 0xec5a14bf	swiotlb_tbl_map_single
++EXPORT_SYMBOL_GPL vmlinux 0xec76f659	platform_create_bundle
++EXPORT_SYMBOL_GPL vmlinux 0xec7a755a	tty_buffer_request_room
++EXPORT_SYMBOL_GPL vmlinux 0xec8d51d7	do_unbind_con_driver
++EXPORT_SYMBOL_GPL vmlinux 0xecaaba07	devres_open_group
++EXPORT_SYMBOL_GPL vmlinux 0xecddc3e2	invalidate_inode_pages2
++EXPORT_SYMBOL_GPL vmlinux 0xecf1c375	pci_ioremap_bar
++EXPORT_SYMBOL_GPL vmlinux 0xed1841c8	usb_unlocked_enable_lpm
++EXPORT_SYMBOL_GPL vmlinux 0xed35d39b	da9052_disable_irq_nosync
++EXPORT_SYMBOL_GPL vmlinux 0xed52f156	kobject_create_and_add
++EXPORT_SYMBOL_GPL vmlinux 0xed5c41bd	iptunnel_xmit
++EXPORT_SYMBOL_GPL vmlinux 0xed75924c	__rio_local_write_config_16
++EXPORT_SYMBOL_GPL vmlinux 0xed7df32f	ip6_datagram_send_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xedae56fb	platform_bus_type
++EXPORT_SYMBOL_GPL vmlinux 0xedbc3f6a	crypto_grab_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xedbc6f67	gnttab_end_foreign_access
++EXPORT_SYMBOL_GPL vmlinux 0xedbd51ba	__mmu_notifier_invalidate_range_start
++EXPORT_SYMBOL_GPL vmlinux 0xedd49930	zs_create_pool
++EXPORT_SYMBOL_GPL vmlinux 0xede2c395	acpi_get_gpio_by_index
++EXPORT_SYMBOL_GPL vmlinux 0xedf3f1f1	do_machine_check
++EXPORT_SYMBOL_GPL vmlinux 0xee274f97	kobject_rename
++EXPORT_SYMBOL_GPL vmlinux 0xee30cd8f	cpu_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xee49d3ea	shmem_file_setup
++EXPORT_SYMBOL_GPL vmlinux 0xee59c54d	usb_hub_find_child
++EXPORT_SYMBOL_GPL vmlinux 0xee6b71c4	syscon_regmap_lookup_by_compatible
++EXPORT_SYMBOL_GPL vmlinux 0xee778eef	reset_controller_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xee845be8	crypto_ahash_final
++EXPORT_SYMBOL_GPL vmlinux 0xee8848cf	da9052_enable_irq
++EXPORT_SYMBOL_GPL vmlinux 0xeeafe100	task_xstate_cachep
++EXPORT_SYMBOL_GPL vmlinux 0xeec02bb0	pci_restore_ats_state
++EXPORT_SYMBOL_GPL vmlinux 0xeec24d31	usb_wait_anchor_empty_timeout
++EXPORT_SYMBOL_GPL vmlinux 0xeed4eacc	pci_user_read_config_byte
++EXPORT_SYMBOL_GPL vmlinux 0xef0859a3	relay_subbufs_consumed
++EXPORT_SYMBOL_GPL vmlinux 0xef1f6e23	apei_resources_request
++EXPORT_SYMBOL_GPL vmlinux 0xef23d470	klist_add_tail
++EXPORT_SYMBOL_GPL vmlinux 0xef409b74	kmsg_dump_get_line
++EXPORT_SYMBOL_GPL vmlinux 0xef6c3f70	round_jiffies_up_relative
++EXPORT_SYMBOL_GPL vmlinux 0xef782b88	gnttab_grant_foreign_access_subpage
++EXPORT_SYMBOL_GPL vmlinux 0xef8c7850	pcap_adc_async
++EXPORT_SYMBOL_GPL vmlinux 0xef964e1d	raw_seq_stop
++EXPORT_SYMBOL_GPL vmlinux 0xefa0a5e5	rtnl_af_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xefb1f3a1	usb_reset_configuration
++EXPORT_SYMBOL_GPL vmlinux 0xefc91531	irq_create_of_mapping
++EXPORT_SYMBOL_GPL vmlinux 0xefd96b91	iommu_attach_group
++EXPORT_SYMBOL_GPL vmlinux 0xeff3732b	ehci_cf_port_reset_rwsem
++EXPORT_SYMBOL_GPL vmlinux 0xf00d71de	ahash_free_instance
++EXPORT_SYMBOL_GPL vmlinux 0xf01a42fb	fat_getattr
++EXPORT_SYMBOL_GPL vmlinux 0xf054ac97	intel_msic_irq_read
++EXPORT_SYMBOL_GPL vmlinux 0xf060ae2f	extcon_set_state
++EXPORT_SYMBOL_GPL vmlinux 0xf0696401	acpi_pci_detect_ejectable
++EXPORT_SYMBOL_GPL vmlinux 0xf08cc79b	regulator_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xf09fc80a	cpuidle_unregister_driver
++EXPORT_SYMBOL_GPL vmlinux 0xf0ab2744	rio_get_device
++EXPORT_SYMBOL_GPL vmlinux 0xf0c70228	vfs_removexattr
++EXPORT_SYMBOL_GPL vmlinux 0xf0cc15b1	fb_deferred_io_open
++EXPORT_SYMBOL_GPL vmlinux 0xf0cd6b50	bd_unlink_disk_holder
++EXPORT_SYMBOL_GPL vmlinux 0xf0f2fdcb	rio_route_add_entry
++EXPORT_SYMBOL_GPL vmlinux 0xf0f5dbc2	timerqueue_iterate_next
++EXPORT_SYMBOL_GPL vmlinux 0xf0f6a58f	fb_bl_default_curve
++EXPORT_SYMBOL_GPL vmlinux 0xf0f72dee	clk_unprepare
++EXPORT_SYMBOL_GPL vmlinux 0xf1143caa	__platform_driver_register
++EXPORT_SYMBOL_GPL vmlinux 0xf143bbbb	rio_unmap_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xf143ec77	blkcg_deactivate_policy
++EXPORT_SYMBOL_GPL vmlinux 0xf15feb14	tps80031_ext_power_req_config
++EXPORT_SYMBOL_GPL vmlinux 0xf1733b51	da9052_adc_read_temp
++EXPORT_SYMBOL_GPL vmlinux 0xf183cfa2	inet_twsk_put
++EXPORT_SYMBOL_GPL vmlinux 0xf184d189	kernel_power_off
++EXPORT_SYMBOL_GPL vmlinux 0xf186c82f	nl_table_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf1940e60	pci_sriov_migration
++EXPORT_SYMBOL_GPL vmlinux 0xf1b31314	delayacct_on
++EXPORT_SYMBOL_GPL vmlinux 0xf1b551d9	ibft_addr
++EXPORT_SYMBOL_GPL vmlinux 0xf1eac845	pm_generic_restore_early
++EXPORT_SYMBOL_GPL vmlinux 0xf20e04d0	rt_mutex_trylock
++EXPORT_SYMBOL_GPL vmlinux 0xf21e1f9b	disable_percpu_irq
++EXPORT_SYMBOL_GPL vmlinux 0xf225e367	__ip_route_output_key
++EXPORT_SYMBOL_GPL vmlinux 0xf22b5b19	usb_hcd_map_urb_for_dma
++EXPORT_SYMBOL_GPL vmlinux 0xf22f0202	inet6_csk_addr2sockaddr
++EXPORT_SYMBOL_GPL vmlinux 0xf24424d2	netlink_has_listeners
++EXPORT_SYMBOL_GPL vmlinux 0xf27848de	xfrm_output
++EXPORT_SYMBOL_GPL vmlinux 0xf27977e2	async_synchronize_cookie_domain
++EXPORT_SYMBOL_GPL vmlinux 0xf28ab8bf	ping_hash
++EXPORT_SYMBOL_GPL vmlinux 0xf29a1a4e	pci_walk_bus
++EXPORT_SYMBOL_GPL vmlinux 0xf2b3146f	sdio_set_block_size
++EXPORT_SYMBOL_GPL vmlinux 0xf2c78bb4	tc3589x_reg_read
++EXPORT_SYMBOL_GPL vmlinux 0xf2c85436	hrtimer_forward
++EXPORT_SYMBOL_GPL vmlinux 0xf2fca922	uart_parse_options
++EXPORT_SYMBOL_GPL vmlinux 0xf30e105d	ezx_pcap_write
++EXPORT_SYMBOL_GPL vmlinux 0xf30fda27	lzo1x_decompress_safe
++EXPORT_SYMBOL_GPL vmlinux 0xf31b3fd1	workqueue_set_max_active
++EXPORT_SYMBOL_GPL vmlinux 0xf32bdc5d	unregister_xenstore_notifier
++EXPORT_SYMBOL_GPL vmlinux 0xf331236f	btree_geo32
++EXPORT_SYMBOL_GPL vmlinux 0xf356b72b	inet_twsk_schedule
++EXPORT_SYMBOL_GPL vmlinux 0xf3576f01	irq_domain_add_legacy
++EXPORT_SYMBOL_GPL vmlinux 0xf36aad47	xenbus_grant_ring
++EXPORT_SYMBOL_GPL vmlinux 0xf37854a8	virtqueue_poll
++EXPORT_SYMBOL_GPL vmlinux 0xf3b172dd	acpi_register_gsi
++EXPORT_SYMBOL_GPL vmlinux 0xf3b445f6	regulator_get_bypass_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf3b451ca	kdb_poll_funcs
++EXPORT_SYMBOL_GPL vmlinux 0xf3ca65fc	vring_new_virtqueue
++EXPORT_SYMBOL_GPL vmlinux 0xf3dd036d	regulator_set_voltage_time
++EXPORT_SYMBOL_GPL vmlinux 0xf3f96415	blkcg_policy_register
++EXPORT_SYMBOL_GPL vmlinux 0xf3ffce45	acpi_dev_pm_remove_dependent
++EXPORT_SYMBOL_GPL vmlinux 0xf40d8140	crypto_attr_alg2
++EXPORT_SYMBOL_GPL vmlinux 0xf41ee523	usb_add_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf4206d7d	ata_std_qc_defer
++EXPORT_SYMBOL_GPL vmlinux 0xf42d163e	cpufreq_register_governor
++EXPORT_SYMBOL_GPL vmlinux 0xf43c1089	ata_acpi_gtm_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf43f48f9	debugfs_create_file
++EXPORT_SYMBOL_GPL vmlinux 0xf46fb8c1	nf_queue_entry_get_refs
++EXPORT_SYMBOL_GPL vmlinux 0xf494f618	mmc_regulator_get_ocrmask
++EXPORT_SYMBOL_GPL vmlinux 0xf499fdb2	rcu_barrier_bh
++EXPORT_SYMBOL_GPL vmlinux 0xf4ab3e45	__inet_hash_nolisten
++EXPORT_SYMBOL_GPL vmlinux 0xf4d89d44	sata_link_resume
++EXPORT_SYMBOL_GPL vmlinux 0xf4e88ed6	__srcu_read_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf4e9fa18	usb_disable_xhci_ports
++EXPORT_SYMBOL_GPL vmlinux 0xf4fc2d6c	__ring_buffer_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xf522f067	register_pernet_device
++EXPORT_SYMBOL_GPL vmlinux 0xf54bd49b	lcm
++EXPORT_SYMBOL_GPL vmlinux 0xf553318d	cpuidle_pause_and_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf56a61a6	rio_mport_get_physefb
++EXPORT_SYMBOL_GPL vmlinux 0xf5785b42	evtchn_get
++EXPORT_SYMBOL_GPL vmlinux 0xf5945bac	gnttab_free_grant_references
++EXPORT_SYMBOL_GPL vmlinux 0xf5a691cd	invalidate_bh_lrus
++EXPORT_SYMBOL_GPL vmlinux 0xf5d13121	rio_request_dma
++EXPORT_SYMBOL_GPL vmlinux 0xf5f538ab	cpufreq_governor_dbs
++EXPORT_SYMBOL_GPL vmlinux 0xf5fef4e3	wm5110_spi_regmap
++EXPORT_SYMBOL_GPL vmlinux 0xf622d0bf	ata_std_postreset
++EXPORT_SYMBOL_GPL vmlinux 0xf62d1831	devm_usb_put_phy
++EXPORT_SYMBOL_GPL vmlinux 0xf6508394	acpi_dev_resume_early
++EXPORT_SYMBOL_GPL vmlinux 0xf665cb46	inet6_destroy_sock
++EXPORT_SYMBOL_GPL vmlinux 0xf68af921	pci_find_next_ext_capability
++EXPORT_SYMBOL_GPL vmlinux 0xf69617e7	swiotlb_tbl_unmap_single
++EXPORT_SYMBOL_GPL vmlinux 0xf6e04730	event_storage
++EXPORT_SYMBOL_GPL vmlinux 0xf6e0ece7	virtqueue_get_vring_size
++EXPORT_SYMBOL_GPL vmlinux 0xf6e874f5	ata_timing_merge
++EXPORT_SYMBOL_GPL vmlinux 0xf7016530	xenbus_gather
++EXPORT_SYMBOL_GPL vmlinux 0xf70274b9	stmpe_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf7322bc8	pv_time_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf74656ab	regulator_can_change_voltage
++EXPORT_SYMBOL_GPL vmlinux 0xf7624bb9	ipv4_update_pmtu
++EXPORT_SYMBOL_GPL vmlinux 0xf77ea080	ata_port_schedule_eh
++EXPORT_SYMBOL_GPL vmlinux 0xf7a14f56	apei_mce_report_mem_error
++EXPORT_SYMBOL_GPL vmlinux 0xf7b46a7a	blk_queue_flush_queueable
++EXPORT_SYMBOL_GPL vmlinux 0xf7c11374	cgroup_taskset_first
++EXPORT_SYMBOL_GPL vmlinux 0xf7daadc3	register_kprobes
++EXPORT_SYMBOL_GPL vmlinux 0xf7e57a33	regmap_raw_read
++EXPORT_SYMBOL_GPL vmlinux 0xf80a6785	pm_generic_thaw_noirq
++EXPORT_SYMBOL_GPL vmlinux 0xf827f656	crypto_lookup_skcipher
++EXPORT_SYMBOL_GPL vmlinux 0xf82f16b3	execute_in_process_context
++EXPORT_SYMBOL_GPL vmlinux 0xf82f3657	work_on_cpu
++EXPORT_SYMBOL_GPL vmlinux 0xf8365581	bus_get_device_klist
++EXPORT_SYMBOL_GPL vmlinux 0xf849645e	relay_buf_full
++EXPORT_SYMBOL_GPL vmlinux 0xf86a3a9f	clk_gate_ops
++EXPORT_SYMBOL_GPL vmlinux 0xf8802492	print_stack_trace
++EXPORT_SYMBOL_GPL vmlinux 0xf88b9ed7	tps6586x_write
++EXPORT_SYMBOL_GPL vmlinux 0xf89aa6f6	ata_sff_dma_pause
++EXPORT_SYMBOL_GPL vmlinux 0xf8d2b717	scsi_get_vpd_page
++EXPORT_SYMBOL_GPL vmlinux 0xf8dafad4	dma_buf_put
++EXPORT_SYMBOL_GPL vmlinux 0xf8f3a0fb	ata_ratelimit
++EXPORT_SYMBOL_GPL vmlinux 0xf8fd6aa4	inet6_sk_rebuild_header
++EXPORT_SYMBOL_GPL vmlinux 0xf8fe3d0b	kmsg_dump_register
++EXPORT_SYMBOL_GPL vmlinux 0xf90f47d4	pwm_config
++EXPORT_SYMBOL_GPL vmlinux 0xf92ce956	kdb_printf
++EXPORT_SYMBOL_GPL vmlinux 0xf932015f	__raw_notifier_call_chain
++EXPORT_SYMBOL_GPL vmlinux 0xf9570177	perf_event_enable
++EXPORT_SYMBOL_GPL vmlinux 0xf95bb95c	__netpoll_cleanup
++EXPORT_SYMBOL_GPL vmlinux 0xf9765833	dmi_match
++EXPORT_SYMBOL_GPL vmlinux 0xf97666a0	set_memory_rw
++EXPORT_SYMBOL_GPL vmlinux 0xf99700d0	inet_getpeer
++EXPORT_SYMBOL_GPL vmlinux 0xf9984208	sk_unattached_filter_create
++EXPORT_SYMBOL_GPL vmlinux 0xf9a054b5	__round_jiffies
++EXPORT_SYMBOL_GPL vmlinux 0xf9a62aad	sk_clone_lock
++EXPORT_SYMBOL_GPL vmlinux 0xf9b048a3	sdio_readw
++EXPORT_SYMBOL_GPL vmlinux 0xf9b48f95	__pm_runtime_disable
++EXPORT_SYMBOL_GPL vmlinux 0xf9ca3160	ata_id_xfermask
++EXPORT_SYMBOL_GPL vmlinux 0xf9d9264e	xen_have_vector_callback
++EXPORT_SYMBOL_GPL vmlinux 0xf9de1561	register_user_hw_breakpoint
++EXPORT_SYMBOL_GPL vmlinux 0xfa012fe7	tracepoint_probe_register
++EXPORT_SYMBOL_GPL vmlinux 0xfa07cc73	driver_remove_file
++EXPORT_SYMBOL_GPL vmlinux 0xfa0fb2b5	wm831x_reg_unlock
++EXPORT_SYMBOL_GPL vmlinux 0xfa1eb910	unregister_syscore_ops
++EXPORT_SYMBOL_GPL vmlinux 0xfa1f4662	scatterwalk_start
++EXPORT_SYMBOL_GPL vmlinux 0xfa463c2c	xenbus_frontend_closed
++EXPORT_SYMBOL_GPL vmlinux 0xfa5e21f1	led_trigger_unregister
++EXPORT_SYMBOL_GPL vmlinux 0xfa5e9026	regmap_bulk_write
++EXPORT_SYMBOL_GPL vmlinux 0xfa6b1d38	blk_queue_bypass_end
++EXPORT_SYMBOL_GPL vmlinux 0xfaa371ae	device_initialize
++EXPORT_SYMBOL_GPL vmlinux 0xfaaa2ba5	usb_sg_init
++EXPORT_SYMBOL_GPL vmlinux 0xfafaa16d	fuse_abort_conn
++EXPORT_SYMBOL_GPL vmlinux 0xfb197f9a	save_stack_trace_tsk
++EXPORT_SYMBOL_GPL vmlinux 0xfb272e45	rio_release_inb_mbox
++EXPORT_SYMBOL_GPL vmlinux 0xfb32b30f	ring_buffer_read_prepare_sync
++EXPORT_SYMBOL_GPL vmlinux 0xfb555a27	unregister_pernet_subsys
++EXPORT_SYMBOL_GPL vmlinux 0xfb64b230	acpi_processor_ffh_cstate_probe
++EXPORT_SYMBOL_GPL vmlinux 0xfb6eedf9	power_group_name
++EXPORT_SYMBOL_GPL vmlinux 0xfb83aceb	usb_string
++EXPORT_SYMBOL_GPL vmlinux 0xfb83db03	cpufreq_show_cpus
++EXPORT_SYMBOL_GPL vmlinux 0xfba525dc	unregister_kretprobe
++EXPORT_SYMBOL_GPL vmlinux 0xfbc14487	eventfd_ctx_fileget
++EXPORT_SYMBOL_GPL vmlinux 0xfbe49a0b	device_remove_bin_file
++EXPORT_SYMBOL_GPL vmlinux 0xfc03d97a	page_is_ram
++EXPORT_SYMBOL_GPL vmlinux 0xfc3b4246	acpi_bus_update_power
++EXPORT_SYMBOL_GPL vmlinux 0xfc4f4953	alarm_init
++EXPORT_SYMBOL_GPL vmlinux 0xfc968c8b	apei_exec_write_register_value
++EXPORT_SYMBOL_GPL vmlinux 0xfc9a9f94	crypto_shash_update
++EXPORT_SYMBOL_GPL vmlinux 0xfc9e1e9b	crypto_unregister_ahash
++EXPORT_SYMBOL_GPL vmlinux 0xfca46cd0	acpi_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xfcadfd1b	regcache_mark_dirty
++EXPORT_SYMBOL_GPL vmlinux 0xfcb0c99a	ipv6_opt_accepted
++EXPORT_SYMBOL_GPL vmlinux 0xfcd22970	locks_alloc_lock
++EXPORT_SYMBOL_GPL vmlinux 0xfcd7bc0b	ring_buffer_empty
++EXPORT_SYMBOL_GPL vmlinux 0xfceb107d	wm831x_auxadc_read
++EXPORT_SYMBOL_GPL vmlinux 0xfd05464b	klist_add_head
++EXPORT_SYMBOL_GPL vmlinux 0xfd1c2ed8	pci_enable_pcie_error_reporting
++EXPORT_SYMBOL_GPL vmlinux 0xfd2333f6	skb_morph
++EXPORT_SYMBOL_GPL vmlinux 0xfd2395b4	usb_hcd_is_primary_hcd
++EXPORT_SYMBOL_GPL vmlinux 0xfd51b281	gnttab_end_foreign_access_ref
++EXPORT_SYMBOL_GPL vmlinux 0xfd7243c7	erst_disable
++EXPORT_SYMBOL_GPL vmlinux 0xfd7e8422	devres_alloc
++EXPORT_SYMBOL_GPL vmlinux 0xfdac929b	inet_unhash
++EXPORT_SYMBOL_GPL vmlinux 0xfdb1d935	device_show_ulong
++EXPORT_SYMBOL_GPL vmlinux 0xfdeeca42	proc_get_parent_data
++EXPORT_SYMBOL_GPL vmlinux 0xfdf26047	md_trim_bio
++EXPORT_SYMBOL_GPL vmlinux 0xfdf37886	__irq_set_handler
++EXPORT_SYMBOL_GPL vmlinux 0xfe03e342	irq_setup_generic_chip
++EXPORT_SYMBOL_GPL vmlinux 0xfe0805dc	tpm_release
++EXPORT_SYMBOL_GPL vmlinux 0xfe0c5879	get_governor_parent_kobj
++EXPORT_SYMBOL_GPL vmlinux 0xfe187cf2	efivar_entry_set
++EXPORT_SYMBOL_GPL vmlinux 0xfe2e41f0	blkdev_aio_write
++EXPORT_SYMBOL_GPL vmlinux 0xfe301480	wm831x_reg_write
++EXPORT_SYMBOL_GPL vmlinux 0xfe31a0f6	rio_map_inb_region
++EXPORT_SYMBOL_GPL vmlinux 0xfe495410	crypto_ahash_digest
++EXPORT_SYMBOL_GPL vmlinux 0xfe6ee69f	ip6_datagram_recv_ctl
++EXPORT_SYMBOL_GPL vmlinux 0xfe727411	get_phys_to_machine
++EXPORT_SYMBOL_GPL vmlinux 0xfe927caa	transport_destroy_device
++EXPORT_SYMBOL_GPL vmlinux 0xfe990052	gpio_free
++EXPORT_SYMBOL_GPL vmlinux 0xfed11ed1	usb_mon_deregister
++EXPORT_SYMBOL_GPL vmlinux 0xfeda4e1c	look_up_OID
++EXPORT_SYMBOL_GPL vmlinux 0xfeea6e8a	device_wakeup_enable
++EXPORT_SYMBOL_GPL vmlinux 0xfeeedb29	xenbus_dev_attrs
++EXPORT_SYMBOL_GPL vmlinux 0xfef8a166	trace_current_buffer_lock_reserve
++EXPORT_SYMBOL_GPL vmlinux 0xfefba31f	__mmdrop
++EXPORT_SYMBOL_GPL vmlinux 0xff05fa13	vring_interrupt
++EXPORT_SYMBOL_GPL vmlinux 0xff21507c	usb_lock_device_for_reset
++EXPORT_SYMBOL_GPL vmlinux 0xff5a8cfe	cn_del_callback
++EXPORT_SYMBOL_GPL vmlinux 0xff5b3d22	led_trigger_store
++EXPORT_SYMBOL_GPL vmlinux 0xff5c260c	power_supply_get_by_name
++EXPORT_SYMBOL_GPL vmlinux 0xff5f2b0e	__i2c_board_lock
++EXPORT_SYMBOL_GPL vmlinux 0xffb495f5	seq_release_net
++EXPORT_SYMBOL_GPL vmlinux 0xffba244b	hwmon_device_register
++EXPORT_SYMBOL_GPL vmlinux 0xffcf84cf	usb_hcd_platform_shutdown
++EXPORT_SYMBOL_GPL vmlinux 0xffe9f2cb	blk_insert_cloned_request
++EXPORT_SYMBOL_GPL vmlinux 0xfffa8c52	efivar_entry_delete
+diff --git a/debian.master/abi/3.11.0-13.20/i386/generic.compiler b/debian.master/abi/3.11.0-13.20/i386/generic.compiler
+new file mode 100644
+index 0000000..fd6ee97
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/i386/generic.compiler
+@@ -0,0 +1 @@
++GCC: (Ubuntu/Linaro 4.8.1-10ubuntu8) 4.8.1
+diff --git a/debian.master/abi/3.11.0-13.20/i386/generic.modules b/debian.master/abi/3.11.0-13.20/i386/generic.modules
+new file mode 100644
+index 0000000..424a97f
+--- /dev/null
++++ b/debian.master/abi/3.11.0-13.20/i386/generic.modules
+@@ -0,0 +1,4149 @@
++3c509
++3c515
++3c574_cs
++3c589_cs
++3c59x
++3w-9xxx
++3w-sas
++3w-xxxx
++53c700
++6lowpan
++6pack
++8021q
++8139cp
++8139too
++8250_accent
++8250_boca
++8250_dw
++8250_exar_st16c554
++8250_fourport
++8250_hub6
++8255
++8255_pci
++8390
++8390p
++88pm800
++88pm805
++88pm80x
++88pm80x_onkey
++88pm860x_battery
++88pm860x_bl
++88pm860x_charger
++88pm860x_onkey
++88pm860x-ts
++9p
++9pnet
++9pnet_rdma
++9pnet_virtio
++a100u2w
++a3d
++a8293
++aacraid
++aat2870_bl
++aat2870-regulator
++ab3100
++ab3100-otp
++abituguru
++abituguru3
++ablk_helper
++ac97_bus
++acard-ahci
++acecad
++acenic
++acerhdf
++acer-wmi
++acpi_ipmi
++acpi_pad
++acpiphp_ibm
++acpi_power_meter
++acquirewdt
++act2000
++act200l-sir
++act_csum
++act_gact
++act_ipt
++actisys-sir
++act_mirred
++act_nat
++act_pedit
++act_police
++act_simple
++act_skbedit
++ad2s1200
++ad2s1210
++ad2s90
++ad5064
++ad525x_dpot
++ad525x_dpot-i2c
++ad525x_dpot-spi
++ad5360
++ad5380
++ad5398
++ad5421
++ad5446
++ad5449
++ad5504
++ad5624r_spi
++ad5686
++ad5755
++ad5764
++ad5791
++ad5930
++ad5933
++ad714x
++ad714x-i2c
++ad714x-spi
++ad7150
++ad7152
++ad7192
++ad7266
++ad7280a
++ad7291
++ad7298
++ad7303
++ad7314
++ad7414
++ad7418
++ad7476
++ad7606
++ad7746
++ad7780
++ad7791
++ad7793
++ad7816
++ad7877
++ad7879
++ad7879-i2c
++ad7879-spi
++ad7887
++ad7923
++ad799x
++ad8366
++ad9523
++ad9832
++ad9834
++ad9850
++ad9852
++ad9910
++ad9951
++adcxx
++addi_apci_035
++addi_apci_1032
++addi_apci_1500
++addi_apci_1516
++addi_apci_1564
++addi_apci_16xx
++addi_apci_2032
++addi_apci_2200
++addi_apci_3120
++addi_apci_3501
++addi_apci_3xxx
++addi_watchdog
++ade7753
++ade7754
++ade7758
++ade7759
++ade7854
++ade7854-i2c
++ade7854-spi
++adf4350
++adfs
++adi
++adis16060
++adis16080
++adis16130
++adis16136
++adis16201
++adis16203
++adis16204
++adis16209
++adis16220
++adis16240
++adis16260
++adis16400
++adis16480
++adis_lib
++adjd_s311
++adl_pci6208
++adl_pci7x3x
++adl_pci8164
++adl_pci9111
++adl_pci9118
++adm1021
++adm1025
++adm1026
++adm1029
++adm1031
++adm1275
++adm8211
++adm9240
++adp5520_bl
++adp5520-keys
++adp5588-keys
++adp5589-keys
++adp8860_bl
++adp8870_bl
++adq12b
++ads1015
++ads7828
++ads7846
++ads7871
++ad_sigma_delta
++adt7310
++adt7316
++adt7316-i2c
++adt7316-spi
++adt7410
++adt7411
++adt7462
++adt7470
++adt7475
++adt7x10
++adummy
++adutux
++adv7170
++adv7175
++adv7180
++advansys
++advantechwdt
++adv_pci1710
++adv_pci1723
++adv_pci1724
++adv_pci_dio
++adxl34x
++adxl34x-i2c
++adxl34x-spi
++adxrs450
++aes-i586
++aesni-intel
++af_802154
++af9013
++af9033
++af_alg
++affs
++af_key
++af_packet_diag
++af-rxrpc
++ah4
++ah6
++aha152x
++aha152x_cs
++aha1542
++aha1740
++ahci
++ahci_imx
++ahci_platform
++aic79xx
++aic7xxx
++aic94xx
++aio_aio12_8
++aio_iiro_16
++aiptek
++aircable
++airo
++airo_cs
++ak8975
++alauda
++algif_hash
++algif_skcipher
++ali-agp
++ali-ircc
++alim1535_wdt
++alim7101_wdt
++alphatrack
++altera-ci
++altera_jtaguart
++altera_ps2
++altera-stapl
++altera_uart
++alx
++ambassador
++amc6821
++amd5536udc
++amd76x_edac
++amd76xrom
++amd8111e
++amd_freq_sensitivity
++amd-rng
++amilo-rfkill
++amplc_dio200
++amplc_dio200_common
++amplc_dio200_pci
++amplc_pc236
++amplc_pc263
++amplc_pci224
++amplc_pci230
++amplc_pci263
++ams369fg06
++analog
++anatop-regulator
++ansi_cprng
++anubis
++aoe
++apanel
++apds9802als
++apds990x
++apm
++apple_bl
++appledisplay
++apple-gmux
++applesmc
++appletalk
++appletouch
++applicom
++ar5523
++ar7part
++arc4
++arcfb
++arcmsr
++arcnet
++arc_ps2
++arc-rawmode
++arc-rimi
++arc_uart
++arizona-haptics
++arizona-i2c
++arizona-ldo1
++arizona-micsupp
++arizona-spi
++ark3116
++arkfb
++arptable_filter
++arp_tables
++arpt_mangle
++as3711_bl
++as3711-regulator
++as5011
++asb100
++asc7621
++asix
++ast
++asus_atk0110
++asus-laptop
++asus-nb-wmi
++asus_oled
++asus-wmi
++async_memcpy
++async_pq
++async_raid6_recov
++async_tx
++async_xor
++at24
++at25
++at76c50x-usb
++at86rf230
++at91_ether
++atbm8830
++aten
++ath
++ath10k_core
++ath10k_pci
++ath3k
++ath5k
++ath6kl_core
++ath6kl_sdio
++ath6kl_usb
++ath9k
++ath9k_common
++ath9k_htc
++ath9k_hw
++ati-agp
++ati_remote
++ati_remote2
++atl1
++atl1c
++atl1e
++atl2
++atlas_btns
++atm
++atmel
++atmel_cs
++atmel_mxt_ts
++atmel_pci
++atmel_pwm
++atmel-pwm-bl
++atmel-ssc
++atmtcp
++atp
++atp870u
++atxp1
++aty128fb
++atyfb
++au0828
++au8522_common
++au8522_decoder
++au8522_dig
++aufs
++auo_k1900fb
++auo_k1901fb
++auo_k190x
++auo-pixcir-ts
++authenc
++authencesn
++auth_rpcgss
++autofs4
++avma1_cs
++avm_cs
++avmfritz
++ax25
++ax88179_178a
++axnet_cs
++b1
++b1dma
++b1isa
++b1pci
++b1pcmcia
++b2c2-flexcop
++b2c2-flexcop-pci
++b2c2-flexcop-usb
++b43
++b43legacy
++b44
++bas_gigaset
++batman-adv
++baycom_epp
++baycom_par
++baycom_ser_fdx
++baycom_ser_hdx
++bcache
++bch
++bcm203x
++bcm3510
++bcm5974
++bcma
++bcma-hcd
++bcm_wimax
++be2iscsi
++be2net
++befs
++belkin_sa
++bfa
++bfs
++bfusb
++bh1770glc
++bh1780gli
++binfmt_aout
++binfmt_misc
++block2mtd
++blocklayoutdriver
++blowfish_common
++blowfish_generic
++bluecard_cs
++bluetooth
++bma150
++bmp085-i2c
++bmp085-spi
++bna
++bnep
++bnx2
++bnx2fc
++bnx2i
++bnx2x
++bonding
++bpa10x
++bpck
++bpck6
++bpctl_mod
++bpqether
++bq2415x_charger
++bq27x00_battery
++br2684
++brcmfmac
++brcmsmac
++brcmutil
++bridge
++broadsheetfb
++bsd_comp
++bt3c_cs
++bt819
++bt856
++bt866
++bt878
++btcx-risc
++btmrvl
++btmrvl_sdio
++btmtk_usb
++btrfs
++btsdio
++bttv
++btuart_cs
++btusb
++btwilink
++bu21013_ts
++budget
++budget-av
++budget-ci
++budget-core
++budget-patch
++BusLogic
++bw-qcam
++bypass
++c101
++c2port-duramar2150
++c4
++c67x00
++c6xdigio
++cachefiles
++cafe_ccic
++cafe_nand
++caif
++caif_hsi
++caif_serial
++caif_socket
++caif_usb
++caif_virtio
++camellia_generic
++can
++can-bcm
++can-dev
++can-gw
++can-raw
++capi
++capidrv
++capmode
++carl9170
++carminefb
++cassini
++cast5_generic
++cast6_generic
++cast_common
++catc
++cb710
++cb710-mmc
++cb_das16_cs
++cb_pcidas
++cb_pcidas64
++cb_pcidda
++cb_pcimdas
++cb_pcimdda
++cc770
++cc770_isa
++cc770_platform
++c_can
++c_can_pci
++c_can_platform
++cciss
++ccm
++cdc-acm
++cdc_eem
++cdc_ether
++cdc_mbim
++cdc_ncm
++cdc-phonet
++cdc_subset
++cdc-wdm
++cedusb
++ceph
++cfag12864b
++cfag12864bfb
++cfg80211
++cfi_cmdset_0001
++cfi_cmdset_0002
++cfi_cmdset_0020
++cfi_probe
++cfi_util
++cfspi_slave
++ch
++ch341
++ch7006
++chipreg
++chnl_net
++chromeos_laptop
++cifs
++ci_hdrc
++ci_hdrc_msm
++ci_hdrc_pci
++cirrus
++cirrusfb
++ck804xrom
++classmate-laptop
++clearpad_tm1217
++clip
++clk-max77686
++clk-si5351
++clk-twl6040
++clk-wm831x
++cls_basic
++cls_cgroup
++cls_flow
++cls_fw
++cls_route
++cls_rsvp
++cls_rsvp6
++cls_tcindex
++cls_u32
++cm109
++cm4000_cs
++cm4040_cs
++cma3000_d0x
++cma3000_d0x_i2c
++cmac
++cmdlinepart
++cmtp
++cnic
++cobra
++coda
++com20020
++com20020_cs
++com20020-isa
++com20020-pci
++com90io
++com90xx
++comedi
++comedi_bond
++comedi_fc
++comedi_parport
++comedi_test
++comm
++compal-laptop
++configfs
++contec_pci_dio
++cops
++cordic
++core
++coretemp
++cosa
++cp210x
++cpcihp_generic
++cpcihp_zt5550
++cpia2
++cpqarray
++cpqphp
++cpu5wdt
++cpuid
++cpu-notifier-error-inject
++c-qcam
++cramfs
++cr_bllcd
++crc32
++crc32-pclmul
++crc7
++crc8
++crc-ccitt
++crc-itu-t
++cros_ec
++cros_ec_i2c
++cros_ec_keyb
++cros_ec_spi
++crvml
++cryptd
++cryptoloop
++crypto_null
++crypto_user
++crystalhd
++cs5345
++cs53l32a
++cs5535-mfd
++cs553x_nand
++cs89x0
++csiostor
++ct82c710
++ctr
++cts
++cuse
++cw1200_core
++cw1200_wlan_sdio
++cw1200_wlan_spi
++cx18
++cx18-alsa
++cx22700
++cx22702
++cx231xx
++cx231xx-alsa
++cx231xx-dvb
++cx2341x
++cx23885
++cx24110
++cx24113
++cx24116
++cx24123
++cx25821
++cx25821-alsa
++cx25840
++cx82310_eth
++cx8800
++cx8802
++cx88-alsa
++cx88-blackbird
++cx88-dvb
++cx88-vp3054-i2c
++cx88xx
++cxacru
++cxd2099
++cxd2820r
++cxgb
++cxgb3
++cxgb3i
++cxgb4
++cxgb4i
++cxgb4vf
++cxt1e1
++cy8ctmg110_ts
++cyapa
++cyber2000fb
++cyberjack
++cyclades
++cypress_cy7c63
++cypress_firmware
++cypress_m8
++cytherm
++cyttsp4_core
++cyttsp4_i2c
++cyttsp4_spi
++cyttsp_core
++cyttsp_i2c
++cyttsp_i2c_common
++cyttsp_spi
++da9030_battery
++da9034-ts
++da903x
++da903x_bl
++da9052-battery
++da9052_bl
++da9052-hwmon
++da9052_onkey
++da9052-regulator
++da9052_tsi
++da9052_wdt
++da9055-hwmon
++da9055_onkey
++da9055-regulator
++da9055_wdt
++DAC960
++daqboard2000
++das08
++das08_cs
++das08_isa
++das08_pci
++das16
++das16m1
++das1800
++das6402
++das800
++db9
++dc395x
++dca
++dccp
++dccp_diag
++dccp_ipv4
++dccp_ipv6
++dccp_probe
++dcdbas
++ddbridge
++de2104x
++de4x5
++decnet
++deflate
++defxx
++dell-laptop
++dell-led
++dell_rbu
++dell-wmi
++dell-wmi-aio
++denali
++denali_dt
++denali_pci
++des_generic
++designware_i2s
++dgrp
++dib0070
++dib0090
++dib3000mb
++dib3000mc
++dib7000m
++dib7000p
++dib8000
++dibx000_common
++digi_acceleport
++diskonchip
++divacapi
++divadidd
++diva_idi
++diva_mnt
++divas
++dl2k
++dlci
++dlm
++dm1105
++dm9601
++dm-bio-prison
++dm-bufio
++dm-cache
++dm-cache-cleaner
++dm-cache-mq
++dm-crypt
++dm-delay
++dme1737
++dmfe
++dm-flakey
++dmi-sysfs
++dm-log
++dm-log-userspace
++dmm32at
++dm-mirror
++dm-multipath
++dm-persistent-data
++dm-queue-length
++dm-raid
++dm-raid45
++dm-region-hash
++dm-round-robin
++dm-service-time
++dm-snapshot
++dm-switch
++dm-thin-pool
++dm-verity
++dmx3191d
++dm-zero
++dnet
++dn_rtmsg
++docg3
++docg4
++donauboe
++dpt_i2o
++drbd
++drm
++drm_kms_helper
++drm_usb
++drxd
++drxk
++ds1621
++ds1682
++ds1wm
++ds2482
++ds2490
++ds2760_battery
++ds2780_battery
++ds2781_battery
++ds2782_battery
++ds3000
++ds620
++dsa_core
++dsbr100
++dscc4
++dss1_divert
++dst
++dst_ca
++dstr
++dt2801
++dt2811
++dt2814
++dt2815
++dt2817
++dt282x
++dt3000
++dt3155v4l
++dt9812
++dtc
++dtl1_cs
++dtlk
++dummy
++dummy-irq
++dvb-as102
++dvb-bt8xx
++dvb-core
++dvb-pll
++dvb-ttpci
++dvb-ttusb-budget
++dvb-usb
++dvb-usb-a800
++dvb-usb-af9005
++dvb-usb-af9005-remote
++dvb-usb-af9015
++dvb-usb-af9035
++dvb-usb-anysee
++dvb-usb-au6610
++dvb-usb-az6007
++dvb-usb-az6027
++dvb-usb-ce6230
++dvb-usb-cinergyT2
++dvb-usb-cxusb
++dvb-usb-dib0700
++dvb-usb-dibusb-common
++dvb-usb-dibusb-mb
++dvb-usb-dibusb-mc
++dvb-usb-digitv
++dvb-usb-dtt200u
++dvb-usb-dtv5100
++dvb-usb-dw2102
++dvb-usb-ec168
++dvb-usb-friio
++dvb-usb-gl861
++dvb-usb-gp8psk
++dvb-usb-it913x
++dvb-usb-lmedm04
++dvb-usb-m920x
++dvb-usb-mxl111sf
++dvb-usb-nova-t-usb2
++dvb-usb-opera
++dvb-usb-pctv452e
++dvb-usb-rtl28xxu
++dvb-usb-technisat-usb2
++dvb-usb-ttusb2
++dvb-usb-umt-010
++dvb_usb_v2
++dvb-usb-vp702x
++dvb-usb-vp7045
++dwc2
++dwc2_pci
++dwc2_platform
++dwc3
++dwc3-exynos
++dwc3-omap
++dwc3-pci
++dw_dmac
++dw_dmac_core
++dw_dmac_pci
++dyna_pci10xx
++dynapro
++e100
++e1000
++e1000e
++e4000
++e752x_edac
++e7xxx_edac
++earth-pt1
++eata
++ebt_802_3
++ebtable_broute
++ebtable_filter
++ebtable_nat
++ebtables
++ebt_among
++ebt_arp
++ebt_arpreply
++ebt_dnat
++ebt_ip
++ebt_ip6
++ebt_limit
++ebt_log
++ebt_mark
++ebt_mark_m
++ebt_nflog
++ebt_pkttype
++ebt_redirect
++ebt_snat
++ebt_stp
++ebt_vlan
++ec100
++echo
++ec_sys
++edac_core
++edac_mce_amd
++edt-ft5x06
++eeepc-laptop
++eeepc-wmi
++eeprom
++eeprom_93cx6
++eeprom_93xx46
++eeti_ts
++efficeon-agp
++efi-pstore
++efs
++einj
++elo
++elsa_cs
++em28xx
++em28xx-alsa
++em28xx-dvb
++em28xx-rc
++emc1403
++emc2103
++emc6w201
++em_canid
++em_cmp
++emi26
++emi62
++em_ipset
++em_meta
++em_nbyte
++empeg
++ems_pci
++ems_pcmcia
++ems_usb
++em_text
++emu10k1-gp
++em_u32
++enc28j60
++enclosure
++ene_ir
++eni
++enic
++epat
++epia
++epic100
++eql
++esb2rom
++esd_usb2
++esi-sir
++esp4
++esp6
++et131x
++ethoc
++eurotechwdt
++evbug
++exofs
++ext2
++extcon-adc-jack
++extcon-arizona
++extcon-gpio
++extcon-max77693
++extcon-max8997
++extcon-palmas
++exynos-rng
++ezusb
++f2fs
++f71805f
++f71808e_wdt
++f71882fg
++f75375s
++f81232
++fakelb
++fam15h_power
++fan53555
++farsync
++faulty
++fb_ddc
++fb_sys_fops
++fc0011
++fc0012
++fc0013
++fc2580
++fcoe
++fcrypt
++fdomain
++fdomain_cs
++fealnx
++ff-memless
++fintek-cir
++firedtv
++firestream
++firewire-core
++firewire-net
++firewire-ohci
++firewire-sbp2
++firewire-serial
++fit2
++fit3
++fixed
++fl512
++flashloader
++floppy
++fm801-gp
++fmc
++fmc-chardev
++fmc-fakedev
++fmc-trivial
++fmc-write-eeprom
++fm_drv
++fmvj18x_cs
++fnic
++forcedeth
++fore_200e
++fotg210-udc
++freevxfs
++friq
++frpw
++fsa9480
++fscache
++fschmd
++fsl_lpuart
++ft1000
++ft1000_pcmcia
++ftdi-elan
++ftdi_sio
++ftl
++fujitsu-laptop
++fujitsu-tablet
++fujitsu_ts
++funsoft
++fusbh200-hcd
++g450_pll
++g760a
++g762
++g_acm_ms
++gadgetfs
++gamecon
++gameport
++garmin_gps
++garp
++g_audio
++g_cdc
++gcm
++g_dbgp
++gdmwm
++gdth
++generic
++generic-adc-battery
++generic_bl
++gen_probe
++geode-aes
++geode-rng
++g_ether
++gf128mul
++gf2k
++g_ffs
++gfs2
++ghash-generic
++g_hid
++gigaset
++girbil-sir
++gl518sm
++gl520sm
++gl620a
++gluebi
++glue_helper
++gma500_gfx
++g_mass_storage
++g_midi
++g_ncm
++g_NCR5380
++g_NCR5380_mmio
++g_nokia
++go7007
++go7007-loader
++go7007-usb
++goku_udc
++goldfish_battery
++goldfishfb
++gp2ap002a00f
++gpio-74x164
++gpio-addr-flash
++gpio-adp5520
++gpio-adp5588
++gpio-amd8111
++gpio-arizona
++gpio-charger
++gpio-cs5535
++gpio-da9052
++gpio-da9055
++gpio-fan
++gpio-generic
++gpio-ich
++gpio-ir-recv
++gpio-it8761e
++gpio-janz-ttl
++gpio_keys
++gpio_keys_polled
++gpio-max7300
++gpio-max7301
++gpio-max730x
++gpio-max732x
++gpio-mc33880
++gpio-mcp23s08
++gpio-ml-ioh
++gpio_mouse
++gpio-pca953x
++gpio-pcf857x
++gpio-pch
++gpio-rdc321x
++gpio-regulator
++gpio-sch
++gpio_tilt_polled
++gpio-tps65912
++gpio-ts5500
++gpio-twl6040
++gpio-viperboard
++gpio-vx855
++gpio-wm831x
++gpio-wm8350
++gpio-wm8994
++g_printer
++gre
++grip
++grip_mp
++gsc_hpdi
++g_serial
++gspca_benq
++gspca_conex
++gspca_cpia1
++gspca_etoms
++gspca_finepix
++gspca_gl860
++gspca_jeilinj
++gspca_jl2005bcd
++gspca_kinect
++gspca_konica
++gspca_m5602
++gspca_main
++gspca_mars
++gspca_mr97310a
++gspca_nw80x
++gspca_ov519
++gspca_ov534
++gspca_ov534_9
++gspca_pac207
++gspca_pac7302
++gspca_pac7311
++gspca_se401
++gspca_sn9c2028
++gspca_sn9c20x
++gspca_sonixb
++gspca_sonixj
++gspca_spca1528
++gspca_spca500
++gspca_spca501
++gspca_spca505
++gspca_spca506
++gspca_spca508
++gspca_spca561
++gspca_sq905
++gspca_sq905c
++gspca_sq930x
++gspca_stk014
++gspca_stv0680
++gspca_stv06xx
++gspca_sunplus
++gspca_t613
++gspca_topro
++gspca_tv8532
++gspca_vc032x
++gspca_vicam
++gspca_xirlink_cit
++gspca_zc3xx
++gtco
++guillemot
++gunze
++g_webcam
++gx1fb
++gxfb
++gx-suspmod
++g_zero
++hamachi
++hampshire
++hangcheck-timer
++hanwang
++hci
++hci_uart
++hci_vhci
++hdaps
++hdlc
++hdlc_cisco
++hdlcdrv
++hdlc_fr
++hdlc_ppp
++hdlc_raw
++hdlc_raw_eth
++hdlc_x25
++hdpvr
++he
++hecubafb
++hexium_gemini
++hexium_orion
++hfc4s8s_l1
++hfcmulti
++hfcpci
++hfcsusb
++hfc_usb
++hfs
++hfsplus
++hgafb
++hid
++hid-a4tech
++hid-apple
++hid-appleir
++hid-aureal
++hid-axff
++hid-belkin
++hid-cherry
++hid-chicony
++hid-cypress
++hid-dr
++hid-elecom
++hid-elo
++hid-emsff
++hid-ezkey
++hid-gaff
++hid-generic
++hid-gyration
++hid-holtekff
++hid-holtek-kbd
++hid-holtek-mouse
++hid-huion
++hid-hyperv
++hid-icade
++hid-kensington
++hid-keytouch
++hid-kye
++hid-lcpower
++hid-lenovo-tpkbd
++hid-logitech
++hid-logitech-dj
++hid-magicmouse
++hid-microsoft
++hid-monterey
++hid-multitouch
++hid-ntrig
++hid-ortek
++hidp
++hid-petalynx
++hid-picolcd
++hid-pl
++hid-primax
++hid-prodikeys
++hid-roccat
++hid-roccat-arvo
++hid-roccat-common
++hid-roccat-isku
++hid-roccat-kone
++hid-roccat-koneplus
++hid-roccat-konepure
++hid-roccat-kovaplus
++hid-roccat-lua
++hid-roccat-pyra
++hid-roccat-savu
++hid-saitek
++hid-samsung
++hid-sensor-accel-3d
++hid-sensor-als
++hid-sensor-gyro-3d
++hid-sensor-hub
++hid-sensor-iio-common
++hid-sensor-magn-3d
++hid-sensor-trigger
++hid-sjoy
++hid-sony
++hid-speedlink
++hid-steelseries
++hid-sunplus
++hid-thingm
++hid-tivo
++hid-tmff
++hid-topseed
++hid-twinhan
++hid-uclogic
++hid-wacom
++hid-waltop
++hid-wiimote
++hid-zpff
++hid-zydacron
++hih6130
++hisax
++hisax_fcpcipnp
++hisax_isac
++hisax_st5481
++hmc5843
++hmc6352
++hopper
++horizon
++hostap
++hostap_cs
++hostap_pci
++hostap_plx
++hostess_sv11
++hp100
++hp4x
++hp_accel
++hpfs
++hpilo
++hpsa
++hptiop
++hpwdt
++hp-wmi
++hsi
++hsi_char
++hso
++htc-pasic3
++htcpen
++hv_balloon
++hv_netvsc
++hv_storvsc
++hv_utils
++hv_vmbus
++hwa-hc
++hwa-rc
++hwmon-vid
++hwpoison-inject
++hx8357
++hyperv_fb
++hysdn
++i1480-dfu-usb
++i1480-est
++i2400m
++i2400m-usb
++i2c-algo-bit
++i2c-algo-pca
++i2c-ali1535
++i2c-ali1563
++i2c-ali15x3
++i2c-amd756
++i2c-amd756-s4882
++i2c-amd8111
++i2c-cbus-gpio
++i2c-designware-core
++i2c-designware-pci
++i2c-designware-platform
++i2c-dev
++i2c-diolan-u2c
++i2c-eg20t
++i2c-gpio
++i2c-hid
++i2c-i801
++i2c-isch
++i2c-ismt
++i2c-kempld
++i2c-matroxfb
++i2c-mux
++i2c-mux-gpio
++i2c-mux-pca9541
++i2c-mux-pca954x
++i2c-nforce2
++i2c-nforce2-s4985
++i2c-ocores
++i2c-parport
++i2c-parport-light
++i2c-pca-isa
++i2c-pca-platform
++i2c-piix4
++i2c-scmi
++i2c-simtec
++i2c-sis5595
++i2c-sis630
++i2c-sis96x
++i2c-smbus
++i2c-stub
++i2c-taos-evm
++i2c-tiny-usb
++i2c-via
++i2c-viapro
++i2c-viperboard
++i2c-xiic
++i2o_block
++i2o_bus
++i2o_config
++i2o_core
++i2o_proc
++i2o_scsi
++i3000_edac
++i3200_edac
++i5000_edac
++i5100_edac
++i5400_edac
++i5k_amb
++i6300esb
++i7300_edac
++i740fb
++i7core_edac
++i810
++i810fb
++i82092
++i82365
++i82860_edac
++i82875p_edac
++i82975x_edac
++i8k
++i915
++ib700wdt
++ib_addr
++ib_cm
++ib_core
++ib_ipoib
++ib_iser
++ib_isert
++ib_mad
++ibmaem
++ibmasm
++ibmasr
++ibmpex
++ibmphp
++ibm_rtl
++ib_mthca
++ib_sa
++ib_srp
++ib_srpt
++ib_ucm
++ib_umad
++ib_uverbs
++ichxrom
++icn
++icp_multi
++ics932s401
++ideapad-laptop
++idmouse
++idt77252
++ie6xx_wdt
++ieee802154
++ifb
++iforce
++igb
++igbvf
++iguanair
++iio_dummy
++iio_hwmon
++iio-trig-interrupt
++iio-trig-periodic-rtc
++iio-trig-sysfs
++ii_pci20kc
++ili210x
++ili922x
++ili9320
++imm
++imon
++ims-pcu
++imx074
++in2000
++ina209
++ina2xx
++industrialio
++industrialio-triggered-buffer
++inet_diag
++inexio
++inftl
++initio
++input-polldev
++int51x1
++intelfb
++intel_ips
++intel_menlow
++intel_mid_battery
++intel_mid_dma
++intel_mid_powerbtn
++intel_mid_thermal
++intel-mid-touch
++intel_oaktrail
++intel_powerclamp
++intel-rng
++intel-rst
++intel_scu_ipcutil
++intel-smartconnect
++intel_vr_nor
++interact
++interval_tree_test
++inv-mpu6050
++ioatdma
++ioc4
++io_edgeport
++io_ti
++iowarrior
++ip6_gre
++ip6table_filter
++ip6table_mangle
++ip6table_nat
++ip6table_raw
++ip6_tables
++ip6table_security
++ip6t_ah
++ip6t_eui64
++ip6t_frag
++ip6t_hbh
++ip6t_ipv6header
++ip6t_MASQUERADE
++ip6t_mh
++ip6t_NPT
++ip6t_REJECT
++ip6t_rpfilter
++ip6t_rt
++ip6_tunnel
++ipack
++ipaq
++ipcomp
++ipcomp6
++ipddp
++ipg
++ip_gre
++iphase
++ipheth
++ipip
++ipmi_devintf
++ipmi_msghandler
++ipmi_poweroff
++ipmi_si
++ipmi_watchdog
++ipoctal
++ipr
++ips
++ip_set
++ip_set_bitmap_ip
++ip_set_bitmap_ipmac
++ip_set_bitmap_port
++ip_set_hash_ip
++ip_set_hash_ipport
++ip_set_hash_ipportip
++ip_set_hash_ipportnet
++ip_set_hash_net
++ip_set_hash_netiface
++ip_set_hash_netport
++ip_set_list_set
++iptable_filter
++iptable_mangle
++iptable_nat
++iptable_raw
++ip_tables
++iptable_security
++ipt_ah
++ipt_CLUSTERIP
++ipt_ECN
++ipt_MASQUERADE
++ipt_REJECT
++ipt_rpfilter
++ipt_ULOG
++ip_tunnel
++ip_vs
++ip_vs_dh
++ip_vs_ftp
++ip_vs_lblc
++ip_vs_lblcr
++ip_vs_lc
++ip_vs_nq
++ip_vs_pe_sip
++ip_vs_rr
++ip_vs_sed
++ip_vs_sh
++ip_vs_wlc
++ip_vs_wrr
++ip_vti
++ipw
++ipw2100
++ipw2200
++ipwireless
++ipx
++ircomm
++ircomm-tty
++irda
++irda-usb
++iris
++ir-jvc-decoder
++ir-kbd-i2c
++irlan
++ir-lirc-codec
++ir-mce_kbd-decoder
++ir-nec-decoder
++irnet
++ir-rc5-decoder
++ir-rc5-sz-decoder
++ir-rc6-decoder
++ir-sanyo-decoder
++ir-sony-decoder
++irtty-sir
++ir-usb
++isci
++iscsi_boot_sysfs
++iscsi_ibft
++iscsi_target_mod
++iscsi_tcp
++isdn
++isdn_bsdcomp
++isdnhdlc
++isicom
++isight_firmware
++isl29003
++isl29018
++isl29020
++isl29028
++isl6271a-regulator
++isl6405
++isl6421
++isl6423
++isofs
++isp116x-hcd
++isp1362-hcd
++isp1704_charger
++isp1760
++it87
++it8712f_wdt
++it87_wdt
++it913x-fe
++iTCO_vendor_support
++iTCO_wdt
++itd1000
++ite-cir
++itg3200
++iuu_phoenix
++ivtv
++ivtv-alsa
++ivtvfb
++iw_c2
++iw_cm
++iw_cxgb3
++iw_cxgb4
++iwl3945
++iwl4965
++iwldvm
++iwlegacy
++iwlmvm
++iwlwifi
++iw_nes
++ix2505v
++ixgb
++ixgbe
++ixgbevf
++janz-cmodio
++janz-ican3
++jc42
++jedec_probe
++jffs2
++jfs
++jmb38x_ms
++jme
++joydev
++joydump
++jr3_pci
++jsm
++k10temp
++k8temp
++kafs
++kalmia
++kaweth
++kb3886_bl
++kbic
++kbtab
++kcomedilib
++ke_counter
++kempld-core
++kempld_wdt
++kernelcapi
++keucr
++keyspan
++keyspan_pda
++keyspan_remote
++kfifo_buf
++khazad
++kingsun-sir
++kl5kusb105
++kobil_sct
++ks0108
++ks0127
++ks8842
++ks8851
++ks8851_mll
++ks959-sir
++ksdazzle-sir
++ksz884x
++ktti
++kvaser_pci
++kvaser_usb
++kvm
++kvm-amd
++kvm-intel
++kxsd9
++kxtj9
++kyrofb
++l1oip
++l2tp_core
++l2tp_debugfs
++l2tp_eth
++l2tp_ip
++l2tp_ip6
++l2tp_netlink
++l2tp_ppp
++l440gx
++l4f00242t03
++l64781
++lanai
++lance
++lapb
++lapbether
++latch-addr-flash
++lattice-ecp3-config
++lcd
++ld9040
++ldusb
++lec
++leds-88pm860x
++leds-adp5520
++leds-atmel-pwm
++leds-bd2802
++leds-blinkm
++leds-clevo-mail
++leds-da903x
++leds-da9052
++leds-dac124s085
++leds-gpio
++leds-lm3530
++leds-lm3533
++leds-lm355x
++leds-lm3642
++leds-lp3944
++leds-lp5521
++leds-lp5523
++leds-lp5562
++leds-lp55xx-common
++leds-lp8788
++leds-lt3593
++leds-max8997
++leds-mc13783
++leds-net48xx
++leds-ot200
++leds-pca9532
++leds-pca955x
++leds-pca9633
++leds-pwm
++leds-regulator
++leds-ss4200
++leds-tca6507
++leds-wm831x-status
++leds-wm8350
++leds-wrap
++ledtrig-backlight
++ledtrig-camera
++ledtrig-default-on
++ledtrig-gpio
++ledtrig-heartbeat
++ledtrig-oneshot
++ledtrig-timer
++ledtrig-transient
++legousbtower
++lg2160
++lgdt3305
++lgdt330x
++lgs8gxx
++lg-vl600
++lib80211
++lib80211_crypt_ccmp
++lib80211_crypt_tkip
++lib80211_crypt_wep
++libahci
++libceph
++libcomposite
++libcrc32c
++libcxgbi
++libertas
++libertas_cs
++libertas_sdio
++libertas_spi
++libertas_tf
++libertas_tf_usb
++libfc
++libfcoe
++libipw
++libiscsi
++libiscsi_tcp
++libore
++libosd
++libsas
++libsrp
++lightning
++line6usb
++lineage-pem
++linear
++lirc_bt829
++lirc_dev
++lirc_igorplugusb
++lirc_imon
++lirc_parallel
++lirc_sasem
++lirc_serial
++lirc_sir
++lirc_zilog
++lis3l02dq
++lis3lv02d
++lis3lv02d_i2c
++litelink-sir
++lkkbd
++llc
++llc2
++lm25066
++lm3533-als
++lm3533_bl
++lm3533-core
++lm3533-ctrlbank
++lm3630_bl
++lm3639_bl
++lm63
++lm70
++lm73
++lm75
++lm77
++lm78
++lm80
++lm83
++lm8323
++lm8333
++lm85
++lm87
++lm90
++lm92
++lm93
++lm95234
++lm95241
++lm95245
++lmc
++lms283gf05
++lms501kf03
++lnbp21
++lnbp22
++lockd
++logibm
++longhaul
++longrun
++lp
++lp3971
++lp3972
++lp855x_bl
++lp8727_charger
++lp8755
++lp8788_bl
++lp8788-charger
++lpc_ich
++lpc_sch
++lpddr_cmds
++lpfc
++lru_cache
++lrw
++ltc2978
++ltc4151
++ltc4215
++ltc4245
++ltc4261
++ltpc
++lttng-ftrace
++lttng-kprobes
++lttng-kretprobes
++lttng-lib-ring-buffer
++lttng-probe-asoc
++lttng-probe-block
++lttng-probe-btrfs
++lttng-probe-compaction
++lttng-probe-ext3
++lttng-probe-ext4
++lttng-probe-gpio
++lttng-probe-irq
++lttng-probe-jbd
++lttng-probe-jbd2
++lttng-probe-kmem
++lttng-probe-kvm
++lttng-probe-kvm-x86
++lttng-probe-kvm-x86-mmu
++lttng-probe-module
++lttng-probe-napi
++lttng-probe-net
++lttng-probe-power
++lttng-probe-printk
++lttng-probe-random
++lttng-probe-rcu
++lttng-probe-regmap
++lttng-probe-regulator
++lttng-probe-rpm
++lttng-probe-sched
++lttng-probe-scsi
++lttng-probe-signal
++lttng-probe-skb
++lttng-probe-sock
++lttng-probe-statedump
++lttng-probe-sunrpc
++lttng-probe-timer
++lttng-probe-udp
++lttng-probe-vmscan
++lttng-probe-workqueue
++lttng-probe-writeback
++lttng-ring-buffer-client-discard
++lttng-ring-buffer-client-mmap-discard
++lttng-ring-buffer-client-mmap-overwrite
++lttng-ring-buffer-client-overwrite
++lttng-ring-buffer-metadata-client
++lttng-ring-buffer-metadata-mmap-client
++lttng-statedump
++lttng-tracer
++lttng-types
++ltv350qv
++lxfb
++lz4
++lz4_compress
++lz4hc
++lz4hc_compress
++m25p80
++m2m-deinterlace
++m52790
++m88rs2000
++ma600-sir
++mac80211
++mac80211_hwsim
++mac802154
++macb
++mac-celtic
++mac-centeuro
++mac-croatian
++mac-cyrillic
++mac-gaelic
++mac-greek
++mac_hid
++machzwd
++mac-iceland
++mac-inuit
++macmodes
++mac-roman
++mac-romanian
++mac-turkish
++macvlan
++macvtap
++magellan
++mantis
++mantis_core
++map_absent
++map_funcs
++map_ram
++map_rom
++matrix-keymap
++matrix_keypad
++matroxfb_accel
++matroxfb_base
++matroxfb_crtc2
++matroxfb_DAC1064
++matroxfb_g450
++matroxfb_maven
++matroxfb_misc
++matroxfb_Ti3026
++matrox_w1
++max1111
++max11801_ts
++max1363
++max1586
++max16064
++max16065
++max1619
++max1668
++max17040_battery
++max17042_battery
++max197
++max2165
++max3100
++max34440
++max517
++max6639
++max6642
++max6650
++max6697
++max6875
++max7359_keypad
++max77686
++max77693
++max8649
++max8660
++max8688
++max8903_charger
++max8907
++max8907-regulator
++max8925_bl
++max8925_onkey
++max8925_power
++max8925-regulator
++max8952
++max8973-regulator
++max8997
++max8997_charger
++max8998
++max8998_charger
++mb862xxfb
++mb86a16
++mb86a20s
++mc13783-adc
++mc13783-pwrbutton
++mc13783-regulator
++mc13783_ts
++mc13892-regulator
++mc13xxx-core
++mc13xxx-i2c
++mc13xxx-regulator-core
++mc13xxx-spi
++mc44s803
++mce_amd_inj
++mce-inject
++mceusb
++mcp2120-sir
++mcp251x
++mcp3021
++mcp320x
++mcp4725
++mcs5000_ts
++mcs7780
++mcs7830
++mcs_touchkey
++mct_u232
++md4
++mdacon
++mdc800
++mdio
++me4000
++me_daq
++megaraid
++megaraid_mbox
++megaraid_mm
++megaraid_sas
++mei
++mei-me
++mei_phy
++mem2mem_testdev
++memstick
++mena21_wdt
++metronomefb
++metro-usb
++meye
++mfd
++mga
++michael_mic
++microcode
++microread
++microread_i2c
++microread_mei
++microtek
++mii
++minix
++mip6
++mISDN_core
++mISDN_dsp
++mISDNinfineon
++mISDNipac
++mISDNisar
++mite
++mixcomwd
++mk712
++mkiss
++mlx4_core
++mlx4_en
++mlx4_ib
++mlx5_core
++mlx5_ib
++mma8450
++mmc_block
++mms114
++mos7720
++mos7840
++moto_modem
++moxa
++mpc624
++mpoa
++mpr121_touchkey
++mpt2sas
++mpt3sas
++mptbase
++mptctl
++mptfc
++mptlan
++mptsas
++mptscsih
++mptspi
++mpu3050
++mrf24j40
++mrp
++mrst_max3110
++msdos
++msi-laptop
++msi-wmi
++msp3400
++mspro_block
++msr
++mt2060
++mt2063
++mt20xx
++mt2131
++mt2266
++mt312
++mt352
++mt9m001
++mt9m111
++mt9t031
++mt9t112
++mt9v011
++mt9v022
++mtd
++mtd_blkdevs
++mtdblock
++mtdblock_ro
++mtd_dataflash
++mtdoops
++mtdram
++mtdswap
++mtip32xx
++mtouch
++multipath
++multiq3
++musb_hdrc
++mv88e6060
++mv88e6xxx_drv
++mvmdio
++mvsas
++mv_u3d_core
++mv_udc
++mvumi
++mwave
++mwifiex
++mwifiex_pcie
++mwifiex_sdio
++mwifiex_usb
++mwl8k
++mxb
++mxl111sf-demod
++mxl111sf-tuner
++mxl5005s
++mxl5007t
++mxm-wmi
++mxser
++myri10ge
++n2
++n411
++nand
++nand_bch
++nand_ecc
++nand_ids
++nandsim
++natsemi
++navman
++nbd
++nci
++ncpfs
++NCR53c406a
++nct6775
++ne
++ne2k-pci
++neofb
++net1080
++net2272
++net2280
++netconsole
++netjet
++netlink_diag
++netprio_cgroup
++netrom
++netsc520
++nettel
++netxen_nic
++newtonkbd
++nfc
++nf_conntrack
++nf_conntrack_amanda
++nf_conntrack_broadcast
++nf_conntrack_ftp
++nf_conntrack_h323
++nf_conntrack_ipv4
++nf_conntrack_ipv6
++nf_conntrack_irc
++nf_conntrack_netbios_ns
++nf_conntrack_netlink
++nf_conntrack_pptp
++nf_conntrack_proto_dccp
++nf_conntrack_proto_gre
++nf_conntrack_proto_sctp
++nf_conntrack_proto_udplite
++nf_conntrack_sane
++nf_conntrack_sip
++nf_conntrack_snmp
++nf_conntrack_tftp
++nfcsim
++nfcwilink
++nf_defrag_ipv4
++nf_defrag_ipv6
++nf_nat
++nf_nat_amanda
++nf_nat_ftp
++nf_nat_h323
++nf_nat_ipv4
++nf_nat_ipv6
++nf_nat_irc
++nf_nat_pptp
++nf_nat_proto_dccp
++nf_nat_proto_gre
++nf_nat_proto_sctp
++nf_nat_proto_udplite
++nf_nat_sip
++nf_nat_snmp_basic
++nf_nat_tftp
++nfnetlink
++nfnetlink_acct
++nfnetlink_cthelper
++nfnetlink_cttimeout
++nfnetlink_log
++nfnetlink_queue
++nfs
++nfs_acl
++nfsd
++nfs_layout_nfsv41_files
++nfsv2
++nfsv3
++nfsv4
++nftl
++nf_tproxy_core
++ngene
++n_hdlc
++ni65
++ni_6527
++ni_65xx
++ni_660x
++ni_670x
++ni_at_a2150
++ni_at_ao
++ni_atmio
++ni_atmio16d
++nicstar
++ni_daq_700
++ni_daq_dio24
++ni_labpc
++ni_labpc_cs
++ni_labpc_pci
++nilfs2
++ni_mio_cs
++ni_pcidio
++ni_pcimio
++ni_tio
++ni_tiocmd
++niu
++nlmon
++nls_ascii
++nls_cp1250
++nls_cp1251
++nls_cp1255
++nls_cp737
++nls_cp775
++nls_cp850
++nls_cp852
++nls_cp855
++nls_cp857
++nls_cp860
++nls_cp861
++nls_cp862
++nls_cp863
++nls_cp864
++nls_cp865
++nls_cp866
++nls_cp869
++nls_cp874
++nls_cp932
++nls_cp936
++nls_cp949
++nls_cp950
++nls_euc-jp
++nls_iso8859-1
++nls_iso8859-13
++nls_iso8859-14
++nls_iso8859-15
++nls_iso8859-2
++nls_iso8859-3
++nls_iso8859-4
++nls_iso8859-5
++nls_iso8859-6
++nls_iso8859-7
++nls_iso8859-9
++nls_koi8-r
++nls_koi8-ru
++nls_koi8-u
++nls_utf8
++nmclan_cs
++nosy
++notifier-error-inject
++nouveau
++nozomi
++n_r3964
++ns558
++ns83820
++nsc_gpio
++nsc-ircc
++nsp32
++nsp_cs
++ntc_thermistor
++ntfs
++n_tracerouter
++n_tracesink
++nuvoton-cir
++nvidiafb
++nvme
++nvram
++nv_tco
++nxt200x
++nxt6000
++objlayoutdriver
++ocfs2
++ocfs2_dlm
++ocfs2_dlmfs
++ocfs2_nodemanager
++ocfs2_stackglue
++ocfs2_stack_o2cb
++ocfs2_stack_user
++ocrdma
++ohci-pci
++old_belkin-sir
++omfs
++omninet
++on20
++on26
++onenand
++opencores-kbd
++openvswitch
++oprofile
++opticon
++option
++or51132
++or51211
++orinoco
++orinoco_cs
++orinoco_nortel
++orinoco_plx
++orinoco_tmd
++orinoco_usb
++osd
++osdblk
++osst
++oti6858
++output
++ov2640
++ov5642
++ov6650
++ov7640
++ov7670
++ov772x
++ov9640
++ov9740
++overlayfs
++oxu210hp-hcd
++ozwpan
++p4-clockmod
++p54common
++p54pci
++p54spi
++p54usb
++p8022
++p8023
++padlock-aes
++padlock-sha
++palmas-regulator
++panasonic-laptop
++panel
++paride
++parkbd
++parport
++parport_ax88796
++parport_cs
++parport_pc
++parport_serial
++pas16
++pata_acpi
++pata_ali
++pata_amd
++pata_arasan_cf
++pata_artop
++pata_atiixp
++pata_atp867x
++pata_cmd640
++pata_cmd64x
++pata_cs5520
++pata_cs5530
++pata_cs5535
++pata_cs5536
++pata_cypress
++pata_efar
++pata_hpt366
++pata_hpt37x
++pata_hpt3x2n
++pata_hpt3x3
++pata_isapnp
++pata_it8213
++pata_it821x
++pata_jmicron
++pata_legacy
++pata_marvell
++pata_mpiix
++pata_netcell
++pata_ninja32
++pata_ns87410
++pata_ns87415
++pata_oldpiix
++pata_opti
++pata_optidma
++pata_pcmcia
++pata_pdc2027x
++pata_pdc202xx_old
++pata_piccolo
++pata_platform
++pata_radisys
++pata_rdc
++pata_rz1000
++pata_sc1200
++pata_sch
++pata_serverworks
++pata_sil680
++pata_sl82c105
++pata_triflex
++pata_via
++pc110pad
++pc300too
++pc87360
++pc8736x_gpio
++pc87413_wdt
++pc87427
++pcap_keys
++pcap-regulator
++pcap_ts
++pcbc
++pcbit
++pcd
++pcf50633
++pcf50633-adc
++pcf50633-backlight
++pcf50633-charger
++pcf50633-gpio
++pcf50633-input
++pcf50633-regulator
++pcf8574_keypad
++pcf8591
++pch_can
++pch_dma
++pch_gbe
++pch_phub
++pch_uart
++pch_udc
++pci
++pci200syn
++pcips2
++pci-stub
++pcl711
++pcl724
++pcl726
++pcl730
++pcl812
++pcl816
++pcl818
++pcm3724
++pcmad
++pcmcia
++pcmcia_core
++pcmciamtd
++pcmcia_rsrc
++pcmda12
++pcmmio
++pcmuio
++pcnet32
++pcnet_cs
++pcrypt
++pcspkr
++pcwd
++pcwd_pci
++pcwd_usb
++pd
++pd6729
++pda_power
++pdc_adma
++peak_pci
++peak_pcmcia
++peak_usb
++pegasus
++penmount
++pf
++pg
++phantom
++phison
++phonet
++phram
++phy-gpio-vbus-usb
++phy-isp1301
++phy-nop
++phy-omap-control
++phy-omap-usb3
++phy-rcar-usb
++phy-samsung-usb
++phy-samsung-usb2
++phy-samsung-usb3
++physmap
++pixcir_i2c_ts
++pktcdvd
++pktgen
++pl2303
++platform_lcd
++plat_nand
++plat-ram
++plip
++plusb
++pluto2
++plx_pci
++pm2fb
++pm3fb
++pm80xx
++pmbus
++pmbus_core
++pmc551
++pmcraid
++pm-notifier-error-inject
++pms
++pn533
++pn544
++pn544_i2c
++pn544_mei
++pn_pep
++poc
++poseidon
++powermate
++powernow-k6
++powernow-k7
++ppa
++ppdev
++ppp_async
++ppp_deflate
++ppp_mppe
++pppoatm
++pppoe
++pppox
++ppp_synctty
++pps_core
++pps-gpio
++pps-ldisc
++pps_parport
++pptp
++prism2_usb
++ps2mult
++psmouse
++psnap
++pt
++pti
++ptp
++ptp_pch
++pvpanic
++pvrusb2
++pwc
++pwm-beeper
++pwm_bl
++pxa27x_udc
++qcaux
++qcserial
++qinfo_probe
++qla1280
++qla2xxx
++qla3xxx
++qla4xxx
++qlcnic
++qlge
++qlogic_cs
++qlogicfas
++qlogicfas408
++qmi_wwan
++qnx4
++qnx6
++qt1010
++qt1070
++qt2160
++quatech2
++quatech_daqp_cs
++quickstart
++quota_tree
++quota_v1
++quota_v2
++qxl
++r128
++r592
++r6040
++r8152
++r815x
++r8169
++r8187se
++r8192e_pci
++r8192u_usb
++r820t
++r82600_edac
++r852
++r8712u
++r8a66597-hcd
++r8a66597-udc
++radeon
++radeonfb
++radio-aimslab
++radio-aztech
++radio-cadet
++radio-gemtek
++radio-i2c-si470x
++radio-isa
++radio-keene
++radio-ma901
++radio-maxiradio
++radio-miropcm20
++radio-mr800
++radio-rtrack2
++radio-sf16fmi
++radio-sf16fmr2
++radio-shark
++radio-si4713
++radio-si476x
++radio-tea5764
++radio-terratec
++radio-timb
++radio-trust
++radio-typhoon
++radio-usb-si470x
++radio-wl1273
++radio-zoltrix
++raid0
++raid1
++raid10
++raid456
++raid6_pq
++raid6test
++raid_class
++ramoops
++raw
++ray_cs
++rbd
++rbtree_test
++rc5t583-regulator
++rc-adstech-dvb-t-pci
++rc-alink-dtu-m
++rc-anysee
++rc-apac-viewcomp
++rc-asus-pc39
++rc-asus-ps3-100
++rc-ati-tv-wonder-hd-600
++rc-ati-x10
++rc-avermedia
++rc-avermedia-a16d
++rc-avermedia-cardbus
++rc-avermedia-dvbt
++rc-avermedia-m135a
++rc-avermedia-m733a-rm-k6
++rc-avermedia-rm-ks
++rc-avertv-303
++rc-azurewave-ad-tu700
++rc-behold
++rc-behold-columbus
++rc-budget-ci-old
++rc-cinergy
++rc-cinergy-1400
++rc-core
++rc-delock-61959
++rc-dib0700-nec
++rc-dib0700-rc5
++rc-digitalnow-tinytwin
++rc-digittrade
++rc-dm1105-nec
++rc-dntv-live-dvb-t
++rc-dntv-live-dvbt-pro
++rc-em-terratec
++rc-encore-enltv
++rc-encore-enltv2
++rc-encore-enltv-fm53
++rc-evga-indtube
++rc-eztv
++rc-flydvb
++rc-flyvideo
++rc-fusionhdtv-mce
++rc-gadmei-rm008z
++rc-genius-tvgo-a11mce
++rc-gotview7135
++rc-hauppauge
++rc-imon-mce
++rc-imon-pad
++rc-iodata-bctv7e
++rc-it913x-v1
++rc-it913x-v2
++rc-kaiomy
++rc-kworld-315u
++rc-kworld-pc150u
++rc-kworld-plus-tv-analog
++rc-leadtek-y04g0051
++rc-lirc
++rc-lme2510
++rc-loopback
++rc-manli
++rc-medion-x10
++rc-medion-x10-digitainer
++rc-medion-x10-or2x
++rc-msi-digivox-ii
++rc-msi-digivox-iii
++rc-msi-tvanywhere
++rc-msi-tvanywhere-plus
++rc-nebula
++rc-nec-terratec-cinergy-xs
++rc-norwood
++rc-npgtech
++rc-pctv-sedna
++rc-pinnacle-color
++rc-pinnacle-grey
++rc-pinnacle-pctv-hd
++rc-pixelview
++rc-pixelview-002t
++rc-pixelview-mk12
++rc-pixelview-new
++rc-powercolor-real-angel
++rc-proteus-2309
++rc-purpletv
++rc-pv951
++rc-rc6-mce
++rc-real-audio-220-32-keys
++rc-reddo
++rc-snapstream-firefly
++rc-streamzap
++rc-tbs-nec
++rc-technisat-usb2
++rc-terratec-cinergy-xs
++rc-terratec-slim
++rc-terratec-slim-2
++rc-tevii-nec
++rc-tivo
++rc-total-media-in-hand
++rc-total-media-in-hand-02
++rc-trekstor
++rc-tt-1500
++rc-twinhan1027
++rc-videomate-m1f
++rc-videomate-s350
++rc-videomate-tv-pvr
++rc-winfast
++rc-winfast-usbii-deluxe
++rdc321x-southbridge
++rdma_cm
++rdma_ucm
++rds
++rds_rdma
++rds_tcp
++redboot
++redrat3
++reed_solomon
++reiserfs
++remoteproc
++renesas_usbhs
++retu-mfd
++retu-pwrbutton
++retu_wdt
++rfc1051
++rfc1201
++rfcomm
++rfd_ftl
++rfkill-gpio
++rfkill-regulator
++rio500
++rionet
++rio-scan
++rivafb
++rj54n1cb0c
++rmd128
++rmd160
++rmd256
++rmd320
++rndis_host
++rndis_wlan
++rocket
++romfs
++rose
++rotary_encoder
++rp2
++rpcsec_gss_krb5
++rsxx
++rt2400pci
++rt2500pci
++rt2500usb
++rt2800lib
++rt2800pci
++rt2800usb
++rt2x00lib
++rt2x00mmio
++rt2x00pci
++rt2x00usb
++rt61pci
++rt73usb
++rtc-88pm80x
++rtc-88pm860x
++rtc-ab3100
++rtc-bq32k
++rtc-bq4802
++rtc-da9052
++rtc-da9055
++rtc-ds1286
++rtc-ds1305
++rtc-ds1307
++rtc-ds1374
++rtc-ds1390
++rtc-ds1511
++rtc-ds1553
++rtc-ds1672
++rtc-ds1742
++rtc-ds2404
++rtc-ds3232
++rtc-ds3234
++rtc-em3027
++rtc-fm3130
++rtc-hid-sensor-time
++rtc-isl12022
++rtc-isl1208
++rtc-lp8788
++rtc-m41t80
++rtc-m41t93
++rtc-m41t94
++rtc-m48t35
++rtc-m48t59
++rtc-m48t86
++rtc-max6900
++rtc-max6902
++rtc-max77686
++rtc-max8907
++rtc-max8925
++rtc-max8997
++rtc-max8998
++rtc-mc13xxx
++rtc-mrst
++rtc-msm6242
++rtc-palmas
++rtc-pcap
++rtc-pcf2123
++rtc-pcf2127
++rtc-pcf50633
++rtc-pcf8523
++rtc-pcf8563
++rtc-pcf8583
++rtc-r9701
++rtc-rc5t583
++rtc-rp5c01
++rtc-rs5c348
++rtc-rs5c372
++rtc-rv3029c2
++rtc-rx4581
++rtc-rx8025
++rtc-rx8581
++rtc-s35390a
++rtc-stk17ta8
++rtc-tps6586x
++rtc-tps65910
++rtc-tps80031
++rtc-v3020
++rtc-wm831x
++rtc-wm8350
++rtc-x1205
++rtd520
++rti800
++rti802
++rtl2830
++rtl2832
++rtl8150
++rtl8180
++rtl8187
++rtl8188ee
++rtl8192c-common
++rtl8192ce
++rtl8192cu
++rtl8192de
++rtl8192se
++rtl8723ae
++rtllib
++rtllib_crypt_ccmp
++rtllib_crypt_tkip
++rtllib_crypt_wep
++rtl_pci
++rtl_usb
++rtlwifi
++rts5139
++rtsx_pci
++rtsx_pci_ms
++rtsx_pci_sdmmc
++rxkad
++s1d13xxxfb
++s2250
++s2255drv
++s2io
++s2mps11
++s3fb
++s526
++s5h1409
++s5h1411
++s5h1420
++s5m8767
++s626
++s6e63m0
++s921
++saa6588
++saa6752hs
++saa7110
++saa7115
++saa7127
++saa7134
++saa7134-alsa
++saa7134-dvb
++saa7134-empress
++saa7146
++saa7146_vv
++saa7164
++saa717x
++saa7185
++saa7706h
++safe_serial
++salsa20_generic
++salsa20-i586
++samsung-keypad
++samsung-laptop
++samsung-q10
++sata_inic162x
++sata_mv
++sata_nv
++sata_promise
++sata_qstor
++sata_rcar
++sata_sil
++sata_sil24
++sata_sis
++sata_svw
++sata_sx4
++sata_uli
++sata_via
++sata_vsc
++savage
++savagefb
++sb1000
++sbc60xxwdt
++sbc7240_wdt
++sbc8360
++sbc_epx_c3
++sbc_fitpc2_wdt
++sbc_gxx
++sbe-2t3e3
++sbni
++sbp_target
++sbs
++sbs-battery
++sbshc
++sc
++sc1200wdt
++sc520cdp
++sc520_wdt
++sc92031
++sca3000
++scb2_flash
++scc
++sch311x_wdt
++sch5627
++sch5636
++sch56xx-common
++sch_atm
++sch_cbq
++sch_choke
++sch_codel
++sch_drr
++sch_dsmark
++sch_fq_codel
++sch_gred
++sch_hfsc
++sch_htb
++sch_ingress
++sch_mqprio
++sch_multiq
++sch_netem
++sch_plug
++sch_prio
++sch_qfq
++sch_red
++sch_sfb
++sch_sfq
++sch_tbf
++sch_teql
++scsi_debug
++scsi_dh
++scsi_dh_alua
++scsi_dh_emc
++scsi_dh_hp_sw
++scsi_dh_rdac
++scsi_tgt
++scsi_transport_fc
++scsi_transport_iscsi
++scsi_transport_sas
++scsi_transport_srp
++sctp
++sctp_probe
++scx200
++scx200_acb
++scx200_docflash
++scx200_gpio
++scx200_hrt
++scx200_wdt
++sdhci
++sdhci-acpi
++sdhci-pci
++sdhci-pltfm
++sdhci-pxav2
++sdhci-pxav3
++sdio_uart
++sdla
++sdricoh_cs
++sealevel
++sedlbauer_cs
++seed
++sep_driver
++seqiv
++ser_gigaset
++serial2002
++serial_cs
++serio_raw
++sermouse
++serpent_generic
++serpent-sse2-i586
++serport
++serqt_usb2
++ses
++sfc
++shark2
++sh_eth
++sh_mobile_ceu_camera
++sh_mobile_csi2
++shpchp
++sht15
++sht21
++sh_veu
++si21xx
++si4713-i2c
++si476x-core
++sidewinder
++siemens_mpi
++sierra
++sierra_net
++sil164
++sim710
++sir-dev
++sis
++sis190
++sis5595
++sis900
++sis-agp
++sisfb
++sisusbvga
++sit
++sja1000
++sja1000_isa
++sja1000_platform
++skel
++skfp
++skge
++sky2
++sl811_cs
++sl811-hcd
++slcan
++slicoss
++slip
++slram
++sm501
++sm501fb
++sm7xxfb
++smb347-charger
++smc9194
++smc91c92_cs
++sm_common
++smc-ultra
++sm_ftl
++smm665
++smsc37b787_wdt
++smsc47b397
++smsc47m1
++smsc47m192
++smsc75xx
++smsc911x
++smsc9420
++smsc95xx
++smsc-ircc2
++smscufx
++smsdvb
++smsmdtv
++smssdio
++smsusb
++snd
++snd-ac97-codec
++snd-ad1816a
++snd-ad1848
++snd-ad1889
++snd-adlib
++snd-ak4113
++snd-ak4114
++snd-ak4117
++snd-ak4xxx-adda
++snd-ali5451
++snd-aloop
++snd-als100
++snd-als300
++snd-als4000
++snd-asihpi
++snd-at73c213
++snd-atiixp
++snd-atiixp-modem
++snd-au8810
++snd-au8820
++snd-au8830
++snd-aw2
++snd-azt1605
++snd-azt2316
++snd-azt2320
++snd-azt3328
++snd-bt87x
++snd-ca0106
++snd-cmi8328
++snd-cmi8330
++snd-cmipci
++snd-compress
++snd-cs4231
++snd-cs4236
++snd-cs4281
++snd-cs46xx
++snd-cs5530
++snd-cs5535audio
++snd-cs8427
++snd-ctxfi
++snd-darla20
++snd-darla24
++snd-dummy
++snd-echo3g
++snd-emu10k1
++snd-emu10k1-synth
++snd-emu10k1x
++snd-emu8000-synth
++snd-emux-synth
++snd-ens1370
++snd-ens1371
++snd-es1688
++snd-es1688-lib
++snd-es18xx
++snd-es1938
++snd-es1968
++snd-firewire-lib
++snd-firewire-speakers
++snd-fm801
++snd-gina20
++snd-gina24
++snd-gusclassic
++snd-gusextreme
++snd-gus-lib
++snd-gusmax
++snd-hda-codec
++snd-hda-codec-analog
++snd-hda-codec-ca0110
++snd-hda-codec-ca0132
++snd-hda-codec-cirrus
++snd-hda-codec-cmedia
++snd-hda-codec-conexant
++snd-hda-codec-hdmi
++snd-hda-codec-idt
++snd-hda-codec-realtek
++snd-hda-codec-si3054
++snd-hda-codec-via
++snd-hda-intel
++snd-hdsp
++snd-hdspm
++snd-hrtimer
++snd-hwdep
++snd-i2c
++snd-ice1712
++snd-ice1724
++snd-ice17xx-ak4xxx
++snd-indigo
++snd-indigodj
++snd-indigodjx
++snd-indigoio
++snd-indigoiox
++snd-intel8x0
++snd-intel8x0m
++snd-interwave
++snd-interwave-stb
++snd-isight
++snd-jazz16
++snd-korg1212
++snd-layla20
++snd-layla24
++snd-lola
++snd-lx6464es
++snd-maestro3
++snd-mia
++snd-miro
++snd-mixart
++snd-mona
++snd-mpu401
++snd-mpu401-uart
++snd-msnd-classic
++snd-msnd-lib
++snd-msnd-pinnacle
++snd-mtpav
++snd-mts64
++snd-nm256
++snd-opl3-lib
++snd-opl3sa2
++snd-opl3-synth
++snd-opl4-lib
++snd-opl4-synth
++snd-opti92x-ad1848
++snd-opti92x-cs4231
++snd-opti93x
++snd-oxygen
++snd-oxygen-lib
++snd-page-alloc
++snd-pcm
++snd-pcsp
++snd-pcxhr
++snd-pdaudiocf
++snd-portman2x4
++snd-pt2258
++snd-rawmidi
++snd-riptide
++snd-rme32
++snd-rme96
++snd-rme9652
++snd-sb16
++snd-sb16-csp
++snd-sb16-dsp
++snd-sb8
++snd-sb8-dsp
++snd-sbawe
++snd-sb-common
++snd-sc6000
++snd-scs1x
++snd-seq
++snd-seq-device
++snd-seq-dummy
++snd-seq-midi
++snd-seq-midi-emul
++snd-seq-midi-event
++snd-seq-virmidi
++snd-serial-u16550
++snd-sis7019
++snd-soc-88pm860x
++snd-soc-ab8500-codec
++snd-soc-ad1836
++snd-soc-ad193x
++snd-soc-ad73311
++snd-soc-adau1373
++snd-soc-adav80x
++snd-soc-ads117x
++snd-soc-ak4104
++snd-soc-ak4535
++snd-soc-ak4641
++snd-soc-ak4642
++snd-soc-ak4671
++snd-soc-ak5386
++snd-soc-alc5623
++snd-soc-alc5632
++snd-soc-arizona
++snd-soc-atmel-pcm
++snd-soc-bt-sco
++snd-soc-core
++snd-soc-cs4270
++snd-soc-cs4271
++snd-soc-cs42l51
++snd-soc-cs42l52
++snd-soc-cs42l73
++snd-soc-cx20442
++snd-soc-da7210
++snd-soc-da7213
++snd-soc-da732x
++snd-soc-da9055
++snd-soc-hdmi-codec
++snd-soc-isabelle
++snd-soc-jz4740-codec
++snd-soc-l3
++snd-soc-lm4857
++snd-soc-lm49453
++snd-soc-max9768
++snd-soc-max98088
++snd-soc-max98090
++snd-soc-max98095
++snd-soc-max9850
++snd-soc-max9877
++snd-soc-mc13783
++snd-soc-mfld-machine
++snd-soc-ml26124
++snd-soc-pcm3008
++snd-soc-rt5631
++snd-soc-rt5640
++snd-soc-sgtl5000
++snd-soc-si476x
++snd-soc-simple-card
++snd-soc-sn95031
++snd-soc-spdif-rx
++snd-soc-spdif-tx
++snd-soc-ssm2518
++snd-soc-ssm2602
++snd-soc-sst-platform
++snd-soc-sta32x
++snd-soc-sta529
++snd-soc-tas5086
++snd-soc-tlv320aic23
++snd-soc-tlv320aic26
++snd-soc-tlv320aic32x4
++snd-soc-tlv320aic3x
++snd-soc-tlv320dac33
++snd-soc-tpa6130a2
++snd-soc-twl6040
++snd-soc-uda134x
++snd-soc-uda1380
++snd-soc-wl1273
++snd-soc-wm0010
++snd-soc-wm1250-ev1
++snd-soc-wm2000
++snd-soc-wm2200
++snd-soc-wm5100
++snd-soc-wm5102
++snd-soc-wm5110
++snd-soc-wm8350
++snd-soc-wm8400
++snd-soc-wm8510
++snd-soc-wm8523
++snd-soc-wm8580
++snd-soc-wm8711
++snd-soc-wm8727
++snd-soc-wm8728
++snd-soc-wm8731
++snd-soc-wm8737
++snd-soc-wm8741
++snd-soc-wm8750
++snd-soc-wm8753
++snd-soc-wm8770
++snd-soc-wm8776
++snd-soc-wm8782
++snd-soc-wm8804
++snd-soc-wm8900
++snd-soc-wm8903
++snd-soc-wm8904
++snd-soc-wm8940
++snd-soc-wm8955
++snd-soc-wm8960
++snd-soc-wm8961
++snd-soc-wm8962
++snd-soc-wm8971
++snd-soc-wm8974
++snd-soc-wm8978
++snd-soc-wm8983
++snd-soc-wm8985
++snd-soc-wm8988
++snd-soc-wm8990
++snd-soc-wm8991
++snd-soc-wm8993
++snd-soc-wm8994
++snd-soc-wm8995
++snd-soc-wm8996
++snd-soc-wm9081
++snd-soc-wm9090
++snd-soc-wm-adsp
++snd-soc-wm-hubs
++snd-sonicvibes
++snd-sscape
++snd-tea575x-tuner
++snd-tea6330t
++snd-timer
++snd-trident
++snd-ua101
++snd-usb-6fire
++snd-usb-audio
++snd-usb-caiaq
++snd-usb-hiface
++snd-usbmidi-lib
++snd-usb-us122l
++snd-usb-usx2y
++snd-util-mem
++snd-via82xx
++snd-via82xx-modem
++snd-virmidi
++snd-virtuoso
++snd-vx222
++snd-vx-lib
++snd-vxpocket
++snd-wavefront
++snd-wss-lib
++snd-ymfpci
++soc_camera
++soc_camera_platform
++soc_mediabus
++soc_scale_crop
++softdog
++softing
++softing_cs
++solo6x10
++solos-pci
++sony-btf-mpx
++sony-laptop
++sonypi
++soundcore
++sp5100_tco
++sp8870
++sp887x
++spaceball
++spaceorb
++sparse-keymap
++spcp8x5
++speakup
++speakup_acntpc
++speakup_acntsa
++speakup_apollo
++speakup_audptr
++speakup_bns
++speakup_decext
++speakup_decpc
++speakup_dectlk
++speakup_dtlk
++speakup_dummy
++speakup_keypc
++speakup_ltlk
++speakup_soft
++speakup_spkout
++speakup_txprt
++spectrum_cs
++speedfax
++speedtch
++spi-altera
++spi-bitbang
++spi-butterfly
++spidev
++spi-dw
++spi-dw-midpci
++spi-dw-mmio
++spi-gpio
++spi_ks8995
++spi-lm70llp
++spi-oc-tiny
++spi-pxa2xx-pci
++spi-pxa2xx-platform
++spi-sc18is602
++spi-tle62x0
++spi-topcliff-pch
++spi-xcomm
++squashfs
++ssb
++ssb-hcd
++ssfdc
++sst25l
++sstfb
++ssu100
++ssv_dnp
++st
++st1232
++st_accel
++st_accel_i2c
++st_accel_spi
++starfire
++stb0899
++stb6000
++stb6100
++st_drv
++ste_modem_rproc
++stex
++st_gyro
++st_gyro_i2c
++st_gyro_spi
++stinger
++stir4200
++stk1160
++stkwebcam
++st_magn
++st_magn_i2c
++st_magn_spi
++stmmac
++stmpe-keypad
++stmpe-ts
++stowaway
++stp
++st_pressure
++st_pressure_i2c
++st_pressure_spi
++streamzap
++st_sensors
++st_sensors_i2c
++st_sensors_spi
++stv0288
++stv0297
++stv0299
++stv0367
++stv0900
++stv090x
++stv6110
++stv6110x
++sundance
++sungem
++sungem_phy
++sunhme
++suni
++sunkbd
++sunrpc
++suunto
++svcrdma
++svgalib
++sworks-agp
++sx8
++sym53c416
++sym53c500_cs
++sym53c8xx
++symbolserial
++synaptics_i2c
++synaptics_i2c_rmi4
++synaptics_usb
++synclink
++synclink_cs
++synclink_gt
++synclinkmp
++syscopyarea
++sysfillrect
++sysimgblt
++sysv
++t128
++t1isa
++t1pci
++target_core_file
++target_core_iblock
++target_core_mod
++target_core_pscsi
++tc1100-wmi
++tc3589x-keypad
++tca6416-keypad
++tca8418_keypad
++tcic
++tcm_fc
++tcm_loop
++tcm_qla2xxx
++tcm_usb_gadget
++tcp_bic
++tcp_diag
++tcp_highspeed
++tcp_htcp
++tcp_hybla
++tcp_illinois
++tcp_lp
++tcp_probe
++tcp_scalable
++tcp_vegas
++tcp_veno
++tcp_westwood
++tcp_yeah
++tcrypt
++tda10021
++tda10023
++tda10048
++tda1004x
++tda10071
++tda10086
++tda18212
++tda18218
++tda18271
++tda18271c2dd
++tda665x
++tda7432
++tda8083
++tda8261
++tda826x
++tda827x
++tda8290
++tda9840
++tda9887
++tda998x
++tdfx
++tdfxfb
++tdo24m
++tea
++tea5761
++tea5767
++tea6415c
++tea6420
++tef6862
++tehuti
++tekram-sir
++teles_cs
++test-kstrtox
++test_power
++test-string_helpers
++tg3
++tgr192
++thinkpad_acpi
++thmc50
++ti-adc081c
++ti_am335x_adc
++ti_am335x_tsc
++ti_am335x_tscadc
++ti_dac7512
++tifm_7xx1
++tifm_core
++tifm_ms
++tifm_sd
++timb_dma
++timberdale
++timblogiw
++timbuart
++timeriomem-rng
++tipc
++ti_usb_3410_5052
++tlan
++tlclk
++tm6000
++tm6000-alsa
++tm6000-dvb
++tmdc
++tmem
++tmiofb
++tmp102
++tmp401
++tmp421
++tmscsim
++toim3232-sir
++topstar-laptop
++toshiba_acpi
++toshiba_bluetooth
++touchit213
++touchright
++touchwin
++tpci200
++tpm_atmel
++tpm_i2c_infineon
++tpm_i2c_stm_st33
++tpm_infineon
++tpm_nsc
++tpm-rng
++tpm_tis
++tps51632-regulator
++tps6105x
++tps6105x-regulator
++tps62360-regulator
++tps65010
++tps65023-regulator
++tps6507x
++tps6507x-regulator
++tps6507x-ts
++tps65090-charger
++tps65090-regulator
++tps65217
++tps65217_bl
++tps65217-regulator
++tps6524x-regulator
++tps6586x-regulator
++tps65910-regulator
++tps65912-regulator
++tps80031-regulator
++trancevibrator
++tranzport
++tridentfb
++ts2020
++ts5500_flash
++ts_bm
++tsc2005
++tsc2007
++tsc40
++tscan1
++ts_fsm
++ts_kmp
++tsl2550
++tsl2563
++tsl2583
++tsl2x7x_core
++ttm
++ttpci-eeprom
++ttusb_dec
++ttusbdecfe
++ttusbir
++tua6100
++tua9001
++tulip
++tuner
++tuner_it913x
++tuner-simple
++tuner-types
++tuner-xc2028
++tunnel4
++tunnel6
++turbografx
++tusb6010
++tvaudio
++tveeprom
++tvp5150
++tw2804
++tw9903
++tw9906
++tw9910
++twidjoy
++twl6040-vibra
++twofish_common
++twofish_generic
++twofish-i586
++typhoon
++u132-hcd
++u14-34f
++uartlite
++ubi
++ubifs
++ucb1400_core
++ucb1400_ts
++ucd9000
++ucd9200
++uda1342
++udc-core
++udf
++udl
++udlfb
++udp_diag
++ueagle-atm
++u_ether
++ufs
++ufshcd
++ufshcd-pci
++ufshcd-pltfrm
++uhid
++uio
++uio_aec
++uio_cif
++uio_dmem_genirq
++uio_netx
++uio_pci_generic
++uio_pdrv
++uio_pdrv_genirq
++uio_sercos3
++uli526x
++ultrastor
++umc
++umem
++ums-alauda
++ums-cypress
++ums-datafab
++ums-eneub6250
++ums-freecom
++ums-isd200
++ums-jumpshot
++ums-karma
++ums-onetouch
++ums-realtek
++ums-sddr09
++ums-sddr55
++ums-usbat
++unioxx5
++unix_diag
++upd64031a
++upd64083
++uPD98402
++u_rndis
++usb3503
++usb_8dev
++usb8xxx
++usbatm
++usb_debug
++usbdux
++usbduxfast
++usbduxsigma
++usb_f_acm
++usb_f_ecm
++usb_f_ecm_subset
++usb_f_eem
++usb_f_ncm
++usb_f_obex
++usb_f_phonet
++usb_f_rndis
++usb_f_serial
++usb_f_ss_lb
++usb_gigaset
++usbhid
++usbip-core
++usbip-host
++usbkbd
++usblcd
++usbled
++usblp
++usbmon
++usbmouse
++usbnet
++usbserial
++usbsevseg
++usb-storage
++usbtest
++usbtmc
++usbtouchscreen
++usbtv
++usbvision
++usb_wwan
++u_serial
++userspace-consumer
++ushc
++uss720
++uvcvideo
++uvesafb
++uwb
++ux500
++v4l2-common
++v4l2-int-device
++v4l2-mem2mem
++vcan
++vcnl4000
++ves1820
++ves1x93
++vesafb
++veth
++vfio
++vfio_iommu_type1
++vfio-pci
++vga16fb
++vgastate
++vgg2432a4
++vhci-hcd
++vhost
++vhost_net
++vhost_scsi
++via
++via686a
++via-camera
++via-cputemp
++viafb
++via-ircc
++via-rhine
++via-rng
++via-sdmmc
++via-velocity
++via_wdt
++video
++videobuf2-core
++videobuf2-dma-contig
++videobuf2-dma-sg
++videobuf2-memops
++videobuf2-vmalloc
++videobuf-core
++videobuf-dma-contig
++videobuf-dma-sg
++videobuf-dvb
++videobuf-vmalloc
++videocodec
++videodev
++viperboard
++viperboard_adc
++virtio_balloon
++virtio_console
++virtio_mmio
++virtio-rng
++virtio_scsi
++virtual
++visor
++vivi
++vivopay-serial
++vlsi_ir
++vmac
++vme
++vme_ca91cx42
++vme_pio2
++vme_tsi148
++vme_user
++vme_vmivme7805
++vmk80xx
++vmlfb
++vmw_balloon
++vmwgfx
++vmw_pvscsi
++vmw_vmci
++vmw_vsock_vmci_transport
++vmxnet3
++vp27smpx
++vpx3220
++vringh
++vsock
++vsxxxaa
++vt1211
++vt6655_stage
++vt6656_stage
++vt8231
++vt8623fb
++vub300
++vx855
++vxge
++vxlan
++w1_bq27000
++w1_ds2408
++w1_ds2413
++w1_ds2423
++w1_ds2431
++w1_ds2433
++w1_ds2760
++w1_ds2780
++w1_ds2781
++w1_ds28e04
++w1-gpio
++w1_smem
++w1_therm
++w35und
++w5100
++w5300
++w6692
++w83627ehf
++w83627hf
++w83627hf_wdt
++w83697hf_wdt
++w83697ug_wdt
++w83781d
++w83791d
++w83792d
++w83793
++w83795
++w83877f_wdt
++w83977af_ir
++w83977f_wdt
++w83l785ts
++w83l786ng
++w90p910_ts
++w9966
++wacom
++wacom_i2c
++wacom_w8001
++wafer5823wdt
++walkera0701
++wanxl
++warrior
++wbsd
++wd
++wd7000
++wdt
++wdt_pci
++whci
++whci-hcd
++whc-rc
++whiteheat
++wil6210
++wimax
++winbond-840
++winbond-cir
++wire
++wishbone-serial
++wistron_btns
++wl1251
++wl1251_sdio
++wl1251_spi
++wl1273-core
++wl12xx
++wl18xx
++wl3501_cs
++wlags49_h25_cs
++wlags49_h2_cs
++wlcore
++wlcore_sdio
++wlcore_spi
++wm831x_backup
++wm831x_bl
++wm831x-dcdc
++wm831x-hwmon
++wm831x-isink
++wm831x-ldo
++wm831x-on
++wm831x_power
++wm831x-ts
++wm831x_wdt
++wm8350-hwmon
++wm8350_power
++wm8350-regulator
++wm8350_wdt
++wm8400-regulator
++wm8739
++wm8775
++wm8994-regulator
++wm97xx-ts
++wmi
++wp512
++wusb-cbaf
++wusbcore
++wusb-wa
++x25
++x25_asy
++x38_edac
++x86_pkg_temp_thermal
++xc4000
++xc5000
++xcbc
++xen-blkback
++xen-evtchn
++xen-fbfront
++xenfs
++xen-gntalloc
++xen-gntdev
++xen-kbdfront
++xen-netback
++xen-pciback
++xen-pcifront
++xen-privcmd
++xen_wdt
++xfrm4_mode_beet
++xfrm4_mode_transport
++xfrm4_mode_tunnel
++xfrm4_tunnel
++xfrm6_mode_beet
++xfrm6_mode_ro
++xfrm6_mode_transport
++xfrm6_mode_tunnel
++xfrm6_tunnel
++xfrm_algo
++xfrm_ipcomp
++xfrm_user
++xfs
++xgifb
++xgmac
++xirc2ps_cs
++xircom_cb
++xo15-ebook
++xor
++xpad
++xprtrdma
++xsens_mt
++x_tables
++xt_addrtype
++xt_AUDIT
++xt_bpf
++xt_CHECKSUM
++xt_CLASSIFY
++xt_cluster
++xt_comment
++xt_connbytes
++xt_connlabel
++xt_connlimit
++xt_connmark
++xt_CONNSECMARK
++xt_conntrack
++xt_cpu
++xt_CT
++xt_dccp
++xt_devgroup
++xt_dscp
++xt_DSCP
++xt_ecn
++xt_esp
++xt_hashlimit
++xt_helper
++xt_hl
++xt_HL
++xt_HMARK
++xt_IDLETIMER
++xt_iprange
++xt_ipvs
++xtkbd
++xt_LED
++xt_length
++xt_limit
++xt_LOG
++xt_mac
++xt_mark
++xt_multiport
++xt_nat
++xt_NETMAP
++xt_nfacct
++xt_NFLOG
++xt_NFQUEUE
++xt_osf
++xt_owner
++xt_physdev
++xt_pkttype
++xt_policy
++xt_quota
++xt_rateest
++xt_RATEEST
++xt_realm
++xt_recent
++xt_REDIRECT
++xts
++xt_sctp
++xt_SECMARK
++xt_set
++xt_socket
++xt_state
++xt_statistic
++xt_string
++xt_tcpmss
++xt_TCPMSS
++xt_TCPOPTSTRIP
++xt_tcpudp
++xt_TEE
++xt_time
++xt_TPROXY
++xt_TRACE
++xt_u32
++xusbatm
++xz_dec_test
++yam
++yealink
++yellowfin
++yenta_socket
++yurex
++z85230
++zatm
++zaurus
++zd1201
++zd1211rw
++zhenhua
++zio
++zl10036
++zl10039
++zl10353
++zl6100
++zlib
++zlib_deflate
++zr36016
++zr36050
++zr36060
++zr36067
++zr364xx
++zram
++zte_ev
+diff --git a/debian.master/abi/perm-blacklist b/debian.master/abi/perm-blacklist
+new file mode 100644
+index 0000000..e69de29
+diff --git a/debian.master/changelog b/debian.master/changelog
+new file mode 100644
+index 0000000..0029ecc
+--- /dev/null
++++ b/debian.master/changelog
+@@ -0,0 +1,10085 @@
++linux (3.11.0-14.21) saucy; urgency=low
++
++  [Brad Figg]
++
++  * Release Tracking Bug
++    - LP: #1250540
++
++  [ Anthony Wong ]
++
++  * SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537
++    - LP: #1231305
++
++  [ Colin Ian King ]
++
++  * SAUCE: eCryptfs: fix 32 bit corruption issue
++    - LP: #1243636
++
++  [ Ming Lei ]
++
++  * SAUCE: ext4: fix performance regression in ext4_writepages
++    - LP: #1242812
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "bridge: only expire the mdb entry when query is received"
++    - LP: #1249081
++  * ext4: fix performance regression in writeback of random writes
++    - LP: #1242812
++  * be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd
++    - LP: #1234019
++  * tcp: TSO packets automatic sizing
++    - LP: #1249081
++  * tcp: TSQ can use a dynamic limit
++    - LP: #1249081
++  * tcp: must unclone packets before mangling them
++    - LP: #1249081
++  * tcp: do not forget FIN in tcp_shifted_skb()
++    - LP: #1249081
++  * tcp: fix incorrect ca_state in tail loss probe
++    - LP: #1249081
++  * net: do not call sock_put() on TIMEWAIT sockets
++    - LP: #1249081
++  * batman-adv: set up network coding packet handlers during module init
++    - LP: #1249081
++  * l2tp: fix kernel panic when using IPv4-mapped IPv6 addresses
++    - LP: #1249081
++  * l2tp: Fix build warning with ipv6 disabled.
++    - LP: #1249081
++  * net: mv643xx_eth: update statistics timer from timer context only
++    - LP: #1249081
++  * net: mv643xx_eth: fix orphaned statistics timer crash
++    - LP: #1249081
++  * net: heap overflow in __audit_sockaddr()
++    - LP: #1249081
++  * sit: amend "allow to use rtnl ops on fb tunnel"
++    - LP: #1249081
++  * proc connector: fix info leaks
++    - LP: #1249081
++  * ipv4: fix ineffective source address selection
++    - LP: #1249081
++  * can: dev: fix nlmsg size calculation in can_get_size()
++    - LP: #1249081
++  * net: secure_seq: Fix warning when CONFIG_IPV6 and CONFIG_INET are not
++    selected
++    - LP: #1249081
++  * xen-netback: Don't destroy the netdev until the vif is shut down
++    - LP: #1249081
++  * net/mlx4_en: Rename name of mlx4_en_rx_alloc members
++    - LP: #1249081
++  * net/mlx4_en: Fix pages never dma unmapped on rx
++    - LP: #1249081
++  * net: vlan: fix nlmsg size calculation in vlan_get_size()
++    - LP: #1249081
++  * bridge: update mdb expiration timer upon reports.
++    - LP: #1249081
++  * vti: get rid of nf mark rule in prerouting
++    - LP: #1249081
++  * l2tp: must disable bh before calling l2tp_xmit_skb()
++    - LP: #1249081
++  * netem: update backlog after drop
++    - LP: #1249081
++  * netem: free skb's in tree on reset
++    - LP: #1249081
++  * farsync: fix info leak in ioctl
++    - LP: #1249081
++  * unix_diag: fix info leak
++    - LP: #1249081
++  * connector: use nlmsg_len() to check message length
++    - LP: #1249081
++  * bnx2x: record rx queue for LRO packets
++    - LP: #1249081
++  * virtio-net: don't respond to cpu hotplug notifier if we're not ready
++    - LP: #1249081
++  * virtio-net: refill only when device is up during setting queues
++    - LP: #1249081
++  * bridge: Correctly clamp MAX forward_delay when enabling STP
++    - LP: #1249081
++  * net: dst: provide accessor function to dst->xfrm
++    - LP: #1249081
++  * sctp: Use software crc32 checksum when xfrm transform will happen.
++    - LP: #1249081
++  * sctp: Perform software checksum if packet has to be fragmented.
++    - LP: #1249081
++  * wanxl: fix info leak in ioctl
++    - LP: #1249081
++  * net: unix: inherit SOCK_PASS{CRED, SEC} flags from socket to fix race
++    - LP: #1249081
++  * net: fix cipso packet validation when !NETLABEL
++    - LP: #1249081
++  * inet: fix possible memory corruption with UDP_CORK and UFO
++    - LP: #1249081
++  * ipv6: always prefer rt6i_gateway if present
++    - LP: #1249081
++  * ipv6: fill rt6i_gateway with nexthop address
++    - LP: #1249081
++  * netfilter: nf_conntrack: fix rt6i_gateway checks for H.323 helper
++    - LP: #1249081
++  * ipv6: probe routes asynchronous in rt6_probe
++    - LP: #1249081
++  * davinci_emac.c: Fix IFF_ALLMULTI setup
++    - LP: #1249081
++  * ARM: 7851/1: check for number of arguments in
++    syscall_get/set_arguments()
++    - LP: #1249081
++  * ARM: integrator: deactivate timer0 on the Integrator/CP
++    - LP: #1249081
++  * ext[34]: fix double put in tmpfile
++    - LP: #1249081
++  * gpio/lynxpoint: check if the interrupt is enabled in IRQ handler
++    - LP: #1249081
++  * dm snapshot: fix data corruption
++    - LP: #1249081
++    - CVE-2013-4299
++  * i2c: ismt: initialize DMA buffer
++    - LP: #1249081
++  * mm: migration: do not lose soft dirty bit if page is in migration state
++    - LP: #1249081
++  * mm/zswap: bugfix: memory leak when re-swapon
++    - LP: #1249081
++  * mm: fix BUG in __split_huge_page_pmd
++    - LP: #1249081
++  * ALSA: us122l: Fix pcm_usb_stream mmapping regression
++    - LP: #1249081
++  * ALSA: hda - Fix inverted internal mic not indicated on some machines
++    - LP: #1227491, #1239392, #1249081
++  * writeback: fix negative bdi max pause
++    - LP: #1249081
++  * w1 - call request_module with w1 master mutex unlocked
++    - LP: #1249081
++  * wireless: radiotap: fix parsing buffer overrun
++    - LP: #1249081
++  * wireless: cw1200: acquire hwbus lock around cw1200_irq_handler() call.
++    - LP: #1249081
++  * serial: vt8500: add missing braces
++    - LP: #1249081
++  * USB: serial: ti_usb_3410_5052: add Abbott strip port ID to combined
++    table as well.
++    - LP: #1249081
++  * USB: serial: option: add support for Inovia SEW858 device
++    - LP: #1249081
++  * usb: serial: option: blacklist Olivetti Olicard200
++    - LP: #1249081
++  * Linux 3.11.7
++    - LP: #1249081
++  * tg3: Add support for new 57786 device id.
++    - LP: #1242610
++
++ -- Brad Figg <brad.figg@canonical.com>  Tue, 12 Nov 2013 08:10:21 -0800
++
++linux (3.11.0-13.20) saucy; urgency=low
++
++  [ Brad Figg ]
++
++  * Release Tracking Bug
++    - LP: #1242793
++
++  [ Paolo Pisati ]
++
++  * [Config] amhf: VIRTIO_CONSOLE=y
++    - LP: #1237982
++  * [Config] AHCI_IMX=y
++    - LP: #1240038
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_USB_OTG=n for all arches
++    - LP: #1047527
++  * dm-raid4-5: Fix compile issues
++    - LP: #1241086
++  * [Config] CONFIG_DM_RAID45=m
++    - LP: #1241086
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "cw1200: Don't perform SPI transfers in interrupt context"
++    - LP: #1237530
++  * block: Fix bio_copy_data()
++    - LP: #1237530
++  * sysv: Add forgotten superblock lock init for v7 fs
++    - LP: #1237530
++  * bcache: Fix a dumb journal discard bug
++    - LP: #1237530
++  * bcache: Strip endline when writing the label through sysfs
++    - LP: #1237530
++  * bcache: Fix for when no journal entries are found
++    - LP: #1237530
++  * bcache: Fix a writeback performance regression
++    - LP: #1237530
++  * bcache: Fix a flush/fua performance bug
++    - LP: #1237530
++  * bcache: Fix a dumb CPU spinning bug in writeback
++    - LP: #1237530
++  * bcache: Fix a shrinker deadlock
++    - LP: #1237530
++  * bcache: Fix for handling overlapping extents when reading in a btree
++    node
++    - LP: #1237530
++  * bcache: Fix flushes in writeback mode
++    - LP: #1237530
++  * kernel/reboot.c: re-enable the function of variable reboot_default
++    - LP: #1237530
++  * x86/reboot: Add quirk to make Dell C6100 use reboot=pci automatically
++    - LP: #1237530
++  * tools lib lk: Uninclude linux/magic.h in debugfs.c
++    - LP: #1237530
++  * x86, efi: Don't map Boot Services on i386
++    - LP: #1237530
++  * mei: make me client counters less error prone
++    - LP: #1237530
++  * mei: bus: stop wait for read during cl state transition
++    - LP: #1237530
++  * mei: cancel stall timers in mei_reset
++    - LP: #1237530
++  * tty: Fix SIGTTOU not sent with tcflush()
++    - LP: #1237530
++  * serial: tegra: fix tty-kref leak
++    - LP: #1237530
++  * serial: pch_uart: fix tty-kref leak in rx-error path
++    - LP: #1237530
++  * serial: pch_uart: fix tty-kref leak in dma-rx path
++    - LP: #1237530
++  * ARM: 7837/3: fix Thumb-2 bug in AES assembler code
++    - LP: #1237530
++  * staging: vt6656: [BUG] main_usb.c oops on device_close move flag
++    earlier.
++    - LP: #1237530
++  * staging: vt6656: [BUG] iwctl_siwencodeext return if device not open
++    - LP: #1237530
++  * drm/i915/tv: clear adjusted_mode.flags
++    - LP: #1237530
++  * cw1200: Use a threaded oneshot irq handler for cw1200_spi
++    - LP: #1237530
++  * xhci: Ensure a command structure points to the correct trb on the
++    command ring
++    - LP: #1237530
++  * xhci: Fix oops happening after address device timeout
++    - LP: #1237530
++  * USB: fix PM config symbol in uhci-hcd, ehci-hcd, and xhci-hcd
++    - LP: #1237530
++  * xhci: Fix race between ep halt and URB cancellation
++    - LP: #1237530
++  * USB: OHCI: accept very late isochronous URBs
++    - LP: #1237530
++  * USB: UHCI: accept very late isochronous URBs
++    - LP: #1237530
++  * USB: Fix breakage in ffs_fs_mount()
++    - LP: #1237530
++  * fsl/usb: Resolve PHY_CLK_VLD instability issue for ULPI phy
++    - LP: #1237530
++  * usb: dwc3: pci: add support for BayTrail
++    - LP: #1237530
++  * usb: dwc3: add support for Merrifield
++    - LP: #1237530
++  * usb/core/devio.c: Don't reject control message to endpoint with wrong
++    direction bit
++    - LP: #1237530
++  * driver core : Fix use after free of dev->parent in device_shutdown
++    - LP: #1237530
++  * dm snapshot: workaround for a false positive lockdep warning
++    - LP: #1237530
++  * dm-snapshot: fix performance degradation due to small hash size
++    - LP: #1237530
++  * dm mpath: disable WRITE SAME if it fails
++    - LP: #1237530
++  * drm/i915: preserve pipe A quirk in i9xx_set_pipeconf
++    - LP: #1237530
++  * drm/i915/dp: increase i2c-over-aux retry interval on AUX DEFER
++    - LP: #1237530
++  * drm/radeon/cik: Fix printing of client name on VM protection fault
++    - LP: #1237530
++  * drm/radeon/cik: Fix encoding of number of banks in tiling configuration
++    info
++    - LP: #1237530
++  * drm/radeon/cik: fix overflow in vram fetch
++    - LP: #1237530
++  * drm/radeon: avoid UVD corruption on AGP cards using GPU gart
++    - LP: #1237530
++  * drm/radeon: Make r100_cp_ring_info() and radeon_ring_gfx() safe (v2)
++    - LP: #1237530
++  * drm/radeon: don't set default clocks for SI when DPM is disabled
++    - LP: #1237530
++  * drm/radeon: disable tests/benchmarks if accel is disabled
++    - LP: #1237530
++  * drm/radeon: add missing hdmi callbacks for rv6xx
++    - LP: #1237530
++  * drm/radeon: fix hdmi audio on DCE3.0/3.1 asics
++    - LP: #1237530
++  * hwmon: (applesmc) Check key count before proceeding
++    - LP: #1237530
++  * ALSA: compress: Fix compress device unregister.
++    - LP: #1237530
++  * irq: Always define devm_{request_threaded,free}_irq()
++    - LP: #1237530
++  * Linux 3.11.4
++    - LP: #1237530
++  * ARM: dtsi: enable ahci sata on imx6q platforms
++    - LP: #1240038
++  * nfsd4: fix leak of inode reference on delegation failure
++    - LP: #1240072
++  * HID: fix data access in implement()
++    - LP: #1240072
++  * HID: fix unused rsize usage
++    - LP: #1240072
++  * sh_eth: fix napi_{en|dis}able() calls racing against interrupts
++    - LP: #1240072
++  * caif: Add missing braces to multiline if in cfctrl_linkup_request
++    - LP: #1240072
++  * tcp: Add missing braces to do_tcp_setsockopt
++    - LP: #1240072
++  * ipv6/exthdrs: accept tlv which includes only padding
++    - LP: #1240072
++  * net: fib: fib6_add: fix potential NULL pointer dereference
++    - LP: #1240072
++  * net: sctp: fix bug in sctp_poll for SOCK_SELECT_ERR_QUEUE
++    - LP: #1240072
++  * net: sctp: fix smatch warning in sctp_send_asconf_del_ip
++    - LP: #1240072
++  * net: fix multiqueue selection
++    - LP: #1240072
++  * net: flow_dissector: fix thoff for IPPROTO_AH
++    - LP: #1240072
++  * net_sched: htb: fix a typo in htb_change_class()
++    - LP: #1240072
++  * r8169: enforce RX_MULTI_EN for the 8168f.
++    - LP: #1240072
++  * netpoll: Should handle ETH_P_ARP other than ETH_P_IP in
++    netpoll_neigh_reply
++    - LP: #1240072
++  * netpoll: fix NULL pointer dereference in netpoll_cleanup
++    - LP: #1240072
++  * tuntap: correctly handle error in tun_set_iff()
++    - LP: #1240072
++  * net: sctp: fix ipv6 ipsec encryption bug in sctp_v6_xmit
++    - LP: #1240072
++  * xen-netback: count number required slots for an skb more carefully
++    - LP: #1240072
++  * resubmit bridge: fix message_age_timer calculation
++    - LP: #1240072
++  * bridge: Clamp forward_delay when enabling STP
++    - LP: #1240072
++  * bridge: use br_port_get_rtnl within rtnl lock
++    - LP: #1240072
++  * bridge: fix NULL pointer deref of br_port_get_rcu
++    - LP: #1240072
++  * ip6_tunnels: raddr and laddr are inverted in nl msg
++    - LP: #1240072
++  * net: sctp: rfc4443: do not report ICMP redirects to user space
++    - LP: #1240072
++  * ethernet/arc/arc_emac: Fix huge delays in large file copies
++    - LP: #1240072
++  * vxlan: Avoid creating fdb entry with NULL destination
++    - LP: #1240072
++  * batman-adv: set the TAG flag for the vid passed to BLA
++    - LP: #1240072
++  * net:dccp: do not report ICMP redirects to user space
++    - LP: #1240072
++  * ip: use ip_hdr() in __ip_make_skb() to retrieve IP header
++    - LP: #1240072
++  * ip: generate unique IP identificator if local fragmentation is allowed
++    - LP: #1240072
++  * skge: fix invalid value passed to pci_unmap_sigle
++    - LP: #1240072
++  * ipv6: udp packets following an UFO enqueued packet need also be handled
++    by UFO
++    - LP: #1240072
++  * via-rhine: fix VLAN priority field (PCP, IEEE 802.1p)
++    - LP: #1240072
++  * IPv6 NAT: Do not drop DNATed 6to4/6rd packets
++    - LP: #1240072
++  * net: net_secret should not depend on TCP
++    - LP: #1240072
++  * ip_tunnel: Do not use stale inner_iph pointer.
++    - LP: #1240072
++  * dm9601: fix IFF_ALLMULTI handling
++    - LP: #1240072
++  * bonding: Fix broken promiscuity reference counting issue
++    - LP: #1240072
++  * ipv6: gre: correct calculation of max_headroom
++    - LP: #1240072
++  * ipv4 igmp: use in_dev_put in timer handlers instead of __in_dev_put
++    - LP: #1240072
++  * ipv6 mcast: use in6_dev_put in timer handlers instead of __in6_dev_put
++    - LP: #1240072
++  * ll_temac: Reset dma descriptors indexes on ndo_open
++    - LP: #1240072
++  * ip_tunnel: Fix a memory corruption in ip_tunnel_xmit
++    - LP: #1240072
++  * ip_tunnel_core: Change __skb_push back to skb_push
++    - LP: #1240072
++  * sit: allow to use rtnl ops on fb tunnel
++    - LP: #1240072
++  * ip6tnl: allow to use rtnl ops on fb tunnel
++    - LP: #1240072
++  * avr32: fix clockevents kernel warning
++    - LP: #1240072
++  * regulator: ti-abb: Fix bias voltage glitch in transition to bypass mode
++    - LP: #1240072
++  * fs/binfmt_elf.c: prevent a coredump with a large vm_map_count from
++    Oopsing
++    - LP: #1240072
++  * gpio/omap: maintain GPIO and IRQ usage separately
++    - LP: #1240072
++  * gpio/omap: auto-setup a GPIO when used as an IRQ
++    - LP: #1240072
++  * ASoC: max98095: a couple array underflows
++    - LP: #1240072
++  * ASoC: 88pm860x: array overflow in snd_soc_put_volsw_2r_st()
++    - LP: #1240072
++  * ASoC: ab8500-codec: info leak in anc_status_control_put()
++    - LP: #1240072
++  * ARM: kvm: rename cpu_reset to avoid name clash
++    - LP: #1240072
++  * ARM: mach-integrator: Add stub for pci_v3_early_init() for !CONFIG_PCI
++    - LP: #1240072
++  * iommu/arm-smmu: fix a signedness bug
++    - LP: #1240072
++  * iommu/arm-smmu: fix iommu_present() test in init
++    - LP: #1240072
++  * iommu/arm-smmu: don't enable SMMU device until probing has completed
++    - LP: #1240072
++  * powerpc/iommu: Use GFP_KERNEL instead of GFP_ATOMIC in
++    iommu_init_table()
++    - LP: #1240072
++  * powerpc/perf: Fix handling of FAB events
++    - LP: #1240072
++  * powerpc/tm: Switch out userspace PPR and DSCR sooner
++    - LP: #1240072
++  * powerpc/tm: Turn interrupts hard off in tm_reclaim()
++    - LP: #1240072
++  * powerpc/vio: Fix modalias_show return values
++    - LP: #1240072
++  * powerpc: Fix parameter clobber in csum_partial_copy_generic()
++    - LP: #1240072
++  * powerpc: Fix memory hotplug with sparse vmemmap
++    - LP: #1240072
++  * powerpc/sysfs: Disable writing to PURR in guest mode
++    - LP: #1240072
++  * powerpc: Restore registers on error exit from
++    csum_partial_copy_generic()
++    - LP: #1240072
++  * fuse: wait for writeback in fuse_file_fallocate()
++    - LP: #1240072
++  * fuse: fix fallocate vs. ftruncate race
++    - LP: #1240072
++  * brcmfmac: obtain platform data upon module initialization
++    - LP: #1240072
++  * Bluetooth: Fix security level for peripheral role
++    - LP: #1240072
++  * Bluetooth: Fix encryption key size for peripheral role
++    - LP: #1240072
++  * Bluetooth: Add a new PID/VID 0cf3/e005 for AR3012.
++    - LP: #1240072
++  * Bluetooth: Add support for BCM20702A0 [0b05, 17cb]
++    - LP: #1240072
++  * Bluetooth: Introduce a new HCI_RFKILLED flag
++    - LP: #1240072
++  * Bluetooth: Fix rfkill functionality during the HCI setup stage
++    - LP: #1240072
++  * nilfs2: fix issue with race condition of competition between segments
++    for dirty blocks
++    - LP: #1240072
++  * ipc/sem.c: fix race in sem_lock()
++    - LP: #1240072
++  * ipc,msg: prevent race with rmid in msgsnd,msgrcv
++    - LP: #1240072
++  * ipc: fix race with LSMs
++    - LP: #1240072
++  * sparc64: Fix buggy strlcpy() conversion in ldom_reboot().
++    - LP: #1240072
++  * sparc: fix ldom_reboot buffer overflow harder
++    - LP: #1240072
++  * sparc64: Remove RWSEM export leftovers
++    - LP: #1240072
++  * sparc64: Fix ITLB handler of null page
++    - LP: #1240072
++  * esp_scsi: Fix tag state corruption when autosensing.
++    - LP: #1240072
++  * sparc64: Fix off by one in trampoline TLB mapping installation loop.
++    - LP: #1240072
++  * sparc64: Fix not SRA'ed %o5 in 32-bit traced syscall
++    - LP: #1240072
++  * sparc32: Fix exit flag passed from traced sys_sigreturn
++    - LP: #1240072
++  * mm: Fix generic hugetlb pte check return type.
++    - LP: #1240072
++  * mm/bounce.c: fix a regression where MS_SNAP_STABLE (stable pages
++    snapshotting) was ignored
++    - LP: #1240072
++  * kernel/kmod.c: check for NULL in call_usermodehelper_exec()
++    - LP: #1240072
++  * staging: comedi: ni_65xx: (bug fix) confine insn_bits to one subdevice
++    - LP: #1240072
++  * NFSv4.1: nfs4_fl_prepare_ds - fix bugs when the connect attempt fails
++    - LP: #1240072
++  * mwifiex: fix NULL pointer dereference in usb suspend handler
++    - LP: #1240072
++  * mwifiex: fix hang issue for USB chipsets
++    - LP: #1240072
++  * mwifiex: fix PCIe hs_cfg cancel cmd timeout
++    - LP: #1240072
++  * usb: chipidea: add Intel Clovertrail pci id
++    - LP: #1240072
++  * USB: serial: option: Ignore card reader interface on Huawei E1750
++    - LP: #1240072
++  * xen/hvc: allow xenboot console to be used again
++    - LP: #1240072
++  * ib_srpt: Destroy cm_id before destroying QP.
++    - LP: #1240072
++  * ib_srpt: always set response for task management
++    - LP: #1240072
++  * rtlwifi: Align private space in rtl_priv struct
++    - LP: #1240072
++  * p54usb: add USB ID for Corega WLUSB2GTST USB adapter
++    - LP: #1240072
++  * mm: avoid reinserting isolated balloon pages into LRU lists
++    - LP: #1240072
++  * iscsi-target: Only perform wait_for_tasks when performing shutdown
++    - LP: #1240072
++  * net: Update the sysctl permissions handler to test effective uid/gid
++    - LP: #1240072
++  * irq: Force hardirq exit's softirq processing on its own stack
++    - LP: #1240072
++  * drm/radeon: fix hdmi callbacks for rv6xx (incorrectly added to r520)
++    - LP: #1240072
++  * dmaengine: imx-dma: fix lockdep issue between irqhandler and tasklet
++    - LP: #1240072
++  * dmaengine: imx-dma: fix callback path in tasklet
++    - LP: #1240072
++  * dmaengine: imx-dma: fix slow path issue in prep_dma_cyclic
++    - LP: #1240072
++  * ACPI / IPMI: Fix atomic context requirement of ipmi_msg_handler()
++    - LP: #1240072
++  * xfs: fix node forward in xfs_node_toosmall
++    - LP: #1240072
++  * drm/nouveau/bios/init: stub opcode 0xaa
++    - LP: #1240072
++  * ARM: tegra: unify Tegra's Kconfig a bit more
++    - LP: #1240072
++  * ALSA: hda - Fix GPIO for Acer Aspire 3830TG
++    - LP: #1240072
++  * ARM: multi_v7_defconfig: enable ARM_ATAG_DTB_COMPAT
++    - LP: #1240072
++  * HID: wiimote: fix FF deadlock
++    - LP: #1240072
++  * mmc: fix null pointer use in mmc_blk_remove_req
++    - LP: #1240072
++  * tile: use a more conservative __my_cpu_offset in CONFIG_PREEMPT
++    - LP: #1240072
++  * s390: fix system call restart after inferior call
++    - LP: #1240072
++  * Btrfs: reset ret in record_one_backref
++    - LP: #1240072
++  * Btrfs: change how we queue blocks for backref checking
++    - LP: #1240072
++  * Btrfs: skip subvol entries when checking if we've created a dir already
++    - LP: #1240072
++  * Btrfs: remove ourselves from the cluster list under lock
++    - LP: #1240072
++  * HID: roccat: add support for KonePureOptical v2
++    - LP: #1240072
++  * HID: add Holtek USB ID 04d9:a081 SHARKOON DarkGlider
++    - LP: #1240072
++  * HID: uhid: add devname module alias
++    - LP: #1240072
++  * HID: uhid: allocate static minor
++    - LP: #1240072
++  * net: qmi_wwan: add new Qualcomm devices
++    - LP: #1240072
++  * bcache: Fix a null ptr deref regression
++    - LP: #1240072
++  * Linux 3.11.5
++    - LP: #1240072
++  * ALSA: snd-usb-usx2y: remove bogus frame checks
++    - LP: #1242700
++  * ALSA: hda - hdmi: Fix channel map switch not taking effect
++    - LP: #1242700
++  * ALSA: hda - Add fixup for ASUS N56VZ
++    - LP: #1242700
++  * ALSA: hda - Fix microphone for Sony VAIO Pro 13 (Haswell model)
++    - LP: #1227093, #1242700
++  * random: run random_int_secret_init() run after all late_initcalls
++    - LP: #1242700
++  * vfs: allow O_PATH file descriptors for fstatfs()
++    - LP: #1242700
++  * i2c: omap: Clear ARDY bit twice
++    - LP: #1242700
++  * hwmon: (applesmc) Always read until end of data
++    - LP: #1242700
++  * Btrfs: use right root when checking for hash collision
++    - LP: #1242700
++  * ext4: fix memory leak in xattr
++    - LP: #1242700
++  * KVM: PPC: Book3S HV: Fix typo in saving DSCR
++    - LP: #1242700
++  * parisc: fix interruption handler to respect pagefault_disable()
++    - LP: #1242700
++  * ARC: Fix __udelay calculation
++    - LP: #1242700
++  * ARC: Handle zero-overhead-loop in unaligned access handler
++    - LP: #1242700
++  * ARC: Fix 32-bit wrap around in access_ok()
++    - LP: #1242700
++  * ARC: Workaround spinlock livelock in SMP SystemC simulation
++    - LP: #1242700
++  * ARC: Fix signal frame management for SA_SIGINFO
++    - LP: #1242700
++  * ARC: Ignore ptrace SETREGSET request for synthetic register "stop_pc"
++    - LP: #1242700
++  * watchdog: ts72xx_wdt: locking bug in ioctl
++    - LP: #1242700
++  * watchdog: kempld_wdt: Fix bit mask definition
++    - LP: #1242700
++  * MIPS: stack protector: Fix per-task canary switch
++    - LP: #1242700
++  * drm/radeon/dpm/btc: off by one in btc_set_mc_special_registers()
++    - LP: #1242700
++  * compiler/gcc4: Add quirk for 'asm goto' miscompilation bug
++    - LP: #1242700
++  * ALSA: hda - Fix mono speakers and headset mic on Dell Vostro 5470
++    - LP: #1236228, #1242700
++  * drm/i915/hsw: Disable L3 caching of atomic memory operations.
++    - LP: #1242700
++  * drm/i915: Only apply DPMS to the encoder if enabled
++    - LP: #1242700
++  * drm/i915: fix rps.vlv_work initialization
++    - LP: #1242700
++  * drm/radeon/dpm: off by one in si_set_mc_special_registers()
++    - LP: #1242700
++  * drm/radeon: forever loop on error in radeon_do_test_moves()
++    - LP: #1242700
++  * drm/radeon: fix typo in CP DMA register headers
++    - LP: #1242700
++  * drm/radeon: fix hw contexts for SUMO2 asics
++    - LP: #1242700
++  * ipc,shm: introduce lockless functions to obtain the ipc object
++    - LP: #1242700
++  * ipc,shm: shorten critical region in shmctl_down
++    - LP: #1242700
++  * ipc: drop ipcctl_pre_down
++    - LP: #1242700
++  * ipc,shm: introduce shmctl_nolock
++    - LP: #1242700
++  * ipc,shm: make shmctl_nolock lockless
++    - LP: #1242700
++  * ipc,shm: shorten critical region for shmctl
++    - LP: #1242700
++  * ipc,shm: cleanup do_shmat pasta
++    - LP: #1242700
++  * ipc,shm: shorten critical region for shmat
++    - LP: #1242700
++  * ipc: rename ids->rw_mutex
++    - LP: #1242700
++  * ipc,msg: drop msg_unlock
++    - LP: #1242700
++  * ipc: document general ipc locking scheme
++    - LP: #1242700
++  * ipc, shm: guard against non-existant vma in shmdt(2)
++    - LP: #1242700
++  * ipc: drop ipc_lock_by_ptr
++    - LP: #1242700
++  * ipc, shm: drop shm_lock_check
++    - LP: #1242700
++  * ipc: drop ipc_lock_check
++    - LP: #1242700
++  * ipc/sem.c: optimize sem_lock()
++    - LP: #1242700
++  * ipc/sem.c: synchronize the proc interface
++    - LP: #1242700
++  * ipc/sem.c: update sem_otime for all operations
++    - LP: #1242700
++  * x86: avoid remapping data in parse_setup_data()
++    - LP: #1242700
++  * Linux 3.11.6
++    - LP: #1242700
++
++ -- Brad Figg <brad.figg@canonical.com>  Mon, 21 Oct 2013 10:21:14 -0700
++
++linux (3.11.0-12.19) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] fix linux-libc-dev generation for arm64
++  * [Config] fix linux-libc-dev generation for x32
++  * [Config] add linux-libc-dev generation for ppc64el
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 09 Oct 2013 12:33:07 +0100
++
++linux (3.11.0-12.18) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packing] tools -- when tools are off they are off
++  * [config] tools -- linux-tools-common really is common
++  * [Packaging] tools -- make cpupower optional
++  * [Packaging] tools -- fix crosscompilation
++  * [config] tools -- enable cpupower
++  * SAUCE: storvsc -- host takes MAINTENANCE_IN commands badly elide them
++    - LP: #1234417
++
++  [ John Johansen ]
++
++  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
++    - LP: #1208988
++  * SAUCE: apparmor: allocate path lookup buffers during init
++    - LP: #1208988
++  * SAUCE: apparmor: fix memleak of the profile hash
++    - LP: #1235523
++  * SAUCE: apparmor: fix memleak of replacedby struct
++    - LP: #1235973
++  * SAUCE: apparmor: fix bad lock balance when introspecting policy
++    - LP: #1235977
++
++  [ Paolo Pisati ]
++
++  * [Config] arm: VIRTIO_[BLK|NET|MMIO]=y
++
++  [ Rob Herring ]
++
++  * SAUCE: (no-up) net: calxedaxgmac: fix clearing of old filter addresses
++    - LP: #1235272
++  * SAUCE: (no-up) net: calxedaxgmac: add uc and mc filter addresses in
++    promiscuous mode
++    - LP: #1235272
++  * SAUCE: (no-up) net: calxedaxgmac: determine number of address filters
++    at runtime
++    - LP: #1235272
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ANDROID=n
++    - LP: #1235161
++  * [Config] CONFIG_L2TP_V3=y
++    - LP: #1235914
++  * Release tracker
++    - LP: #1236999
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "HID: core: fix reporting of raw events"
++    - LP: #1218004
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Oct 2013 13:08:59 +0100
++
++linux (3.11.0-11.17) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] tools -- only build common tools package in master
++  * SAUCE: tools -- report when tool is not available
++    - LP: #1233376
++  * [Packaging] tools -- common tools must carry all possible tools
++    - LP: #1233376
++
++  [ Colin Ian King ]
++
++  * [Config] Fix power and performance regression
++    - LP: #1233681
++
++  [ Colin Watson ]
++
++  * [Config] Clean up various udeb Provides
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11.3
++  * Release tracker
++    - LP: #1233808
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Add CS4208 codec support for MacBook 6,1 and 6,2
++    - LP: #1233623
++  * ALSA: hda - Add fixup for MacBook Air 6,1 and 6,2 with CS4208 codec
++    - LP: #1233623
++  * NVMe: Remove "process_cq did something" message
++    - LP: #1233686
++  * Drivers: hv: balloon: Initialize the transaction ID just before sending the packet
++    - LP: #1233466
++  * cciss: fix info leak in cciss_ioctl32_passthru()
++    - LP: #1188355
++    - CVE-2013-2147
++  * cpqarray: fix info leak in ida_locked_ioctl()
++    - LP: #1188355
++    - CVE-2013-2147
++  * Drivers: hv: util: Fix a bug in version negotiation code for util services
++    - LP: #1233433
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 01 Oct 2013 07:24:27 -0600
++
++linux (3.11.0-9.16) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ
++    CAPACITY (16) at SPC-2"
++  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at
++    SPC-2"
++  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request READ
++    CAPACITY (16) be preferred"
++  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request VPD pages
++    be used at SPC-2"
++
++  [ Seth Forshee ]
++
++  * SAUCE: (no-up) ACPI: Disable Windows 8 compatibility for some Lenovo
++    ThinkPads
++    - LP: #1183856
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_CRYPTO_CRCT10DIF=y, CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
++  * [packaging] Bump ABI for every new release
++  * rebase to v3.11.2
++  * Release tracker
++    - LP: #1231999
++
++
++  [ Upstream Kernel Changes ]
++
++  * scsi: hyper-v storsvc switch up to SPC-3
++  * perf/x86: Add Silvermont (22nm Atom) support
++    - LP: #1091539
++  * perf/x86/intel: Fix Silvermont offcore masks
++    - LP: #1091539
++  * modules: add support for soft module dependencies
++    - LP: #1188010
++  * Reinstate "crypto: crct10dif - Wrap crc_t10dif function all to use
++    crypto transform framework"
++    - LP: #1188010
++  * skge: fix broken driver
++    - LP: #1216745
++  * Input: cypress_ps2 - Return zero finger count if palm is detected.
++    - LP: #1229361
++  * udf: Standardize return values in mount sequence
++    - LP: #1228751
++  * udf: Refuse RW mount of the filesystem instead of making it RO
++    - LP: #1228751
++  * rebase to v3.11.2
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Sep 2013 07:41:07 -0600
++
++linux (3.11.0-8.15) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1227969
++
++  * Update lttng
++    Updated to git://git.lttng.org/lttng-modules.git 9998f5216f4641a79e158135
++    Version 2.3.0+
++
++  [ Upstream Kernel Changes ]
++
++  * igb: Add additional get_phy_id call for i354 devices
++    - LP: #1219619
++  * igb: Read flow control for i350 from correct EEPROM section
++    - LP: #1219619
++  * timekeeping: Fix HRTICK related deadlock from ntp lock changes
++    Required for lttng update.
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Sep 2013 07:41:49 -0600
++
++linux (3.11.0-7.14) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] sort out linux-tools naming
++    - LP: #1205284
++  * [Packaging] linux-tools: switch to common generic version helper
++
++  [ Paolo Pisati ]
++
++  * [Config] highbank: ecx1000: CPU_IDLE causes instabilities, disable it
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1226160
++
++  [ Tony Lindgren ]
++
++  * SAUCE: ARM: dts: Fix muxing and regulator for wl12xx on the SDIO bus
++    for pandaboard
++
++  [ Upstream Kernel Changes ]
++
++  * USB: handle LPM errors during device suspend correctly
++    - LP: #1011415
++  * usb: don't check pm qos NO_POWER_OFF flag in usb_port_suspend()
++    - LP: #1011415
++  * usb: Don't fail port power resume on device disconnect.
++    - LP: #1011415
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Sep 2013 07:30:17 -0600
++
++linux (3.11.0-7.13) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1223545
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: (no-up) scsi: add scsi device flag to request VPD pages be used at SPC-2
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: add scsi device flag to request READ CAPACITY (16) be preferred
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at SPC-2
++    - LP: #1223499
++  * SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ CAPACITY (16) at SPC-2
++    - LP: #1223499
++
++  [ Maximiliano Curia ]
++
++  * SAUCE: (no-up) Only let characters through when there are active readers.
++    - LP: #1208740
++
++  [ Tim Gardner ]
++
++  * [Debian] getabis: Commit new ABI directory, remove the old
++  * [Config] CONFIG_EFIVAR_FS=y
++    - LP: #1223195
++  * [Config] CONFIG_EFI_VARS_PSTORE=m,
++    CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=n
++  * SAUCE: (no-up) USB: input: cm109.c: Convert high volume dev_err() to dev_err_ratelimited()
++    - LP: #1222850
++
++  [ Upstream Kernel Changes ]
++
++  * Intel xhci: refactor EHCI/xHCI port switching
++    - LP: #1210858
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 10 Sep 2013 09:00:19 -0600
++
++linux (3.11.0-6.12) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1222893
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
++  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
++  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
++    - LP: #1222407
++
++  [ Paolo Pisati ]
++
++  * [Config] restore mmc boot on panda
++
++  [ Tyler Hicks ]
++
++  * SAUCE: apparmor: Use shash crypto API interface for profile hashes
++    - LP: #1216294
++
++  [ Upstream Kernel Changes ]
++
++  * net: calxedaxgmac: remove NETIF_F_FRAGLIST setting
++  * net: calxedaxgmac: read correct field in xgmac_desc_get_buf_len
++  * net: calxedaxgmac: fix race between xgmac_tx_complete and xgmac_tx_err
++  * net: calxedaxgmac: fix possible skb free before tx complete
++  * net: calxedaxgmac: update ring buffer tx_head after barriers
++  * net: calxedaxgmac: fix race with tx queue stop/wake
++  * net: calxedaxgmac: enable interrupts after napi_enable
++  * net: calxedaxgmac: fix various errors in xgmac_set_rx_mode
++  * net: calxedaxgmac: remove some unused statistic counters
++  * net: calxedaxgmac: fix rx DMA mapping API size mismatches
++  * net: calxedaxgmac: fix xgmac_xmit DMA mapping error handling
++  * mfd: rtsx: Read vendor setting from config space
++    - LP: #1201698
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Sep 2013 07:21:06 -0600
++
++linux (3.11.0-5.11) saucy; urgency=low
++
++  * Release tracker
++    - LP: #1221886
++
++  [ Adam Lee ]
++
++  * SAUCE: Bluetooth: Add support for 04ca:2007
++    - LP: #1153448
++  * SAUCE: Bluetooth: Add support for 105b:e065
++    - LP: #1161261
++
++  [ Gavin Guo ]
++
++  * SAUCE: Bluetooth: Add support for Broadcom 413c:8143
++    - LP: #1166113
++
++  [ Upstream Kernel Changes ]
++
++  * igb: Reset the link when EEE setting changed
++    - LP: #1219619
++  * igb: Read register for latch_on without return value
++    - LP: #1219619
++  * igb: Added rcu_lock to avoid race
++    - LP: #1219619
++  * igb: don't allow SR-IOV without MSI-X
++    - LP: #1219619
++  * igb: Update MTU so that it is always at least a standard frame size
++    - LP: #1219619
++  * igb: Refactor of init_nvm_params
++    - LP: #1219619
++  * igb: Refactor NVM read functions to accommodate devices with no flash
++    - LP: #1219619
++  * igb: Add device support for flashless SKU of i210 device
++    - LP: #1219619
++  * igb: Fix get_fw_version function for all parts
++    - LP: #1219619
++  * igb: Add macro for size of RETA indirection table
++    - LP: #1219619
++  * igb: Expose RSS indirection table for ethtool
++    - LP: #1219619
++  * igb: Don't look for a PBA in the iNVM when flashless
++    - LP: #1219619
++  * igb: Implementation of 1-sec delay for i210 devices
++    - LP: #1219619
++  * igb: New PHY_ID for i354 device
++    - LP: #1219619
++  * igb: M88E1543 PHY downshift implementation
++    - LP: #1219619
++  * igb: No PHPM support in i354 devices
++    - LP: #1219619
++  * igb: Support to get 2_5G link status for appropriate media type
++    - LP: #1219619
++  * igb: Get speed and duplex for 1G non_copper devices
++    - LP: #1219619
++  * igb: Implementation to report advertised/supported link on i354 devices
++    - LP: #1219619
++  * igb: Update version number
++    - LP: #1219619
++  * Bluetooth: Take proper tty_struct references
++    - LP: #1189998
++  * Bluetooth: Remove the device from the list in the destructor
++    - LP: #1189998
++  * Bluetooth: Move the tty initialization and cleanup out of open/close
++    - LP: #1189998
++  * Bluetooth: Implement .activate, .shutdown and .carrier_raised methods
++    - LP: #1189998
++  * Bluetooth: Fix the reference counting of tty_port
++    - LP: #1189998
++  * Bluetooth: Purge the dlc->tx_queue to avoid circular dependency
++    - LP: #1189998
++
++  [ Wen-chien Jesse Sung ]
++
++  * SAUCE: Bluetooth: Support for loading broadcom patchram firmware
++    - LP: #1065400
++  * SAUCE: Bluetooth: Add support for 13d3:3388 and 13d3:3389
++    - LP: #1065400
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Sep 2013 08:06:17 -0600
++
++linux (3.11.0-5.10) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release tracker
++    - LP: #1220222
++  * Revert "[Config] Fix ubuntu directoy Kbuilds"
++  * Revert "aufs update dropped some Kbuild files"
++  * Revert "ubuntu: AUFS -- follow rename of loop.h into drivers/block"
++  * Revert "ubuntu: AUFS -- update to
++    8e503d4142c189ed6c47a2177ad2cd058e8d340e"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
++  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
++  * rebase to v3.11 final
++  * [Config] clean up ubuntu/Kconfig and ubuntu/Makefile
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
++  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
++  * ubuntu: AUFS -- update to 5ac5fe26a90a818218310e208d17688fddb07622
++  * ubuntu: (no-squash) AUFS -- enable aufs
++  * ubuntu: AUFS -- fix remaining d_count references to use accessor
++  * ubuntu: lttng -- follow rename of pid_ns
++  * SAUCE: disable stack-protector for ARM compressed bootloader
++
++  [ Paolo Pisati ]
++
++  * [Config] ARM_ATAG_DTB_COMPAT=y
++
++  [ Rob Herring ]
++
++  * [Config] Enable KVM and virtio for armhf generic-lpae
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ARPD=y
++  * [Config] CONFIG_ZSWAP=y
++    - LP: #1215379
++
++  [ Upstream Kernel Changes ]
++
++  * uvcvideo: quirk PROBE_DEF for Dell SP2008WFP monitor.
++    - LP: #1217957
++  * ARM: use phys_addr_t for DMA zone sizes
++  * ARM: highbank: enable DMA zone for LPAE
++  * ARM: highbank: select ARCH_HAS_HOLES_MEMORYMODEL
++  * ARM: highbank: select required errata work-arounds
++  * DMA: fix AMBA PL08x compilation issue with 64bit DMA address type
++  * DMA: fix printk warning in AMBA PL08x DMA driver
++  * ARM: highbank: select ARCH_DMA_ADDR_T_64BIT for LPAE
++  * ARM: move outer_cache declaration out of ifdef
++  * ARM: highbank: avoid L2 cache smc calls when PL310 is not present
++  * ARM: highbank: clean-up some unused includes
++  * ARM: xen: only set pm function ptrs for Xen guests
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 03 Sep 2013 17:08:06 +0100
++
++linux (3.11.0-4.9) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc7
++  * Release tracker
++    - LP: #1216962
++
++  [ Upstream Kernel Changes ]
++
++  * mwifiex: do not create AP and P2P interfaces upon driver loading
++    - LP: #1212720
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 Aug 2013 06:25:35 -0600
++
++linux (3.11.0-3.8) saucy; urgency=low
++
++  [ Johannes Berg ]
++
++  * SAUCE: mac80211: ignore (E)CSA in probe response frames
++    - LP: #1201470
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Aug 2013 09:47:36 -0600
++
++linux (3.11.0-3.7) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: (no-up) hv_vss_daemon -- prevent self-daemonising to allow
++    upstart to track
++  * SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the local
++    linux/hyperv.h
++  * SAUCE: hv: Add vss daemon to Makefile
++  * [Debian] Add hv_vss_daemon to tools package
++    - LP: #1213282
++  * [Config] Fix ubuntu directoy Kbuilds
++    - LP: #1181755
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Aug 2013 08:34:05 -0600
++
++linux (3.11.0-3.6) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] tools: conditionalise x86 and hyper-v tools sensibly
++  * [Config] tools: enable x86 and hyper-v
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable
++    snapshot"
++  * Revert "SAUCE: (no-up) apparmor: fix apparmor module status for none
++    root users"
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: (no-up) intel_ips: blacklist ASUSTek G60JX laptops
++    - LP: #1210848
++
++  [ Kamal Mostafa ]
++
++  * [debian] tools: ship 'cpupower' in linux-tools
++    - LP: #1158668
++  * [Config] Build-dep on libpci-dev for cpu tools
++    - LP: #1158668
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc6
++  * Release tracker
++    - LP: #1213941
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 Aug 2013 07:02:07 -0600
++
++linux (3.11.0-2.5) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_PM_DEBUG=y
++    - LP: #1210539
++  * rebase to v3.11-rc5
++  * Release tracker
++    - LP: #1211378
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 12 Aug 2013 06:10:39 -0600
++
++linux (3.11.0-1.4) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Bump ABI when making changes to the inclusion list lest
++    you cause conflicts with existing installed kernel
++    packages.
++    - LP: #1210331
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 09 Aug 2013 03:03:51 +0100
++
++linux (3.11.0-0.3) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Include rbd and kvm in the virtual inclusion list
++    - LP: #1206961
++  * [Config] Removed obsolete inclusion list entries
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Aug 2013 08:52:14 +0100
++
++linux (3.11.0-0.2) saucy; urgency=low
++
++  [ Bruce Allan ]
++
++  * SAUCE: (no-up) e1000e: fix I217/I218 PHY initialization flow
++    - LP: #1206757
++  * SAUCE: (no-up) e1000e: enable support for new device IDs
++    - LP: #1206757
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
++
++  [ Paolo Pisati ]
++
++  * build vexpress a15 dtb
++  * [Config] disable Broadcom bcm support (ARCH_BCM)
++  * [Config] disable Allwinner a1x support (ARCH_SUNXI)
++  * [Config] disable WonderMedia WM8850 support (ARCH_WM8850)
++  * [Config] disable Rockchip support (ARCH_ROCKCHIP)
++  * [Config] disable STMicroelectronics STiH41x SOCs (ARCH_STI)
++  * [Config] disable TI Keystone, AM43xx and OMAP5 support
++  * [Config] ARM_APPENDED_DTB=y
++
++  [ Tim Gardner ]
++
++  * rebase to v3.11-rc4
++  * overlayfs: Update to v19
++  * [Config] Enable overlayfs
++  * SAUCE: Fix lttng compile errors
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.11-rc4
++    - LP: #1163720
++    - LP: #1162026
++    - LP: #1195636
++    - LP: #1195597
++    - LP: #1180409
++    - LP: #1168430
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Sun, 04 Aug 2013 03:45:31 -0600
++
++linux (3.11.0-0.1) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 64ccccf8525fee499625b517c0faadf784c79e93
++    - LP: #1163720
++    - LP: #1162026
++    - LP: #1195636
++    - LP: #1195597
++    - LP: #1180409
++    - LP: #1168430
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 08 Jul 2013 08:50:46 -0600
++
++linux (3.10.0-2.10) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_INTEL_MEI*=m
++    - LP: #1196155
++  * [Config] CONFIG_DEBUG_INFO=y
++
++  [ Stephen Warren ]
++
++  * [Config] fix Calxeda xgmac module filename
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "serial: 8250_pci: add support for another kind of NetMos
++    Technology PCI 9835 Multi-I/O Controller"
++    - LP: #1190967
++  * mfd: lpc_ich: Add support for Intel Avoton SoC
++    - LP: #1196658
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jul 2013 18:08:02 +0100
++
++linux (3.10.0-2.9) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: (no-up) apparmor: Fix quieting of audit messages for
++    network mediation"
++  * Revert "SAUCE: (no-up) apparmor: Fix compile warnings"
++  * Revert "SAUCE: (no-up) AppArmor: basic networking rules"
++  * Revert "SAUCE: (no-up) apparmor: Add the ability to mediate mount"
++  * Revert "SAUCE: (no-up) AppArmor: Add profile introspection file to
++    interface"
++  * Revert "SAUCE: (no-up) AppArmor: Disable Add PR_{GET,SET}_NO_NEW_PRIVS
++    to prevent execve from granting privs"
++  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Jul 2013 17:42:29 +0100
++
++linux (3.10.0-1.8) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Release Tracking Bug
++    - LP: #1195717
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: overlayfs -- follow change to do_splice_direct
++    interface"
++  * Revert "ubuntu: overlayfs -- expose do_splice_direct prototype"
++  * Revert "SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path
++    reference"
++  * Revert "ubuntu: overlayfs -- add FS_ALIAS"
++  * Revert "ubuntu: overlayfs --
++    overlayfs-copy-up-i_uid-i_gid-from-the-underlying-inode"
++  * Revert "ubuntu: overlayfs -- ovl-switch-to-inode_permission"
++  * Revert "ubuntu: overlayfs -- vfs-export-inode_permission-to-modules"
++  * Revert "ubuntu: overlayfs -- overlayfs-create-new-inode-in-ovl_link"
++  * Revert "ubuntu: overlayfs --
++    overlayfs-fix-possible-leak-in-ovl_new_inode"
++  * Revert "ubuntu: overlayfs -- fs-limit-filesystem-stacking-depth"
++  * Revert "ubuntu: overlayfs -- overlay-overlay-filesystem-documentation"
++  * Revert "ubuntu: overlayfs -- overlayfs-implement-show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs-add-statfs-support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- vfs-introduce-clone_private_mount"
++  * Revert "ubuntu: overlayfs -- vfs-export-do_splice_direct-to-modules"
++  * Revert "ubuntu: overlayfs -- vfs-add-i_op-dentry_open"
++  * ubuntu: overlayfs v18 -- -- overlayfs: add statfs support
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs v18 -- -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs v18 -- -- vfs: add i_op->dentry_open()
++  * ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs v18 -- -- vfs: export __inode_permission() to modules
++  * ubuntu: overlayfs v18 -- -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs v18 -- -- overlay filesystem
++  * ubuntu: overlayfs v18 -- -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs v18 -- -- overlay: overlay filesystem documentation
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SUNRPC_DEBUG=y
++    - LP: #1127319
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jun 2013 10:26:52 +0100
++
++linux (3.10.0-0.7) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * autopkgtest: switch Depends: to build-essential
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 25 Jun 2013 08:40:55 +0100
++
++linux (3.10.0-0.6) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_ARCH_TEGRA to fix FTBFS on armhf
++  * SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path reference
++    - LP: #1098378
++  * ubuntu: AUFS -- update to 4f14cef47eb7c23eda7198931fbab1040866b6ee
++  * ubuntu: overlayfs -- expose do_splice_direct prototype
++  * ubuntu: overlayfs -- follow change to do_splice_direct interface
++  * [Config] flip CONFIG_NO_HZ_FULL_ALL off as it is overheating machines
++    - LP: #1192691
++
++  [ Stefan Bader ]
++
++  * (d-i) Add dm-snapshot to md-modules
++    - LP: #1191726
++
++  [ Tim Gardner ]
++
++  * Release tracker
++    - LP: #1194149
++  * [Config] CONFIG_WIL6210=n for armhf
++  * [Config] d-i: Add calxedaxgmac to nic-modules
++    - LP: #1192358
++  * [debian] Use dh_strip
++    - LP: #1192759
++  * [Config] Enable perf for armhf
++  * do_tools=false when cross compiling
++  * [Config] CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
++    - LP: #1108082
++
++  [ Upstream Kernel Changes ]
++
++  * nsp32: switch reset delay to msleep() as it is tooo long
++  * alx: add a simple AR816x/AR817x device driver
++    Plucked from linux-next. replaces ubuntu/alx in favor of
++    'to be merged' version in 3.11.
++  * rebase to v3.10-rc7
++    - LP: #1189363
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Jun 2013 18:10:31 -0600
++
++linux (3.10.0-0.5) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc6
++  * [Config] updateconfigs following rebase to v3.10-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Jun 2013 11:12:39 +0100
++
++linux (3.10.0-0.4) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] updateconfigs following rebase to v3.10-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 11:42:28 +0100
++
++linux (3.10.0-0.3) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc5
++    - LP: #1186170
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 09:23:31 +0100
++
++linux (3.10.0-0.2) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.10-rc4
++  * [Config] CONFIG_BINFMT_SCRIPT=y to fix booting initramfs scripts
++  * [Config] enable SND_PCM_DEBUG SND_PCM_XRUN_DEBUG
++    - LP: #1187744
++  * [Config] enforce CONFIG_BINFMT_SCRIPT=y
++
++  [ Dave Chiluk ]
++
++  * SAUCE: ncpfs: fix rmdir returns Device or resource busy
++    - LP: #1035226
++
++  [ Tim Gardner ]
++
++  * rebase to v3.10-rc3
++  * [Config] sparc be gone
++  * [Config] ia64 be gone
++  * d-i: block-modules provides nbd-modules
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc4
++  * rebase to v3.10-rc3
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 May 2013 06:16:46 -0600
++
++linux (3.10.0-0.1) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * UBUNTU: Disabled lttng
++  * UBUNTU: Disable aufs for FTBS
++  * UBUNTU: Disabled alx
++  * UBUNTU: alx: rename NETIF_F_HW_VLAN_* feature flags to NETIF_F_HW_VLAN_CTAG_*
++  * UBUNTU: rebase to v3.10-rc2
++  * UBUNTU: SAUCE: uvcvideo: quirk PROBE_DEF for Alienware X51 OmniVision webcam
++
++  [ Andy Whitcroft ]
++
++  * UBUNTU: [Config] update standards version to 3.9.4.0
++  * UBUNTU: [Config] squash duplicate package description (long and short)
++  * UBUNTU: [Config] fix up Vcs-git: to point to saucy
++  * UBUNTU: [Config] drop depenancy on util-linux as is Essential
++  * UBUNTU: [Config] drop redundant Build-Conficts:
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc2
++    - LP: #1180351
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.10-rc1
++    - LP: #1172151
++    - LP: #1089795
++    - LP: #1167270
++    - LP: #1128840
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 14 May 2013 13:41:07 -0600
++
++linux (3.10.0-0.0) saucy; urgency=low
++
++  * Dummy
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
++
++linux (3.9.0-2.6) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.9.2
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
++
++linux (3.9.0-1.5) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * rebase to v3.9.1
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Wed, 08 May 2013 12:49:45 -0400
++
++linux (3.9.0-0.4) saucy; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- add FS_ALIAS
++
++  [ Tim Gardner ]
++
++  * Added lttng
++    - LP: #1175784
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 May 2013 17:17:13 -0400
++
++linux (3.9.0-0.3) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 18:20:00 -0400
++
++linux (3.9.0-0.2) saucy; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable extras packaging for amd64/i386.
++    Fixes build depenencies with brittany and linux-meta.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 05:37:01 -0600
++
++linux (3.9.0-0.1) saucy; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc8
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc7
++    - LP: #1128840
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc4
++    - LP: #1095315
++    - LP: #886975
++    - LP: #1086921
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc3
++    - LP: #1155016
++    - LP: #1103594
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc2
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.9-rc1
++    - LP: #901105
++    - LP: #961286
++    - LP: #1011792
++    - LP: #1128934
++    - LP: #886975
++    - LP: #978807
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Feb 2013 09:12:39 -0700
++
++linux (3.8.0-7.14) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_RCU_USER_QS=n
++  * [Config] CONFIG_MTD_ONENAND_SIM=n
++  * annotations: add annotations for CONFIG_CC_STACKPROTECTOR
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1130111
++  * UBUNTU: SAUCE: rt2x00: rt2x00pci_regbusy_read() - only print register access failure once
++    - LP: #1128840
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Feb 2013 09:25:56 -0700
++
++linux (3.8.0-6.13) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1125364
++  * Add ahci modules to d-i
++    - LP: #1124415
++
++
++  [ Chris Wilson ]
++
++  * SAUCE: drm/i915: Wait for pending flips to complete before tearing down
++    the encoders
++    - LP: #1097315
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 12:16:48 -0700
++
++linux (3.8.0-6.12) raring; urgency=low
++
++  [Tim Gardner]
++
++  * perf: NO_LIBPERL=1
++  * Fix linux-headers dependency
++  * Release Tracking Bug
++    - LP: #1124362
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_AUFS_EXPORT to allow nfs exports
++    - LP: #1121699
++
++  [ Daniel Vetter ]
++
++  * SAUCE: drm/i915: write backlight harder
++    - LP: #954661
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 10:25:11 -0700
++
++linux (3.8.0-6.11) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1122071
++  * rebase to v3.8-rc7
++  * Add libaudit-dev as a build dependency
++  * Build perf with NO_LIBPYTHON=1 to avoid a python build dependency.
++
++  [ Leann Ogasawara ]
++
++  * [Config] Remove CONFIG_SATA_AHCI annotation
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Feb 2013 07:41:13 -0500
++
++linux (3.8.0-5.10) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1118568
++
++  * Bump ABI to fix install issue with 3.8.0-4.8.
++    Moving drivers/ata/*ahci* to linux-image caused an
++    install conflict with linux-image-extras without an
++    ABI bump.
++
++  [ Jan Beulich ]
++
++  * SAUCE: xen-pciback: rate limit error messages from
++    xen_pcibk_enable_msi{, x}()
++    - LP: #1117336
++    - CVE-2013-0231
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Feb 2013 05:38:12 -0700
++
++linux (3.8.0-4.9) raring; urgency=low
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * d-i: Add mellanox ethernet drivers to nic-modules
++    - LP: #1015339
++
++  [ Joseph Salisbury ]
++
++  * SAUCE: ACPI: Add DMI entry for Sony VGN-FW41E_H
++    - LP: #1113547
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: alx driver import script
++
++  [ Qualcomm Atheros, Inc ]
++
++  * SAUCE: alx: Update to heads/master
++
++  [ Tim Gardner ]
++
++  * Release Tracking Bug
++    - LP: #1117673
++
++  * [debian] Remove dangling symlink from headers package
++    - LP: #1112442
++  * [config] CONFIG_ALX=m
++  * [Config] Add alx to d-i nic-modules
++  * [Config] CONFIG_SATA_AHCI=m
++    - LP: #1056563
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Feb 2013 05:54:32 -0800
++
++linux (3.8.0-4.8) raring; urgency=low
++
++  [ Allen Ibara ]
++
++  * SAUCE: imx6: dts: Add IMX6Q AHCI support
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.8-rc6
++  * updateconfigs following rebase to v3.8-rc6
++
++  [Leann Ogasawara]
++
++  * Release Tracking Bug
++    - LP: #1112573
++
++  [ Paolo Pisati ]
++
++  * SAUCE: imx6: enable sata clk if SATA_AHCI_PLATFORM
++  * [Config] SERIAL_AMBA_PL011=y (vexpress serial console)
++  * [Config] MMC_ARMMMCI=y (vexpress mmc)
++  * [Config] FB_ARMCLCD=y (vexpress framebuffer)
++
++  [ Seth Forshee ]
++
++  * [Config] CONFIG_MAC80211_MESSAGE_TRACING=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc6
++    - LP: #1107477
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 01 Feb 2013 07:20:59 -0800
++
++linux (3.8.0-3.7) raring; urgency=low
++
++  [ Andy Green ]
++
++  * SAUCE: ARM: OMAP2+: add cpu id register to MAC address helper
++  * SAUCE: ARM: omap2 add mac address allocation register api
++  * SAUCE: ARM: omap2 panda register ethernet and wlan for automatic mac
++    allocation
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.8-rc5
++  * Release Tracking Bug
++    - LP: #1111486
++
++  [ Paolo Pisati ]
++
++  * SAUCE: davinci: vpss: compilation fix
++  * [Config] enable TI OMAP4 support (Pandaboard/ES)
++  * [Config] OMAP_USB2=y (since TWL6030_USB depends on it)
++  * [Config] enable Freescale IMX6 support (SabreLite)
++  * [Config] SERIAL_IMX_CONSOLE=y
++  * [Config] MMC_*_IMX=y
++  * [Config] disable USB_SUSPEND
++  * [Config] USB_MXS_PHY=y
++  * [Config] USB_CHIPIDEA=y
++  * SAUCE: DTB: add support for multiple DTBs
++  * SAUCE: DTB: build imx6q-sabrelite
++  * SAUCE: DTB: build beaglexm
++  * SAUCE: DTB: build panda/panda es
++  * [Config] disable CPU_FREQ
++  * [Config] PANEL_TFP410=y (video DVI output)
++  * [Config] SND_OMAP_SOC*=y
++  * [Config] SND_IMX_SOC*=y
++  * [Config] I2C_IMX=y
++  * [Config] SPI_IMX=m
++
++  [ Stefan Bader ]
++
++  * [Config] Move 9p modules into generic package
++    - LP: #1107658
++
++  [ Tony Lindgren ]
++
++  * SAUCE: ARM: OMAP2+: Limit omap initcalls to omap only on multiplatform
++    kernels
++  * SAUCE: ARM: OMAP2+: Use omap initcalls
++  * SAUCE: ARM: OMAP: Fix i2c cmdline initcall for multiplatform
++  * SAUCE: ARM: OMAP: Fix dmaengine init for multiplatform
++  * SAUCE: ARM: OMAP2+: Add multiplatform debug_ll support
++  * SAUCE: ARM: OMAP2+: Disable code that currently does not work with
++    multiplaform
++  * SAUCE: ARM: OMAP2+: Enable ARCH_MULTIPLATFORM support
++  * SAUCE: ARM: OMAP2+: Add minimal support for booting vexpress
++  * SAUCE: ARM: OMAP2+: Remove now obsolete uncompress.h and debug-macro.S
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc5
++    - LP: #1096789
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Jan 2013 06:44:52 -0800
++
++linux (3.8.0-2.6) raring; urgency=low
++
++  [ Adam Conrad ]
++
++  * Fix up linux-tools -> SRCPKGNAME-tools rename
++
++  [ Andy Whitcroft ]
++
++  * [Config] re-disable CONFIG_SOUND_OSS
++    - LP: #1105230
++
++  [ Arend van Spriel ]
++
++  * SAUCE: brcmsmac: fix tx status processing
++
++  [Leann Ogasawara]
++
++  * Release Tracking Bug
++    - LP: #1105104
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 Jan 2013 11:56:30 -0800
++
++linux (3.8.0-1.5) raring; urgency=low
++
++  [Tim Gardner]
++
++  * Release Tracking Bug
++    - LP: #1101235
++
++  [ Dudley Du ]
++
++  * SAUCE: Input: add support for Cypress PS/2 Trackpads
++    - LP: #978807
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: Input: increase struct ps2dev cmdbuf[] to 8 bytes
++  * SAUCE: Input: Cypress PS/2 Trackpad simulated multitouch
++  * [Config] Add CONFIG_PS2_CYPRESS
++
++  [ Tim Gardner ]
++
++  * rebase to v3.8-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc4
++    - LP: #1095315
++    - LP: #886975
++    - LP: #1086921
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jan 2013 10:50:22 -0800
++
++linux (3.8.0-0.4) raring; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Update CONFIG_TOUCHSCREEN_EGALAX build annotation
++  * [Config] Update CONFIG_IIO build annotation
++  * [Config] Update CONFIG_TOUCHSCREEN_EETI annotation
++  * [Config] Remove CONFIG_SPI_DW_MMIO annotation
++  * [Config] Remove CONFIG_SPI_PL022 annotation
++  * [Config] Update CONFIG_EZX_PCAP annotation
++  * [Config] Update CONFIG_SENSORS_AK8975 annotation
++  * [Config] Disable CONFIG_DRM_MGAG200
++    - LP: #1042903
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 Jan 2013 10:01:50 -0800
++
++linux (3.8.0-0.3) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) trace: add trace events for open(), exec() and
++    uselib()"
++
++  [ Scott James Remnant ]
++
++  * SAUCE: (no-up) trace: add trace events for open(), exec() and uselib()
++    (for v3.7+)
++    - LP: #1085766, #462111
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Jan 2013 16:57:27 +0000
++
++linux (3.8.0-0.2) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [packaging] Add macro to selectively disable building perf
++  * [packaging] Cannot depend on universe package libaudit-dev
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jan 2013 12:43:24 -0700
++
++linux (3.8.0-0.1) raring; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc3
++    - LP: #1096789
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.8-rc2
++    - LP: #1082357
++    - LP: #1075882
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Dec 2012 10:35:09 +0000
++
++linux (3.7.0-7.15) raring; urgency=low
++
++  [ Chris J Arges ]
++
++  * SAUCE: add eeprom_bad_csum_allow module parameter
++    - LP: #1070182
++
++  [ Leann Ogasawara ]
++
++  * Add ceph to linux-image for virtual instances
++    - LP: #1063784
++
++  [ Serge Hallyn ]
++
++  * SAUCE: net: dev_change_net_namespace: send a KOBJ_REMOVED/KOBJ_ADD
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SLUB_DEBUG=y
++    - LP: #1090308
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[SCSI] sd: Implement support for WRITE SAME"
++    - LP: #1089818
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 Dec 2012 06:50:20 -0800
++
++linux (3.7.0-6.14) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] annotations: all new annotations scheme including defaults
++  * [Configs] apply annotation updates to main configs (top section)
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm
++    build"
++  * Revert "SAUCE: [arm] fixup __aeabi_uldivmod undefined build error"
++  * Temporarily disable module check for build
++
++  [ Stefan Bader ]
++
++  * ubuntu: dm-raid45: Adapt to upstream interface changes
++  * Re-enable build of dm-raid45
++
++  [ Tim Gardner ]
++
++  * SAUCE: Moved scripts/fw-to-ihex.sh to debian/scripts/misc
++  * SAUCE: ACPICA: Fix ACPI mutex object allocation memory leak on error
++  * SAUCE: drm: Fix possible EDID memory allocation oops
++  * SAUCE: ttm: Fix possible _manager memory allocation oops
++  * SAUCE: iwlwifi: iwlagn_request_scan: Fix check for priv->scan_request
++  * SAUCE: i915: intel_set_mode: Reduce stack allocation from 500 bytes to
++    2 pointers
++
++  [ Tomas Hozza ]
++
++  * SAUCE: tools: hv: Netlink source address validation allows DoS
++    - LP: #1084777
++    - CVE-2012-5532
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 05 Dec 2012 14:11:12 -0800
++
++linux (3.7.0-5.13) raring; urgency=low
++
++  [ Lino Sanfilippo ]
++
++  * SAUCE: inotify, fanotify: replace fsnotify_put_group() with
++    fsnotify_destroy_group()
++    - LP: #922906
++  * SAUCE: fsnotify: introduce fsnotify_get_group()
++    - LP: #922906
++  * SAUCE: fsnotify: use reference counting for groups
++    - LP: #922906
++  * SAUCE: fsnotify: take groups mark_lock before mark lock
++    - LP: #922906
++  * SAUCE: fanotify: add an extra flag to mark_remove_from_mask that
++    indicates wheather a mark should be destroyed
++    - LP: #922906
++  * SAUCE: fsnotify: use a mutex instead of a spinlock to protect a groups
++    mark list
++    - LP: #922906
++  * SAUCE: fsnotify: pass group to fsnotify_destroy_mark()
++    - LP: #922906
++  * SAUCE: fsnotify: introduce locked versions of fsnotify_add_mark() and
++    fsnotify_remove_mark()
++    - LP: #922906
++  * SAUCE: fsnotify: dont put marks on temporary list when clearing marks
++    by group
++    - LP: #922906
++  * SAUCE: fsnotify: change locking order
++    - LP: #922906
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NFC_LLCP=y
++  * [Config] get-firmware: Filter new files through fwinfo
++  * [Config] CONFIG_MTD_NAND_DOCG4=m for all arches
++  * [Config] CONFIG_DRM_EXYNOS_HDMI=y
++  * [Config] CONFIG_XEN=y for all arches
++  * [Config] CONFIG_SND_OMAP_SOC_ZOOM2=m
++  * [Config] CONFIG_MMC_DW_EXYNOS=m
++  * [Config] CONFIG_GPIO_ADNP=m
++  * [Config] find-obsolete-firmware: Use correct path
++  * rebase to v3.7-rc8
++    - LP: #1084640
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "VFS: don't do protected {sym,hard}links by default"
++    - LP: #1084192
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 28 Nov 2012 16:07:08 +0000
++
++linux (3.7.0-4.12) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "[Config] Use -j1 for headers_install"
++  * Revert "[Config] install-arch-headers needs a valid config"
++    Strayed into the weeds in search of the root cause of the periodic
++    build failure.
++    Fixes powerpc FTBS introduced in -4.11.
++  * [Config] hmake -j1
++    The kernel makefile appears to have parallel dependency
++    problems for the install_headers target. This appears to be root
++    cause for a periodic build failure on N-way machines.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 27 Nov 2012 12:33:06 -0800
++
++linux (3.7.0-4.11) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Use -j1 for headers_install
++    Also fixes a powerpc FTBS introduced by
++    "[Config] install-arch-headers needs a valid config".
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 27 Nov 2012 10:19:30 -0700
++
++linux (3.7.0-4.10) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add rebuild-test support for autopkgtest
++    - LP: #1081500
++  * [tests] move build tests out of the way
++    - LP: #1081500
++  * [tests] add an autopkgtest rebuild test
++    - LP: #1081500
++
++  [ Tim Gardner ]
++
++  * rebase to v3.7-rc7
++  * SAUCE: Remove emi62 files duplicated in linux-firmware
++  * SAUCE: Remove sb16 files duplicated in linux-firmware
++  * SAUCE: Remove whiteheat files duplicated in linux-firmware
++  * SAUCE: Remove yamaha files duplicated in linux-firmware
++  * SAUCE: Remove dsp56k files used only by m68k
++  * SAUCE: firmware: Remove last vestiges of dabusb
++  * SAUCE: Remove vicam files duplicated in linux-firmware
++  * [Config] install-arch-headers needs a valid config
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc7
++    - LP: #1076840
++    - LP: #1081466
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 21 Nov 2012 06:07:23 -0800
++
++linux (3.7.0-3.9) raring; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_X86_CPUFREQ_NFORCE2=y
++    - LP: #1079900
++  * Add nfsv3 to nfs-modules udeb
++
++  [ Paolo Pisati ]
++
++  * [Config] SND_OMAP_SOC*=y
++    - LP: #1019321
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) xen/netfront: handle compound page fragments on transmit
++    - LP: #1078926
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: SECCOMP: audit: always report seccomp violations"
++    - LP: #1079469
++  * Revert "SAUCE: omap3 clocks .dev_id = NULL"
++  * rebase to v3.7-rc6
++  * SAUCE: script to detect obsolete firmware
++  * SAUCE: Remove yam files duplicated in linux-firmware
++  * SAUCE: Remove tehuti files duplicated in linux-firmware
++  * SAUCE: Remove matrox files duplicated in linux-firmware
++  * SAUCE: Remove cxgb3 files duplicated in linux-firmware
++  * SAUCE: Remove r128 files duplicated in linux-firmware
++  * SAUCE: Remove acenic files duplicated in linux-firmware
++  * SAUCE: Remove keyspan files duplicated in linux-firmware
++  * SAUCE: Remove sun files duplicated in linux-firmware
++  * SAUCE: Remove radeon files duplicated in linux-firmware
++  * SAUCE: Update bnx2x firmware to 7.8.2.0
++  * [Config] generic.inclusion-list: econet has disappeared
++
++  [ Upstream Kernel Changes ]
++
++  * seccomp: forcing auditing of kill condition
++    - LP: #1079469
++  * rebase to v3.7-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Nov 2012 12:28:55 -0800
++
++linux (3.7.0-2.8) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "overlayfs: disable until FTBS is fixed"
++  * Revert "ubuntu: overlayfs"
++  * Revert "ubuntu: AUFS"
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- ovl: switch to __inode_permission()
++  * ubuntu: overlayfs -- overlayfs: copy up i_uid/i_gid from the underlying
++    inode
++    - LP: #944386
++  * ubuntu: AUFS (no-squash): basic framework and update machinary
++  * ubuntu: AUFS (no-squash) -- aufs3-base.patch
++  * ubuntu: AUFS (no-squash) -- aufs3-standalone.patch
++  * ubuntu: AUFS: aufs-update -- follow the uapi header changes
++  * ubuntu: AUFS -- update to f2873474324d0a31af4340554b9715f51331bc7f
++  * ubuntu: AUFS (no-squash) -- reenable
++    - LP: #1079193
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: add i_op->dentry_open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++  * ubuntu: overlayfs -- vfs: export __inode_permission() to modules
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Robin Dong ]
++
++  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
++  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 15 Nov 2012 13:35:12 +0000
++
++linux (3.7.0-1.7) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Drop dependency on libaudit-dev
++    Its a universe package which causes an FTBS on the builders.
++    libaudit-dev is not strictly required for the perf tools build.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 14 Nov 2012 10:08:13 -0700
++
++linux (3.7.0-1.6) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enforce -- switch CONFIG_NVRAM to more readable form
++  * [Config] better encode the CONFIG_NVRAM constaint
++  * enforcer -- fix debugging output
++
++  [ Ben Collins ]
++
++  * [Config] Add custom_override rule to allow for alternate kernel
++    file/install
++  * [Config] Use SRCPKGNAME as prefix for indep linux headers package
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped armel
++  * Drop highbank from ABI fetch list
++  * [Config] Use dh_prep instead of 'dh_clean -k'
++  * [Config] Build depend on libaudit-dev, libunwind8-dev for tools
++  * [Config] Document binary-indep dependency chain
++  * rebase to v3.7-rc5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc5
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Nov 2012 07:13:37 -0500
++
++linux (3.7.0-0.5) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_AMD_IOMMU_V2=m
++    - LP: #1071520
++  * [Config] CONFIG_MTD_ONENAND_SIM=n for armel
++    Fixes FTBS
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 15:45:39 -0500
++
++linux (3.7.0-0.4) raring; urgency=low
++
++  [ Ben Collins ]
++
++  * [Config] Update enforce rule for CONFIG_NVRAM to better suit flavours
++
++  [ Tim Gardner ]
++
++  * [Config] do_tools=false for arm
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 05:39:51 -0700
++
++linux (3.7.0-0.3) raring; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_DRM_EXYNOS_HDMI=n for armhf
++  * [Config] CONFIG_MTD_NAND_DOCG4=n for armel/armhf
++  * [Config] Drop highbank harder
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 07 Nov 2012 18:11:45 +0000
++
++linux (3.7.0-0.2) raring; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add fs/udf to linux-image to support DVD/CD formats in virtual
++    instances
++    - LP: #1066921
++  * [Config] drop highbank builds
++
++  [ Jeremy Kerr ]
++
++  * SAUCE: efivarfs: Implement exclusive access for {get, set}_variable
++    - LP: #1063061
++
++  [ Leann Ogasawara ]
++
++  * Reinstate dropped.txt from Ubuntu-3.7.0-0.1-rc1
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped powerpc/ppc64 in favour of the community kernel
++  * [Config] CONFIG_MODULE_SIG=y for amd64,i386, and highbank
++  * rebase to v3.7-rc4
++  * SAUCE: MODSIGN: Emit error for incorrectly signed module
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Nov 2012 05:35:41 -0700
++
++linux (3.7.0-0.1) raring; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc3
++    - LP: #1056078
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.7-rc2
++    - LP: #1060729
++    - LP: #1059523
++    - LP: #1006690
++    - LP: #1049623
++    - LP: #1046512
++    - LP: #1052499
++    - LP: #1037642
++    - LP: #559939
++    - LP: #1052460
++    - LP: #939161
++    - LP: #1046734
++
++ -- Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Oct 2012 08:13:07 -0600
++
++linux (3.6.0-0.1) UNRELEASED; urgency=low
++
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc6
++    - LP: #1000424
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc5
++    - LP: #1040077
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.6-rc3
++    - LP: #1038651
++    - LP: #1034779
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 24 Jul 2012 06:37:09 -0700
++
++linux (3.5.0-6.6) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION enable IPv6
++    experimental features
++  * SAUCE: highbank -- export clock functions for modules
++  * [Config] highbank -- reenable CONFIG_TOUCHSCREEN_W90X900
++  * [Config] highbank -- renenable CONFIG_SERIO_AMBAKMI
++  * [Config] highbank -- reenable CONFIG_RFKILL_GPIO
++  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
++  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
++  * [Config] highbank -- reenable CONFIG_KEYBOARD_SAMSUNG
++  * [Config] highbank -- reenable CONFIG_FB_ARMCLCD
++  * [Config] highbank -- reenable CONFIG_DW_DMAC
++  * [Config] highbank -- reenable CONFIG_USB_R8A66597_HCD
++  * [Config] highbank -- reenable CONFIG_USB_MV_UDC
++  * [Config] highbank -- reenable CONFIG_USB_DWC3
++  * [Config] highbank -- reenable CONFIG_SATA_MV
++  * [Config] highbank -- reenable CONFIG_PATA_ARASAN_CF
++  * [Config] highbank -- CONFIG_CAN_C_CAN_PLATFORM
++  * [Config] highbank -- reenable CONFIG_MMC_ARMMMCI
++  * [Config] highbank -- reenable CONFIG_SERIAL_AMBA_PL010
++  * [Config] highbank -- reenable CONFIG_ATMEL_PWM
++  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
++  * [Config] highbank -- enable CONFIG_EXPERT
++  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
++  * [Config] enable CONFIG_USB_DYNAMIC_MINORS
++  * [Config] enable CONFIG_USB_EHCI_TT_NEWSCHED
++  * [Config] enable CONFIG_USB_ETH_EEM
++  * [Config] enable CONFIG_USB_HCD_BCMA/CONFIG_USB_HCD_SSB
++  * [Config] disable CONFIG_USB_M66592
++  * [Config] enable CONFIG_USB_NET2272
++  * [Config] enable CONFIG_USB_R8A66597
++  * [Config] annotate: CONFIG_USB_OMAP not required for our h/w
++  * [Config] set CONFIG_USB_MUSB_HDRC=m for omap
++  * [Config] annotate: CONFIG_USB_G_MULTI fix rule
++  * [Config] CONFIG_USB_GPIO_VBUS=m for OMAP
++  * [Config] Enable CONFIG_DRM_AST/_CIRRUS_QEMU/_MGAG200
++  * [Config] sync configuration armhf omap -> armel omap
++  * [Config] annotate: CONFIG_IIO triggers build failures on OMAP4
++  * [Config] disable CONFIG_OMAP_IOVMM is deprecated
++
++  [ Bryan Wu ]
++
++  * [Config] change default IO scheduler from CFQ to Deadline
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc"
++  * [Config] Disable CONFIG_MOUSE_INPORT
++
++  [ Tim Gardner ]
++
++  * SAUCE: firmware: Update bnx2x to current firmware version 7.2.51
++  * [Config] Add bnx2x firmware to nic-modules udeb
++  * SAUCE: Add script to convert firmware to ihex format
++  * SAUCE: firmware: Upgrade bnx2 to current versions
++  * [Config] Add tigon firmware to nic-modules udeb
++  * [Config] CONFIG_EARLY_PRINTK_DBGP=y
++    - LP: #1026761
++  * SAUCE: Remove redundant cis firmware
++  * SAUCE: Remove redundant emi26 firmware
++  * SAUCE: Remove redundant ttusb-budget firmware
++  * SAUCE: Remove redundant sun/cassini firmware
++  * SAUCE: Remove redundant ositech/Xilinx7OD firmware
++  * SAUCE: Remove redundant 3com/typhoon.bin firmware
++  * SAUCE: Remove redundant yamaha/ds1 firmware
++  * SAUCE: Remove redundant keyspan_pda firmware
++  * rebase to v3.5
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5
++    - LP: #1027828
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Jul 2012 05:57:04 -0700
++
++linux (3.5.0-5.5) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] annotations: initial import of configuration annotations
++
++  [ Bryan Wu ]
++
++  * [Config] enforcer -- add CONFIG_I2C_DESIGNWARE_PLATFORM enforce checker
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc7
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Bluetooth: btusb: Add vendor specific ID (0a5c:21f4) BCM20702A0
++    - LP: #1010281
++
++  [ Tim Gardner ]
++
++  * [Config] enable CONFIG_I2C_HELPER_AUTO for all flavours as policy
++    expects
++  * [Config] CONFIG_I2O_CONFIG_OLD_IOCTL=n
++  * [Config] CONFIG_BRIDGE_EBT_ULOG=n
++  * [Config] CONFIG_IP_NF_QUEUE=n
++  * [Config] CONFIG_MTD_DOC2000=n
++  * [Config] CONFIG_PRINT_QUOTA_WARNING=n
++  * [Config] CONFIG_PRISM54=n
++  * [Config] CONFIG_SCx200_I2C=n
++  * [Config] CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jul 2012 15:38:41 -0700
++
++linux (3.5.0-4.4) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Packaging] getabis should be extracting all packages
++    - LP: #1021174
++  * [Config] getabis -- series uses linux-image-extra
++    - LP: #1021174
++  * rebase to v3.5-rc6
++
++  [ Bryan Wu ]
++
++  * [Config] built-in CONFIG_MICREL_PHY as other PHY drivers for all
++    flavours
++  * [Config] sync CONFIG_MOUSE_PS2_ config for all flavours
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_RT2800USB_RT35XX and CONFIG_RT2800USB_RT53XX
++    - LP: #1019561
++
++  [ Paolo Pisati ]
++
++  * [Config] SND_OMAP_SOC, SND_OMAP_SOC_MCBSP and SND_OMAP_SOC_OMAP3_BEAGLE =y
++    - LP: #1019321
++
++  [ Stefan Bader ]
++
++  * SAUCE: (pre-up) net: dont use __netdev_alloc_skb for bounce buffer
++    - LP: #1018456
++  * (config) Disable ACPI_PROCFS_POWER
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_ACPI_BGRT=y
++  * Extract firmware module info during getabi
++    - LP: #1021174
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Jul 2012 08:50:20 -0700
++
++linux (3.5.0-3.3) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_MEMTEST=y
++    - LP: #1004535
++  * [Config] config-check: add support for a cut operation
++  * [Config] enforcer -- switch to cut where appropriate
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc5
++  * [Config] Updateconfigs after rebase to v3.5-rc5
++
++  [ Luis Henriques ]
++
++  * SAUCE: ocfs2: Fix NULL pointer dereferrence in
++    __ocfs2_change_file_space
++    - LP: #1006012
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.5) drm/i915: ignore pipe select bit when checking
++    for LVDS register initialization
++    - LP: #1012800
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc5
++    - LP: #1013183
++    - LP: #1017017
++    - LP: #884652
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 02 Jul 2012 06:41:58 -0700
++
++linux (3.5.0-2.2) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.5-rc4
++
++  [ Arend van Spriel ]
++
++  * SAUCE: (drop after 3.5) brcmsmac: fix NULL pointer crash in
++    brcms_c_regd_init()
++    - LP: #950320
++
++  [ Bryan Wu ]
++
++  * [Config] Sync CONFIG_CGROUP_MEM_RES_CTLR_SWAP for ARM
++
++  [ Chris J Arges ]
++
++  * PACKAGING: add .gnu_debuglink sections to .ko files
++    - LP: #669641
++
++  [ Leann Ogasawara ]
++
++  * d-i: Add hid-generic to input-modules
++    - LP: #1017879
++
++  [ Ming Lei ]
++
++  * SAUCE: Revert "mmc: omap_hsmmc: Enable Auto CMD12"
++    - LP: #1017717, #225
++
++  [ Paolo Pisati ]
++
++  * SAUCE: Revert "Fix OMAP EHCI suspend/resume failure (i693)"
++    - LP: #1017718
++  * [Config] Disable generic USB_EHCI_HCD_PLATFORM on omap3
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.5) brcm80211: smac: don't set up tx power limits
++    during initialization
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: always set channel specified
++    by mac80211
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: remove unused code for 40MHz
++    channels
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: clean up channel.c
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: inform mac80211 of the X2
++    regulatory domain
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: enable/disable radio on
++    regulatory updates
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: use mac80211 channel data for
++    tx power limits
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: don't validate channels
++    against internal regulatory data
++    - LP: #950320
++  * SAUCE: (drop after 3.5) brcm80211: smac: use current regulatory domain
++    when checking whether OFDM is allowed
++    - LP: #950320
++
++  [ Tim Gardner ]
++
++  * [Config] Enable CONFIG_CGROUPS for highbank
++    - LP: #1014692
++  * [Config] FB_OMAP*=y and PANEL_TFP410=y
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 26 Jun 2012 06:21:05 -0700
++
++linux (3.5.0-1.1) quantal-proposed; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] highbank -- enable CONFIG_RFKILL=y and CONFIG_CAN=m
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.5-rc1
++  * [Config] Remove USB_DEVICEFS from the config enforcer
++  * [Config] Updateconfigs after rebase to v3.5-rc1
++  * [Config] Temporarily disable CONFIG_MACH_NOKIA_RX51 on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
++  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
++  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
++  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
++  * [Config] Temporarily disable CONFIG_GPIO_EM on arm
++  * [Config] Temporarily disable CONFIG_SERIAL_8250_EM on armhf
++  * [Config] Temporarily disable CONFIG_STMMAC_ETH on armhf
++  * [Config] Temporarily disable CONFIG_HW_RANDOM_ATMEL on armhf
++  * Rebase to v3.5-rc2
++  * [Config] Updateconfigs after rebase to v3.5-rc2
++  * [Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc
++  * Rebase to v3.5-rc3
++  * [Config] Updateconfigs after rebase to v3.5-rc3
++
++  [ Paul Mundt ]
++
++  * SAUCE: fix bug.h's inclusion of kernel.h
++
++  [ Stefan Bader ]
++
++  * SAUCE: Fix compile failures of dm-raid45
++  * [Config] Enable dm-raid45
++  * Move dependency on crda to extra package
++    - LP: #657901
++  * SAUCE: Mask CR4 writes on older Xen hypervisors
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.5-rc3
++    - LP: #993162
++    - LP: #925577
++  * rebase to v3.5-rc2
++  * rebase to v3.5-rc1
++    - LP: #955892
++    - LP: #978038
++    - LP: #987371
++    - LP: #929545
++    - LP: #942316
++    - LP: #903853
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 08 Jun 2012 14:28:46 -0700
++
++linux (3.4.0-5.11) quantal-proposed; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_ARM_LPAE
++    - LP: #1009061
++
++  [ Oleksij Rempel ]
++
++  * SAUCE: b43: do not call ieee80211_unregister_hw if we are not registred
++    - LP: #1008905
++
++  [ Paolo Pisati ]
++
++  * [Config] omap3: MFD_OMAP_USB_HOST is usb host in omap2+.
++    - LP: #1009061
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Jun 2012 08:06:28 -0700
++
++linux (3.4.0-4.10) quantal; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Temporarily disable ABI and module check
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 20:27:31 -0700
++
++linux (3.4.0-4.9) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] fix config split to avoid the shared config
++  * [Config] updateconfigs following split config fix
++  * [Config] linux-image-extras needs full postinst
++  * [Config] CONFIG_BLK_DEV_NVME commonise across architectures
++  * [Config] CONFIG_HP_WATCHDOG enable as module
++  * [Config] CONFIG_PDC_ADMA is not boot essential
++  * [Config] CONFIG_XEN_ACPI_PROCESSOR should be enabled on x86
++  * [Config] CONFIG_VT6655/CONFIG_VT6656=m
++  * [Config] CONFIG_TRANZPORT=m commonise
++  * [Config] CONFIG_R3964=m commonise
++  * [Config] CONFIG_SCSI_DH=m commonise
++  * [Config] CONFIG_SCSI_IBMVSCSIS=m commonise
++  * [Config] CONFIG_AMD_PHY=y phys are not autoloadable
++  * [Config] CONFIG_SCSI_QLA_ISCSI=m commonise
++  * [Config] CONFIG_SCSI_SPI_ATTR=m commonise
++  * [Config] CONFIG_USB_SN9C102 is deprecated disable
++  * [Config] CONFIG_USB_SI470X=m commonise
++  * [Config] CONFIG_USB_ET61X251=m commonise
++  * [Config] CONFIG_RTS_PSTOR=m commonise
++  * [Config] CONFIG_SCANLOG=m commonise
++  * [Config] CONFIG_SCSI_SYM53C8XX_2=m commonise
++  * [Config] CONFIG_SM_FTL=m commonise
++  * [Config] CONFIG_SOLO6X10=m commonise
++  * [Config] CONFIG_SND_PCM_OSS=n using pulseaudio emulation instead
++  * [Config] CONFIG_SPI_DESIGNWARE=m commonise
++  * [Config] CONFIG_SPI_SPIDEV=m commonise
++  * [Config] CONFIG_TABLET_USB_WACOM=m commonise
++  * [Config] CONFIG_TPS65010=m commonise
++  * [Config] CONFIG_STE10XP=y commonise
++  * [Config] CONFIG_X25_ASY=m commonise
++  * [Config] CONFIG_USB_MON=m commonise
++  * [Config] CONFIG_VME_BUS=m commonise
++  * [Config] CONFIG_W35UND=m commonise
++  * [Config] -CONFIG_TCG_TPM=y commonise
++  * [Config] highbank -- commonise filesystems
++  * [Config] highbank -- commonise subsystems
++  * [Config] highbank -- commonise network protocols
++  * [Config] highbank -- commonise input drivers
++  * [Config] highbank -- commonise CRYPTO options
++  * [Config] highbank -- commonise HID options
++  * [Config] highbank -- commonise sensors options
++  * [Config] highbank -- commonise EXPORTFS/FHANDLE
++  * [Config] highbank -- commonise CONFIG_CRYPTO_LZO
++  * [Config] highbank -- commonise ENCRYPTED_KEYS
++  * [Config] highbank -- commonise CONFIG_ATALK
++  * [Config] highbank -- commonise INET/INET6
++  * [Config] highbank -- commonise NLS
++  * [Config] highbank -- commonise BLK/CHR
++  * [Config] highbank -- CONFIG_EXT2_FS=y boot essential on highbank
++  * [Config] highbank -- commonise INET/INET6 part 2
++  * [Config] highbank -- commonise PHY settings
++  * [Config] highbank -- commonise CRC settings
++  * [Config] highbank -- commonise BINFMT settings
++  * [Config] highbank -- commonise DM settings
++  * [Config] highbank -- commonise RTC_DRV settings
++  * [Config] highbank -- commonise KEYBOARD/MOUSE settings
++  * [Config] highbank -- commonise USB settings
++  * [Config] highbank -- commonise GPIO settings
++  * [Config] highbank -- commonise I2C settings
++  * [Config] highbank -- commonise numerous subsystem selectors
++  * [Config] highbank -- commonise A-C modules missmatches
++  * [Config] highbank -- commonise D-F modules missmatches
++  * [Config] CONFIG_AUDIT_LOGINUID_IMMUTABLE incompatible with upstart
++  * [Config] highbank -- commonise G-I modules missmatches
++  * [Config] highbank -- commonise J-L modules missmatches
++  * [Config] highbank -- commonise M modules missmatches
++  * [Config] highbank -- commonise N-P modules missmatches
++  * [Config] highbank -- commonise Q-R modules missmatches
++  * [Config] highbank -- commonise S modules missmatches -- part 1
++  * [Config] highbank -- commonise S modules missmatches -- part 2
++  * [Config] highbank -- commonise T modules missmatches
++  * [Config] highbank -- commonise U-Z modules missmatches
++
++  [ Ike Panhc ]
++
++  * [Config] add highbank flavour
++    - LP: #1000831
++
++  [ Mark Langsdorf ]
++
++  * SAUCE: arm highbank: add support for pl320-ipc driver
++    - LP: #1000831
++
++  [ Rob Herring ]
++
++  * SAUCE: input: add a key driver for highbank
++    - LP: #1000831
++  * SAUCE: ARM: highbank: Add smc calls to enable/disable the L2
++    - LP: #1000831
++  * SAUCE: force DMA buffers to non-bufferable on highbank
++    - LP: #1000831
++  * SAUCE: net: calxedaxgmac: fix net timeout recovery
++    - LP: #1000831
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_IWLWIFI_EXPERIMENTAL_MFP=n
++  * [Config] CONFIG_PCI_REALLOC_ENABLE_AUTO=y
++  * [Config] CONFIG_CIFS_EXPERIMENTAL has disappeared
++  * [Config] Homogenize CIFS configs across all arches
++  * [Config] armhf should not be skipabi or skipmodules
++    - LP: #1006913
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 05:52:49 -0700
++
++linux (3.4.0-3.8) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] include include/generated/compile.h
++    - LP: #942569
++  * [Config] fix up postinst to ensure we know which error is which
++    - LP: #1002388
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: async_populate_rootfs: fix build warnings
++    - LP: #1003417
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: AppArmor: Add the ability to mediate mount"
++  * SAUCE: apparmor: Add the ability to mediate mount
++  * SAUCE: AppArmor: basic networking rules
++  * SAUCE: apparmor: fix profile lookup for unconfined
++    - LP: #978038, #987371
++  * SAUCE: apparmor: fix long path failure due to disconnected path
++    - LP: #955892
++
++  [ Mario Limonciello ]
++
++  * SAUCE: dell-laptop: rfkill blacklist Dell XPS 13z, 15
++    - LP: #901410
++
++  [ Stefan Bader ]
++
++  * (config) Built-in xen-acpi-processor
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NET_DSA=m
++    - LP: #1004148
++  * [Config] Ensure CONFIG_XEN_ACPI_PROCESSOR=y for amd64
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 May 2012 11:38:33 -0700
++
++linux (3.4.0-3.7) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] drop the virtual flavour in favour of a split generic et al
++  * [Config] enforcer -- drop IDLE enforcement
++  * [Config] enable CONFIG_SCSI_VIRTIO=m for amd64
++  * [Config] updateconfigs following removal of -virtual
++
++  [ Leann Ogasawara ]
++
++  * Rebase to v3.4
++
++  [ Seth Forshee ]
++
++  * [Config] disable CONFIG_B43_BCMA_EXTRA
++
++  [ Tim Gardner ]
++
++  * [Config] Check for extras when building udebs
++  * [Config] Collapsed generic-pae into generic [i386]
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 May 2012 07:23:47 -0700
++
++linux (3.4.0-2.6) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: overlayfs -- overlayfs: update touch_atime() usage"
++  * Revert "ubuntu: overlayfs -- overlayfs: switch from d_alloc_root() to
++    d_make_root()"
++  * Revert "ubuntu: overlayfs -- overlayfs: follow header cleanup"
++  * Revert "ubuntu: overlayfs -- overlayfs: apply device cgroup and
++    security permissions to overlay files"
++  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- vfs: introduce clone_private_mount()"
++  * Revert "ubuntu: overlayfs -- vfs: export do_splice_direct() to modules"
++  * Revert "ubuntu: overlayfs -- vfs: add i_op->open()"
++  * Revert "ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()"
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- inode_only_permission: export inode level
++    permissions checks
++  * ubuntu: overlayfs -- overlayfs: switch to use inode_only_permissions
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Robin Dong ]
++
++  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
++  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
++
++  [ Tim Gardner ]
++
++  * [Config] perarch and indep tools builds need separate build directories
++  * Prevent upgrading a non-PAE CPU
++  * perf is not parallel build safe
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 May 2012 08:43:18 -0700
++
++linux (3.4.0-2.5) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] perarch and indep tools builds need separate build directories
++
++  [ Tim Gardner ]
++
++  * Prevent upgrading a non-PAE CPU
++  * [Config] build debug
++  * [Config] perf tools are not parallel build safe
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 15 May 2012 11:37:53 -0700
++
++linux (3.4.0-2.4) quantal; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: fsam7400: use UMH_WAIT_PROC consistently"
++  * Revert "ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86"
++  * Revert "ubuntu: fsam7400: Depend on CHECK_SIGNATURE"
++  * Revert "ubuntu: fsam7400 -- Cleanup Makefile"
++  * Revert "ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M
++    7400"
++  * Revert "ubuntu: omnibook: fix source file newline"
++  * Revert "ubuntu: omnibook -- update BOM"
++  * Revert "SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5}
++    depend on X86"
++  * Revert "ubuntu: omnibook -- Added missing BOM file"
++  * Revert "ubuntu: omnibook -- support Toshiba (HP) netbooks"
++  * Revert "ubuntu: nx-emu - i386: mmap randomization for executable
++    mappings"
++  * Revert "SAUCE: disable_nx should not be in __cpuinitdata section for
++    X86_32"
++  * Revert "ubuntu: nx-emu - i386: NX emulation"
++  * Revert "ubuntu: rfkill drivers -- version 1.3"
++  * Temporarily disable module check
++  * [Config] Remove CONFIG_FSAM7400
++  * [Config] Remove CONFIG_OMNIBOOK
++  * [Config] Update configs
++  * Rebase to v3.4-rc7
++  * SAUCE: genirq: export handle_edge_irq() and irq_to_desc()
++
++  [ Tim Gardner ]
++
++  * Updated generic-pae description
++  * Rebase to v3.4-rc6
++  * install-tools depends on build targets
++
++  [ Upstream Kernel Changes ]
++
++  * kconfig: in debug mode some 0 length message prints occur
++  * rebase to v3.4-rc7
++  * rebase to v3.3-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 May 2012 08:22:56 -0700
++
++linux (3.4.0-1.3) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] control.stub is an intermediate product not a dependancy
++    - LP: #992414
++
++  [ Leann Ogasawara ]
++
++  * remove i386 generic from getabis
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) b43: only reload config after successful initialization
++    - LP: #950295
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 May 2012 09:48:14 -0700
++
++linux (3.4.0-1.2) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] add build depends for flex, bison and pkg-config
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 01 May 2012 13:15:41 +0100
++
++linux (3.4.0-1.1) quantal; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
++    permissions to overlay files
++    - LP: #915941, #918212
++    - CVE-2012-0055
++
++  [ Leann Ogasawara ]
++
++  * Open Q
++  * Rebase to v3.4-rc5
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
++  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
++  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
++  * [Config] Temporarily disable CONFIG_MFD_OMAP_USB_HOST on arm
++  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
++  * [Config] Temporarily disable CONFIG_USB_EHCI_HCD_PLATFORM on arm
++  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
++  * [Config] Temporarily disable CONFIG_AX88796 on arm
++
++  [ Upstream Kernel Changes ]
++
++  * vfs: pass struct path to __dentry_open()
++  * vfs: add i_op->open()
++  * vfs: export do_splice_direct() to modules
++  * vfs: introduce clone_private_mount()
++  * overlay filesystem
++  * overlayfs: add statfs support
++  * overlayfs: implement show_options
++  * overlay: overlay filesystem documentation
++  * fs: limit filesystem stacking depth
++  * overlayfs: follow header cleanup
++  * overlayfs: switch from d_alloc_root() to d_make_root()
++  * overlayfs: update touch_atime() usage
++  * rebase to v3.4-rc5
++    - LP: #950490
++  * rebase to v3.4-rc4
++  * rebase to v3.4-rc3
++  * rebase to v3.4-rc2
++  * rebase to v3.4-rc1
++  * rebase to v3.3
++  * rebase to v3.3-rc7
++  * rebase to v3.3-rc6
++  * rebase to v3.3-rc5
++  * rebase to v3.3-rc4
++    - LP: #900802
++    - LP: #930842
++  * rebase to v3.3-rc3
++    - LP: #924320
++    - LP: #923316
++    - LP: #923409
++    - LP: #918254
++  * rebase to v3.3-rc2
++  * rebase to v3.3-rc1
++    - LP: #795823
++    - LP: #909419
++    - LP: #910792
++    - LP: #878701
++    - LP: #724831
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 25 Jan 2012 06:50:04 -0800
++
++linux (3.2.0-10.18) precise; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: ecryptfs: Print inode on metadata error
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "proc: enable writing to /proc/pid/mem"
++    - LP: #919115
++    - CVE-2012-0056
++  * (pre-stable) ALSA: HDA: Use LPIB position fix for Macbook Pro 7, 1
++    - LP: #909419
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 24 Jan 2012 10:15:12 +0000
++
++linux (3.2.0-10.17) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "SAUCE: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "SAUCE: overlayfs -- overlayfs: implement show_options"
++  * Revert "SAUCE: overlayfs -- overlayfs: add statfs support"
++  * Revert "SAUCE: overlayfs -- overlay filesystem"
++  * Revert "SAUCE: overlayfs -- vfs: introduce clone_private_mount()"
++  * Revert "SAUCE: overlayfs -- vfs: export do_splice_direct() to modules"
++  * Revert "SAUCE: overlayfs -- vfs: add i_op->open()"
++  * ensure debian/ is not excluded from git by default
++  * add new scripting to handle buglinks in rebases
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
++    permissions to overlay files
++    - LP: #915941, #918212
++    - CVE-2012-0055
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: dmar: disable if ricoh multifunction detected"
++  * [Config] Disable CONFIG_INTEL_IOMMU_DEFAULT_ON
++    - LP: #907377, #911236
++  * [Config] Enable CONFIG_IRQ_REMAP
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) x86/PCI: amd: factor out MMCONFIG discovery
++    - LP: #647043
++  * (pre-stable) PNP: work around Dell 1536/1546 BIOS MMCONFIG bug that
++    breaks USB
++    - LP: #647043
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jan 2012 07:10:08 -0800
++
++linux (3.2.0-9.16) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] Enable numerous CONFIG_VIDEO_* cards on ARM
++  * [Config] pull ARM sound modules =m
++  * [Config] CONFIG_RTC_DRV_TEST is for testing only
++  * [Config] CONFIG_USB_DUMMY_HCD is testing only
++  * [Config] CONFIG_USB_FILE_STORAGE is deprecated
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_CAN_TI_HECC on armel"
++  * [Config] Enable CONFIG_HW_RANDOM_PASEMI=m
++  * [Config] Enable CONFIG_MMC_TMIO=m
++  * [Config] Enable CONFIG_MTD_NAND_FSL_ELBC=m
++  * [Config] Enable CONFIG_ISI=m
++  * [Config] Enable CONFIG_MMC=y
++  * [Config] Enable CONFIG_LIRC_PARALLEL=m
++  * [Config] Enable CONFIG_MAC_EMUMOUSEBTN=m
++  * [Config] Enable CONFIG_CHR_DEV_SG=y
++  * [Config] Enable CONFIG_GPIO_PCA953X=m
++  * [Config] Enable CONFIG_GPIO_TWL4030=m
++  * [Config] Enable CONFIG_INET_DIAG=m
++  * [Config] Enable CONFIG_NLS_ISO8859_1=m
++  * [Config] Enable CONFIG_NVRAM=m
++  * [Config] Enable CONFIG_SLIP=m
++  * [Config] Enable CONFIG_PC300TOO=m
++  * [Config] Enable CONFIG_TUN=y
++  * [Config] Enable CONFIG_NET_CLS_CGROUP=m
++  * [Config] Enable CONFIG_THERMAL=y
++  * [Config] Enable CONFIG_PPP=y
++  * [Config] Enable CONFIG_PCI_STUB=m
++  * Rebase to v3.2.1
++  * [Config] Enable CONFIG_RTL8192E=m
++  * [Config] Enable CONFIG_RTS5139=m
++
++  [ Stefan Bader ]
++
++  * [Config] Make CONFIG_VIRTIO_(NET|BLK)=y
++
++  [ Upstream Kernel Changes ]
++
++  * ARM: restart: add restart hook to machine_desc record
++  * ARM: restart: allow platforms more flexibility specifying restart mode
++  * ARM: restart: move reboot failure handing into machine_restart()
++  * ARM: restart: remove argument to setup_mm_for_reboot()
++  * ARM: 7159/1: OMAP: Introduce local common.h files
++  * ARM: restart: only perform setup for restart when soft-restarting
++  * ARM: 7189/1: OMAP3: Fix build break in cpuidle34xx.c because of irq
++    function
++  * ARM: idmap: populate identity map pgd at init time using .init.text
++  * ARM: suspend: use idmap_pgd instead of suspend_pgd
++  * ARM: proc-*.S: place cpu_reset functions into .idmap.text section
++  * ARM: idmap: use idmap_pgd when setting up mm for reboot
++  * ARM: head.S: only include __turn_mmu_on in the initial identity mapping
++  * ARM: SMP: use idmap_pgd for mapping MMU enable during secondary booting
++  * ARM: 7194/1: OMAP: Fix build after a merge between v3.2-rc4 and ARM
++    restart changes
++  * ARM: lib: add call_with_stack function for safely changing stack
++  * ARM: reset: implement soft_restart for jumping to a physical address
++  * ARM: stop: execute platform callback from cpu_stop code
++  * ARM: kexec: use soft_restart for branching to the reboot buffer
++  * ARM: restart: omap: use new restart hook
++  * topdown mmap support
++    - LP: #861296
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to v3.2.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 13 Jan 2012 20:32:08 +0100
++
++linux (3.2.0-8.15) precise; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_ACPI_PROCFS
++  * Remove server from getabis
++  * Temporarily disable module check
++  * [Config] Disable CONFIG_MTD_TESTS
++  * [Config] Disable CONFIG_X86_E_POWERSAVER
++  * [Config] Set CONFIG_ARCNET=m
++  * [Config] Enable CONFIG_ATM_DUMMY=m
++  * [Config] Enable CONFIG_BLK_DEV_MD=y
++  * ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86
++  * [Config] Enable CONFIG_BLK_DEV_SD=y
++  * [Config] Enable CONFIG_BLK_DEV_SR=y
++  * [Config] Enable CONFIG_BLK_DEV_UB=m
++  * [Config] Enable CONFIG_COPS=m
++  * [Config] Enable CONFIG_DVB_USB_EC168=m
++  * [Config] Enable CONFIG_ENC28J60=m
++  * [Config] Enable CONFIG_FB_UVESA=m
++  * [Config] Enable CONFIG_FB_ATY=m
++  * [Config] Enable CONFIG_BROADCOM_PHY=y
++  * [Config] Enable CONFIG_CICADA_PHY=y
++  * [Config] Enable CONFIG_DAVICOM_PHY=y
++  * [Config] Enable CONFIG_ICPLUS_PHY=y
++  * [Config] Enable CONFIG_LSI_ET1011C_PHY=y
++  * [Config] Enable CONFIG_LXT_PHY=y
++  * [Config] Enable CONFIG_MARVELL_PHY=y
++  * [Config] Enable CONFIG_NATIONAL_PHY=y
++  * [Config] Enable CONFIG_QSEMI_PHY=y
++  * [Config] Enable CONFIG_SMSC_PHY=y
++  * [Config] Enable CONFIG_VITESSE_PHY=y
++  * Add 3w-sas to scsi-modules
++    - LP: #776542
++
++  [ Mathieu Trudel-Lapierre ]
++
++  * SAUCE: ipv6: make the net.ipv6.conf.all.use_tempaddr sysctl propagate
++    to interface settings
++
++  [ Paolo Pisati ]
++
++  * Revert "SAUCE: omap3: beagle: if rev unknown, assume xM revision C"
++    - LP: #912199
++  * Revert "SAUCE: omap3: beagle: detect new xM revision B"
++    - LP: #912199
++  * Revert "SAUCE: omap3: beaglexm: fix DVI initialization"
++    - LP: #912199
++
++  [ Upstream Kernel Changes ]
++
++  * Bluetooth: Add support for BCM20702A0 [0a5c:21e3]
++    - LP: #906832
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 06 Jan 2012 10:02:03 -0800
++
++linux (3.2.0-8.14) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_SND_USB_6FIRE
++    - LP: #912197
++  * rebase to mainline v3.2 final release
++  * updateconfigs following rebase to v3.2 final
++  * ubuntu: AUFS -- add BOM and automated update script
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++  * ubuntu: AUFS -- update aufs-update to track new locations of headers
++  * ubuntu: AUFS -- clean up the aufs updater and BOM
++  * ubuntu: AUFS -- documentation on updating aufs2
++  * ubuntu: AUFS -- aufs3-base.patch
++  * ubuntu: AUFS -- aufs3-standalone.patch
++  * ubuntu: AUFS -- fix undefined __devcgroup_inode_permission
++  * ubuntu: AUFS -- fix undefined security_path_link
++  * ubuntu: AUFS -- update to 4cf5db36bcd9748e8e7270022f295f84d1fc2245
++  * ubuntu: AUFS -- updateconfigs following update
++  * ubuntu: AUFS -- suppress benign plink warning messages
++    - LP: #621195
++  * ubuntu: AUFS -- enable in config and makefile
++  * ubuntu: AUFS -- disable in favor of overlayfs
++  * [Config] linux-virtual -- should include the extX modules
++    - LP: #912308
++
++  [ Tyler Hicks ]
++
++  * SAUCE: eCryptfs: Improve statfs reporting
++    - LP: #885744
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream v3.2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 26 Dec 2011 20:24:30 -0800
++
++linux (3.2.0-7.13) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream 3.2-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 19 Dec 2011 09:14:34 -0800
++
++linux (3.2.0-6.12) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream v3.2-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Dec 2011 10:19:02 -0800
++
++linux (3.2.0-5.11) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * enforcer -- allow arch and flavour predicates to take lists
++  * enforcer -- simplify armel/armhf specific options
++  * enforcer -- fix incorrectly specified flavour matches
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable IRQ_REMAP
++  * [Config] Enable CONFIG_SENSORS_LM95245=m
++  * [Config] Enable CONFIG_SENSORS_MAX1668=m
++  * [Config] Enable CONFIG_SENSORS_NTC_THERMISTOR=m
++  * [Config] Enable CONFIG_SENSORS_MAX6639=m
++  * [Config] Enable CONFIG_SENSORS_MAX6642=m
++  * [Config] Enable CONFIG_SENSORS_LINEAGE=m
++  * [Config] Enable CONFIG_CRYPTO_SALSA20=m
++  * [Config] Enable CONFIG_PATA_TOSHIBA=m
++  * [Config] Enable CONFIG_POHMELFS=m
++  * [Config] Enable CONFIG_NET_PACKET_ENGINE=y
++  * [Config] Enable CONFIG_PATA_OPTI=m
++  * add overlayfs to virtual inclusion list
++    - LP: #903897
++  * add veth to virtual inclusion list
++    - LP: #903897
++  * SAUCE: resolve WARNING: at drivers/block/floppy.c:2929 do_fd_request
++
++  [ Paolo Pisati ]
++
++  * [Config] DEFAULT_MMAP_MIN_ADDR=32k on arm
++    - LP: #903346
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_LOCKUP_DETECTOR=y
++    - LP: #903615
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to upstream 55b02d2f
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 12 Dec 2011 07:08:10 -0800
++
++linux (3.2.0-4.10) precise; urgency=low
++
++  [ Kyle McMartin ]
++
++  * SAUCE: dmar: disable if ricoh multifunction detected
++    - LP: #894070
++
++  [ Seth Forshee ]
++
++  * SAUCE: dell-wmi: Demote unknown WMI event message to pr_debug
++    - LP: #581312
++
++  [ Tim Gardner ]
++
++  * Start new release, Bump ABI, rebase to 3.2-rc5
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_SENSORS_AK8975=m
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 10 Dec 2011 08:57:04 -0700
++
++linux (3.2.0-3.9) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: ext4: correct partial write discard size calculation
++    - LP: #894768
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: x86, microcode, AMD: Restrict microcode reporting"
++    - LP: #892615
++
++  [ Matthew Garrett ]
++
++  * SAUCE: pci: Rework ASPM disable code
++
++  [ Upstream Kernel Changes ]
++
++  * x86: Fix boot failures on older AMD CPU's
++    - LP: #892615
++  * EHCI : Fix a regression in the ISO scheduler
++    - LP: #899165
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 05 Dec 2011 10:37:36 -0800
++
++linux (3.2.0-3.8) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armhf -- add d-i configuration
++  * armhf -- disable ABI checks for armhf
++  * armhf -- add arch to getabis config
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 03 Dec 2011 14:22:52 +0000
++
++linux (3.2.0-3.7) precise; urgency=low
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86/paravirt: PTE updates in k(un)map_atomic need to be
++    synchronous, regardless of lazy_mmu mode
++    - LP: #854050
++
++  [ Tim Gardner ]
++
++  * rebase to v3.2-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 02 Dec 2011 11:53:56 -0800
++
++linux (3.2.0-2.6) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armhf -- fix omap flavour to build on armhf
++  * [Config] CONFIG_PATA_MACIO=y to fix MAC qemu boot
++
++  [ Borislav Petkov ]
++
++  * SAUCE: x86, microcode, AMD: Restrict microcode reporting
++    - LP: #892615
++
++  [ Colin Watson ]
++
++  * Add pata_macio to pata-modules
++
++  [ Tim Gardner ]
++
++  * [Config] Prefer crda over wireless-crda
++  * [Config] Fix virtual inclusion list.
++    - LP: #897795
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 30 Nov 2011 06:09:35 -0800
++
++linux (3.2.0-2.5) precise; urgency=low
++
++  [ Paolo Pisati ]
++
++  * [Config] PANEL_DVI=y
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Nov 2011 09:13:24 -0800
++
++linux (3.2.0-2.4) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v3.2-rc3
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: xen: Do not use pv spinlocks on HVM"
++  * Revert "fix ERROR: __devcgroup_inode_permission undefined"
++  * Revert "olpc_dcon_xo_1_5 needs delay.h"
++  * Revert "olpc_dcon_xo_1 needs delay.h"
++  * rebase to 6fe4c6d4
++  * [Config] updateconfigs after rebase to 6fe4c6d4
++
++  [ Tim Gardner ]
++
++  * [Config] Replace wireless-crda with crda,wireless-regdb
++    - LP: #856421
++  * [Config] Relax the dependencies on crda
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) HID: bump maximum global item tag report size to 96 bytes
++    - LP: #724831
++  * Ubuntu: remove coreutils|fileutils package dependency
++    - LP: #892814
++  * iio: iio_event_getfd -- fix ev_int build failure
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to v3.2-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 24 Nov 2011 16:20:45 +0000
++
++linux (3.2.0-1.3) precise; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * Ubuntu: Add ext2 to fs-core-modules
++    - LP: #893395
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 20:42:33 -0800
++
++linux (3.2.0-1.2) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_NFC and associated devices
++  * SAUCE: allow brcmsmac and b43 to both build
++
++  [ Soren Hansen ]
++
++  * Add ixgbe driver to d-i
++    - LP: #891969
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 08:33:46 -0800
++
++linux (3.2.0-1.1) precise; urgency=low
++  [ Andy Whitcroft ]
++
++  * armhf -- enable armhf and create the first flavours
++  * SAUCE: ensure root is ready before running usermodehelpers in it
++  * [Config] enforcer -- ensure CONFIG_FAT_FS is built-in on arm
++
++  [ Leann Ogasawara ]
++
++  * Temporarily ignore module check
++  * [Config] Enable PCI_IOV on powerpc
++  * [Config] Temporarily disable CONFIG_PASEMI_MAC on powerpc
++  * rebase to v3.2-rc2
++  * SAUCE: include <linux/export.h> for cpuidle34xx arm build
++  * SAUCE: include <linux/kernel.h> for linux/mtd/map.h arm build
++  * SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm build
++  * SAUCE: select ARM_AMBA if OMAP3_EMU
++  * [Config] updateconfigs after select ARM_AMBA
++  * [Config] Temporarily disable CONFIG_KVM_BOOK3S_32 on powerpc
++  * [Config] Enable CONFIG_EXT2_FS=m
++  * [Config] Build in CONFIG_SATA_AHCI=y
++  * Resolve linux-image-extra's install dependency
++
++  [ Seth Forshee ]
++
++  * [Config] Enable EVENT_POWER_TRACING_DEPRECATED=y for powertop
++  * SAUCE: (drop after 3.2) Input: ALPS - move protocol information to
++    Documentation
++  * SAUCE: (drop after 3.2) Input: ALPS - add protocol version field in
++    alps_model_info
++  * SAUCE: (drop after 3.2) Input: ALPS - remove assumptions about packet
++    size
++  * SAUCE: (drop after 3.2) Input: ALPS - add support for protocol versions
++    3 and 4
++  * SAUCE: (drop after 3.2) Input: ALPS - add semi-MT support for v3
++    protocol
++  * SAUCE: (drop after 3.2) Input: ALPS - add documentation for protocol
++    versions 3 and 4
++
++  [ Stefan Bader ]
++
++  * [Config] Built-in xen-netfront and xen-blkfront
++  * Fix build of dm-raid45 and re-enable it
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_USB_XHCI_HCD=y
++    - LP: #886167
++  * [Config] CONFIG_R6040=m
++    - LP: #650899
++  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
++    - LP: #854399
++  * [Config] Consolidated amd64 server flavour into generic
++  * [Config] updateconfigs after rebase to 3.2-rc1
++  * [Config] Disabled dm-raid4-5
++  * [Config] Disabled ndiswrapper
++  * [Config] Disable vt6656
++  * [Config] exclude ppp-modules for virtual flavour
++  * [Config] CONFIG_MEMSTICK_R592=m
++    - LP: #238208
++
++  [ Upstream Kernel Changes ]
++
++  * CHROMIUM: seccomp_filter: new mode with configurable syscall filters
++    - LP: #887780
++  * CHROMIUM: seccomp_filter: add process state reporting
++    - LP: #887780
++  * CHROMIUM: seccomp_filter: Document what seccomp_filter is and how it
++    works.
++    - LP: #887780
++  * CHROMIUM: x86: add HAVE_SECCOMP_FILTER and seccomp_execve
++    - LP: #887780
++  * CHROMIUM: arm: select HAVE_SECCOMP_FILTER
++    - LP: #887780
++  * CHROMIUM: seccomp_filters: move to btrees
++  * CHROMIUM: enable CONFIG_BTREE
++  * CHROMIUM: seccomp_filter: kill NR_syscall references
++  * CHROMIUM: seccomp_filters: guard all ftrace wrapper code
++  * CHROMIUM: seccomp_filters: clean up warnings; kref mistake
++  * CHROMIUM: seccomp_filter: remove "skip" from copy and add drop helper
++  * CHROMIUM: seccomp_filter: allow CAP_SYS_ADMIN management of execve
++  * CHROMIUM: seccomp_filter: inheritance documentation
++  * CHROMIUM: seccomp_filter: make inherited filters composable
++  * CHROMIUM: Fix seccomp_t compile error
++    - LP: #887780
++  * CHROMIUM: Fix kref usage
++    - LP: #887780
++  * CHROMIUM: enable CONFIG_SECCOMP_FILTER and CONFIG_HAVE_SECCOMP_FILTER
++  * rebase to v3.2-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 31 Oct 2011 09:24:39 -0400
++
++linux (3.1.0-2.3) precise; urgency=low
++
++  [ Tim Gardner ]
++
++  * Add postinit and postrm scripts to the extras package
++    - LP: #882120
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 Oct 2011 12:48:33 -0700
++
++linux (3.1.0-2.2) precise; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian: add locking to protect debian/files from parallel update
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.1
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 19 Oct 2011 07:12:38 -0700
++
++linux (3.1.0-1.1) precise; urgency=low
++
++  [ Andiry Xu ]
++
++  * SAUCE: (drop during 3.2 merge) xHCI: AMD isoc link TRB chain bit quirk
++    - LP: #872811
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: compcache -- follow changes to bd_claim/bd_release"
++    - LP: #832694
++  * Revert "ubuntu: compcache -- version 0.5.3"
++    - LP: #832694
++  * [Config] standardise CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
++  * [Config] Enable CONFIG_MACVTAP=m
++    - LP: #822601
++  * record the compiler in the ABI and check for inconsistant builds
++  * [Config] move ECRYPT_FS back to =y for all architectures
++    - LP: #827197
++  * [Config] enable CONFIG_DRM_VMWGFX=m
++    - LP: #698009
++  * [Config] re-fix ECRYPT_FS=y
++    - LP: #827197
++  * enforcer -- ensure we have CONFIG_ECRYPT_FS=y
++    - LP: #827197
++  * [Config] dropping compcache configuration options
++  * [Config] standardise on HZ=250
++  * SAUCE: headers_install: fix #include "..." usage for userspace
++    - LP: #824377
++  * make module-inclusion selection retain the left overs
++  * add a new linux-image-extras package for virtual
++
++  [ Colin Watson ]
++
++  * Deliver more Atheros, Ralink, and iwlagn NIC drivers to d-i
++
++  [ edwin_rong ]
++
++  * SAUCE: Staging: add driver for Realtek RTS5139 cardreader
++    - LP: #824273
++
++  [ Greg Kroah-Hartman ]
++
++  * SAUCE: staging: rts5139: add vmalloc.h to some files to fix the build.
++    - LP: #824273
++
++  [ Jesse Sung ]
++
++  * SAUCE: Unregister input device only if it is registered
++    - LP: #839238
++
++  [ Jiri Kosina ]
++
++  * SAUCE: HID: add MacBookAir4, 2 to hid_have_special_driver[]
++
++  [ Joshua V. Dillon ]
++
++  * SAUCE: HID: add support for MacBookAir4,2 keyboard.
++
++  [ Kees Cook ]
++
++  * [Config] enable and enforce SECCOMP_FILTER on x86
++
++  [ Keng-Yu Lin ]
++
++  * [Config] Enable CONFIG_RTS5139=m on i386/amd64
++    - LP: #824273
++
++  [ Leann Ogasawara ]
++
++  * Revert "ubuntu: overlayfs -- ovl: make lower mount read-only"
++  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
++  * Revert "ubuntu: overlayfs -- ovl: improve stack use of lookup and
++    readdir"
++  * Revert "ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs"
++  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
++  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
++  * Revert "ubuntu: overlayfs -- overlay filesystem"
++  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
++  * Revert "SAUCE: ARM: OMAP: Add macros for comparing silicon revision"
++  * Revert "SAUCE: OMAP: DSS2: check for both cpu type and revision, rather
++    than just revision"
++  * Revert "SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX"
++  * Revert "ubuntu: fsam7400 disable driver"
++    - LP: #876030
++  * rebase to v3.1-rc1
++  * [Config] updateconfigs after rebase to v3.1-rc1
++  * rebase to v3.1-rc2
++  * [Config] Updateconfigs after rebase to v3.1-rc2
++  * ubuntu: Yama - update calls to generic_permission() and
++    inode->i_op->permission()
++  * ubuntu: ndiswrapper -- remove netdev_priv macro
++  * ubuntu: aufs -- Temporarily disable due to build failure
++  * [Config] Diable INTEL_MID_PTI on armel
++  * [Config] Temporarily disable CONFIG_FTMAC100 on armel
++  * [Config] Temporarily disable CONFIG_FTGMAC100 on armel
++  * [Config] Temporarily disable CONFIG_CAN_TI_HECC on armel
++  * [Config] Temporarily disable CONFIG_VIDEO_OMAP2_VOUT on armel
++  * [Config] Set CONFIG_DM_MIRROR=m on amd64, i386, and arm
++  * [Config] Set CONFIG_DM_MULTIPATH=m on amd64, i386, and arm
++  * [Config] Set CONFIG_DM_SNAPSHOT=m on amd64, i386, and arm
++  * [Config] Enable CONFIG_EDAC_AMD8111=m on powerpc
++  * [Config] Enable CONFIG_EDAC_AMD8131=m on powerpc
++  * [Config] Enable CONFIG_EDAC_CPC925=m on powerpc
++  * [Config] Enable CONFIG_EDAC_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_ECHO=m on powerpc
++  * [Config] Enable CONFIG_ET131X=m on powerpc
++  * [Config] Set CONFIG_FB_MATROX=m
++  * [Config] Enable CONFIG_FB_UDL=m on powerpc
++  * [Config] Set CONFIG_FB_VIRTUAL=n
++  * [Config] Enable CONFIG_FB_VGA16=m on powerpc
++  * [Config] Enable CONFIG_GPIO_MAX732X=m on arm
++  * [Config] Enable CONFIG_GPIO_PCF857X=m on arm
++  * [Config] Set CONFIG_HOTPLUG_PCI_FAKE=m
++  * [Config] Enable CONFIG_HOTPLUG_PCI=y on powerpc
++  * [Config] Enable CONFIG_HOTPLUG_PCI_CPCI=y on powerpc
++  * [Config] Enable CONFIG_HP_ILO=m on powerpc-smp
++  * [Config] Enable CONFIG_I2C_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_IBM_BSR=m on powerpc
++  * [Config] Enable CONFIG_IBMVETH=m on powerpc
++  * [Config] Enable CONFIG_IDE_PHISON=m on powerpc
++  * [Config] Enable CONFIG_IGB=m on powerpc
++  * [Config] Enable CONFIG_IIO=m on powerpc
++  * [Config] Enable CONFIG_INFINIBAND_NES=m
++  * [Config] Enable CONFIG_IPMI_HANDLER=m on arm
++  * [Config] Enable CONFIG_IWL3945=m on powerpc
++  * [Config] Disable CONFIG_KVM_BOOK3S_64
++  * [Config] Enable CONFIG_LAPBETHER=m on arm
++  * [Config] Enable CONFIG_LEDS_GPIO=m on powerpc
++  * [Config] Enable CONFIG_LEDS_CLEVO_MAIL=m all arch's
++  * [Config] Enable CONFIG_LEDS_PCA9532=m on powerpc
++  * [Config] Enable CONFIG_LEDS_PCA955X=m on powerpc
++  * [Config] Enable CONFIG_LEDS_TRIGGER_DEFAULT_ON=m on powerpc
++  * [Config] Set CONFIG_LEDS_TRIGGER_HEARTBEAT=m on arm and powerpc
++  * [Config] Set CONFIG_LEDS_TRIGGER_TIMER=m on powerpc
++  * [Config] Enable CONFIG_LINE6_USB=m on arm and powerpc
++  * [Config] Enable CONFIG_MEMSTICK=m on arm
++  * [Config] Enable CONFIG_MTD_AFS_PARTS=m on arm
++  * [Config] Enable CONFIG_MTD_ALAUDA=m on arm
++  * [Config] Enable CONFIG_MTD_AR7_PARTS=m on arm
++  * [Config] Enable CONFIG_MTD_ARM_INTEGRATOR=m on arm
++  * [Config] Enable CONFIG_MOXA_SMARTIO=m on powerpc
++  * [Config] Enable CONFIG_MTD_DATAFLASH=m on arm
++  * [Config] Enable CONFIG_MTD_GPIO_ADDR=m on arm
++  * [Config] Enable CONFIG_MTD_IMPA7=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_GPIO=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_NANDSIM=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_PASEMI=m on powerpc
++  * [Config] Enable CONFIG_MTD_NAND_PLATFORM=m on arm
++  * [Config] Enable CONFIG_MTD_NAND_TMIO=m on arm
++  * [Config] Enable CONFIG_MTD_SST25L=m on arm
++  * [Config] Enable CONFIG_NET_CLS_CGROUP=y on arm
++  * [Config] Enable CONFIG_NET_CLS_FLOW=m on arm
++  * [Config] Enable CONFIG_NET_CLS_U32=m on arm
++  * [Config] Enable CONFIG_NET_DCCPPROBE=m on arm
++  * [Config] Enable CONFIG_NET_SCH_INGRESS=m on arm
++  * [Config] Enable CONFIG_NET_TCPPROBE=m on arm
++  * [Config] Enable CONFIG_PASEMI_MAC=m on powerpc
++  * [Config] Enable CONFIG_PATA_NS87410=m on powerpc
++  * [Config] Enable CONFIG_I2C_GPIO=m on powerpc64-smp
++  * [Config] Enable CONFIG_PANEL=m on powerpc
++  * [Config] Enable CONFIG_PATA_CMD640_PCI=m on powerpc
++  * SAUCE: x86: reboot: Make Dell Latitude E6520 use reboot=pci
++    - LP: #833705
++  * [Config] Add CONFIG_EFI_VARS=y to the enforcer
++    - LP: #837332
++  * [Config] Update CONFIG_EFI_VARS enforcer check
++  * [Config] Add aufs to virtual flavor inclusion list
++    - LP: #844159
++  * SAUCE: x86: reboot: Make Dell Optiplex 790 use reboot=pci
++    - LP: #818933
++  * SAUCE: x86: reboot: Make Dell Optiplex 990 use reboot=pci
++    - LP: #768039
++  * SAUCE: x86: reboot: Make Dell Latitude E6220 use reboot=pci
++    - LP: #838402
++  * [Config] Add igbvf to the virtual flavor inclusion list
++    - LP: #794570
++  * [Config] Add ixgbevf to the virtual inclusion list
++    - LP: #872411
++  * [Config] Transition -generic and -server to be identical
++  * rebase to v3.1-rc10
++
++  [ Luke Yelavich ]
++
++  * [Config] Disable legacy IDE drivers on powerpc
++
++  [ Ming Lei ]
++
++  * SAUCE: fireware: add NO_MSI quirks for o2micro controller
++    - LP: #801719
++  * SAUCE: ata_piix: make DVD Drive recognisable on systems with Intel
++    Sandybridge chipsets(v2)
++    - LP: #737388, #782389, #794642
++
++  [ Paolo Pisati ]
++
++  * [Config] Compile-in vfat support for armel
++    - LP: #853783
++
++  [ Randy Dunlap ]
++
++  * SAUCE: staging: fix rts5139 depends & build
++    - LP: #824273
++
++  [ Rene Bolldorf ]
++
++  * SAUCE: (drop after 3.0) ideapad: Check if acpi already handle backlight
++    power in 'ideapad_backlight_notify_power' to avoid a page fault
++
++  [ Seth Forshee ]
++
++  * SAUCE: (no-up) Input: elantech - Add v3 hardware support
++    - LP: #681904
++  * SAUCE: (drop after 3.1) usb_storage: Don't freeze in usb-stor-scan
++    - LP: #810020
++
++  [ Stefan Bader ]
++
++  * (config) Package macvlan and macvtap for virtual
++  * [Config] Force perf to use libiberty for demangling
++    - LP: #783660
++  * SAUCE: xen: Do not use pv spinlocks on HVM
++    - LP: #838026
++
++  [ Tim Gardner ]
++
++  * [Config] Clean up tools rules
++  * [Config] Package x86_energy_perf_policy and turbostat
++    - LP: #797556
++  * rebase to v3.1-rc3
++  * [Config] Simplify binary-udebs dependencies
++  * [Config] kernel preparation cannot be parallelized
++  * [Config] Linearize module/abi checks
++  * [Config] Linearize and simplify tree preparation rules
++  * [Config] Build kernel image in parallel with modules
++  * [Config] Set concurrency for kmake invocations
++  * [Config] Improve install-arch-headers speed
++  * [Config] Fix binary-perarch dependencies
++  * [Config] Removed stamp-flavours target
++  * [Config] Serialize binary indep targets
++  * [Config] Use build stamp directly
++  * [Config] Restore prepare-% target
++  * rebase to v3.1-rc4
++  * rebase to v3.1-rc5
++  * [Config] Disable makedumpfile for i386/amd64
++  * rebase to v3.1-rc6
++  * [Config] Fix binary-% build target
++  * rebase to v3.1-rc7
++  * rebase to v3.1-rc8
++  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
++    - LP: #854399
++  * [Config] Enable ftrace support in the mac80211 layer
++    - LP: #865171
++  * rebase to v3.1-rc9
++  * SAUCE: usb/core/devio.c: Check for printer class specific request
++    - LP: #872711
++
++  [ Upstream Kernel Changes ]
++
++  * overlay filesystem
++  * overlayfs: add statfs support
++  * overlayfs: implement show_options
++  * overlay: overlay filesystem documentation
++  * fs: limit filesystem stacking depth
++
++  [ Will Drewry ]
++
++  * SAUCE: seccomp_filter: new mode with configurable syscall filters
++  * SAUCE: seccomp_filter: add process state reporting
++  * SAUCE: seccomp_filter: Document what seccomp_filter is and how it
++    works.
++  * SAUCE: seccomp_filter: add HAVE_SECCOMP_FILTER and seccomp_execve
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.1-rc1
++  * rebase to v3.1-rc2
++  * rebase to v3.1-rc3
++    +CONFIG_BLK_DEV_BSGLIB=y
++    +CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
++    -CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
++  * rebase to v3.1-rc4
++  * rebase to v3.1-rc5
++  * rebase to v3.1-rc6
++  * rebase to v3.1-rc7
++  * rebase to v3.1-rc8
++  * rebase to v3.1-rc9
++  * rebase to v3.1-rc10
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 15:43:38 -0700
++
++linux (3.1.0-1.0) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Open P-series
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 13:42:40 -0700
++
++linux (3.0.0-8.10) oneiric; urgency=low
++
++  [ Adam Jackson ]
++
++  * SAUCE: drm/i915/pch: Fix integer math bugs in panel fitting
++    - LP: #753994
++
++  [ John Johansen ]
++
++  * [Config] Enable missing IPv6 options
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable config IWLWIFI_DEVICE_SVTOOL
++    - LP: #819925
++  * Rebase to 3.0.1
++
++  [ Upstream Kernel Changes ]
++
++  * x86, intel, power: Correct the MSR_IA32_ENERGY_PERF_BIAS message
++  * ALSA: hda - Turn on extra EAPDs on Conexant codecs
++    - LP: #783582
++  * KVM: Remove SMEP bit from CR4_RESERVED_BITS
++    - LP: #796476
++  * KVM: Add SMEP support when setting CR4
++    - LP: #796476
++  * KVM: Mask function7 ebx against host capability word9
++    - LP: #796476
++  * KVM: Add instruction fetch checking when walking guest page table
++    - LP: #796476
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.0.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 05 Aug 2011 11:32:25 -0700
++
++linux (3.0.0-7.9) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] add local prefix to oss local change_bits"
++  * Revert "SAUCE: add tracing for user initiated readahead requests"
++  * Revert "SAUCE: vfs: Add a trace point in the mark_inode_dirty function"
++  * Revert "SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo
++    Zhaoyang E47"
++  * Revert "SAUCE: fix documentation strings for struct input_keymap_entry"
++  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range checks
++    (grub)"
++  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range
++    checks"
++  * Revert "SAUCE: vt -- allow grub to request automatic vt_handoff"
++  * Revert "SAUCE: vt -- maintain bootloader screen mode and content until
++    vt switch"
++  * [Config] enable CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
++    - LP: #816035
++  * ubuntu: Yama: if an underlying filesystem provides a permissions op use
++    it
++  * SAUCE: (no-up) add tracing for user initiated readahead requests
++  * SAUCE: vt -- maintain bootloader screen mode and content until vt
++    switch
++  * SAUCE: vt -- allow grub to request automatic vt_handoff
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: (no-up) vfs: Add a trace point in the mark_inode_dirty function
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: (no-up) Disable building the ACPI debugfs source"
++  * [Config] enforce ACPI_CUSTOM_METHOD disabled
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: (no-up) Input: ALPS - Enable Intellimouse mode for Lenovo
++    Zhaoyang E47
++    - LP: #632884, #803005
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_BLK_DEV_CMD64X=m on powerpc
++    - LP: #513131
++  * [Config] Enable CONFIG_RT2800PCI_RT53XX=y
++    - LP: #815064
++
++  [ Rezwanul Kabir ]
++
++  * SAUCE: (no-up) Add support for Intellimouse Mode in ALPS touchpad on
++    Dell E2 series Laptops
++    - LP: #632884
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "yama: if an underlying filesystem provides a permissions op use
++    it"
++  * Revert "Add support for Intellimouse Mode in ALPS touchpad on Dell E2
++    series Laptops"
++  * Revert "tty: include linux/slab.h for kfree"
++  * Revert "gpio/ml_ioh_gpio: include linux/slab.h for kfree"
++  * Revert "pch_dma: add include/slab.h for kfree"
++  * mmc: Added quirks for Ricoh 1180:e823 lower base clock frequency
++    - LP: #773524
++  * oss: rename local change_bits to avoid powerpc bitsops.h definition
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 25 Jul 2011 09:08:01 -0700
++
++linux (3.0.0-7.8) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: overlayfs -- overlayfs: add statfs support
++  * [Config] enable CONFIG_OVERLAYFS
++
++  [ Erez Zadok ]
++
++  * ubuntu: overlayfs -- overlayfs: implement show_options
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_ALIM7101_WDT=m on powerpc
++  * [Config] Enable CONFIG_ASUS_OLED=m on powerpc
++  * [Config] Disable CONFIG_ATM_DUMMY on arm
++  * [Config] Enable CONFIG_BLK_DEV_DRBD=m on powerpc
++  * Temporarily disable module check on arm
++  * Rebase to 3.0 final
++  * [Config] Enable CONFIG_CAN_TI_HECC=m on arm
++  * [Config] Set CONFIG_CDROM_PKTCDVD=m on amd64 and i386
++  * [Config] Enable CONFIG_CRYPTO_CCM=m on powerpc
++  * [Config] Enable CONFIG_CRYPTO_DEV_HIFN_795X=m on powerpc
++  * [Config] Enable CONFIG_CRYPTO_GCM=m on powerpc
++  * [Config] Set CRYPTO_LZO=m on powerpc64-smp
++  * [Config] Enable CONFIG_DM9000=m on arm
++  * [Config] Set CONFIG_DISPLAY_SUPPORT=m on arm
++  * [Config] Enable CONFIG_DL2K=m on amd64 and i386
++
++  [ Miklos Szeredi ]
++
++  * ubuntu: overlayfs -- vfs: add i_op->open()
++  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
++  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
++  * ubuntu: overlayfs -- overlay filesystem
++  * ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs
++  * ubuntu: overlayfs -- ovl: improve stack use of lookup and readdir
++  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
++  * ubuntu: overlayfs -- ovl: make lower mount read-only
++
++  [ Neil Brown ]
++
++  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
++
++  [ Tim Gardner ]
++
++  * [Config] Add enic/fnic to udebs
++    - LP: #801610
++
++  [ Upstream Kernel Changes ]
++
++  * yama: if an underlying filesystem provides a permissions op use it
++
++  [ Major Kernel Changes ]
++
++  * Rebase to 3.0 final
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 21 Jul 2011 07:01:32 -0700
++
++linux (3.0.0-6.7) oneiric; urgency=low
++
++  [ Eagon Yager ]
++
++  * [Config] Fix misspelled 'skipmodule' in arm makefile.
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo Zhaoyang E47
++    - LP: #632884, #803005
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Temporarily disable CONFIG_SMC91X on armel-omap"
++  * Revert "[Config] Temporarily Disable CONFIG_BRCMSMAC on arm"
++  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on powerpc"
++  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on arm"
++  * Revert "[Config] Temporarily disable CONFIG_BRCMSMAC on powerpc"
++  * [Config] Set CONFIG_ACPI_PCI_SLOT=m
++  * [Config] Set CONFIG_ACPI_SBS=m
++  * [Config] Set CONFIG_ACPI_WMI=m
++  * [Config] Set CONFIG_AD7150=m on arm
++  * [Config] Set CONFIG_AD7152=m on arm
++  * [Config] Drop CONFIG_GPIO_S5PV210
++  * [Config] Drop CONFIG_GPIO_S5PC100
++  * [Config] Drop CONFIG_GPIO_PLAT_SAMSUNG
++  * [Config] Drop CONFIG_GPIO_EXYNOS4
++
++  [ Stefan Bader ]
++
++  * SAUCE: Re-enable RODATA for i386 virtual
++    - LP: #809838
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15"
++  * (drop after 3.0.0) acer-wmi: Add support for Aspire 1830 wlan hotkey
++    - LP: #771758
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 20 Jul 2011 06:36:02 -0700
++
++linux (3.0.0-5.6) oneiric; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_RTL8192CU=m
++  * Rebase to -rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jul 2011 22:13:50 +0100
++
++linux (3.0.0-4.5) oneiric; urgency=low
++
++  [ Ming Lei ]
++
++  * SAUCE: fix yama_ptracer_del lockdep warning
++    - LP: #791019
++
++  [ Seth Forshee ]
++
++  * SAUCE: (drop after 3.0) asus-wmi: Add callback for hotkey filtering
++  * SAUCE: (drop after 3.0) eeepc-wmi: Add support for T101MT Home/Express Gate key
++  * SAUCE: (drop after 3.0) asus-wmi: Enable autorepeat for hotkey input device
++  * [Config] CONFIG_{ASUS,ASUS_NB,EEEPC}_WMI=m
++    - LP: #805218
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs after rebase to -rc6+
++    Rebased against 4dd1b49c6d215dc41ce50c80b4868388b93f31a3
++  * Adopt a 3 digit verion, e.g., 3.0.0-x.x
++  * Revert "UBUNTU: add dependancies for module-init-tools"
++    This dependency is no longer required for a 3 digit version.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 05 Jul 2011 14:03:04 +0100
++
++linux (3.0-3.4) oneiric; urgency=low
++
++  [ Keng-Yu Lin ]
++
++  * SAUCE: Revert: "dell-laptop: Toggle the unsupported hardware
++    killswitch"
++    - LP: #775281
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc5
++  * [Config] updateconfigs after rebase to 3.0-rc5
++
++  [ Tim Gardner ]
++
++  * [Config] Remove ubuntu/rtl8192se
++  * [Config] Added armel ABI files
++  * [Config] Removed armel versatile flavour
++  * [Config] CONFIG_INTEL_MEI=m
++    - LP: #716867
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Enable auto-parser as default for Conexant codecs
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v3.0-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 30 Jun 2011 14:27:10 +0100
++
++linux (3.0-2.3) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to 0e2bafab74f0d1463383faeb93f9fc5eb8c2c54e
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc4
++  * [Config] updateconfigs after rebase to 3.0-rc4
++  * fix ERROR: __devcgroup_inode_permission undefined
++
++  [ Stefan Bader ]
++
++  * SAUCE: iscsitarget: Remove driver from the kernel
++
++  [ Tim Gardner ]
++
++  * SAUCE: rtl8192se: Force a build for a 2.6/3.0 kernel
++  * [Config] Add grub-efi as a recommended bootloader for server and
++    generic
++    - LP: #800910
++
++  [ Upstream Kernel Changes ]
++
++  * Fix node_start/end_pfn() definition for mm/page_cgroup.c
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 24 Jun 2011 11:51:12 -0700
++
++linux (3.0-1.2) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_CAN_CALC_BITTIMING
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc3
++  * [Config] updateconfigs after rebase to 3.0-rc3
++
++  [ Upstream Kernel Changes ]
++
++  * perf: clear out make flags when calling kernel make kernelver
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Jun 2011 07:25:35 -0700
++
++linux (3.0-0.1) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * use the packaging version in the kernel
++  * use the kernels idea of its version for version_signature
++  * add dependancies for module-init-tools
++  * update control files to version 3
++  * printchanges/insertchanges allow override of prev_release
++  * correct Vcs-Git: to point to oneiric
++
++  [ Leann Ogasawara ]
++
++  * rebase to v3.0-rc1
++  * [Config] updateconfigs after rebase to 3.0-rc1
++  * ubuntu: dm-raid4-5 fix up build failure
++  * [Config] Temporarily Disable CONFIG_GPIO_EXYNOS4 on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_PLAT_SAMSUNG on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_S5PC100 on arm
++  * [Config] Temporarily Disable CONFIG_GPIO_S5PV210 on arm
++  * [Config] Temporarily disable CONFIG_BRCMSMAC on powerpc
++  * [Config] Temporarily Disable CONFIG_BRCMSMAC on arm
++  * [Config] Temporarily Disable CONFIG_RTL8192SE on arm
++  * [Config] Temporarily Disable CONFIG_RTL8192SE on powerpc
++  * [Config] Temporarily disable CONFIG_SMC91X on armel-omap
++  * rebase to v3.0-rc2
++
++  [ Manoj Iyer ]
++
++  * SAUCE: mmc: Enable MMC card reader for RICOH [1180:e823]
++    - LP: #790754
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86 idle: EXPORT_SYMBOL(default_idle, pm_idle) only when APM
++    demands it"
++  * drm/i915: fix regression after clock gating init split
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39 to v3.0-rc1
++  * rebase from v3.0-rc1 to v3.0-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Jun 2011 15:18:33 +0100
++
++linux (2.6.39-3.10) oneiric; urgency=low
++
++  [ Colin Ian King ]
++
++  * SAUCE: S3 early resume debug via keyboard LEDs
++
++  [ Ingo Molnar ]
++
++  * ubuntu: nx-emu - i386: NX emulation
++  * ubuntu: nx-emu - i386: mmap randomization for executable mappings
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] Disable CONFIG_FT1000 on powerpc64-smp"
++  * Revert "[Config] Disable CONFIG_DM_RAID45"
++  * [Config] enable CONFIG_BRCMFMAC=y
++  * [Config] enable CONFIG_MDIO_BITBANG=m across all arch's and flavors
++  * [Config] enable CONFIG_VIDEO_OUTPUT_CONTROL=m on armel-omap
++
++  [ Robert Nelson ]
++
++  * SAUCE: omap3: beagle: detect new xM revision B
++    - LP: #770679
++  * SAUCE: omap3: beagle: detect new xM revision C
++    - LP: #770679
++  * SAUCE: omap3: beagle: if rev unknown, assume xM revision C
++    - LP: #770679
++
++  [ Stefan Bader ]
++
++  * SAUCE: Convert dm-raid45 to new block plugging
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 May 2011 11:46:43 -0700
++
++linux (2.6.39-3.9) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_SCSI_LPFC_DEBUG_FS
++  * rebase to v2.6.39
++  * [Config] enable CONFIG_LLC2=m across all arch's and flavours
++  * [Config] enable CONFIG_INPUT_APANEL=m
++
++  [ Thomas Schlichter ]
++
++  * SAUCE: vesafb: mtrr module parameter is uint, not bool
++    - LP: #778043
++  * SAUCE: vesafb: enable mtrr WC by default
++    - LP: #778043
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc7 to v2.6.39
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 20 May 2011 09:52:32 +0100
++
++linux (2.6.39-2.8) oneiric; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37"
++  * Revert "ubuntu: AUFS -- aufs2-base.patch aufs2.1-37"
++  * Revert "[Config] Disable CONFIG_AUFS_FS"
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-39
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-39
++  * ubuntu: AUFS -- update to c6b76974311efc5bf3eddf921cd015b6aae46935
++  * ubuntu: AUFS -- clean up the aufs updater and BOM
++  * ubuntu: AUFS -- documentation on updating aufs2
++
++  [ Kees Cook ]
++
++  * ubuntu: Yama - LSM hooks
++  * ubuntu: Yama - create task_free security callback
++  * ubuntu: Yama - add ptrace relationship tracking interface
++  * ubuntu: Yama - unconditionally chain to Yama LSM
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: Fix drivers/staging/easycap FTBS"
++  * Revert "[Config] Disable CONFIG_EASYCAP"
++  * ubuntu: fsam7400 disable driver
++  * ubuntu: omnibook disable driver
++  * ubuntu: rfkill disable driver
++
++  [ Tim Gardner ]
++
++  * SAUCE: Fix extra reference in fb_open()
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 May 2011 09:23:56 -0700
++
++linux (2.6.39-2.7) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc7
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc6 to v2.6.39-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 10 May 2011 10:18:28 +0200
++
++linux (2.6.39-1.6) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc6
++  * SAUCE: [arm] fixup __aeabi_uldivmod undefined build error
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs after rebase to 2.6.39-rc6
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc5 to v2.6.39-rc6
++    - LP: #740126
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 05 May 2011 09:46:12 -0700
++
++linux (2.6.39-0.5) oneiric; urgency=low
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: Revert "x86, hibernate: Initialize mmu_cr4_features during boot"
++    - LP: #764758
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc5
++  * [Config] updateconfigs following rebase to v2.6.39-rc5
++
++  [ Paolo Pisati ]
++
++  * [Config] s/USB_MUSB_TUSB6010/USB_MUSB_OMAP2PLUS/ on omap3 to get musb
++    - LP: #759913
++
++  [ Stefan Bader ]
++
++  * Include nls_iso8859-1 for virtual images
++    - LP: #732046
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc4 to v2.6.39-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 27 Apr 2011 06:39:42 -0700
++
++linux (2.6.39-0.4) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc4
++  * [Config] updateconfigs following rebase to v2.6.39-rc4
++  * fixup powerpc implicit declaration of function
++    'crash_kexec_wait_realmode'
++  * [Config] Disable CONFIG_FT1000 on powerpc64-smp
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_TRANSPARENT_HUGEPAGE=y
++    - LP: #769503
++  * [Config] Add cachefiles.ko to virtual flavour
++    - LP: #770430
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc3 to v2.6.39-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 19 Apr 2011 06:25:20 -0700
++
++linux (2.6.39-0.3) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc3
++  * crash_kexec_wait_realmode() undefined when !SMP
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_PM_ADVANCED_DEBUG=y for i386/amd64
++    - LP: #632327
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc2 to v2.6.39-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 12 Apr 2011 06:52:24 -0700
++
++linux (2.6.39-0.2) oneiric; urgency=low
++
++  [ Gustavo F. Padovan ]
++
++  * SAUCE: Revert "Bluetooth: Add new PID for Atheros 3011"
++    - LP: #720949
++
++  [ John Johansen ]
++
++  * AppArmor: Fix masking of capabilities in complain mode
++    - LP: #748656
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc2
++  * [Config] updateconfigs following rebase to v2.6.39-rc2
++  * hv_mouse needs delay.h
++  * olpc_dcon_xo_1 needs delay.h
++  * olpc_dcon_xo_1_5 needs delay.h
++  * Update dropped.txt for Oneiric
++
++  [ Steve Langasek ]
++
++  * [Config] Make linux-libc-dev coinstallable under multiarch
++    - LP: #750585
++
++  [ Upstream Kernel Changes ]
++
++  * x86, hibernate: Initialize mmu_cr4_features during boot
++    - LP: #752870
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.39-rc1 to v2.6.39-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 06 Apr 2011 11:04:15 -0700
++
++linux (2.6.39-0.1) oneiric; urgency=low
++
++  [ Brad Figg ]
++
++  * [Config] Set CONFIG_NR_CPUS=256 for amd64 generic
++    - LP: #737124
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: HID: hid-ntrig: add support for 1b96:0006 model
++  * SAUCE: HID: ntrig: fix suspend/resume on recent models
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: (drop after 2.6.39) v4l: make sure drivers supply a zeroed
++    struct v4l2_subdev
++    - LP: #745213
++
++  [ Kees Cook ]
++
++  * [Config] packaging: adjust perms on vmlinuz as well
++  * SAUCE: nx-emu: further clarify dmesg reporting
++    - LP: #745181
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.39-rc1
++  * [Config] updateconfigs following rebase to v2.6.39-rc1
++  * [Config] Disable CONFIG_DM_RAID45
++  * [Config] Disable CONFIG_SCSI_ISCSITARGET
++  * [Config] Disable CONFIG_EASYCAP
++  * [Config] Disable CONFIG_AUFS_FS
++  * update bnx2 firmware files in d-i/firmware/nic-modules
++  * xhci-pci.c resolve implicit declaration of kzalloc
++  * [Config] Enable CONFIG_DRM_PSB for only x86
++  * [Config] Enable CONFIG_RTS_PSTOR for only x86
++  * mfd/asic3: Fix typo, s/irq_data/data/
++
++  [ Luke Yelavich ]
++
++  * [Config] Disable CONFIG_CRASH_DUMP on 32-bit powerpc kernels
++    - LP: #745358
++  * [Config] Disable CONFIG_DRM_RADEON_KMS on powerpc kernels
++  * [Config] Build some framebuffer drivers as modules for powerpc kernels.
++
++  [ Manoj Iyer ]
++
++  * SAUCE: thinkpad-acpi: module autoloading for newer Lenovo ThinkPads.
++    - LP: #745217
++
++  [ Tim Gardner ]
++
++  * SAUCE: INR_OPEN=4096
++    - LP: #663090
++  * SAUCE: Increase the default hard limit for open FDs to 4096
++    - LP: #663090
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.39-rc1) arm: versatile : Fix typo introduced in irq
++    namespace cleanup
++  * (drop after 2.6.39-rc1) [media] staging: altera-jtag needs delay.h
++  * ALSA: pcm: fix infinite loop in snd_pcm_update_hw_ptr0()
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38 to v2.6.39-rc1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:50:10 -0700
++
++linux (2.6.39-0.0) oneiric; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Open Oneiric 
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:29:23 -0700
++
++linux (2.6.38-7.39) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload.  This is just to rebuild with gcc-4.5.2-7ubuntu1.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Mar 2011 09:27:45 -0700
++
++linux (2.6.38-7.38) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload take 2.  2.6.38-7.37 was accidentally uploaded before
++    gcc-4.5.2-6ubuntu5 finished building on all arches.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 22 Mar 2011 06:12:47 -0700
++
++linux (2.6.38-7.37) natty; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No change upload.  This is just to rebuild with gcc-4.5.2-6ubuntu5.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 20 Mar 2011 16:02:48 -0700
++
++linux (2.6.38-7.36) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler
++    optimisation"
++  * purge last vestiges of maverick
++  * [Config] switch CONFIG_FB_VESA back to module
++
++  [ Chris Wilson ]
++
++  * SAUCE: drm/i915: Fix pipelined fencing
++    - LP: #717114
++
++  [ Loïc Minier ]
++
++  * Include nls_cp437 module in virtual for fat
++    - LP: #732046
++  * Support arch= cross-compilation for any arch
++  * Fix couple of typos in 0-common-vars.mk
++  * Enforce DEFAULT_MMAP_MIN_ADDR on armhf
++  * Add armhf to Debian -> Linux arch map
++  * Add initial armhf.mk
++  * Enable common packages for armhf
++
++  [ Upstream Kernel Changes ]
++
++  * Yama: fix default relationship to check thread group
++    - LP: #737676
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 18 Mar 2011 18:18:02 +0000
++
++linux (2.6.38-7.35) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to 2fbfac4e053861925fa3fffcdc327649b09af54c
++  * rebase fixes bug #715330
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI for powerpc 32bit to fix FTBS
++  * rebase to v2.6.38 final
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: Apply OPTION_BLACKLIST_SENDSETUP also for ZTE MF626
++    - LP: #636091
++
++  [ Tim Gardner ]
++
++  * [Confg] CONFIG_BOOT_PRINTK_DELAY=y
++
++  [ Upstream Kernel Changes ]
++
++  * Yama: use thread group leader when creating match
++    - LP: #729839
++  * (drop after 2.6.38) ahci: AHCI mode SATA patch for Intel Patsburg SATA
++    RAID controller
++    - LP: #735240
++  * (drop after v2.6.38) x86, quirk: Fix SB600 revision check
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc8 to v2.6.38 final
++    - LP: #715330
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 15 Mar 2011 19:04:19 +0000
++
++linux (2.6.38-6.34) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] normalise CONFIG_INTEL_TXT
++  * SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler optimisation
++    - LP: #730860
++  * rebase to mainline v2.6.38-rc8
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc7 + fb62c00a6d8942775abc23d1621db1252e2d93d1
++    to v2.6.38-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Mar 2011 11:54:48 +0000
++
++linux (2.6.38-6.33) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * d-i -- enable speakup-modules udeb
++    - LP: #672699
++  * rebase to 493f3358cb289ccf716c5a14fa5bb52ab75943e5
++  * [Config] debian PPC64 configuration
++  * [Config] cleanup powerpc config fixing unexpected inconsistancies
++  * [Config] resync ppc64 configuration
++  * SAUCE: match up ENTRY/END naming for 32/64 bit
++  * rebase to fb62c00a6d8942775abc23d1621db1252e2d93d1
++  * [Config] update configs after rebase to
++    fb62c00a6d8942775abc23d1621db1252e2d93d1
++  * [Config] pps_gen_parport no longer built
++
++  [ Corentin Chary ]
++
++  * SAUCE: (drop after 2.6.38) eeepc-wmi: reorder keymap
++    - LP: #689393
++  * SAUCE: (drop after 2.6.38) eeepc-wmi: add wlan key found on 1015P
++    - LP: #689393
++
++  [ John Johansen ]
++
++  * SAUCE: Fix aufs calling of security_path_mknod
++    - LP: #724456
++
++  [ Kees Cook ]
++
++  * SAUCE: proc: hide kernel addresses via %pK in /proc/<pid>/stack
++
++  [ Tim Gardner ]
++
++  * rebase to 2.6.38-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "drm/i915: fix corruptions on i8xx due to relaxed fencing"
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc6 to v2.6.38-rc7 +
++    fb62c00a6d8942775abc23d1621db1252e2d93d1
++    - LP: #721389
++    - LP: #722925
++    - LP: #723672
++    - LP: #723676
++    - LP: #715318
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Mar 2011 15:33:17 +0000
++
++linux (2.6.38-5.32) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to mainline 6f576d57f1fa0d6026b495d8746d56d949989161
++  * [Config] updateconfigs following rebase to v2.6.38-rc6
++  * [Config] enable CONFIG_DMAR
++    - LP: #552311
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: skip FDI & PCH enabling for DP_A
++    - LP: #561802, #600453, #681877
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc5 to v2.6.38-rc6
++    - LP: #718402
++    - LP: #719524
++    - LP: #721126
++    - LP: #719691
++    - LP: #722689
++    - LP: #722310
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 22 Feb 2011 13:28:39 +0000
++
++linux (2.6.38-4.31) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * add in bugs closed by upstream patches pulled in by rebases
++  * rebase to 795abaf1e4e188c4171e3cd3dbb11a9fcacaf505
++  * [Config] enable CONFIG_VSX to allow use of vector instuctions
++  * resync with maverick 98defa1c5773a3d7e4c524967eb01d5bae035816
++  * rebase to mainline v2.6.38-rc5
++  * SAUCE: ecryptfs: read on a directory should return EISDIR if not
++    supported
++    - LP: #719691
++
++  [ Colin Ian King ]
++
++  * SAUCE: Dell All-In-One: Remove need for Dell module alias
++
++  [ Manoj Iyer ]
++
++  * SAUCE: (drop after 2.6.38) add ricoh 0xe823 pci id.
++    - LP: #717435
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_CRYPTO_CRC32C_INTEL=y
++
++  [ Upstream Kernel Changes ]
++
++  * Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15
++    - LP: #702434
++  * vfs: fix BUG_ON() in fs/namei.c:1461
++
++  [ Vladislav P ]
++
++  * SAUCE: Release BTM while sleeping to avoid deadlock.
++    - LP: #713837
++
++  [ Major Kernel Changes ]
++
++  * rebase from v2.6.38-rc4 to v2.6.38-rc5
++    - LP: #579276
++    - LP: #715877
++    - LP: #713769
++    - LP: #716811
++  * resync with Maverick Ubuntu-2.6.35-27.47
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Feb 2011 17:24:09 +0000
++
++linux (2.6.38-3.30) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.38-rc4
++  * ppc64 -- add basic architecture
++  * ubuntu: AUFS -- update to 65835da20b77c98fb538c9114fc31f5de1328230
++
++  [ Colin Ian King ]
++
++  * SAUCE: Add WMI hotkeys support for Dell All-In-One series
++    - LP: #676997
++  * SAUCE: Add WMI hotkeys support for another Dell All-In-One series
++    - LP: #701530
++  * SAUCE: Dell WMI: Use sparse keymaps and tidy up code.
++    - LP: #701530
++
++  [ Dan Rosenberg ]
++
++  * SAUCE: (drop after 2.6.38) Convert net %p usage %pK
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of
++    attacking"
++  * SAUCE: (drop after 2.6.38) use %pK for /proc/kallsyms and /proc/modules
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_BLK_CGROUP=y
++    - LP: #706394
++  * [Config] CONFIG_DELL_WMI_AIO=m
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915/lvds: Restore dithering on native modes for gen2/3
++    - LP: #711568
++
++  [ Upstream Kernel Changes ]
++
++  * rebase from v2.6.38-rc3 to v2.6.38-rc4.
++    - LP: #701271
++    - LP: #708521
++    - LP: #710371
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Feb 2011 02:07:18 +0000
++
++linux (2.6.38-2.29) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to 1f0324caefd39985e9fe052fac97da31694db31e
++  * [Config] updateconfigs following rebase to
++    1f0324caefd39985e9fe052fac97da31694db31e
++  * rebase to 70d1f365568e0cdbc9f4ab92428e1830fdb09ab0
++  * [Config] reenable HIBERNATE
++    - LP: #710877
++  * rebase to v2.6.38-rc3
++  * [Config] reenable CONFIG_CRASH_DUMP
++
++  [ Kamal Mostafa ]
++
++  * SAUCE: rtl8192se: fix source file perms
++  * SAUCE: rtl8192se: fix source file newline
++  * SAUCE: omnibook: fix source file newline
++
++  [ Kees Cook ]
++
++  * [Config] packaging: really make System.map mode 0600
++
++  [ Ricardo Salveti de Araujo ]
++
++  * SAUCE: OMAP3630: PM: don't warn the user with a trace in case of
++    PM34XX_ERRATUM
++
++  [ Soren Hansen ]
++
++  * SAUCE: nbd: Remove module-level ioctl mutex
++
++  [ Tim Gardner ]
++
++  * SAUCE: Disable building the ACPI debugfs source
++
++  [ Upstream Kernel Changes ]
++
++  * Set physical start and alignment 1M for virtual i386
++    - LP: #710754
++
++  [ Upstream Kernel Changes ]
++
++  * rebase from v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++    to v2.6.38-rc3
++    - LP: #707902
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 16:30:32 +0000
++
++linux (2.6.38-1.28) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to b1cee06249dfa0ab30951e7f06490a75c155b620
++
++  [ Ricardo Salveti de Araujo ]
++
++  * SAUCE: omap3: beaglexm: fix DVI initialization
++  * [Config] omap: move CONFIG_PANEL_GENERIC_DPI to build in to make
++    display work at Beagle
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 10:51:57 +0000
++
++linux (2.6.38-1.27) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update aufs-update to track new locations of headers
++  * ubuntu: AUFS -- update to c5021514085a5d96364e096dbd34cadb2251abfd
++  * SAUCE: ensure root is ready before running usermodehelpers in it
++  * correct the Vcs linkage to point to natty
++  * rebase to linux tip e78bf5e6cbe837daa6ab628a5f679548742994d3
++  * [Config] update configs following rebase
++    e78bf5e6cbe837daa6ab628a5f679548742994d3
++  * SAUCE: Yama: follow changes to generic_permission
++  * ubuntu: compcache -- follow changes to bd_claim/bd_release
++  * ubuntu: iscsitarget -- follow changes to open_bdev_exclusive
++  * ubuntu: ndiswrapper -- fix interaction between __packed and packed
++  * ubuntu: AUFS -- update to 806051bcbeec27748aae2b7957726a4e63ff308e
++  * update package version to match payload version
++  * rebase to e6f597a1425b5af64917be3448b29e2d5a585ac8
++  * rebase to v2.6.38-rc1
++  * [Config] updateconfigs following rebase to v2.6.38-rc1
++  * SAUCE: x86 fix up jiffies/jiffies_64 handling
++  * rebase to linus tip 2b1caf6ed7b888c95a1909d343799672731651a5
++  * [Config] updateconfigs following rebase to
++    2b1caf6ed7b888c95a1909d343799672731651a5
++  * [Config] disable CONFIG_TRANSPARENT_HUGEPAGE to fix i386 boot crashes
++  * ubuntu: AUFS -- suppress benign plink warning messages
++    - LP: #621195
++  * [Config] CONFIG_NR_CPUS=256 for amd64 -server flavour
++  * rebase to v2.6.38-rc2
++  * rebase to mainline d315777b32a4696feb86f2a0c9e9f39c94683649
++  * rebase to c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++  * [Config] update configs following rebase to
++    c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++  * [Config] disable CONFIG_AD7152 to fix FTBS on armel versatile
++  * [Config] disable CONFIG_AD7150 to fix FTBS on armel versatile
++  * [Config] disable CONFIG_RTL8192CE to fix FTBS on armel omap
++  * [Config] disable CONFIG_MANTIS_CORE to fix FTBS on armel versatile
++
++  [ Kees Cook ]
++
++  * SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of attacking
++
++  [ Stefan Bader ]
++
++  * Temporarily disable RODATA for virtual i386
++    - LP: #699828
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NLS_DEFAULT=utf8
++    - LP: #683690
++  * [Config] CONFIG_HIBERNATION=n
++  * update bnx2 firmware files in d-i/firmware/nic-modules
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "drm/radeon/bo: add some fallback placements for VRAM only
++    objects."
++  * packaging: make System.map mode 0600
++  * thinkpad_acpi: Always report scancodes for hotkeys
++    - LP: #702407
++  * sched: tg->se->load should be initialised to tg->shares
++  * Input: sysrq -- ensure sysrq_enabled and __sysrq_enabled are consistent
++  * brcm80211: include linux/slab.h for kfree
++  * pch_dma: add include/slab.h for kfree
++  * i2c-eg20t: include linux/slab.h for kfree
++  * gpio/ml_ioh_gpio: include linux/slab.h for kfree
++  * tty: include linux/slab.h for kfree
++  * winbond: include linux/delay.h for mdelay et al
++
++  [ Upstream Kernel Changes ]
++
++  * mark the start of v2.6.38 versioning
++  * rebase v2.6.37 to v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
++    - LP: #689886
++    - LP: #702125
++    - LP: #608775
++    - LP: #215802
++    - LP: #686333
++    - LP: #677830
++    - LP: #677652
++    - LP: #696493
++    - LP: #697240
++    - LP: #689036
++    - LP: #705323
++    - LP: #686692
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 09 Jan 2011 13:44:52 +0000
++
++linux (2.6.37-12.26) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.37-rc8
++  * [Config] armel -- reenable omap flavour
++  * [Config] disable CONFIG_MACH_OMAP3517EVM to fix FTBS on armel omap
++  * [Config] disable CONFIG_GPIO_VX855 to fix FTBS on omap armel
++  * [Config] disable CONFIG_WESTBRIDGE_ASTORIA to fix FTBS on omap armel
++  * [Config] disable CONFIG_TI_DAVINCI_EMAC to fix FTBS on omap armel
++  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
++  * [Config] track missing modules
++  * rebase to v2.6.37 final
++
++  [ Chase Douglas ]
++
++  * SAUCE: (drop after 2.6.37) HID: magicmouse: Don't report REL_{X, Y} for
++    Magic Trackpad
++
++  [ Stefan Bader ]
++
++  * Revert "SAUCE: blkfront: default to sd devices"
++    - LP: #684875
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (no-up) libata: Ignore HPA by default."
++    - LP: #380138
++  * [Config] Added autofs4.ko to -virtual flavour
++    - LP: #692917
++
++  [ Upstream Kernel Changes ]
++
++  * Add support for Intellimouse Mode in ALPS touchpad on Dell E2 series
++    Laptops
++    - LP: #632884
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc8
++  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
++  * rebase to v2.6.37 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Dec 2010 18:34:13 +0000
++
++linux (2.6.37-11.25) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i -- add hpsa to the list of block devices
++    - LP: #684304
++  * [Config] add vmw-balloon driver to -virtual flavour
++    - LP: #592039
++  * rebase to v2.6.37-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 21 Dec 2010 13:35:28 +0000
++
++linux (2.6.37-10.24) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.37-rc6
++  * updateconfigs following rebase to v2.6.37-rc6
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 16 Dec 2010 12:34:19 +0000
++
++linux (2.6.37-9.23) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks
++    - LP: #689606
++  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks (grub)
++    - LP: #689606
++
++  [ Kees Cook ]
++
++  * SAUCE: RO/NX protection for loadable kernel, fix ftrace
++    - LP: #690190
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 15 Dec 2010 19:29:57 +0000
++
++linux (2.6.37-9.22) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.35-rc5
++  * [Config] updateconfigs following rebase to v2.6.37-rc5
++  * (no-up) add support for installed header files to ubuntu directory
++    - LP: #684666
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++  * ubuntu: dm-raid4-5 -- follow changes to bio flags
++  * ubuntu: dm-raid4-5 -- re-enable
++  * ubuntu: omnibook -- update BOM
++  * ubuntu: ndiswrapper -- update BOM to match actual version
++  * ubuntu: ndiswrapper -- follow removal of the BKL and locked ioctl
++  * ubuntu: ndiswrapper -- re-enable
++  * ubuntu: iscsitarget -- re-instate copy_io_context
++  * ubuntu: iscsitarget -- follow changes to semaphore initialisation
++  * ubuntu: iscsitarget -- convert NIPQUAD to %pI4
++  * ubuntu: iscsitarget -- re-enable
++
++  [ Kees Cook ]
++
++  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Enable jack sense for Thinkpad Edge 13
++    - LP: #685015
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_9P_FSCACHE=y,CONFIG_9P_FS_POSIX_ACL=y
++  * [Config] CONFIG_CRYPTO_CRC32C=y
++    - LP: #681819
++  * [Config] CONFIG_9P_FSCACHE=n
++  * [Config] Add nfsd modules to -virtual flavour
++    - LP: #688070
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Staging: zram: work around oops due to startup ordering snafu"
++  * NFS: Fix panic after nfs_umount()
++    - LP: #683938
++  * x86: Add NX protection for kernel data
++  * x86: Add RO/NX protection for loadable kernel modules
++  * x86: Resume trampoline must be executable
++  * x86: RO/NX protection for loadable kernel, jump_table fix
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.37-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Dec 2010 18:15:35 +0000
++
++linux (2.6.37-8.21) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- include the aufs_types.h file in
++    linux-libc-headers"
++  * Revert "(no-up) add support for installed header files to ubuntu
++    directory"
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 05 Dec 2010 17:33:28 +0000
++
++linux (2.6.37-8.20) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] drivers/serial/mfd.c: Fix ARM compile error"
++  * Revert "SAUCE: Nouveau: Disable acceleration on MacBook Pros"
++  * Revert "SAUCE: Nouveau: Add quirk framework to disable acceleration"
++  * Revert "SAUCE: i915 -- disable powersave by default"
++  * SAUCE: enable Marvell 9128 PCIe SATA controller
++    - LP: #658521
++  * [Config] evtchn has been renamed
++  * (no-up) add support for installed header files to ubuntu directory
++    - LP: #684666
++  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
++    - LP: #684666
++
++  [ Tim Gardner ]
++
++  * [Config] MISS: evtchn, NEW : xen-evtchn
++  * rebase to v2.6.37-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: Clean conflicting modesetting registers upon init
++    - LP: #683775
++  * rebase to v2.6.37-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 03 Dec 2010 18:42:07 +0000
++
++linux (2.6.37-7.19) natty; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Add bnx2 firmware to nic-modules udeb
++    - LP: #676245
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 26 Nov 2010 17:53:45 +0000
++
++linux (2.6.37-7.18) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID"
++  * Revert "SAUCE: Add extra headers to linux-libc-dev"
++  * Revert "SAUCE: Enable speedstep for sonoma processors."
++  * [Config] enable CONFIG_BT_HCIUART_ATH3K
++  * [Config] enable CONFIG_IWLWIFI_DEBUGFS
++  * [Config] standardise CONFIG_MII
++  * [Config] standardise CONFIG_PRISM2_USB
++  * [Config] standardise CONFIG_SCSI_QLA_ISCSI
++  * [Config] build in CONFIG_AGP
++  * [Config] build in CONFIG_AGP_INTEL
++  * [Config] build in CONFIG_AGP_AMD
++  * [Config] build in CONFIG_AGP_AMD64
++  * [Config] build in CONFIG_AGP_NVIDIA
++  * [Config] build in CONFIG_AGP_VIA
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI for FTBS (arm)
++  * (no-up): document the new ## scheme
++  * [Config] harmonise CONFIG_SERIAL_8250_NR_UARTS
++  * [Config] update CONFIG_SERIAL_8250_RUNTIME_UARTS=32
++    - LP: #675453
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: ARM: Adding vdd_sdi regulator supply to OMAP3EVM
++
++  [ Upstream Kernel Changes ]
++
++  * nx-emu: fix inverted report of disable_nx
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 23 Nov 2010 21:00:39 +0000
++
++linux (2.6.37-6.17) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2-standalone.patch
++    aufs2.1-36-UNRELEASED-20101103"
++  * Revert "ubuntu: AUFS -- aufs2-base.patch
++    aufs2.1-36-UNRELEASED-20101103"
++  * [Config] standardise CONFIG_BT
++  * [Config] standardise CONFIG_IRDA
++  * [Config] standardise CONFIG_LAPB
++  * [Config] standardise CONFIG_RDS
++  * [Config] standardise CONFIG_RFKILL
++  * [Config] standardise CONFIG_TIPC
++  * [Config] standardise CONFIG_X25
++  * [Config] standardise CONFIG_INPUT_EVDEV
++  * [Config] standardise CONFIG_INPUT_JOYDEV
++  * [Config] standardise CONFIG_INPUT_JOYSTICK
++  * [Config] standardise CONFIG_INPUT_TOUCHSCREEN
++  * [Config] CONFIG_INPUT_TOUCHSCREEN=n for FTBS (arm)
++  * [Config] CONFIG_IRDA=n for FTBS (arm)
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-37
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37
++  * ubuntu: AUFS -- update to 097bf62d6f49619359d34bf17f242df38562489a
++
++  [ Tim Gardner ]
++
++  * SAUCE: Fix drivers/staging/easycap FTBS
++  * [Config] CONFIG_EASYCAP=m after fixing FTBS
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Add NX protection for kernel data"
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 18:09:10 +0000
++
++linux (2.6.37-6.16) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] update config for CONFIG_DEBUG_SET_MODULE_RONX"
++  * rebase to v2.6.37-rc3
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_SCHED_AUTOGROUP=y
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Add RO/NX protection for loadable kernel modules"
++  * sched: automated per session task groups
++  * rebase to v2.6.37-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 10:11:13 +0000
++
++linux (2.6.37-6.15) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] standardise CONFIG_CEPH_FS
++  * [Config] standardise CONFIG_SCSI_LPFC_DEBUG_FS
++  * [Config] standardise CONFIG_SCSI_PROC_FS
++  * [Config] standardise CONFIG_UBIFS_FS
++  * [Config] standardise CONFIG_USB_GADGET_DEBUG_FS
++
++  [ Kees Cook ]
++
++  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Enable jack sense for Thinkpad Edge 11
++    - LP: #677210
++  * SAUCE: enable rfkill for rtl8192se driver
++    - LP: #640992
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_EASYCAP=n for FTBS
++  * Rebase to v2.6.32-rc2+git
++
++  [ Upstream Kernel Changes ]
++
++  * x86: Fix improper large page preservation
++  * x86: Add NX protection for kernel data
++  * x86: Add RO/NX protection for loadable kernel modules
++
++  [ Upstream Kernel Changes ]
++
++  * Rebase to Linus 2.6.37-rc2+git
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 20 Nov 2010 11:40:00 +0000
++
++linux (2.6.37-5.14) natty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * PCI: fix offset check for sysfs mmapped files
++    - LP: #676963
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Nov 2010 18:12:27 +0000
++
++linux (2.6.37-5.13) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebased to v2.6.37-rc2
++  * updateconfigs following rebase to v2.6.37-rc2
++
++  [ Tim Gardner ]
++
++  * [Config] Added NFS and related modules to virtual flavour
++    - LP: #659084
++
++  [ Upstream Kernel Changes ]
++
++  * x86, cpu: Rename verify_cpu_64.S to verify_cpu.S
++  * x86, cpu: Clear XD_DISABLED flag on Intel to regain NX
++  * x86, cpu: Call verify_cpu during 32bit CPU startup
++  * x86, cpu: Only CPU features determine NX capabilities
++
++  [ Upstream Changes ]
++
++  * rebased to v2.67.37-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 16 Nov 2010 13:13:29 +0000
++
++linux (2.6.37-4.12) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Upstream] HID: magicmouse: add param for scroll speed"
++  * Revert "[Upstream] HID: magicmouse: properly account for scroll
++    movement in state"
++  * Revert "[Upstream] HID: magicmouse: disable and add module param for
++    scroll acceleration"
++  * Revert "[Upstream] HID: magicmouse: scroll on entire surface, not just
++    middle of mouse"
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: hid: ntrig: remove sysfs nodes
++  * SAUCE: hid: ntrig: Setup input filtering manually
++  * SAUCE: hid: ntrig: New ghost-filtering event logic
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++    - LP: #348861
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "mmc: fix all hangs related to mmc/sd card insert/removal during
++    suspend/resume"
++  * Revert "[ARM] implement arch_randomize_brk()"
++  * Revert "ARM: stack protector: change the canary value per task"
++  * Revert "ARM: initial stack protector (-fstack-protector) support"
++  * Revert "ALSA: hda - Handle pin NID 0x1a on ALC259/269"
++  * Revert "ALSA: hda - Handle missing NID 0x1b on ALC259 codec"
++  * Revert "perf probe: Add kernel source path option"
++  * hid: ntrig: Support single-touch devices
++  * hid: ntrig: Mask pen switch events
++  * net: rtnetlink.h -- only include linux/netdevice.h when used by the
++    kernel
++    - LP: #673073
++  * Fix userspace build of linux/fs.h
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 15 Nov 2010 19:31:44 +0000
++
++linux (2.6.37-3.11) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- update to
++    b37c575759dc4535ccc03241c584ad5fe69e3b25"
++  * Revert "ubuntu: AUFS -- track changes to the arguements to fop fsync()"
++  * Revert "ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601"
++  * Revert "ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601"
++  * Revert "ubuntu: AUFS -- aufs2 base patch for linux-2.6.34"
++  * [Config] Disable intel_idle for -virtual kernels
++    - LP: #651370
++  * [Config] enforcer -- ensure we never enable CONFIG_IMA
++  * debian -- pass the correct flavour name when checking configs
++  * [Config] enforcer -- ensure CONFIG_INTEL_IDLE is off for -virtual
++  * [Config] ensure CONFIG_IPV6=y for powerpc
++  * [Config] enforcer -- ensure CONFIG_IPV6=y
++  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- update to aufs2.1-36-UNRELEASED-20101103
++  * ubuntu: AUFS -- re-enable
++  * ubuntu: AUFS -- track changes to work queue initialisation
++  * ubuntu: AUFS -- track changes to llseek in v2.6.37-rc1
++  * SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++    - LP: #614008
++  * SAUCE: drm -- stop early access to drm devices
++
++  [ Jeremy Kerr ]
++
++  * [Config] Build-in powermac ZILOG serial driver
++    - LP: #673346
++
++  [ Kees Cook ]
++
++  * SAUCE: nx-emu: use upstream ASLR when possible
++
++  [ Tim Gardner ]
++
++  * [Config] Use correct be2iscsi module name in d-i/modules/scsi-modules
++    - LP: #628776
++
++  [ Upstream Kernel Changes ]
++
++  * i386: NX emulation
++  * nx-emu: drop exec-shield sysctl, merge with disable_nx
++  * nx-emu: standardize boottime message prefix
++  * mmap randomization for executable mappings on 32-bit
++  * exec-randomization: brk away from exec rand area
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 11 Nov 2010 23:46:37 +0000
++
++linux (2.6.37-2.10) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * reinstate armel config changes:
++   * [Config] CONFIG_GPIO_PCH=n for armel FTBS
++   * [Config] CONFIG_GPIO_VX855=n for armel FTBS
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Nov 2010 22:20:35 +0000
++
++linux (2.6.37-2.9) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * config -- fix genportsconfig
++  * [Config] move powerpc over from ports to distro
++  * bump master version number to match contained kernel
++  * SAUCE: fix documentation strings for struct input_keymap_entry
++  * usb: gadget: goku_udc: add registered flag bit
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Nov 2010 15:14:11 +0000
++
++linux (2.6.36-2.8) natty; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config]: fix changed CONFIG_SYSFS_DEPRECATED_V2 enforcement rules
++  * [Config]: TWL4030_CORE=n for FTBS
++  * [Config]: CONFIG_ATH6K_LEGACY=n for FTBS
++  * [Config]: CONFIG_SOLO6X10=n for FTBS
++  * [Config]: CONFIG_GPIO_PCH=n for armel FTBS
++  * [Config]: CONFIG_GPIO_VX855=n for armel FTBS
++  * [Config]: CONFIG_DRM_NOUVEAU=n for armel FTBS
++  * [Config]: CONFIG_LINE6_USB=n for armel FTBS
++  * [Config]: CONFIG_SENSORS_AK8975=n for armel FTBS
++  * [Config]: CONFIG_I2C_I801=n for armel FTBS
++  * UBUNTU: SAUCE: AppArmor: Fix unpack of network tables.
++  * AppArmor: compatibility patch for v5 interface
++  * AppArmor: compatibility patch for v5 network controll
++  * Dropped (pre-stable): input: Support Clickpad devices in ClickZone mode
++  * Dropped: UBUNTU: SAUCE: libata: Add ALPM power state accounting to the AHCI driver
++  * Dropped: UBUNTU: SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++  * Dropped: hid: 3m: Convert to MT slots
++  * Dropped: HID: magicmouse: don't allow hidinput to initialize the device
++  * Dropped: HID: magicmouse: simplify touch data bit manipulation
++  * Dropped: HID: magicmouse: simplify touch down logic
++  * Dropped: HID: magicmouse: enable Magic Trackpad support
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: remove sysfs nodes
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: Setup input filtering manually
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: New ghost-filtering event logic
++  * Dropped: UBUNTU: SAUCE: hid: ntrig: identify firmware version (wiggled)
++  * Dropped: UBUNTU: (pre-stable): input: Support Clickpad devices in ClickZone mode
++  * Dropped: UBUNTU: SAUCE: KMS: cache the EDID information of the LVDS
++  * Dropped: UBUNTU: SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * Dropped: UBUNTU: SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++  * Dropped: UBUNTU: SAUCE: x86: implement cs-limit nx-emulation for ia32
++  * Dropped: UBUNTU: SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
++  * Dropped: UBUNTU: SAUCE: [um] Don't use nx_enabled under UML
++  * Dropped: UBUNTU: SAUCE: x86: brk away from exec rand area
++
++  [ Upstream Kernel Changes ]
++
++  * rebased against 2.6.27-rc1
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Oct 2010 19:35:05 -0600
++
++linux (2.6.36-1.7) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebased to v2.6.36 final
++  * [Config] update configs following rebase to v2.6.36 final
++  * [Config] update ports configs following rebase to v2.6.36 final
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to v2.6.36 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 21 Oct 2010 14:28:57 +0100
++
++linux (2.6.36-1.6) natty; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * drop broadcom staging driver preview:
++   * Revert "Staging: Add initial release of brcm80211 - Broadcom 802.11n
++     wireless LAN driver."
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 20 Oct 2010 10:41:25 +0100
++
++linux (2.6.36-1.5) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.36-rc8
++  * updateconfigs following rebase to v2.6.36-rc8
++  * updateportsconfigs following rebase to v2.6.36-rc8
++  * config -- simplify the kernelconfig interface
++  * config -- add new config mode 'dumpconfigs'
++
++  [ Tim Gardner ]
++
++  * Simplify the use of CROSS_COMPILER
++
++  [ Upstream Kernel Changes ]
++
++  * drop broadcom staging driver preview:
++   * Revert "staging: brcm80211: Make compiling of brcm80211.ko and
++     brcmfmac.ko mutually exclusive."
++   * Revert "staging: brcm80211: Fix compile issue when BRCM80211_PCI is not
++     set."
++   * Revert "Staging: brcm80211: remove driver specific -W options"
++   * Revert "Staging: brcm80211: clean up makefile cflag lines"
++   * Revert "staging: brcm80211: add fullmac driver"
++   * Revert "staging: brcm80211: use string native library"
++   * Revert "staging: brcm80211: use native ctype library"
++   * Revert "staging: brcm80211: fix remaining checkpatch errors."
++   * Revert "staging: brcm80211: fix "ERROR: trailing whitespace.""
++   * Revert "staging: brcm80211: fix "ERROR: spaces required around that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: spaces prohibited around that
++     ':' ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required before that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required after that ...""
++   * Revert "staging: brcm80211: fix "ERROR: space required after that close
++     brace""
++   * Revert "staging: brcm80211: fix "ERROR: space prohibited before
++     ...close square bracket""
++   * Revert "staging: brcm80211: fix "ERROR: space prohibited after that
++     ...""
++   * Revert "staging: brcm80211: fix "ERROR: need consistent spacing around
++     '*'""
++   * Revert "staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'"
++   * Revert "staging: brcm80211: fix "ERROR: Macros w/ mult. statements ...
++     do - while loop""
++   * Revert "staging: brcm80211: fix "ERROR: Macros w/ complex values ...
++     parenthesis""
++   * Revert "staging: brcm80211: fix "ERROR: do not initialise statics to 0
++     or NULL""
++   * Revert "staging: brcm80211: fix "ERROR: do not initialise globals to 0
++    or NULL""
++   * Revert "staging: brcm80211: fix "ERROR: while should follow close brace
++     '}'""
++   * Revert "staging: brcm80211: fix "ERROR: that open brace { ... prev
++     line""
++   * Revert "staging: brcm80211: fix "ERROR: trailing statements should be
++     on next line""
++   * Revert "staging: brcm80211: fix "ERROR: do not use assignment in if
++     condition""
++   * Revert "staging: brcm80211: fix "ERROR: return is not a function,
++     paren...""
++   * Revert "staging: brcm80211: fix "ERROR: open brace '{' following
++     function dec...""
++   * Revert "staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo
++     *bar"'"
++   * Revert "staging: brcm80211: Fix URLs for firmware files."
++   * Revert "staging: brcm80211: use '%pM' format to print MAC address"
++   * Revert "staging: brcm80211: Add contact info to TODO list."
++   * Revert "staging: brcm80211: Fix some initialisation failure paths"
++  * Export dump_{write,seek} to binary loader modules
++  * rebase to v2.6.36-rc8.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Oct 2010 18:58:11 +0100
++
++linux (2.6.36-0.4) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: perf: increase stack footprint to avoid stack-protector warning
++    (fixes FTBS on powerpc)
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 13:16:16 +0100
++
++linux (2.6.36-0.3) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable CONFIG_SCSI_QLA_ISCSI to fix FTBS on powerpc
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 03:01:30 +0100
++
++linux (2.6.36-0.2) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] updateportsconfigs following rebase to 2.6.36-rc7
++    (fix FTBS on powerpc)
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 13 Oct 2010 23:25:12 +0100
++
++linux (2.6.36-0.1) natty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * reduce disk usage during buildd builds
++    - LP: #645653
++  * [Config] enforcer -- ensure CONFIG_INIT_PASS_ALL_PARAMS is y
++  * [Config] armel -- drop omap flavour
++
++  [ Tim Gardner ]
++
++  * Added dropped patch list
++  * more dropped patches
++  * [Config] Disable aufs, dmraid-4.5, ndis-wrapper
++  * [Config] Add support for cross compiling armel
++  * [Config] CONFIG_SCSI_QLA_ISCSI=n for armel
++  * [Upstream] drivers/serial/mfd.c: Fix ARM compile error
++  * [Config]: updateconfigs after adding brcm80211
++  * staging: brcm80211: Fix Makefile syntax error
++  * rebased to v2.6.36-rc7
++
++  [ Upstream Kernel Changes ]
++
++  * (upstream) IPS driver: don't toggle CPU turbo on unsupported CPUs
++  * (upstream) IPS driver: verify BIOS provided limits
++  * intel_ips: Print MCP limit exceeded values.
++  * Staging: Add initial release of brcm80211 - Broadcom 802.11n wireless
++    LAN driver.
++  * staging: brcm80211: Fix some initialisation failure paths
++  * staging: brcm80211: Add contact info to TODO list.
++  * staging: brcm80211: use '%pM' format to print MAC address
++  * staging: brcm80211: Fix URLs for firmware files.
++  * staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo *bar"'
++  * staging: brcm80211: fix "ERROR: open brace '{' following function
++    dec..."
++  * staging: brcm80211: fix "ERROR: return is not a function, paren..."
++  * staging: brcm80211: fix "ERROR: do not use assignment in if condition"
++  * staging: brcm80211: fix "ERROR: trailing statements should be on next
++    line"
++  * staging: brcm80211: fix "ERROR: that open brace { ... prev line"
++  * staging: brcm80211: fix "ERROR: while should follow close brace '}'"
++  * staging: brcm80211: fix "ERROR: do not initialise globals to 0 or NULL"
++  * staging: brcm80211: fix "ERROR: do not initialise statics to 0 or NULL"
++  * staging: brcm80211: fix "ERROR: Macros w/ complex values ...
++    parenthesis"
++  * staging: brcm80211: fix "ERROR: Macros w/ mult. statements ... do -
++    while loop"
++  * staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'
++  * staging: brcm80211: fix "ERROR: need consistent spacing around '*'"
++  * staging: brcm80211: fix "ERROR: space prohibited after that ..."
++  * staging: brcm80211: fix "ERROR: space prohibited before ...close square
++    bracket"
++  * staging: brcm80211: fix "ERROR: space required after that close brace"
++  * staging: brcm80211: fix "ERROR: space required after that ..."
++  * staging: brcm80211: fix "ERROR: space required before that ..."
++  * staging: brcm80211: fix "ERROR: spaces prohibited around that ':' ..."
++  * staging: brcm80211: fix "ERROR: spaces required around that ..."
++  * staging: brcm80211: fix "ERROR: trailing whitespace."
++  * staging: brcm80211: fix remaining checkpatch errors.
++  * staging: brcm80211: use native ctype library
++  * staging: brcm80211: use string native library
++  * staging: brcm80211: add fullmac driver
++  * Staging: brcm80211: clean up makefile cflag lines
++  * Staging: brcm80211: remove driver specific -W options
++  * staging: brcm80211: Fix compile issue when BRCM80211_PCI is not set.
++  * staging: brcm80211: Make compiling of brcm80211.ko and brcmfmac.ko
++    mutually exclusive.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Oct 2010 16:00:27 +0100
++
++linux (2.6.35-22.33) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: Add support for Intellimouse Mode in ALPS touchpad on
++    Dell E2 series Laptops"
++    - LP: #641320
++
++  [ Brian Rogers ]
++
++  * SAUCE: ir-core: Fix null dereferences in the protocols sysfs interface
++    - LP: #624701
++
++  [ Christopher James Halse Rogers ]
++
++  * SAUCE: Nouveau: Add quirk framework to disable acceleration
++    - LP: #544088, #546393
++  * SAUCE: Nouveau: Disable acceleration on MacBook Pros
++    - LP: #546393
++
++  [ John Johansen ]
++
++  * Revert "SAUCE: AppArmor: allow newer tools to load policy on older
++    kernels"
++  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
++    - LP: #639758
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: Adding vdd_sdi regulator supply to OMAP3EVM
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: HDA: Enable internal speaker on Dell M101z
++    - LP: #640254
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 17 Sep 2010 13:21:28 -0700
++
++linux (2.6.35-22.32) maverick; urgency=low
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: libata: Add ALPM power state accounting to the AHCI driver
++
++  [ David Henningsson ]
++
++  * SAUCE: ALSA: HDA: Enable internal mic on Dell E6410 and Dell E6510
++    - LP: #605047, #628961
++
++  [ John Johansen ]
++
++  * [Upstream] AppArmor: Fix splitting an fqname into separate namespace
++    and profile names
++    - LP: #615947
++  * [Upstream] AppArmor: Fix locking from removal of profile namespace
++    - LP: #615947
++  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
++    - LP: #639758
++  * SAUCE: Improve Amazon EBS performance for EC2
++    - LP: #634316
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: i915 KMS -- blacklist i855"
++  * Revert "SAUCE: i915 KMS -- blacklist i845g"
++  * Revert "SAUCE: i915 KMS -- blacklist i830"
++  * Revert "SAUCE: i915 KMS -- support disabling KMS for known broken
++    devices"
++  * execute module-inclusion within a subshell
++    - LP: #621175
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) bounce: call flush_dcache_page() after bounce_copy_vec()
++    - LP: #633227
++  * (pre-stable) drm/i915: don't enable self-refresh on Ironlake
++    - LP: #629711
++  * (pre-stable) mm: Move vma_stack_continue into mm.h
++  * x86, hwmon: Fix unsafe smp_processor_id() in thermal_throttle_add_dev
++    - LP: #601073
++  * PM / Runtime: Make runtime_status attribute not debug-only (v. 2)
++  * PM / Runtime: Add runtime PM statistics (v3)
++  * compat: Make compat_alloc_user_space() incorporate the access_ok()
++    - CVE-2010-3081
++  * x86-64, compat: Test %rax for the syscall number, not %eax
++    - CVE-2010-3301
++  * x86-64, compat: Retruncate rax after ia32 syscall entry tracing
++    - CVE-2010-3301
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Sep 2010 08:46:49 -0700
++
++linux (2.6.35-21.31) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * bodge linux-libc-dev package version due to ti-omap4 error
++  * linux-libc-dev -- ensure we can only build this on debian.master
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 13 Sep 2010 09:54:31 -0700
++
++linux (2.6.35-21.30) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
++    - LP: #614008
++
++  [ Daniel Lezcano ]
++
++  * SAUCE: fix compilation warning when CONFIG_SECURITY is not set
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: Input: wacom - add fuzz parameters to features
++  * SAUCE: Input: wacom - collect device quirks into single function
++  * SAUCE: Input: wacom - add support for the Bamboo Touch trackpad
++  * SAUCE: Input: wacom - add a quirk for low resolution Bamboo devices
++  * SAUCE: hid: ntrig: Remove unused device ids
++  * SAUCE: hid: ntrig: remove sysfs nodes
++  * SAUCE: hid: ntrig: Correct logic for quirks
++  * SAUCE: hid: ntrig: zero-initialize ntrig struct
++  * SAUCE: hid: ntrig: Setup input filtering manually
++  * SAUCE: hid: ntrig: New ghost-filtering event logic
++
++  [ Leann Ogasawara ]
++
++  * SAUCE: ndiswrapper: Initialize buffer index and check its value
++    - LP: #613796
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Add support for Intellimouse Mode in ALPS touchpad on Dell E2
++    series Laptops
++    - LP: #632884
++
++  [ Ping Cheng ]
++
++  * SAUCE: Input: wacom - parse the Bamboo device family
++
++  [ Rafi Rubin ]
++
++  * SAUCE: hid: ntrig: identify firmware version (wiggled)
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NL80211_TESTMODE=n
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "input: mt: Add support for the Bamboo Touch trackpad"
++  * e1000e: initial support for 82579 LOMs
++  * e1000e: correct MAC-PHY interconnect register offset for 82579
++  * (pre-stable) ALSA: hda - Add a new hp-laptop model for Conexant 5066,
++    tested on HP G60
++    - LP: #587388
++  * DSS2: Don't power off a panel twice
++    - LP: #588243
++  * mmc: build fix: mmc_pm_notify is only available with CONFIG_PM=y
++  * Input: i8042 - reset keyboard controller wehen resuming from S2R
++    - LP: #86820
++  * ALSA: hda - Fix beep frequency on IDT 92HD73xx and 92HD71Bxx codecs
++    - LP: #414795
++  * agp/intel: Support the extended physical addressing bits on
++    Sandybridge.
++    - LP: #632488
++  * drm/i915,intel_agp: Add support for Sandybridge D0
++    - LP: #632488
++  * (pre-stable) intel_agp,i915: Add more sandybridge graphics device ids
++    - LP: #632488
++  * mmc: omap: fix for bus width which improves SD card's peformance.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 07 Sep 2010 09:58:52 -0700
++
++linux (2.6.35-20.29) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: i915 KMS -- support disabling KMS for known broken devices
++    - LP: #563277
++  * SAUCE: i915 KMS -- blacklist i830
++    - LP: #542208, #563277
++  * SAUCE: i915 KMS -- blacklist i845g
++    - LP: #541492, #563277
++  * SAUCE: i915 KMS -- blacklist i855
++    - LP: #511001, #541511, #563277
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_SENSORS_PKGTEMP=m
++    - LP: #601073
++  * ARM: Temporarily disable module check for armel
++  * rebase to v2.6.35.4
++  * [Config] update configs following rebase to v2.6.35.4
++
++  [ Ricardo Salveti de Araujo ]
++
++  * [Config] Change CONFIG_LEDS_TRIGGER_HEARTBEAT from module to built-in
++    in Omap
++
++  [ Tim Gardner ]
++
++  * [Config] Added be2net, be2scsi to udebs
++    - LP: #628776
++
++  [ Upstream Kernel Changes ]
++
++  * x86, cpu: Package Level Thermal Control, Power Limit Notification
++    definitions
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: pkgtemp hwmon driver
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: thermal throttling handler
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: power limit
++    - LP: #601073
++  * x86, hwmon: Package Level Thermal/Power: pkgtemp documentation
++    - LP: #601073
++  * hid: 3m: Adjust to sequential MT HID protocol
++  * hid: 3m: Convert to MT slots
++  * hid: 3m: Correct touchscreen emulation
++  * hid: 3m: Adjust major / minor axes to scale
++  * input: bcm5974: Adjust major / minor to scale
++  * HID: magicmouse: don't allow hidinput to initialize the device
++  * HID: magicmouse: simplify multitouch feature request
++  * HID: magicmouse: simplify touch data bit manipulation
++  * HID: magicmouse: simplify touch down logic
++  * HID: magicmouse: remove timestamp logic
++  * HID: magicmouse: enable Magic Trackpad support
++  * HID: magicmouse: Adjust major / minor axes to scale
++  * mmc: fix all hangs related to mmc/sd card insert/removal during
++    suspend/resume
++    - LP: #477106
++  * drm/i915: fix VGA plane disable for Ironlake+
++    - LP: #602281
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 30 Aug 2010 08:38:01 -0700
++
++linux (2.6.35-19.28) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No changes from 2.6.35-19.27.  Some armel udebs were accidentally deleted
++    from the archive and a no-change rebuild was attempted.  However, the ABI
++    did not get bumped and resulted in build failures for 2.6.35-19.27.  Fix
++    up the ABI and re-upload.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sat, 28 Aug 2010 16:42:27 -0700
++
++linux (2.6.35-19.27) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * No changes from 2.6.35-19.26.  Some armel udebs were accidentally deleted
++    from the archive.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 27 Aug 2010 08:58:35 -0700
++
++linux (2.6.35-19.26) maverick; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * ARM: OMAP: Beagle: revision detection
++  * ARM: OMAP: Beagle: only Cx boards use pin 23 for write protect
++  * ARM: OMAP: Beagle: no gpio_wp pin connection on xM
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 26 Aug 2010 09:15:09 -0700
++
++linux (2.6.35-19.25) maverick; urgency=low
++
++  [ Jarod Wilson ]
++
++  * SAUCE: Bring in staging/lirc from 2.6.36
++    - LP: #609234
++  * SAUCE: Update ir-core to linuxtv/other which should be merged for
++    2.6.36.
++    - LP: #609234
++  * SAUCE: Fix memleaks in imon and mceusb drivers
++    - LP: #609234
++  * SAUCE: Bring in streamzap support from linuxtv/other
++    - LP: #609234
++
++  [ Mario Limonciello ]
++
++  * Remove ubuntu/lirc in favor of staging/lirc from 2.6.36
++    - LP: #609234
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: ARM: adding i2c eeprom driver to read EDID
++    - LP: #608279
++
++  [ Upstream Kernel Changes ]
++
++  * intel_idle: disable module support
++    - LP: #615265
++  * (pre-stable) ALSA: hda - Ensure codec patch files are checked for the
++    correct codec ID
++  * (pre-stable) ALSA: hda - Rename iMic to Int Mic on Lenovo NB0763
++    - LP: #605101
++  * (pre-stable) ALSA: HDA: Use model=auto for LG R510
++    - LP: #495134
++  * (pre-stable) ALSA: HDA: Add Sony VAIO quirk for ALC269
++    - LP: #519066
++  * (pre-stable) ALSA: HDA: Fix front mic on Dell Precision M6500
++    - LP: #519066
++  * input: mt: Initialize slots to unused (rev2)
++  * input: mt: Add support for the Bamboo Touch trackpad
++  * hid: Add a hid quirk for input sync override
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Aug 2010 12:42:52 -0700
++
++linux (2.6.35-18.24) maverick; urgency=low
++
++  [ Colin Watson ]
++
++  * Pass DEB_MAINT_PARAMS to hook scripts
++
++  [ Leann Ogasawara ]
++
++  * [Config] Add CONFIG_INPUT_UINPUT=y to config enforcer
++    - LP: #584812
++  * rebase to v2.6.35.3
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) dell-wmi: Add support for eject key on Dell Studio 1555
++    - LP: #609234
++  * can: add limit for nframes and clean up signed/unsigned variables
++    - CVE-2010-2959
++  * drm: Initialize ioctl struct when no user data is present
++    - CVE-2010-2803
++  * ARM: initial stack protector (-fstack-protector) support
++  * ARM: stack protector: change the canary value per task
++  * [ARM] implement arch_randomize_brk()
++  * [ARM] add address randomization to mmap()
++  * ARM: fix ASLR of PIE executables
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 22 Aug 2010 19:22:04 -0700
++
++linux (2.6.35-17.23) maverick; urgency=low
++
++  [ Jeremy Kerr ]
++
++  * [Config] build-in uinput module
++    - LP: #584812
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS"
++  * Revert "[Config] [FTBS] ia64: Temporarily disable gpiolib"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_MTD_NAND_DENALI"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_MFD_JANZ_CMODIO"
++  * Revert "[Config] [FTBS] sparc: Temporarily disable
++    CONFIG_INFINIBAND_QIB"
++  * [Config] Enable INTEL_IPS
++    - LP: #601057
++  * Remove ia64 support
++  * [Config] Update portsconfigs after removing ia64 support
++  * Remove sparc support
++  * [Config] Update portsconfigs after removing sparc support
++
++  [ Linus Torvalds ]
++
++  * (pre-stable) mm: fix page table unmap for stack guard page properly
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: (no-up) ARM: Resetting power_mode to its original value.
++    - LP: #591941
++
++  [ Upstream Kernel Changes ]
++
++  * timer: add on-stack deferrable timer interfaces
++    - LP: #601057
++  * x86 platform driver: intelligent power sharing driver
++    - LP: #601057
++  * IPS driver: add GPU busy and turbo checking
++    - LP: #601057
++  * X86: intel_ips, check for kzalloc properly
++    - LP: #601057
++  * ips driver: make it less chatty
++    - LP: #601057
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 17 Aug 2010 09:38:08 -0700
++
++linux (2.6.35-16.22) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian -- more agressivly clean up after depmod on purge
++    - LP: #618591
++
++  [ Henrik Rydberg ]
++
++  * SAUCE: hid: 3m: Simplify touchsreen emulation logic
++
++  [ Leann Ogasawara ]
++
++  * ubuntu: iscsitarget -- version 1.4.20.2
++  * ubuntu: rtl8192se -- update to version 0017.0507.2010
++  * rebase to v2.6.35.2
++  * [Config] update configs following rebase to v2.6.35.2
++  * [Config] update ports configs following rebase to v2.6.35.2
++
++  [ Luke Yelavich ]
++
++  * [Config] Enable new firewire stack on powerpc
++
++  [ Mathieu J. Poirier ]
++
++  * SAUCE: (drop after 2.6.35) ARM: Using gpmc function to init nand flash.
++    - LP: #608266
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 12 Aug 2010 09:58:01 -0700
++
++linux (2.6.35-15.21) maverick; urgency=low
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_SND_USB_UA101=m for all architectures
++
++  [ Upstream Kernel Changes ]
++
++  * Input: introduce MT event slots
++  * Input: document the MT event slot protocol
++  * (pre-stable) sched: Revert nohz_ratelimit() for now
++  * (pre-stable) drm/radeon/kms: add missing copy from user
++    - LP: #606081
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35.1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Aug 2010 09:24:04 -0700
++
++linux (2.6.35-14.20) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update Vcs-Git to point to maverick repo
++  * debian -- include the debian packaging in the -source package
++    - LP: #608674
++  * select debian source format 1.0
++  * add support for building selected stages of kernel
++    - LP: #603087
++  * cleanup conditional dependancy handling
++    - LP: #603087
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Handle missing NID 0x1b on ALC259 codec
++    - LP: #582199, #586418, #588031
++  * ALSA: hda - Handle pin NID 0x1a on ALC259/269
++    - LP: #582199, #586418, #588031
++  * sched: Revert nohz_ratelimit() for now
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 03 Aug 2010 08:46:47 -0700
++
++linux (2.6.35-14.19) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 01 Aug 2010 10:35:56 -0700
++
++linux (2.6.35-13.18) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: (no-up) Modularize vesafb -- fix initialisation
++  * SAUCE: add tracing for user initiated readahead requests
++  * SAUCE: vt -- maintain bootloader screen mode and content until vt
++    switch
++  * SAUCE: vt -- allow grub to request automatic vt_handoff
++  * SAUCE: fbcon -- fix race between open and removal of framebuffers
++  * SAUCE: drm -- stop early access to drm devices
++
++  [ Bryan Wu ]
++
++  * CONFIG: compile in OTG driver and Transceiver driver
++    - LP: #566645
++  * remove OTG modules from modules list file
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-27
++    - LP: #581525, #599450
++  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-29
++  * SAUCE: AppArmor 2.4 compatibility patch
++  * SAUCE: AppArmor: Allow dfa backward compatibility with broken userspace
++  * SAUCE: fix pv-ops for legacy Xen
++  * SAUCE: blkfront: default to sd devices
++  * [Config] Build in drivers required for Xen pv-ops
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Upstream] i915: Use the correct mask to detect i830 aperture
++    size."
++
++  [ Lee Jones ]
++
++  * SAUCE: ARM: OMAP: Add macros for comparing silicon revision
++    - LP: #608095
++  * SAUCE: OMAP: DSS2: check for both cpu type and revision, rather than
++    just revision
++    - LP: #608095
++  * SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX
++    - LP: #608095
++  * SAUCE: ARM: OMAP: Beagle: support twl gpio differences on xM
++    - LP: #608095
++
++  [ Upstream Kernel Changes ]
++
++  * agp/intel: Use the correct mask to detect i830 aperture size.
++    - LP: #597075
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Jul 2010 15:46:59 -0700
++
++linux (2.6.35-12.17) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc6
++  * [Config] update configs following rebase to v2.6.35-rc6
++  * [Config] update ports configs following rebase to v2.6.35-rc6
++  * SAUCE: [FTBS] armel: define KEY_F10 and KEYF11
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 16:16:38 +0200
++
++linux (2.6.35-11.16) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Bump ABI for new compiler update 
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 10:24:58 +0200
++
++linux (2.6.35-10.15) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: ensure vga16fb loads if no other driver claims the VGA
++    device"
++  * [Config] Enable CONFIG_M686=y
++    - LP: #592495
++
++  [ Upstream Kernel Changes ]
++
++  * tracing: Add alignment to syscall metadata declarations
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Jul 2010 18:18:49 +0200
++
++linux (2.6.35-9.14) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- add BOM and automated update script
++  * ubuntu: AUFS -- update to b37c575759dc4535ccc03241c584ad5fe69e3b25
++
++  [ John Johansen ]
++
++  * [Config] Enable DRBD as a module
++
++  [ Kees Cook ]
++
++  * SAUCE: Yama: verify inode is symlink to avoid bind mounts
++    - LP: #604407
++
++  [ Leann Ogasawara ]
++
++  * [Config] Disable CONFIG_DRM_VMWGFX (staging driver)
++    - LP: #606139
++  * [Config] ports: Disable CONFIG_DRM_VMWGFX (staging driver)
++    - LP: #606139
++  * [Config] Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
++  * [Config] ports: Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
++
++  [ Lee Jones ]
++
++  * Stop ARM boards crashing when CUPS is loaded
++    - LP: #601226
++
++  [ Upstream Kernel Changes ]
++
++  * perf probe: Support tracing an entry of array
++  * perf probe: Support static and global variables
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Jul 2010 14:38:17 -0700
++
++linux (2.6.35-8.13) maverick; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: Yama: check PTRACE using thread group leader
++  * SAUCE: Yama: search for PTRACE exceptions via thread group leader
++    - LP: #603716
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc5
++  * [Config] update configs following rebase to v2.6.35-rc5
++
++  [ Nicolas Pitre ]
++
++  * SAUCE: make ndiswrapper available on X86 only
++
++  [ Tim Gardner ]
++
++  * [Config] Added ums-cypress to udeb
++    - LP: #576066
++  * SAUCE: fix build error with CONFIG_BLK_DEV_INITRD=n
++  * [Config] CONFIG_NDISWRAPPER=m across all configs
++
++  [ Upstream Kernel Changes ]
++
++  * HID: magicmouse: report last touch up
++  * rebase to 2.6.35-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Jul 2010 18:57:59 -0700
++
++linux (2.6.35-7.12) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Upstream] i915: Use the correct mask to detect i830 aperture size.
++    - LP: #597075
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.35) drm/radeon/kms: add ioport register access
++    (squashed)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jul 2010 09:53:13 -0600
++
++linux (2.6.35-7.11) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_X86_MRST=n
++
++  [ Upstream Kernel Changes ]
++
++  * (drop after 2.6.35-rc5) writeback: remove writeback_inodes_wbc
++  * (drop after 2.6.35-rc5) writeback: split writeback_inodes_wb
++  * (drop after 2.6.35-rc5) writeback: simplify the write back thread queue
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jul 2010 18:39:08 -0600
++
++linux (2.6.35-7.10) maverick; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: security: create task_free security callback
++  * SAUCE: Yama: add PTRACE exception tracking and interface
++  * SAUCE: security: unconditionally chain to Yama LSM
++  * Revert "SAUCE: ptrace: restrict ptrace scope to children"
++  * Revert "SAUCE: fs: block hardlinks to non-accessible sources"
++  * Revert "SAUCE: fs: block cross-uid sticky symlinks"
++  * [Upstream] security: Yama LSM
++  * [Config] Enable CONFIG_SECURITY_YAMA=y
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs/updateportsconfigs after rebase to 2.6.35-rc4
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to 2.6.35-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 01 Jul 2010 08:55:57 -0700
++
++linux (2.6.35-6.9) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Upstream] direct_splice_actor() should not use pos in sd
++    - LP: #588861
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Jun 2010 12:35:49 -0700
++
++linux (2.6.35-6.8) maverick; urgency=low
++
++  [ Mathieu J. Poirier ]
++
++  * ARM: Adding regulator supply for vdds_sdi.
++    - LP: #597904
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 27 Jun 2010 16:34:43 -0700
++
++linux (2.6.35-6.7) maverick; urgency=low
++
++  [ Alberto Milone ]
++
++  * [Upstream] Add support for the ATIF ACPI method to the radeon driver
++
++  [ Chase Douglas ]
++
++  * [Upstream] HID: magicmouse: scroll on entire surface, not just middle
++    of mouse
++  * [Upstream] HID: magicmouse: disable and add module param for scroll
++    acceleration
++  * [Upstream] HID: magicmouse: properly account for scroll movement in
++    state
++  * [Upstream] HID: magicmouse: add param for scroll speed
++  * [Upstream] HID: magicmouse: enable horizontal scrolling
++
++  [ Henrik Rydberg ]
++
++  * [Upstream] Input: evdev - convert to dynamic event buffer
++  * [Upstream] Input: evdev - use driver hint to compute size of event
++    buffer
++  * [Upstream] Input: bcm5974 - set the average number of events per MT
++    event packet
++  * [Upstream] Input: hid-input - use a larger event buffer for MT devices
++  * [Upstream] Input: evdev - never leave the client buffer empty after
++    write
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: -- mainline 2010-06-23
++  * SAUCE: AppArmor 2.4 compatibility patch
++  * SAUCE: fs: block hardlinks to non-accessible sources AppArmor portion
++
++  [ Leann Ogasawara ]
++
++  * [Config] Enable CONFIG_INTR_REMAP=y
++    - LP: #597091
++  * [Config] Enable CONFIG_X86_X2APIC
++    - LP: #597091
++
++  [ Mathieu J. Poirier ]
++
++  * [Config] ARM: Turning off CONFIG_CPU_IDLE on omap
++    - LP: #594382
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Jun 2010 12:19:48 -0700
++
++linux (2.6.35-5.6) maverick; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] update omap flavour description
++
++  [ Andy Whitcroft ]
++
++  * update to ubuntu-debian:508b7aa34b578c0d1e51bfb571f2bfb824dc65ac
++    - LP: #570500, #576274
++  * SAUCE: add option to hand off all kernel parameters to init
++    - LP: #586386
++  * [Config] enable passing all kernel command line to init
++    - LP: #586386
++  * [Config] disable CONFIG_VMI
++    - LP: #537601
++  * [Config] enable CONFIG_IPV6_SIT_6RD
++    - LP: #591869
++  * [Config] enable CONFIG_VMWARE_BALOON as module
++    - LP: #592039
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: pm: Config option to disable handling of console during
++    suspend/resume"
++    - LP: #594885
++  * [Config] Remove CONFIG_PM_DISABLE_CONSOLE
++  * [Config] ports: enable passing all kernel command line to init
++    - LP: #586386
++  * [Config] Enable CONFIG_FB_VESA=y for x86
++  * [Config] Add CONFIG_FRAMEBUFFER_CONSOLE=y to config enforcer
++  * [Config] Add CONFIG_FB_VESA=y for x86 to config enforcer
++  * [Config] Enable CONFIG_TASK_DELAY_ACCT=y
++    - LP: #493156
++
++  [ Mathieu Poirier ]
++
++  * ARM: Adding MosChip MCS7830 to nic-usb
++    - LP: #584920
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Upstream] docbook: need xmldoclinks for all doc types"
++  * docbook: need xmldoclinks for all doc types
++  * perf probe: Add kernel source path option
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jun 2010 08:05:29 -0700
++
++linux (2.6.35-4.5) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Revert "[Upstream] (evdev) Use driver hint to compute the evdev buffer
++    size (rev2)"
++  * Revert "[Upstream] (evdev) Convert to dynamic event buffer (rev4)"
++  * Revert "[Upstream] (evdev) Use multi-reader buffer to save space
++    (rev4)"
++  * Revert "SAUCE: drivers: Remove some duplicate device entries in various
++    modules"
++  * [Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID
++  * [Upstream] Revert "USB: Adding support for HTC Smartphones to ipaq"
++  * [Upstream] p54usb: Comment out duplicate Medion MD40900 device id
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_NFS_FSCACHE=y
++    - LP: #440522
++  * [Config] CONFIG_FSCACHE_STATS=y, CONFIG_FSCACHE_HISTOGRAM=y
++    - LP: #440522
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 Jun 2010 08:43:07 -0700
++
++linux (2.6.35-3.4) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * debian -- ensure the version number is clean
++
++  [ Henrik Rydberg ]
++
++  * [Upstream] Introduce MT event slots (rev 5)
++  * [Upstream] Document the MT event slot protocol (rev5)
++  * [Upstream] (evdev) Use multi-reader buffer to save space (rev4)
++  * [Upstream] (evdev) Convert to dynamic event buffer (rev4)
++  * [Upstream] (evdev) Use driver hint to compute the evdev buffer size
++    (rev2)
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: Add MODULE_ALIAS for Dell WMI module"
++  * Revert "SAUCE: hostap: send events on data interface as well as master
++    interface"
++  * Revert "Fix webcam having USB ID 0ac8:303b"
++  * Revert "SAUCE: toshiba_acpi -- pull in current -dev version of driver"
++  * rebase to v2.6.35-rc3
++
++  [ Maxim Levitsky ]
++
++  * [Config] Enable new Smartmedia/xD translation layer
++    - LP: #202490
++
++  [ Upstream Kernel Changes ]
++
++  * net: fix deliver_no_wcard regression on loopback device
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 10 Jun 2010 16:15:22 -0700
++
++linux (2.6.35-2.3) maverick; urgency=low
++
++  [ Bryan Wu ]
++
++  * CONFIG: enforce -- make sure we disable CONFIG_LOCALVERSION_AUTO
++
++  [ Leann Ogasawara ]
++
++  * [Config] armel: Enable CONFIG_BNX2=m
++  * [Config] ports: Enable CONFIG_BNX2X=m
++  * SAUCE: armel: define get_dma_ops to fix FTBS
++
++  [ Tim Gardner ]
++
++  * [Upstream] net: Print num_rx_queues imbalance warning only when there
++    are allocated queues
++    - LP: #591416
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 09 Jun 2010 08:27:41 -0700
++
++linux (2.6.35-2.2) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] d-i: make armel configuration versatile flavour specific
++    - LP: #588805
++  * [Config] d-i: enable .udebs for omap flavour
++    - LP: #588805
++
++  [ Kees Cook ]
++
++  * ptrace: limit scope to attach only (allow read)
++    - LP: #589656
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc2
++  * [Config] update configs following rebase to v2.6.35-rc2
++  * [Config] update port configs following rebase to v2.6.35-rc2
++
++  [ Lee Jones ]
++
++  * Enable perf to be more helpful when perf_<version> does not exist.
++    - LP: #570500
++  * 'fdr editconfig' modification. Easily skip over unwanted menuconfigs.
++
++  [ Tim Gardner ]
++
++  * [Config] Update bnx2 udeb firmware files
++    - LP: #589304
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 07 Jun 2010 09:45:04 -0700
++
++linux (2.6.35-1.1) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601
++    - LP: #587888
++  * ubuntu: AUFS -- track changes to the arguements to fop fsync()
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.35-rc1
++  * [Config] update configs following rebase to v2.6.35-rc1
++  * [Config] update port configs following rebase to v2.6.35-rc1
++  * SAUCE: lirc: rename usb_buffer_alloc() and usb_buffer_free()
++  * SAUCE: ndiswrapper: rename usb_buffer_alloc() and usb_buffer_free()
++  * SAUCE: ndiswrapper: convert multicast list to list_head
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_GPIO_JANZ_TTL
++  * [Config] [FTBS] ia64: Temporarily disable gpiolib
++  * [Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_INFINIBAND_QIB
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MFD_JANZ_CMODIO
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_MFD_JANZ_CMODIO
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_DT3155
++  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MTD_NAND_DENALI
++  * [Config] [FTBS] armel: Temporarily disable bnx2
++  * [Config] [FTBS] armel: Temporarily disable CONFIG_SERIAL_UARTLITE
++  * SAUCE: [FTBS] armel: Don't include asm/agp.h for ttm
++  * SAUCE: [FTBS] armel: include linux/dma-mapping.h
++  * SAUCE: [FTBS] armel: replace omap_set_gpio_debounce with
++    gpio_set_debounce
++
++  [ Upstream Kernel Changes ]
++
++  * of/usb: fix build error due to of_node pointer move
++  * n2_crypto: Fix build after of_device/of_platform_driver changes.
++  * powerpc/fsl-booke: fix the case where we are not in the first page
++  * powerpc/fsl-booke: Move the entry setup code into a seperate file
++  * powerpc/kexec: Add support for FSL-BookE
++  * greth: Fix build after OF device conversions.
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.35-rc1
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 04 Jun 2010 23:01:52 -0700
++
++linux (2.6.35-1.0) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Null entry.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 15:17:41 -0700
++
++linux (2.6.34-5.14) maverick; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Added module inclusion support
++  * [Config] Added virtual flavour module inclusion list and d-i package
++    definitions
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 12:58:14 -0700
++
++linux (2.6.34-5.13) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "ubuntu: AUFS -- aufs2 20091209"
++  * Revert "ubuntu: AUFS -- export various core functions
++    (aufs2-standalone.patch)"
++  * Revert "ubuntu: AUFS -- export various core functions
++    (aufs2-base.patch)"
++  * ubuntu: AUFS -- aufs2 base patch for linux-2.6.34
++    - LP: #587888
++  * ubuntu: AUFS -- aufs2 standalone patch for linux-2.6.34
++    - LP: #587888
++  * ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601
++    - LP: #587888
++  * [Config] AUFS -- enable aufs options
++    - LP: #587888
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 01 Jun 2010 08:56:43 -0700
++
++linux (2.6.34-5.12) maverick; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * enforce -- ensure SYSFS compatibility is disabled
++
++  [ Chase Douglas ]
++
++  * build with libdw-dev for perf probe symbol support
++  * maverick ftrace configuration changes
++
++  [ Kees Cook ]
++
++  * Revert "SAUCE: x86: brk away from exec rand area"
++  * Revert "SAUCE: [um] Don't use nx_enabled under UML"
++  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
++  * SAUCE: x86: implement cs-limit nx-emulation for ia32
++    - LP: #369978
++  * SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
++  * SAUCE: x86: brk away from exec rand area
++    - LP: #452175
++  * SAUCE: ptrace: restrict ptrace scope to children
++
++  [ Leann Ogasawara ]
++
++  * Add new omap flavour to getabis
++  * [Config] Enable CONFIG_FRAMEBUFFER_CONSOLE=y for all archs
++    - LP: #585490
++  * build/modules: Temorarily add ignore.modules
++  * ubuntu: iscsitarget -- version 1.4.20.1
++
++  [ Loïc Minier ]
++
++  * SAUCE: [um] Don't use nx_enabled under UML
++    - LP: #524849
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 May 2010 08:27:17 -0700
++
++linux (2.6.34-4.11) maverick; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: omap: remove calls to usb_nop_xceiv_register from board files
++  * [Config] Add support for OMAP-mainline flavour
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: powerpc: fix compile error when ptrace.h is included from
++    userspace
++    - LP: #583733
++
++  [ Chase Douglas ]
++
++  * Revert "SAUCE: Don't register vga16fb framebuffer if other framebuffers
++    are present"
++  * Revert "SAUCE: Disable function tracing after hitting __schedule_bug"
++  * Revert "SAUCE: drm/i915: don't change DRM configuration when releasing
++    load detect pipe"
++
++  [ Kees Cook ]
++
++  * SAUCE: fs: block cross-uid sticky symlinks
++  * SAUCE: fs: block hardlinks to non-accessible sources
++
++  [ Koen Kooi ]
++
++  * SAUCE: board-omap3-beagle: add DSS2 support
++
++  [ Leann Ogasawara ]
++
++  * Revert "staging/go7007 -- disable"
++  * Revert "[Config] staging/winbond -- disable"
++  * Revert "Disable 4MB page tables for Atom, work around errata AAE44"
++  * Revert "SAUCE: sync before umount to reduce time taken by ext4 umount"
++  * Revert "SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit
++    controller"
++  * Revert "SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT"
++  * Revert "SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros"
++  * Revert "SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps"
++  * Revert "SAUCE: r8169: disable TSO by default for RTL8111/8168B
++    chipsets."
++  * Revert "[Upstream] b43: Declare all possible firmware files."
++  * Revert "add Breaks: against hardy lvm2"
++  * Revert "SAUCE: Guest OS does not recognize a lun with non zero target
++    id on Vmware ESX Server"
++  * Revert "SAUCE: Catch nonsense keycodes and silently ignore"
++  * [Config] Enable CONFIG_ECRYPT_FS=y for ports
++  * [Config] Enable CONFIG_USB=y for armel and sparc
++  * [Config] Enable CONFIG_SCSI=y for ia64 and sparc
++  * [Config] Enable CONFIG_RFKILL=y for ports
++  * [Config] Enable CONFIG_ATH9K_DEBUGFS=y
++  * [Config] Enable CONFIG_IWMC3200TOP_DEBUGFS=y
++  * [Config] Enable CONFIG_RCU_FAST_NO_HZ=y
++  * [Config] Enable CONFIG_IWLWIFI_DEVICE_TRACING=y
++  * [Config] Enable CONFIG_LIBERTAS_MESH=y
++  * [Config] Enable CONFIG_MMC_RICOH_MMC=y
++  * [Config] CONFIG_RT2800USB_UNKNOWN=y
++  * [Config] Enable CONFIG_VGA_SWITCHEROO=y
++  * [Config] Enable CONFIG_CEPH_FS=m
++  * [Config] Enable CONFIG_CRYPTO_PCRYPT=m
++  * [Config] Enable CONFIG_EEEPC_WMI=m
++  * [Config] Enable CONFIG_RT2800PCI=m
++  * [Config] Enable CONFIG_SCSI_HPSA=m
++  * [Config] Enable CONFIG_VHOST_NET=m
++  * [Config] Disable CONFIG_SND_HDA_INPUT_BEEP_MODE by default
++    - LP: #582350
++  * [Config] Disable CONFIG_SOUND_OSS* and CONFIG_SND_*OSS
++    - LP: #579300
++  * [Config] Enable CONFIG_PCIEASPM=y
++    - LP: #333990
++  * [Config] updateconfigs for OMAP flavour
++
++  [ Loïc Minier ]
++
++  * Enable perf tools on armel
++
++  [ Tim Gardner ]
++
++  * SAUCE: Updated ndiswrapper to 1.56
++    - LP: #582555
++  * [Config] Added virtual flavour
++  * [Config] Remove support for sub-flavours
++  * [Config] Removed amd64 preempt flavour
++  * [Config] updateconfigs, updateportsconfigs after flavour munging
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 25 May 2010 09:34:55 -0700
++
++linux (2.6.34-3.10) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 18 May 2010 17:35:35 -0700
++
++linux (2.6.34-2.9) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] [FTBS] Disable comedi for armel
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 23:20:55 +0200
++
++linux (2.6.34-2.8) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Drop lpia
++  * [Config] [FTBS] disable KVM
++  * [Config] [FTBS] disable ipr for armel
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 16:07:52 +0200
++
++linux (2.6.34-2.7) maverick; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Config] disable CONFIG_SCSI_IPR on powerpc
++  * [Config] Remove 386 flavour per UDS discussion
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 May 2010 18:26:43 +0200
++
++linux (2.6.34-1.6) maverick; urgency=low
++
++  [ Chase Douglas ]
++
++  * enforce CONFIG_TMPFS_POSIX_ACL=y
++    - LP: #575940
++  * don't force module dependency checking
++    - LP: #577029
++
++  [ Kees Cook ]
++
++  * SAUCE: mmap_min_addr check CAP_SYS_RAWIO only for write
++    - LP: #568844
++
++  [ Leann Ogasawara ]
++
++  * Revert "SAUCE: ata: blacklist FUJITSU MHW2160BH PL"
++  * rebase to v2.6.34-rc7
++  * [Config] update configs following rebase to v2.6.34-rc7
++  * [Config] update port configs following rebase to v2.6.34-rc7
++  * Add btrfs to the udebs
++
++  [ Tim Gardner ]
++
++  * [Config] Add atl1c to nic-modules udeb
++    - LP: #557130
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc7
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 11 May 2010 11:29:08 +0200
++
++linux (2.6.34-1.5) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc6
++  * [Config] update configs following rebase to v2.6.34-rc6
++  * [Config] update port configs following rebase to v2.6.34-rc6
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc6
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Apr 2010 15:54:05 +0100
++
++linux (2.6.34-1.4) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc5
++  * [Config] update ports configs following rebase to v2.6.34-rc5
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc5
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 22 Apr 2010 15:36:12 -0700
++
++linux (2.6.34-1.3) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc4
++  * [Config] update configs following rebase to v2.6.34-rc4
++  * [Config] update port configs following rebase to v2.6.34-rc4
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc4
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc4
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Apr 2010 18:33:44 -0700
++
++linux (2.6.34-1.2) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Temorarily disable building linux-doc
++  * rebase to v2.6.34-rc3
++  * [Config] update configs following rebase to v2.6.34-rc3
++  * [Config] update port configs following rebase to v2.6.34-rc3
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc3
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 30 Mar 2010 16:55:44 -0700
++
++linux (2.6.34-1.1) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * rebase to v2.6.34-rc2
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc2
++  * [Config] update port configs following rebase to v2.6.34-rc2
++  * [Config] update configs following rebase to v2.6.34-rc2
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.34-rc2
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 24 Mar 2010 23:00:39 -0700
++
++linux (2.6.33-1.1) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * ubuntu: dm-raid4-5 -- update to compile with 2.6.33
++  * ubuntu: lirc -- drop explicit include of linux/autoconf.h
++  * ubuntu: lirc -- pass kfifo to kfifo_alloc and move spinlock
++  * ubuntu: lirc -- rename kfifo_put and kfifo_get
++  * ubuntu: iscsitarget -- rename daddr inet_sock field
++  * rebased to v2.6.33
++  * [Config] update configs following rebase to v2.6.33
++  * [Config] update ports configs following rebase to v2.6.33
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.33
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 23 Mar 2010 03:55:46 -0700
++
++linux (2.6.33-0.0) UNRELEASED; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * Null entry.
++
++ -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 17 Mar 2010 07:48:56 -0700
++
++linux (2.6.32-16.25) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * linux-tools -- move to Suggests: with explicit seeding
++    - LP: #534635
++
++  [ Tim Gardner ]
++
++  * [Config] CONFIG_HID=m
++
++  [ Upstream Kernel Changes ]
++
++  * (pre-stable) sched: Fix SMT scheduler regression in
++    find_busiest_queue()
++  * KVM: introduce kvm_vcpu_on_spin
++  * KVM: VMX: Add support for Pause-Loop Exiting
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 09 Mar 2010 14:13:51 +0000
++
++linux (2.6.32-16.24) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * armel -- perf userspace does not support arm
++  * ia64 -- libelf-dev/binutils-dev to not provide necessary libraries
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Mar 2010 11:42:12 +0000
++
++linux (2.6.32-16.23) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: PM report driver and device suspend/resume times -- move config
++  * update to standards version 3.8.4.0
++  * printenv -- expose all of the package selectors
++  * source package -- cleanup source content control
++  * doc package -- ensure we do build package content on buildd
++  * lintian -- correct the address in the debian/copyright
++  * lintian -- update debhelper package version dependancy
++  * lintian -- fix ghostscript dependancy
++  * lintian -- add required misc:Depends
++  * lintian -- move our debhelper compat level to debian/compat
++  * perf -- build the kernel carried tools
++  * perf -- add linux-tools carrying the version switches and manuals
++  * SAUCE: fix up Kconfig for staging drivers
++  * [Config] enable NOUVEAU etc following drm backport
++  * update DRM to mainline v2.6.33
++  * [Config] Remove AppArmor config options that no longer exist (ports)
++  * [Config] updateportsconfigs following drm update
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- update to mainline 2010-03-04
++  * SAUCE: AppArmor: Reintroduce AppArmor 2.4 compatibility
++  * SAUCE: AppArmor: replace strim with strstrip for 2.6.32 kernels
++  * [Config] Remove AppArmor config options that no longer exist
++
++  [ Manoj Iyer ]
++
++  * ubuntu: rtl8192se -- version 2010-0115,0014
++    - LP: #530275
++  * [Config] added CONFIG_RTL8192SE module.
++    - LP: #530275
++
++  [ Tim Gardner ]
++
++  * [Config] Added vmw_pvscsi to d-i/scsi-modules
++    - LP: #531017
++  * [Upstream] netfilter: xt_recent: Add an entry reaper
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "KVM: x86 emulator: Check CPL level during privilege instruction
++    emulation"
++  * Revert "KVM: x86 emulator: Fix popf emulation"
++  * Revert "KVM: x86 emulator: Check IOPL level during io instruction
++    emulation"
++  * Revert "KVM: x86 emulator: Add Virtual-8086 mode of emulation"
++  * Revert "KVM: fix memory access during x86 emulation."
++  * Add vlan (8021.Q) module package for d-i.
++  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
++    Inspiron 700m
++    - LP: #515246
++  * [Upstream] docbook: need xmldoclinks for all doc types
++  * x86: set_personality_ia32() misses force_personality32
++  * lib: Introduce generic list_sort function
++  * drm/nv50: Implement ctxprog/state generation.
++  * drm/nv50: Remove redundant/incorrect ctxvals initialisation.
++  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
++    Inspiron 700m
++    - LP: #515246
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Mar 2010 15:40:38 +0000
++
++linux (2.6.32-15.22) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT"
++  * Revert "SAUCE: PM report driver and device suspend/resume times."
++  * [Config] set CONFIG_SR_REPORT_TIME_LIMIT
++
++  [ Manoj Iyer ]
++
++  * SAUCE: PM report driver and device suspend/resume times.
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Mar 2010 01:35:37 +0000
++
++linux (2.6.32-15.21) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) drm/i915: Increase fb alignment to 64k"
++  * Revert "[Config] lenovo-sl-laptop -- enable"
++  * Revert "ubuntu: lenovo-sl-laptop -- git tip (b19a08f81f)"
++  * armel -- cramfs module will no longer be built
++  * d-i -- make all modules optional
++  * rename the debug packages to match archive standard
++    - LP: #527837
++  * lenovo-sl-laptop is no longer built
++
++  [ Colin Ian King ]
++
++  * Disable 4MB page tables for Atom, work around errata AAE44
++    - LP: #523112
++
++  [ Colin Watson ]
++
++  * ubuntu: dm-raid4-5: Depend on XOR_BLOCKS
++  * ubuntu: fsam7400: Depend on CHECK_SIGNATURE
++
++  [ Jesse Barnes ]
++
++  * SAUCE: drm/i915: don't change DRM configuration when releasing load
++    detect pipe
++    - LP: #488328
++
++  [ Loïc Minier ]
++
++  * [Config] armel Update versatile initrd configs
++    - LP: #524893
++  * SAUCE: [um] Don't use nx_enabled under UML
++    - LP: #524849
++
++  [ Manoj Iyer ]
++
++  * [Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT
++
++  [ Mario Limonciello ]
++
++  * SAUCE: v3 - Add Dell Business Class Netbook LED driver
++
++  [ Rafael J. Wysocki ]
++
++  * SAUCE: PM report driver and device suspend/resume times.
++
++  [ Surbhi Palande ]
++
++  * Revert "[Upstream] e1000e: enhance frame fragment detection"
++    - CVE-2009-4538
++  * Revert "[Upstream] e1000: enhance frame fragment detection"
++    - CVE-2009-4536
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CONFIG_LEDS_DELL_NETBOOKS=m
++  * SAUCE: (pre-stable) netfilter: xt_recent: fix buffer overflow
++  * SAUCE: (pre-stable) netfilter: xt_recent: fix false match
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "(pre-stable) eCryptfs: Add getattr function"
++  * Fix potential crash with sys_move_pages
++  * futex_lock_pi() key refcnt fix
++  * futex: Handle user space corruption gracefully
++  * futex: Handle futex value corruption gracefully
++  * Fix race in tty_fasync() properly
++  * hwmon: (w83781d) Request I/O ports individually for probing
++  * hwmon: (lm78) Request I/O ports individually for probing
++  * hwmon: (adt7462) Wrong ADT7462_VOLT_COUNT
++  * ALSA: ctxfi - fix PTP address initialization
++  * drm/i915: disable hotplug detect before Ironlake CRT detect
++  * drm/i915: enable self-refresh on 965
++  * drm/i915: Disable SR when more than one pipe is enabled
++  * drm/i915: Fix DDC on some systems by clearing BIOS GMBUS setup.
++  * drm/i915: Add HP nx9020/SamsungSX20S to ACPI LID quirk list
++  * drm/i915: Fix the incorrect DMI string for Samsung SX20S laptop
++  * drm/i915: Add MALATA PC-81005 to ACPI LID quirk list
++  * usb: r8a66597-hcd: Flush the D-cache for the pipe-in transfer buffers.
++  * i2c-tiny-usb: Fix on big-endian systems
++  * drm/i915: handle FBC and self-refresh better
++  * drm/i915: Increase fb alignment to 64k
++  * drm/i915: Update write_domains on active list after flush.
++  * regulator: Fix display of null constraints for regulators
++  * ALSA: hda-intel: Avoid divide by zero crash
++  * CPUFREQ: Fix use after free of struct powernow_k8_data
++  * freeze_bdev: don't deactivate successfully frozen MS_RDONLY sb
++  * cciss: Make cciss_seq_show handle holes in the h->drv[] array
++  * ioat: fix infinite timeout checking in ioat2_quiesce
++  * resource: add helpers for fetching rlimits
++  * fs/exec.c: restrict initial stack space expansion to rlimit
++  * cifs: fix length calculation for converted unicode readdir names
++  * NFS: Fix a reference leak in nfs_wb_cancel_page()
++  * NFS: Try to commit unstable writes in nfs_release_page()
++  * NFSv4: Don't allow posix locking against servers that don't support it
++  * NFSv4: Ensure that the NFSv4 locking can recover from stateid errors
++  * NFS: Fix an Oops when truncating a file
++  * NFS: Fix a umount race
++  * NFS: Fix a bug in nfs_fscache_release_page()
++  * NFS: Fix the mapping of the NFSERR_SERVERFAULT error
++  * md: fix 'degraded' calculation when starting a reshape.
++  * V4L/DVB: dvb-core: fix initialization of feeds list in demux filter
++  * Export the symbol of getboottime and mmonotonic_to_bootbased
++  * kvmclock: count total_sleep_time when updating guest clock
++  * KVM: PIT: control word is write-only
++  * tpm_infineon: fix suspend/resume handler for pnp_driver
++  * amd64_edac: Do not falsely trigger kerneloops
++  * netfilter: nf_conntrack: fix memory corruption with multiple namespaces
++  * netfilter: nf_conntrack: per netns nf_conntrack_cachep
++  * netfilter: nf_conntrack: restrict runtime expect hashsize modifications
++  * netfilter: xtables: compat out of scope fix
++  * netfilter: nf_conntrack: fix hash resizing with namespaces
++  * drm/i915: remove full registers dump debug
++  * drm/i915: add i915_lp_ring_sync helper
++  * drm/i915: Don't wait interruptible for possible plane buffer flush
++  * dasd: remove strings from s390dbf
++  * crypto: padlock-sha - Add import/export support
++  * wmi: Free the allocated acpi objects through wmi_get_event_data
++  * dell-wmi, hp-wmi, msi-wmi: check wmi_get_event_data() return value
++  * /dev/mem: introduce size_inside_page()
++  * devmem: check vmalloc address on kmem read/write
++  * devmem: fix kmem write bug on memory holes
++  * SCSI: mptfusion : mptscsih_abort return value should be SUCCESS instead
++    of value 0.
++  * sh: Couple kernel and user write page perm bits for CONFIG_X2TLB
++  * ALSA: hda - use WARN_ON_ONCE() for zero-division detection
++  * dst: call cond_resched() in dst_gc_task()
++  * ALSA: hda - Improved MacBook (Pro) 5,1 / 5,2 support
++  * befs: fix leak
++  * rtc-fm3130: add missing braces
++  * Call flush_dcache_page after PIO data transfers in libata-sff.c
++  * ahci: add Acer G725 to broken suspend list
++  * pktgen: Fix freezing problem
++  * x86/amd-iommu: Fix IOMMU-API initialization for iommu=pt
++  * x86/amd-iommu: Fix deassignment of a device from the pt_domain
++  * x86: Re-get cfg_new in case reuse/move irq_desc
++  * Staging: fix rtl8187se compilation errors with mac80211
++  * ALSA: usb-audio - Avoid Oops after disconnect
++  * serial: 8250: add serial transmitter fully empty test
++  * sysfs: sysfs_sd_setattr set iattrs unconditionally
++  * class: Free the class private data in class_release
++  * USB: usbfs: only copy the actual data received
++  * USB: usbfs: properly clean up the as structure on error paths
++  * rtl8187: Add new device ID
++  * ACPI: Add NULL pointer check in acpi_bus_start
++  * ACPI: fix High cpu temperature with 2.6.32
++  * drm/radeon/kms: use udelay for short delays
++  * NFS: Too many GETATTR and ACCESS calls after direct I/O
++  * eCryptfs: Add getattr function
++  * b43: Fix throughput regression
++  * ath9k: Fix sequence numbers for PAE frames
++  * mac80211: Fix probe request filtering in IBSS mode
++  * iwlwifi: Fix to set correct ht configuration
++  * dm stripe: avoid divide by zero with invalid stripe count
++  * dm log: userspace fix overhead_size calcuations
++  * Linux 2.6.32.9
++  * sfc: Fix SFE4002 initialisation
++  * sfc: Fix sign of efx_mcdi_poll_reboot() error in efx_mcdi_poll()
++  * sfc: SFE4002/SFN4112F: Widen temperature and voltage tolerances
++  * (pre-stable) HID: handle joysticks with large number of buttons
++    - LP: #492056
++  * (pre-stable) HID: extend mask for BUTTON usage page
++    - LP: #492056
++  * PM: Measure device suspend and resume times
++  * e1000: enhance frame fragment detection
++    - CVE-2009-4536
++  * e1000e: enhance frame fragment detection
++    - CVE-2009-4538
++  * KVM: fix memory access during x86 emulation.
++    - CVE-2010-0306
++  * KVM: x86 emulator: Add Virtual-8086 mode of emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Check IOPL level during io instruction emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Fix popf emulation
++    - CVE-2010-0306
++  * KVM: x86 emulator: Check CPL level during privilege instruction
++    emulation
++    - CVE-2010-0306
++  * Input: wacom - ensure the device is initialized properly upon resume
++  * Input: wacom - add defines for packet lengths of various devices
++  * Input: wacom - add support for new LCD tablets
++    - LP: #516777
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Mar 2010 22:56:28 +0000
++
++linux (2.6.32-14.20) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebuild following the GCC update to match compiler for out of tree modules
++  * Revert "[Config] drbd -- enable"
++  * Revert "ubuntu: drbd -- version 8.3.1"
++  * SAUCE: khubd -- switch USB product/manufacturer/serial handling to RCU
++    - LP: #510937
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 19 Feb 2010 18:47:18 +0000
++
++linux (2.6.32-14.19) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * ensure we build the source package contents when enabled
++    - LP: #522308
++  * [Config] enable CONFIG_X86_MCE_XEON75XX
++  * SAUCE: AppArmor -- add linux/kref.h for struct kref
++  * [Config] enable CONFIG_HID_ORTEK
++  * enable udeb generation for arm versatile flavour
++    - LP: #522515
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- update to mainline 2010-02-18
++    - LP: #439560, #496110, #507069
++
++  [ Johnathon Harris ]
++
++  * SAUCE: HID: add support for Ortek WKB-2000
++    - LP: #405390
++
++  [ Upstream Kernel Changes ]
++
++  * tpm_tis: TPM_STS_DATA_EXPECT workaround
++    - LP: #490487
++  * x86, mce: Xeon75xx specific interface to get corrected memory error
++    information
++  * x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
++  * x86, mce: Make xeon75xx memory driver dependent on PCI
++  * drm/edid: Unify detailed block parsing between base and extension
++    blocks
++    - LP: #500999
++  * (pre-stable) eCryptfs: Add getattr function
++    - LP: #390833
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Feb 2010 19:22:02 +0000
++
++linux (2.6.32-13.18) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "enforcer -- make the enforcement configuration common"
++  * Revert "(pre-stable) Input: ALPS - add interleaved protocol support
++    (Dell E6x00 series)"
++  * Revert "(pre-stable) driver-core: fix devtmpfs crash on s390"
++  * Revert "(pre-stable) Driver-Core: devtmpfs - set root directory mode to
++    0755"
++  * Revert "SAUCE: Adds support for COMPAL JHL90 webcam"
++  * Revert "SAUCE: fix kernel oops in VirtualBox during paravirt patching"
++  * Revert "SAUCE: make fc transport removal of target configurable"
++  * enforcer -- make the enforcement configuration common
++  * getabis -- add preempt flavour to the list
++  * [Config] enforce DEVTMPFS options
++  * [Config] armel -- cleanup to-be builtin modules
++  * [Config] cleanup ports configs
++  * [Config] enable CRYPTO_GHASH_CLMUL_NI_INTEL
++    - LP: #485536
++  * add printdebian target to find branch target
++  * distclean -- do not remove debian.env
++  * [Config] generic-pae switch to M586TSC
++    - LP: #519448
++  * git-ubuntu-log -- commonise duplicated log handling
++  * git-ubuntu-log -- tighten up Bug: NNNN matching
++  * git-ubuntu-log -- sort the bug numbers
++
++  [ Chris Wilson ]
++
++  * (pre-stable) drm/i915: Increase fb alignment to 64k
++    - LP: #404064
++
++  [ Eric Miao ]
++
++  * arm -- enable ubuntu/ directory
++
++  [ Huang Ying ]
++
++  * SAUCE: crypto: ghash - Add PCLMULQDQ accelerated implementation
++  * SAUCE: crypto: ghash-intel - Fix building failure on x86_32
++
++  [ Loïc Minier ]
++
++  * [Config] cleanup preempt configuration
++  * [Config] versatile: Fix video output
++    - LP: #517594
++  * [Config] armel DEFAULT_MMAP_MIN_ADDR=32768
++  * [Config] Large update to armel/versatile
++  * [Config] versatile: Add RTC support
++  * [Config] armel: Enable NEON
++  * [Config] versatile: Builtin MMC support
++  * [Config] versatile Builtin SCSI controller
++  * [Config] armel Disable dma_cache_sync callers
++  * [Config] armel Disable asm/time.h users
++  * [Config] armel Disable out of range udelay()
++  * [Config] armel Disable flush_cache_range() users
++  * [Config] armel -- Enable ubuntu/ drivers
++
++  [ Steve Conklin ]
++
++  * SAUCE: drm/i915: Add display hotplug event on Ironlake
++  * SAUCE: drm/i915: Add ACPI OpRegion support for Ironlake
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Upstream]: oprofile/x86: add Xeon 7500 series support"
++  * Revert "Revert "[Bluetooth] Eliminate checks for impossible conditions
++    in IRQ handler""
++  * clockevent: Don't remove broadcast device when cpu is dead
++  * clockevents: Add missing include to pacify sparse
++  * ACPI: don't cond_resched if irq is disabled
++  * be2net: Add support for next generation of BladeEngine device.
++  * be2net: Add the new PCI IDs to PCI_DEVICE_TABLE.
++  * mpt2sas: New device SAS2208 support is added
++  * ar9170: Add support for D-Link DWA 160 A2
++  * powerpc/fsl: Add PCI device ids for new QoirQ chips
++  * davinci: dm646x: Add support for 3.x silicon revision
++  * Input: ALPS - add interleaved protocol support (Dell E6x00 series)
++  * Driver-Core: devtmpfs - set root directory mode to 0755
++  * driver-core: fix devtmpfs crash on s390
++  * vfs: get_sb_single() - do not pass options twice
++  * ALSA: hda - Add PCI IDs for Nvidia G2xx-series
++  * V4L/DVB (13569): smsusb: add autodetection support for five additional
++    Hauppauge USB IDs
++  * USB: mos7840: add device IDs for B&B electronics devices
++  * USB: ftdi_sio: add USB device ID's for B&B Electronics line
++  * V4L/DVB (13168): Add support for Asus Europa Hybrid DVB-T card (SAA7134
++    SubVendor ID: 0x1043 Device ID: 0x4847)
++  * iTCO_wdt: Add support for Intel Ibex Peak
++  * atl1c:use common_task instead of reset_task and link_chg_task
++  * atl1e:disable NETIF_F_TSO6 for hardware limit
++  * V4L/DVB (13680a): DocBook/media: copy images after building HTML
++  * V4L/DVB (13680b): DocBook/media: create links for included sources
++  * netfilter: xtables: fix conntrack match v1 ipt-save output
++  * partitions: read whole sector with EFI GPT header
++  * partitions: use sector size for EFI GPT
++  * ALSA: ice1724 - Patch for suspend/resume for ESI Juli@
++  * sched: Fix isolcpus boot option
++  * sched: Fix missing sched tunable recalculation on cpu add/remove
++  * nohz: Prevent clocksource wrapping during idle
++  * nfsd: Fix sort_pacl in fs/nfsd/nf4acl.c to actually sort groups
++  * timers, init: Limit the number of per cpu calibration bootup messages
++  * PCI: Always set prefetchable base/limit upper32 registers
++  * iscsi class: modify handling of replacement timeout
++  * NFS: Revert default r/wsize behavior
++  * HID: fixup quirk for NCR devices
++  * scsi_devinfo: update Hitachi entries (v2)
++  * scsi_dh: create sysfs file, dh_state for all SCSI disk devices
++  * scsi_transport_fc: remove invalid BUG_ON
++  * lpfc: fix hang on SGI ia64 platform
++  * libfc: fix typo in retry check on received PRLI
++  * libfc: fix ddp in fc_fcp for 0 xid
++  * fcoe: remove redundant checking of netdev->netdev_ops
++  * libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
++  * libfc: lport: fix minor documentation errors
++  * libfc: don't WARN_ON in lport_timeout for RESET state
++  * fcoe: initialize return value in fcoe_destroy
++  * libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in fc_fcp_send_data
++  * libfc: fix memory corruption caused by double frees and bad error
++    handling
++  * libfc: fix free of fc_rport_priv with timer pending
++  * libfc: remote port gets stuck in restart state without really
++    restarting
++  * fcoe, libfc: fix an libfc issue with queue ramp down in libfc
++  * fcoe: Fix checking san mac address
++  * fcoe: Fix getting san mac for VLAN interface
++  * qlge: Remove explicit setting of PCI Dev CTL reg.
++  * qlge: Set PCIE max read request size.
++  * qlge: Don't fail open when port is not initialized.
++  * qlge: Add handler for DCBX firmware event.
++  * qlge: Bonding fix for mode 6.
++  * PCI: AER: fix aer inject result in kernel oops
++  * DMI: allow omitting ident strings in DMI tables
++  * Input: i8042 - remove identification strings from DMI tables
++  * Input: i8042 - add Gigabyte M1022M to the noloop list
++  * Input: i8042 - add Dritek quirk for Acer Aspire 5610.
++  * ALSA: hda - select IbexPeak handler for Calpella
++  * ALSA: hda - Fix quirk for Maxdata obook4-1
++  * ALSA: hda - Add missing Line-Out and PCM switches as slave
++  * iTCO_wdt.c - cleanup chipset documentation
++  * iTCO_wdt: add PCI ID for the Intel EP80579 (Tolapai) SoC
++  * iTCO_wdt: Add Intel Cougar Point and PCH DeviceIDs
++  * ahci: disable SNotification capability for ich8
++  * ata_piix: fix MWDMA handling on PIIX3
++  * md: fix small irregularity with start_ro module parameter
++  * V4L/DVB (13826): uvcvideo: Fix controls blacklisting
++  * cio: fix double free in case of probe failure
++  * cio: dont panic in non-fatal conditions
++  * netiucv: displayed TX bytes value much too high
++  * ipc ns: fix memory leak (idr)
++  * ALSA: hda - Fix HP T5735 automute
++  * hwmon: (fschmd) Fix a memleak on multiple opens of /dev/watchdog
++  * UBI: fix memory leak in update path
++  * UBI: initialise update marker
++  * ASoC: fix a memory-leak in wm8903
++  * mac80211: check that ieee80211_set_power_mgmt only handles STA
++    interfaces.
++  * cfg80211: fix channel setting for wext
++  * KVM: S390: fix potential array overrun in intercept handling
++  * KVM: only allow one gsi per fd
++  * KVM: Fix race between APIC TMR and IRR
++  * KVM: MMU: bail out pagewalk on kvm_read_guest error
++  * KVM: x86: Fix host_mapping_level()
++  * KVM: x86: Fix probable memory leak of vcpu->arch.mce_banks
++  * KVM: x86: Fix leak of free lapic date in kvm_arch_vcpu_init()
++  * KVM: fix lock imbalance in kvm_*_irq_source_id()
++  * KVM: only clear irq_source_id if irqchip is present
++  * IPoIB: Clear ipoib_neigh.dgid in ipoib_neigh_alloc()
++  * x86: Reenable TSC sync check at boot, even with NONSTOP_TSC
++  * ACPI: enable C2 and Turbo-mode on Nehalem notebooks on A/C
++    - LP: #516325
++  * iwlwifi: Fix throughput stall issue in HT mode for 5000
++  * fnctl: f_modown should call write_lock_irqsave/restore
++  * x86, msr/cpuid: Pass the number of minors when unregistering MSR and
++    CPUID drivers.
++  * Linux 2.6.32.7
++  * scsi_lib: Fix bug in completion of bidi commands
++  * mptsas: Fix issue with chain pools allocation on katmai
++  * mm: add new 'read_cache_page_gfp()' helper function
++  * drm/i915: Selectively enable self-reclaim
++  * firewire: ohci: fix crashes with TSB43AB23 on 64bit systems
++  * S390: fix single stepped svcs with TRACE_IRQFLAGS=y
++  * x86: Set hotpluggable nodes in nodes_possible_map
++  * x86: Remove "x86 CPU features in debugfs" (CONFIG_X86_CPU_DEBUG)
++  * libata: retry FS IOs even if it has failed with AC_ERR_INVALID
++  * zcrypt: Do not remove coprocessor for error 8/72
++  * dasd: fix possible NULL pointer errors
++  * ACPI: Add a generic API for _OSC -v2
++  * ACPI: Add platform-wide _OSC support.
++  * ACPI: fix OSC regression that caused aer and pciehp not to load
++  * ACPI: Advertise to BIOS in _OSC: _OST on _PPC changes
++  * UBI: fix volume creation input checking
++  * e1000/e1000e: don't use small hardware rx buffers
++  * drm/i915: Reload hangcheck timer too for Ironlake
++  * Fix a leak in affs_fill_super()
++  * Fix failure exits in bfs_fill_super()
++  * fix oops in fs/9p late mount failure
++  * fix leak in romfs_fill_super()
++  * Fix remount races with symlink handling in affs
++  * fix affs parse_options()
++  * Fix failure exit in ipathfs
++  * mm: fix migratetype bug which slowed swapping
++  * FDPIC: Respect PT_GNU_STACK exec protection markings when creating
++    NOMMU stack
++  * Split 'flush_old_exec' into two functions
++  * sparc: TIF_ABI_PENDING bit removal
++  * x86: get rid of the insane TIF_ABI_PENDING bit
++  * Input: winbond-cir - remove dmesg spam
++  * x86: Disable HPET MSI on ATI SB700/SB800
++  * iwlwifi: set default aggregation frame count limit to 31
++  * drm/i915: only enable hotplug for detected outputs
++  * firewire: core: add_descriptor size check
++  * SECURITY: selinux, fix update_rlimit_cpu parameter
++  * regulator: Specify REGULATOR_CHANGE_STATUS for WM835x LED constraints
++  * x86: Add Dell OptiPlex 760 reboot quirk
++    - LP: #488319
++  * x86: Add quirk for Intel DG45FC board to avoid low memory corruption
++  * x86/amd-iommu: Fix possible integer overflow
++  * clocksource: fix compilation if no GENERIC_TIME
++  * tcp: update the netstamp_needed counter when cloning sockets
++  * sky2: Fix oops in sky2_xmit_frame() after TX timeout
++  * net: restore ip source validation
++  * af_packet: Don't use skb after dev_queue_xmit()
++  * ax25: netrom: rose: Fix timer oopses
++  * KVM: allow userspace to adjust kvmclock offset
++  * oprofile/x86: add Xeon 7500 series support
++  * oprofile/x86: fix crash when profiling more than 28 events
++  * libata: retry link resume if necessary
++  * mm: percpu-vmap fix RCU list walking
++  * mm: purge fragmented percpu vmap blocks
++  * block: fix bio_add_page for non trivial merge_bvec_fn case
++  * Fix 'flush_old_exec()/setup_new_exec()' split
++  * random: drop weird m_time/a_time manipulation
++  * random: Remove unused inode variable
++  * block: fix bugs in bio-integrity mempool usage
++  * usb: r8a66597-hdc disable interrupts fix
++  * connector: Delete buggy notification code.
++  * be2net: Bug fix to support newer generation of BE ASIC
++  * be2net: Fix memset() arg ordering.
++  * mm: flush dcache before writing into page to avoid alias
++  * mac80211: fix NULL pointer dereference when ftrace is enabled
++  * imxfb: correct location of callbacks in suspend and resume
++  * mx3fb: some debug and initialisation fixes
++  * starfire: clean up properly if firmware loading fails
++  * kernel/cred.c: use kmem_cache_free
++  * uartlite: fix crash when using as console
++  * pktcdvd: removing device does not remove its sysfs dir
++  * ath9k: fix eeprom INI values override for 2GHz-only cards
++  * ath9k: fix beacon slot/buffer leak
++  * powerpc: TIF_ABI_PENDING bit removal
++  * NET: fix oops at bootime in sysctl code
++  * Linux 2.6.32.8
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 10 Feb 2010 18:56:52 +0000
++
++linux (2.6.32-12.17) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * restore linux-image prefix -- master
++  * enforce -- we require SELINUX enabled -- master
++  * enforce -- ensure APPARMOR is our default LSM -- master
++  * make doc package completely optional -- master
++  * make source package completely optional -- master
++  * make linux-libc-dev completly optional -- master
++  * convert package disable to a deps list -- master
++  * allow common headers to switch from indep to arch -- master
++  * convert binary package disable to a deps list -- master
++  * add configuration option for a full source build tree -- master
++  * add support for uImage kernels in package control scripts
++  * getabis -- cleanup and parameterise repository list -- master
++  * getabis -- move configuration to etc/getabi -- master
++  * kernelconfig -- move configuration to etc -- master
++  * rules -- make debian/debian.env master for branch name
++  * set the current branch name -- master
++  * pull back common debian.master files into debian -- master
++  * enforcer -- make the enforcement configuration common
++  * insert-changes -- correctly link to debian/rules in DROOT
++
++  [ Colin Watson ]
++
++  * future-proof ddeb handling against buildd changes
++
++  [ Eric Miao ]
++
++  * SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5} depend on
++    X86
++
++  [ Loïc Minier ]
++
++  * Add modules.builtin.bin to prerm rm list
++    - LP: #516584
++
++  [ Tim Gardner ]
++
++  * [Config] Implement the amd64 preempt flavour
++
++  [ Upstream Kernel Changes ]
++
++  * syslog: distinguish between /proc/kmsg and syscalls
++    - LP: #515623
++  * sfc: Fix polling for slow MCDI operations
++  * sfc: Fix conditions for MDIO self-test
++  * sfc: QT202x: Remove unreliable MMD check at initialisation
++  * sfc: Add workspace for GMAC bug workaround to MCDI MAC_STATS buffer
++  * sfc: Use fixed-size buffers for MCDI NVRAM requests
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2010 07:09:31 +0000
++
++linux (2.6.32-12.16) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: acpi battery -- delay first lookup of the battery until
++    first use"
++  * SAUCE: acpi battery -- move first lookup asynchronous
++    - LP: #507211
++  * [Config] update configs to cleanup generic configs
++  * [Config] disable CONFIG_X86_CPU_DEBUG for amd64
++  * [Config] enable USER_NS
++    - LP: #480739, #509808
++
++  [ Heiko Carstens ]
++
++  * (pre-stable) driver-core: fix devtmpfs crash on s390
++    - LP: #512370
++
++  [ John Johansen ]
++
++  * [Config] for server and virtual flavours make CONFIG_SCSI_SYM53C8XX_2=y
++    - LP: #494565
++  * [Config] VIRTIO=y for server/virtual flavours
++    - LP: #494565
++
++  [ Kay Sievers ]
++
++  * (pre-stable) Driver-Core: devtmpfs - set root directory mode to 0755
++    - LP: #512370
++
++  [ Kees Cook ]
++
++  * SAUCE: x86: brk away from exec rand area
++    - LP: #452175
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] e1000: enhance frame fragment detection
++    - CVE-2009-4536
++  * [Upstream] e1000e: enhance frame fragment detection
++    - CVE-2009-4538
++
++  [ Sebastian Kapfer ]
++
++  * (pre-stable) Input: ALPS - add interleaved protocol support (Dell E6x00
++    series)
++    - LP: #296610
++
++  [ Upstream Kernel Changes ]
++
++  * inotify: do not reuse watch descriptors
++    - LP: #485556
++  * inotify: only warn once for inotify problems
++  * revert "drivers/video/s3c-fb.c: fix clock setting for Samsung SoC
++    Framebuffer"
++  * memcg: ensure list is empty at rmdir
++  * drm/i915: remove loop in Ironlake interrupt handler
++  * block: Fix incorrect reporting of partition alignment
++  * x86, mce: Thermal monitoring depends on APIC being enabled
++  * futexes: Remove rw parameter from get_futex_key()
++  * page allocator: update NR_FREE_PAGES only when necessary
++  * x86, apic: use physical mode for IBM summit platforms
++  * edac: i5000_edac critical fix panic out of bounds
++  * x86: SGI UV: Fix mapping of MMIO registers
++  * mfd: WM835x GPIO direction register is not locked
++  * mfd: Correct WM835x ISINK ramp time defines
++  * ALSA: hda - Fix missing capture mixer for ALC861/660 codecs
++  * V4L/DVB (13868): gspca - sn9c20x: Fix test of unsigned.
++  * reiserfs: truncate blocks not used by a write
++  * HID: add device IDs for new model of Apple Wireless Keyboard
++  * PCI/cardbus: Add a fixup hook and fix powerpc
++  * Input: pmouse - move Sentelic probe down the list
++  * asus-laptop: add Lenovo SL hotkey support
++  * sched: Fix cpu_clock() in NMIs, on !CONFIG_HAVE_UNSTABLE_SCHED_CLOCK
++  * sparc64: Fix NMI programming when perf events are active.
++  * sparc64: Fix Niagara2 perf event handling.
++  * i2c: Do not use device name after device_unregister
++  * i2c/pca: Don't use *_interruptible
++  * serial/8250_pnp: add a new Fujitsu Wacom Tablet PC device
++  * sched: Fix task priority bug
++  * vfs: Fix vmtruncate() regression
++  * Linux 2.6.32.5
++  * x86, msr/cpuid: Register enough minors for the MSR and CPUID drivers
++  * V4L/DVB (13900): gspca - sunplus: Fix bridge exchanges.
++  * Staging: asus_oled: fix oops in 2.6.32.2
++  * Staging: hv: fix smp problems in the hyperv core code
++  * tty: fix race in tty_fasync
++  * ecryptfs: use after free
++  * ecryptfs: initialize private persistent file before dereferencing
++    pointer
++  * nozomi: quick fix for the close/close bug
++  * serial: 8250_pnp: use wildcard for serial Wacom tablets
++  * usb: serial: fix memory leak in generic driver
++  * USB: fix bitmask merge error
++  * USB: Don't use GFP_KERNEL while we cannot reset a storage device
++  * USB: EHCI: fix handling of unusual interrupt intervals
++  * USB: EHCI & UHCI: fix race between root-hub suspend and port resume
++  * USB: add missing delay during remote wakeup
++  * USB: add speed values for USB 3.0 and wireless controllers
++  * ACPI: EC: Accelerate query execution
++  * ACPI: EC: Add wait for irq storm
++  * SCSI: enclosure: fix oops while iterating enclosure_status array
++  * drm/i915: Read the response after issuing DDC bus switch command
++  * drm/i915: try another possible DDC bus for the SDVO device with
++    multiple outputs
++  * block: bdev_stack_limits wrapper
++  * DM: Fix device mapper topology stacking
++  * x86/PCI/PAT: return EINVAL for pci mmap WC request for !pat_enabled
++  * USB: fix usbstorage for 2770:915d delivers no FAT
++  * vmalloc: remove BUG_ON due to racy counting of VM_LAZY_FREE
++  * perf timechart: Use tid not pid for COMM change
++  * perf events: Dont report side-band events on each cpu for
++    per-task-per-cpu events
++  * perf: Honour event state for aux stream data
++  * Linux 2.6.32.6
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 27 Jan 2010 16:40:23 +0000
++
++linux (2.6.32-11.15) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) drm/radeon/kms: fix crtc vblank update for r600"
++  * Revert "(pre-stable) sched: Fix balance vs hotplug race"
++  * Revert "[Upstream] acerhdf: Limit modalias matching to supported
++    boards"
++  * Revert "[Upstream] mmc: prevent dangling block device from accessing
++    stale queues"
++  * Revert "SAUCE: Fix nx_enable reporting"
++  * Revert "SAUCE: [x86] fix report of cs-limit nx-emulation"
++  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
++  * SAUCE: i915 -- disable powersave by default
++    - LP: #492392
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
++    - LP: #369978
++  * SAUCE: [x86] fix report of cs-limit nx-emulation
++    - LP: #454285
++  * SAUCE: Fix nx_enable reporting
++    - LP: #454285
++
++  [ Tim Gardner ]
++
++  * [Upstream] b43: Declare all possible firmware files.
++    - LP: #488636
++  * [Config] updateconfigs after adding pvscsi
++    - LP: #497156
++  * [Config] CONFIG_BT=m
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "x86: Side-step lguest problem by only building cmpxchg8b_emu
++    for pre-Pentium"
++  * SCSI: ipr: fix EEH recovery
++  * SCSI: qla2xxx: dpc thread can execute before scsi host has been added
++  * SCSI: st: fix mdata->page_order handling
++  * SCSI: fc class: fix fc_transport_init error handling
++  * sched: Fix task_hot() test order
++  * x86, cpuid: Add "volatile" to asm in native_cpuid()
++  * sched: Select_task_rq_fair() must honour SD_LOAD_BALANCE
++  * clockevents: Prevent clockevent_devices list corruption on cpu hotplug
++  * pata_hpt3x2n: fix clock turnaround
++  * pata_cmd64x: fix overclocking of UDMA0-2 modes
++  * ASoC: wm8974: fix a wrong bit definition
++  * sound: sgio2audio/pdaudiocf/usb-audio: initialize PCM buffer
++  * ALSA: hda - Fix missing capsrc_nids for ALC88x
++  * acerhdf: limit modalias matching to supported
++    - LP: #435958
++  * ACPI: EC: Fix MSI DMI detection
++  * ACPI: Use the return result of ACPI lid notifier chain correctly
++  * powerpc: Handle VSX alignment faults correctly in little-endian mode
++  * ASoC: Do not write to invalid registers on the wm9712.
++  * drm/radeon: fix build on 64-bit with some compilers.
++  * USB: emi62: fix crash when trying to load EMI 6|2 firmware
++  * USB: option: support hi speed for modem Haier CE100
++  * USB: Fix a bug on appledisplay.c regarding signedness
++  * USB: musb: gadget_ep0: avoid SetupEnd interrupt
++  * Bluetooth: Prevent ill-timed autosuspend in USB driver
++  * USB: rename usb_configure_device
++  * USB: fix bugs in usb_(de)authorize_device
++  * drivers/net/usb: Correct code taking the size of a pointer
++  * x86: SGI UV: Fix writes to led registers on remote uv hubs
++  * md: Fix unfortunate interaction with evms
++  * dma: at_hdmac: correct incompatible type for argument 1 of
++    'spin_lock_bh'
++  * dma-debug: Do not add notifier when dma debugging is disabled.
++  * dma-debug: Fix bug causing build warning
++  * cifs: NULL out tcon, pSesInfo, and srvTcp pointers when chasing DFS
++    referrals
++  * x86/amd-iommu: Fix initialization failure panic
++  * ioat3: fix p-disabled q-continuation
++  * ioat2,3: put channel hardware in known state at init
++  * KVM: MMU: remove prefault from invlpg handler
++  * KVM: LAPIC: make sure IRR bitmap is scanned after vm load
++  * Libertas: fix buffer overflow in lbs_get_essid()
++  * iwmc3200wifi: fix array out-of-boundary access
++  * mac80211: fix propagation of failed hardware reconfigurations
++  * mac80211: fix WMM AP settings application
++  * mac80211: Fix IBSS merge
++  * cfg80211: fix race between deauth and assoc response
++  * ath5k: fix SWI calibration interrupt storm
++  * ath9k: wake hardware for interface IBSS/AP/Mesh removal
++  * ath9k: Fix TX queue draining
++  * ath9k: fix missed error codes in the tx status check
++  * ath9k: wake hardware during AMPDU TX actions
++  * ath9k: fix suspend by waking device prior to stop
++  * ath9k_hw: Fix possible OOB array indexing in gen_timer_index[] on
++    64-bit
++  * ath9k_hw: Fix AR_GPIO_INPUT_EN_VAL_BT_PRIORITY_BB and its shift value
++    in 0x4054
++  * iwl3945: disable power save
++  * iwl3945: fix panic in iwl3945 driver
++  * iwlwifi: fix EEPROM/OTP reading endian annotations and a bug
++  * iwlwifi: fix more eeprom endian bugs
++  * iwlwifi: fix 40MHz operation setting on cards that do not allow it
++  * mac80211: fix race with suspend and dynamic_ps_disable_work
++  * NOMMU: Optimise away the {dac_,}mmap_min_addr tests
++  * 'sysctl_max_map_count' should be non-negative
++  * kernel/sysctl.c: fix the incomplete part of
++    sysctl_max_map_count-should-be-non-negative.patch
++  * V4L/DVB (13596): ov511.c typo: lock => unlock
++  * x86/ptrace: make genregs[32]_get/set more robust
++  * memcg: avoid oom-killing innocent task in case of use_hierarchy
++  * e100: Fix broken cbs accounting due to missing memset.
++  * ipv6: reassembly: use seperate reassembly queues for conntrack and
++    local delivery
++  * netfilter: fix crashes in bridge netfilter caused by fragment jumps
++  * hwmon: (sht15) Off-by-one error in array index + incorrect constants
++  * b43: avoid PPC fault during resume
++  * Keys: KEYCTL_SESSION_TO_PARENT needs TIF_NOTIFY_RESUME architecture
++    support
++  * sched: Fix balance vs hotplug race
++  * drm/radeon/kms: fix crtc vblank update for r600
++  * drm: disable all the possible outputs/crtcs before entering KMS mode
++  * S390: dasd: support DIAG access for read-only devices
++  * xen: fix is_disconnected_device/exists_disconnected_device
++  * xen: improvement to wait_for_devices()
++  * xen: wait up to 5 minutes for device connetion
++  * orinoco: fix GFP_KERNEL in orinoco_set_key with interrupts disabled
++  * udf: Try harder when looking for VAT inode
++  * Add unlocked version of inode_add_bytes() function
++  * quota: decouple fs reserved space from quota reservation
++  * ext4: Convert to generic reserved quota's space management.
++  * ext4: fix sleep inside spinlock issue with quota and dealloc (#14739)
++  * x86, msr: Unify rdmsr_on_cpus/wrmsr_on_cpus
++  * cpumask: use modern cpumask style in drivers/edac/amd64_edac.c
++  * amd64_edac: unify MCGCTL ECC switching
++  * x86, msr: Add support for non-contiguous cpumasks
++  * x86, msr: msrs_alloc/free for CONFIG_SMP=n
++  * amd64_edac: fix driver instance freeing
++  * amd64_edac: make driver loading more robust
++  * amd64_edac: fix forcing module load/unload
++  * sched: Sched_rt_periodic_timer vs cpu hotplug
++  * ext4: Update documentation to correct the inode_readahead_blks option
++    name
++  * lguest: fix bug in setting guest GDT entry
++  * vmscan: do not evict inactive pages when skipping an active list scan
++  * ksm: fix mlockfreed to munlocked
++  * rt2x00: Disable powersaving for rt61pci and rt2800pci.
++  * generic_permission: MAY_OPEN is not write access
++  * Linux 2.6.32.3
++  * untangle the do_mremap() mess
++  * fasync: split 'fasync_helper()' into separate add/remove functions
++  * ASoC: fix params_rate() macro use in several codecs
++  * modules: Skip empty sections when exporting section notes
++  * exofs: simple_write_end does not mark_inode_dirty
++  * nfsd: make sure data is on disk before calling ->fsync
++  * sunrpc: fix peername failed on closed listener
++  * SUNRPC: Fix up an error return value in
++    gss_import_sec_context_kerberos()
++  * SUNRPC: Fix the return value in gss_import_sec_context()
++  * sunrpc: on successful gss error pipe write, don't return error
++  * drm/i915: Update LVDS connector status when receiving ACPI LID event
++  * drm/i915: fix order of fence release wrt flushing
++  * drm/i915: Permit pinning whilst the device is 'suspended'
++  * drm: remove address mask param for drm_pci_alloc()
++  * drm/i915: Enable/disable the dithering for LVDS based on VBT setting
++  * drm/i915: Make the BPC in FDI rx/transcoder be consistent with that in
++    pipeconf on Ironlake
++  * drm/i915: Select the correct BPC for LVDS on Ironlake
++  * drm/i915: fix unused var
++  * rtc_cmos: convert shutdown to new pnp_driver->shutdown
++  * drivers/cpuidle/governors/menu.c: fix undefined reference to
++    `__udivdi3'
++  * cgroups: fix 2.6.32 regression causing BUG_ON() in cgroup_diput()
++  * lib/rational.c needs module.h
++  * dma-debug: allow DMA_BIDIRECTIONAL mappings to be synced with
++    DMA_FROM_DEVICE and
++  * kernel/signal.c: fix kernel information leak with print-fatal-signals=1
++  * mmc_block: add dev_t initialization check
++  * mmc_block: fix probe error cleanup bug
++  * mmc_block: fix queue cleanup
++  * ALSA: hda - Fix ALC861-VD capture source mixer
++  * ALSA: ac97: Add Dell Dimension 2400 to Headphone/Line Jack Sense
++    blacklist
++  * ALSA: atiixp: Specify codec for Foxconn RC4107MA-RS2
++    - LP: #498863
++  * ASoC: Fix WM8350 DSP mode B configuration
++  * netfilter: ebtables: enforce CAP_NET_ADMIN
++  * netfilter: nf_ct_ftp: fix out of bounds read in update_nl_seq()
++  * hwmon: (coretemp) Fix TjMax for Atom N450/D410/D510 CPUs
++  * hwmon: (adt7462) Fix pin 28 monitoring
++  * quota: Fix dquot_transfer for filesystems different from ext4
++  * xen: fix hang on suspend.
++  * iwlwifi: fix iwl_queue_used bug when read_ptr == write_ptr
++  * ath5k: Fix eeprom checksum check for custom sized eeproms
++  * cfg80211: fix syntax error on user regulatory hints
++  * iwl: off by one bug
++  * mac80211: add missing sanity checks for action frames
++  * drm/i915: remove render reclock support
++  * libertas: Remove carrier signaling from the scan code
++  * kernel/sysctl.c: fix stable merge error in NOMMU mmap_min_addr
++  * mac80211: fix skb buffering issue (and fixes to that)
++  * fix braindamage in audit_tree.c untag_chunk()
++  * fix more leaks in audit_tree.c tag_chunk()
++  * module: handle ppc64 relocating kcrctabs when CONFIG_RELOCATABLE=y
++  * ipv6: skb_dst() can be NULL in ipv6_hop_jumbo().
++  * agp/intel-agp: Clear entire GTT on startup
++  * Linux 2.6.32.4
++  * ethtool: Add reset operation
++  * gro: Name the GRO result enumeration type
++  * gro: Change all receive functions to return GRO result codes
++  * sfc: 10Xpress: Initialise pause advertising flags
++  * sfc: 10Xpress: Report support for pause frames
++  * sfc: Remove redundant header gmii.h
++  * sfc: Remove redundant hardware initialisation
++  * sfc: Rename Falcon-specific board code and types
++  * sfc: Remove boards.h, moving last remaining declaration to falcon.h
++  * sfc: Remove versioned bitfield macros
++  * sfc: Move RX data FIFO thresholds out of struct efx_nic_type
++  * sfc: Update hardware definitions for Siena
++  * sfc: Rename register I/O header and functions used by both Falcon and
++    Siena
++  * sfc: Eliminate indirect lookups of queue size constants
++  * sfc: Define DMA address mask explicitly in terms of descriptor field
++    width
++  * sfc: Move all TX DMA length limiting into tx.c
++  * sfc: Change order of device removal to reverse of probe order
++  * sfc: Remove declarations of nonexistent functions
++  * sfc: Move efx_xmit_done() declaration into correct stanza
++  * sfc: Move shared members of struct falcon_nic_data into struct efx_nic
++  * sfc: Maintain interrupt moderation values in ticks, not microseconds
++  * sfc: Removed kernel-doc for nonexistent member of efx_phy_operations
++  * sfc: Remove pointless abstraction of memory BAR number
++  * sfc: Remove incorrect assertion from efx_pci_remove_main()
++  * sfc: Remove unnecessary tests of efx->membase
++  * sfc: Move MTD probe after netdev registration and name allocation
++  * sfc: Remove unused code for non-autoneg speed/duplex switching
++  * sfc: Rename 'xfp' file and functions to reflect reality
++  * sfc: Really allow RX checksum offload to be disabled
++  * sfc: Feed GRO result into RX allocation policy and interrupt moderation
++  * sfc: Enable heuristic selection between page and skb RX buffers
++  * sfc: Remove pointless abstraction of memory BAR number (2)
++  * sfc: Remove redundant gotos from __efx_rx_packet()
++  * sfc: Remove ridiculously paranoid assertions
++  * sfc: Move assertions and buffer cleanup earlier in efx_rx_packet_lro()
++  * sfc: Record RX queue number on GRO path
++  * sfc: SFT9001: Reset LED configuration correctly after blinking
++  * sfc: Use a single blink implementation
++  * sfc: Rename efx_board::init_leds to init_phy and use for SFN4111T
++  * sfc: Make board information explicitly Falcon-specific
++  * sfc: Move definition of struct falcon_nic_data into falcon.h
++  * sfc: Move struct falcon_board into struct falcon_nic_data
++  * sfc: Move all I2C stuff into struct falcon_board
++  * sfc: Gather link state fields in struct efx_nic into new struct
++    efx_link_state
++  * sfc: Remove unnecessary casts to struct sk_buff *
++  * sfc: Remove redundant efx_xmit() function
++  * sfc: Combine high-level header files
++  * sfc: Log interrupt and reset type names, not numbers
++  * sfc: Fix descriptor cache sizes
++  * sfc: Treat all MAC registers as 128-bit
++  * sfc: Strengthen EFX_ASSERT_RESET_SERIALISED
++  * sfc: Comment corrections
++  * sfc: Remove unused constant
++  * sfc: Clean up struct falcon_board and struct falcon_board_data
++  * sfc: Fix bugs in RX queue flushing
++  * sfc: Remove unused function efx_flush_queues()
++  * sfc: Only switch Falcon MAC clocks as necessary
++  * sfc: Hold MAC lock for longer in efx_init_port()
++  * sfc: Split MAC stats DMA initiation and completion
++  * sfc: Move Falcon board/PHY/MAC monitoring code to falcon.c
++  * sfc: Simplify XMAC link polling
++  * sfc: Change MAC promiscuity and multicast hash at the same time
++  * sfc: Move inline comment into kernel-doc
++  * sfc: Do not set net_device::trans_start in self-test
++  * sfc: Simplify PHY polling
++  * sfc: QT202x: Reset before reading PHY id
++  * sfc: Replace MDIO spinlock with mutex
++  * sfc: Always start Falcon using the XMAC
++  * sfc: Limit some hardware workarounds to Falcon
++  * sfc: Remove EFX_WORKAROUND_9141 macro
++  * sfc: Remove another unused workaround macro
++  * sfc: Remove some redundant whitespace
++  * sfc: Decouple NIC revision number from Falcon PCI revision number
++  * sfc: Move descriptor cache base addresses to struct efx_nic_type
++  * sfc: Clean up RX event handling
++  * sfc: Remove redundant writes to INT_ADR_KER
++  * sfc: Remove duplicate hardware structure definitions
++  * sfc: Turn pause frame generation on and off at the MAC, not the RX FIFO
++  * sfc: Move Falcon NIC operations to efx_nic_type
++  * sfc: Refactor link configuration
++  * sfc: Generalise link state monitoring
++  * sfc: Add power-management and wake-on-LAN support
++  * sfc: Implement ethtool reset operation
++  * sfc: Add efx_nic_type operation for register self-test
++  * sfc: Add efx_nic_type operation for NVRAM self-test
++  * sfc: Add efx_nic_type operation for identity LED control
++  * sfc: Separate shared NIC code from Falcon-specific and rename
++    accordingly
++  * sfc: Fold falcon_probe_nic_variant() into falcon_probe_nic()
++  * sfc: Extend loopback mode enumeration
++  * sfc: Remove static PHY data and enumerations
++  * sfc: Extend MTD driver for use with new NICs
++  * sfc: Allow for additional checksum offload features
++  * sfc: Rename falcon.h to nic.h
++  * sfc: Move shared NIC code from falcon.c to new source file nic.c
++  * sfc: Add firmware protocol definitions (MCDI)
++  * sfc: Add support for SFC9000 family (1)
++  * sfc: Add support for SFC9000 family (2)
++  * sfc: Implement TSO for TCP/IPv6
++  * sfc: Update version, copyright dates, authors
++  * drivers/net/sfc: Correct code taking the size of a pointer
++  * sfc: Move PHY software state initialisation from init() into probe()
++  * sfc: Include XGXS in XMAC link status check except in XGMII loopback
++  * sfc: Fix DMA mapping cleanup in case of an error in TSO
++  * sfc: QT2025C: Work around PHY bug
++  * sfc: QT2025C: Switch into self-configure mode when not in loopback
++  * sfc: QT2025C: Work around PHY firmware initialisation bug
++  * sfc: QT2025C: Add error message for suspected bad SFP+ cables
++  * sfc: Disable TX descriptor prefetch watchdog
++  * [SCSI] vmw_pvscsi: SCSI driver for VMware's virtual HBA.
++    - LP: #497156
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Jan 2010 16:12:47 +0000
++
++linux (2.6.32-10.14) lucid; urgency=low
++
++  [ Alex Deucher ]
++
++  * SAUCE: drm/radeon/kms: fix LVDS setup on r4xx
++    - LP: #493795
++
++  [ Andy Whitcroft ]
++
++  * Revert "(pre-stable) acpi: Use the ARB_DISABLE for the CPU which model
++    id is less than 0x0f."
++  * config-check -- ensure the checks get run at build time
++  * config-check -- check the processed config during updateconfigs
++  * config-check -- CONFIG_SECCOMP may not be present
++  * TUN is now built in ignore
++  * SAUCE: acpi battery -- delay first lookup of the battery until first
++    use
++  * SAUCE: async_populate_rootfs: move rootfs init earlier
++  * ubuntu: AppArmor -- update to mainline 2010-01-06
++  * SAUCE: move RLIMIT_CORE pipe dumper marker to 1
++    - LP: #498525
++
++  [ Dave Airlie ]
++
++  * (pre-stable) drm/radeon/kms: fix crtc vblank update for r600
++
++  [ Leann Ogasawara ]
++
++  * Add asix to nic-usb-modules file
++    - LP: #499785
++
++  [ Peter Zijlstra ]
++
++  * (pre-stable) sched: Fix balance vs hotplug race
++
++  [ Tim Gardner ]
++
++  * [Config] Enable CONFIG_FUNCTION_TRACER
++    - LP: #497989
++  * [Config] Drop lpia from getabis
++  * [Config] Build in TUN/TAP driver
++    - LP: #499491
++  * [Config] DH_COMPAT=5
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "(pre-stable) drm/i915: Avoid NULL dereference with
++    component_only tv_modes"
++  * Revert "(pre-stable) drm/i915: Fix sync to vblank when VGA output is
++    turned off"
++  * USB: usb-storage: fix bug in fill_inquiry
++  * USB: option: add pid for ZTE
++  * firewire: ohci: handle receive packets with a data length of zero
++  * rcu: Prepare for synchronization fixes: clean up for non-NO_HZ handling
++    of ->completed counter
++  * rcu: Fix synchronization for rcu_process_gp_end() uses of ->completed
++    counter
++  * rcu: Fix note_new_gpnum() uses of ->gpnum
++  * rcu: Remove inline from forward-referenced functions
++  * perf_event: Fix invalid type in ioctl definition
++  * perf_event: Initialize data.period in perf_swevent_hrtimer()
++  * perf: Don't free perf_mmap_data until work has been done
++  * PM / Runtime: Fix lockdep warning in __pm_runtime_set_status()
++  * sched: Check for an idle shared cache in select_task_rq_fair()
++  * sched: Fix affinity logic in select_task_rq_fair()
++  * sched: Rate-limit newidle
++  * sched: Fix and clean up rate-limit newidle code
++  * x86/amd-iommu: attach devices to pre-allocated domains early
++  * x86/amd-iommu: un__init iommu_setup_msi
++  * x86, Calgary IOMMU quirk: Find nearest matching Calgary while walking
++    up the PCI tree
++  * x86: Fix iommu=nodac parameter handling
++  * x86: GART: pci-gart_64.c: Use correct length in strncmp
++  * x86: ASUS P4S800 reboot=bios quirk
++    - LP: #366682
++  * x86, apic: Enable lapic nmi watchdog on AMD Family 11h
++  * ssb: Fix range check in sprom write
++  * ath5k: allow setting txpower to 0
++  * ath5k: enable EEPROM checksum check
++  * hrtimer: Fix /proc/timer_list regression
++  * ALSA: hrtimer - Fix lock-up
++  * ALSA: hda - Terradici HDA controllers does not support 64-bit mode
++  * KVM: x86 emulator: limit instructions to 15 bytes
++  * KVM: s390: Fix prefix register checking in arch/s390/kvm/sigp.c
++  * KVM: s390: Make psw available on all exits, not just a subset
++  * KVM: fix irq_source_id size verification
++  * KVM: x86: include pvclock MSRs in msrs_to_save
++  * x86: Prevent GCC 4.4.x (pentium-mmx et al) function prologue wreckage
++  * x86: Use -maccumulate-outgoing-args for sane mcount prologues
++  * x86, mce: don't restart timer if disabled
++  * x86/mce: Set up timer unconditionally
++  * x86: SGI UV: Fix BAU initialization
++  * x86: Fix duplicated UV BAU interrupt vector
++  * x86: Add new Intel CPU cache size descriptors
++  * x86: Fix typo in Intel CPU cache size descriptor
++  * pata_hpt{37x|3x2n}: fix timing register masks (take 2)
++  * s390: clear high-order bits of registers after sam64
++  * V4L/DVB: Fix test in copy_reg_bits()
++  * bsdacct: fix uid/gid misreporting
++  * UBI: flush wl before clearing update marker
++  * jbd2: don't wipe the journal on a failed journal checksum
++  * USB: xhci: Add correct email and files to MAINTAINERS entry.
++  * USB: musb_gadget_ep0: fix unhandled endpoint 0 IRQs, again
++  * USB: option.c: add support for D-Link DWM-162-U5
++  * USB: usbtmc: repeat usb_bulk_msg until whole message is transfered
++  * USB: usb-storage: add BAD_SENSE flag
++  * USB: Close usb_find_interface race v3
++  * pxa/em-x270: fix usb hub power up/reset sequence
++  * hfs: fix a potential buffer overflow
++  * SUNRPC: IS_ERR/PTR_ERR confusion
++  * NFS: Fix nfs_migrate_page()
++  * md/bitmap: protect against bitmap removal while being updated.
++  * futex: Take mmap_sem for get_user_pages in fault_in_user_writeable
++  * devpts_get_tty() should validate inode
++  * debugfs: fix create mutex racy fops and private data
++  * Driver core: fix race in dev_driver_string
++  * Serial: Do not read IIR in serial8250_start_tx when UART_BUG_TXEN
++  * mac80211: Fix bug in computing crc over dynamic IEs in beacon
++  * mac80211: Fixed bug in mesh portal paths
++  * mac80211: Revert 'Use correct sign for mesh active path refresh'
++  * mac80211: fix scan abort sanity checks
++  * wireless: correctly report signal value for IEEE80211_HW_SIGNAL_UNSPEC
++  * rtl8187: Fix wrong rfkill switch mask for some models
++  * x86: Fix bogus warning in apic_noop.apic_write()
++  * mm: hugetlb: fix hugepage memory leak in mincore()
++  * mm: hugetlb: fix hugepage memory leak in walk_page_range()
++  * powerpc/windfarm: Add detection for second cpu pump
++  * powerpc/therm_adt746x: Record pwm invert bit at module load time]
++  * powerpc: Fix usage of 64-bit instruction in 32-bit altivec code
++  * drm/radeon/kms: Add quirk for HIS X1300 board
++  * drm/radeon/kms: handle vblanks properly with dpms on
++  * drm/radeon/kms: fix legacy crtc2 dpms
++  * drm/radeon/kms: fix vram setup on rs600
++  * drm/radeon/kms: rs6xx/rs740: clamp vram to aperture size
++  * drm/ttm: Fix build failure due to missing struct page
++  * drm/i915: Set the error code after failing to insert new offset into mm
++    ht.
++  * drm/i915: Add the missing clonemask for display port on Ironlake
++  * xen/xenbus: make DEVICE_ATTR()s static
++  * xen: re-register runstate area earlier on resume.
++  * xen: restore runstate_info even if !have_vcpu_info_placement
++  * xen: correctly restore pfn_to_mfn_list_list after resume
++  * xen: register timer interrupt with IRQF_TIMER
++  * xen: register runstate on secondary CPUs
++  * xen: don't call dpm_resume_noirq() with interrupts disabled.
++  * xen: register runstate info for boot CPU early
++  * xen: call clock resume notifier on all CPUs
++  * xen: improve error handling in do_suspend.
++  * xen: don't leak IRQs over suspend/resume.
++  * xen: use iret for return from 64b kernel to 32b usermode
++  * xen: explicitly create/destroy stop_machine workqueues outside
++    suspend/resume region.
++  * Xen balloon: fix totalram_pages counting.
++  * xen: try harder to balloon up under memory pressure.
++  * dm exception store: free tmp_store on persistent flag error
++  * dm snapshot: only take lock for statustype info not table
++  * dm crypt: move private iv fields to structs
++  * dm crypt: restructure essiv error path
++  * dm: avoid _hash_lock deadlock
++  * dm snapshot: cope with chunk size larger than origin
++  * dm crypt: separate essiv allocation from initialisation
++  * dm crypt: make wipe message also wipe essiv key
++  * slc90e66: fix UDMA handling
++  * tcp: Stalling connections: Fix timeout calculation routine
++  * ip_fragment: also adjust skb->truesize for packets not owned by a
++    socket
++  * b44 WOL setup: one-bit-off stack corruption kernel panic fix
++  * sparc64: Don't specify IRQF_SHARED for LDC interrupts.
++  * sparc64: Fix overly strict range type matching for PCI devices.
++  * sparc64: Fix stack debugging IRQ stack regression.
++  * sparc: Set UTS_MACHINE correctly.
++  * b43legacy: avoid PPC fault during resume
++  * tracing: Fix event format export
++  * ath9k: Fix TX hang poll routine
++  * ath9k: fix processing of TX PS null data frames
++  * ath9k: Fix maximum tx fifo settings for single stream devices
++  * ath9k: fix tx status reporting
++  * mac80211: Fix dynamic power save for scanning.
++  * drm/i915: Fix sync to vblank when VGA output is turned off
++  * memcg: fix memory.memsw.usage_in_bytes for root cgroup
++  * thinkpad-acpi: fix default brightness_mode for R50e/R51
++  * thinkpad-acpi: preserve rfkill state across suspend/resume
++  * ipw2100: fix rebooting hang with driver loaded
++  * matroxfb: fix problems with display stability
++  * acerhdf: add new BIOS versions
++  * asus-laptop: change light sens default values.
++  * vmalloc: conditionalize build of pcpu_get_vm_areas()
++  * ACPI: Use the ARB_DISABLE for the CPU which model id is less than 0x0f.
++  * net: Fix userspace RTM_NEWLINK notifications.
++  * ext3: Fix data / filesystem corruption when write fails to copy data
++  * V4L/DVB (13116): gspca - ov519: Webcam 041e:4067 added.
++  * bcm63xx_enet: fix compilation failure after get_stats_count removal
++  * x86: Under BIOS control, restore AP's APIC_LVTTHMR to the BSP value
++  * drm/i915: Avoid NULL dereference with component_only tv_modes
++  * drm/i915: PineView only has LVDS and CRT ports
++  * drm/i915: Fix LVDS stability issue on Ironlake
++  * mm: sigbus instead of abusing oom
++  * ipvs: zero usvc and udest
++  * jffs2: Fix long-standing bug with symlink garbage collection.
++  * intel-iommu: Detect DMAR in hyperspace at probe time.
++  * intel-iommu: Apply BIOS sanity checks for interrupt remapping too.
++  * intel-iommu: Check for an RMRR which ends before it starts.
++  * intel-iommu: Fix oops with intel_iommu=igfx_off
++  * intel-iommu: ignore page table validation in pass through mode
++  * netfilter: xtables: document minimal required version
++  * perf_event: Fix incorrect range check on cpu number
++  * implement early_io{re,un}map for ia64
++  * Linux 2.6.32.2
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 07 Jan 2010 15:28:43 +0000
++
++linux (2.6.32-9.13) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_B43_PHY_LP
++    - LP: #493059
++  * include modules.builtin in the binary debs
++  * config-check -- add a configuration enforcer
++  * config-check -- add a unit-test suite to the checker
++  * [Config] Enable CONFIG_SYN_COOKIES for versatile
++  * [Config] Enable CONFIG_SECURITY_SMACK for ports
++  * [Config] Enable CONFIG_SECURITY_FILE_CAPABILITIES for ports
++  * [Config] Disable CONFIG_COMPAT_BRK for ports
++  * getabis -- add armel versatile to the list
++
++  [ Brad Figg ]
++
++  * SAUCE: Increase the default prealloc buffer for HDA audio devices
++    (non-modem)
++
++  [ Manoj Iyer ]
++
++  * ubuntu: onmibook -- Added missing BOM file
++
++  [ Tim Gardner ]
++
++  * ubuntu: fsam7400 -- Cleanup Makefile
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT"
++  * signal: Fix alternate signal stack check
++  * SCSI: scsi_lib_dma: fix bug with dma maps on nested scsi objects
++  * SCSI: osd_protocol.h: Add missing #include
++  * SCSI: megaraid_sas: fix 64 bit sense pointer truncation
++  * ext4: fix potential buffer head leak when add_dirent_to_buf() returns
++    ENOSPC
++  * ext4: avoid divide by zero when trying to mount a corrupted file system
++  * ext4: fix the returned block count if EXT4_IOC_MOVE_EXT fails
++  * ext4: fix lock order problem in ext4_move_extents()
++  * ext4: fix possible recursive locking warning in EXT4_IOC_MOVE_EXT
++  * ext4: plug a buffer_head leak in an error path of ext4_iget()
++  * ext4: make sure directory and symlink blocks are revoked
++  * ext4: fix i_flags access in ext4_da_writepages_trans_blocks()
++  * ext4: journal all modifications in ext4_xattr_set_handle
++  * ext4: don't update the superblock in ext4_statfs()
++  * ext4: fix uninit block bitmap initialization when s_meta_first_bg is
++    non-zero
++  * ext4: fix block validity checks so they work correctly with meta_bg
++  * ext4: avoid issuing unnecessary barriers
++  * ext4: fix error handling in ext4_ind_get_blocks()
++  * ext4: make trim/discard optional (and off by default)
++  * ext4: make "norecovery" an alias for "noload"
++  * ext4: Fix double-free of blocks with EXT4_IOC_MOVE_EXT
++  * ext4: initialize moved_len before calling ext4_move_extents()
++  * ext4: move_extent_per_page() cleanup
++  * jbd2: Add ENOMEM checking in and for
++    jbd2_journal_write_metadata_buffer()
++  * ext4: Return the PTR_ERR of the correct pointer in
++    setup_new_group_blocks()
++  * ext4: Avoid data / filesystem corruption when write fails to copy data
++  * ext4: wait for log to commit when umounting
++  * ext4: remove blocks from inode prealloc list on failure
++  * ext4: ext4_get_reserved_space() must return bytes instead of blocks
++  * ext4: quota macros cleanup
++  * ext4: fix incorrect block reservation on quota transfer.
++  * ext4: Wait for proper transaction commit on fsync
++  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
++  * ext4: Fix potential fiemap deadlock (mmap_sem vs. i_data_sem)
++  * Linux 2.6.32.1
++  * kbuild: generate modules.builtin
++  * (pre-stable) drm/i915: Fix sync to vblank when VGA output is turned off
++    - LP: #494461
++  * (pre-stable) drm/i915: Avoid NULL dereference with component_only
++    tv_modes
++    - LP: #494045
++
++  [ Zhao Yakui ]
++
++  * (pre-stable) acpi: Use the ARB_DISABLE for the CPU which model id is
++    less than 0x0f.
++    - LP: #481765
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 17 Dec 2009 15:41:21 +0000
++
++linux (2.6.32-8.12) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: AppArmor -- add linux/err.h for ERR_PTR
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 12 Dec 2009 10:56:16 +0000
++
++linux (2.6.32-8.11) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches
++    up"
++  * Revert "SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
++    transition."
++  * Revert "SAUCE: AppArmor: Fix refcounting bug causing leak of creds"
++  * Revert "SAUCE: AppArmor: Fix cap audit_caching preemption disabling"
++  * Revert "SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds"
++  * Revert "SAUCE: AppArmor: Fix oops after profile removal"
++  * Revert "SAUCE: AppArmor: AppArmor disallows truncate of deleted files."
++  * Revert "SAUCE: AppArmor: AppArmor fails to audit change_hat correctly"
++  * Revert "SAUCE: AppArmor: Policy load and replacement can fail to alloc
++    mem"
++  * Revert "SAUCE: AppArmor: AppArmor wrongly reports allow perms as
++    denied"
++  * Revert "SAUCE: AppArmor: Fix mediation of "deleted" paths"
++  * Revert "SAUCE: AppArmor: Fix off by 2 error in getprocattr mem
++    allocation"
++  * Revert "SAUCE: AppArmor: Set error code after structure
++    initialization."
++  * Revert "AppArmor -- fix pstrace_may_access rename"
++  * Revert "ubuntu: AppArmor security module"
++  * Revert "SAUCE: Add config option to set a default LSM"
++  * Revert "ubuntu: fsam7400 -- sw kill switch driver"
++  * Revert "[Config] fsam7400 -- enable"
++  * Revert "[Config] AUFS -- enable"
++  * Revert "ubuntu: AUFS -- aufs2-30 20090727"
++  * Revert "ubuntu: AUFS -- export various core functions -- fixes"
++  * Revert "ubuntu: AUFS -- export various core functions"
++  * Revert "[Config] ubuntu/iscsitarget -- disable"
++  * Revert "[Config] iscsitarget -- enable"
++  * Revert "ubuntu: iscsitarget -- SVN revision r214"
++  * update Vcs-Git to point to the correct repository
++    - LP: #493589
++  * update build environment overrides to lucid
++    - LP: #493589
++  * [Config] enable CONFIG_DEVTMPFS
++  * [Config] update all configs following AppArmor 2009-12-08 update
++  * SAUCE: isapnp_init: make isa PNP scans occur async
++  * [Config] fsam7400 -- enable
++  * [Config] omnibook -- enable
++  * [Config] cleanup CONFIG_AUDIT
++  * ubuntu: AUFS -- export various core functions (aufs2-base.patch)
++  * ubuntu: AUFS -- export various core functions (aufs2-standalone.patch)
++  * ubuntu: AUFS -- aufs2 20091209
++  * [Config] AUFS -- enable
++  * [Config] iscsitarget -- enable
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: KMS: cache the EDID information of the LVDS
++
++  [ Colin Watson ]
++
++  * bnx2: update d-i firmware filenames
++    - LP: #494052
++  * add cdc_ether to nic-usb-modules udeb
++    - LP: #495060
++
++  [ John Johansen ]
++
++  * ubuntu: AppArmor -- mainline 2009-10-08
++
++  [ Manoj Iyer ]
++
++  * ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M 7400
++  * ubuntu: omnibook -- support Toshiba (HP) netbooks
++  * ubuntu: iscsitarget --- version 1.4.19
++    - LP: #494693
++
++  [ Surbhi Palande ]
++
++  * SAUCE: Make populate_rootfs asynchronous
++
++  [ Tim Gardner ]
++
++  * Parallelize flavour builds and packaging
++  * [Config] Enable CONFIG_KSM
++
++  [ Upstream Kernel Changes ]
++
++  * Config option to set a default LSM
++  * LSM: Add security_path_chroot().
++  * LSM: Add security_path_chroot().
++  * LSM: Move security_path_chmod()/security_path_chown() to after
++    mutex_lock().
++  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Dec 2009 17:45:19 +0000
++
++linux (2.6.32-7.10) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable CONFIG_THUMB2_KERNEL to fix arm FTBFS
++
++ -- Andy Whitcroft <apw@canonical.com>  Sun, 06 Dec 2009 12:56:48 +0000
++
++linux (2.6.32-7.9) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: set /proc/acpi/video/*/DOS to 4 by default
++    - LP: #458982
++  * SAUCE: ensure vga16fb loads if no other driver claims the VGA device
++  * [Config] update configs following versatile switch to V7
++  * rebased to v2.6.32
++  * [Config] update configs following rebase to v2.6.32
++  * [Config] update ports configs following rebase to v2.6.32
++  * SAUCE: default ATI Radeon KMS to off until userspace catches up
++
++  [ Arjan van de Ven ]
++
++  * SAUCE: vfs: Add a trace point in the mark_inode_dirty function
++
++  [ Leann Ogasawara ]
++
++  * [SCSI] megaraid_sas: remove sysfs poll_mode_io world writeable
++    permissions
++    - CVE-2009-3939
++
++  [ Loic Minier ]
++
++  * SAUCE: select a v7 CPU for versatile
++
++  [ Takashi Iwai ]
++
++  * SAUCE: ALSA: hda - Add power on/off counter
++
++  [ Upstream changes ]
++
++  * rebased to v2.6.32
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Dec 2009 10:44:50 +0000
++
++linux (2.6.32-6.8) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] disable SSB devices for armel
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 28 Nov 2009 12:16:40 +0000
++
++linux (2.6.32-6.7) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches up"
++  * Revert "SAUCE: Dell XPS710 reboot quirk"
++  * Revert "SAUCE: Link acpi-cpufreq.o first"
++  * Revert "SAUCE: LPIA  Logical reset of USB port on resume"
++  * Revert "SAUCE: LPIA Reboot fix for Intel Crownbeach development boards"
++  * Revert "SAUCE: Enable HDMI audio codec on Studio XPS 1340"
++  * Revert "SAUCE: Dell laptop digital mic does not work, PCI 1028:0271"
++  * Revert "Add Dell Dimension 9200 reboot quirk"
++  * Revert "SAUCE: Correctly blacklist Thinkpad r40e in ACPI"
++  * Revert "SAUCE: tulip: Define ULI PCI ID's"
++  * Revert "SAUCE: Lower warning level of some PCI messages"
++  * Revert "mac80211: fix two issues in debugfs"
++    Drop a number of known redundant commits as identified in the Ubuntu
++    delta review blueprint.
++
++  * reenable armel versatile flavour
++  * [Config] disable CONFIG_USB_DEVICEFS
++
++  [ Tim Gardner ]
++
++  * [Config] udeb: Add squashfs to fs-core-modules
++    - LP: #352615
++  * [Config] Create a real squashfs udeb
++    - LP: #352615
++
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Nov 2009 17:31:16 +0000
++
++linux (2.6.32-5.6) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc8
++  * update configs following rebase to v2.6.32-rc8
++  * update ports configs since rebase to v2.6.32-rc8
++  * [Config] enable cgroup options
++    - LP: #480739
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Nov 2009 11:16:14 +0000
++
++linux (2.6.32-4.5) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
++  * rebase to v2.6.32-rc7
++  * resync with Karmic proposed
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Fix oops after profile removal
++    - LP: #475619
++  * SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds
++    - LP: #437258
++  * SAUCE: AppArmor: Fix cap audit_caching preemption disabling
++    - LP: #479102
++  * SAUCE: AppArmor: Fix refcounting bug causing leak of creds
++    - LP: #479115
++  * SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
++    transition.
++    - LP: #480112
++
++  [ Ubuntu Changes ]
++
++  * resync with Karmic proposed (ddbc670a86a3dee18541a3734149f250ff307adf)
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 13 Nov 2009 11:35:13 +0000
++
++linux (2.6.32-3.4) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
++  * [Upstream] add local prefix to oss local change_bits
++
++  [ Upstream Kernel Changes ]
++
++  * mtd/maps: gpio-addr-flash: pull in linux/ headers rather than asm/
++  * mtd/maps: gpio-addr-flash: depend on GPIO arch support
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 11 Nov 2009 14:47:04 +0000
++
++linux (2.6.32-3.3) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc6
++  * [Config] update configs following rebase to v2.6.32-rc6
++  * [Config] update ports configs following rebase to v2.6.32-rc6
++  * resync with Karmic Ubuntu-2.6.31-15.49
++  * [Config] add module ignores for broken drivers
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: AppArmor wrongly reports allow perms as denied
++    - LP: #453335
++  * SAUCE: AppArmor: Policy load and replacement can fail to alloc mem
++    - LP: #458299
++  * SAUCE: AppArmor: AppArmor fails to audit change_hat correctly
++    - LP: #462824
++  * SAUCE: AppArmor: AppArmor disallows truncate of deleted files.
++    - LP: #451375
++
++  [ Kees Cook ]
++
++  * SAUCE: Fix nx_enable reporting
++    - LP: #454285
++
++  [ Scott James Remnant ]
++
++  * Revert "SAUCE: trace: add trace_event for the open() syscall"
++  * SAUCE: trace: add trace events for open(), exec() and uselib()
++    - LP: #462111
++
++  [ Stefan Bader ]
++
++  * SAUCE: Fix sub-flavour script to not stop on missing directories
++    - LP: #453073
++
++  [ Ubuntu Changes ]
++
++  * resync with Karmic Ubuntu-2.6.31-15.49
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc6
++    - LP: #464552
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 10 Nov 2009 15:00:57 +0000
++
++linux (2.6.32-2.2) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * install the full changelog with the binary package
++  * changelog -- explicitly note rebases and clean history
++  * reinstate armel.mk with no flavours
++    - LP: #449637
++  * [Upstream] block: silently error unsupported empty barriers too
++    - LP: #420423
++  * [Config] udate configs following karmic resync
++  * [Config] update ports configs following karmic resync
++  * [Upstream] lirc -- follow removal of .id element
++
++  [ Colin Watson ]
++
++  * Use section 'admin' rather than 'base'
++  * Add more e100 firmware to nic-modules
++    - LP: #451872
++  * Add qla1280 firmware to scsi-modules
++    - LP: #381037
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Set error code after structure initialization.
++    - LP: #427948
++  * SAUCE: AppArmor: Fix off by 2 error in getprocattr mem allocation
++    - LP: #446595
++  * SAUCE: AppArmor: Fix mediation of "deleted" paths
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] fix report of cs-limit nx-emulation
++    - LP: #454285
++
++  [ Leann Ogasawara ]
++
++  * SAUCE: (drop after 2.6.31) input: Add support for filtering input
++    events
++    - LP: #430809
++  * SAUCE: (drop after 2.6.31) dell-laptop: Trigger rfkill updates on wifi
++    toggle switch press
++    - LP: #430809
++
++  [ Luke Yelavich ]
++
++  * SAUCE: Add sr_mod to the scsi-modules udeb for powerpc
++  * [Config] Add sd_mod to scsi-modules udeb for powerpc
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Update to LIRC 0.8.6
++    - LP: #432678
++  * SAUCE: dell-laptop: Store the HW switch status internally rather than
++    requerying every time
++    - LP: #430809
++  * SAUCE: dell-laptop: Blacklist machines not supporting dell-laptop
++    - LP: #430809
++
++  [ Stefan Bader ]
++
++  * [Upstream] acerhdf: Limit modalias matching to supported boards
++    - LP: #435958
++
++  [ Tim Gardner ]
++
++  * [Upstream] i915: Fix i2c init message
++    - LP: #409361
++  * [Config] Add sym53c8xx.ko to virtual sub-flavour
++    - LP: #439415
++  * [Config] Add d101m_ucode.bin to d-i/firmware/nic-modules
++    - LP: #439456
++  * [Config] Set default I/O scheduler back to CFQ for desktop flavours
++    - LP: #381300
++  * SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros
++    - LP: #430694
++  * SAUCE: Use MODULE_IMPORT macro to tie intel_agp to i915
++    - LP: #430694
++  * [Config] CONFIG_GFS2_FS_LOCKING_DLM=y
++    - LP: #416325
++  * SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT
++    - LP: #430694
++  * SAUCE: Raise the default console 'quiet' level to 2
++  * [Config] CONFIG_X86_PAT=y
++  * [Config] Add armel arch to linux-libc-dev arches.
++    - LP: #449637
++  * [Config] CONFIG_X86_MCE
++  * [Upstream] (drop after 2.6.31) Input: synaptics - add another Protege
++    M300 to rate blacklist
++    - LP: #433801
++
++  [ Upstream Kernel Changes ]
++
++  * sgi-gru: Fix kernel stack buffer overrun, CVE-2009-2584
++  * drm/i915: Fix FDI M/N setting according with correct color depth
++    - LP: #416792
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 22 Oct 2009 16:53:33 +0100
++
++linux (2.6.32-1.1) lucid; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.32-rc3
++  * [Config] update configs following rebase to 2.6.32-rc3
++  * [Config] update ports configs following rebase to 2.6.32-rc3
++  * AppArmor -- fix pstrace_may_access rename
++  * staging/android -- disable
++  * ubuntu: dm-raid-45 -- update to compile with 2.6.32
++  * ubuntu: drbd -- disable
++  * staging/comdi -- disable
++  * staging/go7007 -- disable
++  * [Config] staging/winbond -- disable
++  * [Config] ubuntu/iscsitarget -- disable
++  * [d-i] cbc and ecb are builtin make them optional in udebs
++  * rebase to v2.6.32-rc5
++  * [Config] update configs following rebase to v2.6.32-rc5
++  * [Config] update ports configs following rebase to v2.6.31-rc5
++
++  [ Tim Gardner ]
++
++  * [Config] Add cpio as a build dependency.
++
++  [ Upstream Kernel Changes ]
++
++  * rebase to v2.6.32-rc3
++  * rebase to v2.6.32-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 05 Oct 2009 15:48:58 +0100
++
++linux (2.6.31-11.37) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Increase kernel log buffer to 256K for amd64 flavours
++    - LP: #424810
++  * [Config] Set HZ=100 for amd64 flavours
++    - LP: #438234
++  * [Upstream] e1000e: Emit notice instead of an error when
++    pci_enable_pcie_error_reporting() fails
++    - LP: #436370
++
++  [ Upstream Kernel Changes ]
++
++  * n_tty: honor opost flag for echoes
++  * n_tty: move echoctl check and clean up logic
++    - LP: #438310
++
++  * Revert "[Upstream] drm/i915: Check that the relocation points to within
++    the target" - Use upstream cherry-pick.
++  * drm/i915: Check that the relocation points to within the target
++    - LP: #429241
++
++  * drm/i915: fix tiling on IGDNG
++  * drm/i915: add B43 chipset support
++  * agp/intel: Add B43 chipset support
++    Intel request from kernel team mailing list.
++
++  * HID: completely remove apple mightymouse from blacklist
++    - LP: #428111
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Sep 2009 11:47:29 -0600
++
++linux (2.6.31-11.36) karmic; urgency=low
++
++  [ Brian Rogers ]
++
++  * SAUCE: (drop after 2.6.31) em28xx: ir-kbd-i2c init data needs a
++    persistent object
++  * SAUCE: (drop after 2.6.31) saa7134: ir-kbd-i2c init data needs a
++    persistent object
++
++  [ Takashi Iwai ]
++
++  * [Upstream] ALSA: hda - Add another entry for Nvidia HDMI device
++    - LP: #416482
++
++  [ Tyler Hicks ]
++
++  * SAUCE: (drop after 2.6.31) eCryptfs: Prevent lower dentry from going
++    negative during unlink
++
++  [ Upstream Kernel Changes ]
++
++  * sg: fix oops in the error path in sg_build_indirect()
++  * mpt2sas : Rescan topology from Interrupt context instead of work thread
++  * mpt2sas: Prevent sending command to FW while Host Reset
++  * mpt2sas: setting SDEV into RUNNING state from Interrupt context
++  * mpt2sas: Raid 10 Volume is showing as Raid 1E in dmesg
++  * SCSI: fix oops during scsi scanning
++  * SCSI: libsrp: fix memory leak in srp_ring_free()
++  * cfg80211: fix looping soft lockup in find_ie()
++  * ath5k: write PCU registers on initial reset
++  * binfmt_elf: fix PT_INTERP bss handling
++  * TPM: Fixup boot probe timeout for tpm_tis driver
++  * md: Fix "strchr" [drivers/md/dm-log-userspace.ko] undefined!
++  * x86/amd-iommu: fix broken check in amd_iommu_flush_all_devices
++  * fix undefined reference to user_shm_unlock
++  * perf_counter: Fix buffer overflow in perf_copy_attr()
++  * perf_counter: Start counting time enabled when group leader gets
++    enabled
++  * powerpc/perf_counters: Reduce stack usage of power_check_constraints
++  * powerpc: Fix bug where perf_counters breaks oprofile
++  * powerpc/ps3: Workaround for flash memory I/O error
++  * block: don't assume device has a request list backing in nr_requests
++    store
++  * agp/intel: remove restore in resume
++  * ALSA: cs46xx - Fix minimum period size
++  * ASoC: Fix WM835x Out4 capture enumeration
++  * sound: oxygen: work around MCE when changing volume
++  * mlx4_core: Allocate and map sufficient ICM memory for EQ context
++  * perf stat: Change noise calculation to use stddev
++  * x86: Fix x86_model test in es7000_apic_is_cluster()
++  * x86/i386: Make sure stack-protector segment base is cache aligned
++  * PCI: apply nv_msi_ht_cap_quirk on resume too
++  * x86, pat: Fix cacheflush address in change_page_attr_set_clr()
++  * ARM: 5691/1: fix cache aliasing issues between kmap() and kmap_atomic()
++    with highmem
++  * KVM guest: do not batch pte updates from interrupt context
++  * KVM: Fix coalesced interrupt reporting in IOAPIC
++  * KVM: VMX: Check cpl before emulating debug register access
++  * KVM guest: fix bogus wallclock physical address calculation
++  * KVM: x86: Disallow hypercalls for guest callers in rings > 0
++  * KVM: VMX: Fix cr8 exiting control clobbering by EPT
++  * KVM: x86 emulator: Implement zero-extended immediate decoding
++  * KVM: MMU: make __kvm_mmu_free_some_pages handle empty list
++  * KVM: x86 emulator: fix jmp far decoding (opcode 0xea)
++  * KVM: limit lapic periodic timer frequency
++  * libata: fix off-by-one error in ata_tf_read_block()
++  * PCI quirk: update 82576 device ids in SR-IOV quirks list
++  * PCI: Unhide the SMBus on the Compaq Evo D510 USDT
++  * powerpc/pseries: Fix to handle slb resize across migration
++  * Linux 2.6.31.1
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Sep 2009 13:04:28 -0600
++
++linux (2.6.31-10.35) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Disable CONFIG_UEVENT_HELPER_PATH
++
++  [ Andy Whitcroft ]
++
++  * [Config] Enable CONFIG_USB_GADGET_DUMMY_HCD
++  * remove the tlsup driver
++  * remove lmpcm logitech driver support
++
++  [ Bryan Wu ]
++
++  * Add 3 missing files to prerm remove file list
++    - LP: #345623, #415832
++
++  [ Chris Wilson ]
++
++  * [Upstream] drm/i915: Check that the relocation points to within the
++    target
++    - LP: #429241
++
++  [ Luke Yelavich ]
++
++  * [Config] Set CONFIG_EXT4_FS=y on ports architectures
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
++    - LP: #348861
++
++  [ Tim Gardner ]
++
++  * Revert "[Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux) white-list"
++  * Revert "[Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux) white-list"
++    Upstream suggests that this is not the right approach.
++
++  * [Config] Set default I/O scheduler to DEADLINE
++    CFQ seems to have some load related problems which are often exacerbated by sreadahead.
++    - LP: #381300
++
++  [ ubuntu@tjworld.net ]
++
++  * SAUCE: ipw2200: Enable LED by default
++    - LP: #21367
++
++  [ Upstream Kernel Changes ]
++
++  * ALSA: hda - Add support for new AMD HD audio devices
++    - LP: #430564
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 16 Sep 2009 15:37:49 +0100
++
++linux (2.6.31-10.34) karmic; urgency=low
++
++  [ Ted Tso ]
++
++  * [Upstream] ext3: Don't update superblock write time when filesystem is
++    read-only
++    - LP: #427822
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 16:00:45 -0600
++
++linux (2.6.31-10.33) karmic; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] dvb-usb: fix tuning with Cinergy T2
++    - LP: #421258
++
++  [ Tim Gardner ]
++
++  * [Config] Unconditionally copy files from sub-flavours lists.
++    (really, really fix it this time)
++    - LP: #423426
++  * [Config] Set CONFIG_CACHEFILES=m for all flavours
++
++  [ Upstream Kernel Changes ]
++
++  * ext4: Don't update superblock write time when filesystem is read-only
++    - LP: #427822
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 07:50:21 -0600
++
++linux (2.6.31-10.32) karmic; urgency=low
++
++  [ Eric Miao ]
++
++  * [Config] enable module support for memory stick
++    - LP: #159951
++
++  [ Tim Gardner ]
++
++  * [Config] Unconditionally copy files from sub-flavours lists.
++    - LP: #423426
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Sep 2009 15:57:55 -0600
++
++linux (2.6.31-10.31) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.31 final
++
++  [ Colin Watson ]
++
++  * [Config] Recommend grub-pc in linux-image
++    - LP: #385741
++
++  [ Ike Panhc ]
++
++  * [Upstream] Pull latest update of lenovo-sl-laptop
++
++  [ Peter Feuerer ]
++
++  * [Upstream] (drop after 2.6.31) acerhdf: fix fan control for AOA150
++    model
++    - LP: #426691
++
++  [ Tim Gardner ]
++
++  * [Config] De-macro some package names.
++
++  [ Upstream Changes ]
++
++  * rebase to 2.6.31 final.
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 10 Sep 2009 09:38:10 +0100
++
++linux (2.6.31-10.30) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] Enable CONFIG_USB_DEVICEFS
++    - LP: #417748
++  * [Config] Populate the config-update template a bit more
++
++  [ Andy Whitcroft ]
++
++  * rebase to v2.6.31-rc9
++  * [Config] update configs following rebase to v2.6.31-rc9
++  * [Config] update ports configs following rebase to v2.6.31-rc9
++
++  [ Colin Ian King ]
++
++  * SAUCE: wireless: hostap, fix oops due to early probing interrupt
++    - LP: #254837
++
++  [ Jerone Young ]
++
++  * [Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux)
++    white-list
++    - LP: #281732
++  * [Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux)
++    white-list
++    - LP: #281732
++
++  [ John Johansen ]
++
++  * SAUCE: AppArmor: Fix profile attachment for regexp based profile names
++    - LP: #419308
++  * SAUCE: AppArmor: Return the correct error codes on profile
++    addition/removal
++    - LP: #408473
++  * SAUCE: AppArmor: Fix OOPS in profile listing, and display full list
++    - LP: #408454
++  * SAUCE: AppArmor: Fix mapping of pux to new internal permission format
++    - LP: #419222
++  * SAUCE: AppArmor: Fix change_profile failure
++    - LP: #401931
++  * SAUCE: AppArmor: Tell git to ignore generated include files
++    - LP: #419505
++
++  [ Stefan Bader ]
++
++  * [Upstream] acpi: video: Loosen strictness of video bus detection code
++    - LP: #333386
++  * SAUCE: Remove ov511 driver from ubuntu subdirectory
++
++  [ Tim Gardner ]
++
++  * [Config] Exclude char-modules from non-x86 udeb creation
++  * SAUCE: Notify the ACPI call chain of AC events
++  * [Config] CONFIG_SATA_VIA=m
++    - LP: #403385
++  * [Config] Build in all phylib support modules.
++  * [Config] Don't fail when sub-flavour files are missing
++    - LP: #423426
++  * [Config] Set CONFIG_LSM_MMAP_MIN_ADDR=0
++    - LP: #423513
++
++  [ Upstream ]
++
++  * Rebased against v2.6.31-rc9
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Sep 2009 11:33:45 +0100
++
++linux (2.6.31-9.29) karmic; urgency=low
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] agp/intel: support for new chip variant of IGDNG mobile
++    - LP: #419993
++  * [Config] d-i/modules: Add new char-modules file, initialize with
++    intel-agp
++    - LP: #420605
++
++  [ Upstream ]
++
++  * Rebased against 2.6.31-rc8 plus some inotify regression patches:
++    up through git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6.git
++    adda766193ea1cf3137484a9521972d080d0b7af.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 28 Aug 2009 06:31:30 -0600
++
++linux (2.6.31-8.28) karmic; urgency=low
++
++  [ Ike Panhc ]
++
++  * [Config] Let nic-shared-modules depends on crypto-modules
++    - LP: #360966
++
++  [ Leann Ogasawara ]
++
++  * [Upstream] (drop after 2.6.31) drm/i915: increase default latency
++    constant
++    - LP: #412492
++
++  [ Mario Limonciello ]
++
++  * [Upstream]: (drop after 2.6.31) dell-laptop: don't change softblock
++    status if HW switch is disabled
++    - LP: #418721
++  * [Upstream]: (drop after 2.6.31) compal-laptop: Add support for known
++    Compal made Dell laptops
++  * [Upstream]: (drop after 2.6.31) compal-laptop: Replace sysfs support
++    with rfkill support
++
++  [ Tim Gardner ]
++
++  * [Config] Add acpiphp to virtual sub-flavour
++    - LP: #364916
++  * Drop KSM patch set for now because of instabilities with encrypted swap.
++    - LP: #418781
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2009 08:14:26 -0600
++
++linux (2.6.31-7.27) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] updateconfigs updateportsconfigs after 2.6.31-rc7 rebase
++  * SAUCE: (drop after 2.6.31) Added KSM from mmotm-2009-08-20-19-18
++    Replaces previous ksm patches from 2.6.31-6.25
++  * [Config] KSM=y
++
++  [ Upstream ]
++
++  * Rebased against v2.6.31-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Aug 2009 20:32:11 -0600
++
++linux (2.6.31-6.26) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] enable CONFIG_AUFS_BR_RAMFS
++    - LP: #414738
++  * split out debian directory ready for abstraction
++  * add printdebian target to find branch target
++  * abstracted debian -- debian/files is not abstracted
++  * abstracted debian -- packages must be built in debian/<pkg>
++  * abstracted debian -- kernel-wedge needs to work in debian/
++  * abstracted debian -- ensure we install the copyright file
++  * abstracted-debian -- drop the debian directories from headers
++  * abstracted-debian -- drop the debian directories from headers part 2
++  * SAUCE: ubuntu-insert-changes -- follow abstracted debian
++  * [Upstream] aoe: ensure we initialise the request_queue correctly V2
++    - LP: #410198
++
++  [ Luke Yelavich ]
++
++  * [Config] Ports: Disable CONFIG_CPU_FREQ_DEBUG on powerpc-smp
++  * [Config] Ports: Re-enable windfarm modules on powerpc64-smp
++    - LP: #413150
++  * [Config] Ports: Build all cpu frequency scaling governors into ports
++    kernels
++  * [Config] Ports: Build ext2 and ext3 modules into ports kernels
++  * [Config] Ports: CONFIG_PACKET=y for all ports kernels
++  * [Config] Ports: Enable PS3 network driver
++
++  [ Stefan Bader ]
++
++  * abstracted debian -- call $(DEBIAN)/rules using make
++
++  [ Tim Gardner ]
++
++  * [Config] Abstract the debian directory
++  * SAUCE: Improve error reporting in postinst
++    - LP: #358564
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 16 Aug 2009 20:33:28 -0600
++
++linux (2.6.31-6.25) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * script to generate Ubuntu changes from changelog
++  * [Config] standardise ANDROID options
++  * [Config] standardise CONFIG_ATM as module
++  * [Config] standardise CONFIG_LIB80211 as module
++  * [Config] disable CONFIG_PRINT_QUOTA_WARNING
++  * [Config] set CONFIG_CRAMFS as module
++  * [Config] enable CONFIG_DAB and modules
++  * [Config] set CONFIG_MAC80211_HWSIM as module
++  * [Config] set CONFIG_NET_CLS_FLOW as module
++  * [Config] set CONFIG_NF_CONNTRACK_SANE as module
++  * [Config] set CONFIG_NF_CT_PROTO_DCCP as module
++  * [Config] set CONFIG_RTC_DRV_DS1511 as module
++  * [Config] set CONFIG_RTC_DRV_R9701 as module
++  * [Config] set CONFIG_RTC_DRV_S35390A as module
++  * [Config] set CONFIG_TOIM3232_DONGLE as module
++  * [Config] standardise CONFIG_USB_MIDI_GADGET as module
++  * [Config] standardise CONFIG_USB_G_PRINTER as module
++  * [Config] standardise CONFIG_USB_SERIAL_IR as module
++  * [Config] set CONFIG_USB_SERIAL_IUU as module
++  * [Config] standardise CONFIG_USB_STORAGE_CYPRESS_ATACB as module
++  * [Config] standardise CONFIG_USB_STORAGE_ONETOUCH as module
++  * cleanup remains of dm-loop
++  * drop thinkpad ec and smapi support
++  * drop appleir
++  * [Config] update configs following rebase to v2.6.31-rc6
++  * rebase to v2.6.31-rc6
++
++  [ Hugh Dickins ]
++
++  * SAUCE: ksm patch 1, drop after 2.6.31
++  * SAUCE: ksm patch 2, drop after 2.6.31
++  * SAUCE: ksm patch 3, drop after 2.6.31
++  * SAUCE: ksm patch 4, drop after 2.6.31
++  * SAUCE: ksm patch 5, drop after 2.6.31
++  * SAUCE: ksm patch 7, drop after 2.6.31
++
++  [ Izik Eidus ]
++
++  * SAUCE: ksm patch 0, drop after 2.6.31
++  * SAUCE: ksm patch 6, drop after 2.6.31
++  * SAUCE: ksm patch 8, drop after 2.6.31
++  * SAUCE: ksm patch 9, drop after 2.6.31
++
++  [ Luke Yelavich ]
++
++  * [Config] Ports: Re-add PS3 modules to udebs
++
++  [ Michael Casadevall ]
++
++  * [Config] Update SPARC config and d-i files to reflect what can be built
++
++  [ Tim Gardner ]
++
++  * [Config] Removed armel package support
++  * [Config] Enabled CONFIG_KSM=y
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased against v2.6.31-rc6
++  * ARM: Cleanup: Revert "ARM: Add more cache memory types macros"
++  * ARM: Cleanup: Revert "Do not use OOB with MLC NAND"
++  * ARM: Cleanup: Revert "ARM: Make ARM arch aware of ubuntu/ drivers"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make video capture drivers compile"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix isl29003 HWMON driver for i2c
++    changes"
++  * ARM: Cleanup: Revert "ARM: IMX51: IPU irq handler deadlock fix"
++  * ARM: Cleanup: Revert "ARM: IMX51: Babbage 2.5 needs a different system
++    revision"
++  * ARM: Cleanup: Revert "ARM: IMX51: Compile-in the IMX51 cpufreq driver
++    by default"
++  * ARM: Cleanup: Revert "ARM: IMX51: Enable ZONE_DMA for ARCH_MXC"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make ARCH_MXC auto-enable
++    ARCH_MXC_CANONICAL"
++  * ARM: Cleanup: Revert "ARM: IMX51: Unconditionally disable
++    CONFIG_GPIOLIB"
++  * ARM: Cleanup: Revert "ARM: IMX51: Minimal changes for USB to work on
++    2.6.31"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix plat-mxc/timer.c to handle imx51"
++  * ARM: Cleanup: Revert "ARM: IMX51: Make it compile."
++  * ARM: Cleanup: Revert "ARM: IMX51: Clean-up the craziness of including
++    mxc_uart.h _everywhere_"
++  * ARM: Cleanup: Revert "ARM: IMX51: Move board-mx51* header files to the
++    correct location"
++  * ARM: Cleanup: Revert "ARM: IMX51: Changed from snd_card_new to
++    snd_card_create"
++  * ARM: Cleanup: Revert "ARM: IMX51: Fix up merge error in Kconfig"
++  * ARM: Cleanup: Revert "ARM: IMX51: mxc_timer_init prototype"
++  * ARM: Cleanup: Revert "ARM: IMX51: Removed the mxc_gpio_port structure."
++  * ARM: Cleanup: Revert "ARM: IMX51: Added external declaration for
++    mxc_map_io."
++  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
++  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
++  * ARM: Cleanup: Revert "ARM: IMX51: snd_soc_machine structure replaced
++    with snd_soc_card."
++  * ARM: Cleanup: Revert "ARM: IMX51: codec structure was moved to the card
++    structure"
++  * ARM: Cleanup: Revert "ARM: IMX51: Hack to add defines for
++    DMA_MODE_READ/WRITE/MASK"
++  * ARM: Cleanup: Revert "ARM: IMX51: Add SoC and board support for
++    Freescale mx51 platform"
++  * Driver core: add new device to bus's list before probing
++  * [Upstream] (drop after 2.6.31) ALSA: hda - Reduce click noise at
++    power-saving
++    - LP: #381693, #399750, #380892
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 14 Aug 2009 11:32:23 +0100
++
++linux (2.6.31-5.24) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM: IMX51: Make video capture drivers compile
++  * [Config] IMX51: Config updates
++
++  [ Andy Whitcroft ]
++
++  * remove leftovers of dm-bbr
++
++  [ Leann Ogasawara ]
++
++  * Add pata_cs5535 to pata-modules
++    - LP: #318805
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_PPC64=y for powerpc64-smp
++  * [Config] Set the maximum number of CPUs to 1024 for powerpc64-smp
++  * [Config] CONFIG_PPC_PS3=y for powerpc64-smp
++  * [Config] CONFIG_PPC_MAPLE=y on powerpc64-smp
++  * [Config] CONFIG_PPC_PASEMI=y on powerpc64-smp
++  * [Config] CONFIG_CPU_FREQ_PMAC64=y on powerpc64-smp
++  * [Config] Enable all PS3 drivers in powerpc64-smp
++
++  [ Mario Limonciello ]
++
++  * LIRC -- fix lirc-i2c 2.6.31 compilation
++
++  [ Matthew Garrett ]
++
++  * [Upstream] dell-laptop: Fix rfkill state queries
++
++  [ Tim Gardner ]
++
++  * [Config] Ignore armel ABI and module changes
++  * [Config] Update configs after rebase against 2.6.31-rc5
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc5
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2009 10:10:09 +0100
++
++linux (2.6.31-4.23) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * AUFS -- update to aufs2-30 20090727
++  * [Config] enable AUFS FUSE support
++
++  [ Luke Yelavich ]
++
++  * [Config] CONFIG_JFS_FS=m on sparc
++
++  [ Tim Gardner ]
++
++  * [Upstream] dell-laptop: Fix rfkill state setting.
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 27 Jul 2009 11:11:47 +0100
++
++linux (2.6.31-4.22) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM: IMX51: Add SoC and board support for Freescale mx51 platform
++  * ARM: IMX51: Move board-mx51* header files to the correct location
++  * ARM: IMX51: Clean-up the craziness of including mxc_uart.h _everywhere_
++  * ARM: IMX51: Make it compile.
++  * ARM: IMX51: Unconditionally disable CONFIG_GPIOLIB
++  * ARM: IMX51: Make ARCH_MXC auto-enable ARCH_MXC_CANONICAL
++  * ARM: IMX51: Enable ZONE_DMA for ARCH_MXC
++  * ARM: IMX51: Compile-in the IMX51 cpufreq driver by default
++  * ARM: IMX51: Fix isl29003 HWMON driver for i2c changes
++  * ARM: USB: musb: Refer to musb_otg_timer_func under correct #ifdef
++  * ARM: staging: udlfb: Add vmalloc.h include
++  * UBUNTU [Config]: Bring imx51 config upto date with other flavours
++
++  [ Brad Figg ]
++
++  * ARM: IMX51: Hack to add defines for DMA_MODE_READ/WRITE/MASK
++  * ARM: IMX51: codec structure was moved to the card structure
++  * ARM: IMX51: snd_soc_machine structure replaced with snd_soc_card.
++  * ARM: IMX51: Get to bus_id by calling dev_name.
++  * ARM: IMX51: Get to bus_id by calling dev_name.
++  * ARM: IMX51: Added external declaration for mxc_map_io.
++  * ARM: IMX51: Removed the mxc_gpio_port structure.
++  * ARM: IMX51: mxc_timer_init prototype
++  * ARM: IMX51: Fix up merge error in Kconfig
++  * ARM: IMX51: Changed from snd_card_new to snd_card_create
++
++  [ Dinh Nguyen ]
++
++  * ARM: IMX51: Fix plat-mxc/timer.c to handle imx51
++  * ARM: IMX51: Minimal changes for USB to work on 2.6.31
++  * ARM: IMX51: Babbage 2.5 needs a different system revision
++  * ARM: IMX51: IPU irq handler deadlock fix
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CONFIG_CAN=m
++    - LP: #327243
++  * [Config] Enabled CONFIG_SERIAL=m
++    - LP: #397189
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 24 Jul 2009 06:19:10 -0600
++
++linux (2.6.31-4.21) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * dm-raid-4-5: Add missing brackets around test_bit()
++
++  [ John Johansen ]
++
++  * AppArmor: Fix change_profile failing lpn401931
++  * AppArmor: Fix determination of forced AUDIT messages.
++  * AppArmor: Fix oops in auditing of the policy interface offset
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 19:18:30 +0100
++
++linux (2.6.31-4.20) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: iscsitarget -- update to SVN revision r214
++  * SAUCE: iscsitarget -- renable driver
++  * [Config] consolidate lpia/lpia and i386/generic configs
++  * [Config] enable CRYPTO modules for all architectures
++  * [Config] enable cryptoloop
++  * [Config] enable various filesystems for armel
++  * [Config] sync i386 generic and generic-pae
++  * [Config] add the 386 (486 processors and above) flavour
++  * [Config] re-set DEFAULT_MMAP_MIN_ADDR
++    - LP: #399914
++  * add genconfigs/genportsconfigs to extract the built configs
++  * updateconfigs -- alter concatenation order allow easier updates
++  * intelfb -- INTELFB now conflicts with DRM_I915
++  * printchanges -- rebase tree does not have stable tags use changelog
++  * AppArmor: fix argument size missmatch on 64 bit builds
++
++  [ Ike Panhc ]
++
++  * Ship bnx2x firmware in nic-modules udeb
++    - LP: #360966
++
++  [ Jeff Mahoney ]
++
++  * AppArmor: fix build failure on ia64
++
++  [ John Johansen ]
++
++  * AppArmour: ensure apparmor enabled parmater is off if AppArmor fails to
++    initialize.
++  * AppArmour: fix auditing of domain transitions to include target profile
++    information
++  * AppArmor: fix C99 violation
++  * AppArmor: revert reporting of create to write permission.
++  * SAUCE: Add config option to set a default LSM
++  * [Config] enable AppArmor by default
++  * AppArmor: Fix NULL pointer dereference oops in profile attachment.
++
++  [ Keith Packard ]
++
++  * SAUCE: drm/i915: Allow frame buffers up to 4096x4096 on 915/945 class
++    hardware
++    - LP: #351756
++
++  [ Luke Yelavich ]
++
++  * [Config] add .o files found in arch/powerpc/lib to all powerpc kernel
++    header packages
++    - LP: #355344
++
++  [ Michael Casadevall ]
++
++  * [Config] update SPARC config files to allow success build
++
++  [ Scott James Remnant ]
++
++  * SAUCE: trace: add trace_event for the open() syscall
++
++  [ Stefan Bader ]
++
++  * SAUCE: jfs: Fix early release of acl in jfs_get_acl
++    - LP: #396780
++
++  [ Tim Gardner ]
++
++  * [Upstream] Fix Soltech TA12 volume hotkeys not sending key release
++    - LP: #397499
++  * [Upstream] USB Option driver - Add USB ID for Novatel MC727/U727/USB727
++    refresh
++    - LP: #365291
++  * [Config] SSB/B44 are common across all arches/flavours.
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc4
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 08:41:39 +0100
++
++linux (2.6.31-3.19) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "[Config] Disabled NDISWRAPPER"
++  * ndiswrapper -- fix i386 compilation failures on cmpxchg8b
++  * AUFS -- export various core functions
++  * AUFS -- export various core functions -- fixes
++  * AUFS -- core filesystem
++  * AUFS -- track changes in v2.6.31
++  * [Config] Enable AUFS
++  * droppped 'iwl3945: do not send scan command if channel count zero' as it
++    is already upstream but failed to auto-drop on rebase.
++
++  [ Eric Paris ]
++
++  * SAUCE: fsnotify: use def_bool in kconfig instead of letting the user
++    choose
++  * SAUCE: inotify: check filename before dropping repeat events
++  * SAUCE: fsnotify: fix inotify tail drop check with path entries
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 14 Jul 2009 12:52:55 +0100
++
++linux (2.6.31-3.18) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "Add splice-2.6.23.patch from AUFS to export a symbol needed by
++    AUFS"
++  * Revert "Add put_filp.patch from AUFS to export a symbol needed by AUFS"
++  * Revert "Add sec_perm-2.6.24.patch from AUFS - export
++    security_inode_permission"
++  * clear out left over AUFS files and modifications
++
++  [ Luke Yelavich ]
++
++  * [Config] Enable CONFIG_USB_ISP116X_HCD on sparc
++  * SAUCE: Explicitly include header files to allow apparmor to build on
++    powerpc
++  * [Config] Enable CONFIG_BLK_DEV_IDECD on powerpc
++
++  [ Tim Gardner ]
++
++  * [Config] Dropped ubuntu/misc/wireless/acx
++  * [Config] Disabled NDISWRAPPER until the compile issues are fixed.
++
++  [ Upstream ]
++
++  * Rebased to 2.6.31-rc3
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 18:59:33 +0100
++
++linux (2.6.31-2.17) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_BLK_DEV_CRYPTOLOOP=m for sparc
++  * compcache -- remove redundant Kconfig entries part 2
++  * compcache -- clean up CCFLAGS declarations
++  * [Config] enable AppArmor
++  * AppArmor: fix operator precidence issue in as_path_link
++
++  [ John Johansen ]
++
++  * AppArmor security module
++  * AppArmor: Correct mapping of file permissions.
++  * AppArmor: Turn auditing of ptrace on
++
++  [ Luke Yelavich ]
++
++  * [Config] disable CONFIG_DM_RAID45 on powerpc
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 15:02:05 +0100
++
++linux (2.6.31-2.16) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * compcache -- remove redundant Kconfig entries
++    added ignore and ignore.modules for all arches since the compcache update
++    changes the modules names as well as some compcache ABI values.
++
++  [ Manoj Iyer ]
++
++  * SAUCE: updated dm-raid45 module version to 2009.04.24 (2.6.30-rc3)
++  * SAUCE: update compcache version to 0.5.3
++
++  [ Tim Gardner ]
++
++  * [Config]: Fix sparc FTBS by adding ignore.modules
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 06 Jul 2009 13:35:29 -0600
++
++linux (2.6.31-2.15) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: default ATI Radeon KMS to off until userspace catches up
++  * [Config] Update configs following rebase to 2.6.31-rc2
++  * [Config] update ports configs following update to 2.6.31-rc2
++
++  [ Luke Yelavich ]
++
++  * [Config] powerpc - Disable CONFIG_RDS
++
++  [ Matt Zimmerman ]
++
++  * Rename linux-doc-PKGVER to linux-doc and clean up its description
++    - LP: #382115
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to mainline 2.6.31-rc2
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 04 Jul 2009 17:39:13 +0100
++
++linux (2.6.31-1.14) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update ndiswrapper to 1.55
++  * remove leftovers of gfs
++  * [Config] powerpc: enable CONFIG_PPC_DISABLE_WERROR
++
++  [ Luke Yelavich ]
++
++  * [Config] re-enable and build the ide-pmac driver into powerpc kernels
++  * [Config] Build the ServerWorks Frodo / Apple K2 SATA driver into the
++    kernel
++
++  [ Manoj Iyer ]
++
++  * Remove snd-bt-sco ubuntu driver
++
++  [ Michael Casadevall ]
++
++  * [Config] updates ia64 config and d-i folders to allow succesful build
++  * [Config] Update powerpc and sparc for 2.6.31
++
++  [ Upstream Kernel Changes ]
++
++  * intel-iommu: fix Identity Mapping to be arch independent
++    - LP: #384695
++  * ACPI: video: prevent NULL deref in acpi_get_pci_dev()
++
++ -- Andy Whitcroft <apw@canonical.com>  Tue, 30 Jun 2009 17:47:32 +0100
++
++linux (2.6.31-1.13) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * REBASE: rebased to mainline 2.6.31-rc1
++    - "UBUNTU: SAUCE: UHCI USB quirk for resume"
++      no longer applies, using deprecated interfaces, LPIA only, dropped
++    - "UBUNTU: SAUCE: Mask off garbage in Dell WMI scan code data"
++      changes now upstream, dropped
++  * [Config] Update configs following rebase to 2.6.31-rc1
++  * [Config] update ports configs following update to 2.6.31-rc1
++
++  * [Config] disable broken staging driver CONFIG_STLC45XX
++  * SAUCE: fix compcache to use updates accessors
++  * [Config] disable staging driver CONFIG_VT6655
++  * SAUCE: fix DRDB to use updates accessors
++  * [Disable] ndiswrapper needs update
++  * [Disable] LIRC I2C needs update
++  * [Disable] CONFIG_LENOVO_SL_LAPTOP needs update
++  * [Config] disable I2C_DESIGNWARE does not compile
++  * [Config] disable CONFIG_TLSUP for lpia
++  * [Config] disable CONFIG_FB_UDL for arm
++  * SAUCE: disable adding scsi headers to linux-libc-dev
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Add LIRC drivers
++
++ -- Andy Whitcroft <apw@canonical.com>  Thu, 25 Jun 2009 12:06:22 +0100
++
++linux (2.6.30-10.12) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] split out the ports configs into their own family
++  * [Config] update configs following introduction of ports family
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Rename linux-doc-PKGVER to linux-doc and clean up its
++    description". Fixes linux-doc package name conflicts for now.
++    - LP: #382115
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 22 Jun 2009 09:17:14 -0600
++
++linux (2.6.30-10.11) karmic; urgency=low
++
++  [ Amit Kucheria ]
++
++  * [Config] Comment splitconfig.pl and misc cleanup
++  * [Config] Rename all configs to the new naming scheme
++  * [Config] Splitconfig rework
++  * [Config] Rename scripts/misc/oldconfig to kernelconfig
++  * [Config] Fix build system for new config split
++  * [Config] Run updateconfigs after the splitconfig rework
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: Default to i915.modeset=0 if CONFIG_DRM_I915_KMS=y"
++  * [Config] standardise CONFIG_STAGING=y
++  * [Config] standardise CONFIG_RD_LZMA=y
++  * [Config] CONFIG_PCI_IOV=y
++  * [Config] CONFIG_PCI_STUB=m
++  * [Config] merge kernel configs more agressively
++
++  [ Colin Watson ]
++
++  * [Config] Run kernel-wedge in $(builddir) rather than at the top level
++  * [Config] Add support for including firmware in udebs
++  * [Config] Ship bnx2 firmware in nic-modules udeb
++    - LP: #384861
++
++  [ Luke Yelavich ]
++
++  * [Config] ports - Import of ports architectures into kernel packaging
++    infrastructure
++  * [Config] ports - Do not update ports kernel configurations by default
++  * [Config] ports - Disable ABI checking for ports architectures
++  * [Config] ports - Build drivers in ubuntu sub-directory on powerpc
++  * [Config] ports - Add control.d/vars.* files for ports architectures
++  * [Config] ports - Add ports architectures for linux-libc-dev
++  * [Config] ports - Create powerpc specific message-modules and
++    block-modules udebs
++  * [Config] ports - Add configuration files for ports architectures
++
++  [ Manoj Iyer ]
++
++  * [Config] Enable CONFIG_BLK_DEV_AEC62XX=m for amd64 and i386
++    - LP: #329864
++
++  [ Michael Casadevall ]
++
++  * [Config] ports - Fix compression of kernels
++
++  [ Stefan Bader ]
++
++  * [Upstream] mmc: prevent dangling block device from accessing stale
++    queues
++    - LP: #383668
++
++  [ Tim Gardner ]
++
++  * [Config] Recommend grub-pc in linux-image
++    - LP: #385741
++  * [Config] Implement i386 generic and generic-pae flavours
++  * [Config] ports - Add control info after integrating ports arches
++  * [Config] Removed auto-generated files from git
++  * [Config] Added netxen_nic to nic-modules
++    - LP: #389603
++
++  [ Matt Zimmerman ]
++
++  * Rename linux-doc-PKGVER to linux-doc and clean up its description
++    - LP: #382115
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 15 Jun 2009 14:38:26 -0600
++
++linux (2.6.30-9.10) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * [Config] CONFIG_SECURITY_TOMOYO=y (amd64, i386, lpia)
++  * [Config] CONFIG_KEXEC_JUMP=y (amd64, lpia)
++  * [Config] CONFIG_LENOVO_SL_LAPTOP=m (amd64, lpia)
++  * [Config] CONFIG_POHMELFS_CRYPTO=y (i386, amd64)
++  * [Config] CONFIG_SERIAL_MAX3100=m (i386, amd64, lpia)
++  * [Config] CONFIG_VIDEO_GO7007=m (amd64, i386)
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30 final
++
++ -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jun 2009 11:42:53 +0100
++
++linux (2.6.30-8.9) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Config update removed the following options:
++        CONFIG_EDAC_AMD8111=m
++        CONFIG_EDAC_AMD8131=m
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc8
++
++ -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Jun 2009 09:21:13 +0100
++
++linux (2.6.30-7.8) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Enabled NEW configration options:
++      Paravirtualization layer for spinlocks (PARAVIRT_SPINLOCKS) [N/y/?] Y
++      Cisco FNIC Driver (FCOE_FNIC) [N/m/y/?] M
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc7
++
++ -- Andy Whitcroft <apw@canonical.com>  Sat, 23 May 2009 23:47:24 +0100
++
++linux (2.6.30-6.7) karmic; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Dropped: UBUNTU: SAUCE: input: Blacklist digitizers from joydev.c (now
++    upstream)
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc6
++
++ -- Andy Whitcroft <apw@canonical.com>  Mon, 18 May 2009 18:05:54 +0100
++
++linux (2.6.30-5.6) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Enable Keyspan USB serial device firmware in kernel module
++    - LP: #334285
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc5
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 May 2009 12:02:16 -0600
++
++linux (2.6.30-4.5) karmic; urgency=low
++
++  [ Colin Watson ]
++
++  * Build-Conflict with findutils (= 4.4.1-1ubuntu1), to avoid
++    /usr/include/asm/* going missing
++    - LP: #373214
++
++ -- Stefan Bader <stefan.bader@canonical.com>  Fri, 08 May 2009 11:09:08 +0200
++
++linux (2.6.30-3.4) karmic; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
++    - LP: #369978
++
++  [ Stefan Bader ]
++
++  * SAUCE: input: Blacklist digitizers from joydev.c
++    - LP: #300143
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 01 May 2009 14:00:42 -0600
++
++linux (2.6.30-2.3) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] Enabled CC_STACKPROTECTOR=y for all x86en
++    - LP: #369152
++  * SAUCE: Default to i915_modeset=0 if CONFIG_DRM_I915_KMS=y
++  * [Config] CONFIG_DRM_I915_KMS=y
++  * [Config] Set CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR to appropriate ARCH
++    minimums
++
++  [ Upstream Kernel Changes ]
++
++  * rebased to 2.6.30-rc4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Apr 2009 09:17:05 -0600
++
++linux (2.6.30-1.2) karmic; urgency=low
++
++  [ Tim Gardner ]
++
++  * [Config] armel: disable staging drivers, fixes FTBS
++  * [Config] armel imx51: Disable CONFIG_MTD_NAND_MXC, fixes FTBS
++
++  [ Upstream Kernel Changes ]
++
++  * mpt2sas: Change reset_type enum to avoid namespace collision.
++    Submitted upstream.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 Apr 2009 16:54:41 -0600
++
++linux (2.6.30-1.1) karmic; urgency=low
++
++  * Initial release after rebasing against v2.6.30-rc3
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Mar 2009 19:16:07 -0600
+diff --git a/debian.master/changelog.historical b/debian.master/changelog.historical
+new file mode 100644
+index 0000000..9e3beaf
+--- /dev/null
++++ b/debian.master/changelog.historical
+@@ -0,0 +1,4171 @@
++
++linux (2.6.28-9.31) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: cpufreq-nforce2: probe failures are not errors
++    - LP: #332170
++  * SAUCE: mmc: add MODALIAS linkage for MMC/SD devices
++    - LP: #30335
++  * remove test-suspend script
++    - LP: #333856
++
++  [ Kees Cook ]
++
++  * handle relative paths in modules.dep
++    Fixes 2.6.28-9.30 FTBS.
++
++  [ Upstream Kernel Changes ]
++
++  * ricoh_mmc: Handle newer models of Ricoh controllers
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Mar 2009 08:19:24 -0600
++
++linux (2.6.28-9.30) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * ARM:mx51 Add SoC and board support for mx51 platforms
++  * ARM:mx51 Add CONFIG_ARCH_MXC_CANONICAL to disable parts of Freescale's
++    code
++  * MMC: Add support for 8-bit cards
++  * Add ARM:MX51 SoC support to the build system
++  * ARM: Make ARM arch aware of ubuntu/ drivers
++  * ARM: Add imx51 configuration
++  * Disable d-i modules for imx51 and mv78xx0
++  * Disable Apparmor on boot for ARM
++  * Updating imx51 config
++
++  [ Jason Liu ]
++
++  * Do not use OOB with MLC NAND
++
++  [ Richard Zhu ]
++
++  * Support the eMMC4.3 card
++
++  [ Rob Herring ]
++
++  * ARM: Add more cache memory types macros
++
++  [ Tim Gardner ]
++
++  * Set CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y for i386/amd64/lpia
++
++  [ Manoj Iyer ]
++
++  * Enable CONFIG_RTL8187SE=m
++
++  [ Upstream Kernel Changes ]
++
++  * USB: EHCI: slow down ITD reuse
++    - LP: #329437
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 08 Mar 2009 14:14:15 -0600
++
++linux (2.6.28-9.29) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * link-headers -- only link directories which do not already exist
++    - LP: #315252
++
++  [ Daniel Marjamäki ]
++
++  * SAUCE: (drop after 2.6.28) netxen: fix memory leak in
++    drivers/net/netxen_nic_init.c
++    - LP: #330813
++
++  [ Dhananjay Phadke ]
++
++  * SAUCE: (drop after 2.6.28) netxen: fix endianness in firmware commands
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix ipv6 offload and tx cleanup
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix link speed reporting for some
++    boards
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: firmware init fix
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: cleanup mac list on driver unload
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: hold tx lock while sending firmware
++    commands
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: handle dma mapping failures
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: avoid invalid iounmap
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: include ipv6.h (fixes build failure)
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix vlan tso/checksum offload
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: reduce memory footprint
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: revert jumbo ringsize
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: fix msi-x interrupt handling
++    - LP: #330813
++  * SAUCE: (drop after 2.6.28) netxen: remove pcie workaround
++    - LP: #330813
++
++  [ Hannes Eder ]
++
++  * SAUCE: (drop after 2.6.28) drivers/net/netxen: fix sparse warnings: use
++    NULL pointer instead of plain integer
++    - LP: #330813
++
++  [ Huaxu Wan ]
++
++  * SAUCE: report rfkill changes event if interface is down
++    - LP: #193970
++
++  [ Tim Gardner ]
++
++  * MV78XX0 must specify a target in the vars definition.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ext4: wait on all pending commits in ext4_sync_fs()"
++  * jbd2: Fix return value of jbd2_journal_start_commit()
++  * jbd2: Avoid possible NULL dereference in
++    jbd2_journal_begin_ordered_truncate()
++  * ext4: Fix to read empty directory blocks correctly in 64k
++  * ext4: Fix lockdep warning
++  * ext4: Initialize preallocation list_head's properly
++  * ext4: Implement range_cyclic in ext4_da_writepages instead of
++    write_cache_pages
++  * ext4: Fix NULL dereference in ext4_ext_migrate()'s error handling
++  * ext4: Add fallback for find_group_flex
++  * ext4: Fix deadlock in ext4_write_begin() and ext4_da_write_begin()
++  * Added mv78xx0 flavor
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 06 Mar 2009 06:13:31 -0700
++
++linux (2.6.28-8.28) jaunty; urgency=low
++
++  [ Alexey Starikovskiy ]
++
++  * SAUCE: ACPI: EC: Limit workaround for ASUS notebooks even more
++    - LP: #288385
++
++  [ Scott James Remnant ]
++
++  * SAUCE: Auto-load esp module when device opened.
++  * SAUCE: Auto-load bridge module when socket opened.
++  * SAUCE: Auto-load af_netlink module when socket opened.
++  * SAUCE: Auto-load wanrouter module when socket opened.
++  * SAUCE: Auto-load ip_queue module when socket opened.
++  * SAUCE: Auto-load ip6_queue module when socket opened.
++  * SAUCE: Auto-load cn module when socket opened.
++  * SAUCE: Auto-load scsi_transport_iscsi module when socket opened.
++  * SAUCE: Auto-load ftl module when device opened.
++  * SAUCE: Auto-load pcd module when device opened.
++  * SAUCE: Auto-load pf module when device opened.
++  * SAUCE: Auto-load nftl module when device opened.
++  * SAUCE: Auto-load mousedev module when psaux device opened.
++  * SAUCE: Auto-load mousedev module when /dev/input/mice opened.
++  * SAUCE: Auto-load rng-core module when device opened.
++  * SAUCE: Auto-load openprom module when device opened.
++  * SAUCE: Auto-load applicom module when device opened.
++  * SAUCE: Auto-load toshiba module when device opened.
++  * SAUCE: Auto-load cyclades module when device opened.
++  * SAUCE: Auto-load riscom8 module when device opened.
++  * SAUCE: Auto-load specialix module when device opened.
++  * SAUCE: Auto-load videodev module when device opened.
++  * SAUCE: Auto-load i2c_dev module when device opened.
++  * SAUCE: Auto-load mtdchar module when device opened.
++  * SAUCE: Auto-load pt module when device opened.
++  * SAUCE: Auto-load pg module when device opened.
++  * SAUCE: Auto-load cdc_acm module when device opened.
++  * SAUCE: Auto-load msr module when device opened.
++  * SAUCE: Auto-load cpuid module when device opened.
++  * SAUCE: quickcam: Enable double-buffering by default
++  * SAUCE: libata: Ignore HPA by default.
++  * SAUCE: hostap: Change initial operation mode to managed (infra)
++  * SAUCE: floppy: Provide a PnP device table in the module.
++    - LP: #255651
++  * SAUCE: Auto-load mwave module when device opened.
++  * Build CONFIG_FUSE_FS into kernel, not as module.
++
++  [ Stefan Bader ]
++
++  * Enable build of ext4 as a module on LPIA
++    - LP: #331848
++
++  [ Tim Gardner ]
++
++  * Update configs to fix LPIA FTBS
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Mar 2009 10:43:24 -0700
++
++linux (2.6.28-8.27) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs (arm:ixp4xx)
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: enable Intel HDMI output
++
++  [ Manoj Iyer ]
++
++  * SAUCE: Added quirk for Linksys WUSB600N USB wifi-n networking adapter
++    - LP: #323473
++
++  [ Steve Beattie ]
++
++  * fix apparmor memory leak on unlinked file ops
++    - LP: #329489
++
++  [ Tim Gardner ]
++
++  * SAUCE: Dell XPS710 reboot quirk
++    - LP: #323592
++  * SAUCE: (drop after 2.6.28) ieee80211: Add infrastructure to obsolete
++    scan results
++    - LP: #336055
++  * Add modules.order to the linux-image package.
++
++  [ Upstream Kernel Changes ]
++
++  * iwlwifi: fix time interval misuse in iwl_poll_{direct_}bit
++  * x86: only scan the root bus in early PCI quirks
++    - LP: #267295
++  * ALSA: hda - Intel HDMI audio support
++  * ALSA: hda - Fix unused function in patch_intelhdmi.c
++  * ALSA: handle SiI1392 HDMI codec in patch_intelhdmi.c
++  * ALSA: hda-intel: reorder HDMI audio enabling sequence
++  * ALSA: introduce snd_print_pcm_rates()
++  * ALSA: create hda_eld.c for ELD routines and proc interface
++  * ALSA: ELD proc interface for HDMI sinks
++  * ALSA: hda: make standalone hdmi_fill_audio_infoframe()
++  * ALSA: hda: make global snd_print_channel_allocation()
++  * ALSA: hda: HDMI channel allocations for audio infoframe
++  * ALSA: hda: HDMI channel mapping cleanups
++  * ALSA: hda: minor code cleanups
++  * ALSA: hda: rename sink_eld to hdmi_eld
++  * ALSA: hda - Release ELD proc file
++  * ALSA: hda - minor HDMI code cleanups
++  * ALSA: hda - report selected CA index for Audio InfoFrame
++  * ALSA: hda - Add Intel vendor id string
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 25 Feb 2009 14:23:46 -0700
++
++linux (2.6.28-8.26) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs (armel:ixp4xx)
++    - LP: #331510
++
++  [ Tim Gardner ]
++
++  * Add more missing modules
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 24 Feb 2009 06:58:53 -0700
++
++linux (2.6.28-8.25) jaunty; urgency=low
++
++  [ Scott James Remnant ]
++
++  * SAUCE: Prefer powernow-k8 to acpi-cpufreq
++  * Change CONFIG_X86_P4_CLOCKMOD to be a module again.
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Initialize the new
++    group descriptor when resizing the filesystem"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add sanity check
++    to make_indexed_dir"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: only use
++    i_size_high for regular files"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add sanity checks
++    for the superblock before mounting the filesystem"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix
++    s_dirty_blocks_counter if block allocation failed with nodelalloc"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Init the complete
++    page while building buddy cache"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Don't allow new
++    groups to be added during block allocation"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: mark the
++    blocks/inode bitmap beyond end of group as used"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Use new
++    buffer_head flag to check uninit group bitmaps initialization"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix the race
++    between read_inode_bitmap() and ext4_new_inode()"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix race between
++    read_block_bitmap() and mark_diskspace_used()"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: don't use blocks
++    freed but not yet committed in buddy cache init"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: cleanup mballoc
++    header files"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Use
++    EXT4_GROUP_INFO_NEED_INIT_BIT during resize"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add blocks added
++    during resize to bitmap"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Don't overwrite
++    allocation_context ac_status"
++  * Revert "SAUCE: (revert before 2.6.28.y update) jbd2: Add barrier not
++    supported test to journal_wait_on_commit_record"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Widen type of
++    ext4_sb_info.s_mb_maxs[]"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: avoid ext4_error
++    when mounting a fs with a single bg"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Fix the delalloc
++    writepages to allocate blocks at the right offset."
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: tone down
++    ext4_da_writepages warnings"
++  * Revert "SAUCE: (revert before 2.6.28.y update) ext4: Add support for
++    non-native signed/unsigned htree hash algorithms"
++  * Enabled X86_ACPI_CPUFREQ=y
++
++  [ Upstream Kernel Changes ]
++
++  * ath9k: quiet harmless ForceXPAon messages
++    - LP: #321474
++  * [WATCHDOG] iTCO_wdt: fix SMI_EN regression 2
++    - LP: #314050
++  * pid: implement ns_of_pid
++  * mqueue: fix si_pid value in mqueue do_notify()
++  * powerpc/vsx: Fix VSX alignment handler for regs 32-63
++  * sata_nv: give up hardreset on nf2
++  * Fix Intel IOMMU write-buffer flushing
++  * SCSI: libiscsi: fix iscsi pool leak
++  * x86/cpa: make sure cpa is safe to call in lazy mmu mode
++  * sched: SCHED_OTHER vs SCHED_IDLE isolation
++  * x86, vm86: fix preemption bug
++  * Add support for VT6415 PCIE PATA IDE Host Controller
++  * ext2/xip: refuse to change xip flag during remount with busy inodes
++  * 3c505: do not set pcb->data.raw beyond its size
++  * Bluetooth: Fix TX error path in btsdio driver
++  * ext4: Add support for non-native signed/unsigned htree hash algorithms
++  * ext4: tone down ext4_da_writepages warnings
++  * ext4: Fix the delalloc writepages to allocate blocks at the right
++    offset.
++  * ext4: avoid ext4_error when mounting a fs with a single bg
++  * ext4: Widen type of ext4_sb_info.s_mb_maxs[]
++  * jbd2: Add barrier not supported test to journal_wait_on_commit_record
++  * ext4: Don't overwrite allocation_context ac_status
++  * ext4: Add blocks added during resize to bitmap
++  * ext4: Use EXT4_GROUP_INFO_NEED_INIT_BIT during resize
++  * ext4: cleanup mballoc header files
++  * ext4: don't use blocks freed but not yet committed in buddy cache init
++  * ext4: Fix race between read_block_bitmap() and mark_diskspace_used()
++  * ext4: Fix the race between read_inode_bitmap() and ext4_new_inode()
++  * ext4: Use new buffer_head flag to check uninit group bitmaps
++    initialization
++  * ext4: mark the blocks/inode bitmap beyond end of group as used
++  * ext4: Don't allow new groups to be added during block allocation
++  * ext4: Init the complete page while building buddy cache
++  * ext4: Fix s_dirty_blocks_counter if block allocation failed with
++    nodelalloc
++  * ext4: Add sanity checks for the superblock before mounting the
++    filesystem
++  * ext4: only use i_size_high for regular files
++  * ext4: Add sanity check to make_indexed_dir
++  * ext4: Initialize the new group descriptor when resizing the filesystem
++  * Fix longstanding "error: storage size of '__mod_dmi_device_table' isn't
++    known"
++  * Linux 2.6.28.7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Feb 2009 06:45:55 -0700
++
++linux (2.6.28-8.24) jaunty; urgency=low
++
++  [ Scott James Remnant ]
++
++  * Change CPU_FREQ_DEFAULT_GOV_ONDEMAND to y
++  * SAUCE: Link acpi-cpufreq.o first
++
++  [ Tim Gardner ]
++
++  * Build in CPU Frequency scaling drivers
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 18 Feb 2009 06:12:24 -0700
++
++linux (2.6.28-8.23) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * include the kernel configuration in the sub-flavour images
++    - LP: #328859
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: (drop after 2.6.28) [eCryptfs] Regression in unencrypted
++    filename symlinks" in favor of upstream commit.
++  * Fix compile issues with qc-usb
++  * SAUCE: (remove after 2.6.28) V4L/DVB (10216): saa7127: fix broken
++    S-Video with saa7129
++    - LP: #329267
++
++  [ Upstream Kernel Changes ]
++
++  * Subject:SAUCE: LP#193970 iwlagn: fix hw-rfkill while the interface is
++    down
++    - LP: #193970
++  * x86, vmi: put a missing paravirt_release_pmd in pgd_dtor
++  * nbd: fix I/O hang on disconnected nbds
++  * mac80211: restrict to AP in outgoing interface heuristic
++  * w1: w1 temp calculation overflow fix
++  * zd1211rw: adding 0ace:0xa211 as a ZD1211 device
++  * zd1211rw: treat MAXIM_NEW_RF(0x08) as UW2453_RF(0x09) for TP-Link
++    WN322/422G
++  * parport: parport_serial, don't bind netmos ibm 0299
++  * syscall define: fix uml compile bug
++  * kernel-doc: fix syscall wrapper processing
++  * Fix page writeback thinko, causing Berkeley DB slowdown
++  * write-back: fix nr_to_write counter
++  * writeback: fix break condition
++  * mm: rearrange exit_mmap() to unlock before arch_exit_mmap
++  * powerpc/fsl-booke: Fix mapping functions to use phys_addr_t
++  * lockd: fix regression in lockd's handling of blocked locks
++  * sctp: Fix crc32c calculations on big-endian arhes.
++  * sctp: Correctly start rtx timer on new packet transmissions.
++  * sctp: Properly timestamp outgoing data chunks for rtx purposes
++  * net: Fix frag_list handling in skb_seq_read
++  * net: Fix OOPS in skb_seq_read().
++  * drivers/net/skfp: if !capable(CAP_NET_ADMIN): inverted logic
++  * ipv4: fix infinite retry loop in IP-Config
++  * net: Fix userland breakage wrt. linux/if_tunnel.h
++  * net: packet socket packet_lookup_frame fix
++  * packet: Avoid lock_sock in mmap handler
++  * sungem: Soft lockup in sungem on Netra AC200 when switching interface
++    up
++  * udp: Fix UDP short packet false positive
++  * udp: increments sk_drops in __udp_queue_rcv_skb()
++  * ipv6: Disallow rediculious flowlabel option sizes.
++  * ipv6: Copy cork options in ip6_append_data
++  * net: 4 bytes kernel memory disclosure in SO_BSDCOMPAT gsopt try #2
++  * sky2: fix hard hang with netconsoling and iface going up
++  * tun: Add some missing TUN compat ioctl translations.
++  * tun: Fix unicast filter overflow
++  * virtio_net: Fix MAX_PACKET_LEN to support 802.1Q VLANs
++  * tcp: splice as many packets as possible at once
++  * tcp: Fix length tcp_splice_data_recv passes to skb_splice_bits.
++  * sparc: Enable syscall wrappers for 64-bit (CVE-2009-0029)
++  * sparc64: Annotate sparc64 specific syscalls with SYSCALL_DEFINEx()
++  * ALSA: hda - Add missing terminator in slave dig-out array
++  * ALSA: mtpav - Fix initial value for input hwport
++  * HID: adjust report descriptor fixup for MS 1028 receiver
++  * ide/libata: fix ata_id_is_cfa() (take 4)
++  * libata: fix EH device failure handling
++  * netfilter: fix tuple inversion for Node information request
++  * netfilter: xt_sctp: sctp chunk mapping doesn't work
++  * x86: microcode_amd: fix wrong handling of equivalent CPU id
++  * ide-cd: fix DMA for non bio-backed requests
++  * net: Fix data corruption when splicing from sockets.
++  * Linux 2.6.28.6
++  * eCryptfs: Regression in unencrypted filename symlinks
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 16 Feb 2009 06:43:51 -0700
++
++linux (2.6.28-8.22) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Remove perm-blacklist
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: psmouse/synaptics: ensure we reset the device on resume
++    - LP: #317270
++
++  [ Tim Gardner ]
++
++  * Add lpia to getabi script
++  * SAUCE: tracer for sreadahead
++
++ -- Amit Kucheria <amit.kucheria@ubuntu.com>  Fri, 13 Feb 2009 15:23:21 +0200
++
++linux (2.6.28-8.21) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: switch the Asus Pundit P1-AH2 to old acpi sleep ordering
++    - LP: #327267
++
++  [ Tim Gardner ]
++
++  * Added LPIA arch support
++  * Added libdrm-dev as a 'Replaces' to linux-libc-dev
++  * SAUCE: LPIA support for 9202 HDA Sigmatel codec
++  * SAUCE: Add an X86_LPIA Kconfig option
++  * SAUCE: UHCI USB quirk for resume
++  * SAUCE: LPIA Reboot fix for Intel Crownbeach development boards
++  * SAUCE: LPIA  Logical reset of USB port on resume
++  * Set CONFIG_WIRELESS_OLD_REGULATORY=n, added wireless-crda
++    as an install dependency.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "Revert "x86, early_ioremap: fix fencepost error""
++    - LP: #312554
++  * drm/i915: capture last_vblank count at IRQ uninstall time too
++    - LP: #320813
++  * drm/i915: add get_vblank_counter function for GM45
++    - LP: #320813
++  * Staging: comedi: fix Kbuild
++  * Staging: meilhaus: fix Kbuild
++  * Staging: android: binder: fix arm build errors
++  * Staging: android: timed_gpio: Fix build to build on kernels after
++    2.6.25.
++  * Staging: android: fix build error on 64bit boxes
++  * Staging: android: Add lowmemorykiller documentation.
++  * Staging: android: task_get_unused_fd_flags: fix the wrong usage of
++    tsk->signal
++  * staging: agnx: drivers/staging/agnx/agnx.h needs <linux/io.h>
++  * Staging: usbip: usbip_start_threads(): handle kernel_thread failure
++  * Staging: poch: fix verification of memory area
++  * Documentation: move DMA-mapping.txt to Doc/PCI/
++  * sgi-xp: fix writing past the end of kzalloc()'d space
++  * do_wp_page: fix regression with execute in place
++  * wait: prevent exclusive waiter starvation
++  * shm: fix shmctl(SHM_INFO) lockup with !CONFIG_SHMEM
++  * revert "rlimit: permit setting RLIMIT_NOFILE to RLIM_INFINITY"
++  * prevent kprobes from catching spurious page faults
++  * sound: usb-audio: handle wMaxPacketSize for FIXED_ENDPOINT devices
++  * md: Ensure an md array never has too many devices.
++  * md: Fix a bug in linear.c causing which_dev() to return the wrong
++    device.
++  * ACPI: Enable bit 11 in _PDC to advertise hw coord
++  * ACPI: dock: Don't eval _STA on every show_docked sysfs read
++  * ieee1394: ohci1394: increase AT req. retries, fix ack_busy_X from
++    Panasonic camcorders and others
++  * firewire: ohci: increase AT req. retries, fix ack_busy_X from Panasonic
++    camcorders and others
++  * firewire: sbp2: fix DMA mapping leak on the failure path
++  * firewire: sbp2: add workarounds for 2nd and 3rd generation iPods
++  * ieee1394: sbp2: add workarounds for 2nd and 3rd generation iPods
++  * module: remove over-zealous check in __module_get()
++  * x86: APIC: enable workaround on AMD Fam10h CPUs
++  * eeepc-laptop: fix oops when changing backlight brightness during
++    eeepc-laptop init
++  * eeepc-laptop: Add support for extended hotkeys
++  * e1000: fix bug with shared interrupt during reset
++  * e1000: Fix PCI enable to honor the need_ioport flag
++  * agp/intel: Fix broken ® symbol in device name.
++  * ALSA: hda - Add quirk for FSC Amilo Xi2550
++  * ALSA: hda - Add missing COEF initialization for ALC887
++  * ALSA: hda - Add missing initialization for ALC272
++  * asus_acpi: Add R1F support
++  * panasonic-laptop: fix X[ ARRAY_SIZE(X) ]
++  * ACPI: Skip the first two elements in the _BCL package
++  * ACPI: proc_dir_entry 'video/VGA' already registered
++  * ACPI: disable ACPI cleanly when bad RSDP found
++  * ACPICA: Fix table entry truncation calculation
++  * PCI: properly clean up ASPM link state on device remove
++  * PCI: return error on failure to read PCI ROMs
++  * seq_file: move traverse so it can be used from seq_read
++  * seq_file: fix big-enough lseek() + read()
++  * serial: set correct baud_base for Oxford Semiconductor Ltd EXSYS
++    EX-41092 Dual 16950 Serial adapter
++  * Add support for '8-port RS-232 MIC-3620 from advantech'
++  * mm: fix error case in mlock downgrade reversion
++  * elf core dump: fix get_user use
++  * ACPI: video: Fix reversed brightness behavior on ThinkPad SL series
++  * ipw2200: fix scanning while associated
++  * XFS: set b_error from bio error in xfs_buf_bio_end_io
++  * Revert USB: option: add Pantech cards
++  * USB: option: New mobile broadband modems to be supported
++  * USB: new id for ti_usb_3410_5052 driver
++  * USB: two more usb ids for ti_usb_3410_5052
++  * USB: usb-storage: add Pentax to the bad-vendor list
++  * sata_via: Add VT8261 support
++  * nbd: do not allow two clients at the same time
++  * sctp: Fix another socket race during accept/peeloff
++  * Linux 2.6.28.5
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Feb 2009 16:11:28 -0700
++
++linux (2.6.28-7.20) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * SAUCE: Input: atkbd - Samsung NC10 key repeat fix
++
++  [ Upstream Kernel Changes ]
++
++  * Manually revert "mlock: downgrade mmap sem while populating mlocked
++    regions"
++  * xen: make sysfs files behave as their names suggest
++  * sata_mv: fix 8-port timeouts on 508x/6081 chips
++  * m68knommu: set NO_DMA
++  * PCI/MSI: bugfix/utilize for msi_capability_init()
++  * x86: use early clobbers in usercopy*.c
++  * netfilter: ctnetlink: fix scheduling while atomic
++  * orinoco: move kmalloc(..., GFP_KERNEL) outside spinlock in
++    orinoco_ioctl_set_genie
++  * fbdev/atyfb: Fix DSP config on some PowerMacs & PowerBooks
++  * kmalloc: return NULL instead of link failure
++  * sata_nv: rename nv_nf2_hardreset()
++  * sata_nv: fix MCP5x reset
++  * sata_nv: ck804 has borked hardreset too
++  * Fix memory corruption in console selection
++  * Add enable_ms to jsm driver
++  * nfsd: only set file_lock.fl_lmops in nfsd4_lockt if a stateowner is
++    found
++  * nfsd: Ensure nfsv4 calls the underlying filesystem on LOCKT
++  * iwlwifi: fix rs_get_rate WARN_ON()
++  * p54: fix lm87 checksum endianness
++  * p54: fix p54_read_eeprom to cope with tx_hdr_len
++  * p54usb: rewriting rx/tx routines to make use of usb_anchor's facilities
++  * minstrel: fix warning if lowest supported rate index is not 0
++  * PCI: irq and pci_ids patch for Intel Tigerpoint DeviceIDs
++  * cpuidle: Add decaying history logic to menu idle predictor
++  * ACPI: Avoid array address overflow when _CST MWAIT hint bits are set
++  * video: always update the brightness when poking "brightness"
++  * Newly inserted battery might differ from one just removed, so update of
++    battery info fields is required.
++  * ACPI: Do not modify SCI_EN directly
++  * dlm: initialize file_lock struct in GETLK before copying conflicting
++    lock
++  * sata_mv: Fix chip type for Hightpoint RocketRaid 1740/1742
++  * ACPICA: Allow multiple backslash prefix in namepaths
++  * Linux 2.6.28.4
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 07 Feb 2009 18:53:42 -0700
++
++linux (2.6.28-7.19) jaunty; urgency=low
++
++  * Fix missing modules FTBS
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Feb 2009 15:28:15 -0700
++
++linux (2.6.28-7.18) jaunty; urgency=low
++
++  [ Alok Kataria ]
++
++  * SAUCE: (drop after 2.6.29) x86: add a synthetic TSC_RELIABLE feature
++    bit
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: add X86_FEATURE_HYPERVISOR feature bit
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Hypervisor detection and get tsc_freq
++    from hypervisor
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Add a synthetic TSC_RELIABLE feature
++    bit.
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: Skip verification by the watchdog for
++    TSC clocksource.
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: VMware: Fix vmware_get_tsc code
++    - LP: #319945
++  * SAUCE: (drop after 2.6.29) x86: vmware: look for DMI string in the
++    product serial key
++    - LP: #319945
++
++  [ Andy Whitcroft ]
++
++  * SAUCE: toshiba_acpi -- pull in current -dev version of driver
++    - LP: #269831
++  * SAUCE: toshiba_acpi -- add acpi hotkey kernel thread
++    - LP: #269831
++  * move toshiba laptops back from tlsup to toshiba_acpi
++    - LP: #269831
++
++  [ Aneesh Kumar K.V ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix the delalloc
++    writepages to allocate blocks at the right offset.
++  * SAUCE: (revert before 2.6.28.y update) ext4: avoid ext4_error when
++    mounting a fs with a single bg
++  * SAUCE: (revert before 2.6.28.y update) ext4: Don't overwrite
++    allocation_context ac_status
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add blocks added during
++    resize to bitmap
++  * SAUCE: (revert before 2.6.28.y update) ext4: Use
++    EXT4_GROUP_INFO_NEED_INIT_BIT during resize
++  * SAUCE: (revert before 2.6.28.y update) ext4: cleanup mballoc header
++    files
++  * SAUCE: (revert before 2.6.28.y update) ext4: don't use blocks freed but
++    not yet committed in buddy cache init
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix race between
++    read_block_bitmap() and mark_diskspace_used()
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix the race between
++    read_inode_bitmap() and ext4_new_inode()
++  * SAUCE: (revert before 2.6.28.y update) ext4: Use new buffer_head flag
++    to check uninit group bitmaps initialization
++  * SAUCE: (revert before 2.6.28.y update) ext4: mark the blocks/inode
++    bitmap beyond end of group as used
++  * SAUCE: (revert before 2.6.28.y update) ext4: Don't allow new groups to
++    be added during block allocation
++  * SAUCE: (revert before 2.6.28.y update) ext4: Init the complete page
++    while building buddy cache
++  * SAUCE: (revert before 2.6.28.y update) ext4: Fix s_dirty_blocks_counter
++    if block allocation failed with nodelalloc
++
++  [ Hannes Eder ]
++
++  * SAUCE: (drop after 2.6.29) x86: vmware - fix sparse warnings
++    - LP: #319945
++
++  [ Luke Yelavich ]
++
++  * hid modules have hyphens instead of underscores in their names
++
++  [ Mark Fasheh ]
++
++  * SAUCE: (revert before 2.6.28.y update) jbd2: Add BH_JBDPrivateStart
++
++  [ Theodore Ts'o ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add support for non-native
++    signed/unsigned htree hash algorithms
++  * SAUCE: (revert before 2.6.28.y update) ext4: tone down
++    ext4_da_writepages warnings
++  * SAUCE: (revert before 2.6.28.y update) jbd2: Add barrier not supported
++    test to journal_wait_on_commit_record
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add sanity checks for the
++    superblock before mounting the filesystem
++  * SAUCE: (revert before 2.6.28.y update) ext4: only use i_size_high for
++    regular files
++  * SAUCE: (revert before 2.6.28.y update) ext4: Add sanity check to
++    make_indexed_dir
++  * SAUCE: (revert before 2.6.28.y update) jbd2: On a __journal_expect()
++    assertion failure printk "JBD2", not "EXT3-fs"
++  * SAUCE: (revert before 2.6.28.y update) ext4: Initialize the new group
++    descriptor when resizing the filesystem
++
++  [ Tyler Hicks ]
++
++  * SAUCE: (drop after 2.6.28) [eCryptfs] Regression in unencrypted
++    filename symlinks
++    - LP: #322532
++
++  [ Upstream Kernel Changes ]
++
++  * Input: atkbd - broaden the Dell DMI signatures
++    - LP: #261721
++  * ti_usb_3410_5052: support alternate firmware
++  * ath5k: fix mesh point operation
++  * mac80211: decrement ref count to netdev after launching mesh discovery
++  * inotify: clean up inotify_read and fix locking problems
++  * fuse: destroy bdi on umount
++  * fuse: fix missing fput on error
++  * fuse: fix NULL deref in fuse_file_alloc()
++  * x86, mm: fix pte_free()
++  * klist.c: bit 0 in pointer can't be used as flag
++  * sysfs: fix problems with binary files
++  * x86: fix page attribute corruption with cpa()
++  * USB: fix toggle mismatch in disable_endpoint paths
++  * sound: virtuoso: enable UART on Xonar HDAV1.3
++  * USB: usbmon: Implement compat_ioctl
++  * USB: fix char-device disconnect handling
++  * USB: storage: add unusual devs entry
++  * alpha: nautilus - fix compile failure with gcc-4.3
++  * alpha: fix vmalloc breakage
++  * resources: skip sanity check of busy resources
++  * rtl8187: Add termination packet to prevent stall
++  * it821x: Add ultra_mask quirk for Vortex86SX
++  * libata: pata_via: support VX855, future chips whose IDE controller use
++    0x0571
++  * serial_8250: support for Sealevel Systems Model 7803 COMM+8
++  * drm: stash AGP include under the do-we-have-AGP ifdef
++  * Fix OOPS in mmap_region() when merging adjacent VM_LOCKED file segments
++  * bnx2x: Block nvram access when the device is inactive
++  * ext3: Add sanity check to make_indexed_dir
++  * rtl8187: Fix error in setting OFDM power settings for RTL8187L
++  * epoll: drop max_user_instances and rely only on max_user_watches
++  * gpiolib: fix request related issue
++  * sgi-xpc: Remove NULL pointer dereference.
++  * sgi-xpc: ensure flags are updated before bte_copy
++  * include/linux: Add bsg.h to the Kernel exported headers
++  * ALSA: hda - Fix PCM reference NID for STAC/IDT analog outputs
++  * ALSA: hda - add another MacBook Pro 4, 1 subsystem ID
++  * ALSA: hda - Add quirk for HP DV6700 laptop
++  * crypto: authenc - Fix zero-length IV crash
++  * crypto: ccm - Fix handling of null assoc data
++  * x86, pat: fix reserve_memtype() for legacy 1MB range
++  * x86, pat: fix PTE corruption issue while mapping RAM using /dev/mem
++  * PCI hotplug: fix lock imbalance in pciehp
++  * dmaengine: fix dependency chaining
++  * NET: net_namespace, fix lock imbalance
++  * relay: fix lock imbalance in relay_late_setup_files
++  * Linux 2.6.28.3
++  * ALSA: Enable SPDIF output on ALC655
++  * ALSA: hda - Add ASUS V1Sn support
++  * ALSA: hda - support detecting HD Audio devices with PCI class code
++  * ALSA: hda: alc883 model for ASUS P5Q-EM boards
++  * ALSA: hda - Add quirk for MSI 7260 mobo
++  * ALSA: hda - Add quirk for Sony VAIO VGN-SR19XN
++  * ALSA: oxygen: add Claro halo support
++  * ALSA: hda - Add a new function to seek for a codec ID
++  * ALSA: patch_sigmatel: Add missing Gateway entries and autodetection
++  * ALSA: hda - More fixes on Gateway entries
++  * ALSA: hda - Add MCP67 HDMI support
++  * ALSA: hda - fix name for ALC1200
++  * LSA: hda - Add HP Acacia detection
++  * ALSA: hda - Add quirk for HP 2230s
++  * ALSA: hda - Add quirk for Dell Inspiron Mini9
++  * ALSA: hda - add support for Intel DX58SO board
++  * ALSA: hda - Fix silent headphone output on Panasonic CF-74
++  * ALSA: USB quirk for Logitech Quickcam Pro 9000 name
++  * ALSA: hda - add quirks for some 82801H variants to use ALC883_MITAC
++
++  [ Yasunori Goto ]
++
++  * SAUCE: (revert before 2.6.28.y update) ext4: Widen type of
++    ext4_sb_info.s_mb_maxs[]
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 02 Feb 2009 23:07:13 -0700
++
++linux (2.6.28-6.17) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Updating configs: ARMEL/versatile
++
++ -- Amit Kucheria <amit.kucheria@ubuntu.com>  Fri, 30 Jan 2009 13:36:59 +0200
++
++linux (2.6.28-6.16) jaunty; urgency=low
++
++  [ Luke Yelavich ]
++
++  * Add hid quirks to input-modules udeb
++
++  [ Tim Gardner ]
++
++  * Revert "[arm] Fix kexec on ARM by properly calling the relocation
++    function". This patch was deemed 'bogus' by Russell King on the
++    ARM mailing list.
++
++  [ Upstream Kernel Changes ]
++
++  * PCI: keep ASPM link state consistent throughout PCIe hierarchy
++  * security: introduce missing kfree
++  * rt2x00: add USB ID for the Linksys WUSB200.
++  * p54usb: Add USB ID for Thomson Speedtouch 121g
++  * lib/idr.c: use kmem_cache_zalloc() for the idr_layer cache
++  * sgi-xp: eliminate false detection of no heartbeat
++  * sched: fix update_min_vruntime
++  * IA64: Turn on CONFIG_HAVE_UNSTABLE_CLOCK
++  * sound: virtuoso: do not overwrite EEPROM on Xonar D2/D2X
++  * ALSA: hda - Add quirk for another HP dv5
++  * ALSA: hda - Fix HP dv5 mic input
++  * ALSA: hda - Don't reset HP pinctl in patch_sigmatel.c
++  * ALSA: hda - make laptop-eapd model back for AD1986A
++  * drivers/net/irda/irda-usb.c: fix buffer overflow
++  * usb-storage: add last-sector hacks
++  * usb-storage: set CAPACITY_HEURISTICS flag for bad vendors
++  * pkt_sched: sch_htb: Fix deadlock in hrtimers triggered by HTB
++  * ipv6: Fix fib6_dump_table walker leak
++  * sctp: Avoid memory overflow while FWD-TSN chunk is received with bad
++    stream ID
++  * pkt_sched: cls_u32: Fix locking in u32_change()
++  * r6040: fix wrong logic in mdio code
++  * r6040: save and restore MIER correctly in the interrupt routine
++  * r6040: bump release number to 0.19
++  * tcp: don't mask EOF and socket errors on nonblocking splice receive
++  * p54usb: fix traffic stalls / packet drop
++  * netfilter: x_tables: fix match/target revision lookup
++  * netfilter: ebtables: fix inversion in match code
++  * netfilter: nf_conntrack: fix ICMP/ICMPv6 timeout sysctls on big-endian
++  * dell_rbu: use scnprintf() instead of less secure sprintf()
++  * powerpc: is_hugepage_only_range() must account for both 4kB and 64kB
++    slices
++  * hwmon: (abituguru3) Fix CONFIG_DMI=n fallback to probe
++  * mm: write_cache_pages cyclic fix
++  * mm: write_cache_pages early loop termination
++  * mm: write_cache_pages writepage error fix
++  * mm: write_cache_pages integrity fix
++  * mm: write_cache_pages cleanups
++  * mm: write_cache_pages optimise page cleaning
++  * mm: write_cache_pages terminate quickly
++  * mm: write_cache_pages more terminate quickly
++  * mm: do_sync_mapping_range integrity fix
++  * mm: direct IO starvation improvement
++  * fs: remove WB_SYNC_HOLD
++  * fs: sync_sb_inodes fix
++  * fs: sys_sync fix
++  * Linux 2.6.28.2
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 25 Jan 2009 13:36:16 -0700
++
++linux (2.6.28-5.15) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Revert "Enabled CONFIG_PID_NS=y for i386/amd64"
++    Somehow this commit also reverted the 7 prior commits (which is bad).
++  * Enabled CONFIG_PID_NS=y for i386/amd64 (version 2)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 22 Jan 2009 13:48:34 -0700
++
++linux (2.6.28-5.14) jaunty; urgency=low
++
++  [ Ben Collins ]
++
++  * lirc_gpio: Forward ported to current kernel (jaunty)
++  * configs: Enable LIRC_GPIO on 64-bit/32-bit x86
++    - LP: #298791
++
++  [ Jeff Layton ]
++
++  * SAUCE: cifs: make sure we allocate enough storage for socket address
++    - LP: #318565
++
++  [ Tim Gardner ]
++
++  * check-abi: Return success when ABI skip is requested and no ABI files exist.
++    This ought to fix the armel FTBS.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 22 Jan 2009 06:42:49 -0700
++
++linux (2.6.28-5.13) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: don't use buggy _BCL/_BCM/_BQC for backlight control"
++
++  [ Tim Gardner ]
++
++  * Fix udeb generation breakage caused by the previous armel versatile
++    flavour config update.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 21 Jan 2009 12:38:35 -0700
++
++linux (2.6.28-5.12) jaunty; urgency=low
++
++  [ Ante ]
++
++  * Update drbd to 8.3.0
++
++  [ Dave Airlie ]
++
++  * i915/drm: provide compat defines for userspace for certain struct
++
++  [ Eric Anholt ]
++
++  * drm/i915: Don't double-unpin buffers if we take a signal in
++  * drm/i915: Don't complain when interrupted while pinning in execbuffers.
++  * drm/i915: Don't allow objects to get bound while VT switched.
++
++  [ Jani Monoses ]
++
++  * Fix webcam having USB ID 0ac8:303b
++    - LP: #292086
++
++  [ Jesse Barnes ]
++
++  * drm/i915: set vblank enabled flag correctly across IRQ
++  * drm/i915: don't enable vblanks on disabled pipes
++
++  [ Michael Casadevall ]
++
++  * [arm] Fix kexec on ARM by properly calling the relocation function
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_PID_NS=y for i386/amd64
++  * SAUCE: Increase ATA_TMOUT_PMP_SRST_WAIT to 5 seconds.
++    - LP: #318978
++  * Update armel versatile config
++    - LP: #314789
++  * Enabled CONFIG_RT2860=m for i386/amd64
++  * Enabled CONFIG_RT2870=m for i386/amd64
++
++  [ Upstream Kernel Changes ]
++
++  * Input: atkbd - add keyboard quirk for HP Pavilion ZV6100 laptop
++    - LP: #291878
++  * ALSA: hda - Add quirk for another HP dv7
++  * ALSA: hda - Add quirk for HP6730B laptop
++  * ALSA: caiaq - Fix Oops with MIDI
++  * ALSA: hda - Fix typos for AD1882 codecs
++  * x86: fix intel x86_64 llc_shared_map/cpu_llc_id anomolies
++  * x86: default to SWIOTLB=y on x86_64
++  * CIFS: make sure that DFS pathnames are properly formed
++  * ring-buffer: prevent false positive warning
++  * ring-buffer: fix dangling commit race
++  * iwlwifi: use GFP_KERNEL to allocate Rx SKB memory
++  * tx493[89]ide: Fix length for __ide_flush_dcache_range
++  * tx4939ide: Do not use zero count PRD entry
++  * SCSI: eata: fix the data buffer accessors conversion regression
++  * USB: emi26: fix oops on load
++  * x86, UV: remove erroneous BAU initialization
++  * x86: fix incorrect __read_mostly on _boot_cpu_pda
++  * vmalloc.c: fix flushing in vmap_page_range()
++  * fs: symlink write_begin allocation context fix
++  * cgroups: fix a race between cgroup_clone and umount
++  * dm raid1: fix error count
++  * dm log: fix dm_io_client leak on error paths
++  * minix: fix add link's wrong position calculation
++  * md: fix bitmap-on-external-file bug.
++  * sched_clock: prevent scd->clock from moving backwards, take #2
++  * devices cgroup: allow mkfifo
++  * SCSI: aha152x_cs: Fix regression that keeps driver from using shared
++    interrupts
++  * ioat: fix self test for multi-channel case
++  * USB: isp1760: use a specific PLX bridge instead of any bdridge
++  * USB: isp1760: Fix probe in PCI glue code
++  * USB: unusual_devs.h additions for Pentax K10D
++  * inotify: fix type errors in interfaces
++  * Move compat system call declarations to compat header file
++  * Convert all system calls to return a long
++  * Rename old_readdir to sys_old_readdir
++  * Remove __attribute__((weak)) from sys_pipe/sys_pipe2
++  * Make sys_pselect7 static
++  * Make sys_syslog a conditional system call
++  * System call wrapper infrastructure
++  * powerpc: Enable syscall wrappers for 64-bit
++  * s390: enable system call wrappers
++  * System call wrapper special cases
++  * System call wrappers part 01
++  * System call wrappers part 02
++  * System call wrappers part 03
++  * System call wrappers part 04
++  * System call wrappers part 05
++  * System call wrappers part 06
++  * System call wrappers part 07
++  * System call wrappers part 08
++  * System call wrappers part 09
++  * System call wrappers part 10
++  * System call wrappers part 11
++  * System call wrappers part 12
++  * System call wrappers part 13
++  * System call wrappers part 14
++  * System call wrappers part 15
++  * System call wrappers part 16
++  * System call wrappers part 17
++  * System call wrappers part 18
++  * System call wrappers part 19
++  * System call wrappers part 20
++  * System call wrappers part 21
++  * System call wrappers part 22
++  * System call wrappers part 23
++  * System call wrappers part 24
++  * System call wrappers part 25
++  * System call wrappers part 26
++  * System call wrappers part 27
++  * System call wrappers part 28
++  * System call wrappers part 29
++  * System call wrappers part 30
++  * System call wrappers part 31
++  * System call wrappers part 32
++  * System call wrappers part 33
++  * s390 specific system call wrappers
++  * x86: fix RIP printout in early_idt_handler
++  * Fix timeouts in sys_pselect7
++  * USB: another unusual_devs entry for another bad Argosy storage device
++  * USB: storage: extend unusual range for 067b:3507
++  * USB: storage: recognizing and enabling Nokia 5200 cell phoes
++  * HID: fix error condition propagation in hid-sony driver
++  * fix switch_names() breakage in short-to-short case
++  * nfs: remove redundant tests on reading new pages
++  * eCryptfs: check readlink result was not an error before using it
++  * mvsas: increase port type detection delay to suit Seagate's 10k6 drive ST3450856SS 0003
++  * x86: avoid theoretical vmalloc fault loop
++  * ath9k: enable RXing of beacons on STA/IBSS
++  * mm lockless pagecache barrier fix
++  * powerpc: Disable Collaborative Memory Manager for kdump
++  * ibmvfc: Delay NPIV login retry and add retries
++  * ibmvfc: Improve async event handling
++  * getrusage: RUSAGE_THREAD should return ru_utime and ru_stime
++  * ath5k: ignore the return value of ath5k_hw_noise_floor_calibration
++  * mm: fix assertion
++  * XFS: truncate readdir offsets to signed 32 bit values
++  * Linux 2.6.28.1
++  * eCryptfs: Filename Encryption: Tag 70 packets
++  * eCryptfs: Filename Encryption: Header updates
++  * eCryptfs: Filename Encryption: Encoding and encryption functions
++  * eCryptfs: Filename Encryption: filldir, lookup, and readlink
++  * eCryptfs: Filename Encryption: mount option
++  * eCryptfs: Replace %Z with %z
++  * eCryptfs: Fix data types (int/size_t)
++  * eCryptfs: kerneldoc for ecryptfs_parse_tag_70_packet()
++  * eCryptfs: Clean up ecryptfs_decode_from_filename()
++  * fs/ecryptfs/inode.c: cleanup kerneldoc
++  * staging-p80211: Kill directly reference of netdev->priv
++  * staging-slicoss: Kill directly reference of netdev->priv
++  * staging-winbond: Kill directly reference of netdev->priv
++  * Staging: go7007: fixes due to video_usercopy api change
++  * Staging: go7007: fixes due v4l2_file_operations api change
++  * staging: correct dubious use of !x & y
++  * Staging: w35und: make wb35_probe() and wb35_disconnect() funtions static
++  * Staging: w35und: remove unused wb35_open() and wb35_close() functions
++  * Staging: w35und: use msleep() and udelay()
++  * Staging: w35und: remove the no-op pa_stall_execution macro
++  * Staging: w35und: purb typedef removal
++  * Staging: w35und: reg queue struct typedef removal
++  * Staging: w35und: wb35reg struct typedef removal
++  * Staging: w35und: padapter struct typedef removal
++  * Staging: w35und: merge wblinux struct to adapter
++  * Staging: w35und: wb35_probe() cleanup
++  * Staging: w35und: remove usb_submit_urb wrapper function
++  * Staging: w35und: remove usb_alloc_urb wrapper function
++  * w35und: remove dead code from wbusb_f.h
++  * Staging: w35und: remove true/false boolean macros
++  * Staging: w35und: OS_MEMORY_ALLOC wrapper removal
++  * Staging: w35und: usb_put_dev() is missing from wb35_disconnect()
++  * Staging: w35und: remove macro magic from MLME_GetNextPacket()
++  * Staging: w35und: plug memory leak in wbsoft_tx()
++  * Staging: w35und: move supported band initialization out of wb35_probe()
++  * Staging: w35und: remove timer wrappers
++  * Staging: w35und: remove atomic op wrappers
++  * Staging: w35und: remove memcpy/memcmp wrappers
++  * Staging: w35und: remove abs() and BIT() macros
++  * Staging: w35und: remove unused macros from common.h
++  * Staging: w35und: remove unused link status code
++  * Staging: w35und: #include cleanup
++  * Staging: w35und: remove some dead code
++  * Staging: w35und: move source files to one directory
++  * Staging: w35und: move struct wbsoft_priv to core.h and use it
++  * Staging: w35und: remove ->adapter from struct _HW_DATA_T
++  * Staging: w35und: clean up adapter.h a bit
++  * Staging: w35und: merge struct wb35_adapter to struct wbsoft_priv
++  * Staging: w35und: remove global struct ieee80211_hw
++  * Staging: w35und: inline DRIVER_AUTHOR and DRIVER_DESC macros
++  * Staging: w35und: clean up wblinux.c a bit
++  * Staging: w35und: remove unused ->ShutDowned member from struct
++    LOCAL_PARA
++  * Staging: w35und: move global wbsoft_enabled to struct wbsoft_priv
++  * Staging: w35und: move packet_came() to wb35rx.c
++  * Staging: w35und: remove ->skb_array from struct wbsoft_priv
++  * Staging: w35und: remove ->shutdown from struct wbsoft_priv
++  * Staging: w35und: make functions local to mds.c static
++  * Staging: w35und: make functions local to mlmetxrx.c static
++  * Staging: w35und: remove dead code from mto.c
++  * Staging: w35und: make functions local to wb35rx.c static
++  * Staging: w35und: make functions local to wb35tx.c static
++  * Staging: w35und: remove dead code from wbhal.c
++  * Staging: w35und: remove rxisr.c as dead code
++  * Staging: w35und: fix Kconfig
++  * Staging: w35und: fix config build warnings
++  * Staging: wlan-ng: Remove PCI/PLX/PCMCIA files.
++  * Staging: wlan-ng: Update Help text to mention prism3 devices.
++  * Staging: wlan-ng: Delete PCI/PLX/PCMCIA-specific code.
++  * Staging: wlan-ng: Make wlan-ng use WEXT mode by default.
++  * Staging: wlan-ng: Eliminate more <2.6 kernel support.
++  * Staging: wlan-ng: Eliminate all backwards-compatibility for <2.6.13 kernels.
++  * Staging: wlan-ng: Eliminate a boatload of tertiaryAP-only code.
++  * Staging: wlan-ng: Remove AP-only code from MLME functions.
++  * Staging: wlan-ng: Get rid of the MTU tests in the rx conversion path.
++  * Staging: wlan-ng: Eliminate one more rx mtu test.
++  * Staging: wlan-ng: Eliminate local 'version.h'
++  * Staging: wlan-ng: Eliminate usage of procfs.
++  * Staging: wlan-ng: Use standard kernel integer (u32/s32/etc) types.
++  * Staging: wlan-ng: Eliminate all backwards-compatible kernel code.
++  * Staging: wlan-ng: Wireless Extension support is mandatory.
++  * Staging: wlan-ng: use WIRELESS_EXT, not CONFIG_WIRELESS_EXT
++  * Staging: wlan-ng: Delete a large pile of now-unused code.
++  * Staging: wlan-ng: Delete a pile of unused mibs. And fix WEXT SET_TXPOWER.
++  * Staging: wlan-ng: Consolidate wlan-ng into a single module.
++  * Staging: wlan-ng: Purge all MIBs not used internally.
++  * Staging: wlan-ng: p80211netdev.c fix netdev alloc to prevent oops on device start
++  * Staging: wlan-ng: prism2_usb.c always enable the card in probe_usb
++  * Staging: wlan-ng: hfa384x_usb.c use newest version of 384x_drvr_start
++  * Staging: wlan-ng: p80211wext.c add latest changes & remove extra nulls from wext_handlers
++  * Staging: wlan-ng: p80211wext don't set default key id twice
++  * Staging: wlan-ng: hfa384x_usbin_callback: check for hardware removed
++  * Staging: wlan-ng: p80211conv.c copy code from wlan-ng-devel branch to not drop packets
++  * Staging: wlan-ng: remove unused #include <version.h>
++  * Staging: wlan-ng: p80211wext.c: use ARRAY_SIZE
++  * Staging: wlan-ng: fix compiler warnings
++  * Staging: wlan-ng: skb_p80211_to_ether() - payload_length is unsigned, check before subtraction
++  * Staging: at76_usb: update drivers/staging/at76_usb w/ mac80211 port
++  * Staging: at76_usb: fix build breakage
++  * Staging: at76_usb: remove compiler warnings
++  * Staging: at76_usb: fix up all remaining checkpatch.pl warnings
++  * Staging: at76_usb: cleanup dma on stack issues
++  * Staging: poch: Block size bug fix
++  * Staging: poch: Update TODO list
++  * Staging: poch: Correct pages from bytes.
++  * Staging: poch: minor fixes
++  * Staging: poch: Fix build warnings
++  * Staging: poch: Rx control register init
++  * Staging: poch: Fix user space protocol syncing
++  * Staging: poch: Fine grained locking
++  * Staging: sxg: remove typedefs
++  * Staging: sxg: break the build in a cleaner way when !x86
++  * Staging: sxg: update README
++  * staging: struct device - replace bus_id with dev_name(), dev_set_name()
++  * Staging: echo: remove typedefs
++  * Staging: echo: Lindent drivers/staging/echo
++  * Staging: go7007: saa7134 updates
++  * Staging: go7007: add sensoray 2250/2251 support
++  * Staging: go7007: Convert driver to use video_ioctl2
++  * Staging: go7007: annotate code pointers
++  * Staging: go7007: fix minor build warnings
++  * Staging: go7007: small cleanup
++  * Staging: go7007: add some more v4l2 ioctls
++  * Staging: et131x: Cleanup et131x_debug.h defines
++  * Staging: et131x: fix build failure
++  * Staging: et131x: remove unused variable in et1310_tx.c
++  * Staging: usbip: cleanup kerneldoc
++  * Staging: slicoss: use kzalloc
++  * Staging: slicoss: use correct type for memory allcations
++  * Staging: slicoss: use request_firmware
++  * Staging: add agnx wireless driver
++  * Staging: agnx: fix build errors due to ssid removal
++  * Staging: agnx: fix build errors due to rate control API changes
++  * Staging: agnx: fix build warnings
++  * Staging: add otus Atheros wireless network driver
++  * Staging: otus: fix netdev->priv usage
++  * Staging: otus: fix name clash
++  * Staging: otus: fix urb callback function type
++  * Staging: otus: remove dependence on kernel version
++  * Staging: add rt2860 wireless driver
++  * Staging: rt2860: disable root hack for reading files
++  * Staging: rt2860: fix up netdev->priv usage
++  * Staging: rt2860: use standard bit-reverse function
++  * Staging: rt2860: Fix minor compiler warnings
++  * Staging: rt2860: enable WPA_SUPPLICANT support
++  * Staging: Add ServerEngines benet 10Gb ethernet driver
++  * Staging: benet: fix netif api breakage
++  * Staging: benet: fix up netdev->priv change
++  * Staging: benet: build is broken unless CONFIG_NETPOLL is enabled
++  * Staging: benet: patch to remove subdirectories
++  * Staging: benet: fix build errors when CONFIG_NETPOLL is off
++  * Staging: benet: fix build error.
++  * Staging: benet: patch to use offsetof() instead of AMAP_BYTE_OFFSET()
++  * Staging: benet: fix problems reported by checkpatch
++  * Staging: benet: cleanup a check while posting rx buffers
++  * Staging: add comedi core
++  * Staging: comedi: fix up a lot of checkpatch.pl warnings
++  * Staging: comedi: fix checkpatch.pl errors in comedi_fops.c
++  * Staging: comedi: fix build error in comedilib.h
++  * Staging: comedi: add kcomedilib to the tree
++  * Staging: comedi: set up infrastructure for individual drivers
++  * Staging: comedi: add local copy of interrupt.h
++  * Staging: comedi: add pci and usb wrapper header files
++  * Staging: comedi: comedi driver common function module
++  * Staging: comedi: add mite comedi pci driver
++  * Staging: comedi: add usb usbdux driver
++  * Staging: comedi: add usb usbduxfast driver
++  * Staging: comedi: add usb dt9812 driver
++  * Staging: comedi: add comedi_bond driver
++  * Staging: comedi: add comedi_test driver
++  * Staging: comedi: add comedi_parport driver
++  * Staging: comedi: dt9812: fix up a lot of coding style issues
++  * Staging: comedi: dt9812: remove dt9812.h
++  * Staging: comedi: dt9812: remove typedefs
++  * Staging: comedi: dt9812: fix sparse warnings
++  * Staging: comedi: usbdux: remove kernel version checks
++  * Staging: comedi: usbdux: code style cleanups
++  * Staging: comedi: usbdux: remove // comments
++  * Staging: comedi: usbdux: fix up printk calls
++  * Staging: comedi: usbdux: remove checkpatch.pl warnings
++  * Staging: comedi: usbdux: remove typedef
++  * Staging: comedi: usbdux: remove comedi usb wrappers
++  * Staging: comedi: usbduxfast: remove comedi usb wrappers
++  * Staging: comedi: dt9812: remove #ifdef that is not needed
++  * Staging: comedi: remove usb wrappers
++  * Staging: comedi: remove PCI wrappers
++  * Staging: comedi: add icp_multi driver
++  * Staging: comedi: add me4000 driver
++  * Staging: comedi: fix checkpatch.pl issues in comedi_bond.c
++  * Staging: comedi: fix checkpatch.pl issues in comedi_fc.c
++  * Staging: comedi: remove typedefs from comedi_bond.c
++  * Staging: comedi: fix sparse issues in comedi_bond.c
++  * Staging: comedi: fix checkpatch.pl issues in comedi_test.c
++  * Staging: comedi: fix sparse issues in comedi_test.c
++  * Staging: comedi: remove typedefs from comedi_test.c
++  * Staging: comedi: fix comedi_parport.c checkpatch.pl issues.
++  * Staging: comedi: fix comedi_fc.h checkpatch.pl issues.
++  * Staging: comedi: fix comedi_pci.h checkpatch.pl issues.
++  * Staging: comedi: comedi_pci.h: remove unneeded wrapper
++  * Staging: comedi: comedi_pci.h: remove comedi_pci_enable_no_regions
++  * Staging: comedi: comedi_pci.h: remove comedi_pci_disable_no_regions
++  * Staging: comedi: add s626 driver
++  * Staging: comedi: add rtd520 driver
++  * Staging: comedi: add me_daq driver
++  * Staging: comedi: me_daq: fix checkpatch.pl issues
++  * Staging: comedi: me_daq: remove typedefs
++  * Staging: comedi: me_daq: fix sparse issues
++  * Staging: comedi: fix checkpatch.pl warning in interrupt.h
++  * Staging: comedi: fix build if CONFIG_PROC_FS is not set
++  * Staging: add asus_oled driver
++  * Staging: asus_oled: fix build dependancy
++  * Staging: Add the Meilhaus ME-IDS driver package
++  * Staging: meilhaus: fix __symbol_get problems
++  * Staging: add lcd-panel driver
++  * Staging: panel: major checkpatch cleanup
++  * Staging: panel: remove ifdefs and code for pre-2.6 kernels
++  * Staging: panel: remove support for smartcards
++  * Staging: add Driver for Altera PCI Express Chaining DMA reference design
++  * Staging: add rtl8187se driver
++  * Staging: rtl8187se: remove unneeded files
++  * Staging: rtl8187se: make the built module be the proper name
++  * Staging: rtl8187se: remove duplicate pci ids
++  * Staging: me4000: switch to list_for_each*()
++  * Staging: usbip: switch to list_for_each_entry()
++  * Staging: add princeton instruments usb camera driver
++  * Staging: add mimio xi driver
++  * Staging: add rt2870 wireless driver
++  * Staging: rt2870: disable root hack for reading files
++  * Staging: rt2870: fix up netdev->priv usage
++  * Staging: add frontier tranzport and alphatrack drivers
++  * Staging: frontier: remove unused alphatrack_sysfs.c file
++  * Staging: frontier: fix compiler warnings
++  * Staging: add epl stack
++  * Staging: epl: run Lindent on all kernel/*.h files
++  * Staging: epl: run Lindent on all user/*.h files
++  * Staging: epl: run Lindent on *.h files
++  * Staging: epl: run Lindent on *.c files
++  * Staging: epl: hr timers all run in hard irq context now
++  * Staging: epl: fix netdev->priv b0rkage
++  * Staging: add android framework
++  * Staging: android: add binder driver
++  * Staging: android: binder: Fix gcc warnings about improper format specifiers for size_t in printk
++  * staging: android: binder: Fix use of euid
++  * Staging: android: add logging driver
++  * Staging: android: add ram_console driver
++  * Staging: android: add timed_gpio driver
++  * Staging: android: timed_gpio: Rename android_timed_gpio to timed_gpio
++  * Staging: android: remove dummy android.c driver
++  * Staging: android: add lowmemorykiller driver
++  * Staging: android: binder: fix build errors
++  * staging: __FUNCTION__ is gcc-specific, use __func__
++  * V4L/DVB (10176a): Switch remaining clear_user_page users over to
++    clear_user_highpage
++
++  [ Zhenyu Wang ]
++
++  * agp/intel: add support for G41 chipset
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 18 Jan 2009 20:22:54 -0700
++
++linux (2.6.28-4.11) jaunty; urgency=low
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Enable HDMI audio codec on Studio XPS 1340
++    - LP: #309508
++
++  [ Tim Gardner ]
++
++  * Fix armel d-i FTBSs
++
++  [ Upstream Kernel Changes ]
++
++  * USB: re-enable interface after driver unbinds
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Jan 2009 16:33:08 -0700
++
++linux (2.6.28-4.10) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update kernel bootloader recommends: to prefer grub
++    - LP: #314004
++  * SAUCE: don't use buggy _BCL/_BCM/_BQC for backlight control
++    - LP: #311716
++  * SAUCE: test-suspend -- add the suspend test scripts
++    - LP: #316419
++
++  [ Colin Watson ]
++
++  * Enable udebs for armel
++
++  [ Tim Gardner ]
++
++  * SAUCE: Dell laptop digital mic does not work, PCI 1028:0271
++    - LP: #309508
++  * Enable CIFS_XATTR=y and CONFIG_CIFS_POSIX=y
++    - LP: #220658
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jan 2009 10:38:22 -0700
++
++linux (2.6.28-4.9) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Restore DM_CRYPT, AES, ECB, and CBC as modules. This fixes
++    some installer issues with encrypted /home and Private directories.
++  * Take one more stab at building armel without module or ABI errors.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jan 2009 08:38:23 -0700
++
++linux (2.6.28-4.8) jaunty; urgency=low
++
++  * Fix i386/amd64 FTBS by ignoring all module and ABI changes,
++    not something you would normally do, but I'm sure the ABI
++    has not changed. This will probably also allow the ARM builds to complete.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Jan 2009 14:42:58 -0700
++
++linux (2.6.28-4.7) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable CONFIG_ATH5K=m for i386/amd64
++    - LP: #306719
++  * Build all i386/amd64 AGP/DRM components as modules.
++    - LP: #312721
++  * git commands are now installed outside the default $PATH
++    Use 'git  CMD' instead of 'git-CMD'.
++  * Build in most PATA/SATA drivers. This should allow most i386/amd64 systems to boot
++    without an initramfs, though some support work is still required in initramfs-tools
++    and grub.
++    - LP: #311730
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 02 Jan 2009 07:33:09 -0700
++
++linux (2.6.28-4.6) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Enable CONFIG_X86_E_POWERSAVER=m for i386 generic
++    - LP: #237405
++  * Build i386 AGP drivers as modules
++    - LP: #312721
++  * Build i386 DRM as a module
++    - LP: #312721
++
++  [ Upstream Kernel Changes ]
++
++  * drm/i915: Add missing userland definitions for gem init/execbuffer.
++    - LP: #308387
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Dec 2008 09:16:47 -0700
++
++linux (2.6.28-4.5) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * clean up module dependancy information on package removal/purge
++    - LP: #300773
++
++  [ Tim Gardner ]
++
++  * Update iscsitarget to 0.4.17
++  * Build in ext{234}
++  * Build in Crypto modules AES, CBC, ECB
++  * Build in ACPI AC,BATTERY,BUTTON,FAN,PCI_SLOT,PROCESSOR,SBS,THERMAL,WMI
++  * Build in AGP intel,via,sis,ali,amd,amd64,efficeon,nvidia,sworks
++  * Build in ata,dev_dm,dev_loop,dev_md,dev_sd,dev_sr
++  * Build in BT l2cap,rfcomm,sco
++  * Reduce CONFIG_LEGACY_PTY_COUNT to 0
++  * Build in CDROM_PKTCDVD and CHR_DEV_SG
++  * Build in CPU_FREQ
++    GOV_CONSERVATIVE,GOV_ONDEMAND,GOV_POWERSAVE,GOV_USERSPACE,STAT,TABLE
++  * Build in DM CRYPT,MIRROR,MULTIPATH,SNAPSHOT
++  * Build in DRM
++  * Build in HID
++  * Build in HOTPLUG PCI,PCIE
++  * Build in I2C
++  * Build in IEEE1394 OHCI1394
++  * Build in INPUT EVDEV
++  * Build in IPV6
++  * Build in MMC
++  * Build in PACKET
++  * Enable both IEEE1394 (Firewire) stacks as modules
++    - LP: #276463
++  * Disable SUNRPC_REGISTER_V4
++    - LP: #306016
++  * Enable dm-raid4-5
++    - LP: #309378
++  * Build in PPP
++  * Build in RFKILL
++  * Build in USB SERIAL
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 18 Dec 2008 21:18:44 -0700
++
++linux (2.6.28-3.4) jaunty; urgency=low
++
++  [ Tim Gardner ]
++
++  * Build ecryptfs into the kernel
++    - LP: #302870
++  * Deprecated gnbd
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28-rc8
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 10 Dec 2008 22:45:13 -0700
++
++linux (2.6.28-2.3) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * update the templates so that we have spaces following the title line
++
++  [ Tim Gardner ]
++
++  * Add upload number to kernel version signature. This has the side effect
++    of renaming kernel packages back to the original way, e.g., without '-ub'
++    in the name.
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 04 Dec 2008 12:18:31 -0700
++
++linux (2.6.28-2.2) jaunty; urgency=low
++
++  [ Andy Whitcroft ]
++
++  * Revert "SAUCE: (no-up) version: Implement version_signature proc file."
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: serial: RS485 ioctl structure uses __u32 include linux/types.h
++    - LP: #303711
++
++  [ Tim Gardner ]
++
++  * UBUNTU: Removed CONFIG_DRM_VIA_CHROME9 since it is upstream.
++  * UBUNTU: Removed ubuntu/via_chrome9
++
++  [ Upstream Kernel Changes ]
++
++  * Rebased to v2.6.28-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Dec 2008 07:33:32 -0700
++
++linux (2.6.28-1.1) jaunty; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++  * SAUCE: Adds support for COMPAL JHL90 webcam
++  * Map armel to arm to all editconfigs to work correctly
++  * Add armel to getabis for completeness sake
++  * Add -ub to our versioning to allow kerneloops.org to identify us
++
++  [ Andy Whitcroft ]
++
++  * Fix Vcs-Git path for the kernel repository.
++    - LP: #296915
++
++  [ Ben Collins ]
++
++  * SAUCE: Lower warning level of some PCI messages
++    - LP: #159241
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: (no-up) connector.h: Add idx/val for drbd
++  * SAUCE: (no-up) swap: Add notify_swap_entry_free callback for compcache
++  * SAUCE: drivers: Remove some duplicate device entries in various modules
++  * SAUCE: (no-up) [AppArmor] merge with upstream subversion r1291
++  * SAUCE: (no-up) Enable ubuntu extra subdirectory
++  * SAUCE: (no-up) ACPI: initramfs DSDT override support
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add BOM for iscsitarget
++  * ubuntu: Add squashfs driver
++  * SAUCE: (no-up) Check for squashfs superblock in initramfs mounting.
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Added et131x driver
++  * ubuntu: Add dm-raid4-5 driver
++  * ubuntu: Add ndiswrapper driver
++  * ubuntu: Added ram backed compressed swap module (compcache)
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add ov511 and bt-sco drivers
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * ubuntu: Add at76 driver to build
++  * ubuntu: Add fsam7400 sw kill switch driver
++  * ubuntu: Added qc-usb driver
++  * ubuntu: e1000e: Upgraded module to 0.4.1.7
++  * ubuntu: Added rfkill drivers
++  * ubuntu: VIA - Add VIA DRM Chrome9 3D engine
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * ubuntu: Add LIRC driver
++  * ubuntu: Add GFS driver
++  * ubuntu: New tlsup driver for toshiba laptops
++  * SAUCE: (no-up) Export lookup_has for aufs
++  * SAUCE: (no-up) Modularize vesafb
++  * ubuntu: Config files
++  * Disable some modules that need porting to 2.6.28
++  * ubuntu: Fixup headers creation to include arch/*/include
++  * ubuntu/module-check: Ignore comment lines
++
++  [ Chuck Short ]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++
++  [ cking ]
++
++  * SAUCE: Enable speedstep for sonoma processors.
++
++  [ Colin Ian King ]
++
++  * ubuntu: Add dm-loop
++  * SAUCE: cx88: Support Leadtek WinFast DTV2000 H version J.
++  * SAUCE: fix kernel oops in VirtualBox during paravirt patching
++  * SAUCE: qc-usb: Enable Logitech QuickCam Messenger
++  * SAUCE: appleir: Enable driver for new MacBook Pro
++
++  [ Colin Watson ]
++
++  * Enable configfs, fuse, jfs, reiserfs, and xfs for armel
++  * Extend debian/d-i/ modules handling to make armel easier to support
++  * Create udebs for armel
++
++  [ Fabio M. Di Nitto ]
++
++  * ubuntu: update GFS Cluster File System
++
++  [ Kees Cook ]
++
++  * SAUCE: AppArmor: update to upstream subversion r1302
++
++  [ Leann Ogasawara ]
++
++  * Add automatic model setting for Samsung Q45
++  * Add Dell Dimension 9200 reboot quirk
++
++  [ Mackenzie Morgan ]
++
++  * SAUCE: Add quirk for ASUS Z37E to make sound audible after resume
++
++  [ Matthew Garrett ]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++
++  [ Michael Haas ]
++
++  * add proper aufs source tree from 20080922
++  * Fix AUFS compilation in vfsub.c
++  * Add splice-2.6.23.patch from AUFS to export a symbol needed by AUFS
++  * Add put_filp.patch from AUFS to export a symbol needed by AUFS
++  * Add deny_write_access.patch from AUFS - export deny_write_access
++  * Add sec_perm-2.6.24.patch from AUFS - export security_inode_permission
++  * make sure TMPFS_MAGIC is defined in AUFS Makefile
++  * SAUCE: Revert aufs changes from AppArmor merge
++
++  [ Mohamed Abbas ]
++
++  * SAUCE: iwlagn -- fix rfkill when on when driver loaded
++
++  [ Phillip Lougher ]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++  * gfs1: GFS1 can't create more than 4kb file
++  * uvcvideo: Commit streaming parameters when enabling the video stream.
++
++  [ Tim Gardner ]
++
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: (no-up) Take care of orinoco_cs overlap with hostap_cs
++  * ubuntu: Add GNBD driver
++  * SAUCE: e1000e: Map NV RAM dynamically only when needed.
++  * SAUCE: Correctly blacklist Thinkpad r40e in ACPI
++  * SAUCE: Update Wacom tablet driver to 1.49
++  * SAUCE: Fix Wacom tablet 1.49 porting errors
++  * SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit controller
++  * SAUCE: Fix Oops in wlan_setup
++  * SAUCE: ipw2200: change default policy for auto-associate
++  * Dell Wireless 365 needs BTUSB_RESET quirk.
++  * ndiswrapper remote buffer overflows on long ESSIDs (CVE 2008-4395)
++  * Disabled ubuntu/e1000e config
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++  * Revert "x86, early_ioremap: fix fencepost error"
++  * mac80211: fix two issues in debugfs
++  * iwl3945: do not send scan command if channel count zero
++
++ --  Ben Collins <ben.collins@canonical.com>  Fri, 07 Nov 2008 09:37:42 -0700
++
++linux (2.6.27-8.17) intrepid-proposed; urgency=low
++
++  [ John W. Linville ]
++
++  * SAUCE: iwlagn: avoid sleep in softirq context
++    -LP: #286285
++
++  [ Tim Gardner ]
++
++  * Dell Wireless 365 needs BTUSB_RESET quirk.
++    - LP: #293670
++  * SAUCE: ALSA: hda: make a STAC_DELL_EQ option (version 2)
++    - LP: #293271
++
++  [ Upstream Kernel Changes ]
++
++  * iwlagn: downgrade BUG_ON in interrupt
++  * Input: atkbd - expand Latitude's force release quirk to other Dells
++  * fbcon_set_all_vcs: fix kernel crash when switching the rotated consoles
++  * modules: fix module "notes" kobject leak
++  * Driver core: Fix cleanup in device_create_vargs().
++  * Driver core: Clarify device cleanup.
++  * ath9k/mac80211: disallow fragmentation in ath9k, report to userspace
++  * md: Fix rdev_size_store with size == 0
++  * xfs: fix remount rw with unrecognized options
++  * OHCI: Allow broken controllers to auto-stop
++  * USB: OHCI: fix endless polling behavior
++  * USB: Fix s3c2410_udc usb speed handling
++  * USB: EHCI: log a warning if ehci-hcd is not loaded first
++  * usb gadget: cdc ethernet notification bugfix
++  * usb: musb_hdrc build fixes
++  * drm/i915: fix ioremap of a user address for non-root (CVE-2008-3831)
++  * DVB: au0828: add support for another USB id for Hauppauge HVR950Q
++  * DVB: sms1xxx: support two new revisions of the Hauppauge WinTV
++    MiniStick
++  * security: avoid calling a NULL function pointer in
++    drivers/video/tvaudio.c
++  * Linux 2.6.27.3
++    -LP: #294152
++
++  * gpiolib: fix oops in gpio_get_value_cansleep()
++  * edac cell: fix incorrect edac_mode
++  * x86 ACPI: fix breakage of resume on 64-bit UP systems with SMP kernel
++  * sched: fix the wrong mask_len
++  * USB: cdc-wdm: make module autoload work
++  * USB: don't rebind drivers after failed resume or reset
++  * USB: fix memory leak in cdc-acm
++  * USB: Speedtouch: add pre_reset and post_reset routines
++  * dm kcopyd: avoid queue shuffle
++  * dm snapshot: fix primary_pe race
++  * amd_iommu: fix nasty bug that caused ILLEGAL_DEVICE_TABLE_ENTRY errors
++  * CIFS: fix saving of resume key before CIFSFindNext
++  * netfilter: xt_iprange: fix range inversion match
++  * netfilter: snmp nat leaks memory in case of failure
++  * netfilter: restore lost ifdef guarding defrag exception
++  * anon_vma_prepare: properly lock even newly allocated entries
++  * hvc_console: Fix free_irq in spinlocked section
++  * ACPI Suspend: Enable ACPI during resume if SCI_EN is not set
++  * ACPI suspend: Blacklist HP xw4600 Workstation for old code ordering
++  * ACPI suspend: Always use the 32-bit waking vector
++  * proc: fix vma display mismatch between /proc/pid/{maps,smaps}
++  * SCSI: scsi_dh: add Dell product information into rdac device handler
++  * PCI hotplug: cpqphp: fix kernel NULL pointer dereference
++  * V4L/DVB (9300): pvrusb2: Fix deadlock problem
++  * Linux 2.6.27.4
++    -LP: #294155
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Tue, 04 Nov 2008 12:16:07 -0700
++
++linux (2.6.27-7.16) intrepid-security; urgency=low
++
++  [ Tim Gardner ]
++
++  * ndiswrapper remote buffer overflows on long ESSIDs (CVE 2008-4395)
++    - LP: #275860
++
++  [ Upstream Kernel Changes ]
++
++  * ext[234]: Avoid printk floods in the face of directory corruption
++    (CVE-2008-3528)
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 03 Nov 2008 13:34:42 -0700
++
++linux (2.6.27-7.15) intrepid-security; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * tcp: Restore ordering of TCP options for the sake of inter-operability
++    - LP: #264019
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Mon, 27 Oct 2008 19:28:06 -0600
++
++linux (2.6.27-7.14) intrepid; urgency=low
++
++  [ Tim Gardner ]
++
++  * Disable ath5k in 2.6.27
++    - LP: #288148
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Thu, 23 Oct 2008 07:40:43 -0600
++
++linux (2.6.27-7.13) intrepid; urgency=low
++
++  [ Stefan Bader ]
++
++  * gfs1: GFS1 can't create more than 4kb file
++
++  [ Tim Gardner ]
++
++  * Revert "SAUCE: x86: Reserve FIRST_DEVICE_VECTOR in used_vectors
++    bitmap.". Use upstream commit to avoid future conflicts.
++  * Revert "STABLE queue: mac80211: fix two issues in debugfs".
++    Use upstream commit to avoid future conflicts.
++  * Revert "x86, early_ioremap: fix fencepost error"
++    Use upstream commit to avoid future conflicts.
++
++  [ Upstream Kernel Changes ]
++
++  * sched_rt.c: resch needed in rt_rq_enqueue() for the root rt_rq
++  * x86: Reserve FIRST_DEVICE_VECTOR in used_vectors bitmap.
++  * mac80211: fix two issues in debugfs
++  * Fix barrier fail detection in XFS
++  * tty: Termios locking - sort out real_tty confusions and lock reads
++  * CIFS: make sure we have the right resume info before calling
++    CIFSFindNext
++  * rfkill: update LEDs for all state changes
++  * libertas: clear current command on card removal
++  * b43legacy: Fix failure in rate-adjustment mechanism
++  * x86, early_ioremap: fix fencepost error
++  * x86: SB450: skip IRQ0 override if it is not routed to INT2 of IOAPIC
++  * x86: improve UP kernel when CPU-hotplug and SMP is enabled
++  * sky2: Fix WOL regression
++  * netdrvr: atl1e: Don't take the mdio_lock in atl1e_probe
++  * Linux 2.6.27.2
++
++  [ Amit Kucheria ]
++
++  * Ubuntu: agp: Fix stolen memory counting on G4X.
++    -LP: 285572
++
++  [ Scott Remnant ]
++
++  * add MODULE_ALIAS to load ipmi_devintf with ipmi_si
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 19 Oct 2008 10:06:21 -0600
++
++linux (2.6.27-7.12) intrepid; urgency=low
++
++  [ Chuck Short ]
++
++  * xen: Add xen modules to virtual flavours.
++
++  [ Mario Limonciello ]
++
++  * SAUCE: Add back in lost commit for Apple BT Wireless Keyboard
++    - LP: #162083
++
++  [ Tim Gardner ]
++
++  * Remove depmod created files from packages.
++    - LP: #250511
++  *  Changed default TCP congestion algorithm to 'cubic' (again)
++    - LP: #278801
++  * Update configs for 'disable CONFIG_DYNAMIC_FTRACE'
++    - LP: #263555
++
++  [ Upstream Kernel Changes ]
++
++  * x86: register a platform RTC device if PNP doesn't describe it
++  * disable CONFIG_DYNAMIC_FTRACE due to possible memory corruption on
++    module unload
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 17 Oct 2008 11:25:39 -0600
++
++linux (2.6.27-7.11) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * STABLE queue: mac80211: fix two issues in debugfs
++    - LP: #275227
++  * SAUCE: Adds support for COMPAL JHL90 webcam
++
++  [ Ben Collins ]
++
++  * SAUCE: (no-up) x86: Quiet "Kernel alive" messages
++    - LP: #39985
++  * SAUCE: (no-up) Modularize vesafb
++  * build/config: Enable vesafb module
++  * build: Switch to vesafb as preferred.
++
++  [ Leann Ogasawara ]
++
++  * Add Dell Dimension 9200 reboot quirk
++    - LP: #271370
++
++  [ Michael Haas ]
++
++  * SAUCE: Revert aufs changes from AppArmor merge
++
++  [ Tim Gardner ]
++
++  * fix virtio udeb layout
++    - LP: #257739
++  * Enabled CONFIG_EXT4DEV_FS=m
++  * Changed default TCP congestion algorithm to 'cubic'
++    - LP: #278801
++  * SAUCE: ipw2200: change default policy for auto-associate
++    - LP: #264104
++
++  [ Upstream Kernel Changes ]
++
++  * x86, early_ioremap: fix fencepost error
++    - LP: #263543
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sat, 11 Oct 2008 08:07:42 -0600
++
++linux (2.6.27-7.10) intrepid; urgency=low
++
++  [ Alexey Starikovskiy ]
++
++  * SAUCE: ACPI: EC: do transaction from interrupt context
++    - LP: #277802
++
++  [ Ben Collins ]
++
++  * build/d-i: Change virtio-modules udeb to prio standard
++
++  [ Colin Ian King ]
++
++  * SAUCE: Blacklist IBM 2656 in serio/i8042
++    - LP: #21558
++
++  [ Henrik Rydberg ]
++
++  * Revert "SAUCE: applesmc: Add MacBookAir"
++  * SAUCE: [PATCH 1/5] hwmon: applesmc: Specified number of bytes to read
++    should match actual
++  * SAUCE: [PATCH 2/5] hwmon: applesmc: Fix the 'wait status failed: c !=
++    8' problem
++  * SAUCE: [PATCH 3/5] hwmon: applesmc: Prolong status wait
++  * SAUCE: [PATCH 4/5] hwmon: applesmc: Allow for variable ALV0 and ALV1
++    package length
++  * SAUCE: [PATCH 5/5] hwmon: applesmc: Add support for Macbook Air
++  * SAUCE: hwmon: applesmc: Add support for Macbook Pro 4
++  * SAUCE: hwmon: applesmc: Add support for Macbook Pro 3
++  * SAUCE: hwmon: applesmc: Lighter wait mechanism, drastic improvement
++
++  [ Leann Ogasawara ]
++
++  * Add automatic model setting for Samsung Q45
++    - LP: #200210
++
++  [ Tim Gardner ]
++
++  * SAUCE: Correctly blacklist Thinkpad r40e in ACPI
++    - LP: #278794
++  * SAUCE: Update Wacom tablet driver to 1.49
++    - LP: #260675
++  * SAUCE: ALPS touchpad for Dell Latitude E6500/E6400
++    - LP: #270643
++  * SAUCE: Fix Wacom tablet 1.49 porting errors
++  * SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit controller
++  * SAUCE: Fix Oops in wlan_setup
++    - LP: #263309
++
++  [ Upstream Kernel Changes ]
++
++  * ath9k: fix oops on trying to hold the wrong spinlock
++  * [Bluetooth] Fix double frees on error paths of btusb and bpa10x drivers
++  * [Bluetooth] Add reset quirk for new Targus and Belkin dongles
++  * [Bluetooth] Add reset quirk for A-Link BlueUSB21 dongle
++  * Revert "ax25: Fix std timer socket destroy handling."
++  * ax25: Quick fix for making sure unaccepted sockets get destroyed.
++  * netrom: Fix sock_orphan() use in nr_release
++  * Revert "V4L/DVB (8904): cx88: add missing unlock_kernel"
++  * SLOB: fix bogus ksize calculation
++  * net: only invoke dev->change_rx_flags when device is UP
++  * tcp: Fix possible double-ack w/ user dma
++  * net: Fix netdev_run_todo dead-lock
++  * tcp: Fix tcp_hybla zero congestion window growth with small rho and large cwnd.
++  * [MIPS] Sibyte: Register PIO PATA device only for Swarm and Litte Sur
++  * eeepc-laptop: Fix hwmon interface
++  * hwmon: (it87) Prevent power-off on Shuttle SN68PT
++  * hwmon: Define sysfs interface for energy consumption register
++  * hwmon: (adt7473) Fix some bogosity in documentation file
++  * hwmon: (abituguru3) Enable reading from AUX3 fan on Abit AT8 32X
++  * hwmon: (abituguru3) Enable DMI probing feature on Abit AT8 32X
++  * [CPUFREQ] correct broken links and email addresses
++  * SLOB: fix bogus ksize calculation fix
++  * Don't allow splice() to files opened with O_APPEND
++  * Linux 2.6.27
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Wed, 08 Oct 2008 21:19:34 -0600
++
++linux (2.6.27-6.9) intrepid; urgency=low
++
++  [ Kees Cook ]
++
++  * SAUCE: AppArmor: update to upstream subversion r1302
++    - LP: #269921
++
++  [ Stefan Bader ]
++
++  * Update configuration files to be compliant to desktop specs
++    - LP: #279019
++
++  [ Tim Gardner ]
++
++  * Add support in e1000e for a couple of ICH10 PCI IDs
++  * Enable CONFIG_INPUT_PCSPKR=m
++    - LP: #275453
++
++  [ Upstream Kernel Changes ]
++
++  * V4L/DVB (8559a): Fix a merge conflict at gspca/sonixb
++  * V4L/DVB (8789): wm8739: remove wrong kfree
++  * V4L/DVB (8883): w9968cf: Fix order of usb_alloc_urb validation
++  * V4L/DVB (8884): em28xx-audio: fix memory leak
++  * V4L/DVB (8885): cpia2_usb: fix memory leak
++  * V4L/DVB (8886): ov511: fix memory leak
++  * V4L/DVB (8887): gspca: fix memory leak
++  * V4L/DVB (8892): pvrusb2: Handle USB ID 2040:2950 same as 2040:2900
++  * V4L/DVB (8904): cx88: add missing unlock_kernel
++  * V4L/DVB (8905): ov511: fix exposure sysfs attribute bug
++  * V4L/DVB (8909): gspca: PAC 7302 webcam 093a:262a added.
++  * hrtimer: migrate pending list on cpu offline
++  * hrtimer: fix migration of CB_IRQSAFE_NO_SOFTIRQ hrtimers
++  * hrtimer: mark migration state
++  * hrtimer: prevent migration of per CPU hrtimers
++  * [IA64] Put the space for cpu0 per-cpu area into .data section
++  * powerpc: Fix PCI in Holly device tree
++  * powerpc: Fix failure to shutdown with CPU hotplug
++  * mfd: Fix Kconfig accroding to the new gpiolib symbols
++  * mfd: Fix asic3 compilation
++  * x86: fix typo in enable_mtrr_cleanup early parameter
++  * ipsec: Fix pskb_expand_head corruption in xfrm_state_check_space
++  * iucv: Fix mismerge again.
++  * ALSA: ASoC: Fix cs4270 error path
++  * ALSA: hda - Fix model for Dell Inspiron 1525
++  * sctp: Fix kernel panic while process protocol violation parameter
++  * x86: Fix broken LDT access in VMI
++  * x86, vmi: fix broken LDT access
++  * tcp: Fix NULL dereference in tcp_4_send_ack()
++  * ipv6: NULL pointer dereferrence in tcp_v6_send_ack
++  * XFRM,IPv6: initialize ip6_dst_blackhole_ops.kmem_cachep
++  * af_key: Free dumping state on socket close
++  * dm: always allow one page in dm_merge_bvec
++  * dm: cope with access beyond end of device in dm_merge_bvec
++  * dm mpath: add missing path switching locking
++  * MN10300: Fix IRQ handling
++  * pxa2xx_spi: fix build breakage
++  * e1000e: write protect ICHx NVM to prevent malicious write/erase
++  * powerpc: Fix boot hang regression on MPC8544DS
++  * ASoC: Set correct name for WM8753 rec mixer output
++  * ALSA: snd-powermac: mixers for PowerMac G4 AGP
++  * ALSA: snd-powermac: HP detection for 1st iMac G3 SL
++  * fbcon: fix monochrome color value calculation
++  * inotify: fix lock ordering wrt do_page_fault's mmap_sem
++  * braille_console: only register notifiers when the braille console is used
++  * fix error-path NULL deref in alloc_posix_timer()
++  * memory hotplug: missing zone->lock in test_pages_isolated()
++  * mm: tiny-shmem nommu fix
++  * mm: handle initialising compound pages at orders greater than MAX_ORDER
++  * e1000e: reset swflag after resetting hardware
++  * e1000e: do not ever sleep in interrupt context
++  * e1000e: remove phy read from inside spinlock
++  * e1000e: drop stats lock
++  * e1000e: debug contention on NVM SWFLAG
++  * e1000e: update version from k4 to k6
++  * Check mapped ranges on sysfs resource files
++  * e1000e: Fix incorrect debug warning
++  * [MIPS] Build fix: Fix irq flags type
++  * [MIPS] SMTC: Build fix: Fix filename in Makefile
++  * [MIPS] SMTC: Fix holes in SMTC and FPU affinity support.
++  * [MIPS] SMTC: Close tiny holes in the SMTC IPI replay system.
++  * [MIPS] SMTC: Fix SMTC dyntick support.
++  * [S390] nohz: Fix __udelay.
++  * [S390] qdio: prevent stack clobber
++  * Fix init/main.c to use regular printk with '%pF' for initcall fn
++  * x86 setup: correct segfault in generation of 32-bit reloc kernel
++  * selinux: Fix an uninitialized variable BUG/panic in selinux_secattr_to_sid()
++  * rtc: fix kernel panic on second use of SIGIO nofitication
++  * fbdev: fix recursive notifier and locking when fbdev console is blanked
++  * orion_spi: fix handling of default transfer speed
++  * include/linux/stacktrace.h: declare struct task_struct
++  * cpusets: remove pj from cpuset maintainers
++  * MAINTAINERS: add mailing list for man-pages
++  * SubmitChecklist: interfaces changes should CC linux-api@
++  * Documentation/HOWTO: info about interface changes should CC linux-api@vger
++  * dw_dmac: fix copy/paste bug in tasklet
++  * leds-fsg: change order of initialization and deinitialization
++  * leds-pca955x: add proper error handling and fix bogus memory handling
++  * ACPI: Make /proc/acpi/wakeup interface handle PCI devices (again)
++  * clockevents: check broadcast tick device not the clock events device
++  * V4L/DVB (8919): cx18: Fix tuner audio input for Compro H900 cards
++  * V4L/DVB (8926): gspca: Bad fix of leak memory (changeset 43d2ead315b1).
++  * V4L/DVB (8933): gspca: Disable light frquency for zc3xx cs2102 Kokom.
++  * V4L/DVB (8935): em28xx-cards: Remove duplicate entry (EM2800_BOARD_KWORLD_USB2800)
++  * V4L/DVB (8955): bttv: Prevent NULL pointer dereference in radio_open
++  * V4L/DVB (8957): zr36067: Restore the default pixel format
++  * V4L/DVB (8958): zr36067: Return proper bytes-per-line value
++  * V4L/DVB (8960): drivers/media/video/cafe_ccic.c needs mm.h
++  * V4L/DVB (8961): zr36067: Fix RGBR pixel format
++  * V4L/DVB (8963): s2255drv field count fix
++  * V4L/DVB (8967): Use correct XC3028L firmware for AMD ATI TV Wonder 600
++  * V4L/DVB (8978): sms1xxx: fix product name for Hauppauge WinTV MiniStick
++  * V4L/DVB (8979): sms1xxx: Add new USB product ID for Hauppauge WinTV MiniStick
++  * V4L/DVB (9029): Fix deadlock in demux code
++  * V4L/DVB (9037): Fix support for Hauppauge Nova-S SE
++  * V4L/DVB (9043): S5H1420: Fix size of shadow-array to avoid overflow
++  * V4L/DVB (9053): fix buffer overflow in uvc-video
++  * V4L/DVB (9075): gspca: Bad check of returned status in i2c_read() spca561.
++  * V4L/DVB (9080): gspca: Add a delay after writing to the sonixj sensors.
++  * V4L/DVB (9092): gspca: Bad init values for sonixj ov7660.
++  * V4L/DVB (9099): em28xx: Add detection for K-WORLD DVB-T 310U
++  * V4L/DVB (9103): em28xx: HVR-900 B3C0 - fix audio clicking issue
++  * x86: gart iommu have direct mapping when agp is present too
++  * ide-cd: temporary tray close fix
++  * ide-dma: fix ide_build_dmatable() for TRM290
++  * IDE: Fix platform device registration in Swarm IDE driver (v2)
++  * ide-cd: Optiarc DVD RW AD-7200A does play audio
++  * ide: workaround for bogus gcc warning in ide_sysfs_register_port()
++  * [MIPS] Fix CMP Kconfig configuration and mark as broken.
++  * [MIPS] IP27: Fix build errors if CONFIG_MAPPED_KERNEL=y
++  * x86 ACPI: Blacklist two HP machines with buggy BIOSes
++  * kgdb, x86: Avoid invoking kgdb_nmicallback twice per NMI
++  * kgdb: call touch_softlockup_watchdog on resume
++  * atmel-mci: Initialize BLKR before sending data transfer command
++  * Marker depmod fix core kernel list
++  * Linux 2.6.27-rc9
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 05 Oct 2008 21:27:49 -0600
++
++linux (2.6.27-5.8) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * Update AUFS-related Kconfig
++    - LP: #264048
++
++  [ Michael Haas ]
++
++  * add proper aufs source tree from 20080922
++  * Fix AUFS compilation in vfsub.c
++  * Add splice-2.6.23.patch from AUFS to export a symbol needed by AUFS
++  * Add put_filp.patch from AUFS to export a symbol needed by AUFS
++  * apply (modified) lhash.patch from AUFS to export __lookup_hash()
++  * Add deny_write_access.patch from AUFS - export deny_write_access
++  * Add sec_perm-2.6.24.patch from AUFS - export security_inode_permission
++  * make sure TMPFS_MAGIC is defined in AUFS Makefile
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_IPWIRELESS
++    - LP: #274748
++  * Enabled CONFIG_E1000E, disabled CONFIG_E1000E_NEW
++    This takes advantage of the upstream NVM protection fix in
++    commit 4a7703582836f55a1cbad0e2c1c6ebbee3f9b3a7.
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++  * [SCSI] qla2xxx: Defer enablement of RISC interrupts until ISP
++    initialization completes.
++  * PCI: Fix pcie_aspm=force
++  * PCI: fix compiler warnings in pci_get_subsys()
++  * UBIFS: create the name of the background thread in every case
++  * UBIFS: TNC / GC race fixes
++  * UBIFS: remove incorrect assert
++  * UBIFS: fix printk format warnings
++  * AMD IOMMU: set iommu sunc flag after command queuing
++  * AMD IOMMU: protect completion wait loop with iommu lock
++  * sparc64: Fix disappearing PCI devices on e3500.
++  * x86, oprofile: BUG scheduling while atomic
++  * ALSA: ASoC: Fix at32-pcm build breakage with PM enabled
++  * ath9k: connectivity is lost after Group rekeying is done
++  * wireless: zd1211rw: add device ID fix wifi dongle "trust nw-3100"
++  * [IA64] Ski simulator doesn't need check_sal_cache_flush
++  * [IA64] kexec fails on systems with blocks of uncached memory
++  * ath9k: Fix IRQ nobody cared issue with ath9k
++  * [Bluetooth] Fix I/O errors on MacBooks with Broadcom chips
++  * [Bluetooth] Fix wrong URB handling of btusb driver
++  * [Bluetooth] Fix USB disconnect handling of btusb driver
++  * sparc64: Fix missing devices due to PCI bridge test in
++    of_create_pci_dev().
++  * [WATCHDOG] ibmasr: remove unnecessary spin_unlock()
++  * [WATCHDOG] wdt285: fix sparse warnings
++  * [WATCHDOG] unlocked_ioctl changes
++  * x86: fix 27-rc crash on vsmp due to paravirt during module load
++  * sched: fix init_hrtick() section mismatch warning
++  * clockevents: prevent cpu online to interfere with nohz
++  * x86: prevent stale state of c1e_mask across CPU offline/online
++  * clockevents: prevent stale tick_next_period for onlining CPUs
++  * clockevents: check broadcast device not tick device
++  * clockevents: prevent mode mismatch on cpu online
++  * x86: prevent C-states hang on AMD C1E enabled machines
++  * x86: c1e_idle: don't mark TSC unstable if CPU has invariant TSC
++  * timers: fix build error in !oneshot case
++  * ALSA: ASoC: maintainers - update email address for Liam Girdwood
++  * ibmasr: remove unnecessary spin_unlock()
++  * smb.h: do not include linux/time.h in userspace
++  * kernel-doc: allow structs whose members are all private
++  * kexec: fix segmentation fault in kimage_add_entry
++  * Documentation/DMA-mapping.txt: update for pci_dma_mapping_error()
++    changes
++  * sys_paccept: disable paccept() until API design is resolved
++  * mm: tiny-shmem fix lock ordering: mmap_sem vs i_mutex
++  * Documentation/sysctl/kernel.txt: fix softlockup_thresh description
++  * memcg: check under limit at shrink_usage
++  * atmel_serial: update the powersave handler to match serial core
++  * [SCSI] Fix hang with split requests
++  * USB Storage: Sierra: Non-configurable TRU-Install
++  * USB Serial: Sierra: Device addition & version rev
++  * USB: ehci: fix some ehci hangs and crashes
++  * USB: Fix the Nokia 6300 storage-mode.
++  * USB: Correct Sierra Wireless USB EVDO Modem Device ID
++  * USB: fix hcd interrupt disabling
++  * USB: update of Documentation/usb/anchors.txt
++  * usb gadget: fix omap_udc DMA regression
++  * USB: Fixing Nokia 3310c in storage mode
++  * usb: musb: fix include path
++  * USB: fix EHCI periodic transfers
++  * usb-serial: Add Siemens EF81 to PL-2303 hack triggers
++  * USB: SERIAL CP2101 add device IDs
++  * USB: unusual_devs addition for RockChip MP3 player
++  * USB: fsl_usb2_udc: fix VDBG() format string
++  * usb serial: ti_usb_3410_5052 obviously broken by firmware changes
++  * USB: ftdi_sio: Add 0x5050/0x0900 USB IDs (Papouch Quido USB 4/4)
++  * USB: serial: add ZTE CDMA Tech id to option driver
++  * USB Serial: Sierra: Add MC8785 VID/PID
++  * USB: drivers/usb/musb/: disable it on SuperH
++  * usb: ftdi_sio: add support for Domintell devices
++  * usb: unusual devs patch for Nokia 5310 Music Xpress
++  * USB: revert recovery from transient errors
++  * [MIPS] au1000: Fix gpio direction
++  * [MIPS] Fixe the definition of PTRS_PER_PGD
++  * x86: prevent stale state of c1e_mask across CPU offline/online, fix
++  * x86: disable apm on the olpc
++  * i2c-powermac: Fix section for probe and remove functions
++  * i2c-dev: Return correct error code on class_create() failure
++  * i2c: Fix mailing lists in two MAINTAINERS entries
++  * ath9k: disable MIB interrupts to fix interrupt storm
++  * 9p: implement proper trans module refcounting and unregistration
++  * 9p-trans_fd: fix trans_fd::p9_conn_destroy()
++  * 9p-trans_fd: clean up p9_conn_create()
++  * 9p-trans_fd: don't do fs segment mangling in p9_fd_poll()
++  * 9p-trans_fd: fix and clean up module init/exit paths
++  * 9p: introduce missing kfree
++  * 9p: use an IS_ERR test rather than a NULL test
++  * 9p: fix put_data error handling
++  * netfilter: ip6t_{hbh,dst}: Rejects not-strict mode on rule insertion
++  * MN10300: Move asm-arm/cnt32_to_63.h to include/linux/
++  * MN10300: Make sched_clock() report time since boot
++  * ALSA: fix locking in snd_pcm_open*() and snd_rawmidi_open*()
++  * ALSA: remove unneeded power_mutex lock in snd_pcm_drop
++  * IPoIB: Fix crash when path record fails after path flush
++  * [XFS] Fix extent list corruption in xfs_iext_irec_compact_full().
++  * [XFS] Remove xfs_iext_irec_compact_full()
++  * kgdb: could not write to the last of valid memory with kgdb
++  * kgdb, x86, arm, mips, powerpc: ignore user space single stepping
++  * kgdb, x86_64: gdb serial has BX and DX reversed
++  * kgdb, x86_64: fix PS CS SS registers in gdb serial
++  * kgdboc,tty: Fix tty polling search to use name correctly
++  * ARM: Delete ARM's own cnt32_to_63.h
++  * m32r: remove the unused NOHIGHMEM option
++  * m32r: don't offer CONFIG_ISA
++  * m32r: export empty_zero_page
++  * m32r: export __ndelay
++  * m32r/kernel/: cleanups
++  * [MIPS] au1000: Make sure GPIO value is zero or one
++  * [MIPS] IP27: Switch to dynamic interrupt routing avoding panic on
++    error.
++  * [MIPS] BCM47xx: Fix build error due to missing PCI functions
++  * [SSB] Initialise dma_mask for SSB_BUSTYPE_SSB devices
++  * Swarm: Fix crash due to missing initialization
++  * ide-tape: fix vendor strings
++  * ide: note that IDE generic may prevent other drivers from attaching
++  * cdrom: update ioctl documentation
++  * [SCSI] qlogicpti: fix sg list traversal error in continuation entries
++  * sata_nv: reinstate nv_hardreset() for non generic controllers
++  * scsi: fix fall out of sg-chaining patch in qlogicpti
++  * ALSA: make the CS4270 driver a new-style I2C driver
++  * ALSA: ASoC: Fix another cs4270 error path
++  * Fix NULL pointer dereference in proc_sys_compare
++  * kconfig: fix silentoldconfig
++  * kconfig: readd lost change count
++  * mm owner: fix race between swapoff and exit
++  * Linux 2.6.27-rc8
++  * e1000e: write protect ICHx NVM to prevent malicious write/erase
++
++ -- Amit Kucheria <amit.kucheria@canonical.com>  Tue, 30 Sep 2008 18:22:35 +0300
++
++linux (2.6.27-4.7) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/abi: Add gfs1 to perm blacklist
++  * build/abi: Ignored changes in gfs2 symbols
++
++  [ Fabio M. Di Nitto ]
++
++  * Revert "SAUCE: Export gfs2 symbols required for gfs1 kernel module"
++  * ubuntu: update GFS Cluster File System
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86: Reserve FIRST_DEVICE_VECTOR in used_vectors bitmap.
++    - LP: #276334
++
++  [ Tim Gardner ]
++
++  * Revert "Disable e1000e until the NVRAM corruption problem is found."
++  * Add atl1e and atl2 to Debian installer bits
++    - LP: #273904
++  * SAUCE: e1000e: Map NV RAM dynamically only when needed.
++    - LP: #263555
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Fri, 26 Sep 2008 20:51:22 -0600
++
++linux (2.6.27-4.6) intrepid; urgency=low
++
++  [ Tim Gardner ]
++
++  * Disable e1000e until the NVRAM corruption problem is found.
++    - LP: #263555
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "[Bluetooth] Eliminate checks for impossible conditions in IRQ
++    handler"
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 23 Sep 2008 09:53:57 -0400
++
++linux (2.6.27-4.5) intrepid; urgency=low
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "b43/b43legacy: add RFKILL_STATE_HARD_BLOCKED support"
++  * udf: Fix lock inversion between iprune_mutex and alloc_mutex (v2)
++  * udf: Fix error paths in udf_new_inode()
++  * [SCSI] sd: select CRC_T10DIF only when necessary
++  * [SCSI] zfcp: Fix request queue locking
++  * [SCSI] zfcp: Correctly query end flag in gpn_ft response
++  * [SCSI] zfcp: Simplify ccw notify handler
++  * [SCSI] zfcp: Fix reference counter for remote ports
++  * [SCSI] zfcp: channel cannot be detached due to refcount imbalance
++  * [SCSI] zfcp: Remove duplicated unlikely() macros.
++  * [SCSI] scsi_dh: make check_sense return ADD_TO_MLQUEUE
++  * [SCSI] make scsi_check_sense HARDWARE_ERROR return ADD_TO_MLQUEUE on
++    retry
++  * [SCSI] fix check of PQ and PDT bits for WLUNs
++  * pcm037: add rts/cts support for serial port
++  * i.MX serial: fix init failure
++  * imx serial: set RXD mux bit on i.MX27 and i.MX31
++  * imx serial: fix rts handling for non imx1 based hardware
++  * mlx4_core: Set RAE and init mtt_sz field in FRMR MPT entries
++  * udf: add llseek method
++  * PCI/iommu: blacklist DMAR on Intel G31/G33 chipsets
++  * PCI: Fix printk warnings in probe.c
++  * PCI: Fix printk warnings in setup-bus.c
++  * PCI Hotplug: fakephp: fix deadlock... again
++  * clockevents: remove WARN_ON which was used to gather information
++  * ocfs2: Fix a bug in direct IO read.
++  * arch/x86/kernel/kdebugfs.c: introduce missing kfree
++  * [IA64] fix compile failure with non modular builds
++  * [IA64] fix up bte.h
++  * [IA64] arch/ia64/sn/pci/tioca_provider.c: introduce missing kfree
++  * PCI: fix pciehp_free_irq()
++  * [IA64] prevent ia64 from invoking irq handlers on offline CPUs
++  * ide: Fix pointer arithmetic in hpt3xx driver code (3rd try)
++  * add deprecated ide-scsi to feature-removal-schedule.txt
++  * swiotlb: fix back-off path when memory allocation fails
++  * sparc64: Fix interrupt register calculations on Psycho and Sabre.
++  * VIDEO_SH_MOBILE_CEU should depend on HAS_DMA
++  * m68k: Update defconfigs for 2.6.27-rc6
++  * sparc32: Fix function signature of of_bus_sbus_get_flags().
++  * sched: fix 2.6.27-rc5 couldn't boot on tulsa machine randomly
++  * sched: fix deadlock in setting scheduler parameter to zero
++  * KVM: SVM: fix random segfaults with NPT enabled
++  * KVM: SVM: fix guest global tlb flushes with NPT
++  * KVM: VMX: Always return old for clear_flush_young() when using EPT
++  * clocksource, acpi_pm.c: fix check for monotonicity
++  * [ARM] OMAP: Fix MMC device data
++  * block: disable sysfs parts of the disk command filter
++  * ath9k: Assign seq# when mac80211 requests this
++  * sg: disable interrupts inside sg_copy_buffer
++  * MN10300: Change the fault handler to check in_atomic() not
++    in_interrupt()
++  * [Bluetooth] Fix regression from using default link policy
++  * netlink: fix overrun in attribute iteration
++  * x86: fix possible x86_64 and EFI regression
++  * sparc64: Fix PCI error interrupt registry on PSYCHO.
++  * sparc: Fix user_regset 'n' field values.
++  * niu: panic on reset
++  * PCI: re-add debug prints for unmodified BARs
++  * [ARM] 5245/1: Fix warning about unused return value in drivers/pcmcia
++  * [ARM] 5246/1: tosa: add proper clock alias for tc6393xb clock
++  * [ARM] 5247/1: tosa: SW_EAR_IN support
++  * [ARM] Fix PCI_DMA_BUS_IS_PHYS for ARM
++  * ata: duplicate variable sparse warning
++  * sata_inic162x: enable LED blinking
++  * [libata] LBA28/LBA48 off-by-one bug in ata.h
++  * proc: more debugging for "already registered" case
++  * include/linux/ioport.h: add missing macro argument for devm_release_*
++    family
++  * cpuset: avoid changing cpuset's cpus when -errno returned
++  * cpuset: hotplug documentation fix
++  * coredump_filter: add description of bit 4
++  * bfs: fix Lockdep warning
++  * mm: ifdef Quicklists in /proc/meminfo
++  * spi_mpc83xx: fix clockrate calculation for low speed
++  * spi_mpc83xx: reject invalid transfer sizes
++  * pxa2xx_spi: chipselect bugfixes
++  * pxa2xx_spi: dma bugfixes
++  * mm: mark the correct zone as full when scanning zonelists
++  * Documentation/ABI: /sys/class/gpio
++  * MAINTAINERS: fix USB VIDEO CLASS mail list address
++  * ia64: fix panic during `modprobe -r xpc'
++  * atmel_lcdfb: disable LCD and DMA engines when suspending
++  * spi_s3c24xx: fix section warning
++  * rescan_partitions(): make device capacity errors non-fatal
++  * memstick: fix MSProHG 8-bit interface mode support
++  * Add Uwe Kleine-König to .mailmap
++  * xen: fix for xen guest with mem > 3.7G
++  * x86/paravirt: Remove duplicate paravirt_pagetable_setup_{start, done}()
++  * crypto: talitos - Avoid consecutive packets going out with same IV
++  * slub: fixed uninitialized counter in struct kmem_cache_node
++  * udp: Fix rcv socket locking
++  * IB/mlx4: Fix up fast register page list format
++  * [MIPS] VR41xx: unsigned irq cannot be negative
++  * x86: completely disable NOPL on 32 bits
++  * [S390] cio: Fix driver_data handling for ccwgroup devices.
++  * [S390] cio: fix orb initialization in cio_start_key
++  * sparc64: Fix OOPS in psycho_pcierr_intr_other().
++  * sparc64: Fix SMP bootup with CONFIG_STACK_DEBUG or ftrace.
++  * RDMA/nes: Fix client side QP destroy
++  * IPoIB: Fix deadlock on RTNL between bcast join comp and ipoib_stop()
++  * clockevents: make device shutdown robust
++  * powerpc: Fix interrupt values for DMA2 in MPC8610 HPCD device tree
++  * hpplus: fix build regression
++  * Fix PNP build failure, bugzilla #11276
++  * warn: Turn the netdev timeout WARN_ON() into a WARN()
++  * [XFS] Move memory allocations for log tracing out of the critical path
++  * [XFS] Fix regression introduced by remount fixup
++  * [XFS] Prevent direct I/O from mapping extents beyond eof
++  * [XFS] Fix barrier status change detection.
++  * [XFS] Prevent lockdep false positives when locking two inodes.
++  * [XFS] Fix use-after-free with buffers
++  * [XFS] Don't do I/O beyond eof when unreserving space
++  * powerpc: Holly board needs dtbImage target
++  * Fix compile failure with non modular builds
++  * [ARM] 5249/1: davinci: remove redundant check in davinci_psc_config()
++  * [ARM] omap: back out 'internal_clock' support
++  * sctp: set the skb->ip_summed correctly when sending over loopback.
++  * [ARM] 5255/1: Update jornada ssp to remove build errors/warnings
++  * sctp: do not enable peer features if we can't do them.
++  * sctp: Fix oops when INIT-ACK indicates that peer doesn't support AUTH
++  * bnx2: Promote vector field in bnx2_irq structure from u16 to unsigned
++    int
++  * forcedeth: call restore mac addr in nv_shutdown path
++  * e1000: prevent corruption of EEPROM/NVM
++  * e100: Use pci_pme_active to clear PME_Status and disable PME#
++  * md: Don't wait UNINTERRUPTIBLE for other resync to finish
++  * atstk1000: fix build breakage with BOARD_ATSTK100X_SW2_CUSTOM=y
++  * avr32: add .gitignore files
++  * avr32: add generic_find_next_le_bit bit function
++  * avr32: fix sys_sync_file_range() call convention
++  * avr32: nmi_enter() without nmi_exit()
++  * KVM: ia64: 'struct fdesc' build fix
++  * hwmon: (atxp1) Fix device detection logic
++  * hwmon: (it87) Fix fan tachometer reading in IT8712F rev 0x7 (I)
++  * hwmon: (ad7414) Make ad7414_update_device() static
++  * tmio_mmc: fix compilation with debug enabled
++  * atmel-mci: debugfs: enable clock before dumping regs
++  * atmel-mci: Fix memory leak in atmci_regs_show
++  * atmel-mci: Fix bogus debugfs file size
++  * atmel-mci: Set MMC_CAP_NEEDS_POLL if no detect_pin
++  * mmc_block: handle error from mmc_register_driver()
++  * mmc_test: initialize mmc_test_lock statically
++  * [MIPS] Fix 64-bit IP checksum code
++  * [MIPS] SMTC: Clear TIF_FPUBOUND on clone / fork.
++  * [MIPS] Fix potential latency problem due to non-atomic cpu_wait.
++  * [MIPS] vmlinux.lds.S: handle .text.*
++  * MAINTAINERS: Trivial whitespace cleanups
++  * MAINTAINERS: Various fixes
++  * Linux 2.6.27-rc7
++
++ --  Tim Gardner <tim.gardner@canonical.com>  Sun, 21 Sep 2008 21:49:28 -0600
++
++linux (2.6.27-3.4) intrepid; urgency=low
++
++  [ Colin Ian King ]
++
++  * SAUCE: fix kernel oops in VirtualBox during paravirt patching
++    - LP: #246067
++  * SAUCE: qc-usb: Enable Logitech QuickCam Messenger
++    - LP: #209901
++  * SAUCE: appleir: Enable driver for new MacBook Pro
++    - LP: #157919
++
++  [ Tim Gardner ]
++
++  * Enabled CONFIG_DEBUG_RODATA=y
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "ALSA: hda - Added model selection for iMac 24""
++  * Revert "x86: fix HPET regression in 2.6.26 versus 2.6.25, check hpet
++    against BAR, v3"
++  * Revert "[ARM] use the new byteorder headers"
++  * Revert "mac80211: Use IWEVASSOCREQIE instead of IWEVCUSTOM"
++  * Revert "crypto: camellia - Use kernel-provided bitops, unaligned access
++    helpers"
++  * svcrdma: Fix race between svc_rdma_recvfrom thread and the dto_tasklet
++  * sched, cpuset: rework sched domains and CPU hotplug handling (v4)
++  * ACPI: Fix now signed module parameter.
++  * ACPI: Change package length error to warning
++  * ACPI: Fix now signed module parameter.
++  * ACPI: Fix typo in "Disable MWAIT via DMI on broken Compal board"
++  * acpi: add checking for NULL early param
++  * UBIFS: fix zero-length truncations
++  * Input: bcm5974 - add maintainer entry
++  * sh64: re-add the __strnlen_user() prototype
++  * sh: fix ptrace_64.c:user_disable_single_step()
++  * PNPACPI: ignore the producer/consumer bit for extended IRQ descriptors
++  * UBIFS: always read hashed-key nodes under TNC mutex
++  * UBIFS: allow for racing between GC and TNC
++  * [CIFS] Fix plaintext authentication
++  * sparc32: Implement smp_call_function_single().
++  * sh: crash kernel resource fix
++  * sh: fix kexec entry point for crash kernels
++  * sh: fix platform_resource_setup_memory() section mismatch
++  * sh: update Migo-R defconfig
++  * sh: update AP325RXA defconfig
++  * sh: fix semtimedop syscall
++  * cifs: fix O_APPEND on directio mounts
++  * [CIFS] update cifs change log
++  * [CIFS] Turn off Unicode during session establishment for plaintext
++    authentication
++  * ACPI: thinkpad-acpi: wan radio control is not experimental
++  * sparc: Fix resource flags for PCI children in OF device tree.
++  * remove blk_register_filter and blk_unregister_filter in gendisk
++  * ALSA: oxygen: fix distorted output on AK4396-based cards
++  * ipv6: When we droped a packet, we should return NET_RX_DROP instead of
++    0
++  * pkt_sched: Fix locking of qdisc_root with qdisc_root_sleeping_lock()
++  * net: Unbreak userspace usage of linux/mroute.h
++  * Don't trigger softlockup detector on network fs blocked tasks
++  * Resource handling: add 'insert_resource_expand_to_fit()' function
++  * sparc64: setup_valid_addr_bitmap_from_pavail() should be __init
++  * UBIFS: do not update min_idx_lebs in stafs
++  * UBIFS: push empty flash hack down
++  * UBIFS: remove incorrect index space check
++  * UBIFS: improve statfs reporting
++  * UBIFS: fix assertion
++  * UBIFS: add forgotten gc_idx_lebs component
++  * UBIFS: introduce LEB overhead
++  * UBIFS: improve statfs reporting even more
++  * UBIFS: fill f_fsid
++  * drm/radeon: downgrade debug message from info to debug.
++  * Remove invalidate_partition call from do_md_stop.
++  * Fix problem with waiting while holding rcu read lock in md/bitmap.c
++  * ALSA: hda: Distortion fix for dell_m6_core_init
++  * ALSA: ASoC: fix pxa2xx-i2s clk_get call
++  * block: restore original behavior of /proc/partition when there's no
++    partition
++  * debugobjects: fix lockdep warning
++  * avr32: Fix lockup after Java stack underflow in user mode
++  * avr32: pm_standby low-power ram bug fix
++  * nfsd: fix compound state allocation error handling
++  * sunrpc: fix possible overrun on read of /proc/sys/sunrpc/transports
++  * nfsd: fix buffer overrun decoding NFSv4 acl
++  * audit: Moved variable declaration to beginning of function
++  * Fix modules_install on RO nfs-exported trees.
++  * Remove '#include <stddef.h>' from mm/page_isolation.c
++  * dabusb_fpga_download(): fix a memory leak
++  * [MTD] mtdchar.c: Fix regression in MEMGETREGIONINFO ioctl()
++  * ALSA: hda - Fix ALC663 auto-probe
++  * ALSA: hda - Add mic-boost controls to ALC662/663 auto configuration
++  * Un-break printk strings in x86 PCI probing code
++  * kernel/resource.c: fix new kernel-doc warning
++  * softlockup: minor cleanup, don't check task->state twice
++  * fix typo in arch/parisc/hpux/fs.c
++  * m68k: atari_keyb_init operator precedence fix
++  * ACPI: Fix typo in "Disable MWAIT via DMI on broken Compal board"
++  * don't diff generated firmware files
++  * IDE: compile fix for sff_dma_ops
++  * IDE: palm_bk3710: fix compile warning for unused variable
++  * ide: fix hwif_to_node()
++  * palm_bk3710: improve IDE registration
++  * ide-disk: remove stale init_idedisk_capacity() documentation
++  * ide/Kconfig: mark ide-scsi as deprecated
++  * net/wireless/Kconfig: clarify the description for
++    CONFIG_WIRELESS_EXT_SYSFS
++  * iwlwifi: do not use GFP_DMA in iwl_tx_queue_init
++  * iwlwifi: workaround interrupt handling no some platforms
++  * iwlwifi: fix apm_stop (wrong bit polarity for FLAG_INIT_DONE)
++  * iwlwifi: fix 64bit platform firmware loading
++  * orinoco: Multicast to the specified addresses
++  * wireless/libertas/if_cs.c: fix memory leaks
++  * mac80211: Fix debugfs union misuse and pointer corruption
++  * rt2x00: Compiler warning unmasked by fix of BUILD_BUG_ON
++  * ath9k: Incorrect key used when group and pairwise ciphers are
++    different.
++  * ath9: Fix ath_rx_flush_tid() for IRQs disabled kernel warning message.
++  * net/xfrm: Use an IS_ERR test rather than a NULL test
++  * ipv: Re-enable IP when MTU > 68
++  * NTFS: update homepage
++  * mm: make setup_zone_migrate_reserve() aware of overlapping nodes
++  * VFS: fix dio write returning EIO when try_to_release_page fails
++  * acer-wmi: remove debugfs entries upon unloading
++  * mm/bootmem: silence section mismatch warning -
++    contig_page_data/bootmem_node_data
++  * MAINTAINERS: add a maintainer for the BCM5974 multitouch driver
++  * 8250: improve workaround for UARTs that don't re-assert THRE correctly
++  * mmc: at91_mci: don't use coherent dma buffers
++  * pid_ns: zap_pid_ns_processes: fix the ->child_reaper changing
++  * pid_ns: (BUG 11391) change ->child_reaper when init->group_leader exits
++  * cirrusfb: check_par fixes
++  * devcgroup: fix race against rmdir()
++  * mm: show quicklist usage in /proc/meminfo
++  * mm: size of quicklists shouldn't be proportional to the number of CPUs
++  * ipc: document the new auto_msgmni proc file
++  * hp-wmi: update to match current rfkill semantics
++  * hp-wmi: add proper hotkey support
++  * tdfxfb: fix SDRAM memory size detection
++  * tdfxfb: fix frame buffer name overrun
++  * rtc_time_to_tm: fix signed/unsigned arithmetic
++  * ibft: fix target info parsing in ibft module
++  * sysfs: document files in /sys/firmware/sgi_uv/
++  * rtc-cmos: wake again from S5
++  * pm_qos_requirement might sleep
++  * drivers/char/random.c: fix a race which can lead to a bogus BUG()
++  * ipsec: Fix deadlock in xfrm_state management.
++  * [x86] Fix TSC calibration issues
++  * tipc: Don't use structure names which easily globally conflict.
++  * sparc64: Fix IPI call locking.
++  * [ARM] omap: fix gpio.c build error
++  * sparc64: Prevent sparc64 from invoking irq handlers on offline CPUs
++  * powerpc: Fix uninitialised variable in VSX alignment code
++  * powerpc: Only make kernel text pages of linear mapping executable
++  * powerpc: Make sure _etext is after all kernel text
++  * powerpc: Work around gcc's -fno-omit-frame-pointer bug
++  * powerpc: Fix build error with 64K pages and !hugetlbfs
++  * powerpc: Fix for getting CPU number in power_save_ppc32_restore()
++  * UBIFS: amend f_fsid
++  * net/usb/pegasus: avoid hundreds of diagnostics
++  * ixgbe: initialize interrupt throttle rate
++  * pcnet-cs, axnet_cs: add new IDs, remove dup ID with less info
++  * netxen: Remove workaround for chipset quirk
++  * Split up PIT part of TSC calibration from native_calibrate_tsc
++  * iwlwifi: W/A for the TSF correction in IBSS
++  * iwlwifi: fix hidden ssid discovery in passive channels
++  * iwlwifi: remove false rxon if rx chain changes
++  * iwlwifi: fix station mimo power save values
++  * iwlwifi: fix rx_chain computation
++  * iwlwifi: fix Tx cmd memory allocation failure handling
++  * iwlwifi: call apm stop on exit
++  * iwlwifi: fix STATUS_EXIT_PENDING is not set on pci_remove
++  * ath9k: Fix TX status reporting
++  * ath9k: Fix TX control flag use for no ACK and RTS/CTS
++  * V4L/DVB (8555): au8522: add mechanism to configure IF frequency for vsb
++    and qam
++  * V4L/DVB (8556): au0828: add support for Hauppauge Woodbury
++  * V4L/DVB (8598): au8522: clean up function au8522_set_if
++  * V4L/DVB (8599): au8522: remove if frequency settings from vsb/qam
++    modulation tables
++  * V4L/DVB (8600): au0828: explicitly set 6 MHz IF frequency in
++    hauppauge_hvr950q_config
++  * V4L/DVB (8629): v4l2-ioctl: do not try to handle private V4L1 ioctls
++  * V4L/DVB (8633): ivtv: update ivtv version number
++  * V4L/DVB (8648): ivtv: improve CC support
++  * V4L/DVB (8660): gspca: Simplify the scan of URB packets in pac7311.
++  * V4L/DVB (8661): gspca: Bug in the previous changeset about pac7311.
++  * V4L/DVB (8663): gspca: Webcam 0c45:6128 added in sonixj.
++  * V4L/DVB (8664): gspca: The bridge/sensor of the webcam 093a:2621 is a
++    PAC 7302.
++  * V4L/DVB (8665): gspca: Fix the 640x480 resolution of the webcam
++    093a:2621.
++  * V4L/DVB (8666): gspca: Bad scanning of frames in pac7311.
++  * V4L/DVB (8667): gspca: Bad probe of Z-Star/Vimicro webcams with pas106
++    sensor.
++  * V4L/DVB (8668): gspca: Conflict GSPCA / ET61X251 for the webcam
++    102c:6251.
++  * V4L/DVB (8669): gspca: Add white balance control for spca561 rev 012A.
++  * V4L/DVB (8671): gspca: Remove the unused field 'dev_name' of the device
++    structure.
++  * V4L/DVB (8672): gspca: Big rewrite of spca561.
++  * V4L/DVB (8673): gspca: Bad frame scanning again and bad init in
++    pac7311.
++  * V4L/DVB (8674): gspca: Webcam 0c45:612e added in sonixj.
++  * V4L/DVB (8675): gspca: Pixmap PJPG (Pixart 73xx JPEG) added, generated
++    by pac7311.
++  * V4L/DVB (8678): Remove the dead CONFIG_RADIO_MIROPCM20{,_RDS} code
++  * V4L/DVB (8681): v4l2-ioctl.c: fix warning
++  * V4L/DVB (8682): V4L: fix return value of register video func
++  * V4L/DVB (8701): cx18: Add missing lock for when the irq handler
++    manipulates the queues
++  * V4L/DVB (8703): gspca: Do controls work for spca561 revision 12a.
++  * V4L/DVB (8705): gspca: Adjust some control limits in spca561.
++  * V4L/DVB (8706): Make contrast and brightness work for pac7302.
++  * V4L/DVB (8707): gspca: Colors, hflip and vflip controls added for
++    pac7302.
++  * V4L/DVB (8709): gspca: Fix initialization and controls of sn9x110 -
++    ov7630.
++  * V4L/DVB (8710): gspca: Bad color control in sonixj.
++  * V4L/DVB (8711): gspca: Bad controls and quantization table of pac7311.
++  * V4L/DVB (8712): gspca: Bad start of sonixj webcams since changeset
++    a8779025e7e8.
++  * V4L/DVB (8713): gspca: Bad color control again in sonixj.
++  * V4L/DVB (8714): gspca: Bad start of sn9c110 and sensor om6802.
++  * V4L/DVB (8715): gspca: Change the name of some webcam in the gspca doc.
++  * V4L/DVB (8716): gspca: Bad start of sn9c110 and sensor ov7630.
++  * V4L/DVB (8717): gspca: Frame buffer too small for small resolutions
++    (sonixj and t613).
++  * V4L/DVB (8718): gspca: suspend/resume added.
++  * V4L/DVB (8719): gspca: Have VIDIOC_QUERYCTRL more compliant to the
++    spec.
++  * V4L/DVB (8720): gspca: V4L2_CAP_SENSOR_UPSIDE_DOWN added as a cap for
++    some webcams.
++  * V4L/DVB (8722): sms1xxx: fix typo in license header
++  * V4L/DVB (8726): link tuner before saa7134
++  * V4L/DVB (8727): V4L1: make PMS not autoprobe when builtin.
++  * V4L/DVB (8728): 1-make-pms-not-autoprobe-when-builtin update
++  * V4L/DVB (8749): Fix error code, when camera is not turned on by sonypi
++  * V4L/DVB (8750): V4L: check inval in video_register_device_index()
++  * V4L/DVB (8751): vivi: Fix some issues at vivi register routine
++  * V4L/DVB (8757): v4l-dvb: fix a bunch of sparse warnings
++  * V4L/DVB (8769): cx18: Simplify queue flush logic to prevent oops in
++    cx18_flush_queues()
++  * V4L/DVB (8778): radio: fix incorrect video_register_device result check
++  * V4L/DVB (8779): v4l: fix more incorrect video_register_device result
++    checks
++  * V4L/DVB (8790): saa7115: call i2c_set_clientdata only when state !=
++    NULL
++  * V4L/DVB (8803): s5h1409: Enable QAM_AUTO mode
++  * V4L/DVB (8804): s5h1411: Enable QAM_AUTO mode
++  * V4L/DVB (8805): Steven Toth email address change
++  * V4L/DVB (8809): gspca: Revert commit
++    9a9335776548d01525141c6e8f0c12e86bbde982
++  * V4L/DVB (8810): gspca: Compile error when CONFIG_PM not defined.
++  * V4L/DVB (8812): gspca: Do pac73xx webcams work.
++  * V4L/DVB (8813): gspca: Adjust SOF detection for pac73xx.
++  * V4L/DVB (8814): gspca: Set DISABLED the disabled controls at query
++    control time.
++  * V4L/DVB (8815): gspca: Fix problems with disabled controls.
++  * V4L/DVB (8816): gspca: Set disabled ctrls and fix a register pb with
++    ovxxxx in sonixb.
++  * V4L/DVB (8817): gspca: LED and proble changes in sonixb.
++  * V4L/DVB (8818): gspca: Reinitialize the device on resume.
++  * V4L/DVB (8819): gspca: Initialize the ov519 at open time and source
++    cleanup.
++  * V4L/DVB (8820): gspca: Change initialization and gamma of zc3xx -
++    pas106.
++  * V4L/DVB (8822): gspca: Change some subdriver functions for
++    suspend/resume.
++  * V4L/DVB (8823): gspca: H and V flips work for ov7670 only in ov519.
++  * V4L/DVB (8824): gspca: Too much code removed in the suspend/resume
++    changeset.
++  * V4L/DVB (8825): gspca: More controls for pac73xx and new webcam
++    093a:2624.
++  * V4L/DVB (8826): gspca: Webcam Labtec 2200 (093a:2626) added in pac7311.
++  * V4L/DVB (8827): gspca: Stop pac7302 autogain oscillation.
++  * V4L/DVB (8828): gspca: Set the clock at the end of initialization in
++    sonixj.
++  * V4L/DVB (8829): gspca: Have a clean kmalloc-ated buffer for USB
++    exchanges.
++  * V4L/DVB (8830): gspca: Move some probe code to the new init function.
++  * V4L/DVB (8831): gspca: Resolve webcam conflicts between some drivers.
++  * V4L/DVB (8832): gspca: Bad pixelformat of vc0321 webcams.
++  * V4L/DVB (8833): gspca: Cleanup the sonixb code.
++  * V4L/DVB (8834): gspca: Have a bigger buffer for sn9c10x compressed
++    images.
++  * V4L/DVB (8835): gspca: Same pixfmt as the sn9c102 driver and raw Bayer
++    added in sonixb.
++  * V4L/DVB (8837): dvb: fix I2C adapters name size
++  * V4L/DVB (8839): dib0700: add comment to identify 35th USB id pair
++  * V4L/DVB (8840): dib0700: add basic support for Hauppauge Nova-TD-500
++    (84xxx)
++  * V4L/DVB (8842): vivi_release(): fix use-after-free
++  * V4L/DVB (8843): tda10048_firmware_upload(): fix a memory leak
++  * V4L/DVB (8844): dabusb_fpga_download(): fix a memory leak
++  * bnx2x: Accessing un-mapped page
++  * SELinux: memory leak in security_context_to_sid_core
++  * x86: add io delay quirk for Presario F700
++  * mmap: fix petty bug in anonymous shared mmap offset handling
++  * x86: Change warning message in TSC calibration.
++  * PCI: fix pbus_size_mem() resource alignment for CardBus controllers
++  * [ARM] omap: fix build error in ohci-omap.c
++  * [ARM] remove unused #include <version.h>
++  * ACPI: Make Len Brown the ACPI maintainer again
++  * fujitsu-laptop: fix regression for P8010 in 2.6.27-rc
++  * ACPI: Avoid bogus timeout about SMbus check
++  * acer-wmi: remove debugfs entries upon unloading
++  * forgotten refcount on sysctl root table
++  * V4L/DVB (8868): gspca: Support for vga modes with sif sensors in
++    sonixb.
++  * V4L/DVB (8869): gspca: Move the Sonix webcams with TAS5110C1B from
++    sn9c102 to gspca.
++  * V4L/DVB (8870): gspca: Fix dark room problem with sonixb.
++  * V4L/DVB (8872): gspca: Bad image format and offset with rev072a of
++    spca561.
++  * V4L/DVB (8873): gspca: Bad image offset with rev012a of spca561 and
++    adjust exposure.
++  * V4L/DVB (8874): gspca: Adjust hstart for sn9c103/ov7630 and update
++    usb-id's.
++  * [ARM] omap: fix virtual vs physical address space confusions
++  * V4L/DVB (8876): budget: udelay changed to mdelay
++  * V4L/DVB (8877): b2c2 and bt8xx: udelay to mdelay
++  * V4L/DVB (8880): PATCH: Fix parents on some webcam drivers
++  * V4L/DVB (8881): gspca: After 'while (retry--) {...}', retry will be -1
++    but not 0.
++  * powerpc/spufs: Fix multiple get_spu_context()
++  * powerpc/spufs: Fix race for a free SPU
++  * Input: bcm5974 - small formatting cleanup
++  * Input: bcm5974 - improve finger tracking and counting
++  * Input: bcm5974 - add BTN_TOUCH event for mousedev benefit
++  * Input: i8042 - make Lenovo 3000 N100 blacklist entry more specific
++  * sh: resume_kernel fix for kernel oops built with CONFIG_BKL_PREEMPT=y.
++  * sh64: resume_kernel fix for kernel oops built with
++    CONFIG_BKL_PREEMPT=y.
++  * i2c: fix i2c-sh_mobile timing issues
++  * clockevents: prevent clockevent event_handler ending up handler_noop
++  * clockevents: prevent endless loop in periodic broadcast handler
++  * clockevents: enforce reprogram in oneshot setup
++  * clockevents: prevent multiple init/shutdown
++  * clockevents: prevent endless loop lockup
++  * HPET: make minimum reprogramming delta useful
++  * [MTD] [NAND] tmio_nand: fix base address programming
++  * Fix conditional export of kvh.h and a.out.h to userspace.
++  * async_tx: fix the bug in async_tx_run_dependencies
++  * sched_clock: fix NOHZ interaction
++  * sched: fix process time monotonicity
++  * UBIFS: fix division by zero
++  * UBIFS: make minimum fanout 3
++  * [MIPS] Fix data bus error recovery
++  * [MIPS] Fix WARNING: at kernel/smp.c:290
++  * [MIPS] TXx9: Fix txx9_pcode initialization
++  * [MIPS] TX39xx: Add missing local_flush_icache_range initialization
++  * [MIPS] Probe initrd header only if explicitly specified
++  * res_counter: fix off-by-one bug in setting limit
++  * forcedeth: fix kexec regression
++  * atmel_lcdfb: fix oops in rmmod when framebuffer fails to register
++  * tracehook: comment pasto fixes
++  * drivers/mmc/card/block.c: fix refcount leak in mmc_block_open()
++  * x86: boot: stub out unimplemented CPU feature words
++  * x86: add NOPL as a synthetic CPU feature bit
++  * x86: use X86_FEATURE_NOPL in alternatives
++  * clockevents: broadcast fixup possible waiters
++  * x86: HPET fix moronic 32/64bit thinko
++  * x86: HPET: read back compare register before reading counter
++  * Fix CONFIG_AC97_BUS dependency
++  * [ARM] 5241/1: provide ioremap_wc()
++  * ntp: fix calculation of the next jiffie to trigger RTC sync
++  * clocksource, acpi_pm.c: use proper read function also in errata mode
++  * clocksource, acpi_pm.c: check for monotonicity
++  * x86: delay early cpu initialization until cpuid is done
++  * x86: move mtrr cpu cap setting early in early_init_xxxx
++  * sched: arch_reinit_sched_domains() must destroy domains to force
++    rebuild
++  * x86, xen: Use native_pte_flags instead of native_pte_val for .pte_flags
++  * x86: pda_init(): fix memory leak when using CPU hotplug
++  * x86: cpu_init(): fix memory leak when using CPU hotplug
++  * powerpc/spufs: Fix possible scheduling of a context to multiple SPEs
++  * netfilter: nf_conntrack_sip: de-static helper pointers
++  * netfilter: nf_conntrack_gre: more locking around keymap list
++  * netfilter: nf_conntrack_gre: nf_ct_gre_keymap_flush() fixlet
++  * netfilter: nf_conntrack_irc: make sure string is terminated before
++    calling simple_strtoul
++  * pkt_sched: Fix qdisc state in net_tx_action()
++  * powerpc: Fix rare boot build breakage
++  * ahci, pata_marvell: play nicely together
++  * sata_mv: add RocketRaid 1720 PCI ID to driver
++  * ahci: disable PMP for marvell ahcis
++  * sata_nv: disable hardreset for generic
++  * libata-sff: kill spurious WARN_ON() in ata_hsm_move()
++  * pata_sil680: remove duplicate pcim_enable_device
++  * ahci: RAID mode SATA patch for Intel Ibex Peak DeviceIDs
++  * [MIPS] IP22: Fix detection of second HPC3 on Challenge S
++  * xen: fix 2.6.27-rc5 xen balloon driver warnings
++  * x86: disable static NOPLs on 32 bits
++  * netns : fix kernel panic in timewait socket destruction
++  * bridge: don't allow setting hello time to zero
++  * NFS: Restore missing hunk in NFS mount option parser
++  * usb: fix null deferences in low level usb serial
++  * Fix format of MAINTAINERS
++  * sparc64: Disable timer interrupts in fixup_irqs().
++  * [Bluetooth] Fix reference counting during ACL config stage
++  * [Bluetooth] Enforce correct authentication requirements
++  * [Bluetooth] Reject L2CAP connections on an insecure ACL link
++  * [S390] CVE-2008-1514: prevent ptrace padding area read/write in 31-bit
++    mode
++  * [S390] cio: Correct cleanup on error.
++  * [S390] cio: handle ssch() return codes correctly.
++  * [S390] cio: allow offline processing for disconnected devices
++  * ipsec: Restore larval states and socket policies in dump
++  * update Documentation/filesystems/Locking for 2.6.27 changes
++  * MAINTAINERS: add Atheros maintainer for atlx
++  * lib: Correct printk %pF to work on all architectures
++  * x86: fix memmap=exactmap boot argument
++  * clockevents: remove WARN_ON which was used to gather information
++  * ipv6: Fix OOPS in ip6_dst_lookup_tail().
++  * Linux 2.6.27-rc6
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 02 Sep 2008 12:45:56 -0400
++
++linux (2.6.27-2.3) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/retag: Make script save .orig of tags for later use
++  * ubuntu/lirc: Fix device_create call
++  * build/firmware: Put in-kernel firmware into version specific subdir
++    - LP: #262115
++  * Rebase on linux-2.6 git.
++  * ABI bump
++
++  [ Herton Ronaldo Krzesinski ]
++
++  * SAUCE: (no-up) Apparmor warning fixes
++
++  [ John Johansen ]
++
++  * SAUCE: (no-up) Proper AppArmor ptrace updates for newer lsm API
++
++  [ Mackenzie Morgan ]
++
++  * SAUCE: Add quirk for ASUS Z37E to make sound audible after resume
++    - LP: #25896
++
++ -- Ben Collins <ben.collins@canonical.com>  Wed, 27 Aug 2008 14:03:05 -0400
++
++linux (2.6.27-1.2) intrepid; urgency=low
++
++  [ Amit Kucheria ]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [ Ben Collins ]
++
++  * SAUCE: Lower warning level of some PCI messages
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: (no-up) version: Implement version_signature proc file.
++  * SAUCE: (no-up) connector.h: Add idx/val for drbd
++  * SAUCE: (no-up) swap: Add notify_swap_entry_free callback for compcache
++  * SAUCE: drivers: Remove some duplicate device entries in various modules
++  * SAUCE: (no-up) [AppArmor] merge with upstream subversion r1291
++  * SAUCE: apparmor: Update for changes to ptrace lsm hooks
++  * SAUCE: (no-up) Enable ubuntu extra subdirectory
++  * SAUCE: applesmc: Add MacBookAir
++  * SAUCE: (no-up) ACPI: initramfs DSDT override support
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add BOM for iscsitarget
++  * ubuntu: Add squashfs driver
++  * SAUCE: (no-up) Check for squashfs superblock in initramfs mounting.
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Added et131x driver
++  * ubuntu: Add dm-raid4-5 driver
++  * ubuntu: Add ndiswrapper driver
++  * ubuntu: Added ram backed compressed swap module (compcache)
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add ov511 and bt-sco drivers
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * ubuntu: Add at76 driver to build
++  * ubuntu: Add fsam7400 sw kill switch driver
++  * ubuntu: Added qc-usb driver
++  * ubuntu: e1000e: Upgraded module to 0.4.1.7
++  * ubuntu: Added rfkill drivers
++  * ubuntu: VIA - Add VIA DRM Chrome9 3D engine
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * ubuntu: Add LIRC driver
++  * ubuntu: Add GFS driver
++  * ubuntu: New tlsup driver for toshiba laptops
++  * Update config files
++  * build/d-i: Remove obsolete dm modules
++
++  [ Chuck Short ]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++
++  [ Colin Ian King ]
++
++  * ubuntu: Add dm-loop
++  * SAUCE: Enable speedstep for sonoma processors.
++
++  [ Dennis Noordsij ]
++
++  * SAUCE: Work around ACPI corruption upon suspend on some Dell machines.
++
++  [ Fabio M. Di Nitto ]
++
++  * SAUCE: Export gfs2 symbols required for gfs1 kernel module
++
++  [ Matthew Garrett ]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++
++  [ Phillip Lougher ]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [ Stefan Bader ]
++
++  * SAUCE: (no-up) Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++
++  [ Tim Gardner ]
++
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: (no-up) Take care of orinoco_cs overlap with hostap_cs
++  * ubuntu: Add GNBD driver
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 23 Aug 2008 15:48:35 -0400
++
++linux (2.6.27-0.0) intrepid; urgency=low
++
++  * Not uploaded, placeholder for new release
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 23 Aug 2008 15:48:35 -0400
++
++linux (2.6.26-5.17) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build/abi: Add tosh_smm symbol to blacklist
++
++ -- Ben Collins <ben.collins@canonical.com>  Fri, 15 Aug 2008 09:29:34 -0400
++
++linux (2.6.26-5.16) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * Revert "SAUCE: toshiba_acpi: Rewrote most of the proc entry bits."
++  * Revert "SAUCE: Update toshiba_acpi.c to version 0.19a"
++  * build/config: Disable in-kernel toshiba driver(s)
++  * ubuntu/tlsup: New driver for toshiba laptops
++  * build/config: Enable TLSUP driver
++  * SAUCE: e1000e: Fix E1000E_ENABLED logic to check for our E1000E_NEW
++    driver as well
++  * ubuntu/e1000e: Remove E1000E_ENABLED option in local config
++  * build/config: Update configs to have E1000E_ENABLED set
++  * ubuntu/prism2: Remove duplicate device
++
++  [ Fabio M. Di Nitto ]
++
++  * SAUCE: Export gfs2 symbols required for gfs1 kernel module
++
++  [ Stefan Bader ]
++
++  * SAUCE: x86: HPET rework for SB700
++    - LP: #255910
++
++  [ Tim Gardner ]
++
++  * Add GNBD driver
++  * Enable GNBD driver
++  * SAUCE: Add GFS driver
++  * SAUCE: Enable gfs driver configs
++  * b43: Linksys WMP54G (BCM4306/3) card in a PCI format has an SPROM
++    coding
++
++  [ Upstream Kernel Changes ]
++
++  * KVM: x86 emulator: emulate clflush
++  * USB: quirk PLL power down mode
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 11 Aug 2008 13:19:28 -0400
++
++linux (2.6.26-5.15) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * Revert "SAUCE: Add blacklist support to fix Belkin bluetooth dongle."
++    - Superceded by upstream changes.
++  * build/config: New option enabled for uvcvideo
++  * build/control: Add Vcs-Git meta data to control file
++  * SAUCE: toshiba_acpi: Rewrote most of the new code
++  * abi/perm-blacklist: Add emu10k1 driver to blacklist
++
++  [ Upstream Kernel Changes ]
++
++  * pxamci: trivial fix of DMA alignment register bit clearing
++  * udplite: Protection against coverage value wrap-around
++  * ipv6: use timer pending
++  * ipv6: __KERNEL__ ifdef struct ipv6_devconf
++  * hdlcdrv: Fix CRC calculation.
++  * quota: fix possible infinite loop in quota code
++  * isofs: fix minor filesystem corruption
++  * KVM: VMX: Fix a wrong usage of vmcs_config
++  * KVM: SVM: fix suspend/resume support
++  * KVM: mmu_shrink: kvm_mmu_zap_page requires slots_lock to be held
++  * KVM: VMX: Add ept_sync_context in flush_tlb
++  * KVM: x86 emulator: Fix HLT instruction
++  * KVM: MMU: nuke shadowed pgtable pages and ptes on memslot destruction
++  * KVM: MMU: Fix potential race setting upper shadow ptes on nonpae hosts
++  * Patch Upstream: x86 ptrace: fix PTRACE_GETFPXREGS error
++  * rcu: fix rcu_try_flip_waitack_needed() to prevent grace-period stall
++  * Fix typos from signal_32/64.h merge
++  * x86 reboot quirks: add Dell Precision WorkStation T5400
++  * USB: fix usb serial pm counter decrement for disconnected interfaces
++  * x86, suspend, acpi: enter Big Real Mode
++  * markers: fix duplicate modpost entry
++  * Fix build on COMPAT platforms when CONFIG_EPOLL is disabled
++  * proc: fix /proc/*/pagemap some more
++  * cpusets: fix wrong domain attr updates
++  * x86: fix crash due to missing debugctlmsr on AMD K6-3
++  * ide-cd: fix oops when using growisofs
++  * rtc-at91rm9200: avoid spurious irqs
++  * vmlinux.lds: move __attribute__((__cold__)) functions back into final
++    .text section
++  * ARM: fix fls() for 64-bit arguments
++  * tcp: Clear probes_out more aggressively in tcp_ack().
++  * sparc64: Fix lockdep issues in LDC protocol layer.
++  * sparc64: Fix cpufreq notifier registry.
++  * sparc64: Do not define BIO_VMERGE_BOUNDARY.
++  * iop-adma: fix platform driver hotplug/coldplug
++  * myri10ge: do not forget to setup the single slice pointers
++  * myri10ge: do not use mgp->max_intr_slots before loading the firmware
++  * ALSA: trident - pause s/pdif output
++  * V4L: cx18: Upgrade to newer firmware & update documentation
++  * DVB: dib0700: add support for Hauppauge Nova-TD Stick 52009
++  * V4L: uvcvideo: Fix a buffer overflow in format descriptor parsing
++  * V4L: uvcvideo: Use GFP_NOIO when allocating memory during resume
++  * V4L: uvcvideo: Don't free URB buffers on suspend
++  * V4L: uvcvideo: Make input device support optional
++  * V4L: uvcvideo: Add support for Medion Akoya Mini E1210 integrated
++    webcam
++  * V4L: saa7134: Copy tuner data earlier to avoid overwriting manual tuner
++    type
++  * V4L: cx23885: Bugfix for concurrent use of /dev/video0 and /dev/video1
++  * DVB: cx23885: Ensure PAD_CTRL is always reset to a sensible default
++  * DVB: cx23885: DVB Transport cards using DVB port VIDB/TS1 did not
++    stream
++  * DVB: cx23885: Reallocated the sram to avoid concurrent VIDB/C issues
++  * DVB: cx23885: SRAM changes for the 885 and 887 silicon parts
++  * x86: fix kernel_physical_mapping_init() for large x86 systems
++  * eCryptfs: use page_alloc not kmalloc to get a page of memory
++  * UML - Fix boot crash
++  * ixgbe: remove device ID for unsupported device
++  * mpc52xx_psc_spi: fix block transfer
++  * tmpfs: fix kernel BUG in shmem_delete_inode
++  * markers: fix markers read barrier for multiple probes
++  * VFS: increase pseudo-filesystem block size to PAGE_SIZE
++  * cpufreq acpi: only call _PPC after cpufreq ACPI init funcs got called
++    already
++  * b43legacy: Release mutex in error handling code
++  * ath5k: don't enable MSI, we cannot handle it yet
++  * Fix off-by-one error in iov_iter_advance()
++  * Linux 2.6.26.1
++  * ftrace: remove unneeded documentation
++  * romfs_readpage: don't report errors for pages beyond i_size
++  * netfilter: nf_nat_sip: c= is optional for session
++  * SCSI: bsg: fix bsg_mutex hang with device removal
++  * x86: idle process - add checking for NULL early param
++  * x86: io delay - add checking for NULL early param
++  * Close race in md_probe
++  * Kprobe smoke test lockdep warning
++  * netfilter: xt_time: fix time's time_mt()'s use of do_div()
++  * linear: correct disk numbering error check
++  * SCSI: ch: fix ch_remove oops
++  * NFS: Ensure we zap only the access and acl caches when setting new acls
++  * jbd: fix race between free buffer and commit transaction
++  * Input: i8042 - add Intel D845PESV to nopnp list
++  * Input: i8042 - add Gericom Bellagio to nomux blacklist
++  * Input: i8042 - add Acer Aspire 1360 to nomux blacklist
++  * Bluetooth: Signal user-space for HIDP and BNEP socket errors
++  * Add compat handler for PTRACE_GETSIGINFO
++  * ALSA: hda - Fix wrong volumes in AD1988 auto-probe mode
++  * ALSA: hda - Fix DMA position inaccuracy
++  * ALSA: hda - Add missing Thinkpad Z60m support
++  * ALSA: emu10k1 - Fix inverted Analog/Digital mixer switch on Audigy2
++  * vfs: fix lookup on deleted directory
++  * Ath5k: fix memory corruption
++  * Ath5k: kill tasklets on shutdown
++  * sound: ensure device number is valid in snd_seq_oss_synth_make_info
++  * Linux 2.6.26.2
++
++ -- Ben Collins <ben.collins@canonical.com>  Sun, 03 Aug 2008 13:25:02 -0400
++
++linux (2.6.26-5.14) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * SAUCE: applesmc: Add MacBookAir
++  * build: Do not build ddeb unless we are on the buildd
++  * build: control: Consistency in arch fields.
++  * SAUCE: Update toshiba_acpi.c to version 0.19a
++    - LP: #77026
++  * build: Added perm blacklist support and per-module support to abi-check
++    - Blacklist p80211 module from abi checks
++  * ubuntu/lirc: Get rid of drivers symlink and use real include stuff
++
++
++  [ Colin Ian King ]
++
++  * SAUCE: acerhk module - add support for Amilo A1650g keyboard
++    - LP: #84159
++  * SAUCE: rt2x00: Fix OOPS on failed creation of rt2x00lib workqueue
++    - LP: #249242
++
++  [ Mario Limonciello ]
++
++  * Add LIRC back in
++
++  [ Tim Gardner ]
++
++  * Makefile race condition can lead to ndiswrapper build failure
++    - LP: #241547
++  * update linux-wlan-ng (prism2_usb) to upstream version 1861
++    - LP: #245026
++
++  [ Upstream Kernel Changes ]
++
++  * Fix typos from signal_32/64.h merge
++
++ -- Ben Collins <ben.collins@canonical.com>  Fri, 01 Aug 2008 00:05:01 -0400
++
++linux (2.6.26-5.13) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * build: Make makedumpfile an amd64/i386 only build-dep
++  * ubuntu/acerhk: Fixup assembly to compile with newer binutils
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 26 Jul 2008 16:41:50 -0400
++
++linux (2.6.26-4.12) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * e1000e: Upgraded module to 0.4.1.7 upstream. Placed in ubuntu/,
++    in-kernel driver disabled
++  * config: Disable e1000e in-kernel, and enable newer driver in ubuntu/
++  * rfkill: Update to 1.3 drivers, and move to common location
++  * ubuntu: Actually link kconfig/kbuild into rfkill subdir
++  * config: Enable loading dsdt from initramfs
++    - LP: #246222
++  * ubuntu: [compcache] Update to fix crashes in improper BUG()
++  * build: Create a retag scripts to recover tags from rebases
++  * build: Updates for dbg pkg
++  * build: Make sure no empty lines show up in debian/files
++  * ubuntu: atl1e: Add new driver from 2.6.27-pre-rc1
++    - LP: #243894
++  * sys_getcwd: Fix some brokeness introduced by AppArmor __d_path
++    changes
++    - LP: #251223
++  * ubuntu: unionfs: Added v1.4 module from hardy
++  * build: Add sub-flavour infrastructure, and virtual subflav
++
++  [ Eric Piel ]
++
++  * ACPI: Allow custom DSDT tables to be loaded from initramfs
++
++  [ Kees Cook ]
++
++  * AppArmor: Smack VFS patches
++
++  [ Mario Limonciello ]
++
++  * Work around ACPI corruption upon suspend on some Dell machines.
++    - LP: #183033
++
++  [ Tim Gardner ]
++
++  * Export usbhid_modify_dquirk for LBM module bcm5974
++    - LP: #250838
++  * VIA - Add VIA DRM Chrome9 3D engine
++    - LP: #251862
++  * Define TRUE/FALSE for VIA DRM driver.
++
++ -- Ben Collins <ben.collins@canonical.com>  Tue, 15 Jul 2008 12:51:39 -0400
++
++linux (2.6.26-4.11) intrepid; urgency=low
++
++  [ Ben Collins ]
++
++  * config: Enable bcm5974 driver in all configs
++
++  [ 2.6.26-4.10 ]
++
++  [ Amit Kucheria ]
++
++  * Fix typo in GSPCA Makefile and make it compile
++
++  [ Ben Collins ]
++
++  * ubuntu: Remove UVC driver in favor of in-kernel one (-rc9)
++  * config: Updates for -rc9
++  * ubuntu: Add acx, prism2_usb wireless drivers
++  * config: Enable prism2_usb and acx drivers.
++  * ubuntu: Add at76 driver to build
++  * config: Enable at76_usb driver.
++  * iscsitarget: Fix prototype for bi_end_io callback.
++  * acx: Fix section type mismatch warnings
++  * fsam7400: Add sw kill switch driver
++  * config: Enable fsam7400 driver
++  * qc-usb: Added new driver
++  * config: Enable qc-usb driver
++  * drbd: Remove built-in connector usage
++  * drbd: Do not define idx/val for connector here
++  * connector.h: Add idx/val for drbd
++  * bcm5974: Added new driver
++
++  [ Kees Cook ]
++
++  * SAUCE: [AppArmor] merge with upstream subversion r1291
++  * SAUCE: [AppArmor] fix typo in selinux_inode_link
++  * SAUCE: [AppArmor] aufs patches
++
++  [ Michael Frey (Senior Manager, MID ]
++
++  * SAUCE: Send HCI_RESET for Broadcomm 2046
++    - LP: #241749
++
++  [ Tim Gardner ]
++
++  * SAUCE: Medion Akoya Mini E1210
++
++  [ Upstream Kernel Changes ]
++
++  * Revert "BAST: Remove old IDE driver"
++  * ARM: OMAP: DMA: Don't mark channel active in omap_enable_channel_irq
++  * ARM: OMAP: Correcting the gpmc prefetch control register address
++  * debugobjects: fix lockdep warning
++  * [ARM] 5115/1: pxafb: fix ifdef for command line option handling
++  * [ARM] 5116/1: pxafb: cleanup and fix order of failure handling
++  * [ARM] 5109/1: Mark rtc sa1100 driver as wakeup source before
++    registering it
++  * [ARM] Export dma_sync_sg_for_device()
++  * fix cgroup-inflicted breakage in block_dev.c
++  * [patch for 2.6.26 2/4] vfs: utimensat(): be consistent with utime() for
++    immutable and append-only files
++  * [patch for 2.6.26 1/4] vfs: utimensat(): ignore tv_sec if tv_nsec ==
++    UTIME_OMIT or UTIME_NOW
++  * [patch for 2.6.26 3/4] vfs: utimensat(): fix error checking for
++    {UTIME_NOW,UTIME_OMIT} case
++  * [patch for 2.6.26 4/4] vfs: utimensat(): fix write access check for
++    futimens()
++  * [patch 1/4] vfs: path_{get,put}() cleanups
++  * [patch 2/4] fs: make struct file arg to d_path const
++  * [patch 3/4] vfs: fix ERR_PTR abuse in generic_readlink
++  * [patch 4/4] flock: remove unused fields from file_lock_operations
++  * [patch 3/3] vfs: make d_path() consistent across mount operations
++  * [patch 1/3] vfs: dcache sparse fixes
++  * [patch 2/3] vfs: dcache cleanups
++  * udf: Fix regression in UDF anchor block detection
++  * [SCSI] ses: Fix timeout
++  * netfilter: ip6table_mangle: don't reroute in LOCAL_IN
++  * [SCSI] esp: Fix OOPS in esp_reset_cleanup().
++  * kernel/audit.c: nlh->nlmsg_type is gotten more than once
++  * audit: fix kernel-doc parameter notation
++  * remove useless argument type in audit_filter_user()
++  * Blackfin arch: fix bug - kernel boot fails when Spinlock and rw-lock
++    debugging enabled
++  * Blackfin arch: fix up section mismatch warning
++  * mac80211: implement EU regulatory domain
++  * b43: Do not return TX_BUSY from op_tx
++  * b43legacy: Do not return TX_BUSY from op_tx
++  * b43: Fix possible MMIO access while device is down
++  * b43legacy: Fix possible NULL pointer dereference in DMA code
++  * rt2x00: Fix unbalanced mutex locking
++  * iwlwifi: improve scanning band selection management
++  * [SCSI] esp: tidy up target reference counting
++  * [ARM] 5117/1: pxafb: fix __devinit/exit annotations
++  * thermal: Create CONFIG_THERMAL_HWMON=n
++  * ACPI: don't walk tables if ACPI was disabled
++  * dock: bay: Don't call acpi_walk_namespace() when ACPI is disabled.
++  * x86: shift bits the right way in native_read_tscp
++  * x86: section/warning fixes
++  * V4L/DVB (8004): Fix INPUT dependency at budget-ci
++  * V4L/DVB (8005): Fix OOPS if frontend is null
++  * V4L/DVB (8007): cx18/cx25840: the S-Video LUMA input can use all
++    In1-In8 inputs
++  * V4L/DVB (8008): cx18: remove duplicate audio and video input enums
++  * V4L/DVB (8010): em28xx: Properly register extensions for already
++    attached devices
++  * V4L/DVB (8011): em28xx: enable DVB for HVR-900
++  * V4L/DVB (8012): gl861: sleep a little to avoid I2C errors
++  * V4L/DVB (8013): gl861: remove useless identify_state
++  * V4L/DVB (8015): gl861: replace non critical msleep(0) with msleep(1) to
++    be on the safe side
++  * V4L/DVB (8017): Ensure em28xx extensions only get run against devs that
++    support them
++  * V4L/DVB (8018): Add em2860 chip ID
++  * V4L/DVB (8020): Fix callbacks functions of saa7134_empress
++  * V4L/DVB (8022): saa7134: fix race between opening and closing the
++    device
++  * V4L/DVB (8026): Avoids an OOPS if dev struct can't be successfully
++    recovered
++  * V4L/DVB (8027): saa7134: Avermedia A700: only s-video and composite
++    input are working
++  * V4L/DVB (8028): Improve error messages for tda1004x attach
++  * V4L/DVB (8029): Improve error message at tda1004x_attach
++  * V4L/DVB (8034): tda18271: fix IF notch frequency handling
++  * V4L/DVB (8035): tda18271: dont touch EB14 if rf_cal lookup is out of
++    range
++  * V4L/DVB (8036): tda18271: toggle rf agc speed mode on TDA18271HD/C2
++    only
++  * V4L/DVB (8037): tda18271: ensure that the thermometer is off during
++    channel configuration
++  * V4L/DVB (8039): pxa-camera: fix platform_get_irq() error handling.
++  * V4L/DVB (8040): soc-camera: remove soc_camera_host_class class
++  * V4L/DVB (8042): DVB-USB UMT-010 channel scan oops
++  * V4L/DVB (8043): au0828: add support for additional USB device id's
++  * V4L/DVB (8044): au8522: tuning optimizations
++  * V4L/DVB (8048): saa7134: Fix entries for Avermedia A16d and Avermedia
++    E506
++  * V4L/DVB (8061): cx18: only select tuner / frontend modules if
++    !DVB_FE_CUSTOMISE
++  * V4L/DVB (8063): cx18: Fix unintended auto configurations in
++    cx18-av-core
++  * V4L/DVB (8066): cx18: Fix audio mux input definitions for HVR-1600 Line
++    In 2 and FM radio
++  * V4L/DVB (8067): cx18: Fix firmware load for case when digital capture
++    happens first
++  * V4L/DVB (8068): cx18: Add I2C slave reset via GPIO upon initialization
++  * V4L/DVB (8069): cx18: Fix S-Video and Compsite inputs for the Yuan
++    MPC718 and enable card entry
++  * V4L/DVB (8071): tda10023: Fix possible kernel oops during
++    initialisation
++  * V4L/DVB (8073): av7110: Catch another type of ARM crash
++  * V4L/DVB (8074): av7110: OSD transfers should not be interrupted
++  * V4L/DVB (8075): stv0299: Uncorrected block count and bit error rate
++    fixed
++  * V4L/DVB (8092): videodev: simplify and fix standard enumeration
++  * V4L/DVB (8096): au8522: prevent false-positive lock status
++  * V4L/DVB (8097): xc5000: check device hardware state to determine if
++    firmware download is needed
++  * V4L/DVB (8100): V4L/vivi: fix possible memory leak in vivi_fillbuff
++  * V4L/DVB (8108): Fix open/close race in saa7134
++  * s2io: fix documentation about intr_type
++  * tc35815: Mark carrier-off before starting PHY
++  * tc35815: Fix receiver hangup on Rx FIFO overflow
++  * ixgbe: fix EEH recovery during reset on PPC
++  * igb: fix EEH recovery during reset on PPC
++  * e1000e: fix EEH recovery during reset on PPC
++  * pcnet_cs, axnet_cs: clear bogus interrupt before request_irq
++  * drivers/net/r6040.c: Eliminate double sizeof
++  * ipg: fix jumbo frame compilation
++  * ipg: use NULL, not zero, for pointers
++  * [netdrvr] 3c59x: remove irqs_disabled warning from local_bh_enable
++  * [netdrvr] netxen: fix netxen_pci_tbl[] breakage
++  * e100: Do pci_dma_sync after skb_alloc for proper operation on ixp4xx
++  * e1000: only enable TSO6 via ethtool when using correct hardware
++  * [netdrvr] Fix IOMMU overflow checking in s2io.c
++  * qla3xxx: Hold RTNL while calling dev_close()
++  * Hold RTNL while calling dev_close()
++  * sata_uli: hardreset is broken
++  * rt2x00: Fix lock dependency errror
++  * prism: islpci_eth.c endianness fix
++  * mac80211: fix an oops in several failure paths in key allocation
++  * firewire: fw-sbp2: fix parsing of logical unit directories
++  * kbuild: fix a.out.h export to userspace with O= build.
++  * Ensure interrupted recovery completed properly (v1 metadata plus
++    bitmap)
++  * Don't acknowlege that stripe-expand is complete until it really is.
++  * Fix error paths if md_probe fails.
++  * hamradio: remove unused variable
++  * tcp: calculate tcp_mem based on low memory instead of all memory
++  * tcp: fix for splice receive when used with software LRO
++  * af_unix: fix 'poll for write'/connected DGRAM sockets
++  * netdevice: Fix typo of dev_unicast_add() comment
++  * pkt_sched: ERR_PTR() ususally encodes an negative errno, not positive.
++  * pkt_sched: Remove CONFIG_NET_SCH_RR
++  * include/linux/netdevice.h: don't export MAX_HEADER to userspace
++  * tcp: /proc/net/tcp rto,ato values not scaled properly (v2)
++  * netlink: Fix some doc comments in net/netlink/attr.c
++  * CONNECTOR: add a proc entry to list connectors
++  * inet fragments: fix race between inet_frag_find and
++    inet_frag_secret_rebuild
++  * net/inet_lro: remove setting skb->ip_summed when not LRO-able
++  * netlabel: Fix a problem when dumping the default IPv6 static labels
++  * ipv6 route: Convert rt6_device_match() to use RT6_LOOKUP_F_xxx flags.
++  * sched: fix cpu hotplug
++  * Fix and clean top .gitignore
++  * x86: fix cpu hotplug crash
++  * ptrace GET/SET FPXREGS broken
++  * Input: add KEY_MEDIA_REPEAT definition
++  * Input: fix locking in force-feedback core
++  * [ARM] 5131/1: Annotate platform_secondary_init with trace_hardirqs_off
++  * ide: fix /proc/ide/ide?/mate reporting
++  * netfilter: nf_conntrack_tcp: fixing to check the lower bound of valid
++    ACK
++  * textsearch: fix Boyer-Moore text search bug
++  * hostap: don't report useless WDS frames by default
++  * hostap: fix sparse warnings
++  * mac80211: don't accept WEP keys other than WEP40 and WEP104
++  * V4L/DVB (8145a): USB Video Class driver
++  * [IA64] Bugfix for system with 32 cpus
++  * [IA64] export account_system_vtime
++  * sched: fix divide error when trying to configure rt_period to zero
++  * x86: fix NODES_SHIFT Kconfig range
++  * block: Fix the starving writes bug in the anticipatory IO scheduler
++  * Properly notify block layer of sync writes
++  * rcu: fix hotplug vs rcu race
++  * I2C: S3C2410: Check ACK on byte transmission
++  * I2C: S3C2410: Fixup error codes returned rom a transfer.
++  * I2C: S3C2410: Add MODULE_ALIAS() for s3c2440 device.
++  * PCI: Restrict VPD read permission to root
++  * powerpc/bootwrapper: update for initrd with simpleImage
++  * i2c: Documentation: fix device matching description
++  * i2c: Fix bad hint about irqs in i2c.h
++  * powerpc/legacy_serial: Bail if reg-offset/shift properties are present
++  * powerpc/mpc5200: Fix lite5200b suspend/resume
++  * ipv4: fix sysctl documentation of time related values
++  * net-sched: change tcf_destroy_chain() to clear start of filter list
++  * net-sched: fix filter destruction in atm/hfsc qdisc destruction
++  * netlink: Unneeded local variable
++  * net: Tyop of sk_filter() comment
++  * netdevice: Fix wrong string handle in kernel command line parsing
++  * net: fib_rules: fix error code for unsupported families
++  * dm crypt: use cond_resched
++  * V4L/DVB (8178): uvc: Fix compilation breakage for the other drivers, if
++    uvc is selected
++  * PCI: Limit VPD read/write lengths for Broadcom 5706, 5708, 5709 rev.
++  * PCI: acpiphp: cleanup notify handler on all root bridges
++  * drivers/input/ff-core.c needs <linux/sched.h>
++  * DRM/i915: only use tiled blits on 965+
++  * tty: Fix inverted logic in send_break
++  * x86: fix Intel Mac booting with EFI
++  * arch/x86/mm/init_64.c: early_memtest(): fix types
++  * 9p: fix O_APPEND in legacy mode
++  * slub: Do not use 192 byte sized cache if minimum alignment is 128 byte
++  * Do not overwrite nr_zones on !NUMA when initialising zlcache_ptr
++  * [MIPS] IP32: Fix unexpected irq 71
++  * [MIPS] IP22: Fix crashes due to wrong L1_CACHE_BYTES
++  * [MIPS] cevt-txx9: Reset timer counter on initialization
++  * hrtimer: prevent migration for raising softirq
++  * svcrpc: fix handling of garbage args
++  * OHCI: Fix problem if SM501 and another platform driver is selected
++  * USB: fix cdc-acm resume()
++  * USB: ehci - fix timer regression
++  * USB: ohci - record data toggle after unlink
++  * USB: mass storage: new id for US_SC_CYP_ATACB
++  * sisusbvga: Fix oops on disconnect.
++  * USB: New device ID for ftdi_sio driver
++  * USB: fix interrupt disabling for HCDs with shared interrupt handlers
++  * USB: don't lose disconnections during suspend
++  * USB: another option device id
++  * USB: add a pl2303 device id
++  * USB: fix Oops on loading ipaq module since 2.6.26
++  * USB: adding comment for ipaq forcing number of ports
++  * [MIPS] Fix bug in atomic_sub_if_positive.
++  * xen: fix address truncation in pte mfn<->pfn conversion
++  * sata_sil24: add DID for another adaptec flavor
++  * ahci: always clear all bits in irq_stat
++  * libata-sff: improve HSM violation reporting
++  * sata_mv: safer logic for limit_warnings
++  * Update maintainers for powerpc
++  * Christoph has moved
++  * mm: dirty page accounting vs VM_MIXEDMAP
++  * rtc: rtc_read_alarm() handles wraparound
++  * firmware: fix the request_firmware() dummy
++  * serial: fix serial_match_port() for dynamic major tty-device numbers
++  * get_user_pages(): fix possible page leak on oom
++  * rtc-x1205: Fix alarm set
++  * rtc: fix CMOS time error after writing /proc/acpi/alarm
++  * pci: VT3336 can't do MSI either
++  * Miguel Ojeda has moved
++  * ext3: add missing unlock to error path in ext3_quota_write()
++  * ext4: add missing unlock to an error path in ext4_quota_write()
++  * reiserfs: add missing unlock to an error path in reiserfs_quota_write()
++  * ecryptfs: remove unnecessary mux from ecryptfs_init_ecryptfs_miscdev()
++  * lib: taint kernel in common report_bug() WARN path.
++  * gpio: pca953x (i2c) handles max7310 too
++  * fsl_diu_fb: fix build with CONFIG_PM=y, plus fix some warnings
++  * Update taskstats-struct document for scaled time accounting
++  * cciss: fix regression that no device nodes are created if no logical
++    drives are configured.
++  * delay accounting: maintainer update
++  * Doc*/kernel-parameters.txt: fix stale references
++  * hdaps: add support for various newer Lenovo thinkpads
++  * mn10300: export certain arch symbols required to build allmodconfig
++  * mn10300: provide __ucmpdi2() for MN10300
++  * Introduce rculist.h
++  * man-pages is supported
++  * ntfs: update help text
++  * add kernel-doc for simple_read_from_buffer and memory_read_from_buffer
++  * w100fb: do not depend on SHARPSL
++  * w100fb: add 80 MHz modeline
++  * MFD maintainer
++  * cgroups: document the effect of attaching PID 0 to a cgroup
++  * spi: fix the read path in spidev
++  * doc: doc maintainers
++  * security: filesystem capabilities: fix fragile setuid fixup code
++  * security: filesystem capabilities: fix CAP_SETPCAP handling
++  * Alpha Linux kernel fails with inconsistent kallsyms data
++  * cpusets: document proc status cpus and mems allowed lists
++  * MAINTAINERS: update the email address of Andreas Dilger
++  * cciss: read config to obtain max outstanding commands per controller
++  * olpc: sdhci: add quirk for the Marvell CaFe's vdd/powerup issue
++  * olpc: sdhci: add quirk for the Marvell CaFe's interrupt timeout
++  * cpumask: introduce new APIs
++  * mm: switch node meminfo Active & Inactive pages to Kbytes
++  * Update MAINTAINERS file for the TPM device driver
++  * devcgroup: fix odd behaviour when writing 'a' to devices.allow
++  * doc: document the relax_domain_level kernel boot argument
++  * mmc: don't use DMA on newer ENE controllers
++  * mempolicy: mask off internal flags for userspace API
++  * x86 ACPI: normalize segment descriptor register on resume
++  * x86 ACPI: fix resume from suspend to RAM on uniprocessor x86-64
++  * softlockup: print a module list on being stuck
++  * ide: fix hwif->gendev refcounting
++  * ide: ide_unregister() warm-plug bugfix
++  * ide: ide_unregister() locking bugfix
++  * ahci: give another shot at clearing all bits in irq_stat
++  * Fix clear_refs_write() use of struct mm_walk
++  * Move _RET_IP_ and _THIS_IP_ to include/linux/kernel.h
++  * Fix pagemap_read() use of struct mm_walk
++  * Linux 2.6.26-rc9
++  * Revert "USB: don't explicitly reenable root-hub status interrupts"
++  * Revert "PCI: Correct last two HP entries in the bfsort whitelist"
++  * iwlwifi: fix incorrect 5GHz rates reported in monitor mode
++  * iwlwifi: drop skb silently for Tx request in monitor mode
++  * libertas: support USB persistence on suspend/resume (resend)
++  * tcp: net/ipv4/tcp.c needs linux/scatterlist.h
++  * tcp: fix a size_t < 0 comparison in tcp_read_sock
++  * bridge: fix use-after-free in br_cleanup_bridges()
++  * Add missing skb->dev assignment in Frame Relay RX code
++  * forcedeth: fix lockdep warning on ethtool -s
++  * ehea: fix might sleep problem
++  * ehea: add MODULE_DEVICE_TABLE
++  * ehea: fix race condition
++  * ehea: Access iph->tot_len with correct endianness
++  * pasemi_mac: Access iph->tot_len with correct endianness
++  * ibm_newemac: Fixes kernel crashes when speed of cable connected changes
++  * ibm_newemac: Fixes entry of short packets
++  * fs_enet: restore promiscuous and multicast settings in restart()
++  * can: add sanity checks
++  * x86: KVM guest: Add memory clobber to hypercalls
++  * KVM: IOAPIC: Fix level-triggered irq injection hang
++  * [SCSI] erase invalid data returned by device
++  * pxamci: fix byte aligned DMA transfers
++  * vsprintf: split out '%s' handling logic
++  * vsprintf: split out '%p' handling logic
++  * vsprintf: add infrastructure support for extended '%p' specifiers
++  * vsprintf: add support for '%pS' and '%pF' pointer formats
++  * powerpc: Fix unterminated of_device_id array in legacy_serial.c
++  * [UML] fix gcc ICEs and unresolved externs
++  * ocfs2/dlm: Fixes oops in dlm_new_lockres()
++  * hostap_cs: correct poor NULL checks in suspend/resume routines
++  * drivers/net/wireless/iwlwifi/iwl-3945.c Fix type issue on 64bit
++  * mac80211: move netif_carrier_on to after
++    ieee80211_bss_info_change_notify
++  * mac80211: Only flush workqueue when last interface was removed
++  * zd1211rw: add ID for AirTies WUS-201
++  * ssb-pcicore: Fix IRQ-vector init on embedded devices
++  * mac80211: don't report selected IBSS when not found
++  * crypto: tcrypt - Fix memory leak in test_cipher
++  * sctp: Mark the tsn as received after all allocations finish
++  * [S390] protect _PAGE_SPECIAL bit against mprotect
++  * irda: via-ircc proper dma freeing
++  * irda: New device ID for nsc-ircc
++  * irda: Fix netlink error path return value
++  * [SCSI] mptspi: fix oops in mptspi_dv_renegotiate_work()
++  * Correct hash flushing from huge_ptep_set_wrprotect()
++  * ide: add __ide_default_irq() inline helper
++  * palm_bk3710: fix IDECLK period calculation
++  * it8213: fix return value in it8213_init_one()
++  * [MIPS] Atlas, decstation: Fix section mismatches triggered by
++    defconfigs
++  * [MIPS] Fix 32bit kernels on R4k with 128 byte cache line size
++  * NFS: Fix readdir cache invalidation
++  * SUNRPC: Fix a double-free in rpcbind
++  * SUNRPC: Fix an rpcbind breakage for the case of IPv6 lookups
++  * reiserfs: discard prealloc in reiserfs_delete_inode
++  * Fix broken fix for fsl-diu-db
++  * RDMA/cxgb3: Fix regression caused by class_device -> device conversion
++  * ipv6: fix race between ipv6_del_addr and DAD timer
++  * sctp: Add documentation for sctp sysctl variable
++  * kernel/printk.c: Made printk_recursion_bug_msg static.
++  * powerpc: Add missing reference to coherent_dma_mask
++  * rc80211_pid: Fix fast_start parameter handling
++  * rt2x00: Disable synchronization during initialization
++  * zd1211rw: stop beacons on remove_interface
++  * libertas: fix memory alignment problems on the blackfin
++  * netfilter: nf_conntrack_tcp: fix endless loop
++  * netfilter: nf_nat_snmp_basic: fix a range check in NAT for SNMP
++  * md: ensure all blocks are uptodate or locked when syncing
++  * sched: fix cpu hotplug
++  * x86: fix /dev/mem compatibility under PAT
++  * crypto: chainiv - Invoke completion function
++  * ocfs2: Fix flags in ocfs2_file_lock
++  * kernel/kprobes.c: Made kprobe_blacklist static.
++  * arch/x86/kernel/.gitignore: Added vmlinux.lds to .gitignore file
++    because it shouldn't be tracked.
++  * ftrace: Documentation
++  * Fix PREEMPT_RCU without HOTPLUG_CPU
++  * sched: fix cpu hotplug, cleanup
++  * exec: fix stack excutability without PT_GNU_STACK
++  * slub: Fix use-after-preempt of per-CPU data structure
++  * Documentation: clarify tcp_{r,w}mem sysctl docs
++  * ip: sysctl documentation cleanup
++  * tcp: correct kcalloc usage
++  * ipv4: fib_trie: Fix lookup error return
++  * netlabel: netlink_unicast calls kfree_skb on error path by itself
++  * ipv6: missed namespace context in ipv6_rthdr_rcv
++  * xfrm: Add a XFRM_STATE_AF_UNSPEC flag to xfrm_usersa_info
++  * tun: Persistent devices can get stuck in xoff state
++  * tpm: add Intel TPM TIS device HID
++  * rapidio: fix device reference counting
++  * Fix name of Russell King in various comments
++  * rtc: fix reported IRQ rate for when HPET is enabled
++  * libata-acpi: filter out DIPM enable
++  * Added Targa Visionary 1000 IDE adapter to pata_sis.c
++  * libata-acpi: don't call sleeping function from invalid context
++  * Fix reference counting race on log buffers
++  * [SCSI] ipr: Fix HDIO_GET_IDENTITY oops for SATA devices
++  * IPMI: return correct value from ipmi_write
++  * x86: fix ldt limit for 64 bit
++  * [SCSI] fusion: default MSI to disabled for SPI and FC controllers
++  * [SCSI] bsg: fix oops on remove
++  * drivers/char/pcmcia/ipwireless/hardware.c fix resource leak
++  * drivers/isdn/i4l/isdn_common.c fix small resource leak
++  * fbdev: bugfix for multiprocess defio
++  * serial8250: sanity check nr_uarts on all paths.
++  * ov7670: clean up ov7670_read semantics
++  * rtc-fm3130: fix chip naming
++  * rtc-pcf8563: add chip id
++  * OProfile kernel maintainership changes
++  * frv: fix irqs_disabled() to return an int, not an unsigned long
++  * cifs: fix inode leak in cifs_get_inode_info_unix
++  * cifs: fix wksidarr declaration to be big-endian friendly
++  * cpusets, hotplug, scheduler: fix scheduler domain breakage
++  * Documentation/HOWTO: correct wrong kernel bugzilla FAQ URL
++  * devcgroup: always show positive major/minor num
++  * devcgroup: fix permission check when adding entry to child cgroup
++  * Linux 2.6.26
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 14 Jul 2008 13:41:50 -0400
++
++linux (2.6.26-3.9) intrepid; urgency=low
++
++  * abi: Add dca and ioatdma to modules.ignore
++
++  [ 2.6.26-3.8 ]
++
++  [ Ben Collins ]
++
++  * ubuntu: Add heci driver 3.2.0.24
++  * ubuntu: Add heci to kconfig/kbuild
++  * config: Enable heci module on all flavours
++  * dm-bbr: Update to get it to compile with 2.6.26
++  * config: Enable dm-bbr
++  * ubuntu: Add some media drivers
++  * config: Enable misc media drivers
++  * udeb: Switch to uvesafb in fb-modules
++  * abi: Add more modules to ignore (known)
++
++  [ 2.6.26-3.7 ]
++
++  [Amit Kucheria]
++
++  * SAUCE: make fc transport removal of target configurable
++     - LP: #163075
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [Ben Collins]
++
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: irda: Default to dongle type 9 on IBM hardware
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: version: Implement version_signature proc file.
++  * build: Cleanup arches
++  * build: Remove remnants of unused binary-custom infrastructure
++  * build: Remove disable_d_i (not needed) and cleanup ppa build stuff
++  * ubuntu: New modules, acer-acpi
++  * build: Remove -virtual, and rebuild configs
++  * ubuntu: Add drbd module
++  * acer-acpi: Fix makefile
++  * x86/Kconfig: Fix missing quote for ubuntu Kconfig source
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Added Amiga FS driver
++  * ubuntu: Add squashfs driver
++  * ubuntu: Remove asfs (Amiga FS). Need to be in linux-ports instead
++  * squashfs: Move headers to real include directory
++  * build/configs: The Great Config Consistency Check of 2008
++  * ubuntu: Move third-party includes to ubuntu/include
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Add dm-radi4-5 driver
++  * build: Add CONFIG_DEBUG_SECTION_MISMATCH=y to get old style warnings
++    from build
++  * ubuntu/Makefile: Fixup dm-raid4-5 and add kludge for kbuild
++  * squashfs: Fixes for VFS changes
++  * ubuntu/dm-raid4-5: Fixups for moved/renamed headers/functions in core
++    md
++  * ubuntu: Add ndiswrapper driver
++  * d-i: Update module listings
++  * build: Disable xd block device (ancient)
++  * ndiswrapper: Fixup makefile
++  * d-i: Remove efi-modules. The only module, efivars, is built-in
++  * build: Remove install-source, obsolete and caused build failure
++  * Ubuntu-2.6.26-1.3
++  * build: linux-doc rules got broken when disabling html side. Fixed now.
++  * Ubuntu-2.6.26-1.4
++  * x86: Update to -rc6 allows CONFIG_PCI_OLPC to work with PCI_GOANY
++  * d-i: Make virtio-ring optional (it's built-in on i386)
++  * Ubuntu-2.6.26-1.4
++  * Ubuntu-2.6.26-1.5
++  * config: Enable DVB devices
++  * ubuntu/aufs: Make aufs a bool config, since it needs to be built-in
++  * config: Build aufs into the kernels
++  * build: Fix arguments passed to link-headers script
++  * config: Disable early printk
++  * d-i: Move isofs to storage-core and kill st (scsi tape) from list
++  * config: Enable non-promiscuous access to /dev/mem
++  * x86: Add option to disable decompression info messages
++  * config: Enable no-bz-chatter config options
++  * build: Re-add linux-source package
++  * d-i: Re-add socket-modules. Accidentally removed
++    - LP: #241295
++  * Ubuntu-2.6.26-2.6
++  * Use makedumpfile to generate a vmcoreinfo file.
++  * build: Build-Depend on makedumpfile for vmcoreinfo generation
++  * build: Remove debug print from git-ubuntu-log
++  * Updated configs for -rc7
++  * build: postinst, do not call depmod with -F
++  * config: Enable rtc-cmos as a built-in driver.
++  * control: Provide ndiswrapper-modules-1.9
++  * build: Generate vmcoreinfo in image build for crashdumps without debug
++    image
++  * config: Disable vesafb, since we'll prefer uvesafb
++  * build: Copy uvesafb module to initrd mod directory
++  * abi-check: New, more robust script
++  * config: Enable heap randomization by default
++  * abi-check: Cleanup output and call with perl (not $SHELL)
++  * abi: Ignore missing vesafb (known)
++  * config: Disable pcspkr (in favor of snd-pcsp)
++  * swap: Add notify_swap_entry_free callback for compcache
++  * compcache: Added ram backed compressed swap module
++  * ubuntu: Enable kbuild and kconfig for compcache
++  * config: Enable compcache and tlsf allocator as modules
++  * config: Updated for -rc8. Disables XEN on i386
++  * config: Switch i386-server to 64G, enable PAE, 64-bit res, and XEN
++  * ubuntu: Add misc drivers from hardy lum
++  * ubuntu: Enable build of misc/ subdir
++  * config: Enable misc drivers
++  * aufs: Fix warning about single non-string-literal arg to printf style
++    function
++  * drivers: Remove some duplicate device entries in various modules
++  * config: Disable some duplicate drivers
++  * keyspan: Remove duplicate device ID's
++  * check-aliases: Cleanup output, and fix rolling checks
++  * ubuntu: Disable dm-bbr for now
++  * dm-bbr: First cut at forward portiong. Still needs work.
++  * ubuntu: Disable dm-bbr in kbuild/kconfig
++
++  [Chuck Short]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++     - LP: #175834
++  * SAUCE: [USB]: add ASUS LCM to the blacklist
++
++  [Colin Ian King]
++
++  * SAUCE: airprime.c supports more devices
++    - LP: #208250
++  * SAUCE: Enable speedstep for sonoma processors. 
++     - LP: #132271
++  * Add dm-loop
++  * Add dm-loop BOM
++
++  [Kyle McMartin]
++
++  * SAUCE: fix orinoco_cs oops
++
++  [Mario Limonciello]
++
++  * SAUCE: Enable Reset and SCO workaround on Dell 410 BT adapter
++
++  [Matthew Garrett]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [Phillip Lougher]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [Stefan Bader]
++
++  * SAUCE: Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: Always use SCO protocol (disable eSCO support) Bug: #39414
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers OriginalAuthor:
++    Pascal Terjan <pterjan@mandriva.com> Bug: #137686
++  * SAUCE: Add blacklist support to fix Belkin bluetooth dongle. Bug:
++    #140511
++  * SAUCE: Lower warning level of pci resource allocation messages. Bug:
++    159241
++  * SAUCE: Lower message level for PCI memory and I/O allocation.
++    - LP: #159241
++  * Modify log generation to catch bug numbers when adding with git-am.
++
++  [Tim Gardner]
++
++  * Added the debian directory. Ignore: yes
++  * Add support for UBUNTUINCLUDE Ignore: yes
++  * LUM headers go in /usr/src Ignore: yes
++  * First pass at 2.6.25 configs Ignore: yes
++  * i386 -generic builds. Ignore: yes
++  * SAUCE: Increase CONFIG_IDE_MAX_HWIFS to 8 (from 4)
++  * SAUCE: Add extra headers to linux-libc-dev OriginalAuthor: Soren Hansen
++    OriginalLocation:
++    https://lists.ubuntu.com/archives/kernel-team/2007-November/001891.html
++  * Set CONFIG_DEVKMEM=n Ignore: yes
++  * Enabled ALSA and CGROUPS for i386 Ignore: yes
++  * Enabled amd64 configs. Ignore: yes
++  * CONFIG_STANDALONE=n Ignore: yes
++  * CONFIG_BLK_DEV_4DRIVES=n for i386 Ignore: yes
++  * CONFIG: CONFIG_DEFAULT_RELATIME=y for all flavours. Ignore: yes
++  * Set CONFIG_EDD_OFF=y Ignore: yes
++  * SAUCE: Blacklist Bluetooth Dell Wireless 370 for SCO MTU
++    OriginalAuthor: Mario Limonciello <Mario_Limonciello@Dell.com> Bug:
++    #209715
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: frame buffer regression - screen blank except for blinking
++    cursor after fbcon vtswitch OriginalAuthor: Matthew Garrett
++    <mjg59@srcf.ucam.org> Bug: #201591
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++    OriginalAuthor: Klaus S. Madsen <ubuntu@hjernemadsen.org>
++    OriginalAuthor: Chuck Short <zulcss@ubuntu.com>
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: orinoco_cs.ko missing
++  * Set CONFIG_FB_VESA=m for i386/amd64 Ignore: yes
++  * Set CONFIG_PM_DISABLE_CONSOLE=y for all flavours Ignore: yes
++  * Thorough review of amd64 -generic config Ignore: yes
++  * Build PPA packages for Hardy until the Intrepid archive is opened.
++  * Deleted obsolete flavours Ignore: yes
++  * Don't build docs for PPA Ignore: yes
++  * Build all standard packages in PPA. Ignore: yes
++  * Remove duplicate USB ids
++  * SAUCE: DVB-USB UMT-010 driver oops on install Bug: #115284
++  * Update configs after rebase to 2.6.26-rc1 Ignore: yes
++  * Update configs after rebase Ignore: yes
++  * Disable V4L until the build issues get ironed out. Ignore: yes
++  * Update configs after rebase. Ignore: yes
++  * Another device enable pass Ignore: yes
++  * Update configs after merge. Ignore: yes
++  * SAUCE: fn key doesn't work in hardy with macbook pro fourth generation
++    (4,1)
++    - LP: #207127
++  * Enabled CONFIG_CIFS_DFS_UPCALL=y and CONFIG_CIFS_UPCALL=y
++    - LP: #236830
++
++  [Upstream Kernel Changes]
++
++  * Revert "[WATCHDOG] hpwdt: Add CFLAGS to get driver working"
++  * mac80211: detect driver tx bugs
++  * hwmon: (lm85) Fix function RANGE_TO_REG()
++  * hwmon: (adt7473) Initialize max_duty_at_overheat before use
++  * hwmon: Update the sysfs interface documentation
++  * hwmon: (abituguru3) Identify Abit AW8D board as such
++  * hwmon: (w83791d) new maintainer
++  * hwmon: (abituguru3) update driver detection
++  * hwmon: (lm75) sensor reading bugfix
++  * ipv6: Remove options header when setsockopt's optlen is 0
++  * ipv6: Drop packets for loopback address from outside of the box.
++  * sched: rt: dont stop the period timer when there are tasks wanting to
++    run
++  * sched: fix wait_for_completion_timeout() spurious failure under heavy
++    load
++  * x86: fix NULL pointer deref in __switch_to
++  * xen: Use wmb instead of rmb in xen_evtchn_do_upcall().
++  * xen: mask unwanted pte bits in __supported_pte_mask
++  * xen: don't drop NX bit
++  * sched: refactor wait_for_completion_timeout()
++  * Ext4: Fix online resize block group descriptor corruption
++  * [IA64] SN2: security hole in sn2_ptc_proc_write
++  * alpha: fix module load failures on smp (bug #10926)
++  * alpha: link failure fix
++  * alpha: fix compile failures with gcc-4.3 (bug #10438)
++  * alpha: resurrect Cypress IDE quirk
++  * pppoe: warning fix
++  * sctp: Make sure N * sizeof(union sctp_addr) does not overflow.
++  * netns: Don't receive new packets in a dead network namespace.
++  * Add return value to reserve_bootmem_node()
++  * Slab: Fix memory leak in fallback_alloc()
++  * Fix performance regression on lmbench select benchmark
++  * ALSA: aw2 - Fix Oops at initialization
++  * ALSA: sb - Fix wrong assertions
++  * futexes: fix fault handling in futex_lock_pi
++  * IB/mthca: Clear ICM pages before handing to FW
++  * tty_driver: Update required method documentation
++  * removed unused var real_tty on n_tty_ioctl()
++  * Fix ZERO_PAGE breakage with vmware
++  * mm: fix race in COW logic
++  * NFS: Reduce the NFS mount code stack usage.
++  * NFS: Fix filehandle size comparisons in the mount code
++  * NFS: nfs_updatepage(): don't mark page as dirty if an error occurred
++  * alpha: fix compile error in arch/alpha/mm/init.c
++  * KVM: Fix race between timer migration and vcpu migration
++  * KVM: close timer injection race window in __vcpu_run
++  * KVM: MMU: Fix rmap_write_protect() hugepage iteration bug
++  * KVM: MMU: large page update_pte issue with non-PAE 32-bit guests
++    (resend)
++  * KVM: MMU: Fix oops on guest userspace access to guest pagetable
++  * KVM: ioapic: fix lost interrupt when changing a device's irq
++  * KVM: VMX: Fix host msr corruption with preemption enabled
++  * [GFS2] BUG: unable to handle kernel paging request at ffff81002690e000
++  * xen: remove support for non-PAE 32-bit
++  * kgdb: documentation update - remove kgdboe
++  * kgdb: sparse fix
++  * [IA64] Fix boot failure on ia64/sn2
++  * [IA64] Handle count==0 in sn2_ptc_proc_write()
++  * [IA64] Eliminate NULL test after alloc_bootmem in iosapic_alloc_rte()
++  * [GFS2] fix gfs2 block allocation (cleaned up)
++  * x86: Add structs and functions for paravirt clocksource
++  * x86: Make xen use the paravirt clocksource structs and functions
++  * KVM: Make kvm host use the paravirt clocksource structs
++  * x86: KVM guest: Use the paravirt clocksource structs and functions
++  * KVM: Remove now unused structs from kvm_para.h
++  * enable bus mastering on i915 at resume time
++  * Linux 2.6.26-rc8
++  * # Ubuntu external driver commit.
++  * # Ubuntu commit template.
++
++ -- Ben Collins <ben.collins@canonical.com>  Sat, 21 Jun 2008 09:05:15 -0400
++
++linux (2.6.26-2.6) intrepid; urgency=low
++
++  [Ben Collins]
++
++  * Revert "SAUCE: Export symbols for aufs (in lum) (not needed)
++  * config: Enable DVB devices
++  * ubuntu/aufs: Make aufs a bool config, since it needs to be built-in
++  * config: Build aufs into the kernels
++  * build: Fix arguments passed to link-headers script
++  * config: Disable early printk
++  * d-i: Move isofs to storage-core and kill st (scsi tape) from list
++  * config: Enable non-promiscuous access to /dev/mem
++  * x86: Add option to disable decompression info messages
++  * config: Enable no-bz-chatter config options
++  * build: Re-add linux-source package
++  * d-i: Re-add socket-modules. Accidentally removed
++    - LP: #241295
++
++  [Colin Ian King]
++
++  * Add dm-loop
++
++  [Tim Gardner]
++
++  * Revert "SAUCE: USB bluetooth device 0x0e5e:0x6622 floods errors to
++    syslog (merged upstream)
++
++ -- Ben Collins <ben.collins@canonical.com>  Mon, 16 Jun 2008 10:56:01 -0400
++
++linux (2.6.26-1.5) intrepid; urgency=low
++
++  * d-i: Make virtio-ring optional (it's built-in on i386)
++  * Rebased on 2.6.26-rc6
++
++  [Ubuntu-2.6.26-1.4 Changes below]
++
++  * build: linux-doc rules got broken when disabling html side. Fixed now.
++
++  [Ubuntu-2.6.26-1.3 Changes below]
++
++  * build: Remove install-source, obsolete and caused build failure
++
++  [Ubuntu-2.6.26-1.2 Changes below]
++
++  * Remove efi-modules from d-i module list (efivars is built-in). Caused a
++    build failure.
++  * Patch to arch/x86/xen/time.c to remove __divdi3 usage (build failure on
++    i386).
++
++  [Ubuntu-2.6.26-1.1 Changes below]
++
++  [Amit Kucheria]
++
++  * SAUCE: make fc transport removal of target configurable
++  * SAUCE: Add AGP support for Radeon Mobility 9000 chipset
++  * SAUCE: pm: Config option to disable handling of console during
++    suspend/resume
++
++  [Ben Collins]
++
++  * SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps
++  * SAUCE: irda: Default to dongle type 9 on IBM hardware
++  * SAUCE: tulip: Let dmfe handle davicom on non-sparc
++  * SAUCE: tulip: Define ULI PCI ID's
++  * SAUCE: version: Implement version_signature proc file.
++  * build: Remove remnants of unused binary-custom infrastructure
++  * mmc_block: Fix bad allocation on 64-bit (zero len array)
++  * ubuntu: New modules, acer-acpi
++  * build: Remove -virtual, and rebuild configs
++  * ubuntu: Add drbd module
++  * ubuntu: Add iscsitarget module
++  * ubuntu: Add squashfs driver
++  * build/configs: The Great Config Consistency Check of 2008
++  * ubuntu: Add aufs module
++  * ubuntu: Added atl2 driver
++  * ubuntu: Add dm-radi4-5 driver
++  * build: Add CONFIG_DEBUG_SECTION_MISMATCH=y to get old style warnings
++    from build
++  * squashfs: Fixes for VFS changes
++  * ubuntu/dm-raid4-5: Fixups for moved/renamed headers/functions in core
++    md
++  * ubuntu: Add ndiswrapper driver
++  * d-i: Update module listings
++
++  [Chuck Short]
++
++  * SAUCE: ata: blacklist FUJITSU MHW2160BH PL
++  * SAUCE: [USB]: add ASUS LCM to the blacklist
++
++  [Colin Ian King]
++
++  * SAUCE: Enable speedstep for sonoma processors.
++  * SAUCE: airprime.c supports more devices
++
++  [Kyle McMartin]
++
++  * SAUCE: fix orinoco_cs oops
++
++  [Mario Limonciello]
++
++  * SAUCE: Enable Reset and SCO workaround on Dell 410 BT adapter
++
++  [Matthew Garrett]
++
++  * SAUCE: hostap: send events on data interface as well as master
++    interface
++
++  [Phillip Lougher]
++
++  * SAUCE: r8169: disable TSO by default for RTL8111/8168B chipsets.
++
++  [Stefan Bader]
++
++  * SAUCE: Export dm_disk function of device-mapper
++  * SAUCE: Restore VT fonts on switch
++  * SAUCE: Always use SCO protocol (disable eSCO support) Bug: #39414
++  * SAUCE: mmc: Increase power_up deleay to fix TI readers
++  * SAUCE: Add blacklist support to fix Belkin bluetooth dongle.
++  * SAUCE: Lower warning level of pci resource allocation messages.
++  * SAUCE: Lower message level for PCI memory and I/O allocation.
++    - LP: #159241
++  * Modify log generation to catch bug numbers when adding with git-am.
++
++  [Tim Gardner]
++
++  * SAUCE: hdaps module does not load on Thinkpad T61P
++  * SAUCE: Add extra headers to linux-libc-dev
++  * SAUCE: Export symbols for aufs (in lum).
++  * SAUCE: USB bluetooth device 0x0e5e:0x6622 floods errors to syslog
++  * SAUCE: Blacklist Bluetooth Dell Wireless 370 for SCO MTU
++  * SAUCE: Catch nonsense keycodes and silently ignore
++  * SAUCE: frame buffer regression - screen blank except for blinking
++    cursor after fbcon vtswitch
++  * SAUCE: Added support for HDAPS on various ThinkPads from Lenovo and IBM
++  * SAUCE: Guest OS does not recognize a lun with non zero target id on
++    Vmware ESX Server
++  * SAUCE: Modualrize vesafb
++  * SAUCE: DVB-USB UMT-010 driver oops on install
++  * SAUCE: fn key doesn't work in hardy with macbook pro fourth generation
++    (4,1)
++    - LP: #207127
++
++ -- Ben Collins <ben.collins@canonical.com>  Wed, 11 Jun 2008 05:28:35 -0400
+diff --git a/debian.master/config/amd64/config.common.amd64 b/debian.master/config/amd64/config.common.amd64
+new file mode 100644
+index 0000000..77bf324
+--- /dev/null
++++ b/debian.master/config/amd64/config.common.amd64
+@@ -0,0 +1,117 @@
++#
++# Config options for config.common.amd64 automatically generated by splitconfig.pl
++#
++CONFIG_64BIT=y
++CONFIG_AC97_BUS=m
++CONFIG_ACPI_BLACKLIST_YEAR=0
++CONFIG_AHCI_IMX=m
++CONFIG_ARCH_DEFCONFIG="arch/x86/configs/x86_64_defconfig"
++CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ARCH_SPARSEMEM_DEFAULT=y
++# CONFIG_ASYNC_TX_DMA is not set
++CONFIG_AUDIT_ARCH=y
++CONFIG_BCH=m
++CONFIG_COMPACTION=y
++CONFIG_CPU_FREQ=y
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++CONFIG_EZX_PCAP=y
++CONFIG_FB_BACKLIGHT=y
++CONFIG_FB_BOOT_VESA_SUPPORT=y
++CONFIG_FB_DDC=m
++CONFIG_FB_SVGALIB=m
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++# CONFIG_FONTS is not set
++CONFIG_FUNCTION_TRACER=y
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_TWL6040=m
++# CONFIG_HAVE_AOUT is not set
++CONFIG_HAVE_BOOTMEM_INFO_NODE=y
++# CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HZ=250
++CONFIG_ILLEGAL_POINTER_VALUE=0xdead000000000000
++CONFIG_KSM=y
++CONFIG_KVM=m
++CONFIG_LIBERTAS_MESH=y
++CONFIG_LIS3L02DQ=m
++CONFIG_LOG_BUF_SHIFT=18
++# CONFIG_MFD_TMIO is not set
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++CONFIG_MTD_SM_COMMON=m
++CONFIG_MUSB_PIO_ONLY=y
++CONFIG_NL80211_TESTMODE=y
++CONFIG_NOP_USB_XCEIV=m
++CONFIG_NR_CPUS=256
++CONFIG_OMAP_CONTROL_USB=m
++CONFIG_OUTPUT_FORMAT="elf64-x86-64"
++CONFIG_PCCARD=m
++CONFIG_PHYS_ADDR_T_64BIT=y
++# CONFIG_PM_WAKELOCKS is not set
++CONFIG_PPS=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_RCU_FANOUT=64
++CONFIG_RCU_NOCB_CPU=y
++CONFIG_RCU_USER_QS=y
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_RT2800USB_UNKNOWN=y
++# CONFIG_RT2X00_LIB_DEBUGFS is not set
++CONFIG_RTC_DRV_CMOS=y
++CONFIG_SATA_AHCI_PLATFORM=m
++# CONFIG_SATA_HIGHBANK is not set
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_SPI_ATTRS=y
++CONFIG_SMS_SIANO_DEBUGFS=y
++CONFIG_SND=m
++CONFIG_SND_COMPRESS_OFFLOAD=m
++CONFIG_SND_EMU10K1_SEQ=m
++CONFIG_SND_OPL3_LIB_SEQ=m
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=m
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_HDMI_CODEC=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_SOC_TWL6040=m
++CONFIG_SND_TIMER=m
++CONFIG_SOUND=m
++CONFIG_SPARSEMEM_MANUAL=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_STACK_TRACER=y
++# CONFIG_STANDALONE is not set
++# CONFIG_TICK_CPU_ACCOUNTING is not set
++# CONFIG_TWL4030_CORE is not set
++CONFIG_USB_CHIPIDEA=m
++CONFIG_USB_EHCI_HCD_PLATFORM=y
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_MUSB_TUSB6010=m
++CONFIG_USB_OHCI_HCD_PLATFORM=y
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_CONSOLE=m
++CONFIG_VIRTIO_MMIO=m
++CONFIG_WIL6210=m
++CONFIG_X86_MINIMUM_CPU_FAMILY=64
++CONFIG_X86_SPEEDSTEP_LIB=m
++CONFIG_XEN_MAX_DOMAIN_MEMORY=500
++CONFIG_ZONE_DMA32=y
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/amd64/config.flavour.generic b/debian.master/config/amd64/config.flavour.generic
+new file mode 100644
+index 0000000..bb7773a
+--- /dev/null
++++ b/debian.master/config/amd64/config.flavour.generic
+@@ -0,0 +1,3 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/annotations b/debian.master/config/annotations
+new file mode 100644
+index 0000000..fa9d6ca
+--- /dev/null
++++ b/debian.master/config/annotations
+@@ -0,0 +1,1373 @@
++#  not a thing
++CONFIG_USB_OHCI_HCD_PLATFORM			- flag<IGNORE>
++CONFIG_USB_EHCI_HCD_PLATFORM			- flag<IGNORE>
++CONFIG_USB_OHCI_HCD_PPC_OF_LE			- flag<IGNORE>
++
++# Overall defaults
++set +all !flag EXPERIMENTAL !flag IGNORE ?type tristate	= m
++
++# Mark debugging symbols.
++#  default all debug symbols off
++set +pattern '(^|_)DEBUG(_|$)' ?type bool	= n flag<DEBUG>
++set +pattern '(^|_)DEBUG(_|$)' ?type tristate	= n flag<DEBUG>
++
++#  exceptions
++CONFIG_DEBUG_FS					y note<required debug option>
++CONFIG_DEBUG_KERNEL				y note<required debug option>
++CONFIG_DEBUG_RODATA				y mark<ENFORCED>
++CONFIG_DEBUG_SET_MODULE_RONX			y mark<ENFORCED>
++CONFIG_SLUB_DEBUG				y
++CONFIG_SCHED_DEBUG				y
++
++# IO Schedulers
++set +tree 'IO Schedulers'			= - mark<IO>
++set +all ?mark 'IO' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'IO' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>
++set +all ?mark 'IO' !flag EXPERIMENTAL ?type tristate = m
++#  exceptions
++CONFIG_IOSCHED_CFQ				y
++CONFIG_IOSCHED_DEADLINE				y
++CONFIG_DEFAULT_DEADLINE				y
++CONFIG_CFQ_GROUP_IOSCHED			y
++
++# Filesystems
++set +tree 'File systems' ?tree 'File systems,NLS' = - mark<Filesystem>
++set +all ?mark 'Filesystem' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Filesystem' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>`
++set +all ?mark 'Filesystem' !flag EXPERIMENTAL ?type tristate = m
++#  default installer filesystems should be built-in
++CONFIG_EXT3_FS					y note<default filesystem> mark<CRITICAL>
++CONFIG_EXT4_FS					y note<default filesystem> mark<CRITICAL>
++#  filesystems which do not probe
++CONFIG_FUSE_FS					y note<not autoloadable>
++CONFIG_ECRYPT_FS				y note<not autoloadable>
++#  standard options
++set +pattern _POSIX_ACL$ !flag EXPERIMENTAL	= y
++set +pattern _SECURITY$ !flag EXPERIMENTAL	= y
++set +pattern _XATTR$ !flag EXPERIMENTAL		= y
++#  sub-sub-systems
++CONFIG_MISC_FILESYSTEMS				y
++CONFIG_NETWORK_FILESYSTEMS			y
++CONFIG_DNOTIFY					y
++CONFIG_FANOTIFY					y
++CONFIG_FANOTIFY_ACCESS_PERMISSIONS		y
++CONFIG_FILE_LOCKING				y
++CONFIG_INOTIFY_USER				y
++CONFIG_HUGETLBFS				y
++CONFIG_SYSFS					y
++CONFIG_QUOTA					y
++CONFIG_QUOTA_NETLINK_INTERFACE			y
++CONFIG_PRINT_QUOTA_WARNING			n
++#  btrfs
++CONFIG_BTRFS_FS_POSIX_ACL			y
++#  cachefiles
++CONFIG_CACHEFILES_HISTOGRAM			n
++#  CIFS
++CONFIG_CIFS_ACL					y
++CONFIG_CIFS_DEBUG				y
++CONFIG_CIFS_DEBUG2				n
++CONFIG_CIFS_DFS_UPCALL				y
++CONFIG_CIFS_FSCACHE				y
++CONFIG_CIFS_POSIX				y
++CONFIG_CIFS_SMB2				y
++CONFIG_CIFS_STATS				y
++CONFIG_CIFS_STATS2				n
++CONFIG_CIFS_UPCALL				y
++CONFIG_CIFS_WEAK_PW_HASH			y
++#  ext2
++CONFIG_EXT2_FS_XIP				n
++#  ext3
++CONFIG_EXT3_DEFAULTS_TO_ORDERED			y
++#  f2fs
++CONFIG_F2FS_STAT_FS				y
++#  fat
++CONFIG_FAT_DEFAULT_CODEPAGE			437
++CONFIG_FAT_DEFAULT_IOCHARSET			"iso8859-1"
++#  fscache
++CONFIG_FSCACHE_HISTOGRAM			n
++CONFIG_FSCACHE_OBJECT_LIST			n
++CONFIG_FSCACHE_STATS				y
++#  gfs2
++CONFIG_GFS2_FS_LOCKING_DLM			y
++#  jffs2
++CONFIG_JFFS2_CMODE_FAVOURLZO			y
++CONFIG_JFFS2_COMPRESSION_OPTIONS		y
++CONFIG_JFFS2_FS_DEBUG				0
++CONFIG_JFFS2_FS_WBUF_VERIFY			n
++CONFIG_JFFS2_FS_WRITEBUFFER			y
++CONFIG_JFFS2_LZO				y
++CONFIG_JFFS2_RTIME				y
++CONFIG_JFFS2_RUBIN				n
++CONFIG_JFFS2_SUMMARY				n
++CONFIG_JFFS2_ZLIB				y
++#  jfs
++CONFIG_JFS_STATISTICS				y
++#  iso9660_fs
++CONFIG_JOLIET					y
++CONFIG_ZISOFS					y
++#  ncpfs
++CONFIG_NCPFS_EXTRAS				y
++CONFIG_NCPFS_IOCTL_LOCKING			y
++CONFIG_NCPFS_NFS_NS				y
++CONFIG_NCPFS_NLS				y
++CONFIG_NCPFS_OS2_NS				y
++CONFIG_NCPFS_PACKET_SIGNING			y
++CONFIG_NCPFS_SMALLDOS				n
++CONFIG_NCPFS_STRONG				y
++#  nfsd
++CONFIG_NFSD_V3_ACL				y
++CONFIG_NFSD_V3					y
++CONFIG_NFSD_V4					y note<experimental opt-in>
++#  nfs
++CONFIG_NFS_FSCACHE				y
++CONFIG_NFS_SWAP					y
++CONFIG_NFS_USE_LEGACY_DNS			n
++CONFIG_NFS_V3_ACL				y
++CONFIG_NFS_V4_1					y
++CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN	"kernel.org"
++#  ntfs
++CONFIG_NTFS_RW					n
++#  ocfs2
++CONFIG_OCFS2_FS_STATS				y
++CONFIG_OCFS2_DEBUG_MASKLOG			y
++#  procfs
++CONFIG_PROC_FS					y
++CONFIG_PROC_KCORE				y
++CONFIG_PROC_PAGE_MONITOR			y
++CONFIG_PROC_SYSCTL				y
++CONFIG_PROC_VMCORE				y
++#  pstore
++CONFIG_PSTORE					y
++CONFIG_PSTORE_CONSOLE				n note<can cause machine brickage>
++CONFIG_PSTORE_FTRACE				n
++#  reiserfs
++CONFIG_REISERFS_CHECK				n
++CONFIG_REISERFS_PROC_INFO			n
++#  romfs
++CONFIG_ROMFS_BACKED_BY_BLOCK			y
++#  squashfs
++CONFIG_SQUASHFS_4K_DEVBLK_SIZE			n
++CONFIG_SQUASHFS_EMBEDDED			n
++CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE		3
++CONFIG_SQUASHFS_LZO				y
++CONFIG_SQUASHFS_XZ				y
++CONFIG_SQUASHFS_ZLIB				y
++#  tmpfs
++CONFIG_TMPFS					y
++#  ubifs
++CONFIG_UBIFS_FS_ADVANCED_COMPR			n
++CONFIG_UBIFS_FS_LZO				y
++CONFIG_UBIFS_FS_ZLIB				y
++#  xfs
++CONFIG_XFS_QUOTA				y
++CONFIG_XFS_RT					y
++
++# Subsystems -- mark up for reporting
++CONFIG_PCI					y mark<Subsystem>
++CONFIG_BT					m mark<Subsystem>
++CONFIG_APM					m mark<Subsystem>
++CONFIG_ACPI					y mark<Subsystem>
++
++CONFIG_RFKILL					y mark<Subsystem>
++CONFIG_HOTPLUG_PCI				y mark<Subsystem>
++CONFIG_HOTPLUG_PCI_PCIE				y mark<Subsystem>
++CONFIG_HWMON					y mark<Subsystem>
++CONFIG_HW_RANDOM				y mark<Subsystem>
++CONFIG_MMC					y mark<Subsystem>
++CONFIG_CONNECTOR				y mark<Subsystem>
++CONFIG_POWER_SUPPLY				y mark<Subsystem>
++CONFIG_TCG_TPM					y mark<Subsystem>
++
++CONFIG_LEDS_CLASS				y note<core driver> mark<Subsystem>
++CONFIG_FW_LOADER				y note<core CPU firmware updater> mark<Subsystem>
++
++# HID drivers
++set +tree 'Device Drivers,HID support,HID'	= - mark<HID>
++#  enable modular HID drivers by default
++set +all ?mark 'HID' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'HID' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>`
++set +all ?mark 'HID' !flag EXPERIMENTAL ?type tristate = m
++#  standard forms
++set +pattern _FF$ ?mark HID ?type bool !flag EXPERIMENTAL = y
++#  the core subsystem
++CONFIG_HID					m mark<Subsystem> mark<HID>
++#  sub-sub-systems
++CONFIG_HIDRAW					y
++#  options:
++CONFIG_HID_BATTERY_STRENGTH			y
++CONFIG_HID_PICOLCD_BACKLIGHT			y
++CONFIG_HID_PICOLCD_CIR				y
++CONFIG_HID_PICOLCD_FB				y
++CONFIG_HID_PICOLCD_LCD				y
++CONFIG_HID_PICOLCD_LEDS				y
++CONFIG_HID_WIIMOTE_EXT				y
++
++# Networking
++set +tree 'Networking options'			= - mark<Networking>
++#  enable modular network options by default
++set +all ?mark 'Networking' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Networking' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>`
++set +all ?mark 'Networking' !flag EXPERIMENTAL ?type tristate = m
++#  enable all vendor menus by default
++set +pattern '^NET_VENDOR_' 			= y mark<Networking>
++#  the core subsystem
++CONFIG_NET					y mark<Subsystem>
++CONFIG_NETFILTER				y mark<Subsystem>
++CONFIG_NETLABEL					y mark<Subsystem>
++CONFIG_NET_SCHED				y mark<Subsystem>
++#  IPv6 packets trigger auto-loading of this module and it is easy to trigger
++#  a DOS unless this is builtin.  It is also a critical protocol going forward
++#  and will become boot essential.
++CONFIG_INET					y note<core protocol>
++CONFIG_IPV6					y note<core protocol>
++#  exceptions networking:
++CONFIG_INET_LRO					y note<core networking>
++CONFIG_MII					y note<core networking>
++CONFIG_TUN					y note<core networking>
++CONFIG_TCP_CONG_ADVANCED			y
++CONFIG_TCP_CONG_CUBIC				y note<core networking>
++#  exceptions network protocols:
++CONFIG_UNIX					y note<core protocol>
++CONFIG_PACKET					y note<core protocol>
++CONFIG_FDDI					y note<core protocol>
++CONFIG_PPP					y note<core protocol> mark<Networking>
++#  EXPERIMENTAL Network protocols are generally enabled to allow testing:
++CONFIG_ECONET					m note<network protocol -- opt-in>
++CONFIG_IEEE802154				m note<network protocol -- opt-in>
++CONFIG_LAPB					m note<network protocol -- opt-in>
++CONFIG_NET_DSA					m note<network protocol -- opt-in>
++CONFIG_RDS					m note<network protocol -- opt-in>
++CONFIG_TIPC					m note<network protocol -- opt-in>
++CONFIG_X25					m note<network protocol -- opt-in>
++#  interesting new subsystem
++CONFIG_NFC					m note<experimental subsystem -- opt-in> mark<Subsystem>
++CONFIG_NFC_NCI					m note<experimental protocol -- opt-in>
++#  This option allows bridging between non-IP and IP networks, but is
++#  effectivly deprecated.  We _may_ just _may_ have users on older arches
++#  so keep it there, but do not spread the pain to systems without these
++#  other networks.
++CONFIG_WAN_ROUTER				p policy<(arch i386 amd64 powerpc &/ value m) | value n>
++#  options:
++CONFIG_ARPD					n
++CONFIG_ATM_BR2684_IPFILTER			n
++CONFIG_ATM_CLIP_NO_ICMP				n 
++CONFIG_BATMAN_ADV_BLA				y
++CONFIG_BATMAN_ADV_DAT				y
++CONFIG_BPF_JIT					y note<REFER TO SECURITY>
++CONFIG_BRIDGE_EBT_ULOG				n flag<DEPRECATED>
++CONFIG_BRIDGE_IGMP_SNOOPING			y
++CONFIG_BRIDGE_NETFILTER				y
++CONFIG_CLS_U32_MARK				y
++CONFIG_CLS_U32_PERF				n
++CONFIG_DCB					y 
++CONFIG_DEFAULT_CUBIC				y
++CONFIG_GACT_PROB				y
++CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION	m note<enable IPv6 experimental features>
++CONFIG_IP_ADVANCED_ROUTER			y
++CONFIG_IPDDP_DECAP				y
++CONFIG_IPDDP_ENCAP				y
++CONFIG_IP_FIB_TRIE_STATS			y
++CONFIG_IP_MROUTE				y
++CONFIG_IP_MROUTE_MULTIPLE_TABLES		n
++CONFIG_IP_MULTICAST				y
++CONFIG_IP_MULTIPLE_TABLES			y
++CONFIG_IP_NF_QUEUE				n flag<DEPRECATED>
++CONFIG_IP_PIMSM_V1				y
++CONFIG_IP_PIMSM_V2				y
++#  IP PNP protocols
++CONFIG_IP_PNP					y
++CONFIG_IP_PNP_BOOTP				n
++CONFIG_IP_PNP_DHCP				y
++CONFIG_IP_PNP_RARP				n
++CONFIG_IP_ROUTE_MULTIPATH			y
++CONFIG_IP_ROUTE_VERBOSE				y
++CONFIG_IP_SET_MAX				256
++CONFIG_IPV6_MROUTE_MULTIPLE_TABLES		y
++CONFIG_IPV6_MROUTE				y
++CONFIG_IPV6_MULTIPLE_TABLES			y
++CONFIG_IPV6_PIMSM_V2				y
++CONFIG_IPV6_PRIVACY				y mark<Security>
++CONFIG_IPV6_ROUTER_PREF				y
++CONFIG_IPV6_ROUTE_INFO				y
++#  ipv6 rapid deployment support
++CONFIG_IPV6_SIT_6RD				y
++CONFIG_IPV6_SUBTREES				y
++#  ipv6 VS support is incomplete and "may be dangerous"
++CONFIG_IP_VS_IPV6				n flag<DANGEROUS>
++CONFIG_IP_VS_NFCT				y
++CONFIG_IP_VS_PROTO_AH				y
++CONFIG_IP_VS_PROTO_ESP				y
++CONFIG_IP_VS_PROTO_SCTP				y
++CONFIG_IP_VS_PROTO_TCP				y
++CONFIG_IP_VS_PROTO_UDP				y
++CONFIG_IP_VS_SH_TAB_BITS			8
++CONFIG_IP_VS_TAB_BITS				12
++CONFIG_IPX_INTERN				n
++#  mac802.15.4
++CONFIG_MAC802154				- note<REVIEW>
++CONFIG_NET_CLS_ACT				y
++CONFIG_NET_CLS_IND				n flag<DEPRECATED>
++#  drop packet netlink: only required for high performance networking
++CONFIG_NET_DROP_MONITOR				n
++CONFIG_NET_EMATCH				y
++CONFIG_NET_EMATCH_STACK				32
++CONFIG_NETFILTER_ADVANCED			y
++CONFIG_NETFILTER_NETLINK_QUEUE_CT		y
++CONFIG_NET_IPGRE_BROADCAST			y note<required by GRE>
++CONFIG_NETWORK_SECMARK				y
++#  various netfilter contract bits
++CONFIG_NF_CONNTRACK_EVENTS			y
++CONFIG_NF_CONNTRACK_MARK			y
++CONFIG_NF_CONNTRACK_PROCFS			n flag<DEPRECATED>
++CONFIG_NF_CONNTRACK_SECMARK			y
++CONFIG_NF_CONNTRACK_TIMEOUT			y
++CONFIG_NF_CONNTRACK_TIMESTAMP			y
++CONFIG_NF_CONNTRACK_ZONES			y
++#  SCTP default cookie protocol
++CONFIG_SCTP_HMAC_MD5				y
++CONFIG_SCTP_COOKIE_HMAC_MD5			y
++CONFIG_SCTP_COOKIE_HMAC_SHA1			y
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA1		y
++CONFIG_SYN_COOKIES				y mark<Security>
++CONFIG_TCP_MD5SIG				y mark<Security>
++CONFIG_TIPC_PORTS				8191
++CONFIG_VLAN_8021Q_GVRP				y
++CONFIG_COPS_DAYNA				y
++CONFIG_COPS_TANGENT				y
++
++# USB devices
++set +pattern '_USB'				= - mark<USB>
++#  enable modular network options by default
++set +all ?mark 'USB' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'USB' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>`
++set +all ?mark 'USB' !flag EXPERIMENTAL ?type tristate = m
++#  the core subsystem
++CONFIG_USB					y mark<Subsystem>
++#  sub-sub-systems
++CONFIG_MEDIA_USB_SUPPORT			y
++CONFIG_SND_USB					y
++#  exceptions:
++CONFIG_USB_EHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
++CONFIG_USB_OHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
++CONFIG_USB_UHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
++CONFIG_USB_XHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
++CONFIG_USB_OTG					n note<triggers breakage on x86>
++#  options:
++CONFIG_BRCMFMAC_USB				y
++CONFIG_COMEDI_USB_DRIVERS			y
++CONFIG_DVB_USB_DIBUSB_MB_FAULTY			n
++CONFIG_LINE6_USB_DUMP_CTRL			n
++CONFIG_LINE6_USB_DUMP_MIDI			n
++CONFIG_LINE6_USB_DUMP_PCM			n
++CONFIG_LINE6_USB_IMPULSE_RESPONSE		n
++CONFIG_LINE6_USB_RAW				n flag<DANGEROUS>
++CONFIG_SND_USB_CAIAQ_INPUT			y
++CONFIG_WIMAX_GDM72XX_USB_PM			y
++CONFIG_WIMAX_GDM72XX_USB			y
++CONFIG_MFD_OMAP_USB_HOST			y
++CONFIG_TWL4030_USB				y
++CONFIG_XPS_USB_HCD_XILINX			y
++
++# Disk Drivers
++set +tree 'Device Drivers,ATA'			= - mark<Disk Drivers>
++set +tree 'Device Drivers,IDE'			= - mark<Disk Drivers>
++set +tree 'Device Drivers,SCSI device support'	= - mark<Disk Drivers>
++#  enable modular options by default
++set +all ?mark 'Disk Drivers' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Disk Drivers' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'Disk Drivers' !mark EXPERIMENTAL ?type tristate = m
++#  the core subsystem
++CONFIG_SCSI					y mark<Subsystem>
++CONFIG_ATA					y mark<Subsystem>
++#  sections
++CONFIG_SCSI_LOWLEVEL				y
++CONFIG_SCSI_LOWLEVEL_PCMCIA			y
++#  general options
++CONFIG_ATA_VERBOSE_ERROR			y
++CONFIG_SCSI_CONSTANTS				y
++CONFIG_SCSI_LOGGING				y
++CONFIG_SCSI_MULTI_LUN				y
++CONFIG_SCSI_PROC_FS				y
++CONFIG_SCSI_SCAN_ASYNC				y
++#  generic drivers
++CONFIG_SATA_PMP					y
++CONFIG_ATA_ACPI					y
++CONFIG_ATA_SFF					y
++CONFIG_ATA_BMDMA				y
++CONFIG_SCSI_EATA_LINKED_COMMANDS		y
++CONFIG_SCSI_EATA_MAX_TAGS			16
++CONFIG_SCSI_EATA_TAGGED_QUEUE			y
++#  ATA controllers: some are boot essential on specific architectures
++CONFIG_ATA_GENERIC				p policy<(arch i386 amd64 &/ value y) | value m> note<boot essential on i386/amd64>
++CONFIG_ATA_PIIX					p policy<(arch i386 amd64 &/ value y) | value m> note<boot essential on i386/amd64>
++CONFIG_PATA_ACPI				p policy<(arch i386 amd64 &/ value m)> note<Attachs to _any_ storage class PCI ID, therefore cannot be built in>
++CONFIG_PATA_SIS					p policy<(arch i386 amd64 &/ value y) | value m> note<boot essential on i386/amd64>
++CONFIG_SATA_SVW					p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++#  options:
++CONFIG_AIC79XX_CMDS_PER_DEVICE			32
++CONFIG_AIC79XX_DEBUG_MASK			0
++CONFIG_AIC79XX_REG_PRETTY_PRINT			y
++CONFIG_AIC79XX_RESET_DELAY_MS			5000
++CONFIG_AIC7XXX_CMDS_PER_DEVICE			8
++CONFIG_AIC7XXX_DEBUG_MASK			0
++CONFIG_AIC7XXX_REG_PRETTY_PRINT			y
++CONFIG_AIC7XXX_RESET_DELAY_MS			15000
++CONFIG_MEGARAID_NEWGEN				y
++CONFIG_SCSI_FC_TGT_ATTRS			y
++CONFIG_SCSI_IPR_DUMP				n
++CONFIG_SCSI_IPR_TRACE				n
++CONFIG_SCSI_IZIP_EPP16				n
++CONFIG_SCSI_IZIP_SLOW_CTR			n
++CONFIG_SCSI_MPT2SAS_LOGGING			n
++CONFIG_SCSI_MPT2SAS_MAX_SGE			128
++CONFIG_SCSI_MPT3SAS_LOGGING			n
++CONFIG_SCSI_MPT3SAS_MAX_SGE			128
++CONFIG_SCSI_MVSAS_TASKLET			n
++CONFIG_SCSI_OSD_DPRINT_SENSE			1
++CONFIG_SCSI_SAS_ATA				y
++CONFIG_SCSI_SAS_HOST_SMP			y
++CONFIG_SCSI_SRP_TGT_ATTRS			y
++CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS		16
++CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE	1
++CONFIG_SCSI_SYM53C8XX_MAX_TAGS			64
++CONFIG_SCSI_SYM53C8XX_MMIO			y
++CONFIG_SCSI_FLASHPOINT				y
++CONFIG_SCSI_GENERIC_NCR53C400			y
++CONFIG_SCSI_U14_34F_LINKED_COMMANDS		y
++CONFIG_SCSI_U14_34F_MAX_TAGS			8
++CONFIG_SCSI_U14_34F_TAGGED_QUEUE		y
++
++# Crypto drivers.
++set +tree 'CRYPTO'				= - mark<Crypto>
++#  enable modular options by default
++set +all ?mark 'Crypto' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Crypto' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'Crypto' !mark EXPERIMENTAL ?type tristate = m
++#  the core subsystem
++CONFIG_CRYPTO					y mark<Subsystem>
++#  exceptions
++CONFIG_CRYPTO_CRC32C				y note<dependancy of boot essential>
++CONFIG_CRYPTO_CRC32C_INTEL			y note<dependancy of boot essential>
++CONFIG_CRYPTO_DEV_PADLOCK			y note<dependancy of boot essential>
++CONFIG_CRYPTO_CRC32C				y note<dependancy of boot essential>
++CONFIG_CRYPTO_AES				y note<dependancy of boot essential>
++CONFIG_CRYPTO_CBC				y note<dependancy of boot essential>
++CONFIG_CRYPTO_ECB				y note<dependancy of boot essential>
++CONFIG_CRYPTO_HMAC				y note<dependancy of boot essential>
++CONFIG_CRYPTO_MANAGER				y note<dependancy of boot essential>
++CONFIG_CRYPTO_MD5				y note<dependancy of boot essential>
++CONFIG_CRYPTO_SHA1				y note<dependancy of boot essential>
++CONFIG_CRYPTO_SHA256				y note<dependancy of boot essential>
++CONFIG_CRYPTO_LZO				y note<dependancy of boot essential>
++CONFIG_CRC16					y note<dependancy of boot essential>
++CONFIG_CRC32					y note<dependancy of boot essential>
++CONFIG_ENCRYPTED_KEYS				y note<dependancy of boot essential>
++CONFIG_TRUSTED_KEYS				y note<dependancy of boot essential>
++#  needed for module signing
++CONFIG_ASYMMETRIC_KEY_TYPE			y
++CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE		y
++CONFIG_CRYPTO_SHA512				y
++CONFIG_PUBLIC_KEY_ALGO_RSA			y
++CONFIG_X509_CERTIFICATE_PARSER			y
++#  options:
++CONFIG_CRYPTO_HW				y
++CONFIG_CRYPTO_MANAGER_DISABLE_TESTS		y flag<TESTING>
++CONFIG_CRYPTO_TEST				m flag<TESTING>
++CONFIG_CRYPTO_DEV_NX				y
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC			y
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_COUNT_THLD	255
++CONFIG_CRYPTO_DEV_FSL_CAAM_INTC_TIME_THLD	2048
++CONFIG_CRYPTO_DEV_FSL_CAAM_RINGSIZE		9
++CONFIG_CRYPTO_DEV_HIFN_795X_RNG			y
++
++# PHY support
++set +tree 'Device Drivers,NETDEVICES,PHYLIB'	= - mark<PHYS>
++#  PHY devices with non-standard naming.
++CONFIG_B43_PHY_HT				- mark<PHYS>
++CONFIG_B43_PHY_N				- mark<PHYS>
++CONFIG_STE10XP					- mark<PHYS>
++#  enable modular network options by default
++set +all ?mark 'PHYS' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'PHYS' ?flag EXPERIMENTAL ?type tristate = y note<experimental opt-in>`
++set +all ?mark 'PHYS' !flag EXPERIMENTAL ?type tristate = y note<not autoloadable>
++#  the core subsystem
++CONFIG_PHYLIB					y mark<Subsystem> mark<PHYS>
++CONFIG_FIXED_PHY				y
++#  options:
++CONFIG_B43_PHY_HT				y
++CONFIG_B43_PHY_N				y
++
++# INPUT
++set +tree 'Device Drivers,Input device support,INPUT' = - mark<INPUT>
++set +all ?mark 'INPUT' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'INPUT' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>`
++set +all ?mark 'INPUT' !flag EXPERIMENTAL ?type tristate = m
++CONFIG_INPUT y mark<Subsystem> mark<INPUT>
++#  sub-sub-systems
++CONFIG_INPUT_JOYSTICK				y
++CONFIG_INPUT_KEYBOARD				y
++CONFIG_INPUT_MISC				y
++CONFIG_INPUT_MOUSE				y
++CONFIG_INPUT_TOUCHSCREEN			y
++CONFIG_INPUT_TABLET				y
++CONFIG_INPUT_EVDEV				y
++CONFIG_INPUT_MOUSEDEV				y
++CONFIG_INPUT_UINPUT				y
++#  standard forms
++set +pattern ^MOUSE_PS2_ ?mark INPUT ?type bool !flag EXPERIMENTAL = y
++set +pattern ^TOUCHSCREEN_ ?mark INPUT ?type bool !flag EXPERIMENTAL = y
++set +pattern _FF$ ?mark INPUT ?type bool !flag EXPERIMENTAL = y
++#  INPUT_KXTJ9_POLLED_MODE -- polling is bad generally
++CONFIG_INPUT_KXTJ9_POLLED_MODE			n
++#  options:
++CONFIG_INPUT_MOUSEDEV_PSAUX			y
++CONFIG_INPUT_MOUSEDEV_SCREEN_X			1024
++CONFIG_INPUT_MOUSEDEV_SCREEN_Y			768
++CONFIG_JOYSTICK_IFORCE_232			y
++CONFIG_JOYSTICK_IFORCE_USB			y
++CONFIG_JOYSTICK_XPAD_LEDS			y
++
++# SECURITY
++set +tree 'Security options'			= - mark<Security>
++set +tree 'MODULES,MODULE_SIG'			= - mark<Security>
++CONFIG_SECURITY					y mark<Subsystem>
++CONFIG_SECURITYFS				y
++CONFIG_DEFAULT_SECURITY_APPARMOR		y
++CONFIG_SECURITY_APPARMOR			y
++CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE	1
++CONFIG_SECURITY_SELINUX				y
++CONFIG_SECURITY_SELINUX_AVC_STATS		y
++CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE		0
++CONFIG_SECURITY_SELINUX_BOOTPARAM		y
++CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE	1
++CONFIG_SECURITY_SELINUX_DEVELOP			y
++CONFIG_SECURITY_SELINUX_DISABLE			y	note<REFER TO SECURITY>
++CONFIG_SECURITY_SELINUX_POLICYDB_VERSION_MAX	n
++CONFIG_SECURITY_TOMOYO				y
++CONFIG_SECURITY_TOMOYO_STACKED			y
++CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER	"/sbin/init"
++CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY		2048
++CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG		1024
++CONFIG_SECURITY_TOMOYO_OMIT_USERSPACE_LOADER	n
++CONFIG_SECURITY_TOMOYO_POLICY_LOADER		"/sbin/tomoyo-init"
++CONFIG_SECURITY_SMACK				y
++CONFIG_SECURITY_YAMA				y
++CONFIG_SECURITY_YAMA_STACKED			y
++CONFIG_EVM					y
++CONFIG_IMA					n note<known to cause performance issues>
++CONFIG_INTEL_TXT				p policy<(arch i386 amd64 &/ value y) | value n)>
++CONFIG_INTEGRITY_SIGNATURE			y
++CONFIG_KEYS					y
++CONFIG_LSM_MMAP_MIN_ADDR			0
++CONFIG_SECURITY_DMESG_RESTRICT			n
++CONFIG_SECURITY_NETWORK				y
++CONFIG_SECURITY_NETWORK_XFRM			n
++CONFIG_SECURITY_PATH				y
++# Module signing.
++CONFIG_MODULE_SIG				y mark<Subsystem>
++CONFIG_MODULE_SIG_FORCE				n
++CONFIG_MODULE_SIG_SHA512			y
++# Other security related options.
++CONFIG_CC_STACKPROTECTOR			y mark<Security>
++
++# SENSORS
++set +pattern '^SENSORS_'			= - mark<Sensors>
++set +all ?mark 'Sensors' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Sensors' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'Sensors' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_HWMON					y mark<Subsystem> mark<Sensors>
++#  exceptions:
++CONFIG_SENSORS_SCH56XX_COMMON			- flag<IGNORE>
++CONFIG_SENSORS_AMS_I2C				y
++CONFIG_SENSORS_AMS_PMU				y
++
++# BLK/CHR DEV
++set +tree 'Device Drivers,BLK_DEV' ?pattern (BLK|CHR)_DEV_ = - mark<BLK-CHR>
++set +tree 'Device Drivers,SCSI device support' ?pattern (BLK|CHR)_DEV_ = - mark<BLK-CHR>
++set +all ?mark 'BLK-CHR' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'BLK-CHR' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'BLK-CHR' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_BLK_DEV					y mark<Subsystem> mark<BLK-CHR>
++#  exceptions:
++CONFIG_BLK_DEV_LOOP				y note<dependancy of boot essential>
++CONFIG_BLK_DEV_RAM				y note<dependancy of boot essential>
++CONFIG_BLK_DEV_SD				y note<dependancy of boot essential>
++CONFIG_BLK_DEV_SR				y note<dependancy of boot essential>
++CONFIG_BLK_DEV_HD				n note<very old disk device support>
++CONFIG_BLK_DEV_SR_VENDOR			n note<very old tape device support>
++CONFIG_CHR_DEV_SG				y note<not autoloadable>
++#  options:
++CONFIG_BLK_DEV_LOOP_MIN_COUNT			8
++CONFIG_BLK_DEV_RAM_COUNT			16
++CONFIG_BLK_DEV_RAM_SIZE				65536
++
++# MD
++set +tree 'Device Drivers,MD'			= - mark<MD>
++set +all ?mark 'MD' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'MD' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'MD' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_MD					y mark<Subsystem> mark<MD>
++CONFIG_BLK_DEV_DM				y
++CONFIG_BLK_DEV_MD				y
++#  options:
++CONFIG_DM_UEVENT				y
++CONFIG_MD_AUTODETECT				y
++
++# Misc Devices -- A2D converters
++set +tree 'Device Drivers,Analog to digital converters' = - mark<A2D> mark<Misc Devices>
++set +tree 'Device Drivers,IIO staging drivers,Analog to digital converters' = - mark<A2D> mark<Misc Devices>
++set +all ?mark 'A2D' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'A2D' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'A2D' !mark EXPERIMENTAL ?type tristate = m
++#  options:
++CONFIG_AD799X_RING_BUFFER			y
++CONFIG_LP8788_ADC				y
++
++# Misc Devices -- D2A converters
++set +tree 'Device Drivers,Digital to analog converters' = - mark<D2A> mark<Misc Devices>
++set +all ?mark 'D2A' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'D2A' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'D2A' !mark EXPERIMENTAL ?type tristate = m
++
++# EXTCON
++set +tree 'Device Drivers,EXTCON'		= - mark<EXTCON> mark<Misc Devices>
++set +all ?mark 'EXTCON' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'EXTCON' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'EXTCON' !mark EXPERIMENTAL ?type tristate = m
++# subsystem
++CONFIG_EXTCON					y mark<Subsystem>
++
++# UBUNTU
++set +tree 'Ubuntu Supplied Third-Party Device Drivers' = - mark<UBUNTU>
++set +pattern OVERLAYFS_FS			= - mark<UBUNTU>
++set +all ?mark 'UBUNTU' ?type tristate		= m
++#  exceptions:
++CONFIG_AUFS_BRANCH_MAX_127			y
++CONFIG_AUFS_BR_FUSE				y
++CONFIG_AUFS_BR_HFSPLUS				y
++CONFIG_AUFS_BR_RAMFS				y
++CONFIG_AUFS_EXPORT				n
++CONFIG_AUFS_HNOTIFY				n
++CONFIG_AUFS_PROC_MAP				n note<causes build failures> flag<BUILD FAILURE>
++CONFIG_AUFS_RDU					n	
++CONFIG_AUFS_SHWH				n
++CONFIG_AUFS_SP_IATTR				n	
++#  DM_RAID45 only appears in PC BIOS based systems
++CONFIG_DM_RAID45				p policy<(arch i386 amd64 &/ value m) | value n> note<PC BIOS specific> mark<MD>
++
++# Ubuntu Critical
++CONFIG_INIT_PASS_ALL_PARAMS			y mark<CRITICAL> note<upstart>
++CONFIG_ZRAM					y mark<CRITICAL> note<small memory support in installer>
++CONFIG_ZCACHE					y mark<CRITICAL> note<small memory support in installer>
++
++# RTC
++set +tree 'Device Drivers,RTC_CLASS'		= - mark<RTC>
++set +all ?mark 'RTC' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'RTC' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'RTC' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_RTC_CLASS				y mark<RTC> mark<Subsystem>
++#  options:
++CONFIG_RTC_DRV_TWL4030				p policy<(flavour omap omap4 &/ value y) | value m> note<boot essential on OMAP3/OMAP4>
++CONFIG_RTC_DRV_CMOS				p policy<(arch i386 amd64 &/ value y) | value m> note<boot essential on i386/amd64>
++CONFIG_RTC_DRV_M41T80_WDT			y
++#  read the rtc at boot and set the system clock
++CONFIG_RTC_HCTOSYS				y
++CONFIG_RTC_HCTOSYS_DEVICE			"rtc0"
++CONFIG_RTC_INTF_DEV_UIE_EMUL			n
++#  filesystem interfaces for the rtc
++CONFIG_RTC_INTF_DEV				y
++CONFIG_RTC_INTF_PROC				y
++CONFIG_RTC_INTF_SYSFS				y
++
++# GPIO
++set +tree 'Device Drivers,GPIOLIB'		= - mark<GPIO>
++set +all ?mark 'GPIO' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'GPIO' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'GPIO' !mark EXPERIMENTAL ?type tristate = m
++#  standard forms:
++set +pattern ^GPIO_ ?mark GPIO ?type bool !flag EXPERIMENTAL = y
++#  options:
++CONFIG_GPIO_TWL4030				p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++#  Geode
++CONFIG_GPIO_CS5535				p policy<(value CONFIG_OLPC_X01_SCI y &/ value y) | value m> note<dependancy OLPC_X01_SCI=y>
++CONFIG_GPIO_GE_FPGA				n
++
++# I2C
++set +tree 'Device Drivers,I2C Hardware Bus support'	= - mark<I2C>
++set +all ?mark 'I2C' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'I2C' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'I2C' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_I2C					y mark<Subsystem> mark<I2C>
++#  sub-sub-systems 
++CONFIG_I2C_COMPAT				y
++CONFIG_I2C_HELPER_AUTO				y
++#  options:
++CONFIG_I2C_OMAP					p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_I2C_DESIGNWARE_PLATFORM			p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_I2C_POWERMAC				p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_I2C_ALGOBIT				p policy<(arch powerpc &/ value y) | value m>  note<boot essential dependancy on powerpc>
++
++# Graphics related
++set +tree 'Device Drivers,Graphics support'	= - mark<Graphics>
++set +all ?mark 'Graphics' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'Graphics' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>
++set +all ?mark 'Graphics' !flag EXPERIMENTAL ?type tristate = m
++set +pattern ^FB_[^_]+$ ?mark Graphics ?type bool !flag EXPERIMENTAL = y
++set +pattern ^FB_[^_]+$ ?mark Graphics ?type bool ?flag EXPERIMENTAL = y note<experimental opt-in>
++set +pattern _(KMS|BACKLIGHT|I2C)$ ?mark Graphics ?type bool !flag EXPERIMENTAL = y
++CONFIG_FB					y mark<Subsystem>
++CONFIG_DRM					p mark<Subsystem> policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++#  sub-sub-systems
++CONFIG_BACKLIGHT_LCD_SUPPORT			y
++CONFIG_BACKLIGHT_CLASS_DEVICE			y
++CONFIG_DRM_LOAD_EDID_FIRMWARE			y
++CONFIG_FB_MODE_HELPERS				y
++CONFIG_FIRMWARE_EDID				y
++CONFIG_VGA_ARB					y
++CONFIG_VGA_ARB_MAX_GPUS				16
++CONFIG_LOGO					n
++CONFIG_VGA_CONSOLE				y
++CONFIG_VGA_SWITCHEROO				y
++CONFIG_FB_TILEBLITTING				y
++CONFIG_FONTS					p policy<(flavour omap &/ value y) | value n>
++CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY	y
++CONFIG_FRAMEBUFFER_CONSOLE_ROTATION		n
++CONFIG_VGACON_SOFT_SCROLLBACK			n
++#  options:
++CONFIG_AGP					y note<not autoloadable> mark<Subsystem>
++CONFIG_AGP_AMD64				y note<not autoloadable>
++CONFIG_AGP_INTEL				y note<not autoloadable>
++CONFIG_AGP_VIA					y note<not autoloadable>
++CONFIG_AGP_AMD					y note<not autoloadable>
++CONFIG_AGP_NVIDIA				y note<not autoloadable>
++CONFIG_FB_CARMINE_DRAM_EVAL			y
++CONFIG_DRM_EXYNOS				n flag<BUILD FAILURE>
++#CONFIG_DRM_EXYNOS_FIMC				y
++#CONFIG_DRM_EXYNOS_IPP				y
++#CONFIG_DRM_EXYNOS_ROTATOR			y
++CONFIG_DRM_VMWGFX_FBCON				n
++CONFIG_FB_CYBER2000_DDC				y
++CONFIG_FB_FOREIGN_ENDIAN			n
++#  Pulsbough etc
++CONFIG_DRM_GMA600				y
++CONFIG_DRM_GMA3600				y
++#  nouveau
++CONFIG_NOUVEAU_DEBUG				5
++CONFIG_NOUVEAU_DEBUG_DEFAULT			3
++#  exynos
++CONFIG_EXYNOS_VIDEO				y
++CONFIG_DRM_EXYNOS_DMABUF			y
++CONFIG_DRM_EXYNOS_FIMD				y
++CONFIG_DRM_EXYNOS_G2D				y
++CONFIG_DRM_EXYNOS_HDMI				n
++CONFIG_DRM_EXYNOS_VIDI				y
++#  aty
++CONFIG_FB_ATY_CT				y
++CONFIG_FB_ATY_GX				y
++#  matrox
++CONFIG_FB_MATROX_G				y
++CONFIG_FB_MATROX_MILLENIUM			y
++CONFIG_FB_MATROX_MYSTIQUE			y
++#  MB762XX
++CONFIG_FB_MB862XX_PCI_GDC			y
++#  PM2
++CONFIG_FB_PM2_FIFO_DISCONNECT			y
++#  S3
++CONFIG_FB_S3_DDC				y
++#  SIS
++CONFIG_FB_SIS_300				y
++CONFIG_FB_SIS_315				y
++#  TMIO
++CONFIG_FB_TMIO_ACCELL				y
++#  via
++CONFIG_FB_VIA_X_COMPATIBILITY			y
++#  omap2
++CONFIG_FB_OMAP2_NUM_FBS				3
++CONFIG_OMAP2_DSS_COLLECT_IRQ_STATS		n
++CONFIG_OMAP2_DSS_DEBUGFS			n
++CONFIG_OMAP2_DSS_DPI				y
++CONFIG_OMAP2_DSS_DSI				n
++CONFIG_OMAP4_DSS_HDMI				y
++CONFIG_OMAP2_DSS_MIN_FCK_PER_PCK		0
++CONFIG_OMAP2_DSS_RFBI				n
++CONFIG_OMAP2_DSS_SDI				y
++CONFIG_OMAP2_DSS_SLEEP_AFTER_VENC_RESET		y
++CONFIG_OMAP2_DSS_VENC				y
++CONFIG_OMAP2_VRAM_SIZE				16
++#  omap2 -- FONTS
++CONFIG_FONT_10x18				n
++CONFIG_FONT_6x11				n
++CONFIG_FONT_7x14				n
++CONFIG_FONT_8x8					y
++CONFIG_FONT_8x16				y
++CONFIG_FONT_ACORN_8x8				y
++CONFIG_FONT_MINI_4x6				n
++CONFIG_FONT_PEARL_8x8				n
++CONFIG_FONT_SUN12x22				n
++CONFIG_FONT_SUN8x16				n
++#  ps3
++CONFIG_FB_PS3_DEFAULT_SIZE_M			9
++
++# CPU Frequency Scaling
++set +tree 'Power management and ACPI options,CPU Frequency scaling' = - mark<CPUFREQ>
++set +tree 'Device Drivers,PM_DEVFREQ'		= - mark<CPUFREQ>
++set +all ?mark 'CPUFREQ' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_CPU_FREQ					y mark<Subsystem>
++#  cpu governers:
++CONFIG_CPU_FREQ_GOV_CONSERVATIVE		y note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_ONDEMAND			y note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_PERFORMANCE			y note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_POWERSAVE			y note<not autoloadable>
++CONFIG_CPU_FREQ_GOV_USERSPACE			y note<not autoloadable>
++CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE		y note<for bootspeed>
++#  cpufreq drivers
++CONFIG_X86_ACPI_CPUFREQ				y note<not autoloadable>
++CONFIG_X86_ACPI_CPUFREQ_CPB			y
++CONFIG_X86_POWERNOW_K8				y note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_CENTRINO			y note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_ICH			y note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_SMI			y note<not autoloadable>
++CONFIG_X86_PCC_CPUFREQ				y note<not autoloadable>
++CONFIG_X86_CPUFREQ_NFORCE2			y note<not autoloadable>
++CONFIG_X86_SPEEDSTEP_CENTRINO_TABLE		y
++CONFIG_X86_SPEEDSTEP_RELAXED_CAP_CHECK		y
++CONFIG_ARM_OMAP2PLUS_CPUFREQ			y
++CONFIG_GENERIC_CPUFREQ_CPU0			y
++CONFIG_CPU_FREQ_MAPLE				y
++#  cpufreq monitoring
++CONFIG_CPU_FREQ_STAT				p policy<(arch i386 amd64 armel armhf &/ value y) | value m> note<dependancy of boot essential>
++CONFIG_CPU_FREQ_STAT_DETAILS			y
++#  devfreq
++CONFIG_DEVFREQ_GOV_PERFORMANCE			y
++CONFIG_DEVFREQ_GOV_POWERSAVE			y
++CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND		y
++CONFIG_DEVFREQ_GOV_USERSPACE			y
++
++# Thermal drivers
++set +tree 'Device Drivers,THERMAL' = - mark<THERMAL>
++set +all ?mark 'THERMAL' !mark EXPERIMENTAL ?type tristate = m
++CONFIG_THERMAL					y mark<Subsystem>
++#  options:
++CONFIG_CPU_THERMAL				y
++#  governers;
++CONFIG_FAIR_SHARE				y
++CONFIG_STEP_WISE				y
++CONFIG_USER_SPACE				y
++CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE		y
++
++# Virtualisation
++set +pattern '^XEN_'				= - mark<VIRT>
++set +pattern '^KVM_'				= - mark<VIRT>
++set +pattern '^VIRTIO_'				= - mark<VIRT>
++set +pattern 'CGROUP'				= - mark<VIRT>
++set +all ?mark 'VIRT' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'VIRT' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'VIRT' !flag EXPERIMENTAL ?type tristate = m
++#  standard forms:
++set +pattern CGROUP_[^_]+$ ?mark VIRT ?type bool !flag DEBUG !flag EXPERIMENTAL	= y
++#  sub-sub-systems
++CONFIG_CGROUPS					y
++CONFIG_KVM_GUEST				y
++# XEN
++CONFIG_XEN_BLKDEV_FRONTEND			y note<not autoloadable -- XEN paravirt support>
++CONFIG_XEN_NETDEV_FRONTEND			y note<not autoloadable -- XEN paravirt support>
++CONFIG_XEN_BACKEND				y
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG		y
++CONFIG_XEN_BALLOON				y
++CONFIG_XEN_COMPAT_XENFS				y
++CONFIG_XEN_MCE_LOG				y
++CONFIG_XEN_SCRUB_PAGES				y
++CONFIG_XEN_SELFBALLOONING			y
++CONFIG_XEN_SYS_HYPERVISOR			y
++# KVM
++CONFIG_KVM					p policy<(arch powerpc &/ value y) | value m>
++CONFIG_KVM_MMU_AUDIT				n
++CONFIG_KVM_E500V2				y
++CONFIG_KVM_E500MC				y
++# VIRTIO
++CONFIG_VIRTIO_BLK				p policy<(arch i386 amd64 &/ value y) | (arch armel armhf &/ value n) | value m> note<KVM paravirt support -- not autoloadable>
++CONFIG_VIRTIO_NET				p policy<(arch i386 amd64 &/ value y) | (arch armel armhf &/ value n) | value m> note<KVM paravirt support -- not autoloadable>
++CONFIG_VIRTIO_PCI				p policy<(arch i386 amd64 &/ value y) | (arch armel armhf &/ value n) | value m> note<KVM paravirt support -- not autoloadable>
++CONFIG_VIRTIO_MMIO				p policy<(arch armel armhf &/ value n) | value m> note<KVM paravirt support>
++CONFIG_VIRTIO_BALLOON				p policy<(arch armel armhf &/ value n) | value m> note<KVM paravirt support>
++CONFIG_SCSI_VIRTIO				m note<tech preview of new feature>
++CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES		y
++# CGROUPS
++CONFIG_CGROUP_HUGETLB				y
++#  options:
++CONFIG_LGUEST					n
++
++# MEDIA Support
++set +tree 'Device Drivers,MEDIA_SUPPORT'	= - mark<MEDIA>
++set +all ?mark 'MEDIA' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'MEDIA' ?flag EXPERIMENTAL ?type tristate = m note<experimental opt-in>
++set +all ?mark 'MEDIA' !flag EXPERIMENTAL ?type tristate = m
++#  subsystem
++CONFIG_MEDIA_SUPPORT				y mark<Subsystem>
++#  sub-sub-systems
++CONFIG_MEDIA_ANALOG_TV_SUPPORT			y
++CONFIG_MEDIA_CAMERA_SUPPORT			y
++CONFIG_MEDIA_DIGITAL_TV_SUPPORT			y
++CONFIG_MEDIA_PARPORT_SUPPORT			y
++CONFIG_MEDIA_PCI_SUPPORT			y
++CONFIG_MEDIA_RADIO_SUPPORT			y
++CONFIG_MEDIA_RC_SUPPORT				y
++CONFIG_RADIO_ADAPTERS				y
++CONFIG_RC_DECODERS				y
++CONFIG_RC_DEVICES				y
++CONFIG_V4L_MEM2MEM_DRIVERS			y
++CONFIG_V4L_PLATFORM_DRIVERS			y
++CONFIG_V4L_TEST_DRIVERS				y
++CONFIG_V4L_RADIO_ISA_DRIVERS			y
++#  DVB
++CONFIG_DVB_DYNAMIC_MINORS			y
++CONFIG_DVB_NET					y
++CONFIG_DVB_MAX_ADAPTERS				8
++CONFIG_DVB_AV7110_OSD				y
++#  MEDIA
++CONFIG_MEDIA_ATTACH				y
++CONFIG_MEDIA_SUBDRV_AUTOSELECT			y
++#  RADIO
++CONFIG_RADIO_SI470X				y
++#  SMS
++CONFIG_SMS_SIANO_RC				y
++#  USB
++CONFIG_USB_PWC_INPUT_EVDEV			y
++CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV		y
++#  VIDEO
++CONFIG_VIDEO_FIXED_MINOR_RANGES			n
++CONFIG_VIDEO_CX231XX_RC				y
++CONFIG_VIDEO_PVRUSB2_DVB			y
++CONFIG_VIDEO_PVRUSB2_SYSFS			y
++CONFIG_VIDEO_SAA7134_RC				y
++CONFIG_VIDEO_STK1160_AC97			y
++#  misc
++CONFIG_IR_RX51					n flag<BUILD FAILURE on armhf>
++
++# Staging Drivers
++set +tree 'Device Drivers,STAGING'		= - mark<STAGING>
++set +all ?mark 'STAGING' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'STAGING' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'STAGING' !flag EXPERIMENTAL ?type tristate = m
++#  staging sections:
++CONFIG_LIRC_STAGING				y
++CONFIG_STAGING_MEDIA				y
++#  comedi:
++CONFIG_COMEDI_DEFAULT_BUF_MAXSIZE_KB		20480
++CONFIG_COMEDI_DEFAULT_BUF_SIZE_KB		2048
++CONFIG_COMEDI_MISC_DRIVERS			y
++CONFIG_COMEDI_PCI_DRIVERS			y
++CONFIG_COMEDI_PCMCIA_DRIVERS			y
++CONFIG_COMEDI_ISA_DRIVERS			y
++#  lirc:
++CONFIG_LIRC_SERIAL_TRANSMITTER			y
++#  options:
++CONFIG_DT3155_CCIR				n note<US centric>
++CONFIG_DT3155_STREAMING				y
++CONFIG_PANEL_CHANGE_MESSAGE			n
++CONFIG_PANEL_PARPORT				0
++CONFIG_PANEL_PROFILE				5
++CONFIG_SBE_PMCC4_NCOMM				y
++CONFIG_WIMAX_GDM72XX_K_MODE			y
++CONFIG_WIMAX_GDM72XX_QOS			y
++CONFIG_WIMAX_GDM72XX_WIMAX2			y
++CONFIG_DRM_OMAP					n
++CONFIG_OMAP_BANDGAP				n
++CONFIG_TIDSPBRIDGE				n mark<BUILD FAILURE>
++#CONFIG_TIDSPBRIDGE_BACKTRACE			n mark<DEBUG>
++#CONFIG_TIDSPBRIDGE_CACHE_LINE_CHECK		n
++#CONFIG_TIDSPBRIDGE_NTFY_PWRERR			n
++#CONFIG_TIDSPBRIDGE_RECOVERY			y
++
++# Character Devices
++set +tree 'Device Drivers,Character devices'	= - mark<CHARACTER>
++set +all ?mark 'CHARACTER' ?flag EXPERIMENTAL ?type bool = n
++set +all ?mark 'CHARACTER' ?flag EXPERIMENTAL ?type tristate = n
++set +all ?mark 'CHARACTER' !flag EXPERIMENTAL ?type tristate = m
++#  sub-sub-sections
++CONFIG_SERIAL_NONSTANDARD			y
++#  kmem
++CONFIG_DEVKMEM					n mark<Security>
++#  console
++CONFIG_TTY_PRINTK				y
++#  VTs
++CONFIG_VT					y
++CONFIG_VT_CONSOLE				y
++CONFIG_VT_HW_CONSOLE_BINDING			y
++CONFIG_CONSOLE_TRANSLATIONS			y
++#  ptys -- allow legacy ptys but allocate 0 at boot.
++CONFIG_DEVPTS_MULTIPLE_INSTANCES		y
++CONFIG_LEGACY_PTYS				y
++CONFIG_LEGACY_PTY_COUNT				0
++CONFIG_UNIX98_PTYS				y
++#  hpet
++CONFIG_HPET					y
++CONFIG_HPET_MMAP				y
++#  hardware random
++CONFIG_HW_RANDOM				y
++#  HVC
++CONFIG_HVC_XEN					y
++CONFIG_HVC_XEN_FRONTEND				y
++CONFIG_HVC_DCC					y
++CONFIG_HVC_CONSOLE				n
++CONFIG_HVC_OPAL					y
++CONFIG_HVC_RTAS					y
++CONFIG_HVC_UDBG					y
++#  serial 8250
++CONFIG_SERIAL_8250_CONSOLE			y
++CONFIG_SERIAL_8250_DETECT_IRQ			n
++CONFIG_SERIAL_8250_EXTENDED			y
++CONFIG_SERIAL_8250_MANY_PORTS			y
++CONFIG_SERIAL_8250_NR_UARTS			48
++CONFIG_SERIAL_8250_RSA				y
++CONFIG_SERIAL_8250_RUNTIME_UARTS		32
++CONFIG_SERIAL_8250_SHARE_IRQ			y
++CONFIG_SERIAL_8250_EM				n
++CONFIG_SERIAL_8250 				y note<boot essential -- serial consoles>
++CONFIG_SERIAL_8250_PCI				p policy<(arch i386 amd64 armel armhf &/ value y) | value m> note<boot essential -- serial consoles>
++CONFIG_SERIAL_8250_PNP				p policy<(arch i386 amd64 armel armhf &/ value y) | value m> note<boot essential -- serial consoles>
++#  serial altera
++CONFIG_SERIAL_ALTERA_UART_BAUDRATE		115200
++CONFIG_SERIAL_ALTERA_UART_MAXPORTS		4
++#  serial amba
++CONFIG_SERIAL_AMBA_PL011			p policy<(flavour highbank &/ value y) | value m>
++CONFIG_SERIAL_AMBA_PL011_CONSOLE		y
++#  serial arc
++CONFIG_SERIAL_ARC_NR_PORTS			1
++#  serial scnxp
++CONFIG_SERIAL_SCCNXP				y
++CONFIG_SERIAL_SCCNXP_CONSOLE			y
++#  serial pmaczilog
++CONFIG_SERIAL_PMACZILOG_CONSOLE			y
++CONFIG_SERIAL_PMACZILOG_TTYS			n
++#  options:
++CONFIG_MAX_RAW_DEVS				256
++CONFIG_LP_CONSOLE				n
++CONFIG_CYZ_INTR					n
++CONFIG_IPMI_PANIC_EVENT				n
++CONFIG_STALDRV					y
++CONFIG_TCG_TPM					y
++CONFIG_SERIAL_KGDB_NMI				y
++CONFIG_SERIAL_MAX310X				y
++CONFIG_SERIAL_OMAP_CONSOLE			y
++
++# CONFIG_USB_OHCI_HCD_PLATFORM and CONFIG_USB_EHCI_HCD_PLATFORM must be off on omap
++CONFIG_USB_HCD_BCMA				p policy<(flavour omap &/ value n) | value m> note<USB_{O,E}HCI_HCD_PLATFORM must be off on omap>
++CONFIG_USB_HCD_SSB				p policy<(flavour omap &/ value n) | value m> note<USB_{O,E}HCI_HCD_PLATFORM must be off on omap>
++
++#
++# XXX: v--- unreviewed annotations.
++#
++
++# Boot essential items are always =y
++#  subsystems:
++#  ACPI drivers
++CONFIG_ACPI_AC y note<core ACPI driver>
++CONFIG_ACPI_BATTERY y note<core ACPI driver>
++CONFIG_ACPI_BUTTON y note<core ACPI driver>
++CONFIG_ACPI_FAN y note<core ACPI driver>
++CONFIG_ACPI_PROCESSOR y note<core ACPI driver>
++CONFIG_ACPI_THERMAL y note<core ACPI driver>
++CONFIG_ACPI_HED y note<core ACPI driver>
++CONFIG_ACPI_CONTAINER y note<dependancy ACPI_HOTPLUG_CPU>
++
++# Boot essential disk devices
++CONFIG_EDD y note<core disk support>
++
++# Core debugging support
++CONFIG_KGDB_SERIAL_CONSOLE y note<early debugging support>
++
++# Common boot essential
++CONFIG_XZ_DEC y note<boot essential -- initramfs decompressor>
++CONFIG_KEYBOARD_ATKBD y note<boot essential -- input device>
++CONFIG_SERIO y note<boot essential -- input devices>
++CONFIG_SERIO_I8042 y note<boot essential -- input devices>
++CONFIG_SERIO_LIBPS2 y note<boot essential -- input devices> 
++
++
++# Boot essential dependancies
++CONFIG_BLK_CGROUP y note<dependancy of boot essential>
++CONFIG_DNS_RESOLVER y note<dependancy of boot essential>
++CONFIG_CRC_T10DIF y note<dependancy of boot essential>
++CONFIG_ZSMALLOC y note<dependancy of boot essential>
++
++# x86 boot essential
++CONFIG_PCI_IOAPIC p policy<(arch i386 amd64 &/ value y) | value m> note<boot essential on i386/amd64>
++CONFIG_SCSI_SPI_ATTRS p policy<(arch i386 amd64 &/ value y) | value m> note<dependancy of boot essential>
++CONFIG_TOSHIBA n note<recommended against use>
++
++# ARM/EFI requires FAT for kernel installation.
++CONFIG_FAT_FS p policy<(arch armel armhf i386 amd64 &/ value y) | value m> note<installation essential on ARM and EFI systems>
++CONFIG_VFAT_FS p policy<(arch armel armhf i386 amd64 &/ value y) | value m> note<installation essential on ARM and EFI systems>
++CONFIG_NLS_CODEPAGE_437 p policy<((flavour omap omap4 | arch i386 amd64) &/ value y) | value m> note<installation essential on ARM and EFI systems>
++CONFIG_NLS y note<dependancy of boot essential>
++
++# ARM boot essential devices
++CONFIG_MMC_BLOCK p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_MMC_OMAP_HS p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_FB_OMAP2 p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_NOP_USB_XCEIV p policy<(flavour omap highbank &/ value y) | value m> note<boot essential on omap/highbank>
++CONFIG_PANEL_GENERIC_DPI p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_REGULATOR_FIXED_VOLTAGE p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_SERIAL_OMAP p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_OMAP2_DSS p policy<(arch armel armhf &/ value y) | value m> note<boot essential on arm>
++CONFIG_MMC_SDHCI_PLTFM				p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_NET_CALXEDA_XGMAC			p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_PL330_DMA				p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_SERIO_SERPORT				p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_OMAP_INTERCONNECT			y note<boot essential on omap>
++CONFIG_SND					p policy<(flavour omap &/ value y) | value m> note<not autoloadable on omap>
++CONFIG_SND_OMAP_SOC_OMAP_TWL4030		p policy<(flavour omap &/ value y) | value m> note<not autoloadable on omap>
++CONFIG_SND_SOC					p policy<(flavour omap &/ value y) | value m> note<not autoloadable on omap>
++CONFIG_SOUND					p policy<(flavour omap &/ value y) | value m> note<not autoloadable on omap>
++CONFIG_USB_MUSB_OMAP2PLUS			y
++CONFIG_USB_MUSB_HDRC				p policy<(flavour omap &/ value y) | value m> note<not autoloadable on omap>
++
++# omap3/omap4 boot essential
++CONFIG_MTD p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_BLKDEVS p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_BLOCK p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_CHAR p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_NAND p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_NAND_OMAP2 p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_MTD_OF_PARTS p policy<(flavour omap &/ value y) | value m> note<boot essential on arm>
++CONFIG_KEYBOARD_OMAP4 p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_KEYBOARD_TWL4030 p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_USB_NET_SMSC95XX p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_USB_USBNET p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_HWSPINLOCK_OMAP y note<boot essential on OMAP4>
++CONFIG_HWSPINLOCK_ATMEL n note<depends on CONFIG_ARCH_AT91SAM9G45>
++CONFIG_HW_RANDOM_ATMEL n note<depends on CONFIG_ARCH_AT91SAM9G45>
++CONFIG_LEDS_GPIO p policy<(flavour omap4 &/ value y) | value m> note<enables early heartbeat LEDs>
++CONFIG_LEDS_PWM p policy<(flavour omap4 &/ value y) | value m> note<enables early heartbeat LEDs>
++CONFIG_LEDS_TRIGGER_HEARTBEAT p policy<(flavour omap4 &/ value y) | value m> note<enables early heartbeat LEDs>
++CONFIG_LIB80211 p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_MMC_OMAP p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_MEDIA_SUPPORT p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_MFD_SM501 p policy<(flavour omap4 &/ value y) | value m> note<boot essential on OMAP4>
++CONFIG_USB_INVENTRA_DMA p policy<(flavour omap &/ value y) | value n> note<OMAP2 specific feature>
++
++# highbank boot essential
++CONFIG_SATA_AHCI_PLATFORM p policy<(flavour highbank &/ value y) | (flavour omap4 &/ value n) | value m> note<boot essential on highbank/build failure on ti-omap4> flag<BUILD FAILURE>
++CONFIG_EXT2_FS p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++CONFIG_KEYBOARD_HIGHBANK p policy<(flavour highbank &/ value y) | value m> note<boot essential on highbank>
++
++# POWERPC boot essential devices
++CONFIG_FB_VOODOO1 p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_FB_3DFX p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_FB_PS3 p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_FB_ATY128 p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_FB_RADEON p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_NVRAM p policy<(arch powerpc &/ value y) | value m> note<boot essential on powerpc>
++CONFIG_HW_RANDOM_PASEMI p policy<(arch powerpc &/ value y) | value m> note<dependancy HW_RANDOM>
++CONFIG_PS3_PS3AV p policy<(arch powerpc &/ value y) | value m> note<dependancy HW_RANDOM>
++CONFIG_PS3_SYS_MANAGER p policy<(arch powerpc &/ value y) | value m> note<dependancy HW_RANDOM>
++CONFIG_SERIAL_PMACZILOG p policy<(arch powerpc &/ value y) | value m> note<boot essential -- serial consoles>
++CONFIG_THERM_ADT746X p policy<(arch powerpc &/ value y) | value m> note<boot essential -- cooling support>
++
++# XEN host boot essential
++CONFIG_XEN_ACPI_PROCESSOR p policy<(arch i386 amd64 &/ value y) | value m> <boot essential on XEN host>
++
++# devices which make no sense on some platforms
++CONFIG_PCCARD p policy<(arch armel armhf &/ value n) | value m> note<not a supported interface on arm>
++
++# GRUB2 boot requirement
++CONFIG_FRAMEBUFFER_CONSOLE y note<boot essential for grub2 console>
++
++# TESTING options
++CONFIG_DMATEST n flag<TESTING>
++CONFIG_DEBUG_NX_TEST n flag<TESTING>
++CONFIG_BACKTRACE_SELF_TEST n flag<TESTING>
++CONFIG_FB_VIRTUAL n flag<TESTING>
++CONFIG_MMC_TEST n flag<TESTING>
++CONFIG_MMIOTRACE_TEST n flag<TESTING>
++CONFIG_RCU_TORTURE_TEST n flag<TESTING>
++CONFIG_IEEE802154_FAKEHARD n flag<TESTING>
++CONFIG_LKDTM n flag<TESTING>
++CONFIG_WL12XX_SDIO_TEST n flag<TESTING>
++CONFIG_RING_BUFFER_BENCHMARK n flag<TESTING>
++CONFIG_RTC_DRV_TEST n flag<TESTING>
++CONFIG_USB_DUMMY_HCD n flag<TESTING>
++CONFIG_PCIEAER_INJECT n flag<TESTING>
++CONFIG_PPS_CLIENT_KTIMER n flag<TESTING>
++CONFIG_CRC32_SELFTEST n flag<TESTING>
++CONFIG_OF_SELFTEST n flag<TESTING>
++CONFIG_USB_ZERO_HNPTEST n flag<TEST DEVICE>
++
++# DEBUGGING option
++CONFIG_BRCMDBG - flag<DEBUG>
++CONFIG_USB_XHCI_HCD_DEBUGGING n flag<DEBUG>
++
++# ARM commonly use sd cards as root disks.
++CONFIG_MMC_SDHCI p policy<(flavour omap highbank &/ value y) | value m> note<installation essential on omap/highbank>
++
++# Security risk.
++CONFIG_ACPI_CUSTOM_METHOD n note<Security: allows arbitrary execution>
++
++
++# EFI_VARS is required for EFI boot
++CONFIG_EFI_VARS y note<EFI boot requirement (d-i)>
++
++# OLD/DEPRECATED things
++CONFIG_IA32_AOUT n note<IDE is deprecated>
++CONFIG_MOUSE_INPORT n note<very old ISA based mouse support>
++CONFIG_OMAP_IOVMM n note<deprecated OMAP support>
++
++# IKCONFIG not required
++CONFIG_IKCONFIG n note<not required as configs in /boot>
++
++# POWERPC
++CONFIG_PATA_MACIO y note<boot essential for QEMU on powerpc>
++
++# Non-obvious filesystems.
++CONFIG_USB_FUNCTIONFS m note<filesystems are opt-in>
++CONFIG_USB_GADGETFS m note<filesystems are opt-in>
++CONFIG_LOGFS n note<highly discouraged for use>
++CONFIG_USB_OTG_BLACKLIST_HUB n note<OTG white/blacklists are disabled>
++CONFIG_USB_OTG_WHITELIST n note<OTG white/blacklists are disabled>
++
++# filesystem misc
++CONFIG_SQUASHFS_4K_DEVBLK_SIZE n note<non-default block size>
++
++# ARM omap3
++CONFIG_PANEL_DVI y note<required for omap3 video>
++CONFIG_PANEL_SHARP_LS037V7DW01 p policy<(flavour omap &/ value y) | value m> note<required for omap3 video>
++CONFIG_PANEL_TPO_TD043MTEA1 p policy<(flavour omap &/ value y) | value m> note<required for omap3 video>
++CONFIG_SND_OMAP_SOC p policy<(flavour omap &/ value y) | value m> note<required for omap3 sound>
++CONFIG_SND_OMAP_SOC_MCBSP p policy<(flavour omap &/ value y) | value m> note<required for omap3 sound>
++CONFIG_SND_OMAP_SOC_OMAP3_BEAGLE p policy<(flavour omap &/ value y) | value m> note<required for omap3 sound>
++CONFIG_USB_MUSB_TUSB6010 p policy<(flavour omap highbank &/ value n) | value m> note<USB_MUSB choice>
++CONFIG_USB_OMAP n note<not used for our OMAP3/4 h/w>
++CONFIG_DMA_OMAP y
++
++# ARM gadget mode
++CONFIG_USB_GADGET p policy<(flavour omap omap4 &/ value y) | value m> note<not autoprobable -- only present commonly on omap>
++CONFIG_USB_OTG y note<dependancy of a boot essential>
++CONFIG_USB_G_MULTI p policy<(flavour omap omap4 &/ value m) | value n> note<omap3/omap4 specific feature>
++CONFIG_USB_M66592 n note<gadget device>
++
++# powerpc64-smp requires this as CONFIG_MAPLE is enabled
++CONFIG_ATA_NONSTANDARD p policy<(flavour powerpc64-smp &/ value y) | value n> note<required for powerpc64-smp dep of CONFIG_MAPLE>
++
++# APM Emulation is deliberately off on ARM to prevent new use.
++CONFIG_APM_EMULATION p policy<(arch armel armhf &/ value n) | value m> note<deliberatly forced off for ARM>
++
++# BLK_DEV_XD -- ancient drives
++CONFIG_BLK_DEV_XD n note<ancient drives from pre-history>
++
++# Geode specific, should be enabled by drivers that need it not manually.
++CONFIG_CS5535_MFGPT n note<should be disabled by default>
++
++# DVB_DUMMY_FE only recommended for experts
++CONFIG_DVB_DUMMY_FE n note<expert use only>
++
++# ARM unsupported SOC
++#CONFIG_FTGMAC100 n note<unsupported ARM device>
++#CONFIG_FTMAC100 n note<unsupported ARM device>
++#CONFIG_ARCH_EXYNOS n note<unsupported ARM arch>
++#CONFIG_ARCH_HIGHBANK n note<unsupported ARM arch>
++#CONFIG_ARCH_PICOXCELL n note<unsupported ARM arch>
++#CONFIG_ARCH_PRIMA2 n note<unsupported ARM arch>
++#CONFIG_ARCH_ZYNQ n note<unsupported ARM arch>
++
++CONFIG_ARCH_MULTIPLATFORM			p policy<(flavour highbank &/ value y) | value n>
++CONFIG_ARCH_OMAP				p policy<(flavour omap &/ value y) | value n>
++
++# Options which really should not have an option at all.
++CONFIG_SIGMA n note<unused common driver infrastructure>
++CONFIG_DM9000_FORCE_SIMPLE_PHY_POLL n
++
++# Items which are simply miss identified
++CONFIG_DEBUG_LL_UART_NONE y note<not actually debug>
++CONFIG_USB_SERIAL_DEBUG m note<not actually debug>
++
++# Experimental
++CONFIG_RTL8192DE m note<experimental wireless driver -- opt-in>
++CONFIG_BLK_DEV_UMEM m note<experimental NVRAM disk driver -- opt-in>
++
++# Optional scheduling control
++CONFIG_CFS_BANDWIDTH y note<optional scheduling control -- opt-in>
++
++# Hardware specific experimental options.
++CONFIG_EDAC_SBRIDGE m note<h/w specific experimental option -- opt-in>
++CONFIG_SM_FTL m note<h/w specific experimental option -- opt-in>
++CONFIG_SPI_SPIDEV m note<h/w specific experimental option -- opt-in>
++CONFIG_ATH6KL_USB m note<h/w specific experimental option -- opt-in>
++CONFIG_USB_KC2190 y note<h/w specific experimental option -- opt-in>
++
++# Dummy drivers
++CONFIG_IIO_SIMPLE_DUMMY_BUFFER n note<dummy driver>
++CONFIG_IIO_SIMPLE_DUMMY_EVENTS n note<dummy driver>
++
++# Options where the default is simply too broad:
++
++# The intel IOMMU being on by default causes a slew of issues with
++# machines.  We therefore enable its use, but default it off.
++CONFIG_INTEL_IOMMU_DEFAULT_ON n note<the IOMMU can trigger boot failures>
++
++# H/W specific options
++CONFIG_PATA_HPT3X3_DMA n note<DMA mode is documented problematic>
++CONFIG_B43_BCMA_EXTRA n note<BRCMSMAC is enabled disable to avoid ID overlaps>
++
++# Valid y/n options which are in a sensible position.
++CONFIG_PPC_ICSWX_USE_SIGILL n note<reviewed 05/2012>
++#  forces padding mode, without this we can select at runtime
++CONFIG_USB_SERIAL_SAFE_PADDED n note<reviewed 07/2012>
++#  allows the console to move to an external USB device
++CONFIG_USB_SISUSBVGA_CON n note<reviewed 07/2012>
++
++# Old/Deprecated
++CONFIG_SCSI_AIC7XXX_OLD n note<deprecated in favour of aic7xxx>
++
++# OSS is handled via pulseaudio
++CONFIG_SND_PCM_OSS n note<deprecated in favour of pulseaudio emulation>
++
++# Poulsbo is handled by DRM_GMA500
++CONFIG_STUB_POULSBO n note<deprecated in favour of CONFIG_DRM_GMA500>
++
++# Risky
++CONFIG_RTAS_FLASH n note<potentially risky allowing flash updates>
++
++# Only valid on fully certified platforms
++CONFIG_ATH9K_DFS_CERTIFIED n note<only valid for kernels for certified platforms only>
++
++# CONFIG_AUDIT_LOGINUID_IMMUTABLE is not compatible with upstart
++CONFIG_AUDIT_LOGINUID_IMMUTABLE n note<incompatible with upstart>
++
++# Machine specific on systems we cannot encounter.
++CONFIG_GPIO_EM n note<h/w not encounted>
++
++# Standard options.
++CONFIG_PANIC_ON_OOPS n note<keep working if at all possible>
++
++# CEPHs dependancies
++CONFIG_BLK_DEV_RBD m note<CEPH client side support>
++
++# CGROUP modifications.
++CONFIG_BLK_DEV_THROTTLING y note<CGROUP disk consumption control>
++
++# Block Dev
++CONFIG_BLK_DEV_XIP n note<prevents use of HIGHMEM for ram disks>
++
++#
++# XXX: ^--- unreviewed annotations.
++#
++
++# temporarily disabled options -- build failures.
++CONFIG_TI_CPSW					p policy<(flavour omap &/ value n) | value m> flag<BUILD FAILURE>
++CONFIG_USB_MUSB_DSPS				p policy<(flavour omap &/ value n) | value m> flag<BUILD FAILURE>
++CONFIG_LIS3L02DQ				p policy<(arch armhf &/ value n) | value m> flag<BUILD FAILURE>
++CONFIG_EZX_PCAP					p policy<(arch armhf &/ value n) | value m> flag<BUILD FAILURE>
++CONFIG_TOUCHSCREEN_EGALAX			p policy<(flavour omap4 &/ value n) | value m> flag<BUILD FAILURE> not
++e<FTBS on ti-omap4>
++CONFIG_TOUCHSCREEN_EETI				p policy<(flavour omap4 &/ value n) | value m> flag<BUILD FAILURE> not
++e<FTBS on ti-omap4>
++CONFIG_SENSORS_AK8975				p policy<(flavour omap4 &/ value n) | value m> flag<BUILD FAILURE> note<FTBS on ti-omap4>
++CONFIG_IIO					p policy<(flavour omap4 &/ value n) | value m> flag<BUILD FAILURE> note<FTBS on ti-omap4>
++
++# Ensure DEPRECATED options are off.
++set +all ?flag DEPRECATED ?type bool		= n
++set +all ?flag DEPRECATED ?type tristate	= n
++
++# Ensure DANGEROUS things are turned off.
++set +all ?flag DANGEROUS = n
+diff --git a/debian.master/config/arm64/config.common.arm64 b/debian.master/config/arm64/config.common.arm64
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/arm64/config.common.arm64
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/config/arm64/config.flavour.linaro-SOCFLAVOUR b/debian.master/config/arm64/config.flavour.linaro-SOCFLAVOUR
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/arm64/config.flavour.linaro-SOCFLAVOUR
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/config/armhf/config.common.armhf b/debian.master/config/armhf/config.common.armhf
+new file mode 100644
+index 0000000..b9bc1ca
+--- /dev/null
++++ b/debian.master/config/armhf/config.common.armhf
+@@ -0,0 +1,82 @@
++#
++# Config options for config.common.armhf automatically generated by splitconfig.pl
++#
++# CONFIG_ARCH_SELECT_MEMORY_MODEL is not set
++# CONFIG_ARCH_SPARSEMEM_DEFAULT is not set
++CONFIG_ASYNC_TX_DMA=y
++CONFIG_BCH=y
++# CONFIG_CPU_FREQ is not set
++CONFIG_DEFAULT_MMAP_MIN_ADDR=32768
++# CONFIG_EZX_PCAP is not set
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
++CONFIG_FB_SYS_COPYAREA=y
++CONFIG_FB_SYS_FILLRECT=y
++CONFIG_FB_SYS_IMAGEBLIT=y
++CONFIG_FONTS=y
++# CONFIG_FUNCTION_TRACER is not set
++# CONFIG_HAVE_AOUT is not set
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++CONFIG_HZ=100
++# CONFIG_KSM is not set
++CONFIG_KVM=y
++# CONFIG_LIBERTAS_MESH is not set
++# CONFIG_LIS3L02DQ is not set
++CONFIG_LOG_BUF_SHIFT=17
++CONFIG_MFD_TMIO=y
++CONFIG_MMC_BLOCK=y
++CONFIG_MMC_SDHCI=y
++CONFIG_MMC_SDHCI_PLTFM=y
++CONFIG_MTD=y
++CONFIG_MTD_BLKDEVS=y
++CONFIG_MTD_BLOCK=y
++CONFIG_MTD_CMDLINE_PARTS=y
++CONFIG_MTD_NAND=y
++CONFIG_MTD_NAND_BCH=y
++CONFIG_MTD_NAND_ECC=y
++CONFIG_MTD_NAND_IDS=y
++# CONFIG_NL80211_TESTMODE is not set
++CONFIG_NOP_USB_XCEIV=y
++CONFIG_NR_CPUS=4
++CONFIG_OMAP_CONTROL_USB=y
++# CONFIG_PCCARD is not set
++CONFIG_PM_WAKELOCKS=y
++CONFIG_PPS=y
++CONFIG_PTP_1588_CLOCK=y
++CONFIG_RCU_FANOUT=32
++# CONFIG_RCU_NOCB_CPU is not set
++# CONFIG_RCU_USER_QS is not set
++CONFIG_REGULATOR_FIXED_VOLTAGE=y
++# CONFIG_RT2800USB_UNKNOWN is not set
++CONFIG_RT2X00_LIB_DEBUGFS=y
++CONFIG_RTC_DRV_CMOS=m
++CONFIG_SATA_HIGHBANK=y
++# CONFIG_SCHED_SMT is not set
++CONFIG_SCSI_SPI_ATTRS=m
++CONFIG_SMS_SIANO_DEBUGFS=y
++CONFIG_SND=y
++CONFIG_SND_COMPRESS_OFFLOAD=y
++# CONFIG_SND_OPL4_LIB_SEQ is not set
++CONFIG_SND_PCM=y
++# CONFIG_SND_SBAWE_SEQ is not set
++CONFIG_SND_SOC=y
++CONFIG_SND_SOC_I2C_AND_SPI=y
++CONFIG_SND_TIMER=y
++CONFIG_SOUND=y
++# CONFIG_STACK_TRACER is not set
++CONFIG_STANDALONE=y
++CONFIG_TICK_CPU_ACCOUNTING=y
++CONFIG_TWL4030_CORE=y
++CONFIG_USB_CHIPIDEA=y
++# CONFIG_USB_EHCI_HCD_PLATFORM is not set
++CONFIG_USB_GADGET=y
++CONFIG_USB_G_MULTI=m
++# CONFIG_USB_HCD_BCMA is not set
++# CONFIG_USB_HCD_SSB is not set
++CONFIG_USB_MUSB_HDRC=y
++# CONFIG_USB_MUSB_TUSB6010 is not set
++# CONFIG_USB_OHCI_HCD_PLATFORM is not set
++# CONFIG_VFIO_IOMMU_TYPE1 is not set
++CONFIG_VIRTIO_CONSOLE=y
++CONFIG_VIRTIO_MMIO=y
++# CONFIG_WIL6210 is not set
+diff --git a/debian.master/config/armhf/config.flavour.generic b/debian.master/config/armhf/config.flavour.generic
+new file mode 100644
+index 0000000..bf21d99
+--- /dev/null
++++ b/debian.master/config/armhf/config.flavour.generic
+@@ -0,0 +1,37 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
++CONFIG_AC97_BUS=y
++CONFIG_AHCI_IMX=y
++CONFIG_ARCH_MXC=y
++CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED=y
++CONFIG_ARCH_NR_GPIO=1024
++CONFIG_ARCH_OMAP3=y
++CONFIG_ARCH_OMAP4=y
++# CONFIG_ARCH_PHYS_ADDR_T_64BIT is not set
++CONFIG_ARCH_TEGRA=y
++CONFIG_ARM_ATAG_DTB_COMPAT=y
++# CONFIG_ARM_LPAE is not set
++# CONFIG_COMPACTION is not set
++# CONFIG_CPU_IDLE_CALXEDA is not set
++CONFIG_FB_BACKLIGHT=y
++CONFIG_FB_DDC=m
++CONFIG_FB_SVGALIB=m
++CONFIG_GPIO_GENERIC=y
++CONFIG_GPIO_TWL6040=y
++# CONFIG_HUGETLB_PAGE is not set
++CONFIG_MTD_SM_COMMON=m
++# CONFIG_MUSB_PIO_ONLY is not set
++CONFIG_PCI_SYSCALL=y
++# CONFIG_PHYS_ADDR_T_64BIT is not set
++CONFIG_SATA_AHCI_PLATFORM=y
++CONFIG_SND_EMU10K1_SEQ=m
++CONFIG_SND_OPL3_LIB_SEQ=m
++CONFIG_SND_SOC_HDMI_CODEC=y
++CONFIG_SND_SOC_SGTL5000=y
++CONFIG_SND_SOC_TWL4030=y
++CONFIG_SND_SOC_TWL6040=y
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_TEGRA_HOST1X=m
++CONFIG_VGASTATE=m
++CONFIG_ZONE_DMA_FLAG=0
+diff --git a/debian.master/config/armhf/config.flavour.generic-lpae b/debian.master/config/armhf/config.flavour.generic-lpae
+new file mode 100644
+index 0000000..d5c1b40
+--- /dev/null
++++ b/debian.master/config/armhf/config.flavour.generic-lpae
+@@ -0,0 +1,37 @@
++#
++# Config options for config.flavour.generic-lpae automatically generated by splitconfig.pl
++#
++CONFIG_AC97_BUS=m
++CONFIG_AHCI_IMX=m
++# CONFIG_ARCH_MXC is not set
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_NR_GPIO=0
++# CONFIG_ARCH_OMAP3 is not set
++# CONFIG_ARCH_OMAP4 is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++# CONFIG_ARCH_TEGRA is not set
++# CONFIG_ARM_ATAG_DTB_COMPAT is not set
++CONFIG_ARM_LPAE=y
++CONFIG_COMPACTION=y
++CONFIG_CPU_IDLE_CALXEDA=y
++# CONFIG_FB_BACKLIGHT is not set
++# CONFIG_FB_DDC is not set
++# CONFIG_FB_SVGALIB is not set
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_TWL6040=m
++CONFIG_HUGETLB_PAGE=y
++# CONFIG_MTD_SM_COMMON is not set
++CONFIG_MUSB_PIO_ONLY=y
++# CONFIG_PCI_SYSCALL is not set
++CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_SATA_AHCI_PLATFORM=m
++# CONFIG_SND_EMU10K1_SEQ is not set
++# CONFIG_SND_OPL3_LIB_SEQ is not set
++CONFIG_SND_SOC_HDMI_CODEC=m
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_SOC_TWL4030=m
++CONFIG_SND_SOC_TWL6040=m
++# CONFIG_SPI_PXA2XX_PCI is not set
++# CONFIG_TEGRA_HOST1X is not set
++# CONFIG_VGASTATE is not set
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/config.common.ports b/debian.master/config/config.common.ports
+new file mode 100644
+index 0000000..4574947
+--- /dev/null
++++ b/debian.master/config/config.common.ports
+@@ -0,0 +1,3 @@
++#
++# Common config options automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/config.common.ubuntu b/debian.master/config/config.common.ubuntu
+new file mode 100644
+index 0000000..d6ae2f7
+--- /dev/null
++++ b/debian.master/config/config.common.ubuntu
+@@ -0,0 +1,7098 @@
++#
++# Common config options automatically generated by splitconfig.pl
++#
++CONFIG_3C515=m
++CONFIG_60XX_WDT=m
++CONFIG_6PACK=m
++CONFIG_8139CP=m
++CONFIG_8139TOO=m
++CONFIG_8139TOO_8129=y
++CONFIG_8139TOO_PIO=y
++# CONFIG_8139TOO_TUNE_TWISTER is not set
++# CONFIG_8139_OLD_RX_RESET is not set
++CONFIG_9P_FS=m
++# CONFIG_9P_FSCACHE is not set
++CONFIG_9P_FS_POSIX_ACL=y
++CONFIG_9P_FS_SECURITY=y
++CONFIG_AB3100_CORE=y
++CONFIG_AB3100_OTP=m
++CONFIG_ABX500_CORE=y
++# CONFIG_ACCESSIBILITY is not set
++CONFIG_ACENIC=m
++# CONFIG_ACENIC_OMIT_TIGON_I is not set
++CONFIG_ACERHDF=m
++CONFIG_ACER_WMI=m
++CONFIG_ACORN_PARTITION=y
++# CONFIG_ACORN_PARTITION_ADFS is not set
++# CONFIG_ACORN_PARTITION_CUMANA is not set
++# CONFIG_ACORN_PARTITION_EESOX is not set
++CONFIG_ACORN_PARTITION_ICS=y
++# CONFIG_ACORN_PARTITION_POWERTEC is not set
++CONFIG_ACORN_PARTITION_RISCIX=y
++CONFIG_ACPI=y
++CONFIG_ACPI_AC=y
++CONFIG_ACPI_APEI=y
++CONFIG_ACPI_APEI_EINJ=m
++# CONFIG_ACPI_APEI_ERST_DEBUG is not set
++CONFIG_ACPI_APEI_GHES=y
++CONFIG_ACPI_APEI_MEMORY_FAILURE=y
++CONFIG_ACPI_APEI_PCIEAER=y
++CONFIG_ACPI_BATTERY=y
++CONFIG_ACPI_BGRT=y
++CONFIG_ACPI_BUTTON=y
++CONFIG_ACPI_CMPC=m
++CONFIG_ACPI_CONTAINER=y
++# CONFIG_ACPI_CUSTOM_DSDT is not set
++CONFIG_ACPI_CUSTOM_DSDT_FILE=""
++# CONFIG_ACPI_CUSTOM_METHOD is not set
++# CONFIG_ACPI_DEBUG is not set
++CONFIG_ACPI_DOCK=y
++CONFIG_ACPI_EC_DEBUGFS=m
++CONFIG_ACPI_FAN=y
++CONFIG_ACPI_HED=y
++CONFIG_ACPI_HOTPLUG_CPU=y
++CONFIG_ACPI_HOTPLUG_MEMORY=y
++CONFIG_ACPI_I2C=y
++# CONFIG_ACPI_INITRD_TABLE_OVERRIDE is not set
++CONFIG_ACPI_IPMI=m
++CONFIG_ACPI_NUMA=y
++CONFIG_ACPI_PCI_SLOT=y
++CONFIG_ACPI_PROCESSOR=y
++CONFIG_ACPI_PROCESSOR_AGGREGATOR=m
++# CONFIG_ACPI_PROCFS is not set
++# CONFIG_ACPI_PROCFS_POWER is not set
++CONFIG_ACPI_PROC_EVENT=y
++CONFIG_ACPI_QUICKSTART=m
++CONFIG_ACPI_SBS=m
++CONFIG_ACPI_SLEEP=y
++CONFIG_ACPI_THERMAL=y
++CONFIG_ACPI_TOSHIBA=m
++CONFIG_ACPI_VIDEO=m
++CONFIG_ACPI_WMI=m
++CONFIG_ACQUIRE_WDT=m
++CONFIG_ACT200L_DONGLE=m
++CONFIG_ACTISYS_DONGLE=m
++CONFIG_AD2S1200=m
++CONFIG_AD2S1210=m
++CONFIG_AD2S90=m
++CONFIG_AD5064=m
++CONFIG_AD525X_DPOT=m
++CONFIG_AD525X_DPOT_I2C=m
++CONFIG_AD525X_DPOT_SPI=m
++CONFIG_AD5360=m
++CONFIG_AD5380=m
++CONFIG_AD5421=m
++CONFIG_AD5446=m
++CONFIG_AD5449=m
++CONFIG_AD5504=m
++CONFIG_AD5624R_SPI=m
++CONFIG_AD5686=m
++CONFIG_AD5755=m
++CONFIG_AD5764=m
++CONFIG_AD5791=m
++CONFIG_AD5930=m
++CONFIG_AD5933=m
++CONFIG_AD7150=m
++CONFIG_AD7152=m
++CONFIG_AD7192=m
++CONFIG_AD7266=m
++CONFIG_AD7280=m
++CONFIG_AD7291=m
++CONFIG_AD7298=m
++CONFIG_AD7303=m
++CONFIG_AD7476=m
++CONFIG_AD7606=m
++CONFIG_AD7606_IFACE_PARALLEL=m
++CONFIG_AD7606_IFACE_SPI=m
++CONFIG_AD7746=m
++CONFIG_AD7780=m
++CONFIG_AD7791=m
++CONFIG_AD7793=m
++CONFIG_AD7816=m
++CONFIG_AD7887=m
++CONFIG_AD7923=m
++CONFIG_AD799X=m
++CONFIG_AD799X_RING_BUFFER=y
++CONFIG_AD8366=m
++CONFIG_AD9523=m
++CONFIG_AD9832=m
++CONFIG_AD9834=m
++CONFIG_AD9850=m
++CONFIG_AD9852=m
++CONFIG_AD9910=m
++CONFIG_AD9951=m
++CONFIG_ADAPTEC_STARFIRE=m
++CONFIG_ADE7753=m
++CONFIG_ADE7754=m
++CONFIG_ADE7758=m
++CONFIG_ADE7759=m
++CONFIG_ADE7854=m
++CONFIG_ADE7854_I2C=m
++CONFIG_ADE7854_SPI=m
++CONFIG_ADF4350=m
++CONFIG_ADFS_FS=m
++# CONFIG_ADFS_FS_RW is not set
++CONFIG_ADIS16060=m
++CONFIG_ADIS16080=m
++CONFIG_ADIS16130=m
++CONFIG_ADIS16136=m
++CONFIG_ADIS16201=m
++CONFIG_ADIS16203=m
++CONFIG_ADIS16204=m
++CONFIG_ADIS16209=m
++CONFIG_ADIS16220=m
++CONFIG_ADIS16240=m
++CONFIG_ADIS16260=m
++CONFIG_ADIS16400=m
++CONFIG_ADIS16480=m
++CONFIG_ADJD_S311=m
++CONFIG_ADM8211=m
++CONFIG_ADT7316=m
++CONFIG_ADT7316_I2C=m
++CONFIG_ADT7316_SPI=m
++CONFIG_ADVANTECH_WDT=m
++CONFIG_ADXRS450=m
++CONFIG_AD_SIGMA_DELTA=m
++CONFIG_AEABI=y
++CONFIG_AFFS_FS=m
++# CONFIG_AFS_DEBUG is not set
++CONFIG_AFS_FS=m
++# CONFIG_AFS_FSCACHE is not set
++CONFIG_AF_RXRPC=m
++# CONFIG_AF_RXRPC_DEBUG is not set
++CONFIG_AGP=y
++CONFIG_AGP_ALI=m
++CONFIG_AGP_AMD=y
++CONFIG_AGP_AMD64=y
++CONFIG_AGP_ATI=m
++CONFIG_AGP_EFFICEON=m
++CONFIG_AGP_INTEL=y
++CONFIG_AGP_NVIDIA=y
++CONFIG_AGP_SIS=m
++CONFIG_AGP_SWORKS=m
++CONFIG_AGP_VIA=y
++CONFIG_AIC79XX_CMDS_PER_DEVICE=32
++# CONFIG_AIC79XX_DEBUG_ENABLE is not set
++CONFIG_AIC79XX_DEBUG_MASK=0
++CONFIG_AIC79XX_REG_PRETTY_PRINT=y
++CONFIG_AIC79XX_RESET_DELAY_MS=5000
++CONFIG_AIC7XXX_CMDS_PER_DEVICE=8
++# CONFIG_AIC7XXX_DEBUG_ENABLE is not set
++CONFIG_AIC7XXX_DEBUG_MASK=0
++CONFIG_AIC7XXX_REG_PRETTY_PRINT=y
++CONFIG_AIC7XXX_RESET_DELAY_MS=15000
++# CONFIG_AIC94XX_DEBUG is not set
++CONFIG_AIO=y
++CONFIG_AIRO=m
++CONFIG_AIRO_CS=m
++CONFIG_AIX_PARTITION=y
++CONFIG_AK8975=m
++CONFIG_ALIGNMENT_TRAP=y
++CONFIG_ALIM1535_WDT=m
++CONFIG_ALIM7101_WDT=m
++CONFIG_ALIX=y
++CONFIG_ALI_FIR=m
++CONFIG_ALTERA_STAPL=m
++CONFIG_ALX=m
++CONFIG_AMBA_PL08X=y
++CONFIG_AMD8111_ETH=m
++CONFIG_AMD_IOMMU=y
++CONFIG_AMD_IOMMU_STATS=y
++CONFIG_AMD_IOMMU_V2=m
++CONFIG_AMD_NB=y
++CONFIG_AMD_NUMA=y
++CONFIG_AMD_PHY=y
++CONFIG_AMIGA_PARTITION=y
++CONFIG_AMILO_RFKILL=m
++# CONFIG_ANDROID is not set
++CONFIG_ANON_INODES=y
++CONFIG_APB_TIMER=y
++CONFIG_APDS9802ALS=m
++CONFIG_APM=m
++# CONFIG_APM_ALLOW_INTS is not set
++# CONFIG_APM_CPU_IDLE is not set
++# CONFIG_APM_DISPLAY_BLANK is not set
++# CONFIG_APM_DO_ENABLE is not set
++# CONFIG_APM_EMULATION is not set
++# CONFIG_APM_IGNORE_USER_SUSPEND is not set
++CONFIG_APPLE_GMUX=m
++CONFIG_APPLICOM=m
++CONFIG_AR5523=m
++# CONFIG_ARCH_AT91 is not set
++# CONFIG_ARCH_BCM is not set
++CONFIG_ARCH_BINFMT_ELF_RANDOMIZE_PIE=y
++CONFIG_ARCH_CLOCKSOURCE_DATA=y
++# CONFIG_ARCH_CLPS711X is not set
++CONFIG_ARCH_CPU_PROBE_RELEASE=y
++# CONFIG_ARCH_DAVINCI is not set
++CONFIG_ARCH_DISCARD_MEMBLOCK=y
++CONFIG_ARCH_DMA_ADDR_T_64BIT=y
++# CONFIG_ARCH_DOVE is not set
++# CONFIG_ARCH_EBSA110 is not set
++CONFIG_ARCH_ENABLE_MEMORY_HOTPLUG=y
++CONFIG_ARCH_ENABLE_MEMORY_HOTREMOVE=y
++# CONFIG_ARCH_EP93XX is not set
++# CONFIG_ARCH_EXYNOS is not set
++CONFIG_ARCH_FLATMEM_ENABLE=y
++# CONFIG_ARCH_FOOTBRIDGE is not set
++# CONFIG_ARCH_GEMINI is not set
++CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE=y
++CONFIG_ARCH_HAS_BANDGAP=y
++CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
++CONFIG_ARCH_HAS_CPUFREQ=y
++CONFIG_ARCH_HAS_CPU_AUTOPROBE=y
++CONFIG_ARCH_HAS_CPU_RELAX=y
++CONFIG_ARCH_HAS_DEBUG_STRICT_USER_COPY_CHECKS=y
++CONFIG_ARCH_HAS_HOLES_MEMORYMODEL=y
++CONFIG_ARCH_HAS_OPP=y
++CONFIG_ARCH_HAS_RESET_CONTROLLER=y
++CONFIG_ARCH_HAS_TICK_BROADCAST=y
++CONFIG_ARCH_HAVE_CUSTOM_GPIO_H=y
++CONFIG_ARCH_HAVE_NMI_SAFE_CMPXCHG=y
++CONFIG_ARCH_HIBERNATION_HEADER=y
++CONFIG_ARCH_HIBERNATION_POSSIBLE=y
++CONFIG_ARCH_HIGHBANK=y
++# CONFIG_ARCH_INTEGRATOR is not set
++# CONFIG_ARCH_IOP13XX is not set
++# CONFIG_ARCH_IOP32X is not set
++# CONFIG_ARCH_IOP33X is not set
++# CONFIG_ARCH_IXP4XX is not set
++# CONFIG_ARCH_KEYSTONE is not set
++# CONFIG_ARCH_KIRKWOOD is not set
++# CONFIG_ARCH_KS8695 is not set
++# CONFIG_ARCH_LPC32XX is not set
++CONFIG_ARCH_MAY_HAVE_PC_FDC=y
++CONFIG_ARCH_MEMORY_PROBE=y
++# CONFIG_ARCH_MMP is not set
++# CONFIG_ARCH_MSM is not set
++CONFIG_ARCH_MULTIPLATFORM=y
++# CONFIG_ARCH_MULTI_CPU_AUTO is not set
++# CONFIG_ARCH_MULTI_V6 is not set
++CONFIG_ARCH_MULTI_V6_V7=y
++CONFIG_ARCH_MULTI_V7=y
++# CONFIG_ARCH_MV78XX0 is not set
++# CONFIG_ARCH_MVEBU is not set
++# CONFIG_ARCH_NETX is not set
++CONFIG_ARCH_OMAP=y
++# CONFIG_ARCH_OMAP1 is not set
++CONFIG_ARCH_OMAP2PLUS=y
++CONFIG_ARCH_OMAP2PLUS_TYPICAL=y
++# CONFIG_ARCH_ORION5X is not set
++CONFIG_ARCH_PROC_KCORE_TEXT=y
++# CONFIG_ARCH_PXA is not set
++CONFIG_ARCH_RANDOM=y
++# CONFIG_ARCH_REALVIEW is not set
++CONFIG_ARCH_REQUIRE_GPIOLIB=y
++# CONFIG_ARCH_ROCKCHIP is not set
++# CONFIG_ARCH_RPC is not set
++# CONFIG_ARCH_S3C24XX is not set
++# CONFIG_ARCH_S3C64XX is not set
++# CONFIG_ARCH_S5P64X0 is not set
++# CONFIG_ARCH_S5PC100 is not set
++# CONFIG_ARCH_S5PV210 is not set
++# CONFIG_ARCH_SA1100 is not set
++# CONFIG_ARCH_SHARK is not set
++# CONFIG_ARCH_SHMOBILE is not set
++# CONFIG_ARCH_SIRF is not set
++# CONFIG_ARCH_SOCFPGA is not set
++CONFIG_ARCH_SPARSEMEM_ENABLE=y
++# CONFIG_ARCH_STI is not set
++# CONFIG_ARCH_SUNXI is not set
++CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
++CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE=y
++CONFIG_ARCH_SUPPORTS_MSI=y
++CONFIG_ARCH_SUPPORTS_NUMA_BALANCING=y
++CONFIG_ARCH_SUPPORTS_OPTIMIZED_INLINING=y
++CONFIG_ARCH_SUPPORTS_UPROBES=y
++CONFIG_ARCH_SUSPEND_POSSIBLE=y
++CONFIG_ARCH_TEGRA_114_SOC=y
++CONFIG_ARCH_TEGRA_2x_SOC=y
++CONFIG_ARCH_TEGRA_3x_SOC=y
++# CONFIG_ARCH_U8500 is not set
++CONFIG_ARCH_USES_NUMA_PROT_NONE=y
++CONFIG_ARCH_USES_PG_UNCACHED=y
++CONFIG_ARCH_USE_BUILTIN_BSWAP=y
++# CONFIG_ARCH_VERSATILE is not set
++CONFIG_ARCH_VEXPRESS=y
++CONFIG_ARCH_VEXPRESS_CA9X4=y
++CONFIG_ARCH_VEXPRESS_CORTEX_A5_A9_ERRATA=y
++CONFIG_ARCH_VEXPRESS_DCSCB=y
++CONFIG_ARCH_VIRT=y
++# CONFIG_ARCH_W90X900 is not set
++CONFIG_ARCH_WANTS_PROT_NUMA_PROT_NONE=y
++CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION=y
++CONFIG_ARCH_WANT_FRAME_POINTERS=y
++CONFIG_ARCH_WANT_GENERAL_HUGETLB=y
++CONFIG_ARCH_WANT_HUGE_PMD_SHARE=y
++CONFIG_ARCH_WANT_IPC_PARSE_VERSION=y
++CONFIG_ARCH_WANT_OLD_COMPAT_IPC=y
++CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
++# CONFIG_ARCH_WM8850 is not set
++# CONFIG_ARCH_ZYNQ is not set
++CONFIG_ARCNET=m
++CONFIG_ARCNET_1051=m
++CONFIG_ARCNET_1201=m
++CONFIG_ARCNET_CAP=m
++CONFIG_ARCNET_COM20020=m
++CONFIG_ARCNET_COM20020_CS=m
++CONFIG_ARCNET_COM20020_ISA=m
++CONFIG_ARCNET_COM20020_PCI=m
++CONFIG_ARCNET_COM90xx=m
++CONFIG_ARCNET_COM90xxIO=m
++CONFIG_ARCNET_RAW=m
++CONFIG_ARCNET_RIM_I=m
++CONFIG_ARC_EMAC=m
++CONFIG_ARM=y
++CONFIG_ARM_AMBA=y
++CONFIG_ARM_APPENDED_DTB=y
++CONFIG_ARM_ARCH_TIMER=y
++CONFIG_ARM_AT91_ETHER=m
++CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_EXTEND=y
++# CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_FROM_BOOTLOADER is not set
++CONFIG_ARM_CCI=y
++CONFIG_ARM_CHARLCD=y
++CONFIG_ARM_CPU_SUSPEND=y
++CONFIG_ARM_CPU_TOPOLOGY=y
++CONFIG_ARM_DMA_MEM_BUFFERABLE=y
++CONFIG_ARM_ERRATA_430973=y
++CONFIG_ARM_ERRATA_643719=y
++CONFIG_ARM_ERRATA_720789=y
++CONFIG_ARM_ERRATA_754322=y
++CONFIG_ARM_ERRATA_754327=y
++CONFIG_ARM_ERRATA_764369=y
++CONFIG_ARM_ERRATA_775420=y
++CONFIG_ARM_ERRATA_798181=y
++CONFIG_ARM_GIC=y
++CONFIG_ARM_KPROBES_TEST=m
++CONFIG_ARM_L1_CACHE_SHIFT=6
++CONFIG_ARM_L1_CACHE_SHIFT_6=y
++CONFIG_ARM_NR_BANKS=8
++CONFIG_ARM_PATCH_PHYS_VIRT=y
++CONFIG_ARM_PSCI=y
++# CONFIG_ARM_SMMU is not set
++CONFIG_ARM_SP805_WATCHDOG=m
++CONFIG_ARM_THUMB=y
++# CONFIG_ARM_THUMBEE is not set
++CONFIG_ARM_TIMER_SP804=y
++CONFIG_ARM_UNWIND=y
++CONFIG_ARM_VIRT_EXT=y
++CONFIG_ARPD=y
++CONFIG_ASN1=y
++CONFIG_ASUS_LAPTOP=m
++CONFIG_ASUS_NB_WMI=m
++CONFIG_ASUS_OLED=m
++CONFIG_ASUS_WMI=m
++CONFIG_ASYMMETRIC_KEY_TYPE=y
++CONFIG_ASYMMETRIC_PUBLIC_KEY_SUBTYPE=y
++CONFIG_ASYNC_CORE=m
++CONFIG_ASYNC_MEMCPY=m
++CONFIG_ASYNC_PQ=m
++CONFIG_ASYNC_RAID6_RECOV=m
++CONFIG_ASYNC_RAID6_TEST=m
++CONFIG_ASYNC_XOR=m
++CONFIG_AT76C50X_USB=m
++CONFIG_AT803X_PHY=y
++CONFIG_ATA=y
++CONFIG_ATAGS=y
++CONFIG_ATAGS_PROC=y
++CONFIG_ATALK=m
++CONFIG_ATARI_PARTITION=y
++CONFIG_ATA_ACPI=y
++CONFIG_ATA_BMDMA=y
++CONFIG_ATA_GENERIC=y
++# CONFIG_ATA_NONSTANDARD is not set
++CONFIG_ATA_OVER_ETH=m
++CONFIG_ATA_PIIX=y
++CONFIG_ATA_SFF=y
++CONFIG_ATA_VERBOSE_ERROR=y
++CONFIG_ATH10K=m
++# CONFIG_ATH10K_DEBUG is not set
++CONFIG_ATH10K_DEBUGFS=y
++CONFIG_ATH10K_PCI=m
++CONFIG_ATH10K_TRACING=y
++CONFIG_ATH5K=m
++# CONFIG_ATH5K_DEBUG is not set
++CONFIG_ATH5K_PCI=y
++# CONFIG_ATH5K_TRACER is not set
++CONFIG_ATH6KL=m
++# CONFIG_ATH6KL_DEBUG is not set
++CONFIG_ATH6KL_SDIO=m
++# CONFIG_ATH6KL_TRACING is not set
++CONFIG_ATH6KL_USB=m
++CONFIG_ATH9K=m
++CONFIG_ATH9K_AHB=y
++CONFIG_ATH9K_BTCOEX_SUPPORT=y
++CONFIG_ATH9K_COMMON=m
++CONFIG_ATH9K_DEBUGFS=y
++CONFIG_ATH9K_HTC=m
++CONFIG_ATH9K_HTC_DEBUGFS=y
++CONFIG_ATH9K_HW=m
++CONFIG_ATH9K_LEGACY_RATE_CONTROL=y
++CONFIG_ATH9K_PCI=y
++CONFIG_ATH_CARDS=m
++CONFIG_ATH_COMMON=m
++# CONFIG_ATH_DEBUG is not set
++CONFIG_ATL1=m
++CONFIG_ATL1C=m
++CONFIG_ATL1E=m
++CONFIG_ATL2=m
++CONFIG_ATM=m
++CONFIG_ATMEL=m
++CONFIG_ATMEL_PWM=m
++CONFIG_ATMEL_SSC=m
++CONFIG_ATM_AMBASSADOR=m
++# CONFIG_ATM_AMBASSADOR_DEBUG is not set
++CONFIG_ATM_BR2684=m
++# CONFIG_ATM_BR2684_IPFILTER is not set
++CONFIG_ATM_CLIP=m
++# CONFIG_ATM_CLIP_NO_ICMP is not set
++CONFIG_ATM_DRIVERS=y
++CONFIG_ATM_DUMMY=m
++CONFIG_ATM_ENI=m
++# CONFIG_ATM_ENI_DEBUG is not set
++# CONFIG_ATM_ENI_TUNE_BURST is not set
++CONFIG_ATM_FIRESTREAM=m
++CONFIG_ATM_FORE200E=m
++CONFIG_ATM_FORE200E_DEBUG=0
++CONFIG_ATM_FORE200E_TX_RETRY=16
++# CONFIG_ATM_FORE200E_USE_TASKLET is not set
++CONFIG_ATM_HE=m
++CONFIG_ATM_HE_USE_SUNI=y
++CONFIG_ATM_HORIZON=m
++# CONFIG_ATM_HORIZON_DEBUG is not set
++CONFIG_ATM_IA=m
++# CONFIG_ATM_IA_DEBUG is not set
++CONFIG_ATM_IDT77252=m
++# CONFIG_ATM_IDT77252_DEBUG is not set
++# CONFIG_ATM_IDT77252_RCV_ALL is not set
++CONFIG_ATM_IDT77252_USE_SUNI=y
++CONFIG_ATM_LANAI=m
++CONFIG_ATM_LANE=m
++CONFIG_ATM_MPOA=m
++CONFIG_ATM_NICSTAR=m
++# CONFIG_ATM_NICSTAR_USE_IDT77105 is not set
++# CONFIG_ATM_NICSTAR_USE_SUNI is not set
++CONFIG_ATM_SOLOS=m
++CONFIG_ATM_TCP=m
++CONFIG_ATM_ZATM=m
++# CONFIG_ATM_ZATM_DEBUG is not set
++# CONFIG_ATOMIC64_SELFTEST is not set
++CONFIG_ATP=m
++CONFIG_AUDIT=y
++CONFIG_AUDITSYSCALL=y
++CONFIG_AUDIT_GENERIC=y
++# CONFIG_AUDIT_LOGINUID_IMMUTABLE is not set
++CONFIG_AUDIT_TREE=y
++CONFIG_AUDIT_WATCH=y
++CONFIG_AUFS_BDEV_LOOP=y
++# CONFIG_AUFS_BRANCH_MAX_1023 is not set
++CONFIG_AUFS_BRANCH_MAX_127=y
++# CONFIG_AUFS_BRANCH_MAX_32767 is not set
++# CONFIG_AUFS_BRANCH_MAX_511 is not set
++CONFIG_AUFS_BR_FUSE=y
++CONFIG_AUFS_BR_HFSPLUS=y
++CONFIG_AUFS_BR_RAMFS=y
++# CONFIG_AUFS_DEBUG is not set
++CONFIG_AUFS_EXPORT=y
++CONFIG_AUFS_FS=m
++# CONFIG_AUFS_HNOTIFY is not set
++CONFIG_AUFS_INO_T_64=y
++CONFIG_AUFS_POLL=y
++# CONFIG_AUFS_PROC_MAP is not set
++# CONFIG_AUFS_RDU is not set
++CONFIG_AUFS_SBILIST=y
++# CONFIG_AUFS_SHWH is not set
++# CONFIG_AUFS_SP_IATTR is not set
++CONFIG_AUTOFS4_FS=m
++CONFIG_AUTO_ZRELADDR=y
++CONFIG_AUXDISPLAY=y
++CONFIG_AVERAGE=y
++CONFIG_AX25=m
++CONFIG_AX25_DAMA_SLAVE=y
++CONFIG_AX88796=m
++# CONFIG_AX88796_93CX6 is not set
++CONFIG_B43=m
++CONFIG_B43LEGACY=m
++# CONFIG_B43LEGACY_DEBUG is not set
++CONFIG_B43LEGACY_DMA=y
++CONFIG_B43LEGACY_DMA_AND_PIO_MODE=y
++# CONFIG_B43LEGACY_DMA_MODE is not set
++CONFIG_B43LEGACY_HWRNG=y
++CONFIG_B43LEGACY_LEDS=y
++CONFIG_B43LEGACY_PCICORE_AUTOSELECT=y
++CONFIG_B43LEGACY_PCI_AUTOSELECT=y
++CONFIG_B43LEGACY_PIO=y
++# CONFIG_B43LEGACY_PIO_MODE is not set
++CONFIG_B43_BCMA=y
++CONFIG_B43_BCMA_PIO=y
++# CONFIG_B43_DEBUG is not set
++CONFIG_B43_HWRNG=y
++CONFIG_B43_LEDS=y
++CONFIG_B43_PCICORE_AUTOSELECT=y
++CONFIG_B43_PCI_AUTOSELECT=y
++# CONFIG_B43_PCMCIA is not set
++CONFIG_B43_PHY_HT=y
++CONFIG_B43_PHY_LP=y
++CONFIG_B43_PHY_N=y
++CONFIG_B43_PIO=y
++# CONFIG_B43_SDIO is not set
++CONFIG_B43_SSB=y
++CONFIG_B44=m
++CONFIG_B44_PCI=y
++CONFIG_B44_PCICORE_AUTOSELECT=y
++CONFIG_B44_PCI_AUTOSELECT=y
++CONFIG_BACKLIGHT_88PM860X=m
++CONFIG_BACKLIGHT_AAT2870=m
++CONFIG_BACKLIGHT_ADP5520=m
++CONFIG_BACKLIGHT_ADP8860=m
++CONFIG_BACKLIGHT_ADP8870=m
++CONFIG_BACKLIGHT_APPLE=m
++CONFIG_BACKLIGHT_AS3711=m
++CONFIG_BACKLIGHT_ATMEL_PWM=m
++CONFIG_BACKLIGHT_CARILLO_RANCH=m
++CONFIG_BACKLIGHT_CLASS_DEVICE=y
++CONFIG_BACKLIGHT_DA903X=m
++CONFIG_BACKLIGHT_DA9052=m
++CONFIG_BACKLIGHT_GENERIC=m
++CONFIG_BACKLIGHT_LCD_SUPPORT=y
++CONFIG_BACKLIGHT_LM3533=m
++CONFIG_BACKLIGHT_LM3630=m
++CONFIG_BACKLIGHT_LM3639=m
++CONFIG_BACKLIGHT_LP855X=m
++CONFIG_BACKLIGHT_LP8788=m
++CONFIG_BACKLIGHT_MAX8925=m
++CONFIG_BACKLIGHT_PANDORA=m
++CONFIG_BACKLIGHT_PCF50633=m
++CONFIG_BACKLIGHT_PWM=m
++CONFIG_BACKLIGHT_SAHARA=m
++CONFIG_BACKLIGHT_TPS65217=m
++CONFIG_BACKLIGHT_WM831X=m
++# CONFIG_BACKTRACE_SELF_TEST is not set
++CONFIG_BALLOON_COMPACTION=y
++CONFIG_BASE_FULL=y
++CONFIG_BASE_SMALL=0
++CONFIG_BATMAN_ADV=m
++CONFIG_BATMAN_ADV_BLA=y
++CONFIG_BATMAN_ADV_DAT=y
++# CONFIG_BATMAN_ADV_DEBUG is not set
++CONFIG_BATMAN_ADV_NC=y
++CONFIG_BATTERY_88PM860X=m
++CONFIG_BATTERY_BQ27X00_I2C=y
++CONFIG_BATTERY_BQ27X00_PLATFORM=y
++CONFIG_BATTERY_BQ27x00=m
++CONFIG_BATTERY_DA9030=m
++CONFIG_BATTERY_DA9052=m
++CONFIG_BATTERY_DS2760=m
++CONFIG_BATTERY_DS2780=m
++CONFIG_BATTERY_DS2781=m
++CONFIG_BATTERY_DS2782=m
++CONFIG_BATTERY_GOLDFISH=m
++CONFIG_BATTERY_INTEL_MID=m
++CONFIG_BATTERY_MAX17040=m
++CONFIG_BATTERY_MAX17042=m
++CONFIG_BATTERY_RX51=m
++CONFIG_BATTERY_SBS=m
++CONFIG_BAYCOM_EPP=m
++CONFIG_BAYCOM_PAR=m
++CONFIG_BAYCOM_SER_FDX=m
++CONFIG_BAYCOM_SER_HDX=m
++CONFIG_BCACHE=m
++# CONFIG_BCACHE_CLOSURES_DEBUG is not set
++# CONFIG_BCACHE_DEBUG is not set
++# CONFIG_BCACHE_EDEBUG is not set
++CONFIG_BCH_CONST_M=14
++CONFIG_BCH_CONST_PARAMS=y
++CONFIG_BCH_CONST_T=4
++CONFIG_BCM87XX_PHY=y
++CONFIG_BCMA=m
++CONFIG_BCMA_BLOCKIO=y
++# CONFIG_BCMA_DEBUG is not set
++CONFIG_BCMA_DRIVER_GMAC_CMN=y
++CONFIG_BCMA_DRIVER_GPIO=y
++CONFIG_BCMA_HOST_PCI=y
++CONFIG_BCMA_HOST_PCI_POSSIBLE=y
++CONFIG_BCMA_POSSIBLE=y
++CONFIG_BCM_WIMAX=m
++CONFIG_BE2ISCSI=m
++CONFIG_BE2NET=m
++# CONFIG_BEFS_DEBUG is not set
++CONFIG_BEFS_FS=m
++CONFIG_BFS_FS=m
++CONFIG_BINARY_PRINTF=y
++CONFIG_BINFMT_AOUT=m
++CONFIG_BINFMT_ELF=y
++CONFIG_BINFMT_MISC=m
++CONFIG_BINFMT_SCRIPT=y
++CONFIG_BITREVERSE=y
++CONFIG_BLK_CGROUP=y
++CONFIG_BLK_CPQ_CISS_DA=m
++CONFIG_BLK_CPQ_DA=m
++CONFIG_BLK_DEV=y
++CONFIG_BLK_DEV_3W_XXXX_RAID=m
++CONFIG_BLK_DEV_BSG=y
++CONFIG_BLK_DEV_BSGLIB=y
++# CONFIG_BLK_DEV_COW_COMMON is not set
++CONFIG_BLK_DEV_CRYPTOLOOP=m
++CONFIG_BLK_DEV_DAC960=m
++CONFIG_BLK_DEV_DM=y
++CONFIG_BLK_DEV_DRBD=m
++CONFIG_BLK_DEV_FD=m
++# CONFIG_BLK_DEV_HD is not set
++CONFIG_BLK_DEV_INITRD=y
++CONFIG_BLK_DEV_INTEGRITY=y
++CONFIG_BLK_DEV_IO_TRACE=y
++CONFIG_BLK_DEV_LOOP=y
++CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
++CONFIG_BLK_DEV_MD=y
++CONFIG_BLK_DEV_NBD=m
++CONFIG_BLK_DEV_NVME=m
++CONFIG_BLK_DEV_OSD=m
++CONFIG_BLK_DEV_PCIESSD_MTIP32XX=m
++CONFIG_BLK_DEV_RAM=y
++CONFIG_BLK_DEV_RAM_COUNT=16
++CONFIG_BLK_DEV_RAM_SIZE=65536
++CONFIG_BLK_DEV_RBD=m
++CONFIG_BLK_DEV_RSXX=m
++CONFIG_BLK_DEV_SD=y
++CONFIG_BLK_DEV_SR=y
++# CONFIG_BLK_DEV_SR_VENDOR is not set
++CONFIG_BLK_DEV_SX8=m
++CONFIG_BLK_DEV_THROTTLING=y
++CONFIG_BLK_DEV_UMEM=m
++# CONFIG_BLK_DEV_XIP is not set
++CONFIG_BLOCK=y
++CONFIG_BLOCK_COMPAT=y
++CONFIG_BMP085=y
++CONFIG_BMP085_I2C=m
++CONFIG_BMP085_SPI=m
++CONFIG_BNA=m
++CONFIG_BNX2=m
++CONFIG_BNX2X=m
++CONFIG_BNX2X_SRIOV=y
++CONFIG_BOARD_TPCI200=m
++CONFIG_BONDING=m
++# CONFIG_BOOTPARAM_HARDLOCKUP_PANIC is not set
++CONFIG_BOOTPARAM_HARDLOCKUP_PANIC_VALUE=0
++# CONFIG_BOOTPARAM_HOTPLUG_CPU0 is not set
++# CONFIG_BOOTPARAM_HUNG_TASK_PANIC is not set
++CONFIG_BOOTPARAM_HUNG_TASK_PANIC_VALUE=0
++# CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC is not set
++CONFIG_BOOTPARAM_SOFTLOCKUP_PANIC_VALUE=0
++CONFIG_BOOT_PRINTK_DELAY=y
++CONFIG_BOUNCE=y
++CONFIG_BPCTL=m
++CONFIG_BPF_JIT=y
++CONFIG_BPQETHER=m
++CONFIG_BQL=y
++CONFIG_BRANCH_PROFILE_NONE=y
++# CONFIG_BRCMDBG is not set
++CONFIG_BRCMFMAC=m
++CONFIG_BRCMFMAC_SDIO=y
++CONFIG_BRCMFMAC_USB=y
++CONFIG_BRCMSMAC=m
++CONFIG_BRCMUTIL=m
++CONFIG_BRCM_TRACING=y
++CONFIG_BRIDGE=m
++CONFIG_BRIDGE_EBT_802_3=m
++CONFIG_BRIDGE_EBT_AMONG=m
++CONFIG_BRIDGE_EBT_ARP=m
++CONFIG_BRIDGE_EBT_ARPREPLY=m
++CONFIG_BRIDGE_EBT_BROUTE=m
++CONFIG_BRIDGE_EBT_DNAT=m
++CONFIG_BRIDGE_EBT_IP=m
++CONFIG_BRIDGE_EBT_IP6=m
++CONFIG_BRIDGE_EBT_LIMIT=m
++CONFIG_BRIDGE_EBT_LOG=m
++CONFIG_BRIDGE_EBT_MARK=m
++CONFIG_BRIDGE_EBT_MARK_T=m
++CONFIG_BRIDGE_EBT_NFLOG=m
++CONFIG_BRIDGE_EBT_PKTTYPE=m
++CONFIG_BRIDGE_EBT_REDIRECT=m
++CONFIG_BRIDGE_EBT_SNAT=m
++CONFIG_BRIDGE_EBT_STP=m
++CONFIG_BRIDGE_EBT_T_FILTER=m
++CONFIG_BRIDGE_EBT_T_NAT=m
++# CONFIG_BRIDGE_EBT_ULOG is not set
++CONFIG_BRIDGE_EBT_VLAN=m
++CONFIG_BRIDGE_IGMP_SNOOPING=y
++CONFIG_BRIDGE_NETFILTER=y
++CONFIG_BRIDGE_NF_EBTABLES=m
++CONFIG_BRIDGE_VLAN_FILTERING=y
++CONFIG_BROADCOM_PHY=y
++CONFIG_BSD_DISKLABEL=y
++CONFIG_BSD_PROCESS_ACCT=y
++CONFIG_BSD_PROCESS_ACCT_V3=y
++CONFIG_BT=m
++CONFIG_BTREE=y
++# CONFIG_BTRFS_DEBUG is not set
++CONFIG_BTRFS_FS=m
++# CONFIG_BTRFS_FS_CHECK_INTEGRITY is not set
++CONFIG_BTRFS_FS_POSIX_ACL=y
++# CONFIG_BTRFS_FS_RUN_SANITY_TESTS is not set
++CONFIG_BT_ATH3K=m
++CONFIG_BT_BNEP=m
++CONFIG_BT_BNEP_MC_FILTER=y
++CONFIG_BT_BNEP_PROTO_FILTER=y
++CONFIG_BT_CMTP=m
++CONFIG_BT_HCIBCM203X=m
++CONFIG_BT_HCIBFUSB=m
++CONFIG_BT_HCIBLUECARD=m
++CONFIG_BT_HCIBPA10X=m
++CONFIG_BT_HCIBT3C=m
++CONFIG_BT_HCIBTSDIO=m
++CONFIG_BT_HCIBTUART=m
++CONFIG_BT_HCIBTUSB=m
++CONFIG_BT_HCIDTL1=m
++CONFIG_BT_HCIUART=m
++CONFIG_BT_HCIUART_3WIRE=y
++CONFIG_BT_HCIUART_ATH3K=y
++CONFIG_BT_HCIUART_BCSP=y
++CONFIG_BT_HCIUART_H4=y
++CONFIG_BT_HCIUART_LL=y
++CONFIG_BT_HCIVHCI=m
++CONFIG_BT_HIDP=m
++CONFIG_BT_MRVL=m
++CONFIG_BT_MRVL_SDIO=m
++CONFIG_BT_RFCOMM=m
++CONFIG_BT_RFCOMM_TTY=y
++CONFIG_BT_WILINK=m
++CONFIG_BUG=y
++CONFIG_BUILDTIME_EXTABLE_SORT=y
++CONFIG_C101=m
++CONFIG_C2PORT=m
++CONFIG_C2PORT_DURAMAR_2150=m
++CONFIG_CACHEFILES=m
++# CONFIG_CACHEFILES_DEBUG is not set
++# CONFIG_CACHEFILES_HISTOGRAM is not set
++CONFIG_CACHE_L2X0=y
++CONFIG_CACHE_PL310=y
++CONFIG_CAIF=m
++# CONFIG_CAIF_DEBUG is not set
++CONFIG_CAIF_HSI=m
++CONFIG_CAIF_NETDEV=m
++CONFIG_CAIF_SPI_SLAVE=m
++# CONFIG_CAIF_SPI_SYNC is not set
++CONFIG_CAIF_TTY=m
++CONFIG_CAIF_USB=m
++CONFIG_CAIF_VIRTIO=m
++CONFIG_CALGARY_IOMMU=y
++CONFIG_CALGARY_IOMMU_ENABLED_BY_DEFAULT=y
++CONFIG_CAN=m
++CONFIG_CAN_8DEV_USB=m
++CONFIG_CAN_AT91=m
++CONFIG_CAN_BCM=m
++CONFIG_CAN_CALC_BITTIMING=y
++CONFIG_CAN_CC770=m
++CONFIG_CAN_CC770_ISA=m
++CONFIG_CAN_CC770_PLATFORM=m
++CONFIG_CAN_C_CAN=m
++CONFIG_CAN_C_CAN_PCI=m
++CONFIG_CAN_C_CAN_PLATFORM=m
++# CONFIG_CAN_DEBUG_DEVICES is not set
++CONFIG_CAN_DEV=m
++CONFIG_CAN_EMS_PCI=m
++CONFIG_CAN_EMS_PCMCIA=m
++CONFIG_CAN_EMS_USB=m
++CONFIG_CAN_ESD_USB2=m
++# CONFIG_CAN_FLEXCAN is not set
++CONFIG_CAN_GRCAN=m
++CONFIG_CAN_GW=m
++CONFIG_CAN_JANZ_ICAN3=m
++CONFIG_CAN_KVASER_PCI=m
++CONFIG_CAN_KVASER_USB=m
++CONFIG_CAN_LEDS=y
++CONFIG_CAN_MCP251X=m
++CONFIG_CAN_PEAK_PCI=m
++CONFIG_CAN_PEAK_PCIEC=y
++CONFIG_CAN_PEAK_PCMCIA=m
++CONFIG_CAN_PEAK_USB=m
++CONFIG_CAN_PLX_PCI=m
++CONFIG_CAN_RAW=m
++CONFIG_CAN_SJA1000=m
++CONFIG_CAN_SJA1000_ISA=m
++CONFIG_CAN_SJA1000_OF_PLATFORM=m
++CONFIG_CAN_SJA1000_PLATFORM=m
++CONFIG_CAN_SLCAN=m
++CONFIG_CAN_SOFTING=m
++CONFIG_CAN_SOFTING_CS=m
++CONFIG_CAN_TI_HECC=m
++CONFIG_CAN_TSCAN1=m
++CONFIG_CAN_VCAN=m
++CONFIG_CAPI_AVM=y
++CONFIG_CAPI_EICON=y
++CONFIG_CAPI_TRACE=y
++CONFIG_CARDBUS=y
++CONFIG_CARDMAN_4000=m
++CONFIG_CARDMAN_4040=m
++CONFIG_CARL9170=m
++# CONFIG_CARL9170_DEBUGFS is not set
++CONFIG_CARL9170_HWRNG=y
++CONFIG_CARL9170_LEDS=y
++CONFIG_CARL9170_WPC=y
++# CONFIG_CARMINE_DRAM_CUSTOM is not set
++CONFIG_CASSINI=m
++CONFIG_CB710_CORE=m
++# CONFIG_CB710_DEBUG is not set
++CONFIG_CB710_DEBUG_ASSUMPTIONS=y
++# CONFIG_CC_OPTIMIZE_FOR_SIZE is not set
++CONFIG_CC_STACKPROTECTOR=y
++CONFIG_CDROM_PKTCDVD=m
++CONFIG_CDROM_PKTCDVD_BUFFERS=8
++# CONFIG_CDROM_PKTCDVD_WCACHE is not set
++CONFIG_CED1401=m
++CONFIG_CEPH_FS=m
++CONFIG_CEPH_LIB=m
++# CONFIG_CEPH_LIB_PRETTYDEBUG is not set
++CONFIG_CEPH_LIB_USE_DNS_RESOLVER=y
++CONFIG_CFAG12864B=m
++CONFIG_CFAG12864B_RATE=20
++CONFIG_CFG80211=m
++# CONFIG_CFG80211_CERTIFICATION_ONUS is not set
++CONFIG_CFG80211_DEBUGFS=y
++CONFIG_CFG80211_DEFAULT_PS=y
++# CONFIG_CFG80211_DEVELOPER_WARNINGS is not set
++# CONFIG_CFG80211_INTERNAL_REGDB is not set
++# CONFIG_CFG80211_REG_DEBUG is not set
++CONFIG_CFG80211_WEXT=y
++CONFIG_CFQ_GROUP_IOSCHED=y
++CONFIG_CFS_BANDWIDTH=y
++CONFIG_CGROUPS=y
++CONFIG_CGROUP_CPUACCT=y
++# CONFIG_CGROUP_DEBUG is not set
++CONFIG_CGROUP_DEVICE=y
++CONFIG_CGROUP_FREEZER=y
++CONFIG_CGROUP_HUGETLB=y
++CONFIG_CGROUP_PERF=y
++CONFIG_CGROUP_SCHED=y
++CONFIG_CHARGER_88PM860X=m
++CONFIG_CHARGER_BQ2415X=m
++CONFIG_CHARGER_GPIO=m
++CONFIG_CHARGER_ISP1704=m
++CONFIG_CHARGER_LP8727=m
++CONFIG_CHARGER_LP8788=m
++CONFIG_CHARGER_MANAGER=y
++CONFIG_CHARGER_MAX8903=m
++CONFIG_CHARGER_MAX8997=m
++CONFIG_CHARGER_MAX8998=m
++CONFIG_CHARGER_PCF50633=m
++CONFIG_CHARGER_SMB347=m
++CONFIG_CHARGER_TPS65090=m
++CONFIG_CHARGER_TWL4030=m
++CONFIG_CHECKPOINT_RESTORE=y
++CONFIG_CHECK_SIGNATURE=y
++CONFIG_CHELSIO_T1=m
++CONFIG_CHELSIO_T1_1G=y
++CONFIG_CHELSIO_T3=m
++CONFIG_CHELSIO_T4=m
++CONFIG_CHELSIO_T4VF=m
++CONFIG_CHROMEOS_LAPTOP=m
++CONFIG_CHR_DEV_OSST=m
++CONFIG_CHR_DEV_SCH=m
++CONFIG_CHR_DEV_SG=y
++CONFIG_CHR_DEV_ST=m
++CONFIG_CICADA_PHY=y
++CONFIG_CIFS=m
++CONFIG_CIFS_ACL=y
++CONFIG_CIFS_DEBUG=y
++# CONFIG_CIFS_DEBUG2 is not set
++CONFIG_CIFS_DFS_UPCALL=y
++CONFIG_CIFS_FSCACHE=y
++CONFIG_CIFS_POSIX=y
++CONFIG_CIFS_SMB2=y
++CONFIG_CIFS_STATS=y
++# CONFIG_CIFS_STATS2 is not set
++CONFIG_CIFS_UPCALL=y
++CONFIG_CIFS_WEAK_PW_HASH=y
++CONFIG_CIFS_XATTR=y
++CONFIG_CISS_SCSI_TAPE=y
++CONFIG_CLEANCACHE=y
++CONFIG_CLKBLD_I8253=y
++CONFIG_CLKDEV_LOOKUP=y
++CONFIG_CLKEVT_I8253=y
++CONFIG_CLKSRC_I8253=y
++CONFIG_CLKSRC_MMIO=y
++CONFIG_CLKSRC_OF=y
++CONFIG_CLK_TWL6040=m
++CONFIG_CLOCKSOURCE_WATCHDOG=y
++CONFIG_CLONE_BACKWARDS=y
++CONFIG_CLS_U32_MARK=y
++# CONFIG_CLS_U32_PERF is not set
++CONFIG_CLZ_TAB=y
++CONFIG_CMA=y
++CONFIG_CMA_ALIGNMENT=8
++CONFIG_CMA_AREAS=7
++# CONFIG_CMA_DEBUG is not set
++CONFIG_CMA_SIZE_MBYTES=16
++# CONFIG_CMA_SIZE_SEL_MAX is not set
++CONFIG_CMA_SIZE_SEL_MBYTES=y
++# CONFIG_CMA_SIZE_SEL_MIN is not set
++# CONFIG_CMA_SIZE_SEL_PERCENTAGE is not set
++CONFIG_CMDLINE=""
++# CONFIG_CMDLINE_BOOL is not set
++CONFIG_CNIC=m
++CONFIG_CODA_FS=m
++CONFIG_COMEDI=m
++CONFIG_COMEDI_8255=m
++CONFIG_COMEDI_8255_PCI=m
++CONFIG_COMEDI_ADDI_APCI_035=m
++CONFIG_COMEDI_ADDI_APCI_1032=m
++CONFIG_COMEDI_ADDI_APCI_1500=m
++CONFIG_COMEDI_ADDI_APCI_1516=m
++CONFIG_COMEDI_ADDI_APCI_1564=m
++CONFIG_COMEDI_ADDI_APCI_16XX=m
++CONFIG_COMEDI_ADDI_APCI_2032=m
++CONFIG_COMEDI_ADDI_APCI_2200=m
++CONFIG_COMEDI_ADDI_APCI_3120=m
++CONFIG_COMEDI_ADDI_APCI_3501=m
++CONFIG_COMEDI_ADDI_APCI_3XXX=m
++CONFIG_COMEDI_ADDI_WATCHDOG=m
++CONFIG_COMEDI_ADL_PCI6208=m
++CONFIG_COMEDI_ADL_PCI7X3X=m
++CONFIG_COMEDI_ADL_PCI8164=m
++CONFIG_COMEDI_ADL_PCI9111=m
++CONFIG_COMEDI_ADL_PCI9118=m
++CONFIG_COMEDI_ADQ12B=m
++CONFIG_COMEDI_ADV_PCI1710=m
++CONFIG_COMEDI_ADV_PCI1723=m
++CONFIG_COMEDI_ADV_PCI1724=m
++CONFIG_COMEDI_ADV_PCI_DIO=m
++CONFIG_COMEDI_AIO_AIO12_8=m
++CONFIG_COMEDI_AIO_IIRO_16=m
++CONFIG_COMEDI_AMPLC_DIO200=m
++CONFIG_COMEDI_AMPLC_DIO200_ISA=m
++CONFIG_COMEDI_AMPLC_DIO200_PCI=m
++CONFIG_COMEDI_AMPLC_PC236=m
++CONFIG_COMEDI_AMPLC_PC236_ISA=m
++CONFIG_COMEDI_AMPLC_PC236_PCI=m
++CONFIG_COMEDI_AMPLC_PC263_ISA=m
++CONFIG_COMEDI_AMPLC_PC263_PCI=m
++CONFIG_COMEDI_AMPLC_PCI224=m
++CONFIG_COMEDI_AMPLC_PCI230=m
++CONFIG_COMEDI_BOND=m
++CONFIG_COMEDI_C6XDIGIO=m
++CONFIG_COMEDI_CB_DAS16_CS=m
++CONFIG_COMEDI_CB_PCIDAS=m
++CONFIG_COMEDI_CB_PCIDAS64=m
++CONFIG_COMEDI_CB_PCIDDA=m
++CONFIG_COMEDI_CB_PCIMDAS=m
++CONFIG_COMEDI_CB_PCIMDDA=m
++CONFIG_COMEDI_CONTEC_PCI_DIO=m
++CONFIG_COMEDI_DAQBOARD2000=m
++CONFIG_COMEDI_DAS08=m
++CONFIG_COMEDI_DAS08_CS=m
++CONFIG_COMEDI_DAS08_ISA=m
++CONFIG_COMEDI_DAS08_PCI=m
++CONFIG_COMEDI_DAS16=m
++CONFIG_COMEDI_DAS16M1=m
++CONFIG_COMEDI_DAS1800=m
++CONFIG_COMEDI_DAS6402=m
++CONFIG_COMEDI_DAS800=m
++# CONFIG_COMEDI_DEBUG is not set
++CONFIG_COMEDI_DEFAULT_BUF_MAXSIZE_KB=20480
++CONFIG_COMEDI_DEFAULT_BUF_SIZE_KB=2048
++CONFIG_COMEDI_DMM32AT=m
++CONFIG_COMEDI_DT2801=m
++CONFIG_COMEDI_DT2811=m
++CONFIG_COMEDI_DT2814=m
++CONFIG_COMEDI_DT2815=m
++CONFIG_COMEDI_DT2817=m
++CONFIG_COMEDI_DT282X=m
++CONFIG_COMEDI_DT3000=m
++CONFIG_COMEDI_DT9812=m
++CONFIG_COMEDI_DYNA_PCI10XX=m
++CONFIG_COMEDI_FC=m
++CONFIG_COMEDI_FL512=m
++CONFIG_COMEDI_GSC_HPDI=m
++CONFIG_COMEDI_ICP_MULTI=m
++CONFIG_COMEDI_II_PCI20KC=m
++CONFIG_COMEDI_ISA_DRIVERS=y
++CONFIG_COMEDI_JR3_PCI=m
++CONFIG_COMEDI_KCOMEDILIB=m
++CONFIG_COMEDI_KE_COUNTER=m
++CONFIG_COMEDI_ME4000=m
++CONFIG_COMEDI_ME_DAQ=m
++CONFIG_COMEDI_MISC_DRIVERS=y
++CONFIG_COMEDI_MITE=m
++CONFIG_COMEDI_MPC624=m
++CONFIG_COMEDI_MULTIQ3=m
++CONFIG_COMEDI_NI_6527=m
++CONFIG_COMEDI_NI_65XX=m
++CONFIG_COMEDI_NI_660X=m
++CONFIG_COMEDI_NI_670X=m
++CONFIG_COMEDI_NI_ATMIO=m
++CONFIG_COMEDI_NI_ATMIO16D=m
++CONFIG_COMEDI_NI_AT_A2150=m
++CONFIG_COMEDI_NI_AT_AO=m
++CONFIG_COMEDI_NI_DAQ_700_CS=m
++CONFIG_COMEDI_NI_DAQ_DIO24_CS=m
++CONFIG_COMEDI_NI_LABPC=m
++CONFIG_COMEDI_NI_LABPC_CS=m
++CONFIG_COMEDI_NI_LABPC_ISA=m
++CONFIG_COMEDI_NI_LABPC_PCI=m
++CONFIG_COMEDI_NI_MIO_CS=m
++CONFIG_COMEDI_NI_PCIDIO=m
++CONFIG_COMEDI_NI_PCIMIO=m
++CONFIG_COMEDI_NI_TIO=m
++CONFIG_COMEDI_NI_TIOCMD=m
++CONFIG_COMEDI_PARPORT=m
++CONFIG_COMEDI_PCI_DRIVERS=y
++CONFIG_COMEDI_PCL711=m
++CONFIG_COMEDI_PCL724=m
++CONFIG_COMEDI_PCL726=m
++CONFIG_COMEDI_PCL730=m
++CONFIG_COMEDI_PCL812=m
++CONFIG_COMEDI_PCL816=m
++CONFIG_COMEDI_PCL818=m
++CONFIG_COMEDI_PCM3724=m
++CONFIG_COMEDI_PCMAD=m
++CONFIG_COMEDI_PCMCIA_DRIVERS=y
++CONFIG_COMEDI_PCMDA12=m
++CONFIG_COMEDI_PCMMIO=m
++CONFIG_COMEDI_PCMUIO=m
++CONFIG_COMEDI_POC=m
++CONFIG_COMEDI_QUATECH_DAQP_CS=m
++CONFIG_COMEDI_RTD520=m
++CONFIG_COMEDI_RTI800=m
++CONFIG_COMEDI_RTI802=m
++CONFIG_COMEDI_S526=m
++CONFIG_COMEDI_S626=m
++CONFIG_COMEDI_SERIAL2002=m
++CONFIG_COMEDI_SKEL=m
++CONFIG_COMEDI_SSV_DNP=m
++CONFIG_COMEDI_TEST=m
++CONFIG_COMEDI_UNIOXX5=m
++CONFIG_COMEDI_USBDUX=m
++CONFIG_COMEDI_USBDUXFAST=m
++CONFIG_COMEDI_USBDUXSIGMA=m
++CONFIG_COMEDI_USB_DRIVERS=y
++CONFIG_COMEDI_VMK80XX=m
++CONFIG_COMMON_CLK=y
++# CONFIG_COMMON_CLK_DEBUG is not set
++CONFIG_COMMON_CLK_MAX77686=m
++CONFIG_COMMON_CLK_SI5351=m
++CONFIG_COMMON_CLK_VERSATILE=y
++CONFIG_COMMON_CLK_WM831X=m
++CONFIG_COMPAL_LAPTOP=m
++CONFIG_COMPAT=y
++CONFIG_COMPAT_BINFMT_ELF=y
++# CONFIG_COMPAT_BRK is not set
++CONFIG_COMPAT_FOR_U64_ALIGNMENT=y
++CONFIG_COMPAT_NETLINK_MESSAGES=y
++CONFIG_COMPAT_OLD_SIGACTION=y
++# CONFIG_COMPAT_VDSO is not set
++# CONFIG_COMPILE_TEST is not set
++CONFIG_CONFIGFS_FS=m
++CONFIG_CONNECTOR=y
++CONFIG_CONSOLE_POLL=y
++CONFIG_CONSOLE_TRANSLATIONS=y
++CONFIG_CONTEXT_SWITCH_TRACER=y
++CONFIG_CONTEXT_TRACKING=y
++# CONFIG_CONTEXT_TRACKING_FORCE is not set
++CONFIG_COPS=m
++CONFIG_COPS_DAYNA=y
++CONFIG_COPS_TANGENT=y
++CONFIG_CORDIC=m
++CONFIG_COREDUMP=y
++CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
++CONFIG_COSA=m
++# CONFIG_CPA_DEBUG is not set
++CONFIG_CPU5_WDT=m
++CONFIG_CPUSETS=y
++CONFIG_CPU_32v6K=y
++CONFIG_CPU_32v7=y
++CONFIG_CPU_ABRT_EV7=y
++# CONFIG_CPU_BPREDICT_DISABLE is not set
++CONFIG_CPU_CACHE_V7=y
++CONFIG_CPU_CACHE_VIPT=y
++CONFIG_CPU_COPY_V6=y
++CONFIG_CPU_CP15=y
++CONFIG_CPU_CP15_MMU=y
++# CONFIG_CPU_DCACHE_DISABLE is not set
++# CONFIG_CPU_FREQ_DEFAULT_GOV_CONSERVATIVE is not set
++# CONFIG_CPU_FREQ_DEFAULT_GOV_ONDEMAND is not set
++CONFIG_CPU_FREQ_DEFAULT_GOV_PERFORMANCE=y
++# CONFIG_CPU_FREQ_DEFAULT_GOV_POWERSAVE is not set
++# CONFIG_CPU_FREQ_DEFAULT_GOV_USERSPACE is not set
++CONFIG_CPU_FREQ_GOV_COMMON=y
++CONFIG_CPU_FREQ_GOV_CONSERVATIVE=y
++CONFIG_CPU_FREQ_GOV_ONDEMAND=y
++CONFIG_CPU_FREQ_GOV_PERFORMANCE=y
++CONFIG_CPU_FREQ_GOV_POWERSAVE=y
++CONFIG_CPU_FREQ_GOV_USERSPACE=y
++CONFIG_CPU_FREQ_STAT=y
++CONFIG_CPU_FREQ_STAT_DETAILS=y
++CONFIG_CPU_FREQ_TABLE=y
++CONFIG_CPU_HAS_ASID=y
++# CONFIG_CPU_ICACHE_DISABLE is not set
++CONFIG_CPU_IDLE=y
++CONFIG_CPU_IDLE_GOV_LADDER=y
++CONFIG_CPU_IDLE_GOV_MENU=y
++CONFIG_CPU_IDLE_MULTIPLE_DRIVERS=y
++CONFIG_CPU_NOTIFIER_ERROR_INJECT=m
++CONFIG_CPU_PABRT_V7=y
++CONFIG_CPU_PM=y
++CONFIG_CPU_RMAP=y
++CONFIG_CPU_SUP_AMD=y
++CONFIG_CPU_SUP_CENTAUR=y
++CONFIG_CPU_SUP_CYRIX_32=y
++CONFIG_CPU_SUP_INTEL=y
++CONFIG_CPU_SUP_TRANSMETA_32=y
++CONFIG_CPU_SUP_UMC_32=y
++CONFIG_CPU_THERMAL=y
++CONFIG_CPU_TLB_V7=y
++CONFIG_CPU_V7=y
++CONFIG_CRAMFS=m
++CONFIG_CRASH_DUMP=y
++CONFIG_CRC16=y
++CONFIG_CRC32=y
++# CONFIG_CRC32_BIT is not set
++# CONFIG_CRC32_SARWATE is not set
++# CONFIG_CRC32_SELFTEST is not set
++# CONFIG_CRC32_SLICEBY4 is not set
++CONFIG_CRC32_SLICEBY8=y
++CONFIG_CRC7=m
++CONFIG_CRC8=m
++CONFIG_CRC_CCITT=m
++CONFIG_CRC_ITU_T=m
++CONFIG_CRC_T10DIF=y
++CONFIG_CROSS_COMPILE=""
++CONFIG_CROSS_MEMORY_ATTACH=y
++CONFIG_CRYPTO=y
++CONFIG_CRYPTO_ABLK_HELPER_X86=m
++CONFIG_CRYPTO_AEAD=m
++CONFIG_CRYPTO_AEAD2=y
++CONFIG_CRYPTO_AES=y
++CONFIG_CRYPTO_AES_586=m
++CONFIG_CRYPTO_AES_ARM=m
++CONFIG_CRYPTO_AES_NI_INTEL=m
++CONFIG_CRYPTO_AES_X86_64=m
++CONFIG_CRYPTO_ALGAPI=y
++CONFIG_CRYPTO_ALGAPI2=y
++CONFIG_CRYPTO_ANSI_CPRNG=m
++CONFIG_CRYPTO_ANUBIS=m
++CONFIG_CRYPTO_ARC4=m
++CONFIG_CRYPTO_AUTHENC=m
++CONFIG_CRYPTO_BLKCIPHER=y
++CONFIG_CRYPTO_BLKCIPHER2=y
++CONFIG_CRYPTO_BLOWFISH=m
++CONFIG_CRYPTO_BLOWFISH_COMMON=m
++CONFIG_CRYPTO_BLOWFISH_X86_64=m
++CONFIG_CRYPTO_CAMELLIA=m
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX2_X86_64=m
++CONFIG_CRYPTO_CAMELLIA_AESNI_AVX_X86_64=m
++CONFIG_CRYPTO_CAMELLIA_X86_64=m
++CONFIG_CRYPTO_CAST5=m
++CONFIG_CRYPTO_CAST5_AVX_X86_64=m
++CONFIG_CRYPTO_CAST6=m
++CONFIG_CRYPTO_CAST6_AVX_X86_64=m
++CONFIG_CRYPTO_CAST_COMMON=m
++CONFIG_CRYPTO_CBC=y
++CONFIG_CRYPTO_CCM=m
++CONFIG_CRYPTO_CMAC=m
++CONFIG_CRYPTO_CRC32=m
++CONFIG_CRYPTO_CRC32C=y
++CONFIG_CRYPTO_CRC32C_INTEL=y
++CONFIG_CRYPTO_CRC32_PCLMUL=m
++CONFIG_CRYPTO_CRCT10DIF=y
++CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
++CONFIG_CRYPTO_CRYPTD=m
++CONFIG_CRYPTO_CTR=m
++CONFIG_CRYPTO_CTS=m
++CONFIG_CRYPTO_DEFLATE=m
++CONFIG_CRYPTO_DES=m
++CONFIG_CRYPTO_DEV_GEODE=m
++CONFIG_CRYPTO_DEV_HIFN_795X=m
++CONFIG_CRYPTO_DEV_HIFN_795X_RNG=y
++CONFIG_CRYPTO_DEV_OMAP_AES=m
++CONFIG_CRYPTO_DEV_OMAP_SHAM=m
++CONFIG_CRYPTO_DEV_PADLOCK=y
++CONFIG_CRYPTO_DEV_PADLOCK_AES=m
++CONFIG_CRYPTO_DEV_PADLOCK_SHA=m
++CONFIG_CRYPTO_DEV_SAHARA=m
++CONFIG_CRYPTO_DEV_TEGRA_AES=m
++CONFIG_CRYPTO_ECB=y
++CONFIG_CRYPTO_FCRYPT=m
++CONFIG_CRYPTO_GCM=m
++CONFIG_CRYPTO_GF128MUL=m
++CONFIG_CRYPTO_GHASH=m
++CONFIG_CRYPTO_GHASH_CLMUL_NI_INTEL=m
++CONFIG_CRYPTO_GLUE_HELPER_X86=m
++CONFIG_CRYPTO_HASH=y
++CONFIG_CRYPTO_HASH2=y
++CONFIG_CRYPTO_HMAC=y
++CONFIG_CRYPTO_HW=y
++CONFIG_CRYPTO_KHAZAD=m
++CONFIG_CRYPTO_LRW=m
++CONFIG_CRYPTO_LZ4=m
++CONFIG_CRYPTO_LZ4HC=m
++CONFIG_CRYPTO_LZO=y
++CONFIG_CRYPTO_MANAGER=y
++CONFIG_CRYPTO_MANAGER2=y
++CONFIG_CRYPTO_MANAGER_DISABLE_TESTS=y
++CONFIG_CRYPTO_MD4=m
++CONFIG_CRYPTO_MD5=y
++CONFIG_CRYPTO_MICHAEL_MIC=m
++CONFIG_CRYPTO_NULL=m
++CONFIG_CRYPTO_PCBC=m
++CONFIG_CRYPTO_PCOMP=m
++CONFIG_CRYPTO_PCOMP2=y
++CONFIG_CRYPTO_PCRYPT=m
++CONFIG_CRYPTO_RMD128=m
++CONFIG_CRYPTO_RMD160=m
++CONFIG_CRYPTO_RMD256=m
++CONFIG_CRYPTO_RMD320=m
++CONFIG_CRYPTO_RNG=y
++CONFIG_CRYPTO_RNG2=y
++CONFIG_CRYPTO_SALSA20=m
++CONFIG_CRYPTO_SALSA20_586=m
++CONFIG_CRYPTO_SALSA20_X86_64=m
++CONFIG_CRYPTO_SEED=m
++CONFIG_CRYPTO_SEQIV=m
++CONFIG_CRYPTO_SERPENT=m
++CONFIG_CRYPTO_SERPENT_AVX2_X86_64=m
++CONFIG_CRYPTO_SERPENT_AVX_X86_64=m
++CONFIG_CRYPTO_SERPENT_SSE2_586=m
++CONFIG_CRYPTO_SERPENT_SSE2_X86_64=m
++CONFIG_CRYPTO_SHA1=y
++CONFIG_CRYPTO_SHA1_ARM=m
++CONFIG_CRYPTO_SHA1_SSSE3=m
++CONFIG_CRYPTO_SHA256=y
++CONFIG_CRYPTO_SHA256_SSSE3=m
++CONFIG_CRYPTO_SHA512=y
++CONFIG_CRYPTO_SHA512_SSSE3=m
++CONFIG_CRYPTO_TEA=m
++CONFIG_CRYPTO_TEST=m
++CONFIG_CRYPTO_TGR192=m
++CONFIG_CRYPTO_TWOFISH=m
++CONFIG_CRYPTO_TWOFISH_586=m
++CONFIG_CRYPTO_TWOFISH_AVX_X86_64=m
++CONFIG_CRYPTO_TWOFISH_COMMON=m
++CONFIG_CRYPTO_TWOFISH_X86_64=m
++CONFIG_CRYPTO_TWOFISH_X86_64_3WAY=m
++CONFIG_CRYPTO_USER=m
++CONFIG_CRYPTO_USER_API=m
++CONFIG_CRYPTO_USER_API_HASH=m
++CONFIG_CRYPTO_USER_API_SKCIPHER=m
++CONFIG_CRYPTO_VMAC=m
++CONFIG_CRYPTO_WORKQUEUE=y
++CONFIG_CRYPTO_WP512=m
++CONFIG_CRYPTO_XCBC=m
++CONFIG_CRYPTO_XTS=m
++CONFIG_CRYPTO_ZLIB=m
++CONFIG_CRYSTALHD=m
++# CONFIG_CS5535_MFGPT is not set
++CONFIG_CS89x0=m
++CONFIG_CS89x0_PLATFORM=y
++CONFIG_CUSE=m
++CONFIG_CW1200=m
++CONFIG_CW1200_WLAN_SDIO=m
++CONFIG_CW1200_WLAN_SPI=m
++CONFIG_CXT1E1=m
++CONFIG_CYCLADES=m
++CONFIG_CYPRESS_FIRMWARE=m
++# CONFIG_CYZ_INTR is not set
++CONFIG_DA9052_WATCHDOG=m
++CONFIG_DA9055_WATCHDOG=m
++CONFIG_DAVICOM_PHY=y
++CONFIG_DCA=m
++CONFIG_DCACHE_WORD_ACCESS=y
++CONFIG_DCB=y
++CONFIG_DCDBAS=m
++CONFIG_DDR=y
++CONFIG_DE2104X=m
++CONFIG_DE2104X_DSL=0
++CONFIG_DE4X5=m
++# CONFIG_DEBUG_ATOMIC_SLEEP is not set
++# CONFIG_DEBUG_BLK_CGROUP is not set
++# CONFIG_DEBUG_BLOCK_EXT_DEVT is not set
++# CONFIG_DEBUG_BOOT_PARAMS is not set
++# CONFIG_DEBUG_BUGVERBOSE is not set
++# CONFIG_DEBUG_CREDENTIALS is not set
++# CONFIG_DEBUG_DEVRES is not set
++# CONFIG_DEBUG_DRIVER is not set
++# CONFIG_DEBUG_FORCE_WEAK_PER_CPU is not set
++CONFIG_DEBUG_FS=y
++# CONFIG_DEBUG_GPIO is not set
++# CONFIG_DEBUG_HIGHMEM is not set
++# CONFIG_DEBUG_HOTPLUG_CPU0 is not set
++CONFIG_DEBUG_IMX_UART_PORT=1
++CONFIG_DEBUG_INFO=y
++# CONFIG_DEBUG_INFO_REDUCED is not set
++CONFIG_DEBUG_KERNEL=y
++# CONFIG_DEBUG_KMEMLEAK is not set
++# CONFIG_DEBUG_KOBJECT is not set
++# CONFIG_DEBUG_LIST is not set
++# CONFIG_DEBUG_LL is not set
++CONFIG_DEBUG_LL_INCLUDE="mach/debug-macro.S"
++# CONFIG_DEBUG_LOCKING_API_SELFTESTS is not set
++# CONFIG_DEBUG_LOCK_ALLOC is not set
++# CONFIG_DEBUG_MEMORY_INIT is not set
++# CONFIG_DEBUG_MUTEXES is not set
++# CONFIG_DEBUG_NMI_SELFTEST is not set
++# CONFIG_DEBUG_NOTIFIERS is not set
++# CONFIG_DEBUG_NX_TEST is not set
++# CONFIG_DEBUG_OBJECTS is not set
++# CONFIG_DEBUG_PAGEALLOC is not set
++# CONFIG_DEBUG_PERF_USE_VMALLOC is not set
++# CONFIG_DEBUG_PER_CPU_MAPS is not set
++# CONFIG_DEBUG_PINCTRL is not set
++CONFIG_DEBUG_RODATA=y
++# CONFIG_DEBUG_RODATA_TEST is not set
++# CONFIG_DEBUG_RT_MUTEXES is not set
++# CONFIG_DEBUG_SECTION_MISMATCH is not set
++CONFIG_DEBUG_SET_MODULE_RONX=y
++# CONFIG_DEBUG_SG is not set
++# CONFIG_DEBUG_SHIRQ is not set
++# CONFIG_DEBUG_SPINLOCK is not set
++# CONFIG_DEBUG_STACKOVERFLOW is not set
++# CONFIG_DEBUG_STACK_USAGE is not set
++# CONFIG_DEBUG_STRICT_USER_COPY_CHECKS is not set
++# CONFIG_DEBUG_TLBFLUSH is not set
++# CONFIG_DEBUG_USER is not set
++# CONFIG_DEBUG_VIRTUAL is not set
++# CONFIG_DEBUG_VM is not set
++# CONFIG_DEBUG_WRITECOUNT is not set
++# CONFIG_DEBUG_WW_MUTEX_SLOWPATH is not set
++CONFIG_DECNET=m
++CONFIG_DECNET_NF_GRABULATOR=m
++# CONFIG_DECNET_ROUTER is not set
++CONFIG_DECOMPRESS_BZIP2=y
++CONFIG_DECOMPRESS_GZIP=y
++CONFIG_DECOMPRESS_LZ4=y
++CONFIG_DECOMPRESS_LZMA=y
++CONFIG_DECOMPRESS_LZO=y
++CONFIG_DECOMPRESS_XZ=y
++# CONFIG_DEFAULT_CFQ is not set
++CONFIG_DEFAULT_CUBIC=y
++CONFIG_DEFAULT_DEADLINE=y
++CONFIG_DEFAULT_HOSTNAME="(none)"
++CONFIG_DEFAULT_HUNG_TASK_TIMEOUT=120
++CONFIG_DEFAULT_IOSCHED="deadline"
++CONFIG_DEFAULT_IO_DELAY_TYPE=1
++CONFIG_DEFAULT_MESSAGE_LOGLEVEL=4
++# CONFIG_DEFAULT_NOOP is not set
++# CONFIG_DEFAULT_RENO is not set
++CONFIG_DEFAULT_SECURITY="apparmor"
++CONFIG_DEFAULT_SECURITY_APPARMOR=y
++# CONFIG_DEFAULT_SECURITY_DAC is not set
++# CONFIG_DEFAULT_SECURITY_SELINUX is not set
++# CONFIG_DEFAULT_SECURITY_SMACK is not set
++# CONFIG_DEFAULT_SECURITY_TOMOYO is not set
++# CONFIG_DEFAULT_SECURITY_YAMA is not set
++CONFIG_DEFAULT_TCP_CONG="cubic"
++CONFIG_DEFCONFIG_LIST="/lib/modules/$UNAME_RELEASE/.config"
++CONFIG_DEFXX=m
++# CONFIG_DEFXX_MMIO is not set
++CONFIG_DELL_LAPTOP=m
++CONFIG_DELL_RBU=m
++CONFIG_DELL_WMI=m
++CONFIG_DELL_WMI_AIO=m
++# CONFIG_DEPRECATED_PARAM_STRUCT is not set
++CONFIG_DETECT_HUNG_TASK=y
++CONFIG_DEVFREQ_GOV_PERFORMANCE=y
++CONFIG_DEVFREQ_GOV_POWERSAVE=y
++CONFIG_DEVFREQ_GOV_SIMPLE_ONDEMAND=y
++CONFIG_DEVFREQ_GOV_USERSPACE=y
++# CONFIG_DEVKMEM is not set
++CONFIG_DEVPORT=y
++CONFIG_DEVPTS_MULTIPLE_INSTANCES=y
++CONFIG_DEVTMPFS=y
++CONFIG_DEVTMPFS_MOUNT=y
++CONFIG_DEV_APPLETALK=m
++CONFIG_DE_AOC=y
++CONFIG_DGRP=m
++CONFIG_DIRECT_GBPAGES=y
++CONFIG_DISPLAY_CONNECTOR_ANALOG_TV=m
++CONFIG_DISPLAY_CONNECTOR_DVI=m
++CONFIG_DISPLAY_CONNECTOR_HDMI=m
++CONFIG_DISPLAY_ENCODER_TFP410=m
++CONFIG_DISPLAY_ENCODER_TPD12S015=m
++CONFIG_DISPLAY_PANEL_DPI=m
++CONFIG_DISPLAY_PANEL_DSI_CM=m
++CONFIG_DISPLAY_PANEL_LGPHILIPS_LB035Q02=m
++CONFIG_DISPLAY_PANEL_NEC_NL8048HL11=m
++CONFIG_DISPLAY_PANEL_SHARP_LS037V7DW01=m
++CONFIG_DISPLAY_PANEL_SONY_ACX565AKM=m
++CONFIG_DISPLAY_PANEL_TPO_TD043MTEA1=m
++CONFIG_DL2K=m
++CONFIG_DLCI=m
++CONFIG_DLCI_MAX=8
++CONFIG_DLM=m
++# CONFIG_DLM_DEBUG is not set
++CONFIG_DM9000=m
++# CONFIG_DM9000_FORCE_SIMPLE_PHY_POLL is not set
++CONFIG_DM9102=m
++CONFIG_DMADEVICES=y
++# CONFIG_DMADEVICES_DEBUG is not set
++CONFIG_DMAR_TABLE=y
++# CONFIG_DMATEST is not set
++CONFIG_DMA_ACPI=y
++# CONFIG_DMA_API_DEBUG is not set
++CONFIG_DMA_ENGINE=y
++CONFIG_DMA_OF=y
++CONFIG_DMA_OMAP=y
++CONFIG_DMA_SHARED_BUFFER=y
++CONFIG_DMA_VIRTUAL_CHANNELS=y
++CONFIG_DMI=y
++CONFIG_DMIID=y
++CONFIG_DMI_SYSFS=m
++CONFIG_DM_BIO_PRISON=m
++CONFIG_DM_BUFIO=m
++CONFIG_DM_CACHE=m
++CONFIG_DM_CACHE_CLEANER=m
++CONFIG_DM_CACHE_MQ=m
++CONFIG_DM_CRYPT=m
++# CONFIG_DM_DEBUG is not set
++# CONFIG_DM_DEBUG_BLOCK_STACK_TRACING is not set
++CONFIG_DM_DELAY=m
++CONFIG_DM_FLAKEY=m
++CONFIG_DM_LOG_USERSPACE=m
++CONFIG_DM_MIRROR=m
++CONFIG_DM_MULTIPATH=m
++CONFIG_DM_MULTIPATH_QL=m
++CONFIG_DM_MULTIPATH_ST=m
++CONFIG_DM_PERSISTENT_DATA=m
++CONFIG_DM_RAID=m
++CONFIG_DM_RAID45=m
++CONFIG_DM_SNAPSHOT=m
++CONFIG_DM_SWITCH=m
++CONFIG_DM_THIN_PROVISIONING=m
++CONFIG_DM_UEVENT=y
++CONFIG_DM_VERITY=m
++CONFIG_DM_ZERO=m
++CONFIG_DNET=m
++CONFIG_DNOTIFY=y
++CONFIG_DNS_RESOLVER=y
++CONFIG_DONGLE=y
++CONFIG_DOUBLEFAULT=y
++CONFIG_DQL=y
++CONFIG_DRAGONRISE_FF=y
++# CONFIG_DRBD_FAULT_INJECTION is not set
++CONFIG_DRM=m
++CONFIG_DRM_AST=m
++CONFIG_DRM_CIRRUS_QEMU=m
++# CONFIG_DRM_EXYNOS is not set
++CONFIG_DRM_GEM_CMA_HELPER=y
++CONFIG_DRM_GMA3600=y
++CONFIG_DRM_GMA500=m
++CONFIG_DRM_GMA600=y
++CONFIG_DRM_I2C_CH7006=m
++CONFIG_DRM_I2C_NXP_TDA998X=m
++CONFIG_DRM_I2C_SIL164=m
++CONFIG_DRM_I810=m
++CONFIG_DRM_I915=m
++CONFIG_DRM_I915_KMS=y
++# CONFIG_DRM_IMX is not set
++CONFIG_DRM_KMS_CMA_HELPER=y
++CONFIG_DRM_KMS_HELPER=m
++CONFIG_DRM_LOAD_EDID_FIRMWARE=y
++# CONFIG_DRM_MEDFIELD is not set
++CONFIG_DRM_MGA=m
++# CONFIG_DRM_MGAG200 is not set
++CONFIG_DRM_NOUVEAU=m
++CONFIG_DRM_NOUVEAU_BACKLIGHT=y
++# CONFIG_DRM_OMAP is not set
++CONFIG_DRM_QXL=m
++CONFIG_DRM_R128=m
++CONFIG_DRM_RADEON=m
++CONFIG_DRM_RADEON_UMS=y
++CONFIG_DRM_RCAR_DU=m
++CONFIG_DRM_SAVAGE=m
++CONFIG_DRM_SHMOBILE=m
++CONFIG_DRM_SIS=m
++CONFIG_DRM_TDFX=m
++CONFIG_DRM_TEGRA=y
++# CONFIG_DRM_TEGRA_DEBUG is not set
++CONFIG_DRM_TEGRA_STAGING=y
++# CONFIG_DRM_TILCDC is not set
++CONFIG_DRM_TTM=m
++CONFIG_DRM_UDL=m
++CONFIG_DRM_USB=m
++CONFIG_DRM_VIA=m
++CONFIG_DRM_VMWGFX=m
++# CONFIG_DRM_VMWGFX_FBCON is not set
++CONFIG_DS1682=m
++CONFIG_DSCC4=m
++CONFIG_DSCC4_PCISYNC=y
++CONFIG_DSCC4_PCI_RST=y
++# CONFIG_DT3155_CCIR is not set
++CONFIG_DT3155_STREAMING=y
++CONFIG_DTC=y
++CONFIG_DTLK=m
++CONFIG_DUMMY=m
++CONFIG_DUMMY_CONSOLE=y
++CONFIG_DUMMY_IRQ=m
++CONFIG_DVB_A8293=m
++CONFIG_DVB_AF9013=m
++CONFIG_DVB_AF9033=m
++CONFIG_DVB_AS102=m
++CONFIG_DVB_ATBM8830=m
++CONFIG_DVB_AU8522=m
++CONFIG_DVB_AU8522_DTV=m
++CONFIG_DVB_AU8522_V4L=m
++CONFIG_DVB_AV7110=m
++CONFIG_DVB_AV7110_OSD=y
++CONFIG_DVB_B2C2_FLEXCOP=m
++CONFIG_DVB_B2C2_FLEXCOP_PCI=m
++# CONFIG_DVB_B2C2_FLEXCOP_PCI_DEBUG is not set
++CONFIG_DVB_B2C2_FLEXCOP_USB=m
++# CONFIG_DVB_B2C2_FLEXCOP_USB_DEBUG is not set
++CONFIG_DVB_BCM3510=m
++CONFIG_DVB_BT8XX=m
++CONFIG_DVB_BUDGET=m
++CONFIG_DVB_BUDGET_AV=m
++CONFIG_DVB_BUDGET_CI=m
++CONFIG_DVB_BUDGET_CORE=m
++CONFIG_DVB_BUDGET_PATCH=m
++CONFIG_DVB_CORE=m
++CONFIG_DVB_CX22700=m
++CONFIG_DVB_CX22702=m
++CONFIG_DVB_CX24110=m
++CONFIG_DVB_CX24116=m
++CONFIG_DVB_CX24123=m
++CONFIG_DVB_CXD2099=m
++CONFIG_DVB_CXD2820R=m
++CONFIG_DVB_DDBRIDGE=m
++CONFIG_DVB_DIB3000MB=m
++CONFIG_DVB_DIB3000MC=m
++CONFIG_DVB_DIB7000M=m
++CONFIG_DVB_DIB7000P=m
++CONFIG_DVB_DIB8000=m
++CONFIG_DVB_DM1105=m
++CONFIG_DVB_DRXD=m
++CONFIG_DVB_DRXK=m
++CONFIG_DVB_DS3000=m
++# CONFIG_DVB_DUMMY_FE is not set
++CONFIG_DVB_DYNAMIC_MINORS=y
++CONFIG_DVB_EC100=m
++CONFIG_DVB_FIREDTV=m
++CONFIG_DVB_FIREDTV_INPUT=y
++CONFIG_DVB_HOPPER=m
++CONFIG_DVB_ISL6405=m
++CONFIG_DVB_ISL6421=m
++CONFIG_DVB_ISL6423=m
++CONFIG_DVB_IT913X_FE=m
++CONFIG_DVB_IX2505V=m
++CONFIG_DVB_L64781=m
++CONFIG_DVB_LG2160=m
++CONFIG_DVB_LGDT3305=m
++CONFIG_DVB_LGDT330X=m
++CONFIG_DVB_LGS8GXX=m
++CONFIG_DVB_LNBP21=m
++CONFIG_DVB_LNBP22=m
++CONFIG_DVB_M88RS2000=m
++CONFIG_DVB_MANTIS=m
++CONFIG_DVB_MAX_ADAPTERS=8
++CONFIG_DVB_MB86A16=m
++CONFIG_DVB_MB86A20S=m
++CONFIG_DVB_MT312=m
++CONFIG_DVB_MT352=m
++CONFIG_DVB_NET=y
++CONFIG_DVB_NGENE=m
++CONFIG_DVB_NXT200X=m
++CONFIG_DVB_NXT6000=m
++CONFIG_DVB_OR51132=m
++CONFIG_DVB_OR51211=m
++CONFIG_DVB_PLL=m
++CONFIG_DVB_PLUTO2=m
++CONFIG_DVB_PT1=m
++CONFIG_DVB_RTL2830=m
++CONFIG_DVB_RTL2832=m
++CONFIG_DVB_S5H1409=m
++CONFIG_DVB_S5H1411=m
++CONFIG_DVB_S5H1420=m
++CONFIG_DVB_S921=m
++CONFIG_DVB_SI21XX=m
++CONFIG_DVB_SP8870=m
++CONFIG_DVB_SP887X=m
++CONFIG_DVB_STB0899=m
++CONFIG_DVB_STB6000=m
++CONFIG_DVB_STB6100=m
++CONFIG_DVB_STV0288=m
++CONFIG_DVB_STV0297=m
++CONFIG_DVB_STV0299=m
++CONFIG_DVB_STV0367=m
++CONFIG_DVB_STV0900=m
++CONFIG_DVB_STV090x=m
++CONFIG_DVB_STV6110=m
++CONFIG_DVB_STV6110x=m
++CONFIG_DVB_TDA10021=m
++CONFIG_DVB_TDA10023=m
++CONFIG_DVB_TDA10048=m
++CONFIG_DVB_TDA1004X=m
++CONFIG_DVB_TDA10071=m
++CONFIG_DVB_TDA10086=m
++CONFIG_DVB_TDA18271C2DD=m
++CONFIG_DVB_TDA665x=m
++CONFIG_DVB_TDA8083=m
++CONFIG_DVB_TDA8261=m
++CONFIG_DVB_TDA826X=m
++CONFIG_DVB_TS2020=m
++CONFIG_DVB_TTUSB_BUDGET=m
++CONFIG_DVB_TTUSB_DEC=m
++CONFIG_DVB_TUA6100=m
++CONFIG_DVB_TUNER_CX24113=m
++CONFIG_DVB_TUNER_DIB0070=m
++CONFIG_DVB_TUNER_DIB0090=m
++CONFIG_DVB_TUNER_ITD1000=m
++CONFIG_DVB_USB=m
++CONFIG_DVB_USB_A800=m
++CONFIG_DVB_USB_AF9005=m
++CONFIG_DVB_USB_AF9005_REMOTE=m
++CONFIG_DVB_USB_AF9015=m
++CONFIG_DVB_USB_AF9035=m
++CONFIG_DVB_USB_ANYSEE=m
++CONFIG_DVB_USB_AU6610=m
++CONFIG_DVB_USB_AZ6007=m
++CONFIG_DVB_USB_AZ6027=m
++CONFIG_DVB_USB_CE6230=m
++CONFIG_DVB_USB_CINERGY_T2=m
++CONFIG_DVB_USB_CXUSB=m
++# CONFIG_DVB_USB_DEBUG is not set
++CONFIG_DVB_USB_DIB0700=m
++CONFIG_DVB_USB_DIBUSB_MB=m
++# CONFIG_DVB_USB_DIBUSB_MB_FAULTY is not set
++CONFIG_DVB_USB_DIBUSB_MC=m
++CONFIG_DVB_USB_DIGITV=m
++CONFIG_DVB_USB_DTT200U=m
++CONFIG_DVB_USB_DTV5100=m
++CONFIG_DVB_USB_DW2102=m
++CONFIG_DVB_USB_EC168=m
++CONFIG_DVB_USB_FRIIO=m
++CONFIG_DVB_USB_GL861=m
++CONFIG_DVB_USB_GP8PSK=m
++CONFIG_DVB_USB_IT913X=m
++CONFIG_DVB_USB_LME2510=m
++CONFIG_DVB_USB_M920X=m
++CONFIG_DVB_USB_MXL111SF=m
++CONFIG_DVB_USB_NOVA_T_USB2=m
++CONFIG_DVB_USB_OPERA1=m
++CONFIG_DVB_USB_PCTV452E=m
++CONFIG_DVB_USB_RTL28XXU=m
++CONFIG_DVB_USB_TECHNISAT_USB2=m
++CONFIG_DVB_USB_TTUSB2=m
++CONFIG_DVB_USB_UMT_010=m
++CONFIG_DVB_USB_V2=m
++CONFIG_DVB_USB_VP702X=m
++CONFIG_DVB_USB_VP7045=m
++CONFIG_DVB_VES1820=m
++CONFIG_DVB_VES1X93=m
++CONFIG_DVB_ZL10036=m
++CONFIG_DVB_ZL10039=m
++CONFIG_DVB_ZL10353=m
++CONFIG_DW_APB_TIMER=y
++CONFIG_DW_DMAC=m
++CONFIG_DW_DMAC_CORE=m
++CONFIG_DW_DMAC_PCI=m
++CONFIG_DW_WATCHDOG=m
++CONFIG_DX_SEP=m
++CONFIG_DYNAMIC_DEBUG=y
++CONFIG_DYNAMIC_FTRACE=y
++CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
++CONFIG_E100=m
++CONFIG_E1000=m
++CONFIG_E1000E=m
++CONFIG_EARLY_PRINTK=y
++CONFIG_EARLY_PRINTK_DBGP=y
++CONFIG_EARLY_PRINTK_INTEL_MID=y
++CONFIG_ECHO=m
++CONFIG_ECRYPT_FS=y
++CONFIG_ECRYPT_FS_MESSAGING=y
++CONFIG_EDAC=y
++CONFIG_EDAC_AMD64=m
++# CONFIG_EDAC_AMD64_ERROR_INJECTION is not set
++CONFIG_EDAC_AMD76X=m
++# CONFIG_EDAC_DEBUG is not set
++CONFIG_EDAC_DECODE_MCE=m
++CONFIG_EDAC_E752X=m
++CONFIG_EDAC_E7XXX=m
++CONFIG_EDAC_HIGHBANK_L2=m
++CONFIG_EDAC_HIGHBANK_MC=m
++CONFIG_EDAC_I3000=m
++CONFIG_EDAC_I3200=m
++CONFIG_EDAC_I5000=m
++CONFIG_EDAC_I5100=m
++CONFIG_EDAC_I5400=m
++CONFIG_EDAC_I7300=m
++CONFIG_EDAC_I7CORE=m
++CONFIG_EDAC_I82860=m
++CONFIG_EDAC_I82875P=m
++CONFIG_EDAC_I82975X=m
++CONFIG_EDAC_LEGACY_SYSFS=y
++CONFIG_EDAC_MCE_INJ=m
++CONFIG_EDAC_MM_EDAC=m
++CONFIG_EDAC_R82600=m
++CONFIG_EDAC_SBRIDGE=m
++CONFIG_EDAC_X38=m
++CONFIG_EDD=y
++CONFIG_EDD_OFF=y
++CONFIG_EEEPC_LAPTOP=m
++CONFIG_EEEPC_WMI=m
++CONFIG_EEPROM_93CX6=m
++CONFIG_EEPROM_93XX46=m
++CONFIG_EEPROM_AT24=m
++CONFIG_EEPROM_AT25=m
++CONFIG_EEPROM_LEGACY=m
++CONFIG_EEPROM_MAX6875=m
++CONFIG_EFI=y
++CONFIG_EFIVAR_FS=y
++CONFIG_EFI_PARTITION=y
++CONFIG_EFI_STUB=y
++CONFIG_EFI_VARS=y
++CONFIG_EFI_VARS_PSTORE=m
++# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
++CONFIG_EFS_FS=m
++CONFIG_EISA=y
++CONFIG_EISA_NAMES=y
++CONFIG_EISA_PCI_EISA=y
++CONFIG_EISA_VIRTUAL_ROOT=y
++CONFIG_EISA_VLB_PRIMING=y
++CONFIG_EL3=m
++CONFIG_ELF_CORE=y
++# CONFIG_EMBEDDED is not set
++# CONFIG_ENABLE_MUST_CHECK is not set
++# CONFIG_ENABLE_WARN_DEPRECATED is not set
++CONFIG_ENC28J60=m
++# CONFIG_ENC28J60_WRITEVERIFY is not set
++CONFIG_ENCLOSURE_SERVICES=m
++CONFIG_ENCRYPTED_KEYS=y
++CONFIG_ENIC=m
++CONFIG_EPIC100=m
++CONFIG_EPOLL=y
++CONFIG_EQUALIZER=m
++CONFIG_ESI_DONGLE=m
++CONFIG_ET131X=m
++CONFIG_ETHERNET=y
++CONFIG_ETHOC=m
++CONFIG_EUROTECH_WDT=m
++CONFIG_EVENTFD=y
++CONFIG_EVENT_TRACING=y
++CONFIG_EVM=y
++CONFIG_EVM_HMAC_VERSION=2
++# CONFIG_EXOFS_DEBUG is not set
++CONFIG_EXOFS_FS=m
++CONFIG_EXPERT=y
++CONFIG_EXPORTFS=y
++CONFIG_EXT2_FS=m
++CONFIG_EXT2_FS_POSIX_ACL=y
++CONFIG_EXT2_FS_SECURITY=y
++CONFIG_EXT2_FS_XATTR=y
++# CONFIG_EXT2_FS_XIP is not set
++CONFIG_EXT3_DEFAULTS_TO_ORDERED=y
++CONFIG_EXT3_FS=y
++CONFIG_EXT3_FS_POSIX_ACL=y
++CONFIG_EXT3_FS_SECURITY=y
++CONFIG_EXT3_FS_XATTR=y
++# CONFIG_EXT4_DEBUG is not set
++CONFIG_EXT4_FS=y
++CONFIG_EXT4_FS_POSIX_ACL=y
++CONFIG_EXT4_FS_SECURITY=y
++CONFIG_EXTCON=y
++CONFIG_EXTCON_ADC_JACK=m
++CONFIG_EXTCON_ARIZONA=m
++CONFIG_EXTCON_GPIO=m
++CONFIG_EXTCON_MAX77693=m
++CONFIG_EXTCON_MAX8997=m
++CONFIG_EXTCON_PALMAS=m
++CONFIG_EXTRA_FIRMWARE=""
++CONFIG_EXYNOS_ADC=y
++CONFIG_EXYNOS_VIDEO=y
++CONFIG_F2FS_FS=m
++CONFIG_F2FS_FS_POSIX_ACL=y
++CONFIG_F2FS_FS_SECURITY=y
++CONFIG_F2FS_FS_XATTR=y
++CONFIG_F2FS_STAT_FS=y
++CONFIG_F71808E_WDT=m
++CONFIG_FAIR_GROUP_SCHED=y
++CONFIG_FANOTIFY=y
++CONFIG_FANOTIFY_ACCESS_PERMISSIONS=y
++CONFIG_FARSYNC=m
++CONFIG_FAT_DEFAULT_CODEPAGE=437
++CONFIG_FAT_DEFAULT_IOCHARSET="iso8859-1"
++CONFIG_FAT_FS=y
++# CONFIG_FAULT_INJECTION is not set
++CONFIG_FB=y
++CONFIG_FB_3DFX=m
++# CONFIG_FB_3DFX_ACCEL is not set
++# CONFIG_FB_3DFX_I2C is not set
++CONFIG_FB_ARC=m
++CONFIG_FB_ARK=m
++CONFIG_FB_ARMCLCD=y
++CONFIG_FB_ASILIANT=y
++CONFIG_FB_ATY=m
++CONFIG_FB_ATY128=m
++CONFIG_FB_ATY128_BACKLIGHT=y
++CONFIG_FB_ATY_BACKLIGHT=y
++CONFIG_FB_ATY_CT=y
++# CONFIG_FB_ATY_GENERIC_LCD is not set
++CONFIG_FB_ATY_GX=y
++CONFIG_FB_AUO_K1900=m
++CONFIG_FB_AUO_K1901=m
++CONFIG_FB_AUO_K190X=m
++CONFIG_FB_BROADSHEET=m
++CONFIG_FB_CARILLO_RANCH=m
++CONFIG_FB_CARMINE=m
++CONFIG_FB_CARMINE_DRAM_EVAL=y
++CONFIG_FB_CFB_COPYAREA=y
++CONFIG_FB_CFB_FILLRECT=y
++CONFIG_FB_CFB_IMAGEBLIT=y
++# CONFIG_FB_CFB_REV_PIXELS_IN_BYTE is not set
++CONFIG_FB_CIRRUS=m
++CONFIG_FB_CYBER2000=m
++CONFIG_FB_CYBER2000_DDC=y
++CONFIG_FB_DEFERRED_IO=y
++CONFIG_FB_EFI=y
++# CONFIG_FB_FOREIGN_ENDIAN is not set
++CONFIG_FB_GEODE=y
++CONFIG_FB_GEODE_GX=m
++CONFIG_FB_GEODE_GX1=m
++CONFIG_FB_GEODE_LX=m
++CONFIG_FB_GOLDFISH=m
++CONFIG_FB_HECUBA=m
++CONFIG_FB_HGA=m
++CONFIG_FB_HYPERV=m
++CONFIG_FB_I740=m
++CONFIG_FB_I810=m
++# CONFIG_FB_I810_GTF is not set
++CONFIG_FB_IMSTT=y
++CONFIG_FB_INTEL=m
++# CONFIG_FB_INTEL_DEBUG is not set
++# CONFIG_FB_INTEL_I2C is not set
++CONFIG_FB_KYRO=m
++CONFIG_FB_LE80578=m
++# CONFIG_FB_MACMODES is not set
++CONFIG_FB_MATROX=m
++CONFIG_FB_MATROX_G=y
++CONFIG_FB_MATROX_I2C=m
++CONFIG_FB_MATROX_MAVEN=m
++CONFIG_FB_MATROX_MILLENIUM=y
++CONFIG_FB_MATROX_MYSTIQUE=y
++CONFIG_FB_MB862XX=m
++CONFIG_FB_MB862XX_I2C=y
++CONFIG_FB_MB862XX_PCI_GDC=y
++CONFIG_FB_METRONOME=m
++CONFIG_FB_MODE_HELPERS=y
++CONFIG_FB_MX3=y
++CONFIG_FB_N411=m
++CONFIG_FB_NEOMAGIC=m
++CONFIG_FB_NVIDIA=m
++CONFIG_FB_NVIDIA_BACKLIGHT=y
++# CONFIG_FB_NVIDIA_DEBUG is not set
++CONFIG_FB_NVIDIA_I2C=y
++CONFIG_FB_OMAP2=y
++# CONFIG_FB_OMAP2_DEBUG_SUPPORT is not set
++CONFIG_FB_OMAP2_NUM_FBS=3
++CONFIG_FB_PM2=m
++CONFIG_FB_PM2_FIFO_DISCONNECT=y
++CONFIG_FB_PM3=m
++CONFIG_FB_RADEON=m
++CONFIG_FB_RADEON_BACKLIGHT=y
++# CONFIG_FB_RADEON_DEBUG is not set
++CONFIG_FB_RADEON_I2C=y
++CONFIG_FB_RIVA=m
++CONFIG_FB_RIVA_BACKLIGHT=y
++# CONFIG_FB_RIVA_DEBUG is not set
++CONFIG_FB_RIVA_I2C=y
++CONFIG_FB_S1D13XXX=m
++CONFIG_FB_S3=m
++CONFIG_FB_S3_DDC=y
++CONFIG_FB_SAVAGE=m
++# CONFIG_FB_SAVAGE_ACCEL is not set
++# CONFIG_FB_SAVAGE_I2C is not set
++CONFIG_FB_SIMPLE=y
++CONFIG_FB_SIS=m
++CONFIG_FB_SIS_300=y
++CONFIG_FB_SIS_315=y
++CONFIG_FB_SM501=m
++CONFIG_FB_SM7XX=m
++CONFIG_FB_SMSCUFX=m
++CONFIG_FB_SSD1307=m
++CONFIG_FB_SYS_FOPS=m
++CONFIG_FB_TILEBLITTING=y
++CONFIG_FB_TMIO=m
++CONFIG_FB_TMIO_ACCELL=y
++CONFIG_FB_TRIDENT=m
++CONFIG_FB_UDL=m
++CONFIG_FB_UVESA=m
++CONFIG_FB_VESA=m
++CONFIG_FB_VGA16=m
++CONFIG_FB_VIA=m
++# CONFIG_FB_VIA_DIRECT_PROCFS is not set
++CONFIG_FB_VIA_X_COMPATIBILITY=y
++# CONFIG_FB_VIRTUAL is not set
++CONFIG_FB_VOODOO1=m
++CONFIG_FB_VT8623=m
++CONFIG_FB_XGI=m
++CONFIG_FCOE=m
++CONFIG_FCOE_FNIC=m
++CONFIG_FDDI=y
++CONFIG_FEALNX=m
++CONFIG_FEC=y
++CONFIG_FHANDLE=y
++CONFIG_FIB_RULES=y
++CONFIG_FILE_LOCKING=y
++CONFIG_FIREWIRE=m
++CONFIG_FIREWIRE_NET=m
++CONFIG_FIREWIRE_NOSY=m
++CONFIG_FIREWIRE_OHCI=m
++# CONFIG_FIREWIRE_OHCI_REMOTE_DMA is not set
++CONFIG_FIREWIRE_SBP2=m
++CONFIG_FIREWIRE_SERIAL=m
++CONFIG_FIRMWARE_EDID=y
++CONFIG_FIRMWARE_IN_KERNEL=y
++CONFIG_FIRMWARE_MEMMAP=y
++CONFIG_FIXED_PHY=y
++CONFIG_FIX_EARLYCON_MEM=y
++CONFIG_FLATMEM=y
++CONFIG_FLATMEM_MANUAL=y
++CONFIG_FLAT_NODE_MEM_MAP=y
++CONFIG_FMC=m
++CONFIG_FMC_CHARDEV=m
++CONFIG_FMC_FAKEDEV=m
++CONFIG_FMC_TRIVIAL=m
++CONFIG_FMC_WRITE_EEPROM=m
++# CONFIG_FONT_10x18 is not set
++# CONFIG_FONT_6x11 is not set
++# CONFIG_FONT_7x14 is not set
++CONFIG_FONT_8x16=y
++CONFIG_FONT_8x8=y
++CONFIG_FONT_ACORN_8x8=y
++# CONFIG_FONT_MINI_4x6 is not set
++# CONFIG_FONT_PEARL_8x8 is not set
++# CONFIG_FONT_SUN12x22 is not set
++# CONFIG_FONT_SUN8x16 is not set
++CONFIG_FONT_SUPPORT=y
++CONFIG_FORCEDETH=m
++CONFIG_FORCE_MAX_ZONEORDER=11
++# CONFIG_FPE_FASTFPE is not set
++CONFIG_FPE_NWFPE=y
++# CONFIG_FPE_NWFPE_XP is not set
++CONFIG_FRAMEBUFFER_CONSOLE=y
++CONFIG_FRAMEBUFFER_CONSOLE_DETECT_PRIMARY=y
++# CONFIG_FRAMEBUFFER_CONSOLE_ROTATION is not set
++CONFIG_FRAME_POINTER=y
++CONFIG_FRAME_WARN=1024
++CONFIG_FREEZER=y
++CONFIG_FRONTSWAP=y
++CONFIG_FSCACHE=m
++# CONFIG_FSCACHE_DEBUG is not set
++# CONFIG_FSCACHE_HISTOGRAM is not set
++# CONFIG_FSCACHE_OBJECT_LIST is not set
++CONFIG_FSCACHE_STATS=y
++CONFIG_FSNOTIFY=y
++CONFIG_FS_MBCACHE=y
++CONFIG_FS_POSIX_ACL=y
++CONFIG_FT1000=m
++CONFIG_FT1000_PCMCIA=m
++CONFIG_FT1000_USB=m
++CONFIG_FTGMAC100=m
++CONFIG_FTL=m
++CONFIG_FTMAC100=m
++CONFIG_FTRACE=y
++CONFIG_FTRACE_MCOUNT_RECORD=y
++# CONFIG_FTRACE_STARTUP_TEST is not set
++CONFIG_FTRACE_SYSCALLS=y
++CONFIG_FUJITSU_LAPTOP=m
++# CONFIG_FUJITSU_LAPTOP_DEBUG is not set
++CONFIG_FUJITSU_TABLET=m
++CONFIG_FUNCTION_GRAPH_TRACER=y
++CONFIG_FUNCTION_PROFILER=y
++CONFIG_FUSE_FS=y
++CONFIG_FUSION=y
++CONFIG_FUSION_CTL=m
++CONFIG_FUSION_FC=m
++CONFIG_FUSION_LAN=m
++CONFIG_FUSION_LOGGING=y
++CONFIG_FUSION_MAX_SGE=128
++CONFIG_FUSION_SAS=m
++CONFIG_FUSION_SPI=m
++CONFIG_FUTEX=y
++CONFIG_FW_LOADER=y
++CONFIG_FW_LOADER_USER_HELPER=y
++CONFIG_GACT_PROB=y
++CONFIG_GADGET_UAC1=y
++CONFIG_GAMEPORT=m
++CONFIG_GAMEPORT_EMU10K1=m
++CONFIG_GAMEPORT_FM801=m
++CONFIG_GAMEPORT_L4=m
++CONFIG_GAMEPORT_NS558=m
++CONFIG_GARP=m
++CONFIG_GART_IOMMU=y
++# CONFIG_GCOV_KERNEL is not set
++CONFIG_GENERIC_ACL=y
++CONFIG_GENERIC_ADC_BATTERY=m
++CONFIG_GENERIC_ALLOCATOR=y
++CONFIG_GENERIC_BUG=y
++CONFIG_GENERIC_BUG_RELATIVE_POINTERS=y
++CONFIG_GENERIC_CALIBRATE_DELAY=y
++CONFIG_GENERIC_CLOCKEVENTS=y
++CONFIG_GENERIC_CLOCKEVENTS_BROADCAST=y
++CONFIG_GENERIC_CLOCKEVENTS_BUILD=y
++CONFIG_GENERIC_CLOCKEVENTS_MIN_ADJUST=y
++CONFIG_GENERIC_CMOS_UPDATE=y
++CONFIG_GENERIC_CPU=y
++# CONFIG_GENERIC_CPU_DEVICES is not set
++CONFIG_GENERIC_FIND_FIRST_BIT=y
++CONFIG_GENERIC_HARDIRQS=y
++CONFIG_GENERIC_HWEIGHT=y
++CONFIG_GENERIC_IDLE_POLL_SETUP=y
++CONFIG_GENERIC_IO=y
++CONFIG_GENERIC_IOMAP=y
++CONFIG_GENERIC_IRQ_CHIP=y
++CONFIG_GENERIC_IRQ_PROBE=y
++CONFIG_GENERIC_IRQ_SHOW=y
++CONFIG_GENERIC_ISA_DMA=y
++CONFIG_GENERIC_NET_UTILS=y
++CONFIG_GENERIC_PCI_IOMAP=y
++CONFIG_GENERIC_PENDING_IRQ=y
++CONFIG_GENERIC_PINCONF=y
++CONFIG_GENERIC_SCHED_CLOCK=y
++CONFIG_GENERIC_SMP_IDLE_THREAD=y
++CONFIG_GENERIC_STRNCPY_FROM_USER=y
++CONFIG_GENERIC_STRNLEN_USER=y
++CONFIG_GENERIC_TIME_VSYSCALL=y
++CONFIG_GENERIC_TRACER=y
++CONFIG_GEOS=y
++CONFIG_GFS2_FS=m
++CONFIG_GFS2_FS_LOCKING_DLM=y
++CONFIG_GIGASET_BASE=m
++# CONFIG_GIGASET_CAPI is not set
++# CONFIG_GIGASET_DEBUG is not set
++# CONFIG_GIGASET_DUMMYLL is not set
++CONFIG_GIGASET_I4L=y
++CONFIG_GIGASET_M101=m
++CONFIG_GIGASET_M105=m
++CONFIG_GIRBIL_DONGLE=m
++# CONFIG_GOOGLE_FIRMWARE is not set
++CONFIG_GPIOLIB=y
++CONFIG_GPIO_74X164=m
++CONFIG_GPIO_ACPI=y
++CONFIG_GPIO_ADNP=m
++CONFIG_GPIO_ADP5520=m
++CONFIG_GPIO_ADP5588=m
++CONFIG_GPIO_AMD8111=m
++CONFIG_GPIO_ARIZONA=m
++CONFIG_GPIO_CS5535=m
++CONFIG_GPIO_DA9052=m
++CONFIG_GPIO_DA9055=m
++CONFIG_GPIO_DEVRES=y
++# CONFIG_GPIO_EM is not set
++CONFIG_GPIO_GENERIC_PLATFORM=m
++CONFIG_GPIO_GRGPIO=m
++CONFIG_GPIO_ICH=m
++CONFIG_GPIO_INTEL_PMIC=y
++CONFIG_GPIO_IT8761E=m
++CONFIG_GPIO_JANZ_TTL=m
++CONFIG_GPIO_LANGWELL=y
++CONFIG_GPIO_LYNXPOINT=y
++CONFIG_GPIO_MAX7300=m
++CONFIG_GPIO_MAX7301=m
++CONFIG_GPIO_MAX730X=m
++CONFIG_GPIO_MAX732X=m
++CONFIG_GPIO_MC33880=m
++CONFIG_GPIO_MCP23S08=m
++CONFIG_GPIO_ML_IOH=m
++CONFIG_GPIO_MSIC=y
++CONFIG_GPIO_MXC=y
++CONFIG_GPIO_PALMAS=y
++CONFIG_GPIO_PCA953X=m
++CONFIG_GPIO_PCF857X=m
++CONFIG_GPIO_PCH=m
++CONFIG_GPIO_PL061=y
++CONFIG_GPIO_RC5T583=y
++CONFIG_GPIO_RCAR=m
++CONFIG_GPIO_RDC321X=m
++CONFIG_GPIO_SCH=m
++CONFIG_GPIO_STMPE=y
++CONFIG_GPIO_SX150X=y
++# CONFIG_GPIO_SYSFS is not set
++CONFIG_GPIO_TC3589X=y
++CONFIG_GPIO_TIMBERDALE=y
++CONFIG_GPIO_TPS6586X=y
++CONFIG_GPIO_TPS65910=y
++CONFIG_GPIO_TPS65912=m
++CONFIG_GPIO_TS5500=m
++CONFIG_GPIO_TWL4030=y
++CONFIG_GPIO_UCB1400=y
++CONFIG_GPIO_VIPERBOARD=m
++CONFIG_GPIO_VX855=m
++CONFIG_GPIO_WM831X=m
++CONFIG_GPIO_WM8350=m
++CONFIG_GPIO_WM8994=m
++CONFIG_GREENASIA_FF=y
++CONFIG_HAMACHI=m
++CONFIG_HAMRADIO=y
++CONFIG_HANGCHECK_TIMER=m
++CONFIG_HAPPYMEAL=m
++CONFIG_HARDIRQS_SW_RESEND=y
++CONFIG_HARDLOCKUP_DETECTOR=y
++CONFIG_HAS_DMA=y
++CONFIG_HAS_IOMEM=y
++CONFIG_HAS_IOPORT=y
++# CONFIG_HAVE_64BIT_ALIGNED_ACCESS is not set
++CONFIG_HAVE_ALIGNED_STRUCT_PAGE=y
++CONFIG_HAVE_ARCH_JUMP_LABEL=y
++CONFIG_HAVE_ARCH_KGDB=y
++CONFIG_HAVE_ARCH_KMEMCHECK=y
++CONFIG_HAVE_ARCH_PFN_VALID=y
++CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
++CONFIG_HAVE_ARCH_SOFT_DIRTY=y
++CONFIG_HAVE_ARCH_TRACEHOOK=y
++CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
++CONFIG_HAVE_ARM_ARCH_TIMER=y
++CONFIG_HAVE_ARM_SCU=y
++CONFIG_HAVE_ARM_TWD=y
++CONFIG_HAVE_ATOMIC_IOMAP=y
++CONFIG_HAVE_BPF_JIT=y
++CONFIG_HAVE_CLK=y
++CONFIG_HAVE_CLK_PREPARE=y
++CONFIG_HAVE_CMPXCHG_DOUBLE=y
++CONFIG_HAVE_CMPXCHG_LOCAL=y
++CONFIG_HAVE_CONTEXT_TRACKING=y
++CONFIG_HAVE_C_RECORDMCOUNT=y
++CONFIG_HAVE_DEBUG_KMEMLEAK=y
++CONFIG_HAVE_DEBUG_STACKOVERFLOW=y
++CONFIG_HAVE_DMA_API_DEBUG=y
++CONFIG_HAVE_DMA_ATTRS=y
++CONFIG_HAVE_DMA_CONTIGUOUS=y
++CONFIG_HAVE_DYNAMIC_FTRACE=y
++CONFIG_HAVE_DYNAMIC_FTRACE_WITH_REGS=y
++CONFIG_HAVE_EFFICIENT_UNALIGNED_ACCESS=y
++CONFIG_HAVE_FENTRY=y
++CONFIG_HAVE_FTRACE_MCOUNT_RECORD=y
++CONFIG_HAVE_FUNCTION_GRAPH_FP_TEST=y
++CONFIG_HAVE_FUNCTION_GRAPH_TRACER=y
++CONFIG_HAVE_FUNCTION_TRACER=y
++CONFIG_HAVE_FUNCTION_TRACE_MCOUNT_TEST=y
++CONFIG_HAVE_GENERIC_HARDIRQS=y
++CONFIG_HAVE_HW_BREAKPOINT=y
++CONFIG_HAVE_IDE=y
++CONFIG_HAVE_IMX_ANATOP=y
++CONFIG_HAVE_IMX_GPC=y
++CONFIG_HAVE_IMX_MMDC=y
++CONFIG_HAVE_IMX_SRC=y
++CONFIG_HAVE_INTEL_TXT=y
++CONFIG_HAVE_IOREMAP_PROT=y
++CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
++CONFIG_HAVE_KERNEL_BZIP2=y
++CONFIG_HAVE_KERNEL_GZIP=y
++CONFIG_HAVE_KERNEL_LZ4=y
++CONFIG_HAVE_KERNEL_LZMA=y
++CONFIG_HAVE_KERNEL_LZO=y
++CONFIG_HAVE_KERNEL_XZ=y
++CONFIG_HAVE_KPROBES=y
++CONFIG_HAVE_KPROBES_ON_FTRACE=y
++CONFIG_HAVE_KRETPROBES=y
++CONFIG_HAVE_KVM=y
++CONFIG_HAVE_KVM_CPU_RELAX_INTERCEPT=y
++CONFIG_HAVE_KVM_EVENTFD=y
++CONFIG_HAVE_KVM_IRQCHIP=y
++CONFIG_HAVE_KVM_IRQ_ROUTING=y
++CONFIG_HAVE_KVM_MSI=y
++CONFIG_HAVE_LATENCYTOP_SUPPORT=y
++CONFIG_HAVE_MEMBLOCK=y
++CONFIG_HAVE_MEMBLOCK_NODE_MAP=y
++CONFIG_HAVE_MEMORY_PRESENT=y
++CONFIG_HAVE_MIXED_BREAKPOINTS_REGS=y
++CONFIG_HAVE_MMIOTRACE_SUPPORT=y
++CONFIG_HAVE_MOD_ARCH_SPECIFIC=y
++CONFIG_HAVE_NET_DSA=y
++CONFIG_HAVE_OPROFILE=y
++CONFIG_HAVE_OPTPROBES=y
++CONFIG_HAVE_PATA_PLATFORM=y
++CONFIG_HAVE_PCSPKR_PLATFORM=y
++CONFIG_HAVE_PERF_EVENTS=y
++CONFIG_HAVE_PERF_EVENTS_NMI=y
++CONFIG_HAVE_PERF_REGS=y
++CONFIG_HAVE_PERF_USER_STACK_DUMP=y
++CONFIG_HAVE_PROC_CPU=y
++CONFIG_HAVE_REGS_AND_STACK_ACCESS_API=y
++CONFIG_HAVE_SETUP_PER_CPU_AREA=y
++CONFIG_HAVE_SMP=y
++CONFIG_HAVE_SYSCALL_TRACEPOINTS=y
++CONFIG_HAVE_TEXT_POKE_SMP=y
++CONFIG_HAVE_UID16=y
++CONFIG_HAVE_UNSTABLE_SCHED_CLOCK=y
++CONFIG_HAVE_USER_RETURN_NOTIFIER=y
++CONFIG_HDLC=m
++CONFIG_HDLC_CISCO=m
++CONFIG_HDLC_FR=m
++CONFIG_HDLC_PPP=m
++CONFIG_HDLC_RAW=m
++CONFIG_HDLC_RAW_ETH=m
++CONFIG_HDLC_X25=m
++CONFIG_HDMI=y
++CONFIG_HDQ_MASTER_OMAP=m
++# CONFIG_HEADERS_CHECK is not set
++CONFIG_HERMES=m
++CONFIG_HERMES_CACHE_FW_ON_INIT=y
++# CONFIG_HERMES_PRISM is not set
++CONFIG_HFSPLUS_FS=m
++CONFIG_HFS_FS=m
++CONFIG_HIBERNATE_CALLBACKS=y
++CONFIG_HIBERNATION=y
++CONFIG_HID=m
++CONFIG_HIDRAW=y
++CONFIG_HID_A4TECH=m
++CONFIG_HID_ACRUX=m
++CONFIG_HID_ACRUX_FF=y
++CONFIG_HID_APPLE=m
++CONFIG_HID_APPLEIR=m
++CONFIG_HID_AUREAL=m
++CONFIG_HID_BATTERY_STRENGTH=y
++CONFIG_HID_BELKIN=m
++CONFIG_HID_CHERRY=m
++CONFIG_HID_CHICONY=m
++CONFIG_HID_CYPRESS=m
++CONFIG_HID_DRAGONRISE=m
++CONFIG_HID_ELECOM=m
++CONFIG_HID_ELO=m
++CONFIG_HID_EMS_FF=m
++CONFIG_HID_EZKEY=m
++CONFIG_HID_GENERIC=m
++CONFIG_HID_GREENASIA=m
++CONFIG_HID_GYRATION=m
++CONFIG_HID_HOLTEK=m
++CONFIG_HID_HUION=m
++CONFIG_HID_HYPERV_MOUSE=m
++CONFIG_HID_ICADE=m
++CONFIG_HID_KENSINGTON=m
++CONFIG_HID_KEYTOUCH=m
++CONFIG_HID_KYE=m
++CONFIG_HID_LCPOWER=m
++CONFIG_HID_LENOVO_TPKBD=m
++CONFIG_HID_LOGITECH=m
++CONFIG_HID_LOGITECH_DJ=m
++CONFIG_HID_MAGICMOUSE=m
++CONFIG_HID_MICROSOFT=m
++CONFIG_HID_MONTEREY=m
++CONFIG_HID_MULTITOUCH=m
++CONFIG_HID_NTRIG=m
++CONFIG_HID_ORTEK=m
++CONFIG_HID_PANTHERLORD=m
++CONFIG_HID_PETALYNX=m
++CONFIG_HID_PICOLCD=m
++CONFIG_HID_PICOLCD_BACKLIGHT=y
++CONFIG_HID_PICOLCD_CIR=y
++CONFIG_HID_PICOLCD_FB=y
++CONFIG_HID_PICOLCD_LCD=y
++CONFIG_HID_PICOLCD_LEDS=y
++CONFIG_HID_PID=y
++CONFIG_HID_PRIMAX=m
++CONFIG_HID_PRODIKEYS=m
++CONFIG_HID_ROCCAT=m
++CONFIG_HID_SAITEK=m
++CONFIG_HID_SAMSUNG=m
++CONFIG_HID_SENSOR_ACCEL_3D=m
++CONFIG_HID_SENSOR_ALS=m
++# CONFIG_HID_SENSOR_ENUM_BASE_QUIRKS is not set
++CONFIG_HID_SENSOR_GYRO_3D=m
++CONFIG_HID_SENSOR_HUB=m
++CONFIG_HID_SENSOR_IIO_COMMON=m
++CONFIG_HID_SENSOR_IIO_TRIGGER=m
++CONFIG_HID_SENSOR_MAGNETOMETER_3D=m
++CONFIG_HID_SMARTJOYPLUS=m
++CONFIG_HID_SONY=m
++CONFIG_HID_SPEEDLINK=m
++CONFIG_HID_STEELSERIES=m
++CONFIG_HID_SUNPLUS=m
++CONFIG_HID_THINGM=m
++CONFIG_HID_THRUSTMASTER=m
++CONFIG_HID_TIVO=m
++CONFIG_HID_TOPSEED=m
++CONFIG_HID_TWINHAN=m
++CONFIG_HID_UCLOGIC=m
++CONFIG_HID_WACOM=m
++CONFIG_HID_WALTOP=m
++CONFIG_HID_WIIMOTE=m
++CONFIG_HID_ZEROPLUS=m
++CONFIG_HID_ZYDACRON=m
++CONFIG_HIGHMEM=y
++# CONFIG_HIGHMEM4G is not set
++CONFIG_HIGHMEM64G=y
++CONFIG_HIGHPTE=y
++CONFIG_HIGH_RES_TIMERS=y
++# CONFIG_HIPPI is not set
++CONFIG_HISAX_16_0=y
++CONFIG_HISAX_16_3=y
++CONFIG_HISAX_1TR6=y
++CONFIG_HISAX_ASUSCOM=y
++CONFIG_HISAX_AVM_A1=y
++CONFIG_HISAX_AVM_A1_CS=m
++CONFIG_HISAX_AVM_A1_PCMCIA=y
++CONFIG_HISAX_BKM_A4T=y
++# CONFIG_HISAX_DEBUG is not set
++CONFIG_HISAX_DIEHLDIVA=y
++CONFIG_HISAX_ELSA=y
++CONFIG_HISAX_ELSA_CS=m
++CONFIG_HISAX_ENTERNOW_PCI=y
++CONFIG_HISAX_EURO=y
++CONFIG_HISAX_FRITZPCI=y
++CONFIG_HISAX_FRITZ_PCIPNP=m
++CONFIG_HISAX_GAZEL=y
++CONFIG_HISAX_HFC4S8S=m
++CONFIG_HISAX_HFCS=y
++CONFIG_HISAX_HFCUSB=m
++CONFIG_HISAX_HFC_PCI=y
++CONFIG_HISAX_HFC_SX=y
++CONFIG_HISAX_HSTSAPHIR=y
++CONFIG_HISAX_ISURF=y
++CONFIG_HISAX_IX1MICROR2=y
++CONFIG_HISAX_MAX_CARDS=8
++CONFIG_HISAX_MIC=y
++CONFIG_HISAX_NETJET=y
++CONFIG_HISAX_NETJET_U=y
++CONFIG_HISAX_NI1=y
++CONFIG_HISAX_NICCY=y
++# CONFIG_HISAX_NO_KEYPAD is not set
++# CONFIG_HISAX_NO_LLC is not set
++# CONFIG_HISAX_NO_SENDCOMPLETE is not set
++CONFIG_HISAX_S0BOX=y
++CONFIG_HISAX_SCT_QUADRO=y
++CONFIG_HISAX_SEDLBAUER=y
++CONFIG_HISAX_SEDLBAUER_CS=m
++CONFIG_HISAX_SPORTSTER=y
++CONFIG_HISAX_ST5481=m
++CONFIG_HISAX_TELEINT=y
++CONFIG_HISAX_TELESPCI=y
++CONFIG_HISAX_TELES_CS=m
++CONFIG_HISAX_W6692=y
++CONFIG_HMC6352=m
++CONFIG_HOLTEK_FF=y
++CONFIG_HOSTAP=m
++CONFIG_HOSTAP_CS=m
++CONFIG_HOSTAP_FIRMWARE=y
++CONFIG_HOSTAP_FIRMWARE_NVRAM=y
++CONFIG_HOSTAP_PCI=m
++CONFIG_HOSTAP_PLX=m
++CONFIG_HOSTESS_SV11=m
++CONFIG_HOTPLUG_CPU=y
++CONFIG_HOTPLUG_PCI=y
++CONFIG_HOTPLUG_PCI_ACPI=y
++CONFIG_HOTPLUG_PCI_ACPI_IBM=m
++CONFIG_HOTPLUG_PCI_COMPAQ=m
++CONFIG_HOTPLUG_PCI_COMPAQ_NVRAM=y
++CONFIG_HOTPLUG_PCI_CPCI=y
++CONFIG_HOTPLUG_PCI_CPCI_GENERIC=m
++CONFIG_HOTPLUG_PCI_CPCI_ZT5550=m
++CONFIG_HOTPLUG_PCI_IBM=m
++CONFIG_HOTPLUG_PCI_PCIE=y
++CONFIG_HOTPLUG_PCI_SHPC=m
++CONFIG_HP100=m
++CONFIG_HPET=y
++CONFIG_HPET_EMULATE_RTC=y
++CONFIG_HPET_MMAP=y
++CONFIG_HPET_TIMER=y
++CONFIG_HPFS_FS=m
++CONFIG_HPWDT_NMI_DECODING=y
++CONFIG_HP_ACCEL=m
++CONFIG_HP_ILO=m
++CONFIG_HP_WATCHDOG=m
++CONFIG_HP_WMI=m
++CONFIG_HSI=m
++CONFIG_HSI_BOARDINFO=y
++CONFIG_HSI_CHAR=m
++CONFIG_HTC_EGPIO=y
++CONFIG_HTC_I2CPLD=y
++CONFIG_HTC_PASIC3=m
++CONFIG_HT_IRQ=y
++CONFIG_HUGETLBFS=y
++CONFIG_HVC_DCC=y
++CONFIG_HVC_DRIVER=y
++CONFIG_HVC_IRQ=y
++CONFIG_HVC_XEN=y
++CONFIG_HVC_XEN_FRONTEND=y
++CONFIG_HWMON=y
++# CONFIG_HWMON_DEBUG_CHIP is not set
++CONFIG_HWMON_VID=m
++CONFIG_HWPOISON_INJECT=m
++# CONFIG_HWSPINLOCK_OMAP is not set
++CONFIG_HW_CONSOLE=y
++CONFIG_HW_PERF_EVENTS=y
++CONFIG_HW_RANDOM=y
++CONFIG_HW_RANDOM_AMD=m
++# CONFIG_HW_RANDOM_ATMEL is not set
++CONFIG_HW_RANDOM_EXYNOS=m
++CONFIG_HW_RANDOM_GEODE=m
++CONFIG_HW_RANDOM_INTEL=m
++CONFIG_HW_RANDOM_TIMERIOMEM=m
++CONFIG_HW_RANDOM_TPM=m
++CONFIG_HW_RANDOM_VIA=m
++CONFIG_HW_RANDOM_VIRTIO=m
++CONFIG_HYPERV=m
++CONFIG_HYPERVISOR_GUEST=y
++CONFIG_HYPERV_BALLOON=m
++CONFIG_HYPERV_NET=m
++CONFIG_HYPERV_STORAGE=m
++CONFIG_HYPERV_UTILS=m
++CONFIG_HYSDN=m
++CONFIG_HYSDN_CAPI=y
++# CONFIG_HZ_100 is not set
++# CONFIG_HZ_1000 is not set
++CONFIG_HZ_250=y
++# CONFIG_HZ_300 is not set
++# CONFIG_HZ_PERIODIC is not set
++CONFIG_I2C=y
++CONFIG_I2C_ALGOBIT=m
++CONFIG_I2C_ALGOPCA=m
++CONFIG_I2C_ALI1535=m
++CONFIG_I2C_ALI1563=m
++CONFIG_I2C_ALI15X3=m
++CONFIG_I2C_AMD756=m
++CONFIG_I2C_AMD756_S4882=m
++CONFIG_I2C_AMD8111=m
++CONFIG_I2C_ARB_GPIO_CHALLENGE=m
++CONFIG_I2C_BOARDINFO=y
++CONFIG_I2C_CBUS_GPIO=m
++CONFIG_I2C_CHARDEV=m
++CONFIG_I2C_COMPAT=y
++# CONFIG_I2C_DEBUG_ALGO is not set
++# CONFIG_I2C_DEBUG_BUS is not set
++# CONFIG_I2C_DEBUG_CORE is not set
++CONFIG_I2C_DESIGNWARE_CORE=m
++CONFIG_I2C_DESIGNWARE_PCI=m
++CONFIG_I2C_DESIGNWARE_PLATFORM=m
++CONFIG_I2C_DIOLAN_U2C=m
++CONFIG_I2C_EG20T=m
++CONFIG_I2C_GPIO=m
++CONFIG_I2C_HELPER_AUTO=y
++CONFIG_I2C_HID=m
++CONFIG_I2C_I801=m
++CONFIG_I2C_IMX=y
++CONFIG_I2C_ISCH=m
++CONFIG_I2C_ISMT=m
++CONFIG_I2C_KEMPLD=m
++CONFIG_I2C_MUX=m
++CONFIG_I2C_MUX_GPIO=m
++CONFIG_I2C_MUX_PCA9541=m
++CONFIG_I2C_MUX_PCA954x=m
++CONFIG_I2C_MUX_PINCTRL=m
++CONFIG_I2C_NFORCE2=m
++CONFIG_I2C_NFORCE2_S4985=m
++CONFIG_I2C_NOMADIK=m
++CONFIG_I2C_OCORES=m
++CONFIG_I2C_OMAP=y
++CONFIG_I2C_PARPORT=m
++CONFIG_I2C_PARPORT_LIGHT=m
++CONFIG_I2C_PCA_ISA=m
++CONFIG_I2C_PCA_PLATFORM=m
++CONFIG_I2C_PIIX4=m
++# CONFIG_I2C_PXA_PCI is not set
++CONFIG_I2C_SCMI=m
++CONFIG_I2C_SI470X=m
++CONFIG_I2C_SI4713=m
++CONFIG_I2C_SIMTEC=m
++CONFIG_I2C_SIS5595=m
++CONFIG_I2C_SIS630=m
++CONFIG_I2C_SIS96X=m
++CONFIG_I2C_SMBUS=m
++CONFIG_I2C_STUB=m
++CONFIG_I2C_TAOS_EVM=m
++CONFIG_I2C_TEGRA=m
++CONFIG_I2C_TINY_USB=m
++CONFIG_I2C_VERSATILE=m
++CONFIG_I2C_VIA=m
++CONFIG_I2C_VIAPRO=m
++CONFIG_I2C_VIPERBOARD=m
++CONFIG_I2C_XILINX=m
++CONFIG_I2O=m
++CONFIG_I2O_BLOCK=m
++CONFIG_I2O_BUS=m
++CONFIG_I2O_CONFIG=m
++# CONFIG_I2O_CONFIG_OLD_IOCTL is not set
++CONFIG_I2O_EXT_ADAPTEC=y
++CONFIG_I2O_EXT_ADAPTEC_DMA64=y
++CONFIG_I2O_LCT_NOTIFY_ON_CHANGES=y
++CONFIG_I2O_PROC=m
++CONFIG_I2O_SCSI=m
++CONFIG_I6300ESB_WDT=m
++CONFIG_I7300_IDLE=m
++CONFIG_I7300_IDLE_IOAT_CHANNEL=y
++CONFIG_I82092=m
++CONFIG_I82365=m
++CONFIG_I8253_LOCK=y
++CONFIG_I8K=m
++# CONFIG_IA32_AOUT is not set
++CONFIG_IA32_EMULATION=y
++CONFIG_IB700_WDT=m
++CONFIG_IBMASR=m
++CONFIG_IBM_ASM=m
++CONFIG_IBM_RTL=m
++CONFIG_ICPLUS_PHY=y
++CONFIG_ICS932S401=m
++CONFIG_ICST=y
++# CONFIG_IDE is not set
++CONFIG_IDEAPAD_LAPTOP=m
++CONFIG_IDE_PHISON=m
++CONFIG_IE6XX_WDT=m
++CONFIG_IEEE802154=m
++CONFIG_IEEE802154_6LOWPAN=m
++CONFIG_IEEE802154_AT86RF230=m
++CONFIG_IEEE802154_DRIVERS=m
++# CONFIG_IEEE802154_FAKEHARD is not set
++CONFIG_IEEE802154_FAKELB=m
++CONFIG_IEEE802154_MRF24J40=m
++CONFIG_IFB=m
++CONFIG_IGB=m
++CONFIG_IGBVF=m
++CONFIG_IGB_DCA=y
++CONFIG_IGB_HWMON=y
++CONFIG_IIO=m
++CONFIG_IIO_ADIS_LIB=m
++CONFIG_IIO_ADIS_LIB_BUFFER=y
++CONFIG_IIO_BUFFER=y
++CONFIG_IIO_BUFFER_CB=y
++CONFIG_IIO_CONSUMERS_PER_TRIGGER=2
++CONFIG_IIO_INTERRUPT_TRIGGER=m
++CONFIG_IIO_KFIFO_BUF=m
++CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
++CONFIG_IIO_SIMPLE_DUMMY=m
++# CONFIG_IIO_SIMPLE_DUMMY_BUFFER is not set
++# CONFIG_IIO_SIMPLE_DUMMY_EVENTS is not set
++CONFIG_IIO_ST_ACCEL_3AXIS=m
++CONFIG_IIO_ST_ACCEL_I2C_3AXIS=m
++CONFIG_IIO_ST_ACCEL_SPI_3AXIS=m
++CONFIG_IIO_ST_GYRO_3AXIS=m
++CONFIG_IIO_ST_GYRO_I2C_3AXIS=m
++CONFIG_IIO_ST_GYRO_SPI_3AXIS=m
++CONFIG_IIO_ST_MAGN_3AXIS=m
++CONFIG_IIO_ST_MAGN_I2C_3AXIS=m
++CONFIG_IIO_ST_MAGN_SPI_3AXIS=m
++CONFIG_IIO_ST_PRESS=m
++CONFIG_IIO_ST_PRESS_I2C=m
++CONFIG_IIO_ST_PRESS_SPI=m
++CONFIG_IIO_ST_SENSORS_CORE=m
++CONFIG_IIO_ST_SENSORS_I2C=m
++CONFIG_IIO_ST_SENSORS_SPI=m
++CONFIG_IIO_SYSFS_TRIGGER=m
++CONFIG_IIO_TRIGGER=y
++CONFIG_IIO_TRIGGERED_BUFFER=m
++# CONFIG_IKCONFIG is not set
++# CONFIG_IMA is not set
++# CONFIG_IMX2_WDT is not set
++# CONFIG_IMX_DMA is not set
++# CONFIG_IMX_SDMA is not set
++CONFIG_IMX_WEIM=y
++CONFIG_INET=y
++CONFIG_INET6_AH=m
++CONFIG_INET6_ESP=m
++CONFIG_INET6_IPCOMP=m
++CONFIG_INET6_TUNNEL=m
++CONFIG_INET6_XFRM_MODE_BEET=m
++CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION=m
++CONFIG_INET6_XFRM_MODE_TRANSPORT=m
++CONFIG_INET6_XFRM_MODE_TUNNEL=m
++CONFIG_INET6_XFRM_TUNNEL=m
++CONFIG_INET_AH=m
++CONFIG_INET_DCCP_DIAG=m
++CONFIG_INET_DIAG=m
++CONFIG_INET_ESP=m
++CONFIG_INET_IPCOMP=m
++CONFIG_INET_LRO=y
++CONFIG_INET_TCP_DIAG=m
++CONFIG_INET_TUNNEL=m
++CONFIG_INET_UDP_DIAG=m
++CONFIG_INET_XFRM_MODE_BEET=m
++CONFIG_INET_XFRM_MODE_TRANSPORT=m
++CONFIG_INET_XFRM_MODE_TUNNEL=m
++CONFIG_INET_XFRM_TUNNEL=m
++CONFIG_INFINIBAND=m
++CONFIG_INFINIBAND_ADDR_TRANS=y
++CONFIG_INFINIBAND_AMSO1100=m
++# CONFIG_INFINIBAND_AMSO1100_DEBUG is not set
++CONFIG_INFINIBAND_CXGB3=m
++# CONFIG_INFINIBAND_CXGB3_DEBUG is not set
++CONFIG_INFINIBAND_CXGB4=m
++CONFIG_INFINIBAND_IPATH=m
++CONFIG_INFINIBAND_IPOIB=m
++CONFIG_INFINIBAND_IPOIB_CM=y
++# CONFIG_INFINIBAND_IPOIB_DEBUG is not set
++CONFIG_INFINIBAND_ISER=m
++CONFIG_INFINIBAND_ISERT=m
++CONFIG_INFINIBAND_MTHCA=m
++# CONFIG_INFINIBAND_MTHCA_DEBUG is not set
++CONFIG_INFINIBAND_NES=m
++# CONFIG_INFINIBAND_NES_DEBUG is not set
++CONFIG_INFINIBAND_OCRDMA=m
++CONFIG_INFINIBAND_QIB=m
++CONFIG_INFINIBAND_QIB_DCA=y
++CONFIG_INFINIBAND_SRP=m
++CONFIG_INFINIBAND_SRPT=m
++CONFIG_INFINIBAND_USER_ACCESS=m
++CONFIG_INFINIBAND_USER_MAD=m
++CONFIG_INFINIBAND_USER_MEM=y
++CONFIG_INFTL=m
++CONFIG_INITRAMFS_SOURCE=""
++CONFIG_INIT_ENV_ARG_LIMIT=32
++CONFIG_INLINE_READ_UNLOCK=y
++CONFIG_INLINE_READ_UNLOCK_IRQ=y
++CONFIG_INLINE_SPIN_UNLOCK_IRQ=y
++CONFIG_INLINE_WRITE_UNLOCK=y
++CONFIG_INLINE_WRITE_UNLOCK_IRQ=y
++CONFIG_INOTIFY_USER=y
++CONFIG_INPUT=y
++CONFIG_INPUT_88PM80X_ONKEY=m
++CONFIG_INPUT_88PM860X_ONKEY=m
++CONFIG_INPUT_AD714X=m
++CONFIG_INPUT_AD714X_I2C=m
++CONFIG_INPUT_AD714X_SPI=m
++CONFIG_INPUT_ADXL34X=m
++CONFIG_INPUT_ADXL34X_I2C=m
++CONFIG_INPUT_ADXL34X_SPI=m
++CONFIG_INPUT_APANEL=m
++CONFIG_INPUT_ARIZONA_HAPTICS=m
++CONFIG_INPUT_ATI_REMOTE2=m
++CONFIG_INPUT_ATLAS_BTNS=m
++CONFIG_INPUT_BMA150=m
++CONFIG_INPUT_CM109=m
++CONFIG_INPUT_CMA3000=m
++CONFIG_INPUT_CMA3000_I2C=m
++CONFIG_INPUT_DA9052_ONKEY=m
++CONFIG_INPUT_DA9055_ONKEY=m
++CONFIG_INPUT_EVBUG=m
++CONFIG_INPUT_EVDEV=y
++CONFIG_INPUT_FF_MEMLESS=m
++CONFIG_INPUT_GP2A=m
++CONFIG_INPUT_GPIO_ROTARY_ENCODER=m
++CONFIG_INPUT_GPIO_TILT_POLLED=m
++CONFIG_INPUT_IMS_PCU=m
++CONFIG_INPUT_JOYDEV=m
++CONFIG_INPUT_JOYSTICK=y
++CONFIG_INPUT_KEYBOARD=y
++CONFIG_INPUT_KEYSPAN_REMOTE=m
++CONFIG_INPUT_KXTJ9=m
++# CONFIG_INPUT_KXTJ9_POLLED_MODE is not set
++CONFIG_INPUT_MATRIXKMAP=m
++CONFIG_INPUT_MAX8925_ONKEY=m
++CONFIG_INPUT_MC13783_PWRBUTTON=m
++CONFIG_INPUT_MISC=y
++CONFIG_INPUT_MMA8450=m
++CONFIG_INPUT_MOUSE=y
++CONFIG_INPUT_MOUSEDEV=y
++CONFIG_INPUT_MOUSEDEV_PSAUX=y
++CONFIG_INPUT_MOUSEDEV_SCREEN_X=1024
++CONFIG_INPUT_MOUSEDEV_SCREEN_Y=768
++CONFIG_INPUT_MPU3050=m
++CONFIG_INPUT_PCAP=m
++CONFIG_INPUT_PCF50633_PMU=m
++CONFIG_INPUT_PCF8574=m
++CONFIG_INPUT_PCSPKR=m
++CONFIG_INPUT_POLLDEV=m
++CONFIG_INPUT_POWERMATE=m
++CONFIG_INPUT_PWM_BEEPER=m
++CONFIG_INPUT_RETU_PWRBUTTON=m
++CONFIG_INPUT_SPARSEKMAP=m
++CONFIG_INPUT_TABLET=y
++CONFIG_INPUT_TOUCHSCREEN=y
++CONFIG_INPUT_TWL4030_PWRBUTTON=m
++CONFIG_INPUT_TWL4030_VIBRA=m
++CONFIG_INPUT_TWL6040_VIBRA=m
++CONFIG_INPUT_UINPUT=y
++CONFIG_INPUT_WISTRON_BTNS=m
++CONFIG_INPUT_WM831X_ON=m
++CONFIG_INPUT_XEN_KBDDEV_FRONTEND=m
++CONFIG_INPUT_YEALINK=m
++CONFIG_INSTRUCTION_DECODER=y
++CONFIG_INTEGRITY=y
++CONFIG_INTEGRITY_ASYMMETRIC_KEYS=y
++CONFIG_INTEGRITY_AUDIT=y
++CONFIG_INTEGRITY_SIGNATURE=y
++CONFIG_INTEL_IDLE=y
++CONFIG_INTEL_IOATDMA=m
++CONFIG_INTEL_IOMMU=y
++# CONFIG_INTEL_IOMMU_DEFAULT_ON is not set
++CONFIG_INTEL_IOMMU_FLOPPY_WA=y
++CONFIG_INTEL_IPS=m
++CONFIG_INTEL_MEI=m
++CONFIG_INTEL_MEI_ME=m
++CONFIG_INTEL_MENLOW=m
++CONFIG_INTEL_MFLD_THERMAL=m
++CONFIG_INTEL_MID_DMAC=m
++CONFIG_INTEL_MID_POWER_BUTTON=m
++CONFIG_INTEL_MID_PTI=m
++CONFIG_INTEL_OAKTRAIL=m
++CONFIG_INTEL_POWERCLAMP=m
++CONFIG_INTEL_RST=m
++CONFIG_INTEL_SCU_IPC=y
++CONFIG_INTEL_SCU_IPC_UTIL=m
++CONFIG_INTEL_SCU_WATCHDOG=y
++CONFIG_INTEL_SMARTCONNECT=m
++CONFIG_INTEL_TXT=y
++CONFIG_INTERVAL_TREE_TEST=m
++CONFIG_INV_MPU6050_IIO=m
++CONFIG_IOMMU_API=y
++# CONFIG_IOMMU_DEBUG is not set
++CONFIG_IOMMU_HELPER=y
++# CONFIG_IOMMU_STRESS is not set
++CONFIG_IOMMU_SUPPORT=y
++CONFIG_IOSCHED_CFQ=y
++CONFIG_IOSCHED_DEADLINE=y
++CONFIG_IOSCHED_NOOP=y
++# CONFIG_IO_DELAY_0X80 is not set
++CONFIG_IO_DELAY_0XED=y
++# CONFIG_IO_DELAY_NONE is not set
++CONFIG_IO_DELAY_TYPE_0X80=0
++CONFIG_IO_DELAY_TYPE_0XED=1
++CONFIG_IO_DELAY_TYPE_NONE=3
++CONFIG_IO_DELAY_TYPE_UDELAY=2
++# CONFIG_IO_DELAY_UDELAY is not set
++CONFIG_IP1000=m
++CONFIG_IP6_NF_FILTER=m
++CONFIG_IP6_NF_IPTABLES=m
++CONFIG_IP6_NF_MANGLE=m
++CONFIG_IP6_NF_MATCH_AH=m
++CONFIG_IP6_NF_MATCH_EUI64=m
++CONFIG_IP6_NF_MATCH_FRAG=m
++CONFIG_IP6_NF_MATCH_HL=m
++CONFIG_IP6_NF_MATCH_IPV6HEADER=m
++CONFIG_IP6_NF_MATCH_MH=m
++CONFIG_IP6_NF_MATCH_OPTS=m
++CONFIG_IP6_NF_MATCH_RPFILTER=m
++CONFIG_IP6_NF_MATCH_RT=m
++CONFIG_IP6_NF_RAW=m
++CONFIG_IP6_NF_SECURITY=m
++CONFIG_IP6_NF_TARGET_HL=m
++CONFIG_IP6_NF_TARGET_MASQUERADE=m
++CONFIG_IP6_NF_TARGET_NPT=m
++CONFIG_IP6_NF_TARGET_REJECT=m
++CONFIG_IPACK_BUS=m
++CONFIG_IPC_NS=y
++CONFIG_IPDDP=m
++CONFIG_IPDDP_ENCAP=y
++CONFIG_IPMI_DEVICE_INTERFACE=m
++CONFIG_IPMI_HANDLER=m
++# CONFIG_IPMI_PANIC_EVENT is not set
++CONFIG_IPMI_POWEROFF=m
++CONFIG_IPMI_SI=m
++CONFIG_IPMI_WATCHDOG=m
++CONFIG_IPPP_FILTER=y
++CONFIG_IPV6=y
++CONFIG_IPV6_GRE=m
++CONFIG_IPV6_MIP6=m
++CONFIG_IPV6_MROUTE=y
++CONFIG_IPV6_MROUTE_MULTIPLE_TABLES=y
++CONFIG_IPV6_MULTIPLE_TABLES=y
++CONFIG_IPV6_NDISC_NODETYPE=y
++# CONFIG_IPV6_OPTIMISTIC_DAD is not set
++CONFIG_IPV6_PIMSM_V2=y
++CONFIG_IPV6_PRIVACY=y
++CONFIG_IPV6_ROUTER_PREF=y
++CONFIG_IPV6_ROUTE_INFO=y
++CONFIG_IPV6_SIT=m
++CONFIG_IPV6_SIT_6RD=y
++CONFIG_IPV6_SUBTREES=y
++CONFIG_IPV6_TUNNEL=m
++CONFIG_IPW2100=m
++# CONFIG_IPW2100_DEBUG is not set
++CONFIG_IPW2100_MONITOR=y
++CONFIG_IPW2200=m
++# CONFIG_IPW2200_DEBUG is not set
++CONFIG_IPW2200_MONITOR=y
++CONFIG_IPW2200_PROMISCUOUS=y
++CONFIG_IPW2200_QOS=y
++CONFIG_IPW2200_RADIOTAP=y
++CONFIG_IPWIRELESS=m
++CONFIG_IPX=m
++# CONFIG_IPX_INTERN is not set
++CONFIG_IP_ADVANCED_ROUTER=y
++CONFIG_IP_DCCP=m
++# CONFIG_IP_DCCP_CCID2_DEBUG is not set
++# CONFIG_IP_DCCP_CCID3 is not set
++# CONFIG_IP_DCCP_DEBUG is not set
++CONFIG_IP_FIB_TRIE_STATS=y
++CONFIG_IP_MROUTE=y
++# CONFIG_IP_MROUTE_MULTIPLE_TABLES is not set
++CONFIG_IP_MULTICAST=y
++CONFIG_IP_MULTIPLE_TABLES=y
++CONFIG_IP_NF_ARPFILTER=m
++CONFIG_IP_NF_ARPTABLES=m
++CONFIG_IP_NF_ARP_MANGLE=m
++CONFIG_IP_NF_FILTER=m
++CONFIG_IP_NF_IPTABLES=m
++CONFIG_IP_NF_MANGLE=m
++CONFIG_IP_NF_MATCH_AH=m
++CONFIG_IP_NF_MATCH_ECN=m
++CONFIG_IP_NF_MATCH_RPFILTER=m
++CONFIG_IP_NF_MATCH_TTL=m
++CONFIG_IP_NF_RAW=m
++CONFIG_IP_NF_SECURITY=m
++CONFIG_IP_NF_TARGET_CLUSTERIP=m
++CONFIG_IP_NF_TARGET_ECN=m
++CONFIG_IP_NF_TARGET_MASQUERADE=m
++CONFIG_IP_NF_TARGET_NETMAP=m
++CONFIG_IP_NF_TARGET_REDIRECT=m
++CONFIG_IP_NF_TARGET_REJECT=m
++CONFIG_IP_NF_TARGET_TTL=m
++CONFIG_IP_NF_TARGET_ULOG=m
++CONFIG_IP_PIMSM_V1=y
++CONFIG_IP_PIMSM_V2=y
++CONFIG_IP_PNP=y
++# CONFIG_IP_PNP_BOOTP is not set
++CONFIG_IP_PNP_DHCP=y
++# CONFIG_IP_PNP_RARP is not set
++CONFIG_IP_ROUTE_CLASSID=y
++CONFIG_IP_ROUTE_MULTIPATH=y
++CONFIG_IP_ROUTE_VERBOSE=y
++CONFIG_IP_SCTP=m
++CONFIG_IP_SET=m
++CONFIG_IP_SET_BITMAP_IP=m
++CONFIG_IP_SET_BITMAP_IPMAC=m
++CONFIG_IP_SET_BITMAP_PORT=m
++CONFIG_IP_SET_HASH_IP=m
++CONFIG_IP_SET_HASH_IPPORT=m
++CONFIG_IP_SET_HASH_IPPORTIP=m
++CONFIG_IP_SET_HASH_IPPORTNET=m
++CONFIG_IP_SET_HASH_NET=m
++CONFIG_IP_SET_HASH_NETIFACE=m
++CONFIG_IP_SET_HASH_NETPORT=m
++CONFIG_IP_SET_LIST_SET=m
++CONFIG_IP_SET_MAX=256
++CONFIG_IP_VS=m
++# CONFIG_IP_VS_DEBUG is not set
++CONFIG_IP_VS_DH=m
++CONFIG_IP_VS_FTP=m
++# CONFIG_IP_VS_IPV6 is not set
++CONFIG_IP_VS_LBLC=m
++CONFIG_IP_VS_LBLCR=m
++CONFIG_IP_VS_LC=m
++CONFIG_IP_VS_NFCT=y
++CONFIG_IP_VS_NQ=m
++CONFIG_IP_VS_PE_SIP=m
++CONFIG_IP_VS_PROTO_AH=y
++CONFIG_IP_VS_PROTO_AH_ESP=y
++CONFIG_IP_VS_PROTO_ESP=y
++CONFIG_IP_VS_PROTO_SCTP=y
++CONFIG_IP_VS_PROTO_TCP=y
++CONFIG_IP_VS_PROTO_UDP=y
++CONFIG_IP_VS_RR=m
++CONFIG_IP_VS_SED=m
++CONFIG_IP_VS_SH=m
++CONFIG_IP_VS_SH_TAB_BITS=8
++CONFIG_IP_VS_TAB_BITS=12
++CONFIG_IP_VS_WLC=m
++CONFIG_IP_VS_WRR=m
++CONFIG_IRCOMM=m
++CONFIG_IRDA=m
++CONFIG_IRDA_CACHE_LAST_LSAP=y
++# CONFIG_IRDA_DEBUG is not set
++CONFIG_IRDA_FAST_RR=y
++CONFIG_IRDA_ULTRA=y
++CONFIG_IRLAN=m
++CONFIG_IRNET=m
++CONFIG_IRQCHIP=y
++# CONFIG_IRQSOFF_TRACER is not set
++CONFIG_IRQ_DOMAIN=y
++# CONFIG_IRQ_DOMAIN_DEBUG is not set
++CONFIG_IRQ_FORCED_THREADING=y
++CONFIG_IRQ_REMAP=y
++# CONFIG_IRQ_TIME_ACCOUNTING is not set
++CONFIG_IRQ_WORK=y
++CONFIG_IRTTY_SIR=m
++CONFIG_IR_ENE=m
++CONFIG_IR_FINTEK=m
++CONFIG_IR_GPIO_CIR=m
++CONFIG_IR_IGUANA=m
++CONFIG_IR_IMON=m
++CONFIG_IR_ITE_CIR=m
++CONFIG_IR_JVC_DECODER=m
++CONFIG_IR_LIRC_CODEC=m
++CONFIG_IR_MCEUSB=m
++CONFIG_IR_MCE_KBD_DECODER=m
++CONFIG_IR_NEC_DECODER=m
++CONFIG_IR_NUVOTON=m
++CONFIG_IR_RC5_DECODER=m
++CONFIG_IR_RC5_SZ_DECODER=m
++CONFIG_IR_RC6_DECODER=m
++CONFIG_IR_REDRAT3=m
++CONFIG_IR_SANYO_DECODER=m
++CONFIG_IR_SONY_DECODER=m
++CONFIG_IR_STREAMZAP=m
++CONFIG_IR_TTUSBIR=m
++CONFIG_IR_WINBOND_CIR=m
++CONFIG_ISA=y
++CONFIG_ISAPNP=y
++CONFIG_ISA_DMA_API=y
++CONFIG_ISCSI_BOOT_SYSFS=m
++CONFIG_ISCSI_IBFT=m
++CONFIG_ISCSI_IBFT_FIND=y
++CONFIG_ISCSI_TARGET=m
++CONFIG_ISCSI_TCP=m
++CONFIG_ISDN=y
++CONFIG_ISDN_AUDIO=y
++CONFIG_ISDN_CAPI=m
++CONFIG_ISDN_CAPI_CAPI20=m
++CONFIG_ISDN_CAPI_CAPIDRV=m
++CONFIG_ISDN_CAPI_MIDDLEWARE=y
++CONFIG_ISDN_DIVAS=m
++CONFIG_ISDN_DIVAS_BRIPCI=y
++CONFIG_ISDN_DIVAS_DIVACAPI=m
++CONFIG_ISDN_DIVAS_MAINT=m
++CONFIG_ISDN_DIVAS_PRIPCI=y
++CONFIG_ISDN_DIVAS_USERIDI=m
++CONFIG_ISDN_DIVERSION=m
++CONFIG_ISDN_DRV_ACT2000=m
++CONFIG_ISDN_DRV_AVMB1_AVM_CS=m
++CONFIG_ISDN_DRV_AVMB1_B1ISA=m
++CONFIG_ISDN_DRV_AVMB1_B1PCI=m
++CONFIG_ISDN_DRV_AVMB1_B1PCIV4=y
++CONFIG_ISDN_DRV_AVMB1_B1PCMCIA=m
++CONFIG_ISDN_DRV_AVMB1_C4=m
++CONFIG_ISDN_DRV_AVMB1_T1ISA=m
++CONFIG_ISDN_DRV_AVMB1_T1PCI=m
++CONFIG_ISDN_DRV_AVMB1_VERBOSE_REASON=y
++CONFIG_ISDN_DRV_GIGASET=m
++CONFIG_ISDN_DRV_HISAX=m
++CONFIG_ISDN_DRV_ICN=m
++CONFIG_ISDN_DRV_PCBIT=m
++CONFIG_ISDN_DRV_SC=m
++CONFIG_ISDN_HDLC=m
++CONFIG_ISDN_I4L=m
++CONFIG_ISDN_MPP=y
++CONFIG_ISDN_PPP=y
++CONFIG_ISDN_PPP_BSDCOMP=m
++CONFIG_ISDN_PPP_VJ=y
++CONFIG_ISDN_TTY_FAX=y
++CONFIG_ISDN_X25=y
++CONFIG_ISI=m
++CONFIG_ISL29003=m
++CONFIG_ISL29020=m
++CONFIG_ISO9660_FS=m
++CONFIG_IT8712F_WDT=m
++CONFIG_IT87_WDT=m
++CONFIG_ITCO_VENDOR_SUPPORT=y
++CONFIG_ITCO_WDT=m
++CONFIG_ITG3200=m
++CONFIG_IWL3945=m
++CONFIG_IWL4965=m
++CONFIG_IWLDVM=m
++CONFIG_IWLEGACY=m
++# CONFIG_IWLEGACY_DEBUG is not set
++CONFIG_IWLEGACY_DEBUGFS=y
++CONFIG_IWLMVM=m
++CONFIG_IWLWIFI=m
++# CONFIG_IWLWIFI_DEBUG is not set
++CONFIG_IWLWIFI_DEBUGFS=y
++CONFIG_IWLWIFI_DEVICE_TRACING=y
++CONFIG_IWLWIFI_OPMODE_MODULAR=y
++# CONFIG_IWLWIFI_P2P is not set
++CONFIG_IXGB=m
++CONFIG_IXGBE=m
++CONFIG_IXGBEVF=m
++CONFIG_IXGBE_DCA=y
++CONFIG_IXGBE_DCB=y
++CONFIG_IXGBE_HWMON=y
++CONFIG_JBD=y
++CONFIG_JBD2=y
++# CONFIG_JBD2_DEBUG is not set
++# CONFIG_JBD_DEBUG is not set
++CONFIG_JFFS2_CMODE_FAVOURLZO=y
++# CONFIG_JFFS2_CMODE_NONE is not set
++# CONFIG_JFFS2_CMODE_PRIORITY is not set
++# CONFIG_JFFS2_CMODE_SIZE is not set
++CONFIG_JFFS2_COMPRESSION_OPTIONS=y
++CONFIG_JFFS2_FS=m
++CONFIG_JFFS2_FS_DEBUG=0
++# CONFIG_JFFS2_FS_WBUF_VERIFY is not set
++CONFIG_JFFS2_FS_WRITEBUFFER=y
++# CONFIG_JFFS2_FS_XATTR is not set
++CONFIG_JFFS2_LZO=y
++CONFIG_JFFS2_RTIME=y
++# CONFIG_JFFS2_RUBIN is not set
++# CONFIG_JFFS2_SUMMARY is not set
++CONFIG_JFFS2_ZLIB=y
++# CONFIG_JFS_DEBUG is not set
++CONFIG_JFS_FS=m
++CONFIG_JFS_POSIX_ACL=y
++CONFIG_JFS_SECURITY=y
++CONFIG_JFS_STATISTICS=y
++CONFIG_JME=m
++CONFIG_JOLIET=y
++CONFIG_JOYSTICK_A3D=m
++CONFIG_JOYSTICK_ADI=m
++CONFIG_JOYSTICK_ANALOG=m
++CONFIG_JOYSTICK_AS5011=m
++CONFIG_JOYSTICK_COBRA=m
++CONFIG_JOYSTICK_DB9=m
++CONFIG_JOYSTICK_GAMECON=m
++CONFIG_JOYSTICK_GF2K=m
++CONFIG_JOYSTICK_GRIP=m
++CONFIG_JOYSTICK_GRIP_MP=m
++CONFIG_JOYSTICK_GUILLEMOT=m
++CONFIG_JOYSTICK_IFORCE=m
++CONFIG_JOYSTICK_IFORCE_232=y
++CONFIG_JOYSTICK_IFORCE_USB=y
++CONFIG_JOYSTICK_INTERACT=m
++CONFIG_JOYSTICK_JOYDUMP=m
++CONFIG_JOYSTICK_MAGELLAN=m
++CONFIG_JOYSTICK_SIDEWINDER=m
++CONFIG_JOYSTICK_SPACEBALL=m
++CONFIG_JOYSTICK_SPACEORB=m
++CONFIG_JOYSTICK_STINGER=m
++CONFIG_JOYSTICK_TMDC=m
++CONFIG_JOYSTICK_TURBOGRAFX=m
++CONFIG_JOYSTICK_TWIDJOY=m
++CONFIG_JOYSTICK_WALKERA0701=m
++CONFIG_JOYSTICK_WARRIOR=m
++CONFIG_JOYSTICK_XPAD=m
++CONFIG_JOYSTICK_XPAD_FF=y
++CONFIG_JOYSTICK_XPAD_LEDS=y
++CONFIG_JOYSTICK_ZHENHUA=m
++CONFIG_JUMP_LABEL=y
++CONFIG_KALLSYMS=y
++CONFIG_KALLSYMS_ALL=y
++CONFIG_KARMA_PARTITION=y
++CONFIG_KDB_CONTINUE_CATASTROPHIC=0
++CONFIG_KDB_KEYBOARD=y
++CONFIG_KEMPLD_WDT=m
++# CONFIG_KERNEL_BZIP2 is not set
++CONFIG_KERNEL_GZIP=y
++# CONFIG_KERNEL_LZ4 is not set
++# CONFIG_KERNEL_LZMA is not set
++# CONFIG_KERNEL_LZO is not set
++# CONFIG_KERNEL_XZ is not set
++CONFIG_KEXEC=y
++CONFIG_KEXEC_JUMP=y
++CONFIG_KEYBOARD_ADP5520=m
++CONFIG_KEYBOARD_ADP5588=m
++CONFIG_KEYBOARD_ADP5589=m
++CONFIG_KEYBOARD_ATKBD=y
++CONFIG_KEYBOARD_CROS_EC=m
++CONFIG_KEYBOARD_GPIO=m
++CONFIG_KEYBOARD_GPIO_POLLED=m
++# CONFIG_KEYBOARD_IMX is not set
++CONFIG_KEYBOARD_LKKBD=m
++CONFIG_KEYBOARD_LM8323=m
++CONFIG_KEYBOARD_LM8333=m
++CONFIG_KEYBOARD_MATRIX=m
++CONFIG_KEYBOARD_MAX7359=m
++CONFIG_KEYBOARD_MCS=m
++CONFIG_KEYBOARD_MPR121=m
++CONFIG_KEYBOARD_NEWTON=m
++CONFIG_KEYBOARD_NVEC=m
++CONFIG_KEYBOARD_OMAP4=m
++CONFIG_KEYBOARD_OPENCORES=m
++CONFIG_KEYBOARD_QT1070=m
++CONFIG_KEYBOARD_QT2160=m
++CONFIG_KEYBOARD_SAMSUNG=m
++CONFIG_KEYBOARD_STMPE=m
++CONFIG_KEYBOARD_STOWAWAY=m
++CONFIG_KEYBOARD_SUNKBD=m
++CONFIG_KEYBOARD_TC3589X=m
++CONFIG_KEYBOARD_TCA6416=m
++CONFIG_KEYBOARD_TCA8418=m
++CONFIG_KEYBOARD_TEGRA=m
++CONFIG_KEYBOARD_TWL4030=m
++CONFIG_KEYBOARD_XTKBD=m
++CONFIG_KEYS=y
++CONFIG_KEYS_COMPAT=y
++# CONFIG_KEYS_DEBUG_PROC_KEYS is not set
++CONFIG_KGDB=y
++CONFIG_KGDB_KDB=y
++CONFIG_KGDB_LOW_LEVEL_TRAP=y
++CONFIG_KGDB_SERIAL_CONSOLE=y
++# CONFIG_KGDB_TESTS is not set
++CONFIG_KINGSUN_DONGLE=m
++CONFIG_KPROBES=y
++CONFIG_KPROBES_ON_FTRACE=y
++# CONFIG_KPROBES_SANITY_TEST is not set
++CONFIG_KPROBE_EVENT=y
++CONFIG_KRETPROBES=y
++CONFIG_KS0108=m
++CONFIG_KS0108_DELAY=2
++CONFIG_KS0108_PORT=0x378
++CONFIG_KS8842=m
++CONFIG_KS8851=m
++CONFIG_KS8851_MLL=m
++CONFIG_KS959_DONGLE=m
++CONFIG_KSDAZZLE_DONGLE=m
++CONFIG_KSZ884X_PCI=m
++CONFIG_KTIME_SCALAR=y
++CONFIG_KUSER_HELPERS=y
++CONFIG_KVM_AMD=m
++CONFIG_KVM_APIC_ARCHITECTURE=y
++CONFIG_KVM_ARM_HOST=y
++CONFIG_KVM_ARM_MAX_VCPUS=4
++CONFIG_KVM_ARM_TIMER=y
++CONFIG_KVM_ARM_VGIC=y
++CONFIG_KVM_ASYNC_PF=y
++CONFIG_KVM_DEVICE_ASSIGNMENT=y
++CONFIG_KVM_GUEST=y
++CONFIG_KVM_INTEL=m
++CONFIG_KVM_MMIO=y
++# CONFIG_KVM_MMU_AUDIT is not set
++CONFIG_KXSD9=m
++CONFIG_L2TP=m
++CONFIG_L2TP_DEBUGFS=m
++CONFIG_L2TP_ETH=m
++CONFIG_L2TP_IP=m
++CONFIG_L2TP_V3=y
++CONFIG_LANCE=m
++CONFIG_LANMEDIA=m
++CONFIG_LAPB=m
++CONFIG_LAPBETHER=m
++CONFIG_LATENCYTOP=y
++CONFIG_LATTICE_ECP3_CONFIG=m
++CONFIG_LBDAF=y
++CONFIG_LCD_AMS369FG06=m
++CONFIG_LCD_CLASS_DEVICE=m
++CONFIG_LCD_HX8357=m
++CONFIG_LCD_ILI922X=m
++CONFIG_LCD_ILI9320=m
++CONFIG_LCD_L4F00242T03=m
++CONFIG_LCD_LD9040=m
++CONFIG_LCD_LMS283GF05=m
++CONFIG_LCD_LMS501KF03=m
++CONFIG_LCD_LTV350QV=m
++CONFIG_LCD_PLATFORM=m
++CONFIG_LCD_S6E63M0=m
++CONFIG_LCD_TDO24M=m
++CONFIG_LCD_VGG2432A4=m
++# CONFIG_LDM_DEBUG is not set
++CONFIG_LDM_PARTITION=y
++CONFIG_LEDS_88PM860X=m
++CONFIG_LEDS_ADP5520=m
++CONFIG_LEDS_ASIC3=y
++CONFIG_LEDS_ATMEL_PWM=m
++CONFIG_LEDS_BD2802=m
++CONFIG_LEDS_BLINKM=m
++CONFIG_LEDS_CLASS=y
++CONFIG_LEDS_CLEVO_MAIL=m
++CONFIG_LEDS_DA903X=m
++CONFIG_LEDS_DA9052=m
++CONFIG_LEDS_DAC124S085=m
++CONFIG_LEDS_DELL_NETBOOKS=m
++CONFIG_LEDS_GPIO=m
++CONFIG_LEDS_INTEL_SS4200=m
++CONFIG_LEDS_LM3530=m
++CONFIG_LEDS_LM3533=m
++CONFIG_LEDS_LM355x=m
++CONFIG_LEDS_LM3642=m
++CONFIG_LEDS_LP3944=m
++CONFIG_LEDS_LP5521=m
++CONFIG_LEDS_LP5523=m
++CONFIG_LEDS_LP5562=m
++CONFIG_LEDS_LP55XX_COMMON=m
++CONFIG_LEDS_LP8788=m
++CONFIG_LEDS_LT3593=m
++CONFIG_LEDS_MAX8997=m
++CONFIG_LEDS_MC13783=m
++CONFIG_LEDS_NET48XX=m
++CONFIG_LEDS_OT200=m
++CONFIG_LEDS_PCA9532=m
++CONFIG_LEDS_PCA9532_GPIO=y
++CONFIG_LEDS_PCA955X=m
++CONFIG_LEDS_PCA9633=m
++CONFIG_LEDS_PWM=m
++CONFIG_LEDS_REGULATOR=m
++CONFIG_LEDS_RENESAS_TPU=y
++CONFIG_LEDS_TCA6507=m
++CONFIG_LEDS_TRIGGERS=y
++CONFIG_LEDS_TRIGGER_BACKLIGHT=m
++CONFIG_LEDS_TRIGGER_CAMERA=m
++CONFIG_LEDS_TRIGGER_CPU=y
++CONFIG_LEDS_TRIGGER_DEFAULT_ON=m
++CONFIG_LEDS_TRIGGER_GPIO=m
++CONFIG_LEDS_TRIGGER_HEARTBEAT=m
++CONFIG_LEDS_TRIGGER_ONESHOT=m
++CONFIG_LEDS_TRIGGER_TIMER=m
++CONFIG_LEDS_TRIGGER_TRANSIENT=m
++CONFIG_LEDS_WM831X_STATUS=m
++CONFIG_LEDS_WM8350=m
++CONFIG_LEDS_WRAP=m
++CONFIG_LEGACY_PTYS=y
++CONFIG_LEGACY_PTY_COUNT=0
++# CONFIG_LGUEST is not set
++# CONFIG_LGUEST_GUEST is not set
++CONFIG_LIB80211=m
++CONFIG_LIB80211_CRYPT_CCMP=m
++CONFIG_LIB80211_CRYPT_TKIP=m
++CONFIG_LIB80211_CRYPT_WEP=m
++# CONFIG_LIB80211_DEBUG is not set
++CONFIG_LIBCRC32C=m
++CONFIG_LIBERTAS=m
++CONFIG_LIBERTAS_CS=m
++# CONFIG_LIBERTAS_DEBUG is not set
++CONFIG_LIBERTAS_SDIO=m
++CONFIG_LIBERTAS_SPI=m
++CONFIG_LIBERTAS_THINFIRM=m
++# CONFIG_LIBERTAS_THINFIRM_DEBUG is not set
++CONFIG_LIBERTAS_THINFIRM_USB=m
++CONFIG_LIBERTAS_USB=m
++CONFIG_LIBFC=m
++CONFIG_LIBFCOE=m
++CONFIG_LIBIPW=m
++# CONFIG_LIBIPW_DEBUG is not set
++CONFIG_LINE6_USB=m
++# CONFIG_LINE6_USB_IMPULSE_RESPONSE is not set
++CONFIG_LIRC=m
++CONFIG_LIRC_BT829=m
++CONFIG_LIRC_IGORPLUGUSB=m
++CONFIG_LIRC_IMON=m
++CONFIG_LIRC_PARALLEL=m
++CONFIG_LIRC_SASEM=m
++CONFIG_LIRC_SERIAL=m
++CONFIG_LIRC_SERIAL_TRANSMITTER=y
++CONFIG_LIRC_SIR=m
++CONFIG_LIRC_STAGING=y
++CONFIG_LIRC_ZILOG=m
++CONFIG_LITELINK_DONGLE=m
++# CONFIG_LKDTM is not set
++CONFIG_LLC=m
++CONFIG_LLC2=m
++CONFIG_LOCALVERSION=""
++# CONFIG_LOCALVERSION_AUTO is not set
++CONFIG_LOCAL_TIMERS=y
++CONFIG_LOCKD=m
++CONFIG_LOCKDEP_SUPPORT=y
++CONFIG_LOCKD_V4=y
++CONFIG_LOCKUP_DETECTOR=y
++# CONFIG_LOCK_STAT is not set
++# CONFIG_LOGFS is not set
++CONFIG_LOGIG940_FF=y
++CONFIG_LOGIRUMBLEPAD2_FF=y
++CONFIG_LOGITECH_FF=y
++CONFIG_LOGIWHEELS_FF=y
++# CONFIG_LOGO is not set
++CONFIG_LOOPBACK_TARGET=m
++CONFIG_LP8788_ADC=y
++CONFIG_LPC_ICH=m
++CONFIG_LPC_SCH=m
++# CONFIG_LP_CONSOLE is not set
++CONFIG_LRU_CACHE=m
++CONFIG_LSI_ET1011C_PHY=y
++CONFIG_LSM_MMAP_MIN_ADDR=0
++CONFIG_LTPC=m
++CONFIG_LXT_PHY=y
++CONFIG_LZ4HC_COMPRESS=m
++CONFIG_LZ4_COMPRESS=m
++CONFIG_LZ4_DECOMPRESS=y
++CONFIG_LZO_COMPRESS=y
++CONFIG_LZO_DECOMPRESS=y
++CONFIG_M25PXX_USE_FAST_READ=y
++# CONFIG_M486 is not set
++# CONFIG_M586 is not set
++# CONFIG_M586MMX is not set
++# CONFIG_M586TSC is not set
++CONFIG_M686=y
++CONFIG_MA600_DONGLE=m
++CONFIG_MAC80211=m
++CONFIG_MAC80211_DEBUGFS=y
++# CONFIG_MAC80211_DEBUG_MENU is not set
++CONFIG_MAC80211_HAS_RC=y
++CONFIG_MAC80211_HWSIM=m
++CONFIG_MAC80211_LEDS=y
++CONFIG_MAC80211_MESH=y
++CONFIG_MAC80211_MESSAGE_TRACING=y
++CONFIG_MAC80211_RC_DEFAULT="minstrel_ht"
++CONFIG_MAC80211_RC_DEFAULT_MINSTREL=y
++# CONFIG_MAC80211_RC_DEFAULT_PID is not set
++CONFIG_MAC80211_RC_MINSTREL=y
++CONFIG_MAC80211_RC_MINSTREL_HT=y
++CONFIG_MAC80211_RC_PID=y
++CONFIG_MAC802154=m
++CONFIG_MACB=m
++CONFIG_MACHZ_WDT=m
++# CONFIG_MACH_CM_T35 is not set
++CONFIG_MACH_CM_T3517=y
++# CONFIG_MACH_CRANEBOARD is not set
++# CONFIG_MACH_DEVKIT8000 is not set
++# CONFIG_MACH_EUKREA_CPUIMX51SD is not set
++CONFIG_MACH_IGEP0020=y
++CONFIG_MACH_IGEP0030=y
++# CONFIG_MACH_IMX51_DT is not set
++# CONFIG_MACH_MX51_BABBAGE is not set
++CONFIG_MACH_NOKIA_RM680=y
++# CONFIG_MACH_NOKIA_RX51 is not set
++# CONFIG_MACH_OMAP3517EVM is not set
++CONFIG_MACH_OMAP3530_LV_SOM=y
++CONFIG_MACH_OMAP3EVM=y
++CONFIG_MACH_OMAP3_BEAGLE=y
++CONFIG_MACH_OMAP3_PANDORA=y
++CONFIG_MACH_OMAP3_TORPEDO=y
++CONFIG_MACH_OMAP_3430SDP=y
++CONFIG_MACH_OMAP_3630SDP=y
++CONFIG_MACH_OMAP_GENERIC=y
++CONFIG_MACH_OMAP_LDP=y
++CONFIG_MACH_OMAP_ZOOM2=y
++CONFIG_MACH_OMAP_ZOOM3=y
++CONFIG_MACH_OVERO=y
++CONFIG_MACH_SBC3530=y
++CONFIG_MACH_TI8148EVM=y
++CONFIG_MACH_TI8168EVM=y
++CONFIG_MACH_TOUCHBOOK=y
++CONFIG_MACINTOSH_DRIVERS=y
++CONFIG_MACVLAN=m
++CONFIG_MACVTAP=m
++CONFIG_MAC_EMUMOUSEBTN=m
++CONFIG_MAC_PARTITION=y
++CONFIG_MAGIC_SYSRQ=y
++CONFIG_MAILBOX=y
++CONFIG_MANTIS_CORE=m
++CONFIG_MARVELL_PHY=y
++# CONFIG_MATH_EMULATION is not set
++# CONFIG_MATOM is not set
++CONFIG_MAX1363=m
++CONFIG_MAX517=m
++CONFIG_MAX63XX_WATCHDOG=m
++CONFIG_MAX8925_POWER=m
++# CONFIG_MAXSMP is not set
++CONFIG_MAX_RAW_DEVS=256
++# CONFIG_MCORE2 is not set
++CONFIG_MCP2120_DONGLE=m
++CONFIG_MCP320X=m
++CONFIG_MCP4725=m
++CONFIG_MCPM=y
++# CONFIG_MCRUSOE is not set
++CONFIG_MCS_FIR=m
++# CONFIG_MCYRIXIII is not set
++CONFIG_MD=y
++CONFIG_MDA_CONSOLE=m
++CONFIG_MDIO=m
++CONFIG_MDIO_BITBANG=y
++CONFIG_MDIO_BUS_MUX=y
++CONFIG_MDIO_BUS_MUX_GPIO=y
++CONFIG_MDIO_BUS_MUX_MMIOREG=y
++CONFIG_MDIO_GPIO=y
++CONFIG_MD_AUTODETECT=y
++CONFIG_MD_FAULTY=m
++CONFIG_MD_LINEAR=m
++CONFIG_MD_MULTIPATH=m
++CONFIG_MD_RAID0=m
++CONFIG_MD_RAID1=m
++CONFIG_MD_RAID10=m
++CONFIG_MD_RAID456=m
++CONFIG_MEDIA_ALTERA_CI=m
++CONFIG_MEDIA_ANALOG_TV_SUPPORT=y
++CONFIG_MEDIA_ATTACH=y
++CONFIG_MEDIA_CAMERA_SUPPORT=y
++CONFIG_MEDIA_COMMON_OPTIONS=y
++# CONFIG_MEDIA_CONTROLLER is not set
++CONFIG_MEDIA_DIGITAL_TV_SUPPORT=y
++CONFIG_MEDIA_PARPORT_SUPPORT=y
++CONFIG_MEDIA_PCI_SUPPORT=y
++CONFIG_MEDIA_RADIO_SUPPORT=y
++CONFIG_MEDIA_RC_SUPPORT=y
++CONFIG_MEDIA_SUBDRV_AUTOSELECT=y
++CONFIG_MEDIA_SUPPORT=m
++CONFIG_MEDIA_TUNER=m
++CONFIG_MEDIA_TUNER_E4000=m
++CONFIG_MEDIA_TUNER_FC0011=m
++CONFIG_MEDIA_TUNER_FC0012=m
++CONFIG_MEDIA_TUNER_FC0013=m
++CONFIG_MEDIA_TUNER_FC2580=m
++CONFIG_MEDIA_TUNER_IT913X=m
++CONFIG_MEDIA_TUNER_MAX2165=m
++CONFIG_MEDIA_TUNER_MC44S803=m
++CONFIG_MEDIA_TUNER_MT2060=m
++CONFIG_MEDIA_TUNER_MT2063=m
++CONFIG_MEDIA_TUNER_MT20XX=m
++CONFIG_MEDIA_TUNER_MT2131=m
++CONFIG_MEDIA_TUNER_MT2266=m
++CONFIG_MEDIA_TUNER_MXL5005S=m
++CONFIG_MEDIA_TUNER_MXL5007T=m
++CONFIG_MEDIA_TUNER_QT1010=m
++CONFIG_MEDIA_TUNER_R820T=m
++CONFIG_MEDIA_TUNER_SIMPLE=m
++CONFIG_MEDIA_TUNER_TDA18212=m
++CONFIG_MEDIA_TUNER_TDA18218=m
++CONFIG_MEDIA_TUNER_TDA18271=m
++CONFIG_MEDIA_TUNER_TDA827X=m
++CONFIG_MEDIA_TUNER_TDA8290=m
++CONFIG_MEDIA_TUNER_TDA9887=m
++CONFIG_MEDIA_TUNER_TEA5761=m
++CONFIG_MEDIA_TUNER_TEA5767=m
++CONFIG_MEDIA_TUNER_TUA9001=m
++CONFIG_MEDIA_TUNER_XC2028=m
++CONFIG_MEDIA_TUNER_XC4000=m
++CONFIG_MEDIA_TUNER_XC5000=m
++CONFIG_MEDIA_USB_SUPPORT=y
++# CONFIG_MEFFICEON is not set
++CONFIG_MEGARAID_LEGACY=m
++CONFIG_MEGARAID_MAILBOX=m
++CONFIG_MEGARAID_MM=m
++CONFIG_MEGARAID_NEWGEN=y
++CONFIG_MEGARAID_SAS=m
++# CONFIG_MELAN is not set
++CONFIG_MEMCG=y
++# CONFIG_MEMCG_KMEM is not set
++CONFIG_MEMCG_SWAP=y
++# CONFIG_MEMCG_SWAP_ENABLED is not set
++CONFIG_MEMORY=y
++CONFIG_MEMORY_FAILURE=y
++CONFIG_MEMORY_HOTPLUG=y
++CONFIG_MEMORY_HOTPLUG_SPARSE=y
++CONFIG_MEMORY_HOTREMOVE=y
++CONFIG_MEMORY_ISOLATION=y
++CONFIG_MEMORY_NOTIFIER_ERROR_INJECT=m
++CONFIG_MEMSTICK=m
++# CONFIG_MEMSTICK_DEBUG is not set
++CONFIG_MEMSTICK_JMICRON_38X=m
++CONFIG_MEMSTICK_R592=m
++CONFIG_MEMSTICK_REALTEK_PCI=m
++CONFIG_MEMSTICK_TIFM_MS=m
++# CONFIG_MEMSTICK_UNSAFE_RESUME is not set
++CONFIG_MEMTEST=y
++CONFIG_MEM_SOFT_DIRTY=y
++CONFIG_MEN_A21_WDT=m
++CONFIG_MFD_88PM800=m
++CONFIG_MFD_88PM805=m
++CONFIG_MFD_88PM860X=y
++CONFIG_MFD_AAT2870_CORE=y
++CONFIG_MFD_ARIZONA=y
++CONFIG_MFD_ARIZONA_I2C=m
++CONFIG_MFD_ARIZONA_SPI=m
++CONFIG_MFD_AS3711=y
++CONFIG_MFD_ASIC3=y
++CONFIG_MFD_CORE=y
++CONFIG_MFD_CROS_EC=m
++CONFIG_MFD_CROS_EC_I2C=m
++CONFIG_MFD_CROS_EC_SPI=m
++CONFIG_MFD_CS5535=m
++CONFIG_MFD_DA9052_I2C=y
++CONFIG_MFD_DA9052_SPI=y
++CONFIG_MFD_DA9055=y
++CONFIG_MFD_INTEL_MSIC=y
++CONFIG_MFD_JANZ_CMODIO=m
++CONFIG_MFD_KEMPLD=m
++CONFIG_MFD_LM3533=m
++CONFIG_MFD_LP8788=y
++CONFIG_MFD_MAX77686=y
++CONFIG_MFD_MAX77693=y
++CONFIG_MFD_MAX8907=m
++CONFIG_MFD_MAX8925=y
++CONFIG_MFD_MAX8997=y
++CONFIG_MFD_MAX8998=y
++CONFIG_MFD_MC13783=m
++CONFIG_MFD_MC13XXX=m
++CONFIG_MFD_MC13XXX_I2C=m
++CONFIG_MFD_MC13XXX_SPI=m
++CONFIG_MFD_NVEC=m
++CONFIG_MFD_OMAP_USB_HOST=y
++CONFIG_MFD_PALMAS=y
++CONFIG_MFD_PCF50633=m
++CONFIG_MFD_RC5T583=y
++CONFIG_MFD_RDC321X=m
++CONFIG_MFD_RETU=m
++CONFIG_MFD_RTSX_PCI=m
++CONFIG_MFD_SEC_CORE=y
++CONFIG_MFD_SI476X_CORE=m
++CONFIG_MFD_SM501=m
++# CONFIG_MFD_SM501_GPIO is not set
++CONFIG_MFD_SMSC=y
++CONFIG_MFD_STMPE=y
++CONFIG_MFD_SYSCON=y
++CONFIG_MFD_T7L66XB=y
++CONFIG_MFD_TC3589X=y
++CONFIG_MFD_TC6387XB=y
++CONFIG_MFD_TC6393XB=y
++CONFIG_MFD_TIMBERDALE=m
++CONFIG_MFD_TI_AM335X_TSCADC=m
++CONFIG_MFD_TPS65090=y
++CONFIG_MFD_TPS65217=m
++CONFIG_MFD_TPS6586X=y
++CONFIG_MFD_TPS65910=y
++CONFIG_MFD_TPS65912=y
++CONFIG_MFD_TPS65912_I2C=y
++CONFIG_MFD_TPS65912_SPI=y
++CONFIG_MFD_TPS80031=y
++CONFIG_MFD_TWL4030_AUDIO=y
++CONFIG_MFD_VIPERBOARD=m
++CONFIG_MFD_VX855=m
++CONFIG_MFD_WL1273_CORE=m
++CONFIG_MFD_WM5102=y
++CONFIG_MFD_WM5110=y
++CONFIG_MFD_WM831X=y
++CONFIG_MFD_WM831X_I2C=y
++CONFIG_MFD_WM831X_SPI=y
++CONFIG_MFD_WM8350=y
++CONFIG_MFD_WM8350_I2C=y
++CONFIG_MFD_WM8400=y
++CONFIG_MFD_WM8994=y
++CONFIG_MFD_WM8997=y
++# CONFIG_MGEODEGX1 is not set
++# CONFIG_MGEODE_LX is not set
++CONFIG_MG_DISK=m
++CONFIG_MG_DISK_RES=0
++CONFIG_MICREL_KS8995MA=m
++CONFIG_MICREL_PHY=y
++CONFIG_MICROCODE=m
++CONFIG_MICROCODE_AMD=y
++# CONFIG_MICROCODE_AMD_EARLY is not set
++CONFIG_MICROCODE_INTEL=y
++# CONFIG_MICROCODE_INTEL_EARLY is not set
++CONFIG_MICROCODE_INTEL_LIB=y
++CONFIG_MICROCODE_OLD_INTERFACE=y
++CONFIG_MIGHT_HAVE_CACHE_L2X0=y
++CONFIG_MIGRATION=y
++CONFIG_MII=m
++CONFIG_MINIX_FS=m
++CONFIG_MINIX_SUBPARTITION=y
++CONFIG_MISC_FILESYSTEMS=y
++CONFIG_MISDN=m
++CONFIG_MISDN_AVMFRITZ=m
++CONFIG_MISDN_DSP=m
++CONFIG_MISDN_HFCMULTI=m
++CONFIG_MISDN_HFCPCI=m
++CONFIG_MISDN_HFCUSB=m
++CONFIG_MISDN_INFINEON=m
++CONFIG_MISDN_IPAC=m
++CONFIG_MISDN_ISAR=m
++CONFIG_MISDN_L1OIP=m
++CONFIG_MISDN_NETJET=m
++CONFIG_MISDN_SPEEDFAX=m
++CONFIG_MISDN_W6692=m
++CONFIG_MIXCOMWD=m
++# CONFIG_MK6 is not set
++# CONFIG_MK7 is not set
++# CONFIG_MK8 is not set
++CONFIG_MKISS=m
++CONFIG_MLX4_CORE=m
++# CONFIG_MLX4_DEBUG is not set
++CONFIG_MLX4_EN=m
++CONFIG_MLX4_EN_DCB=y
++CONFIG_MLX4_INFINIBAND=m
++CONFIG_MLX5_CORE=m
++# CONFIG_MLX5_DEBUG is not set
++CONFIG_MLX5_INFINIBAND=m
++CONFIG_MMC=y
++CONFIG_MMC_ARMMMCI=y
++CONFIG_MMC_BLOCK_BOUNCE=y
++CONFIG_MMC_BLOCK_MINORS=8
++CONFIG_MMC_CB710=m
++# CONFIG_MMC_CLKGATE is not set
++# CONFIG_MMC_DEBUG is not set
++CONFIG_MMC_DW=m
++CONFIG_MMC_DW_EXYNOS=m
++# CONFIG_MMC_DW_IDMAC is not set
++CONFIG_MMC_DW_PCI=m
++CONFIG_MMC_DW_PLTFM=m
++CONFIG_MMC_DW_SOCFPGA=m
++# CONFIG_MMC_MXC is not set
++CONFIG_MMC_OMAP=m
++CONFIG_MMC_OMAP_HS=y
++CONFIG_MMC_REALTEK_PCI=m
++CONFIG_MMC_RICOH_MMC=y
++CONFIG_MMC_SDHCI_ACPI=m
++CONFIG_MMC_SDHCI_ESDHC_IMX=y
++CONFIG_MMC_SDHCI_IO_ACCESSORS=y
++CONFIG_MMC_SDHCI_PCI=m
++CONFIG_MMC_SDHCI_PXAV2=m
++CONFIG_MMC_SDHCI_PXAV3=m
++CONFIG_MMC_SDHCI_TEGRA=m
++CONFIG_MMC_SDRICOH_CS=m
++CONFIG_MMC_SPI=m
++# CONFIG_MMC_TEST is not set
++CONFIG_MMC_TIFM_SD=m
++CONFIG_MMC_TMIO=m
++CONFIG_MMC_TMIO_CORE=m
++# CONFIG_MMC_UNSAFE_RESUME is not set
++CONFIG_MMC_USHC=m
++CONFIG_MMC_VIA_SDMMC=m
++CONFIG_MMC_VUB300=m
++CONFIG_MMC_WBSD=m
++CONFIG_MMIOTRACE=y
++# CONFIG_MMIOTRACE_TEST is not set
++CONFIG_MMU=y
++CONFIG_MMU_NOTIFIER=y
++CONFIG_MM_OWNER=y
++CONFIG_MODULES=y
++CONFIG_MODULES_USE_ELF_REL=y
++CONFIG_MODULES_USE_ELF_RELA=y
++# CONFIG_MODULE_FORCE_LOAD is not set
++# CONFIG_MODULE_FORCE_UNLOAD is not set
++CONFIG_MODULE_SIG=y
++CONFIG_MODULE_SIG_ALL=y
++# CONFIG_MODULE_SIG_FORCE is not set
++CONFIG_MODULE_SIG_HASH="sha512"
++# CONFIG_MODULE_SIG_SHA1 is not set
++# CONFIG_MODULE_SIG_SHA224 is not set
++# CONFIG_MODULE_SIG_SHA256 is not set
++# CONFIG_MODULE_SIG_SHA384 is not set
++CONFIG_MODULE_SIG_SHA512=y
++CONFIG_MODULE_SRCVERSION_ALL=y
++CONFIG_MODULE_UNLOAD=y
++CONFIG_MODVERSIONS=y
++CONFIG_MOUSE_APPLETOUCH=m
++CONFIG_MOUSE_BCM5974=m
++CONFIG_MOUSE_CYAPA=m
++CONFIG_MOUSE_GPIO=m
++# CONFIG_MOUSE_INPORT is not set
++CONFIG_MOUSE_LOGIBM=m
++CONFIG_MOUSE_PC110PAD=m
++CONFIG_MOUSE_PS2=m
++CONFIG_MOUSE_PS2_ALPS=y
++CONFIG_MOUSE_PS2_CYPRESS=y
++CONFIG_MOUSE_PS2_ELANTECH=y
++CONFIG_MOUSE_PS2_LIFEBOOK=y
++CONFIG_MOUSE_PS2_LOGIPS2PP=y
++CONFIG_MOUSE_PS2_SENTELIC=y
++CONFIG_MOUSE_PS2_SYNAPTICS=y
++CONFIG_MOUSE_PS2_TOUCHKIT=y
++CONFIG_MOUSE_PS2_TRACKPOINT=y
++CONFIG_MOUSE_SERIAL=m
++CONFIG_MOUSE_SYNAPTICS_I2C=m
++CONFIG_MOUSE_SYNAPTICS_USB=m
++CONFIG_MOUSE_VSXXXAA=m
++CONFIG_MOVABLE_NODE=y
++CONFIG_MOXA_INTELLIO=m
++CONFIG_MOXA_SMARTIO=m
++# CONFIG_MPENTIUM4 is not set
++# CONFIG_MPENTIUMII is not set
++# CONFIG_MPENTIUMIII is not set
++# CONFIG_MPENTIUMM is not set
++CONFIG_MPILIB=y
++# CONFIG_MPSC is not set
++CONFIG_MRP=m
++CONFIG_MSDOS_FS=m
++CONFIG_MSDOS_PARTITION=y
++CONFIG_MSI_LAPTOP=m
++CONFIG_MSI_WMI=m
++CONFIG_MSPRO_BLOCK=m
++CONFIG_MTDRAM_ERASE_SIZE=128
++CONFIG_MTDRAM_TOTAL_SIZE=4096
++CONFIG_MTD_ABSENT=m
++CONFIG_MTD_AFS_PARTS=m
++CONFIG_MTD_ALAUDA=m
++CONFIG_MTD_AMD76XROM=m
++CONFIG_MTD_AR7_PARTS=m
++CONFIG_MTD_BLOCK2MTD=m
++CONFIG_MTD_BLOCK_RO=m
++CONFIG_MTD_CFI=m
++# CONFIG_MTD_CFI_ADV_OPTIONS is not set
++CONFIG_MTD_CFI_AMDSTD=m
++CONFIG_MTD_CFI_I1=y
++CONFIG_MTD_CFI_I2=y
++# CONFIG_MTD_CFI_I4 is not set
++# CONFIG_MTD_CFI_I8 is not set
++CONFIG_MTD_CFI_INTELEXT=m
++CONFIG_MTD_CFI_STAA=m
++CONFIG_MTD_CFI_UTIL=m
++CONFIG_MTD_CK804XROM=m
++CONFIG_MTD_COMPLEX_MAPPINGS=y
++CONFIG_MTD_DATAFLASH=m
++CONFIG_MTD_DATAFLASH_OTP=y
++# CONFIG_MTD_DATAFLASH_WRITE_VERIFY is not set
++CONFIG_MTD_DOCG3=m
++CONFIG_MTD_ESB2ROM=m
++CONFIG_MTD_GEN_PROBE=m
++CONFIG_MTD_GPIO_ADDR=m
++CONFIG_MTD_ICHXROM=m
++CONFIG_MTD_IMPA7=m
++CONFIG_MTD_INTEL_VR_NOR=m
++CONFIG_MTD_JEDECPROBE=m
++CONFIG_MTD_L440GX=m
++CONFIG_MTD_LATCH_ADDR=m
++CONFIG_MTD_LPDDR=m
++CONFIG_MTD_M25P80=m
++CONFIG_MTD_MAP_BANK_WIDTH_1=y
++# CONFIG_MTD_MAP_BANK_WIDTH_16 is not set
++CONFIG_MTD_MAP_BANK_WIDTH_2=y
++# CONFIG_MTD_MAP_BANK_WIDTH_32 is not set
++CONFIG_MTD_MAP_BANK_WIDTH_4=y
++# CONFIG_MTD_MAP_BANK_WIDTH_8 is not set
++CONFIG_MTD_MTDRAM=m
++CONFIG_MTD_NAND_CAFE=m
++CONFIG_MTD_NAND_CS553X=m
++CONFIG_MTD_NAND_DENALI=m
++CONFIG_MTD_NAND_DENALI_DT=m
++CONFIG_MTD_NAND_DENALI_PCI=m
++CONFIG_MTD_NAND_DENALI_SCRATCH_REG_ADDR=0xFF108018
++CONFIG_MTD_NAND_DISKONCHIP=m
++# CONFIG_MTD_NAND_DISKONCHIP_BBTWRITE is not set
++CONFIG_MTD_NAND_DISKONCHIP_PROBE_ADDRESS=0
++# CONFIG_MTD_NAND_DISKONCHIP_PROBE_ADVANCED is not set
++CONFIG_MTD_NAND_DOCG4=m
++CONFIG_MTD_NAND_ECC_BCH=y
++# CONFIG_MTD_NAND_ECC_SMC is not set
++CONFIG_MTD_NAND_GPIO=m
++# CONFIG_MTD_NAND_MXC is not set
++CONFIG_MTD_NAND_NANDSIM=m
++CONFIG_MTD_NAND_OMAP2=y
++CONFIG_MTD_NAND_OMAP_BCH=y
++# CONFIG_MTD_NAND_OMAP_BCH4 is not set
++CONFIG_MTD_NAND_OMAP_BCH8=y
++CONFIG_MTD_NAND_PLATFORM=m
++CONFIG_MTD_NAND_RICOH=m
++CONFIG_MTD_NAND_TMIO=m
++CONFIG_MTD_NETSC520=m
++CONFIG_MTD_NETtel=m
++CONFIG_MTD_OF_PARTS=y
++CONFIG_MTD_ONENAND=m
++CONFIG_MTD_ONENAND_2X_PROGRAM=y
++CONFIG_MTD_ONENAND_GENERIC=m
++CONFIG_MTD_ONENAND_OMAP2=m
++# CONFIG_MTD_ONENAND_OTP is not set
++CONFIG_MTD_ONENAND_VERIFY_WRITE=y
++CONFIG_MTD_OOPS=m
++CONFIG_MTD_PCI=m
++CONFIG_MTD_PCMCIA=m
++# CONFIG_MTD_PCMCIA_ANONYMOUS is not set
++CONFIG_MTD_PHRAM=m
++CONFIG_MTD_PHYSMAP=m
++# CONFIG_MTD_PHYSMAP_COMPAT is not set
++CONFIG_MTD_PHYSMAP_OF=m
++CONFIG_MTD_PLATRAM=m
++CONFIG_MTD_PMC551=m
++# CONFIG_MTD_PMC551_BUGFIX is not set
++# CONFIG_MTD_PMC551_DEBUG is not set
++CONFIG_MTD_QINFO_PROBE=m
++CONFIG_MTD_RAM=m
++CONFIG_MTD_REDBOOT_DIRECTORY_BLOCK=-1
++CONFIG_MTD_REDBOOT_PARTS=m
++# CONFIG_MTD_REDBOOT_PARTS_READONLY is not set
++# CONFIG_MTD_REDBOOT_PARTS_UNALLOCATED is not set
++CONFIG_MTD_ROM=m
++CONFIG_MTD_SBC_GXX=m
++CONFIG_MTD_SC520CDP=m
++CONFIG_MTD_SCB2_FLASH=m
++CONFIG_MTD_SCx200_DOCFLASH=m
++CONFIG_MTD_SLRAM=m
++CONFIG_MTD_SST25L=m
++CONFIG_MTD_SWAP=m
++# CONFIG_MTD_TESTS is not set
++CONFIG_MTD_TS5500=m
++CONFIG_MTD_UBI=m
++CONFIG_MTD_UBI_BEB_LIMIT=20
++CONFIG_MTD_UBI_FASTMAP=y
++CONFIG_MTD_UBI_GLUEBI=m
++CONFIG_MTD_UBI_WL_THRESHOLD=4096
++CONFIG_MTRR=y
++CONFIG_MTRR_SANITIZER=y
++CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
++CONFIG_MTRR_SANITIZER_SPARE_REG_NR_DEFAULT=1
++CONFIG_MULTI_IRQ_HANDLER=y
++CONFIG_MUTEX_SPIN_ON_OWNER=y
++# CONFIG_MVIAC3_2 is not set
++# CONFIG_MVIAC7 is not set
++CONFIG_MVMDIO=m
++CONFIG_MWAVE=m
++CONFIG_MWIFIEX=m
++CONFIG_MWIFIEX_PCIE=m
++CONFIG_MWIFIEX_SDIO=m
++CONFIG_MWIFIEX_USB=m
++# CONFIG_MWINCHIP3D is not set
++# CONFIG_MWINCHIPC6 is not set
++CONFIG_MWL8K=m
++CONFIG_MX3_IPU=y
++CONFIG_MX3_IPU_IRQS=4
++# CONFIG_MXC_DEBUG_BOARD is not set
++# CONFIG_MXC_IRQ_PRIOR is not set
++CONFIG_MXM_WMI=m
++# CONFIG_MXS_DMA is not set
++CONFIG_MYRI10GE=m
++CONFIG_MYRI10GE_DCA=y
++CONFIG_N2=m
++CONFIG_NAMESPACES=y
++CONFIG_NATIONAL_PHY=y
++CONFIG_NATSEMI=m
++CONFIG_NCPFS_EXTRAS=y
++CONFIG_NCPFS_IOCTL_LOCKING=y
++CONFIG_NCPFS_NFS_NS=y
++CONFIG_NCPFS_NLS=y
++CONFIG_NCPFS_OS2_NS=y
++CONFIG_NCPFS_PACKET_SIGNING=y
++# CONFIG_NCPFS_SMALLDOS is not set
++CONFIG_NCPFS_STRONG=y
++CONFIG_NCP_FS=m
++CONFIG_NE2000=m
++CONFIG_NE2K_PCI=m
++CONFIG_NEED_BOUNCE_POOL=y
++CONFIG_NEED_DMA_MAP_STATE=y
++CONFIG_NEED_MULTIPLE_NODES=y
++CONFIG_NEED_PER_CPU_EMBED_FIRST_CHUNK=y
++CONFIG_NEED_PER_CPU_PAGE_FIRST_CHUNK=y
++CONFIG_NEED_SG_DMA_LENGTH=y
++CONFIG_NEON=y
++CONFIG_NET=y
++CONFIG_NET5501=y
++CONFIG_NETCONSOLE=m
++CONFIG_NETCONSOLE_DYNAMIC=y
++CONFIG_NETDEVICES=y
++CONFIG_NETFILTER=y
++CONFIG_NETFILTER_ADVANCED=y
++# CONFIG_NETFILTER_DEBUG is not set
++CONFIG_NETFILTER_NETLINK=m
++CONFIG_NETFILTER_NETLINK_ACCT=m
++CONFIG_NETFILTER_NETLINK_LOG=m
++CONFIG_NETFILTER_NETLINK_QUEUE=m
++CONFIG_NETFILTER_NETLINK_QUEUE_CT=y
++CONFIG_NETFILTER_TPROXY=m
++CONFIG_NETFILTER_XTABLES=m
++CONFIG_NETFILTER_XT_CONNMARK=m
++CONFIG_NETFILTER_XT_MARK=m
++CONFIG_NETFILTER_XT_MATCH_ADDRTYPE=m
++CONFIG_NETFILTER_XT_MATCH_BPF=m
++CONFIG_NETFILTER_XT_MATCH_CLUSTER=m
++CONFIG_NETFILTER_XT_MATCH_COMMENT=m
++CONFIG_NETFILTER_XT_MATCH_CONNBYTES=m
++CONFIG_NETFILTER_XT_MATCH_CONNLABEL=m
++CONFIG_NETFILTER_XT_MATCH_CONNLIMIT=m
++CONFIG_NETFILTER_XT_MATCH_CONNMARK=m
++CONFIG_NETFILTER_XT_MATCH_CONNTRACK=m
++CONFIG_NETFILTER_XT_MATCH_CPU=m
++CONFIG_NETFILTER_XT_MATCH_DCCP=m
++CONFIG_NETFILTER_XT_MATCH_DEVGROUP=m
++CONFIG_NETFILTER_XT_MATCH_DSCP=m
++CONFIG_NETFILTER_XT_MATCH_ECN=m
++CONFIG_NETFILTER_XT_MATCH_ESP=m
++CONFIG_NETFILTER_XT_MATCH_HASHLIMIT=m
++CONFIG_NETFILTER_XT_MATCH_HELPER=m
++CONFIG_NETFILTER_XT_MATCH_HL=m
++CONFIG_NETFILTER_XT_MATCH_IPRANGE=m
++CONFIG_NETFILTER_XT_MATCH_IPVS=m
++CONFIG_NETFILTER_XT_MATCH_LENGTH=m
++CONFIG_NETFILTER_XT_MATCH_LIMIT=m
++CONFIG_NETFILTER_XT_MATCH_MAC=m
++CONFIG_NETFILTER_XT_MATCH_MARK=m
++CONFIG_NETFILTER_XT_MATCH_MULTIPORT=m
++CONFIG_NETFILTER_XT_MATCH_NFACCT=m
++CONFIG_NETFILTER_XT_MATCH_OSF=m
++CONFIG_NETFILTER_XT_MATCH_OWNER=m
++CONFIG_NETFILTER_XT_MATCH_PHYSDEV=m
++CONFIG_NETFILTER_XT_MATCH_PKTTYPE=m
++CONFIG_NETFILTER_XT_MATCH_POLICY=m
++CONFIG_NETFILTER_XT_MATCH_QUOTA=m
++CONFIG_NETFILTER_XT_MATCH_RATEEST=m
++CONFIG_NETFILTER_XT_MATCH_REALM=m
++CONFIG_NETFILTER_XT_MATCH_RECENT=m
++CONFIG_NETFILTER_XT_MATCH_SCTP=m
++CONFIG_NETFILTER_XT_MATCH_SOCKET=m
++CONFIG_NETFILTER_XT_MATCH_STATE=m
++CONFIG_NETFILTER_XT_MATCH_STATISTIC=m
++CONFIG_NETFILTER_XT_MATCH_STRING=m
++CONFIG_NETFILTER_XT_MATCH_TCPMSS=m
++CONFIG_NETFILTER_XT_MATCH_TIME=m
++CONFIG_NETFILTER_XT_MATCH_U32=m
++CONFIG_NETFILTER_XT_SET=m
++CONFIG_NETFILTER_XT_TARGET_AUDIT=m
++CONFIG_NETFILTER_XT_TARGET_CHECKSUM=m
++CONFIG_NETFILTER_XT_TARGET_CLASSIFY=m
++CONFIG_NETFILTER_XT_TARGET_CONNMARK=m
++CONFIG_NETFILTER_XT_TARGET_CONNSECMARK=m
++CONFIG_NETFILTER_XT_TARGET_CT=m
++CONFIG_NETFILTER_XT_TARGET_DSCP=m
++CONFIG_NETFILTER_XT_TARGET_HL=m
++CONFIG_NETFILTER_XT_TARGET_HMARK=m
++CONFIG_NETFILTER_XT_TARGET_IDLETIMER=m
++CONFIG_NETFILTER_XT_TARGET_LED=m
++CONFIG_NETFILTER_XT_TARGET_LOG=m
++CONFIG_NETFILTER_XT_TARGET_MARK=m
++CONFIG_NETFILTER_XT_TARGET_NETMAP=m
++CONFIG_NETFILTER_XT_TARGET_NFLOG=m
++CONFIG_NETFILTER_XT_TARGET_NFQUEUE=m
++CONFIG_NETFILTER_XT_TARGET_NOTRACK=m
++CONFIG_NETFILTER_XT_TARGET_RATEEST=m
++CONFIG_NETFILTER_XT_TARGET_REDIRECT=m
++CONFIG_NETFILTER_XT_TARGET_SECMARK=m
++CONFIG_NETFILTER_XT_TARGET_TCPMSS=m
++CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
++CONFIG_NETFILTER_XT_TARGET_TEE=m
++CONFIG_NETFILTER_XT_TARGET_TPROXY=m
++CONFIG_NETFILTER_XT_TARGET_TRACE=m
++CONFIG_NETLABEL=y
++CONFIG_NETLINK_DIAG=m
++CONFIG_NETLINK_MMAP=y
++CONFIG_NETPOLL=y
++# CONFIG_NETPOLL_TRAP is not set
++CONFIG_NETPRIO_CGROUP=m
++CONFIG_NETROM=m
++CONFIG_NETWORK_FILESYSTEMS=y
++# CONFIG_NETWORK_PHY_TIMESTAMPING is not set
++CONFIG_NETWORK_SECMARK=y
++CONFIG_NETXEN_NIC=m
++CONFIG_NET_9P=m
++# CONFIG_NET_9P_DEBUG is not set
++CONFIG_NET_9P_RDMA=m
++CONFIG_NET_9P_VIRTIO=m
++CONFIG_NET_ACT_CSUM=m
++CONFIG_NET_ACT_GACT=m
++CONFIG_NET_ACT_IPT=m
++CONFIG_NET_ACT_MIRRED=m
++CONFIG_NET_ACT_NAT=m
++CONFIG_NET_ACT_PEDIT=m
++CONFIG_NET_ACT_POLICE=m
++CONFIG_NET_ACT_SIMP=m
++CONFIG_NET_ACT_SKBEDIT=m
++CONFIG_NET_CADENCE=y
++CONFIG_NET_CALXEDA_XGMAC=m
++CONFIG_NET_CLS=y
++CONFIG_NET_CLS_ACT=y
++CONFIG_NET_CLS_BASIC=m
++CONFIG_NET_CLS_CGROUP=m
++CONFIG_NET_CLS_FLOW=m
++CONFIG_NET_CLS_FW=m
++# CONFIG_NET_CLS_IND is not set
++CONFIG_NET_CLS_ROUTE4=m
++CONFIG_NET_CLS_RSVP=m
++CONFIG_NET_CLS_RSVP6=m
++CONFIG_NET_CLS_TCINDEX=m
++CONFIG_NET_CLS_U32=m
++CONFIG_NET_CORE=y
++CONFIG_NET_DCCPPROBE=m
++CONFIG_NET_DMA=y
++# CONFIG_NET_DROP_MONITOR is not set
++CONFIG_NET_DSA=m
++CONFIG_NET_DSA_MV88E6060=m
++CONFIG_NET_DSA_MV88E6123_61_65=m
++CONFIG_NET_DSA_MV88E6131=m
++CONFIG_NET_DSA_MV88E6XXX=m
++CONFIG_NET_DSA_MV88E6XXX_NEED_PPU=y
++CONFIG_NET_DSA_TAG_DSA=y
++CONFIG_NET_DSA_TAG_EDSA=y
++CONFIG_NET_DSA_TAG_TRAILER=y
++CONFIG_NET_EMATCH=y
++CONFIG_NET_EMATCH_CANID=m
++CONFIG_NET_EMATCH_CMP=m
++CONFIG_NET_EMATCH_IPSET=m
++CONFIG_NET_EMATCH_META=m
++CONFIG_NET_EMATCH_NBYTE=m
++CONFIG_NET_EMATCH_STACK=32
++CONFIG_NET_EMATCH_TEXT=m
++CONFIG_NET_EMATCH_U32=m
++CONFIG_NET_FC=y
++CONFIG_NET_FLOW_LIMIT=y
++CONFIG_NET_IPGRE=m
++CONFIG_NET_IPGRE_BROADCAST=y
++CONFIG_NET_IPGRE_DEMUX=m
++CONFIG_NET_IPIP=m
++CONFIG_NET_IPVTI=m
++CONFIG_NET_IP_TUNNEL=m
++CONFIG_NET_KEY=m
++# CONFIG_NET_KEY_MIGRATE is not set
++CONFIG_NET_MPLS_GSO=m
++CONFIG_NET_NS=y
++CONFIG_NET_PACKET_ENGINE=y
++CONFIG_NET_PKTGEN=m
++CONFIG_NET_POLL_CONTROLLER=y
++CONFIG_NET_RX_BUSY_POLL=y
++CONFIG_NET_SB1000=m
++CONFIG_NET_SCHED=y
++CONFIG_NET_SCH_ATM=m
++CONFIG_NET_SCH_CBQ=m
++CONFIG_NET_SCH_CHOKE=m
++CONFIG_NET_SCH_CODEL=m
++CONFIG_NET_SCH_DRR=m
++CONFIG_NET_SCH_DSMARK=m
++CONFIG_NET_SCH_FIFO=y
++CONFIG_NET_SCH_FQ_CODEL=m
++CONFIG_NET_SCH_GRED=m
++CONFIG_NET_SCH_HFSC=m
++CONFIG_NET_SCH_HTB=m
++CONFIG_NET_SCH_INGRESS=m
++CONFIG_NET_SCH_MQPRIO=m
++CONFIG_NET_SCH_MULTIQ=m
++CONFIG_NET_SCH_NETEM=m
++CONFIG_NET_SCH_PLUG=m
++CONFIG_NET_SCH_PRIO=m
++CONFIG_NET_SCH_QFQ=m
++CONFIG_NET_SCH_RED=m
++CONFIG_NET_SCH_SFB=m
++CONFIG_NET_SCH_SFQ=m
++CONFIG_NET_SCH_TBF=m
++CONFIG_NET_SCH_TEQL=m
++CONFIG_NET_SCTPPROBE=m
++CONFIG_NET_TCPPROBE=m
++# CONFIG_NET_TEAM is not set
++CONFIG_NET_TULIP=y
++CONFIG_NET_VENDOR_3COM=y
++CONFIG_NET_VENDOR_8390=y
++CONFIG_NET_VENDOR_ADAPTEC=y
++CONFIG_NET_VENDOR_ALTEON=y
++CONFIG_NET_VENDOR_AMD=y
++CONFIG_NET_VENDOR_ARC=y
++CONFIG_NET_VENDOR_ATHEROS=y
++CONFIG_NET_VENDOR_BROADCOM=y
++CONFIG_NET_VENDOR_BROCADE=y
++CONFIG_NET_VENDOR_CHELSIO=y
++CONFIG_NET_VENDOR_CIRRUS=y
++CONFIG_NET_VENDOR_CISCO=y
++CONFIG_NET_VENDOR_DEC=y
++CONFIG_NET_VENDOR_DLINK=y
++CONFIG_NET_VENDOR_EMULEX=y
++CONFIG_NET_VENDOR_EXAR=y
++CONFIG_NET_VENDOR_FARADAY=y
++CONFIG_NET_VENDOR_FREESCALE=y
++CONFIG_NET_VENDOR_FUJITSU=y
++CONFIG_NET_VENDOR_HP=y
++CONFIG_NET_VENDOR_I825XX=y
++CONFIG_NET_VENDOR_INTEL=y
++CONFIG_NET_VENDOR_MARVELL=y
++CONFIG_NET_VENDOR_MELLANOX=y
++CONFIG_NET_VENDOR_MICREL=y
++CONFIG_NET_VENDOR_MICROCHIP=y
++CONFIG_NET_VENDOR_MYRI=y
++CONFIG_NET_VENDOR_NATSEMI=y
++CONFIG_NET_VENDOR_NVIDIA=y
++CONFIG_NET_VENDOR_OKI=y
++CONFIG_NET_VENDOR_QLOGIC=y
++CONFIG_NET_VENDOR_RDC=y
++CONFIG_NET_VENDOR_REALTEK=y
++CONFIG_NET_VENDOR_SEEQ=y
++CONFIG_NET_VENDOR_SILAN=y
++CONFIG_NET_VENDOR_SILICOM=y
++CONFIG_NET_VENDOR_SIS=y
++CONFIG_NET_VENDOR_SMSC=y
++CONFIG_NET_VENDOR_STMICRO=y
++CONFIG_NET_VENDOR_SUN=y
++CONFIG_NET_VENDOR_TEHUTI=y
++CONFIG_NET_VENDOR_TI=y
++CONFIG_NET_VENDOR_VIA=y
++CONFIG_NET_VENDOR_WIZNET=y
++CONFIG_NET_VENDOR_XIRCOM=y
++CONFIG_NEW_LEDS=y
++CONFIG_NFC=m
++CONFIG_NFC_HCI=m
++CONFIG_NFC_MEI_PHY=m
++CONFIG_NFC_MICROREAD=m
++CONFIG_NFC_MICROREAD_I2C=m
++CONFIG_NFC_MICROREAD_MEI=m
++CONFIG_NFC_NCI=m
++CONFIG_NFC_NCI_SPI=y
++CONFIG_NFC_PN533=m
++CONFIG_NFC_PN544=m
++CONFIG_NFC_PN544_I2C=m
++CONFIG_NFC_PN544_MEI=m
++CONFIG_NFC_SHDLC=y
++CONFIG_NFC_SIM=m
++CONFIG_NFC_WILINK=m
++CONFIG_NFSD=m
++# CONFIG_NFSD_FAULT_INJECTION is not set
++CONFIG_NFSD_V2_ACL=y
++CONFIG_NFSD_V3=y
++CONFIG_NFSD_V3_ACL=y
++CONFIG_NFSD_V4=y
++CONFIG_NFSD_V4_SECURITY_LABEL=y
++CONFIG_NFS_ACL_SUPPORT=m
++CONFIG_NFS_COMMON=y
++CONFIG_NFS_DEBUG=y
++CONFIG_NFS_FS=m
++CONFIG_NFS_FSCACHE=y
++CONFIG_NFS_SWAP=y
++CONFIG_NFS_USE_KERNEL_DNS=y
++# CONFIG_NFS_USE_LEGACY_DNS is not set
++CONFIG_NFS_V2=m
++CONFIG_NFS_V3=m
++CONFIG_NFS_V3_ACL=y
++CONFIG_NFS_V4=m
++CONFIG_NFS_V4_1=y
++CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN="kernel.org"
++CONFIG_NFS_V4_2=y
++CONFIG_NFS_V4_SECURITY_LABEL=y
++CONFIG_NFTL=m
++CONFIG_NFTL_RW=y
++CONFIG_NF_CONNTRACK=m
++CONFIG_NF_CONNTRACK_AMANDA=m
++CONFIG_NF_CONNTRACK_BROADCAST=m
++CONFIG_NF_CONNTRACK_EVENTS=y
++CONFIG_NF_CONNTRACK_FTP=m
++CONFIG_NF_CONNTRACK_H323=m
++CONFIG_NF_CONNTRACK_IPV4=m
++CONFIG_NF_CONNTRACK_IPV6=m
++CONFIG_NF_CONNTRACK_IRC=m
++CONFIG_NF_CONNTRACK_LABELS=y
++CONFIG_NF_CONNTRACK_MARK=y
++CONFIG_NF_CONNTRACK_NETBIOS_NS=m
++CONFIG_NF_CONNTRACK_PPTP=m
++# CONFIG_NF_CONNTRACK_PROCFS is not set
++CONFIG_NF_CONNTRACK_SANE=m
++CONFIG_NF_CONNTRACK_SECMARK=y
++CONFIG_NF_CONNTRACK_SIP=m
++CONFIG_NF_CONNTRACK_SNMP=m
++CONFIG_NF_CONNTRACK_TFTP=m
++CONFIG_NF_CONNTRACK_TIMEOUT=y
++CONFIG_NF_CONNTRACK_TIMESTAMP=y
++CONFIG_NF_CONNTRACK_ZONES=y
++CONFIG_NF_CT_NETLINK=m
++CONFIG_NF_CT_NETLINK_HELPER=m
++CONFIG_NF_CT_NETLINK_TIMEOUT=m
++CONFIG_NF_CT_PROTO_DCCP=m
++CONFIG_NF_CT_PROTO_GRE=m
++CONFIG_NF_CT_PROTO_SCTP=m
++CONFIG_NF_CT_PROTO_UDPLITE=m
++CONFIG_NF_DEFRAG_IPV4=m
++CONFIG_NF_DEFRAG_IPV6=m
++CONFIG_NF_NAT=m
++CONFIG_NF_NAT_AMANDA=m
++CONFIG_NF_NAT_FTP=m
++CONFIG_NF_NAT_H323=m
++CONFIG_NF_NAT_IPV4=m
++CONFIG_NF_NAT_IPV6=m
++CONFIG_NF_NAT_IRC=m
++CONFIG_NF_NAT_NEEDED=y
++CONFIG_NF_NAT_PPTP=m
++CONFIG_NF_NAT_PROTO_DCCP=m
++CONFIG_NF_NAT_PROTO_GRE=m
++CONFIG_NF_NAT_PROTO_SCTP=m
++CONFIG_NF_NAT_PROTO_UDPLITE=m
++CONFIG_NF_NAT_SIP=m
++CONFIG_NF_NAT_SNMP_BASIC=m
++CONFIG_NF_NAT_TFTP=m
++CONFIG_NI65=m
++CONFIG_NILFS2_FS=m
++CONFIG_NIU=m
++CONFIG_NLATTR=y
++CONFIG_NLMON=m
++CONFIG_NLS=y
++CONFIG_NLS_ASCII=m
++CONFIG_NLS_CODEPAGE_1250=m
++CONFIG_NLS_CODEPAGE_1251=m
++CONFIG_NLS_CODEPAGE_437=y
++CONFIG_NLS_CODEPAGE_737=m
++CONFIG_NLS_CODEPAGE_775=m
++CONFIG_NLS_CODEPAGE_850=m
++CONFIG_NLS_CODEPAGE_852=m
++CONFIG_NLS_CODEPAGE_855=m
++CONFIG_NLS_CODEPAGE_857=m
++CONFIG_NLS_CODEPAGE_860=m
++CONFIG_NLS_CODEPAGE_861=m
++CONFIG_NLS_CODEPAGE_862=m
++CONFIG_NLS_CODEPAGE_863=m
++CONFIG_NLS_CODEPAGE_864=m
++CONFIG_NLS_CODEPAGE_865=m
++CONFIG_NLS_CODEPAGE_866=m
++CONFIG_NLS_CODEPAGE_869=m
++CONFIG_NLS_CODEPAGE_874=m
++CONFIG_NLS_CODEPAGE_932=m
++CONFIG_NLS_CODEPAGE_936=m
++CONFIG_NLS_CODEPAGE_949=m
++CONFIG_NLS_CODEPAGE_950=m
++CONFIG_NLS_DEFAULT="utf8"
++CONFIG_NLS_ISO8859_1=m
++CONFIG_NLS_ISO8859_13=m
++CONFIG_NLS_ISO8859_14=m
++CONFIG_NLS_ISO8859_15=m
++CONFIG_NLS_ISO8859_2=m
++CONFIG_NLS_ISO8859_3=m
++CONFIG_NLS_ISO8859_4=m
++CONFIG_NLS_ISO8859_5=m
++CONFIG_NLS_ISO8859_6=m
++CONFIG_NLS_ISO8859_7=m
++CONFIG_NLS_ISO8859_8=m
++CONFIG_NLS_ISO8859_9=m
++CONFIG_NLS_KOI8_R=m
++CONFIG_NLS_KOI8_U=m
++CONFIG_NLS_MAC_CELTIC=m
++CONFIG_NLS_MAC_CENTEURO=m
++CONFIG_NLS_MAC_CROATIAN=m
++CONFIG_NLS_MAC_CYRILLIC=m
++CONFIG_NLS_MAC_GAELIC=m
++CONFIG_NLS_MAC_GREEK=m
++CONFIG_NLS_MAC_ICELAND=m
++CONFIG_NLS_MAC_INUIT=m
++CONFIG_NLS_MAC_ROMAN=m
++CONFIG_NLS_MAC_ROMANIAN=m
++CONFIG_NLS_MAC_TURKISH=m
++CONFIG_NLS_UTF8=m
++CONFIG_NODES_SHIFT=6
++CONFIG_NODES_SPAN_OTHER_NODES=y
++# CONFIG_NOHIGHMEM is not set
++CONFIG_NOP_TRACER=y
++CONFIG_NORTEL_HERMES=m
++CONFIG_NOTIFIER_ERROR_INJECTION=m
++CONFIG_NOUVEAU_DEBUG=5
++CONFIG_NOUVEAU_DEBUG_DEFAULT=3
++CONFIG_NOZOMI=m
++CONFIG_NO_BOOTMEM=y
++CONFIG_NO_HZ=y
++CONFIG_NO_HZ_COMMON=y
++# CONFIG_NO_HZ_FULL is not set
++CONFIG_NO_HZ_IDLE=y
++CONFIG_NO_IOPORT=y
++CONFIG_NS83820=m
++CONFIG_NSC_FIR=m
++CONFIG_NSC_GPIO=m
++CONFIG_NTB=m
++CONFIG_NTB_NETDEV=m
++# CONFIG_NTFS_DEBUG is not set
++CONFIG_NTFS_FS=m
++# CONFIG_NTFS_RW is not set
++CONFIG_NUMA=y
++CONFIG_NUMA_BALANCING=y
++CONFIG_NUMA_BALANCING_DEFAULT_ENABLED=y
++# CONFIG_NUMA_EMU is not set
++CONFIG_NVEC_PAZ00=m
++CONFIG_NVEC_POWER=m
++CONFIG_NVRAM=m
++CONFIG_NV_TCO=m
++# CONFIG_N_GSM is not set
++CONFIG_N_HDLC=m
++CONFIG_OABI_COMPAT=y
++# CONFIG_OCFS2_DEBUG_FS is not set
++CONFIG_OCFS2_DEBUG_MASKLOG=y
++CONFIG_OCFS2_FS=m
++CONFIG_OCFS2_FS_O2CB=m
++CONFIG_OCFS2_FS_STATS=y
++CONFIG_OCFS2_FS_USERSPACE_CLUSTER=m
++CONFIG_OC_ETM=y
++CONFIG_OF=y
++CONFIG_OF_ADDRESS=y
++CONFIG_OF_EARLY_FLATTREE=y
++CONFIG_OF_FLATTREE=y
++CONFIG_OF_GPIO=y
++CONFIG_OF_I2C=y
++CONFIG_OF_IOMMU=y
++CONFIG_OF_IRQ=y
++CONFIG_OF_MDIO=y
++CONFIG_OF_MTD=y
++CONFIG_OF_NET=y
++CONFIG_OF_PCI=y
++CONFIG_OF_PCI_IRQ=y
++# CONFIG_OF_SELFTEST is not set
++CONFIG_OID_REGISTRY=y
++CONFIG_OLD_BELKIN_DONGLE=m
++CONFIG_OLD_SIGACTION=y
++CONFIG_OLD_SIGSUSPEND3=y
++CONFIG_OMAP2PLUS_MBOX=m
++CONFIG_OMAP2_DSS=y
++# CONFIG_OMAP2_DSS_DEBUG is not set
++# CONFIG_OMAP2_DSS_DEBUGFS is not set
++CONFIG_OMAP2_DSS_DPI=y
++# CONFIG_OMAP2_DSS_DSI is not set
++CONFIG_OMAP2_DSS_MIN_FCK_PER_PCK=0
++# CONFIG_OMAP2_DSS_RFBI is not set
++CONFIG_OMAP2_DSS_SDI=y
++CONFIG_OMAP2_DSS_SLEEP_AFTER_VENC_RESET=y
++CONFIG_OMAP2_DSS_VENC=y
++CONFIG_OMAP2_VRFB=y
++CONFIG_OMAP3_EMU=y
++# CONFIG_OMAP3_L2_AUX_SECURE_SAVE_RESTORE is not set
++# CONFIG_OMAP3_SDRC_AC_TIMING is not set
++CONFIG_OMAP4_DSS_HDMI=y
++CONFIG_OMAP4_DSS_HDMI_AUDIO=y
++CONFIG_OMAP4_THERMAL=y
++CONFIG_OMAP_32K_TIMER=y
++CONFIG_OMAP_DM_TIMER=y
++CONFIG_OMAP_INTERCONNECT=y
++CONFIG_OMAP_IOMMU=y
++# CONFIG_OMAP_IOVMM is not set
++CONFIG_OMAP_MBOX=m
++CONFIG_OMAP_MBOX_KFIFO_SIZE=256
++CONFIG_OMAP_MUX=y
++# CONFIG_OMAP_MUX_DEBUG is not set
++CONFIG_OMAP_MUX_WARNINGS=y
++CONFIG_OMAP_OCP2SCP=m
++CONFIG_OMAP_PACKAGE_CBB=y
++CONFIG_OMAP_PACKAGE_CBP=y
++CONFIG_OMAP_PACKAGE_CUS=y
++CONFIG_OMAP_PM_NOOP=y
++CONFIG_OMAP_REMOTEPROC=m
++CONFIG_OMAP_RESET_CLOCKS=y
++CONFIG_OMAP_USB2=y
++CONFIG_OMAP_USB3=m
++CONFIG_OMAP_WATCHDOG=m
++CONFIG_OMFS_FS=m
++CONFIG_OPENVSWITCH=m
++CONFIG_OPENVSWITCH_GRE=y
++CONFIG_OPROFILE=m
++# CONFIG_OPROFILE_EVENT_MULTIPLEX is not set
++CONFIG_OPROFILE_NMI_TIMER=y
++CONFIG_OPTIMIZE_INLINING=y
++CONFIG_OPTPROBES=y
++CONFIG_ORE=m
++CONFIG_ORINOCO_USB=m
++CONFIG_OSF_PARTITION=y
++CONFIG_OUTER_CACHE=y
++CONFIG_OUTER_CACHE_SYNC=y
++CONFIG_OVERLAYFS_FS=m
++CONFIG_P54_COMMON=m
++CONFIG_P54_LEDS=y
++CONFIG_P54_PCI=m
++CONFIG_P54_SPI=m
++# CONFIG_P54_SPI_DEFAULT_EEPROM is not set
++CONFIG_P54_USB=m
++CONFIG_PACKET=y
++CONFIG_PACKET_DIAG=m
++CONFIG_PADATA=y
++CONFIG_PAGEFLAGS_EXTENDED=y
++CONFIG_PAGE_OFFSET=0xC0000000
++CONFIG_PANASONIC_LAPTOP=m
++CONFIG_PANEL=m
++CONFIG_PANEL_ACX565AKM=m
++# CONFIG_PANEL_CHANGE_MESSAGE is not set
++CONFIG_PANEL_GENERIC_DPI=y
++CONFIG_PANEL_LGPHILIPS_LB035Q02=m
++CONFIG_PANEL_NEC_NL8048HL11_01B=m
++CONFIG_PANEL_PARPORT=0
++CONFIG_PANEL_PICODLP=m
++CONFIG_PANEL_PROFILE=5
++CONFIG_PANEL_SHARP_LS037V7DW01=y
++CONFIG_PANEL_TFP410=y
++CONFIG_PANEL_TPO_TD043MTEA1=y
++# CONFIG_PANIC_ON_OOPS is not set
++CONFIG_PANIC_ON_OOPS_VALUE=0
++CONFIG_PANTHERLORD_FF=y
++CONFIG_PARAVIRT=y
++CONFIG_PARAVIRT_CLOCK=y
++# CONFIG_PARAVIRT_DEBUG is not set
++CONFIG_PARAVIRT_SPINLOCKS=y
++# CONFIG_PARAVIRT_TIME_ACCOUNTING is not set
++CONFIG_PARIDE=m
++CONFIG_PARIDE_ATEN=m
++CONFIG_PARIDE_BPCK=m
++CONFIG_PARIDE_BPCK6=m
++CONFIG_PARIDE_COMM=m
++CONFIG_PARIDE_DSTR=m
++CONFIG_PARIDE_EPAT=m
++# CONFIG_PARIDE_EPATC8 is not set
++CONFIG_PARIDE_EPIA=m
++CONFIG_PARIDE_FIT2=m
++CONFIG_PARIDE_FIT3=m
++CONFIG_PARIDE_FRIQ=m
++CONFIG_PARIDE_FRPW=m
++CONFIG_PARIDE_KBIC=m
++CONFIG_PARIDE_KTTI=m
++CONFIG_PARIDE_ON20=m
++CONFIG_PARIDE_ON26=m
++CONFIG_PARIDE_PCD=m
++CONFIG_PARIDE_PD=m
++CONFIG_PARIDE_PF=m
++CONFIG_PARIDE_PG=m
++CONFIG_PARIDE_PT=m
++CONFIG_PARPORT=m
++CONFIG_PARPORT_1284=y
++CONFIG_PARPORT_AX88796=m
++# CONFIG_PARPORT_GSC is not set
++CONFIG_PARPORT_NOT_PC=y
++CONFIG_PARPORT_PC=m
++CONFIG_PARPORT_PC_FIFO=y
++CONFIG_PARPORT_PC_PCMCIA=m
++# CONFIG_PARPORT_PC_SUPERIO is not set
++CONFIG_PARPORT_SERIAL=m
++CONFIG_PARTITION_ADVANCED=y
++CONFIG_PATA_ACPI=m
++CONFIG_PATA_ALI=m
++CONFIG_PATA_AMD=m
++CONFIG_PATA_ARASAN_CF=m
++CONFIG_PATA_ARTOP=m
++CONFIG_PATA_ATIIXP=m
++CONFIG_PATA_ATP867X=m
++CONFIG_PATA_CMD640_PCI=m
++CONFIG_PATA_CMD64X=m
++CONFIG_PATA_CS5520=m
++CONFIG_PATA_CS5530=m
++CONFIG_PATA_CS5535=m
++CONFIG_PATA_CS5536=m
++CONFIG_PATA_CYPRESS=m
++CONFIG_PATA_EFAR=m
++CONFIG_PATA_HPT366=m
++CONFIG_PATA_HPT37X=m
++CONFIG_PATA_HPT3X2N=m
++CONFIG_PATA_HPT3X3=m
++# CONFIG_PATA_HPT3X3_DMA is not set
++# CONFIG_PATA_IMX is not set
++CONFIG_PATA_ISAPNP=m
++CONFIG_PATA_IT8213=m
++CONFIG_PATA_IT821X=m
++CONFIG_PATA_JMICRON=m
++CONFIG_PATA_LEGACY=m
++CONFIG_PATA_MARVELL=m
++CONFIG_PATA_MPIIX=m
++CONFIG_PATA_NETCELL=m
++CONFIG_PATA_NINJA32=m
++CONFIG_PATA_NS87410=m
++CONFIG_PATA_NS87415=m
++CONFIG_PATA_OF_PLATFORM=m
++CONFIG_PATA_OLDPIIX=m
++CONFIG_PATA_OPTI=m
++CONFIG_PATA_OPTIDMA=m
++CONFIG_PATA_PCMCIA=m
++CONFIG_PATA_PDC2027X=m
++CONFIG_PATA_PDC_OLD=m
++CONFIG_PATA_PLATFORM=m
++CONFIG_PATA_QDI=m
++CONFIG_PATA_RADISYS=m
++CONFIG_PATA_RDC=m
++CONFIG_PATA_RZ1000=m
++CONFIG_PATA_SC1200=m
++CONFIG_PATA_SCH=m
++CONFIG_PATA_SERVERWORKS=m
++CONFIG_PATA_SIL680=m
++CONFIG_PATA_SIS=y
++CONFIG_PATA_TOSHIBA=m
++CONFIG_PATA_TRIFLEX=m
++CONFIG_PATA_VIA=m
++CONFIG_PATA_WINBOND=m
++CONFIG_PATA_WINBOND_VLB=m
++CONFIG_PC300TOO=m
++CONFIG_PC8736x_GPIO=m
++CONFIG_PC87413_WDT=m
++CONFIG_PCCARD_NONSTATIC=y
++CONFIG_PCF50633_ADC=m
++CONFIG_PCF50633_GPIO=m
++CONFIG_PCH_CAN=m
++CONFIG_PCH_DMA=m
++CONFIG_PCH_GBE=m
++CONFIG_PCH_PHUB=m
++CONFIG_PCI=y
++CONFIG_PCI200SYN=m
++CONFIG_PCIEAER=y
++# CONFIG_PCIEAER_INJECT is not set
++CONFIG_PCIEASPM=y
++# CONFIG_PCIEASPM_DEBUG is not set
++CONFIG_PCIEASPM_DEFAULT=y
++# CONFIG_PCIEASPM_PERFORMANCE is not set
++# CONFIG_PCIEASPM_POWERSAVE is not set
++CONFIG_PCIEPORTBUS=y
++# CONFIG_PCIE_ECRC is not set
++CONFIG_PCIE_PME=y
++CONFIG_PCIPCWATCHDOG=m
++CONFIG_PCI_ATMEL=m
++CONFIG_PCI_ATS=y
++CONFIG_PCI_BIOS=y
++# CONFIG_PCI_CNB20LE_QUIRK is not set
++# CONFIG_PCI_DEBUG is not set
++CONFIG_PCI_DIRECT=y
++CONFIG_PCI_DOMAINS=y
++CONFIG_PCI_GOANY=y
++# CONFIG_PCI_GOBIOS is not set
++# CONFIG_PCI_GODIRECT is not set
++# CONFIG_PCI_GOMMCONFIG is not set
++CONFIG_PCI_IOAPIC=y
++CONFIG_PCI_IOV=y
++CONFIG_PCI_LABEL=y
++CONFIG_PCI_MMCONFIG=y
++CONFIG_PCI_MSI=y
++CONFIG_PCI_PASID=y
++CONFIG_PCI_PRI=y
++CONFIG_PCI_QUIRKS=y
++CONFIG_PCI_REALLOC_ENABLE_AUTO=y
++CONFIG_PCI_STUB=m
++CONFIG_PCI_XEN=y
++CONFIG_PCMCIA=m
++CONFIG_PCMCIA_3C574=m
++CONFIG_PCMCIA_3C589=m
++CONFIG_PCMCIA_AHA152X=m
++CONFIG_PCMCIA_ATMEL=m
++CONFIG_PCMCIA_AXNET=m
++CONFIG_PCMCIA_FDOMAIN=m
++CONFIG_PCMCIA_FMVJ18X=m
++CONFIG_PCMCIA_HERMES=m
++CONFIG_PCMCIA_LOAD_CIS=y
++CONFIG_PCMCIA_NINJA_SCSI=m
++CONFIG_PCMCIA_NMCLAN=m
++CONFIG_PCMCIA_PCNET=m
++CONFIG_PCMCIA_PROBE=y
++CONFIG_PCMCIA_QLOGIC=m
++CONFIG_PCMCIA_RAYCS=m
++CONFIG_PCMCIA_SMC91C92=m
++CONFIG_PCMCIA_SPECTRUM=m
++CONFIG_PCMCIA_SYM53C500=m
++CONFIG_PCMCIA_WL3501=m
++CONFIG_PCMCIA_XIRC2PS=m
++CONFIG_PCMCIA_XIRCOM=m
++CONFIG_PCNET32=m
++CONFIG_PCSPKR_PLATFORM=y
++CONFIG_PCWATCHDOG=m
++CONFIG_PD6729=m
++CONFIG_PDA_POWER=m
++CONFIG_PDC_ADMA=m
++CONFIG_PERCPU_RWSEM=y
++CONFIG_PERF_EVENTS=y
++CONFIG_PERF_USE_VMALLOC=y
++CONFIG_PHANTOM=m
++CONFIG_PHONET=m
++CONFIG_PHYLIB=y
++CONFIG_PHYSICAL_ALIGN=0x1000000
++CONFIG_PHYSICAL_START=0x1000000
++# CONFIG_PID_IN_CONTEXTIDR is not set
++CONFIG_PID_NS=y
++CONFIG_PINCONF=y
++CONFIG_PINCTRL=y
++CONFIG_PINCTRL_IMX=y
++CONFIG_PINCTRL_IMX6Q=y
++CONFIG_PINCTRL_IMX6SL=y
++CONFIG_PINCTRL_SINGLE=y
++CONFIG_PINCTRL_TEGRA=y
++CONFIG_PINCTRL_TEGRA114=y
++CONFIG_PINCTRL_TEGRA20=y
++CONFIG_PINCTRL_TEGRA30=y
++CONFIG_PINCTRL_VF610=y
++CONFIG_PINMUX=y
++CONFIG_PL310_ERRATA_588369=y
++CONFIG_PL310_ERRATA_727915=y
++CONFIG_PL310_ERRATA_753970=y
++CONFIG_PL310_ERRATA_769419=y
++CONFIG_PL320_MBOX=y
++CONFIG_PL330_DMA=m
++# CONFIG_PLAT_SPEAR is not set
++CONFIG_PLAT_VERSATILE=y
++CONFIG_PLAT_VERSATILE_CLCD=y
++CONFIG_PLAT_VERSATILE_SCHED_CLOCK=y
++CONFIG_PLIP=m
++CONFIG_PLX_HERMES=m
++CONFIG_PM=y
++CONFIG_PMBUS=m
++CONFIG_PMIC_ADP5520=y
++CONFIG_PMIC_DA903X=y
++CONFIG_PMIC_DA9052=y
++CONFIG_PM_ADVANCED_DEBUG=y
++# CONFIG_PM_AUTOSLEEP is not set
++CONFIG_PM_CLK=y
++CONFIG_PM_DEBUG=y
++CONFIG_PM_DEVFREQ=y
++CONFIG_PM_NOTIFIER_ERROR_INJECT=m
++CONFIG_PM_OPP=y
++CONFIG_PM_RUNTIME=y
++CONFIG_PM_SLEEP=y
++CONFIG_PM_SLEEP_DEBUG=y
++CONFIG_PM_SLEEP_SMP=y
++CONFIG_PM_STD_PARTITION=""
++# CONFIG_PM_TEST_SUSPEND is not set
++CONFIG_PM_TRACE=y
++CONFIG_PM_TRACE_RTC=y
++CONFIG_PM_WAKELOCKS_GC=y
++CONFIG_PM_WAKELOCKS_LIMIT=100
++CONFIG_PNFS_BLOCK=m
++CONFIG_PNFS_FILE_LAYOUT=m
++CONFIG_PNFS_OBJLAYOUT=m
++CONFIG_PNP=y
++CONFIG_PNPACPI=y
++CONFIG_PNPBIOS=y
++CONFIG_PNPBIOS_PROC_FS=y
++# CONFIG_PNP_DEBUG_MESSAGES is not set
++CONFIG_POSIX_MQUEUE=y
++CONFIG_POSIX_MQUEUE_SYSCTL=y
++CONFIG_POWER_AVS=y
++CONFIG_POWER_AVS_OMAP=y
++CONFIG_POWER_AVS_OMAP_CLASS3=y
++CONFIG_POWER_RESET=y
++CONFIG_POWER_RESET_GPIO=y
++CONFIG_POWER_RESET_RESTART=y
++CONFIG_POWER_RESET_VEXPRESS=y
++CONFIG_POWER_SUPPLY=y
++# CONFIG_POWER_SUPPLY_DEBUG is not set
++CONFIG_PPDEV=m
++CONFIG_PPP=y
++CONFIG_PPPOATM=m
++CONFIG_PPPOE=m
++CONFIG_PPPOL2TP=m
++CONFIG_PPP_ASYNC=m
++CONFIG_PPP_BSDCOMP=m
++CONFIG_PPP_DEFLATE=m
++CONFIG_PPP_FILTER=y
++CONFIG_PPP_MPPE=m
++CONFIG_PPP_MULTILINK=y
++CONFIG_PPP_SYNC_TTY=m
++CONFIG_PPS_CLIENT_GPIO=m
++# CONFIG_PPS_CLIENT_KTIMER is not set
++CONFIG_PPS_CLIENT_LDISC=m
++CONFIG_PPS_CLIENT_PARPORT=m
++# CONFIG_PPS_DEBUG is not set
++CONFIG_PPTP=m
++# CONFIG_PREEMPT is not set
++# CONFIG_PREEMPT_NONE is not set
++CONFIG_PREEMPT_NOTIFIERS=y
++# CONFIG_PREEMPT_RCU is not set
++CONFIG_PREEMPT_VOLUNTARY=y
++CONFIG_PREVENT_FIRMWARE_BUILD=y
++CONFIG_PRINTER=m
++CONFIG_PRINTK=y
++CONFIG_PRINTK_TIME=y
++# CONFIG_PRINT_QUOTA_WARNING is not set
++CONFIG_PRISM2_USB=m
++# CONFIG_PRISM54 is not set
++CONFIG_PROBE_EVENTS=y
++CONFIG_PROCESSOR_SELECT=y
++CONFIG_PROC_DEVICETREE=y
++CONFIG_PROC_EVENTS=y
++CONFIG_PROC_FS=y
++CONFIG_PROC_KCORE=y
++CONFIG_PROC_PAGE_MONITOR=y
++CONFIG_PROC_PID_CPUSET=y
++CONFIG_PROC_SYSCTL=y
++CONFIG_PROC_VMCORE=y
++# CONFIG_PROFILE_ALL_BRANCHES is not set
++# CONFIG_PROFILE_ANNOTATED_BRANCHES is not set
++CONFIG_PROFILING=y
++# CONFIG_PROVE_LOCKING is not set
++# CONFIG_PROVIDE_OHCI1394_DMA_INIT is not set
++CONFIG_PSTORE=y
++# CONFIG_PSTORE_CONSOLE is not set
++# CONFIG_PSTORE_FTRACE is not set
++CONFIG_PSTORE_RAM=m
++CONFIG_PTP_1588_CLOCK_PCH=m
++CONFIG_PUBLIC_KEY_ALGO_RSA=y
++CONFIG_PVPANIC=m
++CONFIG_PWM=y
++# CONFIG_PWM_IMX is not set
++CONFIG_PWM_PCA9685=m
++CONFIG_PWM_SYSFS=y
++CONFIG_PWM_TEGRA=m
++CONFIG_PWM_TWL=m
++CONFIG_PWM_TWL_LED=m
++CONFIG_QFMT_V1=m
++CONFIG_QFMT_V2=m
++CONFIG_QLA3XXX=m
++CONFIG_QLCNIC=m
++CONFIG_QLCNIC_SRIOV=y
++CONFIG_QLGE=m
++CONFIG_QNX4FS_FS=m
++# CONFIG_QNX6FS_DEBUG is not set
++CONFIG_QNX6FS_FS=m
++CONFIG_QSEMI_PHY=y
++CONFIG_QUOTA=y
++CONFIG_QUOTACTL=y
++CONFIG_QUOTACTL_COMPAT=y
++# CONFIG_QUOTA_DEBUG is not set
++CONFIG_QUOTA_NETLINK_INTERFACE=y
++CONFIG_QUOTA_TREE=m
++CONFIG_R3964=m
++CONFIG_R6040=m
++CONFIG_R8169=m
++CONFIG_R8187SE=m
++CONFIG_R8712U=m
++CONFIG_RADIO_ADAPTERS=y
++CONFIG_RADIO_AZTECH=m
++CONFIG_RADIO_CADET=m
++CONFIG_RADIO_GEMTEK=m
++CONFIG_RADIO_ISA=m
++CONFIG_RADIO_MAXIRADIO=m
++CONFIG_RADIO_MIROPCM20=m
++CONFIG_RADIO_RTRACK=m
++CONFIG_RADIO_RTRACK2=m
++CONFIG_RADIO_SAA7706H=m
++CONFIG_RADIO_SF16FMI=m
++CONFIG_RADIO_SF16FMR2=m
++CONFIG_RADIO_SHARK=m
++CONFIG_RADIO_SHARK2=m
++CONFIG_RADIO_SI470X=y
++CONFIG_RADIO_SI4713=m
++CONFIG_RADIO_SI476X=m
++CONFIG_RADIO_TEA5764=m
++CONFIG_RADIO_TEF6862=m
++CONFIG_RADIO_TERRATEC=m
++CONFIG_RADIO_TIMBERDALE=m
++CONFIG_RADIO_TRUST=m
++CONFIG_RADIO_TYPHOON=m
++CONFIG_RADIO_WL1273=m
++CONFIG_RADIO_WL128X=m
++CONFIG_RADIO_ZOLTRIX=m
++CONFIG_RAID6_PQ=m
++CONFIG_RAID_ATTRS=m
++CONFIG_RAPIDIO=y
++CONFIG_RAPIDIO_CPS_GEN2=y
++CONFIG_RAPIDIO_CPS_XX=y
++# CONFIG_RAPIDIO_DEBUG is not set
++CONFIG_RAPIDIO_DISC_TIMEOUT=30
++CONFIG_RAPIDIO_DMA_ENGINE=y
++# CONFIG_RAPIDIO_ENABLE_RX_TX_PORTS is not set
++CONFIG_RAPIDIO_ENUM_BASIC=m
++CONFIG_RAPIDIO_TSI568=y
++CONFIG_RAPIDIO_TSI57X=y
++CONFIG_RAPIDIO_TSI721=y
++CONFIG_RATIONAL=y
++CONFIG_RAW_DRIVER=m
++CONFIG_RBTREE_TEST=m
++# CONFIG_RCU_CPU_STALL_INFO is not set
++CONFIG_RCU_CPU_STALL_TIMEOUT=60
++# CONFIG_RCU_FANOUT_EXACT is not set
++CONFIG_RCU_FANOUT_LEAF=16
++CONFIG_RCU_FAST_NO_HZ=y
++CONFIG_RCU_NOCB_CPU_ALL=y
++# CONFIG_RCU_NOCB_CPU_NONE is not set
++# CONFIG_RCU_NOCB_CPU_ZERO is not set
++CONFIG_RCU_STALL_COMMON=y
++# CONFIG_RCU_TORTURE_TEST is not set
++# CONFIG_RCU_TRACE is not set
++CONFIG_RC_ATI_REMOTE=m
++CONFIG_RC_CORE=m
++CONFIG_RC_DECODERS=y
++CONFIG_RC_DEVICES=y
++CONFIG_RC_LOOPBACK=m
++CONFIG_RC_MAP=m
++CONFIG_RDS=m
++# CONFIG_RDS_DEBUG is not set
++CONFIG_RDS_RDMA=m
++CONFIG_RDS_TCP=m
++CONFIG_RD_BZIP2=y
++CONFIG_RD_GZIP=y
++CONFIG_RD_LZ4=y
++CONFIG_RD_LZMA=y
++CONFIG_RD_LZO=y
++CONFIG_RD_XZ=y
++# CONFIG_READABLE_ASM is not set
++CONFIG_REALTEK_AUTOPM=y
++CONFIG_REALTEK_PHY=y
++CONFIG_REED_SOLOMON=m
++CONFIG_REED_SOLOMON_DEC16=y
++CONFIG_REED_SOLOMON_DEC8=y
++CONFIG_REED_SOLOMON_ENC8=y
++CONFIG_REGMAP=y
++CONFIG_REGMAP_I2C=y
++CONFIG_REGMAP_IRQ=y
++CONFIG_REGMAP_MMIO=y
++CONFIG_REGMAP_SPI=y
++CONFIG_REGULATOR=y
++CONFIG_REGULATOR_88PM8607=y
++CONFIG_REGULATOR_AAT2870=m
++CONFIG_REGULATOR_AB3100=m
++CONFIG_REGULATOR_AD5398=m
++CONFIG_REGULATOR_ANATOP=m
++CONFIG_REGULATOR_ARIZONA=m
++CONFIG_REGULATOR_AS3711=m
++CONFIG_REGULATOR_DA903X=m
++CONFIG_REGULATOR_DA9052=m
++CONFIG_REGULATOR_DA9055=m
++# CONFIG_REGULATOR_DEBUG is not set
++# CONFIG_REGULATOR_DUMMY is not set
++CONFIG_REGULATOR_FAN53555=m
++CONFIG_REGULATOR_GPIO=m
++CONFIG_REGULATOR_ISL6271A=m
++CONFIG_REGULATOR_LP3971=m
++CONFIG_REGULATOR_LP3972=m
++CONFIG_REGULATOR_LP872X=y
++CONFIG_REGULATOR_LP8755=m
++CONFIG_REGULATOR_LP8788=y
++CONFIG_REGULATOR_MAX1586=m
++CONFIG_REGULATOR_MAX77686=m
++CONFIG_REGULATOR_MAX77693=m
++CONFIG_REGULATOR_MAX8649=m
++CONFIG_REGULATOR_MAX8660=m
++CONFIG_REGULATOR_MAX8907=m
++CONFIG_REGULATOR_MAX8925=m
++CONFIG_REGULATOR_MAX8952=m
++CONFIG_REGULATOR_MAX8973=m
++CONFIG_REGULATOR_MAX8997=m
++CONFIG_REGULATOR_MAX8998=m
++CONFIG_REGULATOR_MC13783=m
++CONFIG_REGULATOR_MC13892=m
++CONFIG_REGULATOR_MC13XXX_CORE=m
++CONFIG_REGULATOR_PALMAS=m
++CONFIG_REGULATOR_PCAP=m
++CONFIG_REGULATOR_PCF50633=m
++CONFIG_REGULATOR_RC5T583=m
++CONFIG_REGULATOR_S2MPS11=m
++CONFIG_REGULATOR_S5M8767=m
++CONFIG_REGULATOR_TI_ABB=y
++CONFIG_REGULATOR_TPS51632=m
++CONFIG_REGULATOR_TPS6105X=m
++CONFIG_REGULATOR_TPS62360=m
++CONFIG_REGULATOR_TPS65023=m
++CONFIG_REGULATOR_TPS6507X=m
++CONFIG_REGULATOR_TPS65090=m
++CONFIG_REGULATOR_TPS65217=m
++CONFIG_REGULATOR_TPS6524X=m
++CONFIG_REGULATOR_TPS6586X=m
++CONFIG_REGULATOR_TPS65910=m
++CONFIG_REGULATOR_TPS65912=m
++CONFIG_REGULATOR_TPS80031=m
++CONFIG_REGULATOR_TWL4030=y
++CONFIG_REGULATOR_USERSPACE_CONSUMER=m
++CONFIG_REGULATOR_VEXPRESS=m
++CONFIG_REGULATOR_VIRTUAL_CONSUMER=m
++CONFIG_REGULATOR_WM831X=m
++CONFIG_REGULATOR_WM8350=m
++CONFIG_REGULATOR_WM8400=m
++CONFIG_REGULATOR_WM8994=m
++# CONFIG_REISERFS_CHECK is not set
++CONFIG_REISERFS_FS=m
++CONFIG_REISERFS_FS_POSIX_ACL=y
++CONFIG_REISERFS_FS_SECURITY=y
++CONFIG_REISERFS_FS_XATTR=y
++# CONFIG_REISERFS_PROC_INFO is not set
++CONFIG_RELAY=y
++CONFIG_RELOCATABLE=y
++CONFIG_REMOTEPROC=m
++CONFIG_RESET_CONTROLLER=y
++CONFIG_RESOURCE_COUNTERS=y
++CONFIG_RETU_WATCHDOG=m
++CONFIG_RFD_FTL=m
++CONFIG_RFKILL=y
++CONFIG_RFKILL_GPIO=m
++CONFIG_RFKILL_INPUT=y
++CONFIG_RFKILL_LEDS=y
++CONFIG_RFKILL_REGULATOR=m
++CONFIG_RFS_ACCEL=y
++CONFIG_RING_BUFFER=y
++CONFIG_RING_BUFFER_ALLOW_SWAP=y
++# CONFIG_RING_BUFFER_BENCHMARK is not set
++# CONFIG_RING_BUFFER_STARTUP_TEST is not set
++CONFIG_RIONET=m
++CONFIG_RIONET_RX_SIZE=128
++CONFIG_RIONET_TX_SIZE=128
++CONFIG_ROCKETPORT=m
++CONFIG_ROMFS_BACKED_BY_BLOCK=y
++# CONFIG_ROMFS_BACKED_BY_BOTH is not set
++# CONFIG_ROMFS_BACKED_BY_MTD is not set
++CONFIG_ROMFS_FS=m
++CONFIG_ROMFS_ON_BLOCK=y
++CONFIG_ROSE=m
++CONFIG_RPCSEC_GSS_KRB5=m
++CONFIG_RPMSG=m
++CONFIG_RPS=y
++CONFIG_RT2400PCI=m
++CONFIG_RT2500PCI=m
++CONFIG_RT2500USB=m
++CONFIG_RT2800PCI=m
++CONFIG_RT2800PCI_RT3290=y
++CONFIG_RT2800PCI_RT33XX=y
++CONFIG_RT2800PCI_RT35XX=y
++CONFIG_RT2800PCI_RT53XX=y
++CONFIG_RT2800USB=m
++CONFIG_RT2800USB_RT33XX=y
++CONFIG_RT2800USB_RT35XX=y
++CONFIG_RT2800USB_RT53XX=y
++CONFIG_RT2800USB_RT55XX=y
++CONFIG_RT2800_LIB=m
++CONFIG_RT2X00=m
++# CONFIG_RT2X00_DEBUG is not set
++CONFIG_RT2X00_LIB=m
++CONFIG_RT2X00_LIB_CRYPTO=y
++CONFIG_RT2X00_LIB_FIRMWARE=y
++CONFIG_RT2X00_LIB_LEDS=y
++CONFIG_RT2X00_LIB_MMIO=m
++CONFIG_RT2X00_LIB_PCI=m
++CONFIG_RT2X00_LIB_USB=m
++CONFIG_RT61PCI=m
++CONFIG_RT73USB=m
++CONFIG_RTC_CLASS=y
++# CONFIG_RTC_DEBUG is not set
++CONFIG_RTC_DRV_88PM80X=m
++CONFIG_RTC_DRV_88PM860X=m
++CONFIG_RTC_DRV_AB3100=m
++CONFIG_RTC_DRV_BQ32K=m
++CONFIG_RTC_DRV_BQ4802=m
++CONFIG_RTC_DRV_DA9052=m
++CONFIG_RTC_DRV_DA9055=m
++CONFIG_RTC_DRV_DS1286=m
++CONFIG_RTC_DRV_DS1305=m
++CONFIG_RTC_DRV_DS1307=m
++CONFIG_RTC_DRV_DS1374=m
++CONFIG_RTC_DRV_DS1390=m
++CONFIG_RTC_DRV_DS1511=m
++CONFIG_RTC_DRV_DS1553=m
++CONFIG_RTC_DRV_DS1672=m
++CONFIG_RTC_DRV_DS1742=m
++CONFIG_RTC_DRV_DS2404=m
++CONFIG_RTC_DRV_DS3232=m
++CONFIG_RTC_DRV_DS3234=m
++CONFIG_RTC_DRV_EM3027=m
++CONFIG_RTC_DRV_FM3130=m
++CONFIG_RTC_DRV_HID_SENSOR_TIME=m
++# CONFIG_RTC_DRV_IMXDI is not set
++CONFIG_RTC_DRV_ISL12022=m
++CONFIG_RTC_DRV_ISL1208=m
++CONFIG_RTC_DRV_LP8788=m
++CONFIG_RTC_DRV_M41T80=m
++CONFIG_RTC_DRV_M41T80_WDT=y
++CONFIG_RTC_DRV_M41T93=m
++CONFIG_RTC_DRV_M41T94=m
++CONFIG_RTC_DRV_M48T35=m
++CONFIG_RTC_DRV_M48T59=m
++CONFIG_RTC_DRV_M48T86=m
++CONFIG_RTC_DRV_MAX6900=m
++CONFIG_RTC_DRV_MAX6902=m
++CONFIG_RTC_DRV_MAX77686=m
++CONFIG_RTC_DRV_MAX8907=m
++CONFIG_RTC_DRV_MAX8925=m
++CONFIG_RTC_DRV_MAX8997=m
++CONFIG_RTC_DRV_MAX8998=m
++CONFIG_RTC_DRV_MC13XXX=m
++CONFIG_RTC_DRV_MSM6242=m
++# CONFIG_RTC_DRV_MXC is not set
++CONFIG_RTC_DRV_PALMAS=m
++CONFIG_RTC_DRV_PCAP=m
++CONFIG_RTC_DRV_PCF2123=m
++CONFIG_RTC_DRV_PCF2127=m
++CONFIG_RTC_DRV_PCF50633=m
++CONFIG_RTC_DRV_PCF8523=m
++CONFIG_RTC_DRV_PCF8563=m
++CONFIG_RTC_DRV_PCF8583=m
++CONFIG_RTC_DRV_PL030=m
++CONFIG_RTC_DRV_PL031=m
++CONFIG_RTC_DRV_R9701=m
++CONFIG_RTC_DRV_RC5T583=m
++CONFIG_RTC_DRV_RP5C01=m
++CONFIG_RTC_DRV_RS5C348=m
++CONFIG_RTC_DRV_RS5C372=m
++CONFIG_RTC_DRV_RV3029C2=m
++CONFIG_RTC_DRV_RX4581=m
++CONFIG_RTC_DRV_RX8025=m
++CONFIG_RTC_DRV_RX8581=m
++CONFIG_RTC_DRV_S35390A=m
++CONFIG_RTC_DRV_SNVS=m
++CONFIG_RTC_DRV_STK17TA8=m
++CONFIG_RTC_DRV_TEGRA=m
++# CONFIG_RTC_DRV_TEST is not set
++CONFIG_RTC_DRV_TPS6586X=m
++CONFIG_RTC_DRV_TPS65910=m
++CONFIG_RTC_DRV_TPS80031=m
++CONFIG_RTC_DRV_TWL4030=y
++CONFIG_RTC_DRV_V3020=m
++CONFIG_RTC_DRV_VRTC=m
++CONFIG_RTC_DRV_WM831X=m
++CONFIG_RTC_DRV_WM8350=m
++CONFIG_RTC_DRV_X1205=m
++CONFIG_RTC_HCTOSYS=y
++CONFIG_RTC_HCTOSYS_DEVICE="rtc0"
++CONFIG_RTC_INTF_DEV=y
++# CONFIG_RTC_INTF_DEV_UIE_EMUL is not set
++CONFIG_RTC_INTF_PROC=y
++CONFIG_RTC_INTF_SYSFS=y
++CONFIG_RTC_LIB=y
++CONFIG_RTC_SYSTOHC=y
++CONFIG_RTL8180=m
++CONFIG_RTL8187=m
++CONFIG_RTL8187_LEDS=y
++CONFIG_RTL8188EE=m
++CONFIG_RTL8192CE=m
++CONFIG_RTL8192CU=m
++CONFIG_RTL8192C_COMMON=m
++CONFIG_RTL8192DE=m
++CONFIG_RTL8192E=m
++CONFIG_RTL8192SE=m
++CONFIG_RTL8192U=m
++CONFIG_RTL8723AE=m
++CONFIG_RTLLIB=m
++CONFIG_RTLLIB_CRYPTO_CCMP=m
++CONFIG_RTLLIB_CRYPTO_TKIP=m
++CONFIG_RTLLIB_CRYPTO_WEP=m
++CONFIG_RTLWIFI=m
++# CONFIG_RTLWIFI_DEBUG is not set
++CONFIG_RTLWIFI_PCI=m
++CONFIG_RTLWIFI_USB=m
++CONFIG_RTL_CARDS=m
++CONFIG_RTS5139=m
++# CONFIG_RTS5139_DEBUG is not set
++CONFIG_RT_GROUP_SCHED=y
++CONFIG_RT_MUTEXES=y
++# CONFIG_RT_MUTEX_TESTER is not set
++CONFIG_RWSEM_GENERIC_SPINLOCK=y
++CONFIG_RWSEM_XCHGADD_ALGORITHM=y
++CONFIG_RXKAD=m
++CONFIG_S2IO=m
++# CONFIG_SAMPLES is not set
++CONFIG_SAMSUNG_LAPTOP=m
++CONFIG_SAMSUNG_Q10=m
++CONFIG_SAMSUNG_USB2PHY=m
++CONFIG_SAMSUNG_USB3PHY=m
++CONFIG_SAMSUNG_USBPHY=m
++CONFIG_SATA_ACARD_AHCI=m
++CONFIG_SATA_AHCI=m
++CONFIG_SATA_INIC162X=m
++CONFIG_SATA_MV=m
++CONFIG_SATA_NV=m
++CONFIG_SATA_PMP=y
++CONFIG_SATA_PROMISE=m
++CONFIG_SATA_QSTOR=m
++CONFIG_SATA_RCAR=m
++CONFIG_SATA_SIL=m
++CONFIG_SATA_SIL24=m
++CONFIG_SATA_SIS=m
++CONFIG_SATA_SVW=m
++CONFIG_SATA_SX4=m
++CONFIG_SATA_ULI=m
++CONFIG_SATA_VIA=m
++CONFIG_SATA_VITESSE=m
++CONFIG_SATA_ZPODD=y
++CONFIG_SBC7240_WDT=m
++CONFIG_SBC8360_WDT=m
++CONFIG_SBC_EPX_C3_WATCHDOG=m
++CONFIG_SBC_FITPC2_WATCHDOG=m
++CONFIG_SBE_2T3E3=m
++CONFIG_SBE_PMCC4_NCOMM=y
++CONFIG_SBNI=m
++# CONFIG_SBNI_MULTILINE is not set
++CONFIG_SBP_TARGET=m
++CONFIG_SBYPASS=m
++CONFIG_SC1200_WDT=m
++CONFIG_SC520_WDT=m
++CONFIG_SC92031=m
++CONFIG_SCA3000=m
++CONFIG_SCC=m
++# CONFIG_SCC_DELAY is not set
++# CONFIG_SCC_TRXECHO is not set
++CONFIG_SCHEDSTATS=y
++CONFIG_SCHED_AUTOGROUP=y
++CONFIG_SCHED_DEBUG=y
++CONFIG_SCHED_HRTICK=y
++CONFIG_SCHED_MC=y
++CONFIG_SCHED_OMIT_FRAME_POINTER=y
++CONFIG_SCHED_TRACER=y
++CONFIG_SCSI=y
++CONFIG_SCSI_3W_9XXX=m
++CONFIG_SCSI_3W_SAS=m
++CONFIG_SCSI_7000FASST=m
++CONFIG_SCSI_AACRAID=m
++CONFIG_SCSI_ACARD=m
++CONFIG_SCSI_ADVANSYS=m
++CONFIG_SCSI_AHA152X=m
++CONFIG_SCSI_AHA1542=m
++CONFIG_SCSI_AHA1740=m
++CONFIG_SCSI_AIC79XX=m
++CONFIG_SCSI_AIC7XXX=m
++# CONFIG_SCSI_AIC7XXX_OLD is not set
++CONFIG_SCSI_AIC94XX=m
++CONFIG_SCSI_ARCMSR=m
++CONFIG_SCSI_BFA_FC=m
++CONFIG_SCSI_BNX2X_FCOE=m
++CONFIG_SCSI_BNX2_ISCSI=m
++CONFIG_SCSI_BUSLOGIC=m
++CONFIG_SCSI_CHELSIO_FCOE=m
++CONFIG_SCSI_CONSTANTS=y
++CONFIG_SCSI_CXGB3_ISCSI=m
++CONFIG_SCSI_CXGB4_ISCSI=m
++CONFIG_SCSI_DC390T=m
++CONFIG_SCSI_DC395x=m
++CONFIG_SCSI_DEBUG=m
++CONFIG_SCSI_DH=m
++CONFIG_SCSI_DH_ALUA=m
++CONFIG_SCSI_DH_EMC=m
++CONFIG_SCSI_DH_HP_SW=m
++CONFIG_SCSI_DH_RDAC=m
++CONFIG_SCSI_DMA=y
++CONFIG_SCSI_DMX3191D=m
++CONFIG_SCSI_DPT_I2O=m
++CONFIG_SCSI_DTC3280=m
++CONFIG_SCSI_EATA=m
++CONFIG_SCSI_EATA_LINKED_COMMANDS=y
++CONFIG_SCSI_EATA_MAX_TAGS=16
++CONFIG_SCSI_EATA_TAGGED_QUEUE=y
++CONFIG_SCSI_ENCLOSURE=m
++CONFIG_SCSI_FC_ATTRS=m
++CONFIG_SCSI_FC_TGT_ATTRS=y
++CONFIG_SCSI_FLASHPOINT=y
++CONFIG_SCSI_FUTURE_DOMAIN=m
++CONFIG_SCSI_GDTH=m
++CONFIG_SCSI_GENERIC_NCR5380=m
++CONFIG_SCSI_GENERIC_NCR5380_MMIO=m
++CONFIG_SCSI_GENERIC_NCR53C400=y
++CONFIG_SCSI_HPSA=m
++CONFIG_SCSI_HPTIOP=m
++CONFIG_SCSI_IMM=m
++CONFIG_SCSI_IN2000=m
++CONFIG_SCSI_INIA100=m
++CONFIG_SCSI_INITIO=m
++CONFIG_SCSI_IPR=m
++# CONFIG_SCSI_IPR_DUMP is not set
++# CONFIG_SCSI_IPR_TRACE is not set
++CONFIG_SCSI_IPS=m
++CONFIG_SCSI_ISCI=m
++CONFIG_SCSI_ISCSI_ATTRS=m
++# CONFIG_SCSI_IZIP_EPP16 is not set
++# CONFIG_SCSI_IZIP_SLOW_CTR is not set
++CONFIG_SCSI_LOGGING=y
++CONFIG_SCSI_LOWLEVEL=y
++CONFIG_SCSI_LOWLEVEL_PCMCIA=y
++CONFIG_SCSI_LPFC=m
++# CONFIG_SCSI_LPFC_DEBUG_FS is not set
++CONFIG_SCSI_MOD=y
++CONFIG_SCSI_MPT2SAS=m
++# CONFIG_SCSI_MPT2SAS_LOGGING is not set
++CONFIG_SCSI_MPT2SAS_MAX_SGE=128
++CONFIG_SCSI_MPT3SAS=m
++# CONFIG_SCSI_MPT3SAS_LOGGING is not set
++CONFIG_SCSI_MPT3SAS_MAX_SGE=128
++CONFIG_SCSI_MULTI_LUN=y
++CONFIG_SCSI_MVSAS=m
++# CONFIG_SCSI_MVSAS_DEBUG is not set
++# CONFIG_SCSI_MVSAS_TASKLET is not set
++CONFIG_SCSI_MVUMI=m
++CONFIG_SCSI_NCR53C406A=m
++CONFIG_SCSI_NETLINK=y
++CONFIG_SCSI_NSP32=m
++# CONFIG_SCSI_OSD_DEBUG is not set
++CONFIG_SCSI_OSD_DPRINT_SENSE=1
++CONFIG_SCSI_OSD_INITIATOR=m
++CONFIG_SCSI_OSD_ULD=m
++CONFIG_SCSI_PAS16=m
++CONFIG_SCSI_PM8001=m
++CONFIG_SCSI_PMCRAID=m
++CONFIG_SCSI_PPA=m
++CONFIG_SCSI_PROC_FS=y
++CONFIG_SCSI_QLA_FC=m
++CONFIG_SCSI_QLA_ISCSI=m
++CONFIG_SCSI_QLOGIC_1280=m
++CONFIG_SCSI_QLOGIC_FAS=m
++CONFIG_SCSI_SAS_ATA=y
++CONFIG_SCSI_SAS_ATTRS=m
++CONFIG_SCSI_SAS_HOST_SMP=y
++CONFIG_SCSI_SAS_LIBSAS=m
++CONFIG_SCSI_SCAN_ASYNC=y
++CONFIG_SCSI_SIM710=m
++CONFIG_SCSI_SRP=m
++CONFIG_SCSI_SRP_ATTRS=m
++CONFIG_SCSI_SRP_TGT_ATTRS=y
++CONFIG_SCSI_STEX=m
++CONFIG_SCSI_SYM53C416=m
++CONFIG_SCSI_SYM53C8XX_2=m
++CONFIG_SCSI_SYM53C8XX_DEFAULT_TAGS=16
++CONFIG_SCSI_SYM53C8XX_DMA_ADDRESSING_MODE=1
++CONFIG_SCSI_SYM53C8XX_MAX_TAGS=64
++CONFIG_SCSI_SYM53C8XX_MMIO=y
++CONFIG_SCSI_T128=m
++CONFIG_SCSI_TGT=m
++CONFIG_SCSI_U14_34F=m
++CONFIG_SCSI_U14_34F_LINKED_COMMANDS=y
++CONFIG_SCSI_U14_34F_MAX_TAGS=8
++CONFIG_SCSI_U14_34F_TAGGED_QUEUE=y
++CONFIG_SCSI_UFSHCD=m
++CONFIG_SCSI_UFSHCD_PCI=m
++CONFIG_SCSI_UFSHCD_PLATFORM=m
++CONFIG_SCSI_ULTRASTOR=m
++CONFIG_SCSI_VIRTIO=m
++CONFIG_SCTP_COOKIE_HMAC_MD5=y
++CONFIG_SCTP_COOKIE_HMAC_SHA1=y
++# CONFIG_SCTP_DBG_OBJCNT is not set
++# CONFIG_SCTP_DEFAULT_COOKIE_HMAC_MD5 is not set
++# CONFIG_SCTP_DEFAULT_COOKIE_HMAC_NONE is not set
++CONFIG_SCTP_DEFAULT_COOKIE_HMAC_SHA1=y
++CONFIG_SCx200=m
++CONFIG_SCx200HR_TIMER=m
++CONFIG_SCx200_ACB=m
++CONFIG_SCx200_GPIO=m
++# CONFIG_SCx200_I2C is not set
++CONFIG_SCx200_WDT=m
++CONFIG_SDIO_UART=m
++CONFIG_SDLA=m
++CONFIG_SEALEVEL_4021=m
++CONFIG_SECCOMP=y
++CONFIG_SECCOMP_FILTER=y
++CONFIG_SECURITY=y
++CONFIG_SECURITYFS=y
++CONFIG_SECURITY_APPARMOR=y
++CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE=1
++CONFIG_SECURITY_APPARMOR_HASH=y
++# CONFIG_SECURITY_APPARMOR_STATS is not set
++CONFIG_SECURITY_APPARMOR_UNCONFINED_INIT=y
++# CONFIG_SECURITY_DMESG_RESTRICT is not set
++CONFIG_SECURITY_NETWORK=y
++# CONFIG_SECURITY_NETWORK_XFRM is not set
++CONFIG_SECURITY_PATH=y
++CONFIG_SECURITY_SELINUX=y
++CONFIG_SECURITY_SELINUX_AVC_STATS=y
++CONFIG_SECURITY_SELINUX_BOOTPARAM=y
++CONFIG_SECURITY_SELINUX_BOOTPARAM_VALUE=0
++CONFIG_SECURITY_SELINUX_CHECKREQPROT_VALUE=1
++CONFIG_SECURITY_SELINUX_DEVELOP=y
++CONFIG_SECURITY_SELINUX_DISABLE=y
++# CONFIG_SECURITY_SELINUX_POLICYDB_VERSION_MAX is not set
++CONFIG_SECURITY_SMACK=y
++CONFIG_SECURITY_TOMOYO=y
++CONFIG_SECURITY_TOMOYO_ACTIVATION_TRIGGER="/sbin/init"
++CONFIG_SECURITY_TOMOYO_MAX_ACCEPT_ENTRY=2048
++CONFIG_SECURITY_TOMOYO_MAX_AUDIT_LOG=1024
++# CONFIG_SECURITY_TOMOYO_OMIT_USERSPACE_LOADER is not set
++CONFIG_SECURITY_TOMOYO_POLICY_LOADER="/sbin/tomoyo-init"
++CONFIG_SECURITY_YAMA=y
++CONFIG_SECURITY_YAMA_STACKED=y
++CONFIG_SELECT_MEMORY_MODEL=y
++CONFIG_SENSORS_ABITUGURU=m
++CONFIG_SENSORS_ABITUGURU3=m
++CONFIG_SENSORS_ACPI_POWER=m
++CONFIG_SENSORS_AD7314=m
++CONFIG_SENSORS_AD7414=m
++CONFIG_SENSORS_AD7418=m
++CONFIG_SENSORS_ADCXX=m
++CONFIG_SENSORS_ADM1021=m
++CONFIG_SENSORS_ADM1025=m
++CONFIG_SENSORS_ADM1026=m
++CONFIG_SENSORS_ADM1029=m
++CONFIG_SENSORS_ADM1031=m
++CONFIG_SENSORS_ADM1275=m
++CONFIG_SENSORS_ADM9240=m
++CONFIG_SENSORS_ADS1015=m
++CONFIG_SENSORS_ADS7828=m
++CONFIG_SENSORS_ADS7871=m
++CONFIG_SENSORS_ADT7310=m
++CONFIG_SENSORS_ADT7410=m
++CONFIG_SENSORS_ADT7411=m
++CONFIG_SENSORS_ADT7462=m
++CONFIG_SENSORS_ADT7470=m
++CONFIG_SENSORS_ADT7475=m
++CONFIG_SENSORS_ADT7X10=m
++CONFIG_SENSORS_AMC6821=m
++CONFIG_SENSORS_APDS990X=m
++CONFIG_SENSORS_APPLESMC=m
++CONFIG_SENSORS_ASB100=m
++CONFIG_SENSORS_ASC7621=m
++CONFIG_SENSORS_ATK0110=m
++CONFIG_SENSORS_ATXP1=m
++CONFIG_SENSORS_BH1770=m
++CONFIG_SENSORS_BH1780=m
++CONFIG_SENSORS_CORETEMP=m
++CONFIG_SENSORS_DA9052_ADC=m
++CONFIG_SENSORS_DA9055=m
++CONFIG_SENSORS_DME1737=m
++CONFIG_SENSORS_DS1621=m
++CONFIG_SENSORS_DS620=m
++CONFIG_SENSORS_EMC1403=m
++CONFIG_SENSORS_EMC2103=m
++CONFIG_SENSORS_EMC6W201=m
++CONFIG_SENSORS_F71805F=m
++CONFIG_SENSORS_F71882FG=m
++CONFIG_SENSORS_F75375S=m
++CONFIG_SENSORS_FAM15H_POWER=m
++CONFIG_SENSORS_FSCHMD=m
++CONFIG_SENSORS_G760A=m
++CONFIG_SENSORS_G762=m
++CONFIG_SENSORS_GL518SM=m
++CONFIG_SENSORS_GL520SM=m
++CONFIG_SENSORS_GPIO_FAN=m
++CONFIG_SENSORS_HDAPS=m
++CONFIG_SENSORS_HIH6130=m
++CONFIG_SENSORS_HMC5843=m
++CONFIG_SENSORS_I5K_AMB=m
++CONFIG_SENSORS_IBMAEM=m
++CONFIG_SENSORS_IBMPEX=m
++CONFIG_SENSORS_IIO_HWMON=m
++CONFIG_SENSORS_INA209=m
++CONFIG_SENSORS_INA2XX=m
++CONFIG_SENSORS_ISL29018=m
++CONFIG_SENSORS_ISL29028=m
++CONFIG_SENSORS_IT87=m
++CONFIG_SENSORS_JC42=m
++CONFIG_SENSORS_K10TEMP=m
++CONFIG_SENSORS_K8TEMP=m
++CONFIG_SENSORS_LINEAGE=m
++CONFIG_SENSORS_LIS3LV02D=m
++CONFIG_SENSORS_LIS3_I2C=m
++CONFIG_SENSORS_LIS3_SPI=m
++CONFIG_SENSORS_LM25066=m
++CONFIG_SENSORS_LM3533=m
++CONFIG_SENSORS_LM63=m
++CONFIG_SENSORS_LM70=m
++CONFIG_SENSORS_LM73=m
++CONFIG_SENSORS_LM75=m
++CONFIG_SENSORS_LM77=m
++CONFIG_SENSORS_LM78=m
++CONFIG_SENSORS_LM80=m
++CONFIG_SENSORS_LM83=m
++CONFIG_SENSORS_LM85=m
++CONFIG_SENSORS_LM87=m
++CONFIG_SENSORS_LM90=m
++CONFIG_SENSORS_LM92=m
++CONFIG_SENSORS_LM93=m
++CONFIG_SENSORS_LM95234=m
++CONFIG_SENSORS_LM95241=m
++CONFIG_SENSORS_LM95245=m
++CONFIG_SENSORS_LTC2978=m
++CONFIG_SENSORS_LTC4151=m
++CONFIG_SENSORS_LTC4215=m
++CONFIG_SENSORS_LTC4245=m
++CONFIG_SENSORS_LTC4261=m
++CONFIG_SENSORS_MAX1111=m
++CONFIG_SENSORS_MAX16064=m
++CONFIG_SENSORS_MAX16065=m
++CONFIG_SENSORS_MAX1619=m
++CONFIG_SENSORS_MAX1668=m
++CONFIG_SENSORS_MAX197=m
++CONFIG_SENSORS_MAX34440=m
++CONFIG_SENSORS_MAX6639=m
++CONFIG_SENSORS_MAX6642=m
++CONFIG_SENSORS_MAX6650=m
++CONFIG_SENSORS_MAX6697=m
++CONFIG_SENSORS_MAX8688=m
++CONFIG_SENSORS_MC13783_ADC=m
++CONFIG_SENSORS_MCP3021=m
++CONFIG_SENSORS_NCT6775=m
++CONFIG_SENSORS_NTC_THERMISTOR=m
++CONFIG_SENSORS_PC87360=m
++CONFIG_SENSORS_PC87427=m
++CONFIG_SENSORS_PCF8591=m
++CONFIG_SENSORS_PMBUS=m
++CONFIG_SENSORS_SCH5627=m
++CONFIG_SENSORS_SCH5636=m
++CONFIG_SENSORS_SCH56XX_COMMON=m
++CONFIG_SENSORS_SHT15=m
++CONFIG_SENSORS_SHT21=m
++CONFIG_SENSORS_SIS5595=m
++CONFIG_SENSORS_SMM665=m
++CONFIG_SENSORS_SMSC47B397=m
++CONFIG_SENSORS_SMSC47M1=m
++CONFIG_SENSORS_SMSC47M192=m
++CONFIG_SENSORS_THMC50=m
++CONFIG_SENSORS_TMP102=m
++CONFIG_SENSORS_TMP401=m
++CONFIG_SENSORS_TMP421=m
++CONFIG_SENSORS_TSL2550=m
++CONFIG_SENSORS_TSL2563=m
++CONFIG_SENSORS_TWL4030_MADC=m
++CONFIG_SENSORS_UCD9000=m
++CONFIG_SENSORS_UCD9200=m
++CONFIG_SENSORS_VEXPRESS=m
++CONFIG_SENSORS_VIA686A=m
++CONFIG_SENSORS_VIA_CPUTEMP=m
++CONFIG_SENSORS_VT1211=m
++CONFIG_SENSORS_VT8231=m
++CONFIG_SENSORS_W83627EHF=m
++CONFIG_SENSORS_W83627HF=m
++CONFIG_SENSORS_W83781D=m
++CONFIG_SENSORS_W83791D=m
++CONFIG_SENSORS_W83792D=m
++CONFIG_SENSORS_W83793=m
++CONFIG_SENSORS_W83795=m
++# CONFIG_SENSORS_W83795_FANCTRL is not set
++CONFIG_SENSORS_W83L785TS=m
++CONFIG_SENSORS_W83L786NG=m
++CONFIG_SENSORS_WM831X=m
++CONFIG_SENSORS_WM8350=m
++CONFIG_SENSORS_ZL6100=m
++CONFIG_SERIAL_8250=y
++CONFIG_SERIAL_8250_ACCENT=m
++CONFIG_SERIAL_8250_BOCA=m
++CONFIG_SERIAL_8250_CONSOLE=y
++CONFIG_SERIAL_8250_CS=m
++# CONFIG_SERIAL_8250_DEPRECATED_OPTIONS is not set
++# CONFIG_SERIAL_8250_DETECT_IRQ is not set
++CONFIG_SERIAL_8250_DMA=y
++CONFIG_SERIAL_8250_DW=m
++# CONFIG_SERIAL_8250_EM is not set
++CONFIG_SERIAL_8250_EXAR_ST16C554=m
++CONFIG_SERIAL_8250_EXTENDED=y
++CONFIG_SERIAL_8250_FOURPORT=m
++CONFIG_SERIAL_8250_HUB6=m
++CONFIG_SERIAL_8250_MANY_PORTS=y
++CONFIG_SERIAL_8250_NR_UARTS=48
++CONFIG_SERIAL_8250_PCI=y
++CONFIG_SERIAL_8250_PNP=y
++CONFIG_SERIAL_8250_RSA=y
++CONFIG_SERIAL_8250_RUNTIME_UARTS=32
++CONFIG_SERIAL_8250_SHARE_IRQ=y
++CONFIG_SERIAL_ALTERA_JTAGUART=m
++CONFIG_SERIAL_ALTERA_UART=m
++CONFIG_SERIAL_ALTERA_UART_BAUDRATE=115200
++CONFIG_SERIAL_ALTERA_UART_MAXPORTS=4
++CONFIG_SERIAL_AMBA_PL010=m
++CONFIG_SERIAL_AMBA_PL011=y
++CONFIG_SERIAL_AMBA_PL011_CONSOLE=y
++CONFIG_SERIAL_ARC=m
++CONFIG_SERIAL_ARC_NR_PORTS=1
++CONFIG_SERIAL_CORE=y
++CONFIG_SERIAL_CORE_CONSOLE=y
++CONFIG_SERIAL_FSL_LPUART=m
++# CONFIG_SERIAL_IFX6X60 is not set
++CONFIG_SERIAL_IMX=y
++CONFIG_SERIAL_IMX_CONSOLE=y
++CONFIG_SERIAL_IPOCTAL=m
++CONFIG_SERIAL_JSM=m
++CONFIG_SERIAL_KGDB_NMI=y
++CONFIG_SERIAL_MAX3100=m
++CONFIG_SERIAL_MAX310X=y
++CONFIG_SERIAL_MFD_HSU=m
++CONFIG_SERIAL_MRST_MAX3110=m
++CONFIG_SERIAL_NONSTANDARD=y
++CONFIG_SERIAL_OF_PLATFORM=y
++CONFIG_SERIAL_OMAP=y
++CONFIG_SERIAL_OMAP_CONSOLE=y
++CONFIG_SERIAL_PCH_UART=m
++CONFIG_SERIAL_RP2=m
++CONFIG_SERIAL_RP2_NR_UARTS=32
++CONFIG_SERIAL_SCCNXP=y
++CONFIG_SERIAL_SCCNXP_CONSOLE=y
++CONFIG_SERIAL_TEGRA=m
++CONFIG_SERIAL_TIMBERDALE=m
++CONFIG_SERIAL_UARTLITE=m
++CONFIG_SERIAL_XILINX_PS_UART=m
++CONFIG_SERIO=y
++CONFIG_SERIO_ALTERA_PS2=m
++CONFIG_SERIO_AMBAKMI=m
++CONFIG_SERIO_APBPS2=m
++CONFIG_SERIO_ARC_PS2=m
++CONFIG_SERIO_CT82C710=m
++CONFIG_SERIO_I8042=y
++CONFIG_SERIO_LIBPS2=y
++CONFIG_SERIO_NVEC_PS2=m
++CONFIG_SERIO_OLPC_APSP=m
++CONFIG_SERIO_PARKBD=m
++CONFIG_SERIO_PCIPS2=m
++CONFIG_SERIO_PS2MULT=m
++CONFIG_SERIO_RAW=m
++CONFIG_SERIO_SERPORT=m
++CONFIG_SFC=m
++CONFIG_SFC_MCDI_MON=y
++CONFIG_SFC_MTD=y
++CONFIG_SFC_SRIOV=y
++CONFIG_SFI=y
++CONFIG_SGI_IOC4=m
++CONFIG_SGI_PARTITION=y
++CONFIG_SHMEM=y
++CONFIG_SH_ETH=m
++CONFIG_SIGMATEL_FIR=m
++CONFIG_SIGNALFD=y
++CONFIG_SIGNATURE=y
++CONFIG_SIS190=m
++CONFIG_SIS900=m
++CONFIG_SKFP=m
++CONFIG_SKGE=m
++# CONFIG_SKGE_DEBUG is not set
++CONFIG_SKGE_GENESIS=y
++CONFIG_SKY2=m
++# CONFIG_SKY2_DEBUG is not set
++# CONFIG_SLAB is not set
++CONFIG_SLABINFO=y
++CONFIG_SLHC=y
++CONFIG_SLICOSS=m
++CONFIG_SLIP=m
++CONFIG_SLIP_COMPRESSED=y
++CONFIG_SLIP_MODE_SLIP6=y
++CONFIG_SLIP_SMART=y
++# CONFIG_SLOB is not set
++CONFIG_SLUB=y
++CONFIG_SLUB_CPU_PARTIAL=y
++CONFIG_SLUB_DEBUG=y
++# CONFIG_SLUB_DEBUG_ON is not set
++# CONFIG_SLUB_STATS is not set
++CONFIG_SMARTJOYPLUS_FF=y
++CONFIG_SMC911X=m
++CONFIG_SMC9194=m
++CONFIG_SMC91X=m
++CONFIG_SMC_IRCC_FIR=m
++CONFIG_SMP=y
++CONFIG_SMP_ON_UP=y
++CONFIG_SMSC37B787_WDT=m
++CONFIG_SMSC911X=m
++# CONFIG_SMSC911X_ARCH_HOOKS is not set
++CONFIG_SMSC9420=m
++CONFIG_SMSC_PHY=y
++CONFIG_SMSC_SCH311X_WDT=m
++CONFIG_SMS_SDIO_DRV=m
++CONFIG_SMS_SIANO_MDTV=m
++CONFIG_SMS_SIANO_RC=y
++CONFIG_SMS_USB_DRV=m
++CONFIG_SM_FTL=m
++CONFIG_SND_AC97_CODEC=m
++CONFIG_SND_AC97_POWER_SAVE=y
++CONFIG_SND_AC97_POWER_SAVE_DEFAULT=0
++CONFIG_SND_AD1816A=m
++CONFIG_SND_AD1848=m
++CONFIG_SND_AD1889=m
++CONFIG_SND_ADLIB=m
++CONFIG_SND_ALI5451=m
++CONFIG_SND_ALOOP=m
++CONFIG_SND_ALS100=m
++CONFIG_SND_ALS300=m
++CONFIG_SND_ALS4000=m
++CONFIG_SND_ARM=y
++CONFIG_SND_ARMAACI=m
++CONFIG_SND_ASIHPI=m
++CONFIG_SND_AT73C213=m
++CONFIG_SND_AT73C213_TARGET_BITRATE=48000
++CONFIG_SND_ATIIXP=m
++CONFIG_SND_ATIIXP_MODEM=m
++CONFIG_SND_ATMEL_SOC=m
++CONFIG_SND_AU8810=m
++CONFIG_SND_AU8820=m
++CONFIG_SND_AU8830=m
++CONFIG_SND_AW2=m
++CONFIG_SND_AZT1605=m
++CONFIG_SND_AZT2316=m
++CONFIG_SND_AZT2320=m
++CONFIG_SND_AZT3328=m
++CONFIG_SND_BT87X=m
++# CONFIG_SND_BT87X_OVERCLOCK is not set
++CONFIG_SND_CA0106=m
++CONFIG_SND_CMI8328=m
++CONFIG_SND_CMI8330=m
++CONFIG_SND_CMIPCI=m
++CONFIG_SND_CS4231=m
++CONFIG_SND_CS4236=m
++CONFIG_SND_CS4281=m
++CONFIG_SND_CS46XX=m
++CONFIG_SND_CS46XX_NEW_DSP=y
++CONFIG_SND_CS5530=m
++CONFIG_SND_CS5535AUDIO=m
++CONFIG_SND_CTXFI=m
++CONFIG_SND_DARLA20=m
++CONFIG_SND_DARLA24=m
++CONFIG_SND_DEBUG=y
++# CONFIG_SND_DEBUG_VERBOSE is not set
++CONFIG_SND_DESIGNWARE_I2S=m
++CONFIG_SND_DMA_SGBUF=y
++CONFIG_SND_DRIVERS=y
++CONFIG_SND_DUMMY=m
++CONFIG_SND_DYNAMIC_MINORS=y
++CONFIG_SND_ECHO3G=m
++CONFIG_SND_EMU10K1=m
++CONFIG_SND_EMU10K1X=m
++CONFIG_SND_ENS1370=m
++CONFIG_SND_ENS1371=m
++CONFIG_SND_ES1688=m
++CONFIG_SND_ES18XX=m
++CONFIG_SND_ES1938=m
++CONFIG_SND_ES1968=m
++CONFIG_SND_ES1968_INPUT=y
++CONFIG_SND_ES1968_RADIO=y
++CONFIG_SND_FIREWIRE=y
++CONFIG_SND_FIREWIRE_LIB=m
++CONFIG_SND_FIREWIRE_SPEAKERS=m
++CONFIG_SND_FM801=m
++CONFIG_SND_FM801_TEA575X_BOOL=y
++CONFIG_SND_GINA20=m
++CONFIG_SND_GINA24=m
++CONFIG_SND_GUSCLASSIC=m
++CONFIG_SND_GUSEXTREME=m
++CONFIG_SND_GUSMAX=m
++CONFIG_SND_HDA_CODEC_ANALOG=y
++CONFIG_SND_HDA_CODEC_CA0110=y
++CONFIG_SND_HDA_CODEC_CA0132=y
++CONFIG_SND_HDA_CODEC_CA0132_DSP=y
++CONFIG_SND_HDA_CODEC_CIRRUS=y
++CONFIG_SND_HDA_CODEC_CMEDIA=y
++CONFIG_SND_HDA_CODEC_CONEXANT=y
++CONFIG_SND_HDA_CODEC_HDMI=y
++CONFIG_SND_HDA_CODEC_REALTEK=y
++CONFIG_SND_HDA_CODEC_SI3054=y
++CONFIG_SND_HDA_CODEC_SIGMATEL=y
++CONFIG_SND_HDA_CODEC_VIA=y
++CONFIG_SND_HDA_DSP_LOADER=y
++CONFIG_SND_HDA_GENERIC=y
++CONFIG_SND_HDA_HWDEP=y
++CONFIG_SND_HDA_I915=y
++CONFIG_SND_HDA_INPUT_BEEP=y
++CONFIG_SND_HDA_INPUT_BEEP_MODE=0
++CONFIG_SND_HDA_INPUT_JACK=y
++CONFIG_SND_HDA_INTEL=m
++CONFIG_SND_HDA_PATCH_LOADER=y
++CONFIG_SND_HDA_POWER_SAVE_DEFAULT=0
++CONFIG_SND_HDA_PREALLOC_SIZE=64
++CONFIG_SND_HDA_RECONFIG=y
++CONFIG_SND_HDSP=m
++CONFIG_SND_HDSPM=m
++CONFIG_SND_HRTIMER=m
++CONFIG_SND_HWDEP=m
++CONFIG_SND_ICE1712=m
++CONFIG_SND_ICE1724=m
++CONFIG_SND_IMX_SOC=y
++CONFIG_SND_INDIGO=m
++CONFIG_SND_INDIGODJ=m
++CONFIG_SND_INDIGODJX=m
++CONFIG_SND_INDIGOIO=m
++CONFIG_SND_INDIGOIOX=m
++CONFIG_SND_INTEL8X0=m
++CONFIG_SND_INTEL8X0M=m
++CONFIG_SND_INTERWAVE=m
++CONFIG_SND_INTERWAVE_STB=m
++CONFIG_SND_ISA=y
++CONFIG_SND_ISIGHT=m
++CONFIG_SND_JACK=y
++CONFIG_SND_JAZZ16=m
++CONFIG_SND_KCTL_JACK=y
++CONFIG_SND_KORG1212=m
++CONFIG_SND_LAYLA20=m
++CONFIG_SND_LAYLA24=m
++CONFIG_SND_LOLA=m
++CONFIG_SND_LX6464ES=m
++CONFIG_SND_MAESTRO3=m
++CONFIG_SND_MAESTRO3_INPUT=y
++CONFIG_SND_MAX_CARDS=32
++CONFIG_SND_MFLD_MACHINE=m
++CONFIG_SND_MIA=m
++CONFIG_SND_MIRO=m
++CONFIG_SND_MIXART=m
++# CONFIG_SND_MIXER_OSS is not set
++CONFIG_SND_MONA=m
++CONFIG_SND_MPU401=m
++CONFIG_SND_MPU401_UART=m
++CONFIG_SND_MSND_CLASSIC=m
++CONFIG_SND_MSND_PINNACLE=m
++CONFIG_SND_MTPAV=m
++CONFIG_SND_MTS64=m
++CONFIG_SND_NM256=m
++CONFIG_SND_OMAP_SOC=y
++CONFIG_SND_OMAP_SOC_DMIC=y
++CONFIG_SND_OMAP_SOC_HDMI=y
++CONFIG_SND_OMAP_SOC_MCBSP=y
++CONFIG_SND_OMAP_SOC_MCPDM=y
++CONFIG_SND_OMAP_SOC_OMAP3_PANDORA=m
++CONFIG_SND_OMAP_SOC_OMAP_ABE_TWL6040=y
++CONFIG_SND_OMAP_SOC_OMAP_HDMI=y
++CONFIG_SND_OMAP_SOC_OMAP_TWL4030=y
++CONFIG_SND_OPL3SA2=m
++CONFIG_SND_OPL3_LIB=m
++CONFIG_SND_OPL4_LIB=m
++CONFIG_SND_OPTI92X_AD1848=m
++CONFIG_SND_OPTI92X_CS4231=m
++CONFIG_SND_OPTI93X=m
++CONFIG_SND_OXYGEN=m
++CONFIG_SND_OXYGEN_LIB=m
++CONFIG_SND_PCI=y
++CONFIG_SND_PCMCIA=y
++# CONFIG_SND_PCM_OSS is not set
++CONFIG_SND_PCM_XRUN_DEBUG=y
++CONFIG_SND_PCSP=m
++CONFIG_SND_PCXHR=m
++CONFIG_SND_PDAUDIOCF=m
++CONFIG_SND_PORTMAN2X4=m
++CONFIG_SND_RAWMIDI=m
++CONFIG_SND_RAWMIDI_SEQ=m
++CONFIG_SND_RIPTIDE=m
++CONFIG_SND_RME32=m
++CONFIG_SND_RME96=m
++CONFIG_SND_RME9652=m
++CONFIG_SND_SB16=m
++CONFIG_SND_SB16_CSP=y
++CONFIG_SND_SB16_DSP=m
++CONFIG_SND_SB8=m
++CONFIG_SND_SB8_DSP=m
++CONFIG_SND_SBAWE=m
++CONFIG_SND_SB_COMMON=m
++CONFIG_SND_SC6000=m
++CONFIG_SND_SCS1X=m
++CONFIG_SND_SEQUENCER=m
++# CONFIG_SND_SEQUENCER_OSS is not set
++CONFIG_SND_SEQ_DUMMY=m
++CONFIG_SND_SEQ_HRTIMER_DEFAULT=y
++CONFIG_SND_SERIAL_U16550=m
++CONFIG_SND_SIMPLE_CARD=m
++CONFIG_SND_SIS7019=m
++CONFIG_SND_SOC_88PM860X=m
++CONFIG_SND_SOC_AB8500_CODEC=m
++CONFIG_SND_SOC_AC97_BUS=y
++CONFIG_SND_SOC_AC97_CODEC=m
++CONFIG_SND_SOC_AD1836=m
++CONFIG_SND_SOC_AD193X=m
++CONFIG_SND_SOC_AD1980=m
++CONFIG_SND_SOC_AD73311=m
++CONFIG_SND_SOC_ADAU1373=m
++CONFIG_SND_SOC_ADAV80X=m
++CONFIG_SND_SOC_ADS117X=m
++CONFIG_SND_SOC_AK4104=m
++CONFIG_SND_SOC_AK4535=m
++CONFIG_SND_SOC_AK4641=m
++CONFIG_SND_SOC_AK4642=m
++CONFIG_SND_SOC_AK4671=m
++CONFIG_SND_SOC_AK5386=m
++CONFIG_SND_SOC_ALC5623=m
++CONFIG_SND_SOC_ALC5632=m
++CONFIG_SND_SOC_ALL_CODECS=m
++CONFIG_SND_SOC_ARIZONA=m
++CONFIG_SND_SOC_BT_SCO=m
++CONFIG_SND_SOC_CS4270=m
++CONFIG_SND_SOC_CS4271=m
++CONFIG_SND_SOC_CS42L51=m
++CONFIG_SND_SOC_CS42L52=m
++CONFIG_SND_SOC_CS42L73=m
++CONFIG_SND_SOC_CX20442=m
++CONFIG_SND_SOC_DA7210=m
++CONFIG_SND_SOC_DA7213=m
++CONFIG_SND_SOC_DA732X=m
++CONFIG_SND_SOC_DA9055=m
++CONFIG_SND_SOC_DMAENGINE_PCM=y
++CONFIG_SND_SOC_DMIC=y
++CONFIG_SND_SOC_FSL_SSI=y
++CONFIG_SND_SOC_FSL_UTILS=y
++CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM=y
++CONFIG_SND_SOC_IMX_AUDMUX=y
++CONFIG_SND_SOC_IMX_MC13783=m
++CONFIG_SND_SOC_IMX_PCM_DMA=y
++CONFIG_SND_SOC_IMX_SGTL5000=y
++CONFIG_SND_SOC_IMX_SSI=m
++CONFIG_SND_SOC_IMX_WM8962=m
++CONFIG_SND_SOC_ISABELLE=m
++CONFIG_SND_SOC_JZ4740_CODEC=m
++CONFIG_SND_SOC_L3=m
++CONFIG_SND_SOC_LM4857=m
++CONFIG_SND_SOC_LM49453=m
++CONFIG_SND_SOC_MAX9768=m
++CONFIG_SND_SOC_MAX98088=m
++CONFIG_SND_SOC_MAX98090=m
++CONFIG_SND_SOC_MAX98095=m
++CONFIG_SND_SOC_MAX9850=m
++CONFIG_SND_SOC_MAX9877=m
++CONFIG_SND_SOC_MC13783=m
++CONFIG_SND_SOC_ML26124=m
++CONFIG_SND_SOC_PCM3008=m
++CONFIG_SND_SOC_RT5631=m
++CONFIG_SND_SOC_RT5640=m
++CONFIG_SND_SOC_SI476X=m
++CONFIG_SND_SOC_SN95031=m
++CONFIG_SND_SOC_SPDIF=m
++CONFIG_SND_SOC_SSM2518=m
++CONFIG_SND_SOC_SSM2602=m
++CONFIG_SND_SOC_STA32X=m
++CONFIG_SND_SOC_STA529=m
++CONFIG_SND_SOC_STAC9766=m
++CONFIG_SND_SOC_TAS5086=m
++CONFIG_SND_SOC_TEGRA=m
++CONFIG_SND_SOC_TEGRA20_AC97=m
++CONFIG_SND_SOC_TEGRA20_DAS=m
++CONFIG_SND_SOC_TEGRA20_I2S=m
++CONFIG_SND_SOC_TEGRA20_SPDIF=m
++CONFIG_SND_SOC_TEGRA30_AHUB=m
++CONFIG_SND_SOC_TEGRA30_I2S=m
++CONFIG_SND_SOC_TEGRA_ALC5632=m
++CONFIG_SND_SOC_TEGRA_RT5640=m
++CONFIG_SND_SOC_TEGRA_TRIMSLICE=m
++CONFIG_SND_SOC_TEGRA_WM8753=m
++CONFIG_SND_SOC_TEGRA_WM8903=m
++CONFIG_SND_SOC_TEGRA_WM9712=m
++CONFIG_SND_SOC_TLV320AIC23=m
++CONFIG_SND_SOC_TLV320AIC26=m
++CONFIG_SND_SOC_TLV320AIC32X4=m
++CONFIG_SND_SOC_TLV320AIC3X=m
++CONFIG_SND_SOC_TLV320DAC33=m
++CONFIG_SND_SOC_TPA6130A2=m
++CONFIG_SND_SOC_UDA134X=m
++CONFIG_SND_SOC_UDA1380=m
++CONFIG_SND_SOC_WL1273=m
++CONFIG_SND_SOC_WM0010=m
++CONFIG_SND_SOC_WM1250_EV1=m
++CONFIG_SND_SOC_WM2000=m
++CONFIG_SND_SOC_WM2200=m
++CONFIG_SND_SOC_WM5100=m
++CONFIG_SND_SOC_WM5102=m
++CONFIG_SND_SOC_WM5110=m
++CONFIG_SND_SOC_WM8350=m
++CONFIG_SND_SOC_WM8400=m
++CONFIG_SND_SOC_WM8510=m
++CONFIG_SND_SOC_WM8523=m
++CONFIG_SND_SOC_WM8580=m
++CONFIG_SND_SOC_WM8711=m
++CONFIG_SND_SOC_WM8727=m
++CONFIG_SND_SOC_WM8728=m
++CONFIG_SND_SOC_WM8731=m
++CONFIG_SND_SOC_WM8737=m
++CONFIG_SND_SOC_WM8741=m
++CONFIG_SND_SOC_WM8750=m
++CONFIG_SND_SOC_WM8753=m
++CONFIG_SND_SOC_WM8770=m
++CONFIG_SND_SOC_WM8776=m
++CONFIG_SND_SOC_WM8782=m
++CONFIG_SND_SOC_WM8804=m
++CONFIG_SND_SOC_WM8900=m
++CONFIG_SND_SOC_WM8903=m
++CONFIG_SND_SOC_WM8904=m
++CONFIG_SND_SOC_WM8940=m
++CONFIG_SND_SOC_WM8955=m
++CONFIG_SND_SOC_WM8960=m
++CONFIG_SND_SOC_WM8961=m
++CONFIG_SND_SOC_WM8962=m
++CONFIG_SND_SOC_WM8971=m
++CONFIG_SND_SOC_WM8974=m
++CONFIG_SND_SOC_WM8978=m
++CONFIG_SND_SOC_WM8983=m
++CONFIG_SND_SOC_WM8985=m
++CONFIG_SND_SOC_WM8988=m
++CONFIG_SND_SOC_WM8990=m
++CONFIG_SND_SOC_WM8991=m
++CONFIG_SND_SOC_WM8993=m
++CONFIG_SND_SOC_WM8994=m
++CONFIG_SND_SOC_WM8995=m
++CONFIG_SND_SOC_WM8996=m
++CONFIG_SND_SOC_WM9081=m
++CONFIG_SND_SOC_WM9090=m
++CONFIG_SND_SOC_WM9705=m
++CONFIG_SND_SOC_WM9712=m
++CONFIG_SND_SOC_WM9713=m
++CONFIG_SND_SOC_WM_ADSP=m
++CONFIG_SND_SOC_WM_HUBS=m
++CONFIG_SND_SONICVIBES=m
++CONFIG_SND_SPI=y
++CONFIG_SND_SSCAPE=m
++CONFIG_SND_SST_PLATFORM=m
++CONFIG_SND_SUPPORT_OLD_API=y
++CONFIG_SND_TEA575X=m
++CONFIG_SND_TRIDENT=m
++CONFIG_SND_USB=y
++CONFIG_SND_USB_6FIRE=m
++CONFIG_SND_USB_AUDIO=m
++CONFIG_SND_USB_CAIAQ=m
++CONFIG_SND_USB_CAIAQ_INPUT=y
++CONFIG_SND_USB_HIFACE=m
++CONFIG_SND_USB_UA101=m
++CONFIG_SND_USB_US122L=m
++CONFIG_SND_USB_USX2Y=m
++# CONFIG_SND_VERBOSE_PRINTK is not set
++CONFIG_SND_VERBOSE_PROCFS=y
++CONFIG_SND_VIA82XX=m
++CONFIG_SND_VIA82XX_MODEM=m
++CONFIG_SND_VIRMIDI=m
++CONFIG_SND_VIRTUOSO=m
++CONFIG_SND_VMASTER=y
++CONFIG_SND_VX222=m
++CONFIG_SND_VXPOCKET=m
++CONFIG_SND_VX_LIB=m
++CONFIG_SND_WAVEFRONT=m
++CONFIG_SND_WSS_LIB=m
++CONFIG_SND_YMFPCI=m
++# CONFIG_SOC_AM33XX is not set
++# CONFIG_SOC_AM43XX is not set
++CONFIG_SOC_BUS=y
++CONFIG_SOC_CAMERA=m
++CONFIG_SOC_CAMERA_IMX074=m
++CONFIG_SOC_CAMERA_MT9M001=m
++CONFIG_SOC_CAMERA_MT9M111=m
++CONFIG_SOC_CAMERA_MT9T031=m
++CONFIG_SOC_CAMERA_MT9T112=m
++CONFIG_SOC_CAMERA_MT9V022=m
++CONFIG_SOC_CAMERA_OV2640=m
++CONFIG_SOC_CAMERA_OV5642=m
++CONFIG_SOC_CAMERA_OV6650=m
++CONFIG_SOC_CAMERA_OV772X=m
++CONFIG_SOC_CAMERA_OV9640=m
++CONFIG_SOC_CAMERA_OV9740=m
++CONFIG_SOC_CAMERA_PLATFORM=m
++CONFIG_SOC_CAMERA_RJ54N1=m
++CONFIG_SOC_CAMERA_SCALE_CROP=m
++CONFIG_SOC_CAMERA_TW9910=m
++CONFIG_SOC_HAS_OMAP2_SDRC=y
++# CONFIG_SOC_IMX53 is not set
++CONFIG_SOC_IMX6Q=y
++CONFIG_SOC_IMX6SL=y
++CONFIG_SOC_OMAP3430=y
++# CONFIG_SOC_OMAP5 is not set
++CONFIG_SOC_TI81XX=y
++CONFIG_SOC_VF610=y
++CONFIG_SOFT_WATCHDOG=m
++CONFIG_SOLARIS_X86_PARTITION=y
++CONFIG_SOLO6X10=m
++CONFIG_SONYPI=m
++CONFIG_SONYPI_COMPAT=y
++CONFIG_SONY_LAPTOP=m
++# CONFIG_SOUND_OSS_CORE is not set
++# CONFIG_SOUND_PRIME is not set
++CONFIG_SP5100_TCO=m
++CONFIG_SPARSEMEM=y
++CONFIG_SPARSEMEM_ALLOC_MEM_MAP_TOGETHER=y
++CONFIG_SPARSEMEM_EXTREME=y
++CONFIG_SPARSEMEM_STATIC=y
++CONFIG_SPARSEMEM_VMEMMAP=y
++CONFIG_SPARSEMEM_VMEMMAP_ENABLE=y
++CONFIG_SPARSE_IRQ=y
++# CONFIG_SPARSE_RCU_POINTER is not set
++CONFIG_SPEAKUP=m
++CONFIG_SPEAKUP_SYNTH_ACNTPC=m
++CONFIG_SPEAKUP_SYNTH_ACNTSA=m
++CONFIG_SPEAKUP_SYNTH_APOLLO=m
++CONFIG_SPEAKUP_SYNTH_AUDPTR=m
++CONFIG_SPEAKUP_SYNTH_BNS=m
++CONFIG_SPEAKUP_SYNTH_DECEXT=m
++CONFIG_SPEAKUP_SYNTH_DECPC=m
++CONFIG_SPEAKUP_SYNTH_DECTLK=m
++CONFIG_SPEAKUP_SYNTH_DTLK=m
++CONFIG_SPEAKUP_SYNTH_DUMMY=m
++CONFIG_SPEAKUP_SYNTH_KEYPC=m
++CONFIG_SPEAKUP_SYNTH_LTLK=m
++CONFIG_SPEAKUP_SYNTH_SOFT=m
++CONFIG_SPEAKUP_SYNTH_SPKOUT=m
++CONFIG_SPEAKUP_SYNTH_TXPRT=m
++CONFIG_SPI=y
++CONFIG_SPI_ALTERA=m
++CONFIG_SPI_BITBANG=m
++CONFIG_SPI_BUTTERFLY=m
++# CONFIG_SPI_DEBUG is not set
++CONFIG_SPI_DESIGNWARE=m
++CONFIG_SPI_DW_MID_DMA=y
++CONFIG_SPI_DW_MMIO=m
++CONFIG_SPI_DW_PCI=m
++CONFIG_SPI_FSL_LIB=y
++CONFIG_SPI_FSL_SPI=y
++CONFIG_SPI_GPIO=m
++CONFIG_SPI_IMX=m
++CONFIG_SPI_LM70_LLP=m
++CONFIG_SPI_MASTER=y
++CONFIG_SPI_OC_TINY=m
++CONFIG_SPI_OMAP24XX=y
++CONFIG_SPI_PL022=m
++CONFIG_SPI_PXA2XX=m
++CONFIG_SPI_PXA2XX_DMA=y
++CONFIG_SPI_SC18IS602=m
++CONFIG_SPI_SPIDEV=m
++CONFIG_SPI_TEGRA114=m
++CONFIG_SPI_TEGRA20_SFLASH=m
++CONFIG_SPI_TEGRA20_SLINK=m
++CONFIG_SPI_TLE62X0=m
++CONFIG_SPI_TOPCLIFF_PCH=m
++CONFIG_SPI_XCOMM=m
++# CONFIG_SPI_XILINX is not set
++CONFIG_SPLIT_PTLOCK_CPUS=4
++CONFIG_SQUASHFS=m
++# CONFIG_SQUASHFS_4K_DEVBLK_SIZE is not set
++# CONFIG_SQUASHFS_EMBEDDED is not set
++CONFIG_SQUASHFS_FRAGMENT_CACHE_SIZE=3
++CONFIG_SQUASHFS_LZO=y
++CONFIG_SQUASHFS_XATTR=y
++CONFIG_SQUASHFS_XZ=y
++CONFIG_SQUASHFS_ZLIB=y
++CONFIG_SRAM=y
++CONFIG_SSB=m
++CONFIG_SSB_B43_PCI_BRIDGE=y
++CONFIG_SSB_BLOCKIO=y
++# CONFIG_SSB_DEBUG is not set
++CONFIG_SSB_DRIVER_GPIO=y
++CONFIG_SSB_DRIVER_PCICORE=y
++CONFIG_SSB_DRIVER_PCICORE_POSSIBLE=y
++CONFIG_SSB_PCIHOST=y
++CONFIG_SSB_PCIHOST_POSSIBLE=y
++# CONFIG_SSB_PCMCIAHOST is not set
++CONFIG_SSB_PCMCIAHOST_POSSIBLE=y
++CONFIG_SSB_POSSIBLE=y
++CONFIG_SSB_SDIOHOST=y
++CONFIG_SSB_SDIOHOST_POSSIBLE=y
++# CONFIG_SSB_SILENT is not set
++CONFIG_SSB_SPROM=y
++CONFIG_SSFDC=m
++CONFIG_STACKTRACE=y
++CONFIG_STACKTRACE_SUPPORT=y
++CONFIG_STAGING=y
++CONFIG_STAGING_MEDIA=y
++CONFIG_STE10XP=y
++CONFIG_STE_MODEM_RPROC=m
++# CONFIG_STMMAC_DA is not set
++# CONFIG_STMMAC_DEBUG_FS is not set
++CONFIG_STMMAC_ETH=m
++# CONFIG_STMMAC_PCI is not set
++CONFIG_STMMAC_PLATFORM=y
++CONFIG_STMPE_I2C=y
++CONFIG_STMPE_SPI=y
++CONFIG_STMP_DEVICE=y
++CONFIG_STOP_MACHINE=y
++CONFIG_STP=m
++CONFIG_STRICT_DEVMEM=y
++# CONFIG_STRIP_ASM_SYMS is not set
++CONFIG_SUNDANCE=m
++# CONFIG_SUNDANCE_MMIO is not set
++CONFIG_SUNGEM=m
++CONFIG_SUNGEM_PHY=m
++CONFIG_SUNRPC=m
++CONFIG_SUNRPC_BACKCHANNEL=y
++CONFIG_SUNRPC_DEBUG=y
++CONFIG_SUNRPC_GSS=m
++CONFIG_SUNRPC_SWAP=y
++CONFIG_SUNRPC_XPRT_RDMA=m
++CONFIG_SUN_PARTITION=y
++CONFIG_SUSPEND=y
++CONFIG_SUSPEND_FREEZER=y
++CONFIG_SWAP=y
++CONFIG_SWIOTLB=y
++CONFIG_SWIOTLB_XEN=y
++CONFIG_SWP_EMULATE=y
++CONFIG_SYNCLINK=m
++CONFIG_SYNCLINKMP=m
++CONFIG_SYNCLINK_CS=m
++CONFIG_SYNCLINK_GT=m
++CONFIG_SYN_COOKIES=y
++CONFIG_SYSCTL=y
++CONFIG_SYSCTL_EXCEPTION_TRACE=y
++CONFIG_SYSCTL_SYSCALL=y
++CONFIG_SYSFS=y
++# CONFIG_SYSFS_DEPRECATED is not set
++CONFIG_SYSV68_PARTITION=y
++CONFIG_SYSVIPC=y
++CONFIG_SYSVIPC_COMPAT=y
++CONFIG_SYSVIPC_SYSCTL=y
++CONFIG_SYSV_FS=m
++CONFIG_SYS_HYPERVISOR=y
++CONFIG_SYS_SUPPORTS_APM_EMULATION=y
++CONFIG_SYS_SUPPORTS_HUGETLBFS=y
++CONFIG_TABLET_USB_ACECAD=m
++CONFIG_TABLET_USB_AIPTEK=m
++CONFIG_TABLET_USB_GTCO=m
++CONFIG_TABLET_USB_HANWANG=m
++CONFIG_TABLET_USB_KBTAB=m
++CONFIG_TABLET_USB_WACOM=m
++CONFIG_TARGET_CORE=m
++CONFIG_TASKSTATS=y
++CONFIG_TASK_DELAY_ACCT=y
++CONFIG_TASK_IO_ACCOUNTING=y
++CONFIG_TASK_XACCT=y
++CONFIG_TC1100_WMI=m
++CONFIG_TCG_ATMEL=m
++CONFIG_TCG_INFINEON=m
++CONFIG_TCG_NSC=m
++CONFIG_TCG_ST33_I2C=m
++CONFIG_TCG_TIS=m
++CONFIG_TCG_TIS_I2C_INFINEON=m
++CONFIG_TCG_TPM=y
++CONFIG_TCIC=m
++CONFIG_TCM_FC=m
++CONFIG_TCM_FILEIO=m
++CONFIG_TCM_IBLOCK=m
++CONFIG_TCM_PSCSI=m
++CONFIG_TCM_QLA2XXX=m
++CONFIG_TCP_CONG_ADVANCED=y
++CONFIG_TCP_CONG_BIC=m
++CONFIG_TCP_CONG_CUBIC=y
++CONFIG_TCP_CONG_HSTCP=m
++CONFIG_TCP_CONG_HTCP=m
++CONFIG_TCP_CONG_HYBLA=m
++CONFIG_TCP_CONG_ILLINOIS=m
++CONFIG_TCP_CONG_LP=m
++CONFIG_TCP_CONG_SCALABLE=m
++CONFIG_TCP_CONG_VEGAS=m
++CONFIG_TCP_CONG_VENO=m
++CONFIG_TCP_CONG_WESTWOOD=m
++CONFIG_TCP_CONG_YEAH=m
++CONFIG_TCP_MD5SIG=y
++CONFIG_TEGRA20_APB_DMA=y
++CONFIG_TEGRA20_MC=y
++CONFIG_TEGRA30_MC=y
++CONFIG_TEGRA_AHB=y
++CONFIG_TEGRA_EMC_SCALING_ENABLE=y
++CONFIG_TEGRA_HOST1X_FIREWALL=y
++CONFIG_TEGRA_IOMMU_GART=y
++CONFIG_TEGRA_IOMMU_SMMU=y
++CONFIG_TEGRA_PCI=y
++CONFIG_TEHUTI=m
++CONFIG_TEKRAM_DONGLE=m
++CONFIG_TELCLOCK=m
++CONFIG_TEST_KSTRTOX=m
++# CONFIG_TEST_LIST_SORT is not set
++CONFIG_TEST_POWER=m
++CONFIG_TEST_STRING_HELPERS=m
++CONFIG_TEXTSEARCH=y
++CONFIG_TEXTSEARCH_BM=m
++CONFIG_TEXTSEARCH_FSM=m
++CONFIG_TEXTSEARCH_KMP=m
++CONFIG_THERMAL=y
++# CONFIG_THERMAL_DEFAULT_GOV_FAIR_SHARE is not set
++CONFIG_THERMAL_DEFAULT_GOV_STEP_WISE=y
++# CONFIG_THERMAL_DEFAULT_GOV_USER_SPACE is not set
++CONFIG_THERMAL_EMULATION=y
++CONFIG_THERMAL_GOV_FAIR_SHARE=y
++CONFIG_THERMAL_GOV_STEP_WISE=y
++CONFIG_THERMAL_GOV_USER_SPACE=y
++CONFIG_THERMAL_HWMON=y
++CONFIG_THINKPAD_ACPI=m
++CONFIG_THINKPAD_ACPI_ALSA_SUPPORT=y
++# CONFIG_THINKPAD_ACPI_DEBUG is not set
++CONFIG_THINKPAD_ACPI_DEBUGFACILITIES=y
++CONFIG_THINKPAD_ACPI_HOTKEY_POLL=y
++# CONFIG_THINKPAD_ACPI_UNSAFE_LEDS is not set
++CONFIG_THINKPAD_ACPI_VIDEO=y
++CONFIG_THRUSTMASTER_FF=y
++# CONFIG_THUMB2_KERNEL is not set
++CONFIG_TICK_ONESHOT=y
++CONFIG_TIFM_7XX1=m
++CONFIG_TIFM_CORE=m
++CONFIG_TIGON3=m
++CONFIG_TIMB_DMA=m
++CONFIG_TIMERFD=y
++CONFIG_TIMER_STATS=y
++CONFIG_TIPC=m
++CONFIG_TIPC_MEDIA_IB=y
++CONFIG_TIPC_PORTS=8191
++CONFIG_TI_ADC081C=m
++CONFIG_TI_AM335X_ADC=m
++CONFIG_TI_DAC7512=m
++CONFIG_TI_DAVINCI_CPDMA=m
++CONFIG_TI_DAVINCI_EMAC=m
++CONFIG_TI_DAVINCI_MDIO=m
++CONFIG_TI_EDMA=y
++CONFIG_TI_EMIF=m
++CONFIG_TI_PRIV_EDMA=y
++CONFIG_TI_SOC_THERMAL=m
++CONFIG_TI_ST=m
++CONFIG_TLAN=m
++CONFIG_TMD_HERMES=m
++CONFIG_TMPFS=y
++CONFIG_TMPFS_POSIX_ACL=y
++CONFIG_TMPFS_XATTR=y
++CONFIG_TOIM3232_DONGLE=m
++CONFIG_TOPSTAR_LAPTOP=m
++# CONFIG_TOSHIBA is not set
++CONFIG_TOSHIBA_BT_RFKILL=m
++CONFIG_TOSHIBA_FIR=m
++CONFIG_TOUCHSCREEN_88PM860X=m
++CONFIG_TOUCHSCREEN_AD7877=m
++CONFIG_TOUCHSCREEN_AD7879=m
++CONFIG_TOUCHSCREEN_AD7879_I2C=m
++CONFIG_TOUCHSCREEN_AD7879_SPI=m
++CONFIG_TOUCHSCREEN_ADS7846=m
++CONFIG_TOUCHSCREEN_ATMEL_MXT=m
++CONFIG_TOUCHSCREEN_AUO_PIXCIR=m
++CONFIG_TOUCHSCREEN_BU21013=m
++CONFIG_TOUCHSCREEN_CLEARPAD_TM1217=m
++CONFIG_TOUCHSCREEN_CY8CTMG110=m
++CONFIG_TOUCHSCREEN_CYTTSP4_CORE=m
++CONFIG_TOUCHSCREEN_CYTTSP4_I2C=m
++CONFIG_TOUCHSCREEN_CYTTSP4_SPI=m
++CONFIG_TOUCHSCREEN_CYTTSP_CORE=m
++CONFIG_TOUCHSCREEN_CYTTSP_I2C=m
++CONFIG_TOUCHSCREEN_CYTTSP_SPI=m
++CONFIG_TOUCHSCREEN_DA9034=m
++CONFIG_TOUCHSCREEN_DA9052=m
++CONFIG_TOUCHSCREEN_DYNAPRO=m
++CONFIG_TOUCHSCREEN_EDT_FT5X06=m
++CONFIG_TOUCHSCREEN_EETI=m
++CONFIG_TOUCHSCREEN_EGALAX=m
++CONFIG_TOUCHSCREEN_ELO=m
++CONFIG_TOUCHSCREEN_FUJITSU=m
++CONFIG_TOUCHSCREEN_GUNZE=m
++CONFIG_TOUCHSCREEN_HAMPSHIRE=m
++CONFIG_TOUCHSCREEN_HTCPEN=m
++CONFIG_TOUCHSCREEN_ILI210X=m
++CONFIG_TOUCHSCREEN_INEXIO=m
++CONFIG_TOUCHSCREEN_INTEL_MID=m
++CONFIG_TOUCHSCREEN_MAX11801=m
++CONFIG_TOUCHSCREEN_MC13783=m
++CONFIG_TOUCHSCREEN_MCS5000=m
++CONFIG_TOUCHSCREEN_MK712=m
++CONFIG_TOUCHSCREEN_MMS114=m
++CONFIG_TOUCHSCREEN_MTOUCH=m
++CONFIG_TOUCHSCREEN_PCAP=m
++CONFIG_TOUCHSCREEN_PENMOUNT=m
++CONFIG_TOUCHSCREEN_PIXCIR=m
++CONFIG_TOUCHSCREEN_ST1232=m
++CONFIG_TOUCHSCREEN_STMPE=m
++CONFIG_TOUCHSCREEN_SYNAPTICS_I2C_RMI4=m
++CONFIG_TOUCHSCREEN_TI_AM335X_TSC=m
++CONFIG_TOUCHSCREEN_TOUCHIT213=m
++CONFIG_TOUCHSCREEN_TOUCHRIGHT=m
++CONFIG_TOUCHSCREEN_TOUCHWIN=m
++CONFIG_TOUCHSCREEN_TPS6507X=m
++CONFIG_TOUCHSCREEN_TSC2005=m
++CONFIG_TOUCHSCREEN_TSC2007=m
++CONFIG_TOUCHSCREEN_TSC_SERIO=m
++CONFIG_TOUCHSCREEN_UCB1400=m
++CONFIG_TOUCHSCREEN_USB_3M=y
++CONFIG_TOUCHSCREEN_USB_COMPOSITE=m
++CONFIG_TOUCHSCREEN_USB_DMC_TSC10=y
++CONFIG_TOUCHSCREEN_USB_E2I=y
++CONFIG_TOUCHSCREEN_USB_EASYTOUCH=y
++CONFIG_TOUCHSCREEN_USB_EGALAX=y
++CONFIG_TOUCHSCREEN_USB_ELO=y
++CONFIG_TOUCHSCREEN_USB_ETT_TC45USB=y
++CONFIG_TOUCHSCREEN_USB_ETURBO=y
++CONFIG_TOUCHSCREEN_USB_GENERAL_TOUCH=y
++CONFIG_TOUCHSCREEN_USB_GOTOP=y
++CONFIG_TOUCHSCREEN_USB_GUNZE=y
++CONFIG_TOUCHSCREEN_USB_IDEALTEK=y
++CONFIG_TOUCHSCREEN_USB_IRTOUCH=y
++CONFIG_TOUCHSCREEN_USB_ITM=y
++CONFIG_TOUCHSCREEN_USB_JASTEC=y
++CONFIG_TOUCHSCREEN_USB_NEXIO=y
++CONFIG_TOUCHSCREEN_USB_PANJIT=y
++CONFIG_TOUCHSCREEN_USB_ZYTRONIC=y
++CONFIG_TOUCHSCREEN_W90X900=m
++CONFIG_TOUCHSCREEN_WACOM_I2C=m
++CONFIG_TOUCHSCREEN_WACOM_W8001=m
++CONFIG_TOUCHSCREEN_WM831X=m
++CONFIG_TOUCHSCREEN_WM9705=y
++CONFIG_TOUCHSCREEN_WM9712=y
++CONFIG_TOUCHSCREEN_WM9713=y
++CONFIG_TOUCHSCREEN_WM97XX=m
++CONFIG_TPS6105X=m
++CONFIG_TPS65010=m
++CONFIG_TPS6507X=m
++CONFIG_TRACEPOINTS=y
++CONFIG_TRACER_MAX_TRACE=y
++CONFIG_TRACER_SNAPSHOT=y
++# CONFIG_TRACER_SNAPSHOT_PER_CPU_SWAP is not set
++CONFIG_TRACE_CLOCK=y
++CONFIG_TRACE_IRQFLAGS_SUPPORT=y
++CONFIG_TRACE_ROUTER=m
++CONFIG_TRACE_SINK=m
++CONFIG_TRACING=y
++CONFIG_TRACING_SUPPORT=y
++CONFIG_TRANSPARENT_HUGEPAGE=y
++# CONFIG_TRANSPARENT_HUGEPAGE_ALWAYS is not set
++CONFIG_TRANSPARENT_HUGEPAGE_MADVISE=y
++CONFIG_TRANZPORT=m
++CONFIG_TREE_RCU=y
++# CONFIG_TREE_RCU_TRACE is not set
++CONFIG_TRUSTED_KEYS=y
++CONFIG_TSL2583=m
++CONFIG_TSL2x7x=m
++CONFIG_TTPCI_EEPROM=m
++CONFIG_TTY=y
++CONFIG_TTY_PRINTK=y
++CONFIG_TULIP=m
++# CONFIG_TULIP_MMIO is not set
++# CONFIG_TULIP_MWI is not set
++# CONFIG_TULIP_NAPI is not set
++CONFIG_TUN=y
++CONFIG_TWL4030_MADC=m
++CONFIG_TWL4030_POWER=y
++CONFIG_TWL4030_USB=m
++CONFIG_TWL4030_WATCHDOG=m
++CONFIG_TWL6030_USB=m
++CONFIG_TWL6040_CORE=y
++CONFIG_TYPHOON=m
++# CONFIG_UACCESS_WITH_MEMCPY is not set
++CONFIG_UBIFS_FS=m
++# CONFIG_UBIFS_FS_ADVANCED_COMPR is not set
++CONFIG_UBIFS_FS_LZO=y
++CONFIG_UBIFS_FS_ZLIB=y
++CONFIG_UCB1400_CORE=m
++CONFIG_UCS2_STRING=y
++CONFIG_UDF_FS=m
++CONFIG_UDF_NLS=y
++CONFIG_UEVENT_HELPER_PATH=""
++# CONFIG_UFS_DEBUG is not set
++CONFIG_UFS_FS=m
++# CONFIG_UFS_FS_WRITE is not set
++CONFIG_UHID=m
++CONFIG_UID16=y
++CONFIG_UIO=m
++CONFIG_UIO_AEC=m
++CONFIG_UIO_CIF=m
++CONFIG_UIO_DMEM_GENIRQ=m
++CONFIG_UIO_NETX=m
++CONFIG_UIO_PCI_GENERIC=m
++CONFIG_UIO_PDRV=m
++CONFIG_UIO_PDRV_GENIRQ=m
++CONFIG_UIO_SERCOS3=m
++CONFIG_ULI526X=m
++CONFIG_ULTRA=m
++CONFIG_ULTRIX_PARTITION=y
++CONFIG_UNCOMPRESS_INCLUDE="debug/uncompress.h"
++CONFIG_UNIX=y
++CONFIG_UNIX98_PTYS=y
++CONFIG_UNIXWARE_DISKLABEL=y
++CONFIG_UNIX_DIAG=m
++CONFIG_UNUSED_SYMBOLS=y
++CONFIG_UPROBES=y
++CONFIG_UPROBE_EVENT=y
++CONFIG_USB=y
++CONFIG_USBIP_CORE=m
++# CONFIG_USBIP_DEBUG is not set
++CONFIG_USBIP_HOST=m
++CONFIG_USBIP_VHCI_HCD=m
++CONFIG_USBPCWATCHDOG=m
++CONFIG_USB_ACM=m
++CONFIG_USB_ADUTUX=m
++CONFIG_USB_ALI_M5632=y
++CONFIG_USB_AMD5536UDC=m
++CONFIG_USB_AN2720=y
++CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
++CONFIG_USB_APPLEDISPLAY=m
++CONFIG_USB_ARCH_HAS_EHCI=y
++CONFIG_USB_ARCH_HAS_HCD=y
++CONFIG_USB_ARMLINUX=y
++CONFIG_USB_ATM=m
++CONFIG_USB_AUDIO=m
++CONFIG_USB_BELKIN=y
++CONFIG_USB_BTMTK=m
++CONFIG_USB_C67X00_HCD=m
++CONFIG_USB_CATC=m
++CONFIG_USB_CDC_COMPOSITE=m
++CONFIG_USB_CDC_PHONET=m
++# CONFIG_USB_CHIPIDEA_DEBUG is not set
++CONFIG_USB_CHIPIDEA_HOST=y
++CONFIG_USB_CHIPIDEA_UDC=y
++CONFIG_USB_COMMON=y
++CONFIG_USB_CONFIGFS=m
++CONFIG_USB_CONFIGFS_ACM=y
++CONFIG_USB_CONFIGFS_ECM=y
++CONFIG_USB_CONFIGFS_ECM_SUBSET=y
++CONFIG_USB_CONFIGFS_EEM=y
++CONFIG_USB_CONFIGFS_NCM=y
++CONFIG_USB_CONFIGFS_OBEX=y
++CONFIG_USB_CONFIGFS_PHONET=y
++CONFIG_USB_CONFIGFS_RNDIS=y
++CONFIG_USB_CONFIGFS_SERIAL=y
++CONFIG_USB_CXACRU=m
++CONFIG_USB_CYPRESS_CY7C63=m
++CONFIG_USB_CYTHERM=m
++# CONFIG_USB_DEBUG is not set
++CONFIG_USB_DEFAULT_PERSIST=y
++CONFIG_USB_DSBR=m
++# CONFIG_USB_DUMMY_HCD is not set
++CONFIG_USB_DWC2=m
++# CONFIG_USB_DWC2_DEBUG is not set
++# CONFIG_USB_DWC2_TRACK_MISSED_SOFS is not set
++CONFIG_USB_DWC3=m
++# CONFIG_USB_DWC3_DEBUG is not set
++CONFIG_USB_DWC3_DUAL_ROLE=y
++# CONFIG_USB_DWC3_GADGET is not set
++# CONFIG_USB_DWC3_HOST is not set
++CONFIG_USB_DYNAMIC_MINORS=y
++CONFIG_USB_EG20T=m
++CONFIG_USB_EHCI_HCD=y
++CONFIG_USB_EHCI_HCD_OMAP=y
++# CONFIG_USB_EHCI_MXC is not set
++CONFIG_USB_EHCI_PCI=y
++CONFIG_USB_EHCI_ROOT_HUB_TT=y
++CONFIG_USB_EHCI_TEGRA=y
++CONFIG_USB_EHCI_TT_NEWSCHED=y
++CONFIG_USB_EMI26=m
++CONFIG_USB_EMI62=m
++CONFIG_USB_ENESTORAGE=m
++CONFIG_USB_EPSON2888=y
++CONFIG_USB_ETH=m
++CONFIG_USB_ETH_EEM=y
++CONFIG_USB_ETH_RNDIS=y
++CONFIG_USB_EZUSB_FX2=m
++CONFIG_USB_FOTG210_UDC=m
++# CONFIG_USB_FSL_USB2 is not set
++CONFIG_USB_FTDI_ELAN=m
++CONFIG_USB_FUNCTIONFS=m
++CONFIG_USB_FUNCTIONFS_ETH=y
++CONFIG_USB_FUNCTIONFS_GENERIC=y
++CONFIG_USB_FUNCTIONFS_RNDIS=y
++CONFIG_USB_FUSB300=m
++CONFIG_USB_FUSBH200_HCD=m
++CONFIG_USB_F_ACM=m
++CONFIG_USB_F_ECM=m
++CONFIG_USB_F_EEM=m
++CONFIG_USB_F_NCM=m
++CONFIG_USB_F_OBEX=m
++CONFIG_USB_F_PHONET=m
++CONFIG_USB_F_RNDIS=m
++CONFIG_USB_F_SERIAL=m
++CONFIG_USB_F_SS_LB=m
++CONFIG_USB_F_SUBSET=m
++CONFIG_USB_GADGETFS=m
++# CONFIG_USB_GADGET_DEBUG is not set
++# CONFIG_USB_GADGET_DEBUG_FILES is not set
++# CONFIG_USB_GADGET_DEBUG_FS is not set
++CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS=2
++CONFIG_USB_GADGET_TARGET=m
++CONFIG_USB_GADGET_VBUS_DRAW=2
++CONFIG_USB_GL860=m
++CONFIG_USB_GOKU=m
++CONFIG_USB_GPIO_VBUS=m
++CONFIG_USB_GSPCA=m
++CONFIG_USB_GSPCA_BENQ=m
++CONFIG_USB_GSPCA_CONEX=m
++CONFIG_USB_GSPCA_CPIA1=m
++CONFIG_USB_GSPCA_ETOMS=m
++CONFIG_USB_GSPCA_FINEPIX=m
++CONFIG_USB_GSPCA_JEILINJ=m
++CONFIG_USB_GSPCA_JL2005BCD=m
++CONFIG_USB_GSPCA_KINECT=m
++CONFIG_USB_GSPCA_KONICA=m
++CONFIG_USB_GSPCA_MARS=m
++CONFIG_USB_GSPCA_MR97310A=m
++CONFIG_USB_GSPCA_NW80X=m
++CONFIG_USB_GSPCA_OV519=m
++CONFIG_USB_GSPCA_OV534=m
++CONFIG_USB_GSPCA_OV534_9=m
++CONFIG_USB_GSPCA_PAC207=m
++CONFIG_USB_GSPCA_PAC7302=m
++CONFIG_USB_GSPCA_PAC7311=m
++CONFIG_USB_GSPCA_SE401=m
++CONFIG_USB_GSPCA_SN9C2028=m
++CONFIG_USB_GSPCA_SN9C20X=m
++CONFIG_USB_GSPCA_SONIXB=m
++CONFIG_USB_GSPCA_SONIXJ=m
++CONFIG_USB_GSPCA_SPCA1528=m
++CONFIG_USB_GSPCA_SPCA500=m
++CONFIG_USB_GSPCA_SPCA501=m
++CONFIG_USB_GSPCA_SPCA505=m
++CONFIG_USB_GSPCA_SPCA506=m
++CONFIG_USB_GSPCA_SPCA508=m
++CONFIG_USB_GSPCA_SPCA561=m
++CONFIG_USB_GSPCA_SQ905=m
++CONFIG_USB_GSPCA_SQ905C=m
++CONFIG_USB_GSPCA_SQ930X=m
++CONFIG_USB_GSPCA_STK014=m
++CONFIG_USB_GSPCA_STV0680=m
++CONFIG_USB_GSPCA_SUNPLUS=m
++CONFIG_USB_GSPCA_T613=m
++CONFIG_USB_GSPCA_TOPRO=m
++CONFIG_USB_GSPCA_TV8532=m
++CONFIG_USB_GSPCA_VC032X=m
++CONFIG_USB_GSPCA_VICAM=m
++CONFIG_USB_GSPCA_XIRLINK_CIT=m
++CONFIG_USB_GSPCA_ZC3XX=m
++CONFIG_USB_G_ACM_MS=m
++CONFIG_USB_G_DBGP=m
++# CONFIG_USB_G_DBGP_PRINTK is not set
++CONFIG_USB_G_DBGP_SERIAL=y
++CONFIG_USB_G_HID=m
++CONFIG_USB_G_MULTI_CDC=y
++CONFIG_USB_G_MULTI_RNDIS=y
++CONFIG_USB_G_NCM=m
++CONFIG_USB_G_NOKIA=m
++CONFIG_USB_G_PRINTER=m
++CONFIG_USB_G_SERIAL=m
++CONFIG_USB_G_WEBCAM=m
++CONFIG_USB_HID=m
++CONFIG_USB_HIDDEV=y
++CONFIG_USB_HSIC_USB3503=m
++CONFIG_USB_HSO=m
++CONFIG_USB_HWA_HCD=m
++CONFIG_USB_IDMOUSE=m
++# CONFIG_USB_IMX21_HCD is not set
++CONFIG_USB_INVENTRA_DMA=y
++CONFIG_USB_IOWARRIOR=m
++CONFIG_USB_IPHETH=m
++CONFIG_USB_IRDA=m
++CONFIG_USB_ISIGHTFW=m
++CONFIG_USB_ISP116X_HCD=m
++CONFIG_USB_ISP1301=m
++CONFIG_USB_ISP1362_HCD=m
++CONFIG_USB_ISP1760_HCD=m
++CONFIG_USB_KAWETH=m
++CONFIG_USB_KBD=m
++CONFIG_USB_KC2190=y
++CONFIG_USB_KEENE=m
++CONFIG_USB_LCD=m
++CONFIG_USB_LD=m
++CONFIG_USB_LED=m
++CONFIG_USB_LEGOTOWER=m
++CONFIG_USB_LIBCOMPOSITE=m
++CONFIG_USB_M5602=m
++# CONFIG_USB_M66592 is not set
++CONFIG_USB_MA901=m
++CONFIG_USB_MASS_STORAGE=m
++CONFIG_USB_MDC800=m
++CONFIG_USB_MICROTEK=m
++CONFIG_USB_MIDI_GADGET=m
++CONFIG_USB_MON=m
++CONFIG_USB_MOUSE=m
++CONFIG_USB_MR800=m
++# CONFIG_USB_MUSB_AM35X is not set
++# CONFIG_USB_MUSB_DSPS is not set
++CONFIG_USB_MUSB_DUAL_ROLE=y
++# CONFIG_USB_MUSB_GADGET is not set
++# CONFIG_USB_MUSB_HOST is not set
++CONFIG_USB_MUSB_OMAP2PLUS=m
++CONFIG_USB_MUSB_UX500=m
++CONFIG_USB_MV_U3D=m
++CONFIG_USB_MV_UDC=m
++CONFIG_USB_MXS_PHY=y
++CONFIG_USB_NET2272=m
++CONFIG_USB_NET2272_DMA=y
++CONFIG_USB_NET2280=m
++CONFIG_USB_NET_AX88179_178A=m
++CONFIG_USB_NET_AX8817X=m
++CONFIG_USB_NET_CDCETHER=m
++CONFIG_USB_NET_CDC_EEM=m
++CONFIG_USB_NET_CDC_MBIM=m
++CONFIG_USB_NET_CDC_NCM=m
++CONFIG_USB_NET_CDC_SUBSET=m
++CONFIG_USB_NET_CX82310_ETH=m
++CONFIG_USB_NET_DM9601=m
++CONFIG_USB_NET_GL620A=m
++CONFIG_USB_NET_INT51X1=m
++CONFIG_USB_NET_KALMIA=m
++CONFIG_USB_NET_MCS7830=m
++CONFIG_USB_NET_NET1080=m
++CONFIG_USB_NET_PLUSB=m
++CONFIG_USB_NET_QMI_WWAN=m
++CONFIG_USB_NET_RNDIS_HOST=m
++CONFIG_USB_NET_RNDIS_WLAN=m
++CONFIG_USB_NET_SMSC75XX=m
++CONFIG_USB_NET_SMSC95XX=m
++CONFIG_USB_NET_ZAURUS=m
++# CONFIG_USB_OHCI_BIG_ENDIAN_DESC is not set
++# CONFIG_USB_OHCI_BIG_ENDIAN_MMIO is not set
++CONFIG_USB_OHCI_HCD=y
++CONFIG_USB_OHCI_HCD_OMAP3=y
++CONFIG_USB_OHCI_HCD_PCI=m
++CONFIG_USB_OHCI_LITTLE_ENDIAN=y
++# CONFIG_USB_OTG is not set
++# CONFIG_USB_OTG_BLACKLIST_HUB is not set
++# CONFIG_USB_OTG_WHITELIST is not set
++CONFIG_USB_OXU210HP_HCD=m
++CONFIG_USB_PEGASUS=m
++CONFIG_USB_PHY=y
++CONFIG_USB_PRINTER=m
++CONFIG_USB_PWC=m
++# CONFIG_USB_PWC_DEBUG is not set
++CONFIG_USB_PWC_INPUT_EVDEV=y
++CONFIG_USB_PXA27X=m
++CONFIG_USB_R8A66597=m
++CONFIG_USB_R8A66597_HCD=m
++CONFIG_USB_RCAR_PHY=m
++CONFIG_USB_RENESAS_USBHS=m
++CONFIG_USB_RENESAS_USBHS_HCD=m
++CONFIG_USB_RENESAS_USBHS_UDC=m
++CONFIG_USB_RIO500=m
++CONFIG_USB_RTL8150=m
++CONFIG_USB_RTL8152=m
++CONFIG_USB_S2255=m
++CONFIG_USB_SERIAL=m
++CONFIG_USB_SERIAL_AIRCABLE=m
++CONFIG_USB_SERIAL_ARK3116=m
++CONFIG_USB_SERIAL_BELKIN=m
++CONFIG_USB_SERIAL_CH341=m
++CONFIG_USB_SERIAL_CP210X=m
++CONFIG_USB_SERIAL_CYBERJACK=m
++CONFIG_USB_SERIAL_CYPRESS_M8=m
++CONFIG_USB_SERIAL_DEBUG=m
++CONFIG_USB_SERIAL_DIGI_ACCELEPORT=m
++CONFIG_USB_SERIAL_EDGEPORT=m
++CONFIG_USB_SERIAL_EDGEPORT_TI=m
++CONFIG_USB_SERIAL_EMPEG=m
++CONFIG_USB_SERIAL_F81232=m
++CONFIG_USB_SERIAL_FLASHLOADER=m
++CONFIG_USB_SERIAL_FTDI_SIO=m
++CONFIG_USB_SERIAL_FUNSOFT=m
++CONFIG_USB_SERIAL_GARMIN=m
++CONFIG_USB_SERIAL_GENERIC=y
++CONFIG_USB_SERIAL_HP4X=m
++CONFIG_USB_SERIAL_IPAQ=m
++CONFIG_USB_SERIAL_IPW=m
++CONFIG_USB_SERIAL_IR=m
++CONFIG_USB_SERIAL_IUU=m
++CONFIG_USB_SERIAL_KEYSPAN=m
++CONFIG_USB_SERIAL_KEYSPAN_MPR=y
++CONFIG_USB_SERIAL_KEYSPAN_PDA=m
++CONFIG_USB_SERIAL_KEYSPAN_USA18X=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19QI=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19QW=y
++CONFIG_USB_SERIAL_KEYSPAN_USA19W=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28X=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28XA=y
++CONFIG_USB_SERIAL_KEYSPAN_USA28XB=y
++CONFIG_USB_SERIAL_KEYSPAN_USA49W=y
++CONFIG_USB_SERIAL_KEYSPAN_USA49WLC=y
++CONFIG_USB_SERIAL_KLSI=m
++CONFIG_USB_SERIAL_KOBIL_SCT=m
++CONFIG_USB_SERIAL_MCT_U232=m
++CONFIG_USB_SERIAL_METRO=m
++CONFIG_USB_SERIAL_MOS7715_PARPORT=y
++CONFIG_USB_SERIAL_MOS7720=m
++CONFIG_USB_SERIAL_MOS7840=m
++CONFIG_USB_SERIAL_MOTOROLA=m
++CONFIG_USB_SERIAL_NAVMAN=m
++CONFIG_USB_SERIAL_OMNINET=m
++CONFIG_USB_SERIAL_OPTICON=m
++CONFIG_USB_SERIAL_OPTION=m
++CONFIG_USB_SERIAL_OTI6858=m
++CONFIG_USB_SERIAL_PL2303=m
++CONFIG_USB_SERIAL_QCAUX=m
++CONFIG_USB_SERIAL_QT2=m
++CONFIG_USB_SERIAL_QUALCOMM=m
++CONFIG_USB_SERIAL_QUATECH2=m
++CONFIG_USB_SERIAL_SAFE=m
++# CONFIG_USB_SERIAL_SAFE_PADDED is not set
++CONFIG_USB_SERIAL_SIEMENS_MPI=m
++CONFIG_USB_SERIAL_SIERRAWIRELESS=m
++CONFIG_USB_SERIAL_SPCP8X5=m
++CONFIG_USB_SERIAL_SSU100=m
++CONFIG_USB_SERIAL_SUUNTO=m
++CONFIG_USB_SERIAL_SYMBOL=m
++CONFIG_USB_SERIAL_TI=m
++CONFIG_USB_SERIAL_VISOR=m
++CONFIG_USB_SERIAL_VIVOPAY_SERIAL=m
++CONFIG_USB_SERIAL_WHITEHEAT=m
++CONFIG_USB_SERIAL_WISHBONE=m
++CONFIG_USB_SERIAL_WWAN=m
++CONFIG_USB_SERIAL_XIRCOM=m
++CONFIG_USB_SERIAL_XSENS_MT=m
++CONFIG_USB_SERIAL_ZIO=m
++CONFIG_USB_SERIAL_ZTE=m
++CONFIG_USB_SEVSEG=m
++CONFIG_USB_SI470X=m
++CONFIG_USB_SIERRA_NET=m
++CONFIG_USB_SISUSBVGA=m
++# CONFIG_USB_SISUSBVGA_CON is not set
++CONFIG_USB_SL811_CS=m
++CONFIG_USB_SL811_HCD=m
++CONFIG_USB_SL811_HCD_ISO=y
++# CONFIG_USB_SN9C102 is not set
++CONFIG_USB_SPEEDTOUCH=m
++CONFIG_USB_STKWEBCAM=m
++CONFIG_USB_STORAGE=m
++CONFIG_USB_STORAGE_ALAUDA=m
++CONFIG_USB_STORAGE_CYPRESS_ATACB=m
++CONFIG_USB_STORAGE_DATAFAB=m
++# CONFIG_USB_STORAGE_DEBUG is not set
++CONFIG_USB_STORAGE_ENE_UB6250=m
++CONFIG_USB_STORAGE_FREECOM=m
++CONFIG_USB_STORAGE_ISD200=m
++CONFIG_USB_STORAGE_JUMPSHOT=m
++CONFIG_USB_STORAGE_KARMA=m
++CONFIG_USB_STORAGE_ONETOUCH=m
++CONFIG_USB_STORAGE_REALTEK=m
++CONFIG_USB_STORAGE_SDDR09=m
++CONFIG_USB_STORAGE_SDDR55=m
++CONFIG_USB_STORAGE_USBAT=m
++CONFIG_USB_STV06XX=m
++CONFIG_USB_SUPPORT=y
++CONFIG_USB_SWITCH_FSA9480=m
++CONFIG_USB_TEST=m
++CONFIG_USB_TMC=m
++CONFIG_USB_TRANCEVIBRATOR=m
++CONFIG_USB_U132_HCD=m
++CONFIG_USB_UEAGLEATM=m
++CONFIG_USB_UHCI_HCD=y
++CONFIG_USB_ULPI=y
++CONFIG_USB_ULPI_VIEWPORT=y
++CONFIG_USB_USBNET=m
++CONFIG_USB_USS720=m
++# CONFIG_USB_UX500_DMA is not set
++CONFIG_USB_U_ETHER=m
++CONFIG_USB_U_RNDIS=m
++CONFIG_USB_U_SERIAL=m
++CONFIG_USB_VIDEO_CLASS=m
++CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV=y
++CONFIG_USB_VL600=m
++CONFIG_USB_WDM=m
++CONFIG_USB_WHCI_HCD=m
++CONFIG_USB_WPAN_HCD=m
++CONFIG_USB_WUSB=m
++CONFIG_USB_WUSB_CBAF=m
++# CONFIG_USB_WUSB_CBAF_DEBUG is not set
++CONFIG_USB_XHCI_HCD=y
++# CONFIG_USB_XHCI_HCD_DEBUGGING is not set
++CONFIG_USB_XHCI_PLATFORM=m
++CONFIG_USB_XUSBATM=m
++CONFIG_USB_YUREX=m
++CONFIG_USB_ZD1201=m
++CONFIG_USB_ZERO=m
++CONFIG_USB_ZR364XX=m
++CONFIG_USER_RETURN_NOTIFIER=y
++CONFIG_USER_STACKTRACE_SUPPORT=y
++CONFIG_USE_GENERIC_SMP_HELPERS=y
++CONFIG_USE_OF=y
++CONFIG_USE_PERCPU_NUMA_NODE_ID=y
++CONFIG_UTS_NS=y
++CONFIG_UWB=m
++CONFIG_UWB_HWA=m
++CONFIG_UWB_I1480U=m
++CONFIG_UWB_WHCI=m
++CONFIG_V4L2_MEM2MEM_DEV=m
++CONFIG_V4L_MEM2MEM_DRIVERS=y
++CONFIG_V4L_PLATFORM_DRIVERS=y
++CONFIG_V4L_RADIO_ISA_DRIVERS=y
++CONFIG_V4L_TEST_DRIVERS=y
++CONFIG_VCNL4000=m
++CONFIG_VECTORS_BASE=0xffff0000
++CONFIG_VERSION_SIGNATURE=""
++CONFIG_VETH=m
++CONFIG_VEXPRESS_CONFIG=y
++CONFIG_VFAT_FS=y
++CONFIG_VFIO=m
++CONFIG_VFIO_PCI=m
++CONFIG_VFIO_PCI_VGA=y
++CONFIG_VFP=y
++CONFIG_VFPv3=y
++CONFIG_VF_PIT_TIMER=y
++# CONFIG_VGACON_SOFT_SCROLLBACK is not set
++CONFIG_VGA_ARB=y
++CONFIG_VGA_ARB_MAX_GPUS=16
++CONFIG_VGA_CONSOLE=y
++CONFIG_VGA_SWITCHEROO=y
++CONFIG_VHOST=m
++CONFIG_VHOST_NET=m
++CONFIG_VHOST_RING=m
++CONFIG_VHOST_SCSI=m
++CONFIG_VIA_FIR=m
++CONFIG_VIA_RHINE=m
++CONFIG_VIA_RHINE_MMIO=y
++CONFIG_VIA_VELOCITY=m
++CONFIG_VIA_WDT=m
++CONFIG_VIDEOBUF2_CORE=m
++CONFIG_VIDEOBUF2_DMA_CONTIG=m
++CONFIG_VIDEOBUF2_DMA_SG=m
++CONFIG_VIDEOBUF2_MEMOPS=m
++CONFIG_VIDEOBUF2_VMALLOC=m
++CONFIG_VIDEOBUF_DMA_CONTIG=m
++CONFIG_VIDEOBUF_DMA_SG=m
++CONFIG_VIDEOBUF_DVB=m
++CONFIG_VIDEOBUF_GEN=m
++CONFIG_VIDEOBUF_VMALLOC=m
++CONFIG_VIDEOMODE_HELPERS=y
++CONFIG_VIDEO_ADV7170=m
++CONFIG_VIDEO_ADV7175=m
++CONFIG_VIDEO_ADV7180=m
++# CONFIG_VIDEO_ADV_DEBUG is not set
++CONFIG_VIDEO_AU0828=m
++CONFIG_VIDEO_AU0828_V4L2=y
++CONFIG_VIDEO_BT819=m
++CONFIG_VIDEO_BT848=m
++CONFIG_VIDEO_BT856=m
++CONFIG_VIDEO_BT866=m
++CONFIG_VIDEO_BTCX=m
++CONFIG_VIDEO_BWQCAM=m
++CONFIG_VIDEO_CAFE_CCIC=m
++# CONFIG_VIDEO_CODA is not set
++CONFIG_VIDEO_CPIA2=m
++CONFIG_VIDEO_CQCAM=m
++CONFIG_VIDEO_CS5345=m
++CONFIG_VIDEO_CS53L32A=m
++CONFIG_VIDEO_CX18=m
++CONFIG_VIDEO_CX18_ALSA=m
++CONFIG_VIDEO_CX231XX=m
++CONFIG_VIDEO_CX231XX_ALSA=m
++CONFIG_VIDEO_CX231XX_DVB=m
++CONFIG_VIDEO_CX231XX_RC=y
++CONFIG_VIDEO_CX2341X=m
++CONFIG_VIDEO_CX23885=m
++CONFIG_VIDEO_CX25821=m
++CONFIG_VIDEO_CX25821_ALSA=m
++CONFIG_VIDEO_CX25840=m
++CONFIG_VIDEO_CX88=m
++CONFIG_VIDEO_CX88_ALSA=m
++CONFIG_VIDEO_CX88_BLACKBIRD=m
++CONFIG_VIDEO_CX88_DVB=m
++CONFIG_VIDEO_CX88_MPEG=m
++CONFIG_VIDEO_CX88_VP3054=m
++CONFIG_VIDEO_DEV=m
++CONFIG_VIDEO_DM6446_CCDC=m
++CONFIG_VIDEO_DT3155=m
++CONFIG_VIDEO_EM28XX=m
++CONFIG_VIDEO_EM28XX_ALSA=m
++CONFIG_VIDEO_EM28XX_DVB=m
++CONFIG_VIDEO_EM28XX_RC=m
++CONFIG_VIDEO_FB_IVTV=m
++# CONFIG_VIDEO_FIXED_MINOR_RANGES is not set
++CONFIG_VIDEO_GO7007=m
++CONFIG_VIDEO_GO7007_LOADER=m
++CONFIG_VIDEO_GO7007_USB=m
++CONFIG_VIDEO_GO7007_USB_S2250_BOARD=m
++CONFIG_VIDEO_HDPVR=m
++CONFIG_VIDEO_HEXIUM_GEMINI=m
++CONFIG_VIDEO_HEXIUM_ORION=m
++CONFIG_VIDEO_IR_I2C=m
++CONFIG_VIDEO_IVTV=m
++CONFIG_VIDEO_IVTV_ALSA=m
++CONFIG_VIDEO_KS0127=m
++CONFIG_VIDEO_M52790=m
++CONFIG_VIDEO_MEM2MEM_DEINTERLACE=m
++CONFIG_VIDEO_MEM2MEM_TESTDEV=m
++CONFIG_VIDEO_MEYE=m
++CONFIG_VIDEO_MSP3400=m
++CONFIG_VIDEO_MT9V011=m
++# CONFIG_VIDEO_MX3 is not set
++CONFIG_VIDEO_MXB=m
++CONFIG_VIDEO_OMAP2_VOUT=m
++CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
++CONFIG_VIDEO_OUTPUT_CONTROL=m
++CONFIG_VIDEO_OV7640=m
++CONFIG_VIDEO_OV7670=m
++CONFIG_VIDEO_PMS=m
++CONFIG_VIDEO_PVRUSB2=m
++# CONFIG_VIDEO_PVRUSB2_DEBUGIFC is not set
++CONFIG_VIDEO_PVRUSB2_DVB=y
++CONFIG_VIDEO_PVRUSB2_SYSFS=y
++CONFIG_VIDEO_SAA6588=m
++CONFIG_VIDEO_SAA7110=m
++CONFIG_VIDEO_SAA711X=m
++CONFIG_VIDEO_SAA7127=m
++CONFIG_VIDEO_SAA7134=m
++CONFIG_VIDEO_SAA7134_ALSA=m
++CONFIG_VIDEO_SAA7134_DVB=m
++CONFIG_VIDEO_SAA7134_RC=y
++CONFIG_VIDEO_SAA7146=m
++CONFIG_VIDEO_SAA7146_VV=m
++CONFIG_VIDEO_SAA7164=m
++CONFIG_VIDEO_SAA717X=m
++CONFIG_VIDEO_SAA7185=m
++CONFIG_VIDEO_SH_MOBILE_CEU=m
++CONFIG_VIDEO_SH_MOBILE_CSI2=m
++CONFIG_VIDEO_SH_VEU=m
++CONFIG_VIDEO_SONY_BTF_MPX=m
++CONFIG_VIDEO_STK1160=m
++CONFIG_VIDEO_STK1160_AC97=y
++CONFIG_VIDEO_TDA7432=m
++CONFIG_VIDEO_TDA9840=m
++CONFIG_VIDEO_TEA6415C=m
++CONFIG_VIDEO_TEA6420=m
++CONFIG_VIDEO_TIMBERDALE=m
++CONFIG_VIDEO_TLG2300=m
++CONFIG_VIDEO_TM6000=m
++CONFIG_VIDEO_TM6000_ALSA=m
++CONFIG_VIDEO_TM6000_DVB=m
++CONFIG_VIDEO_TUNER=m
++CONFIG_VIDEO_TVAUDIO=m
++CONFIG_VIDEO_TVEEPROM=m
++CONFIG_VIDEO_TVP5150=m
++CONFIG_VIDEO_TW2804=m
++CONFIG_VIDEO_TW9903=m
++CONFIG_VIDEO_TW9906=m
++CONFIG_VIDEO_UDA1342=m
++CONFIG_VIDEO_UPD64031A=m
++CONFIG_VIDEO_UPD64083=m
++CONFIG_VIDEO_USBTV=m
++CONFIG_VIDEO_USBVISION=m
++CONFIG_VIDEO_V4L2=m
++CONFIG_VIDEO_V4L2_INT_DEVICE=m
++CONFIG_VIDEO_VIA_CAMERA=m
++CONFIG_VIDEO_VIVI=m
++CONFIG_VIDEO_VP27SMPX=m
++CONFIG_VIDEO_VPX3220=m
++CONFIG_VIDEO_W9966=m
++CONFIG_VIDEO_WM8739=m
++CONFIG_VIDEO_WM8775=m
++CONFIG_VIDEO_ZORAN=m
++CONFIG_VIDEO_ZORAN_AVS6EYES=m
++CONFIG_VIDEO_ZORAN_BUZ=m
++CONFIG_VIDEO_ZORAN_DC10=m
++CONFIG_VIDEO_ZORAN_DC30=m
++CONFIG_VIDEO_ZORAN_LML33=m
++CONFIG_VIDEO_ZORAN_LML33R10=m
++CONFIG_VIDEO_ZORAN_ZR36060=m
++CONFIG_VIPERBOARD_ADC=m
++CONFIG_VIRTIO=y
++CONFIG_VIRTIO_BALLOON=m
++CONFIG_VIRTIO_BLK=y
++CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES=y
++CONFIG_VIRTIO_NET=y
++CONFIG_VIRTIO_PCI=y
++CONFIG_VIRTUALIZATION=y
++CONFIG_VIRT_CPU_ACCOUNTING=y
++CONFIG_VIRT_CPU_ACCOUNTING_GEN=y
++CONFIG_VIRT_DRIVERS=y
++CONFIG_VIRT_TO_BUS=y
++CONFIG_VITESSE_PHY=y
++CONFIG_VLAN_8021Q=m
++CONFIG_VLAN_8021Q_GVRP=y
++CONFIG_VLAN_8021Q_MVRP=y
++CONFIG_VLSI_FIR=m
++CONFIG_VM86=y
++CONFIG_VME_BUS=m
++CONFIG_VME_CA91CX42=m
++CONFIG_VME_PIO2=m
++CONFIG_VME_TSI148=m
++CONFIG_VME_USER=m
++CONFIG_VMIVME_7805=m
++# CONFIG_VMSPLIT_1G is not set
++# CONFIG_VMSPLIT_2G is not set
++CONFIG_VMSPLIT_3G=y
++CONFIG_VMWARE_BALLOON=m
++CONFIG_VMWARE_PVSCSI=m
++CONFIG_VMWARE_VMCI=m
++CONFIG_VMWARE_VMCI_VSOCKETS=m
++CONFIG_VMXNET3=m
++CONFIG_VM_EVENT_COUNTERS=y
++CONFIG_VORTEX=m
++CONFIG_VSOCKETS=m
++CONFIG_VT=y
++CONFIG_VT6655=m
++CONFIG_VT6656=m
++CONFIG_VT_CONSOLE=y
++CONFIG_VT_CONSOLE_SLEEP=y
++CONFIG_VT_HW_CONSOLE_BINDING=y
++CONFIG_VXFS_FS=m
++CONFIG_VXGE=m
++# CONFIG_VXGE_DEBUG_TRACE_ALL is not set
++CONFIG_VXLAN=m
++CONFIG_W1=m
++CONFIG_W1_CON=y
++CONFIG_W1_MASTER_DS1WM=m
++CONFIG_W1_MASTER_DS2482=m
++CONFIG_W1_MASTER_DS2490=m
++CONFIG_W1_MASTER_GPIO=m
++CONFIG_W1_MASTER_MATROX=m
++# CONFIG_W1_MASTER_MXC is not set
++CONFIG_W1_SLAVE_BQ27000=m
++CONFIG_W1_SLAVE_DS2408=m
++CONFIG_W1_SLAVE_DS2408_READBACK=y
++CONFIG_W1_SLAVE_DS2413=m
++CONFIG_W1_SLAVE_DS2423=m
++CONFIG_W1_SLAVE_DS2431=m
++CONFIG_W1_SLAVE_DS2433=m
++# CONFIG_W1_SLAVE_DS2433_CRC is not set
++CONFIG_W1_SLAVE_DS2760=m
++CONFIG_W1_SLAVE_DS2780=m
++CONFIG_W1_SLAVE_DS2781=m
++CONFIG_W1_SLAVE_DS28E04=m
++CONFIG_W1_SLAVE_SMEM=m
++CONFIG_W1_SLAVE_THERM=m
++CONFIG_W35UND=m
++CONFIG_W83627HF_WDT=m
++CONFIG_W83697HF_WDT=m
++CONFIG_W83697UG_WDT=m
++CONFIG_W83877F_WDT=m
++CONFIG_W83977F_WDT=m
++CONFIG_WAFER_WDT=m
++CONFIG_WAN=y
++CONFIG_WANXL=m
++CONFIG_WATCHDOG=y
++CONFIG_WATCHDOG_CORE=y
++# CONFIG_WATCHDOG_NOWAYOUT is not set
++CONFIG_WD80x3=m
++CONFIG_WDT=m
++CONFIG_WDTPCI=m
++CONFIG_WEXT_CORE=y
++CONFIG_WEXT_PRIV=y
++CONFIG_WEXT_PROC=y
++CONFIG_WEXT_SPY=y
++CONFIG_WIL6210_ISR_COR=y
++CONFIG_WIL6210_TRACING=y
++CONFIG_WILINK_PLATFORM_DATA=y
++CONFIG_WIMAX=m
++CONFIG_WIMAX_DEBUG_LEVEL=8
++CONFIG_WIMAX_GDM72XX=m
++CONFIG_WIMAX_GDM72XX_K_MODE=y
++CONFIG_WIMAX_GDM72XX_QOS=y
++# CONFIG_WIMAX_GDM72XX_SDIO is not set
++CONFIG_WIMAX_GDM72XX_USB=y
++CONFIG_WIMAX_GDM72XX_USB_PM=y
++CONFIG_WIMAX_GDM72XX_WIMAX2=y
++CONFIG_WIMAX_I2400M=m
++CONFIG_WIMAX_I2400M_DEBUG_LEVEL=8
++CONFIG_WIMAX_I2400M_USB=m
++CONFIG_WINBOND_840=m
++CONFIG_WINBOND_FIR=m
++CONFIG_WIRELESS=y
++CONFIG_WIRELESS_EXT=y
++CONFIG_WIZNET_BUS_ANY=y
++# CONFIG_WIZNET_BUS_DIRECT is not set
++# CONFIG_WIZNET_BUS_INDIRECT is not set
++CONFIG_WIZNET_W5100=m
++CONFIG_WIZNET_W5300=m
++CONFIG_WL1251=m
++CONFIG_WL1251_SDIO=m
++CONFIG_WL1251_SPI=m
++CONFIG_WL12XX=m
++CONFIG_WL18XX=m
++CONFIG_WLAGS49_H2=m
++CONFIG_WLAGS49_H25=m
++CONFIG_WLAN=y
++CONFIG_WLCORE=m
++CONFIG_WLCORE_SDIO=m
++CONFIG_WLCORE_SPI=m
++CONFIG_WL_TI=y
++CONFIG_WM831X_BACKUP=m
++CONFIG_WM831X_POWER=m
++CONFIG_WM831X_WATCHDOG=m
++CONFIG_WM8350_POWER=m
++CONFIG_WM8350_WATCHDOG=m
++CONFIG_WQ_POWER_EFFICIENT_DEFAULT=y
++CONFIG_X25=m
++CONFIG_X25_ASY=m
++CONFIG_X509_CERTIFICATE_PARSER=y
++CONFIG_X86=y
++CONFIG_X86_32=y
++CONFIG_X86_32_IRIS=m
++# CONFIG_X86_32_NON_STANDARD is not set
++CONFIG_X86_32_SMP=y
++CONFIG_X86_64=y
++CONFIG_X86_64_ACPI_NUMA=y
++CONFIG_X86_64_SMP=y
++CONFIG_X86_ACPI_CPUFREQ=y
++CONFIG_X86_ACPI_CPUFREQ_CPB=y
++CONFIG_X86_AMD_FREQ_SENSITIVITY=m
++# CONFIG_X86_ANCIENT_MCE is not set
++CONFIG_X86_APM_BOOT=y
++# CONFIG_X86_BIGSMP is not set
++CONFIG_X86_BOOTPARAM_MEMORY_CORRUPTION_CHECK=y
++CONFIG_X86_CHECK_BIOS_CORRUPTION=y
++CONFIG_X86_CMOV=y
++CONFIG_X86_CMPXCHG64=y
++CONFIG_X86_CPUFREQ_NFORCE2=y
++CONFIG_X86_CPUID=m
++CONFIG_X86_DEBUGCTLMSR=y
++# CONFIG_X86_DEBUG_STATIC_CPU_HAS is not set
++# CONFIG_X86_DECODER_SELFTEST is not set
++CONFIG_X86_DEV_DMA_OPS=y
++CONFIG_X86_EXTENDED_PLATFORM=y
++# CONFIG_X86_E_POWERSAVER is not set
++CONFIG_X86_GENERIC=y
++# CONFIG_X86_GOLDFISH is not set
++CONFIG_X86_GX_SUSPMOD=m
++CONFIG_X86_HT=y
++CONFIG_X86_INTEL_LPSS=y
++CONFIG_X86_INTEL_MID=y
++CONFIG_X86_INTEL_PSTATE=y
++CONFIG_X86_INTEL_USERCOPY=y
++CONFIG_X86_INTERNODE_CACHE_SHIFT=6
++CONFIG_X86_IO_APIC=y
++CONFIG_X86_L1_CACHE_SHIFT=6
++CONFIG_X86_LOCAL_APIC=y
++CONFIG_X86_LONGHAUL=m
++CONFIG_X86_LONGRUN=m
++CONFIG_X86_MCE=y
++CONFIG_X86_MCE_AMD=y
++CONFIG_X86_MCE_INJECT=m
++CONFIG_X86_MCE_INTEL=y
++CONFIG_X86_MCE_THRESHOLD=y
++CONFIG_X86_MDFLD=y
++CONFIG_X86_MPPARSE=y
++CONFIG_X86_MSR=m
++CONFIG_X86_NEED_RELOCS=y
++CONFIG_X86_NUMACHIP=y
++CONFIG_X86_P4_CLOCKMOD=m
++CONFIG_X86_PAE=y
++CONFIG_X86_PAT=y
++CONFIG_X86_PCC_CPUFREQ=y
++CONFIG_X86_PKG_TEMP_THERMAL=m
++CONFIG_X86_PLATFORM_DEVICES=y
++CONFIG_X86_PM_TIMER=y
++CONFIG_X86_POWERNOW_K6=m
++CONFIG_X86_POWERNOW_K7=m
++CONFIG_X86_POWERNOW_K7_ACPI=y
++CONFIG_X86_POWERNOW_K8=y
++CONFIG_X86_PPRO_FENCE=y
++# CONFIG_X86_PTDUMP is not set
++# CONFIG_X86_RDC321X is not set
++CONFIG_X86_REBOOTFIXUPS=y
++CONFIG_X86_REROUTE_FOR_BROKEN_BOOT_IRQS=y
++CONFIG_X86_RESERVE_LOW=64
++CONFIG_X86_SMAP=y
++CONFIG_X86_SPEEDSTEP_CENTRINO=y
++CONFIG_X86_SPEEDSTEP_CENTRINO_TABLE=y
++CONFIG_X86_SPEEDSTEP_ICH=y
++CONFIG_X86_SPEEDSTEP_RELAXED_CAP_CHECK=y
++CONFIG_X86_SPEEDSTEP_SMI=y
++CONFIG_X86_SUPPORTS_MEMORY_FAILURE=y
++CONFIG_X86_THERMAL_VECTOR=y
++CONFIG_X86_TSC=y
++CONFIG_X86_USE_PPRO_CHECKSUM=y
++# CONFIG_X86_UV is not set
++# CONFIG_X86_VERBOSE_BOOTUP is not set
++# CONFIG_X86_VSMP is not set
++CONFIG_X86_WANT_INTEL_MID=y
++CONFIG_X86_X2APIC=y
++CONFIG_X86_X32=y
++CONFIG_XEN=y
++CONFIG_XENFS=m
++CONFIG_XEN_ACPI_PROCESSOR=y
++CONFIG_XEN_BACKEND=y
++CONFIG_XEN_BALLOON=y
++CONFIG_XEN_BALLOON_MEMORY_HOTPLUG=y
++CONFIG_XEN_BLKDEV_BACKEND=m
++CONFIG_XEN_BLKDEV_FRONTEND=y
++CONFIG_XEN_COMPAT_XENFS=y
++# CONFIG_XEN_DEBUG_FS is not set
++CONFIG_XEN_DEV_EVTCHN=m
++CONFIG_XEN_DOM0=y
++CONFIG_XEN_FBDEV_FRONTEND=m
++CONFIG_XEN_GNTDEV=m
++CONFIG_XEN_GRANT_DEV_ALLOC=m
++CONFIG_XEN_HAVE_PVMMU=y
++CONFIG_XEN_MCE_LOG=y
++CONFIG_XEN_NETDEV_BACKEND=m
++CONFIG_XEN_NETDEV_FRONTEND=y
++CONFIG_XEN_PCIDEV_BACKEND=m
++CONFIG_XEN_PCIDEV_FRONTEND=m
++CONFIG_XEN_PRIVCMD=m
++CONFIG_XEN_PRIVILEGED_GUEST=y
++CONFIG_XEN_PVHVM=y
++CONFIG_XEN_SAVE_RESTORE=y
++CONFIG_XEN_SCRUB_PAGES=y
++CONFIG_XEN_SELFBALLOONING=y
++CONFIG_XEN_SYS_HYPERVISOR=y
++CONFIG_XEN_TMEM=m
++CONFIG_XEN_WDT=m
++CONFIG_XEN_XENBUS_FRONTEND=y
++CONFIG_XFRM=y
++CONFIG_XFRM_ALGO=m
++CONFIG_XFRM_IPCOMP=m
++# CONFIG_XFRM_MIGRATE is not set
++# CONFIG_XFRM_STATISTICS is not set
++# CONFIG_XFRM_SUB_POLICY is not set
++CONFIG_XFRM_USER=m
++# CONFIG_XFS_DEBUG is not set
++CONFIG_XFS_FS=m
++CONFIG_XFS_POSIX_ACL=y
++CONFIG_XFS_QUOTA=y
++CONFIG_XFS_RT=y
++# CONFIG_XFS_WARN is not set
++CONFIG_XO15_EBOOK=m
++CONFIG_XOR_BLOCKS=m
++CONFIG_XPS=y
++CONFIG_XZ_DEC=y
++CONFIG_XZ_DEC_ARM=y
++CONFIG_XZ_DEC_ARMTHUMB=y
++CONFIG_XZ_DEC_BCJ=y
++CONFIG_XZ_DEC_IA64=y
++CONFIG_XZ_DEC_POWERPC=y
++CONFIG_XZ_DEC_SPARC=y
++CONFIG_XZ_DEC_TEST=m
++CONFIG_XZ_DEC_X86=y
++CONFIG_YAM=m
++CONFIG_YELLOWFIN=m
++CONFIG_YENTA=m
++CONFIG_YENTA_ENE_TUNE=y
++CONFIG_YENTA_O2=y
++CONFIG_YENTA_RICOH=y
++CONFIG_YENTA_TI=y
++CONFIG_YENTA_TOSHIBA=y
++CONFIG_ZBOOT_ROM_BSS=0x0
++CONFIG_ZBOOT_ROM_TEXT=0x0
++CONFIG_ZBUD=y
++CONFIG_ZCACHE=y
++# CONFIG_ZCACHE_DEBUG is not set
++CONFIG_ZD1211RW=m
++# CONFIG_ZD1211RW_DEBUG is not set
++CONFIG_ZEROPLUS_FF=y
++CONFIG_ZISOFS=y
++CONFIG_ZLIB_DEFLATE=m
++CONFIG_ZLIB_INFLATE=y
++CONFIG_ZONE_DMA=y
++CONFIG_ZRAM=m
++# CONFIG_ZRAM_DEBUG is not set
++CONFIG_ZSMALLOC=y
++CONFIG_ZSWAP=y
+diff --git a/debian.master/config/enforce b/debian.master/config/enforce
+new file mode 100644
+index 0000000..41f2391
+--- /dev/null
++++ b/debian.master/config/enforce
+@@ -0,0 +1,131 @@
++#
++# SECURITY items
++#
++# Ensure this option is enabled.
++value CONFIG_COMPAT_BRK n
++value CONFIG_DEVKMEM n
++value CONFIG_LSM_MMAP_MIN_ADDR 0
++value CONFIG_SECURITY y
++!exists CONFIG_SECURITY_FILE_CAPABILITIES | value CONFIG_SECURITY_FILE_CAPABILITIES y
++value CONFIG_SECURITY_SELINUX y
++value CONFIG_SECURITY_SMACK y
++value CONFIG_SECURITY_YAMA y
++value CONFIG_SYN_COOKIES y
++value CONFIG_DEFAULT_SECURITY_APPARMOR y
++value CONFIG_DEBUG_INFO y
++# For architectures which support this option ensure it is enabled.
++!exists CONFIG_XEN_ACPI_PROCESSOR | value CONFIG_XEN_ACPI_PROCESSOR y
++!exists CONFIG_SECCOMP | value CONFIG_SECCOMP y
++!exists CONFIG_HAVE_ARCH_SECCOMP_FILTER | value CONFIG_SECCOMP_FILTER y
++!exists CONFIG_CC_STACKPROTECTOR | value CONFIG_CC_STACKPROTECTOR y
++!exists CONFIG_DEBUG_RODATA | value CONFIG_DEBUG_RODATA y
++!exists CONFIG_DEBUG_SET_MODULE_RONX | value CONFIG_DEBUG_SET_MODULE_RONX y
++!exists CONFIG_STRICT_DEVMEM | value CONFIG_STRICT_DEVMEM y
++# For architectures which support this option ensure it is disabled.
++!exists CONFIG_COMPAT_VDSO | value CONFIG_COMPAT_VDSO n
++!exists CONFIG_ACPI_CUSTOM_METHOD | value CONFIG_ACPI_CUSTOM_METHOD n
++# Default to 32768 on ARM, 65536 for everything else.
++(arch armel armhf &/ value CONFIG_DEFAULT_MMAP_MIN_ADDR 32768) | \
++ value CONFIG_DEFAULT_MMAP_MIN_ADDR 65536
++
++# upstart requires DEVTMPFS be enabled and mounted by default.
++value CONFIG_DEVTMPFS y
++value CONFIG_DEVTMPFS_MOUNT y
++
++# some /dev nodes require POSIX ACLs, like /dev/dsp
++value CONFIG_TMPFS_POSIX_ACL y
++
++# Ramdisk size should be a minimum of 64M
++value CONFIG_BLK_DEV_RAM_SIZE 65536
++
++# LVM requires dm_mod built in to activate correctly (LP: #560717)
++value CONFIG_BLK_DEV_DM y
++
++# sysfs: ensure all DEPRECATED items are off
++!exists CONFIG_SYSFS_DEPRECATED_V2 | value CONFIG_SYSFS_DEPRECATED_V2 n
++!exists CONFIG_SYSFS_DEPRECATED | value CONFIG_SYSFS_DEPRECATED n
++
++# automatically add local version will cause packaging failure
++value CONFIG_LOCALVERSION_AUTO n
++
++# provide framebuffer console form the start
++# UbuntuSpec:foundations-m-grub2-boot-framebuffer
++value CONFIG_FRAMEBUFFER_CONSOLE y
++
++# GRUB changes will rely on built in vesafb on x86,
++# UbuntuSpec:foundations-m-grub2-boot-framebuffer
++#(( arch i386 | arch amd64 ) & value CONFIG_FB_VESA y) | \
++#	value CONFIG_FB_VESA m | !exists CONFIG_FB_VESA
++value CONFIG_FB_VESA m | !exists CONFIG_FB_VESA
++
++# Build in uinput module so that it's always available (LP: 584812)
++value CONFIG_INPUT_UINPUT y
++
++# upstart relies on getting all of the kernel arguments
++#value CONFIG_INIT_PASS_ALL_PARAMS y
++
++# Enabling CONFIG_IMA is vastly expensive, ensure it is off
++value CONFIG_IMA n
++
++# Ensure CONFIG_IPV6 is y, if this is a module we get a module load for
++# every ipv6 packet, bad.
++value CONFIG_IPV6 y
++
++# Ensure ECRYPT_FS is y as it cannot be autoloaded and it has complex
++# dependancies which can pull it =m at a whim.
++value CONFIG_ECRYPT_FS y
++
++# Ensure CONFIG_EFI_VARS is y as debian-installer relies on having
++# access to efivars when installing in EFI mode. See LP:837332
++value CONFIG_EFI_VARS y | !exists CONFIG_EFI_VARS
++
++# Ensure CONFIG_VFAT_FS is y for arm, needed to ensure we able to replace
++# a kernel with the same version.  Also needed for EFI based systems.
++(arch armel armhf i386 amd64 &/ value CONFIG_VFAT_FS y) | \
++ value CONFIG_VFAT_FS m
++
++# Ensure CONFIG_GPIO_TWL4030 is y for arm, LP:921934
++(arch armel armhf &/ value CONFIG_GPIO_TWL4030 y) | \
++ value CONFIG_GPIO_TWL4030 m | \
++ !exists CONFIG_GPIO_TWL4030
++
++# Ensure CONFIG_THERM_ADT746X is y for powerpc-smp flavours.
++# See LP:923094
++(flavour powerpc-smp &/ value CONFIG_THERM_ADT746X y) | \
++ !exists CONFIG_THERM_ADT746X
++
++# Ensure CONFIG_NVRAM is y for powerpc-smp, LP:942193
++(flavour powerpc-smp powerpc-e500 powerpc-e500mc &/ value CONFIG_NVRAM y) | \
++ (flavour powerpc-e500 powerpc-e500mc) | \
++ value CONFIG_NVRAM m | \
++ !exists CONFIG_NVRAM
++
++# Ensure CONFIG_STUB_POULSBO is disabled if CONFIG_DRM_PSB is enabled
++# See LP:899244
++(!exists CONFIG_DRM_PSB | value CONFIG_DRM_PSB n) | \
++((value CONFIG_DRM_PSB y | value CONFIG_DRM_PSB m) & (value CONFIG_STUB_POULSBO n | !exists CONFIG_STUB_POULSBO))
++
++# Ensure CONFIG_B43_BCMA_EXTRA is disabled if CONFIG_BRCMSMAC is enabled.
++# Otherwise b43 and brcmsmac will overlap in the hardware they claim to
++# support.
++(!exists CONFIG_BRCMSMAC | value CONFIG_BRCMSMAC n) | \
++((value CONFIG_BRCMSMAC y | value CONFIG_BRCMSMAC m) & (value CONFIG_B43_BCMA_EXTRA n | !exists CONFIG_B43_BCMA_EXTRA))
++
++# CONFIG_AUDIT_LOGINUID_IMMUTABLE is not compatible with upstart
++value CONFIG_AUDIT_LOGINUID_IMMUTABLE n
++
++# CONFIG_I2C_DESIGNWARE_PLATFORM is required by Calxeda Highbank
++(flavour highbank &/ value CONFIG_I2C_DESIGNWARE_PLATFORM y) | \
++value CONFIG_I2C_DESIGNWARE_PLATFORM m | \
++!exists CONFIG_I2C_DESIGNWARE_PLATFORM
++
++# Don't use the generic ehci/ohci code on omap, it doesn't work
++((flavour generic & arch armhf &/ value CONFIG_USB_EHCI_HCD_PLATFORM n & value CONFIG_USB_OHCI_HCD_PLATFORM n) | \
++	!exists MISSING)
++
++# CONFIG_DRM_MGAG200, experimental driver hangs boot on HP Proliant Gen8
++# See LP:1042903
++(!exists CONFIG_DRM_MGAG200 | value CONFIG_DRM_MGAG200 n)
++
++# Required if /init is a shell script.
++value CONFIG_BINFMT_SCRIPT y
+diff --git a/debian.master/config/i386/config.common.i386 b/debian.master/config/i386/config.common.i386
+new file mode 100644
+index 0000000..bd7149d
+--- /dev/null
++++ b/debian.master/config/i386/config.common.i386
+@@ -0,0 +1,115 @@
++#
++# Config options for config.common.i386 automatically generated by splitconfig.pl
++#
++# CONFIG_64BIT is not set
++CONFIG_AC97_BUS=m
++CONFIG_ACPI_BLACKLIST_YEAR=2000
++CONFIG_AHCI_IMX=m
++CONFIG_ARCH_DEFCONFIG="arch/x86/configs/i386_defconfig"
++CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-ecx -fcall-saved-edx"
++# CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
++CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
++CONFIG_ARCH_SELECT_MEMORY_MODEL=y
++CONFIG_ASYNC_TX_DMA=y
++# CONFIG_AUDIT_ARCH is not set
++CONFIG_BCH=m
++CONFIG_COMPACTION=y
++CONFIG_CPU_FREQ=y
++CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
++CONFIG_EZX_PCAP=y
++CONFIG_FB_BACKLIGHT=y
++CONFIG_FB_BOOT_VESA_SUPPORT=y
++CONFIG_FB_DDC=m
++CONFIG_FB_SVGALIB=m
++CONFIG_FB_SYS_COPYAREA=m
++CONFIG_FB_SYS_FILLRECT=m
++CONFIG_FB_SYS_IMAGEBLIT=m
++# CONFIG_FONTS is not set
++CONFIG_FUNCTION_TRACER=y
++CONFIG_GPIO_GENERIC=m
++CONFIG_GPIO_TWL6040=m
++CONFIG_HAVE_AOUT=y
++# CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
++CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++CONFIG_HUGETLB_PAGE=y
++CONFIG_HZ=250
++CONFIG_ILLEGAL_POINTER_VALUE=0
++CONFIG_KSM=y
++CONFIG_KVM=m
++CONFIG_LIBERTAS_MESH=y
++CONFIG_LIS3L02DQ=m
++CONFIG_LOG_BUF_SHIFT=17
++# CONFIG_MFD_TMIO is not set
++CONFIG_MMC_BLOCK=m
++CONFIG_MMC_SDHCI=m
++CONFIG_MMC_SDHCI_PLTFM=m
++CONFIG_MTD=m
++CONFIG_MTD_BLKDEVS=m
++CONFIG_MTD_BLOCK=m
++CONFIG_MTD_CMDLINE_PARTS=m
++CONFIG_MTD_NAND=m
++CONFIG_MTD_NAND_BCH=m
++CONFIG_MTD_NAND_ECC=m
++CONFIG_MTD_NAND_IDS=m
++CONFIG_MTD_SM_COMMON=m
++CONFIG_MUSB_PIO_ONLY=y
++CONFIG_NL80211_TESTMODE=y
++CONFIG_NOP_USB_XCEIV=m
++CONFIG_NR_CPUS=8
++CONFIG_OMAP_CONTROL_USB=m
++CONFIG_OUTPUT_FORMAT="elf32-i386"
++CONFIG_PCCARD=m
++CONFIG_PHYS_ADDR_T_64BIT=y
++CONFIG_PM_WAKELOCKS=y
++CONFIG_PPS=m
++CONFIG_PTP_1588_CLOCK=m
++CONFIG_RCU_FANOUT=32
++# CONFIG_RCU_NOCB_CPU is not set
++CONFIG_REGULATOR_FIXED_VOLTAGE=m
++CONFIG_RT2800USB_UNKNOWN=y
++# CONFIG_RT2X00_LIB_DEBUGFS is not set
++CONFIG_RTC_DRV_CMOS=y
++CONFIG_SATA_AHCI_PLATFORM=m
++# CONFIG_SATA_HIGHBANK is not set
++CONFIG_SCHED_SMT=y
++CONFIG_SCSI_SPI_ATTRS=y
++# CONFIG_SMS_SIANO_DEBUGFS is not set
++CONFIG_SND=m
++CONFIG_SND_COMPRESS_OFFLOAD=m
++CONFIG_SND_EMU10K1_SEQ=m
++CONFIG_SND_OPL3_LIB_SEQ=m
++CONFIG_SND_OPL4_LIB_SEQ=m
++CONFIG_SND_PCM=m
++CONFIG_SND_SBAWE_SEQ=m
++CONFIG_SND_SOC=m
++CONFIG_SND_SOC_HDMI_CODEC=m
++CONFIG_SND_SOC_I2C_AND_SPI=m
++CONFIG_SND_SOC_SGTL5000=m
++CONFIG_SND_SOC_TWL6040=m
++CONFIG_SND_TIMER=m
++CONFIG_SOUND=m
++# CONFIG_SPARSEMEM_MANUAL is not set
++CONFIG_SPI_PXA2XX_PCI=m
++CONFIG_STACK_TRACER=y
++# CONFIG_STANDALONE is not set
++CONFIG_TICK_CPU_ACCOUNTING=y
++# CONFIG_TWL4030_CORE is not set
++CONFIG_USB_CHIPIDEA=m
++CONFIG_USB_EHCI_HCD_PLATFORM=y
++CONFIG_USB_GADGET=m
++# CONFIG_USB_G_MULTI is not set
++CONFIG_USB_HCD_BCMA=m
++CONFIG_USB_HCD_SSB=m
++CONFIG_USB_MUSB_HDRC=m
++CONFIG_USB_MUSB_TUSB6010=m
++CONFIG_USB_OHCI_HCD_PLATFORM=y
++CONFIG_VFIO_IOMMU_TYPE1=m
++CONFIG_VGASTATE=m
++CONFIG_VIRTIO_CONSOLE=m
++CONFIG_VIRTIO_MMIO=m
++CONFIG_WIL6210=m
++CONFIG_X86_MINIMUM_CPU_FAMILY=5
++CONFIG_X86_SPEEDSTEP_LIB=y
++CONFIG_XEN_MAX_DOMAIN_MEMORY=64
++# CONFIG_ZONE_DMA32 is not set
++CONFIG_ZONE_DMA_FLAG=1
+diff --git a/debian.master/config/i386/config.flavour.generic b/debian.master/config/i386/config.flavour.generic
+new file mode 100644
+index 0000000..bb7773a
+--- /dev/null
++++ b/debian.master/config/i386/config.flavour.generic
+@@ -0,0 +1,3 @@
++#
++# Config options for config.flavour.generic automatically generated by splitconfig.pl
++#
+diff --git a/debian.master/config/x32/config.common.x32 b/debian.master/config/x32/config.common.x32
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/x32/config.common.x32
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/config/x32/config.flavour.generic b/debian.master/config/x32/config.flavour.generic
+new file mode 100644
+index 0000000..ad33444
+--- /dev/null
++++ b/debian.master/config/x32/config.flavour.generic
+@@ -0,0 +1 @@
++# nothing here yet
+diff --git a/debian.master/control.d/flavour-control.stub b/debian.master/control.d/flavour-control.stub
+new file mode 100644
+index 0000000..9636fbf
+--- /dev/null
++++ b/debian.master/control.d/flavour-control.stub
+@@ -0,0 +1,119 @@
++# Items that get replaced:
++# FLAVOUR
++# DESC
++# ARCH
++# SUPPORTED
++# TARGET
++# BOOTLOADER
++# =PROVIDES=
++#
++# Items marked with =FOO= are optional
++#
++# This file describes the template for packages that are created for each flavour
++# in debian/control.d/vars.*
++#
++# This file gets edited in a couple of places. See the debian/control.stub rule in
++# debian/rules. PGGVER, ABINUM, and SRCPKGNAME are all converted in the
++# process of creating debian/control.
++#
++# The flavour specific strings (ARCH, DESC, etc) are converted using values from the various
++# flavour files in debian/control.d/vars.*
++#
++# XXX: Leave the blank line before the first package!!
++
++Package: linux-image-PKGVER-ABINUM-FLAVOUR
++Architecture: ARCH
++Section: kernel
++Priority: optional
++Pre-Depends: dpkg (>= 1.10.24)
++Provides: linux-image, linux-image-3.0, fuse-module, =PROVIDES=
++Depends: ${misc:Depends}, ${shlibs:Depends}, initramfs-tools (>= 0.36ubuntu6), module-init-tools (>= 3.3-pre11-4ubuntu3)
++Conflicts: hotplug (<< 0.0.20040105-1)
++Recommends: BOOTLOADER
++Suggests: fdutils, SRCPKGNAME-doc-PKGVER | SRCPKGNAME-source-PKGVER, SRCPKGNAME-tools, linux-headers-PKGVER-ABINUM-FLAVOUR
++Description: Linux kernel image for version PKGVER on DESC
++ This package contains the Linux kernel image for version PKGVER on
++ DESC.
++ .
++ Also includes the corresponding System.map file, the modules built by the
++ packager, and scripts that try to ensure that the system is not left in an
++ unbootable state after an update.
++ .
++ Supports SUPPORTED processors.
++ .
++ TARGET
++ .
++ You likely do not want to install this package directly. Instead, install
++ the linux-FLAVOUR meta-package, which will ensure that upgrades work
++ correctly, and that supporting packages are also installed.
++
++Package: linux-image-extra-PKGVER-ABINUM-FLAVOUR
++Architecture: ARCH
++Section: kernel
++Priority: optional
++Depends: ${misc:Depends}, ${shlibs:Depends}, linux-image-PKGVER-ABINUM-FLAVOUR, crda (>=1.1.1-1ubuntu2) | wireless-crda
++Description: Linux kernel extra modules for version PKGVER on DESC
++ This package contains the Linux kernel extra modules for version PKGVER on
++ DESC.
++ .
++ Also includes the corresponding System.map file, the modules built by the
++ packager, and scripts that try to ensure that the system is not left in an
++ unbootable state after an update.
++ .
++ Supports SUPPORTED processors.
++ .
++ TARGET
++ .
++ You likely do not want to install this package directly. Instead, install
++ the linux-FLAVOUR meta-package, which will ensure that upgrades work
++ correctly, and that supporting packages are also installed.
++
++Package: linux-headers-PKGVER-ABINUM-FLAVOUR
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, linux-headers-PKGVER-ABINUM, ${shlibs:Depends}
++Provides: linux-headers, linux-headers-3.0
++Description: Linux kernel headers for version PKGVER on DESC
++ This package provides kernel header files for version PKGVER on
++ DESC.
++ .
++ This is for sites that want the latest kernel headers.  Please read
++ /usr/share/doc/linux-headers-PKGVER-ABINUM/debian.README.gz for details.
++
++Package: linux-image-PKGVER-ABINUM-FLAVOUR-dbgsym
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}
++Provides: linux-debug
++Description: Linux kernel debug image for version PKGVER on DESC
++ This package provides a kernel debug image for version PKGVER on
++ DESC.
++ .
++ This is for sites that wish to debug the kernel.
++ .
++ The kernel image contained in this package is NOT meant to boot from. It
++ is uncompressed, and unstripped. This package also includes the
++ unstripped modules.
++
++Package: linux-tools-PKGVER-ABINUM-FLAVOUR
++Architecture: ARCH
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, SRCPKGNAME-tools-PKGVER-ABINUM
++Description: Linux kernel version specific tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PKGVER-ABINUM on
++ =HUMAN=.
++
++Package: SRCPKGNAME-udebs-FLAVOUR
++XC-Package-Type: udeb
++Section: debian-installer
++Architecture: ARCH
++Depends: ${udeb:Depends}
++Description: Metapackage depending on kernel udebs
++ This package depends on the all udebs that the kernel build generated,
++ for easier version and migration tracking.
++
+diff --git a/debian.master/control.d/generic.inclusion-list b/debian.master/control.d/generic.inclusion-list
+new file mode 100644
+index 0000000..e9b2311
+--- /dev/null
++++ b/debian.master/control.d/generic.inclusion-list
+@@ -0,0 +1,159 @@
++arch/*/{crypto,kernel,oprofile}
++arch/*/kvm/kvm.ko
++arch/x86/kvm/kvm-intel.ko
++arch/x86/kvm/kvm-amd.ko
++crypto/*
++drivers/acpi/*
++drivers/ata/ahci_platform.ko
++drivers/ata/ahci.ko
++drivers/ata/acard-ahci.ko
++drivers/ata/libahci.ko
++drivers/block/nbd.ko
++drivers/block/floppy.ko
++drivers/block/cryptoloop.ko
++drivers/block/rbd.ko
++drivers/char/hangcheck-timer.ko
++drivers/char/ipmi/ipmi_msghandler.ko
++drivers/char/lp.ko
++drivers/char/nvram.ko
++drivers/char/ppdev.ko
++drivers/char/raw.ko
++drivers/hv/*
++drivers/infiniband/core/ib_core.ko
++drivers/infiniband/core/ib_addr.ko
++drivers/infiniband/core/ib_cm.ko
++drivers/infiniband/core/ib_mad.ko
++drivers/infiniband/core/ib_sa.ko
++drivers/infiniband/core/iw_cm.ko
++drivers/infiniband/core/rdma_cm.ko
++drivers/input/evbug.ko
++drivers/input/gameport/gameport.ko
++drivers/input/mouse/psmouse.ko
++drivers/input/serio/serio_raw.ko
++drivers/input/serio/serport.ko
++drivers/input/joydev.ko
++drivers/input/touchscreen/usbtouchscreen.ko
++drivers/input/misc/xen-kbdfront.ko
++drivers/md/*
++drivers/message/fusion*
++drivers/misc/vmw_balloon.ko
++drivers/net/mii.ko
++drivers/net/ethernet/8390/8390.ko
++drivers/net/ethernet/realtek/8139too.ko
++drivers/net/ethernet/realtek/8139cp.ko
++drivers/net/appletalk/ipddp.ko
++drivers/net/bonding/bonding.ko
++drivers/net/ppp/bsd_comp.ko
++drivers/net/dummy.ko
++drivers/net/ethernet/intel/e1000/e1000.ko
++drivers/net/ethernet/intel/e1000e/e1000e.ko
++drivers/net/eql.ko
++drivers/net/ifb.ko
++drivers/net/ethernet/intel/igbvf/igbvf.ko
++drivers/net/ethernet/intel/ixgbevf/ixgbevf.ko
++drivers/net/macvlan.ko
++drivers/net/macvtap.ko
++drivers/net/ethernet/8390/ne2k-pci.ko
++drivers/net/netconsole.ko
++drivers/net/ethernet/amd/pcnet32.ko
++drivers/net/hyperv/hv_netvsc.ko
++drivers/net/ppp/*
++drivers/net/slip/*
++drivers/net/veth.ko
++drivers/net/vmxnet3/vmxnet3.ko
++drivers/net/xen-netback/*
++drivers/parport/parport.ko
++drivers/parport/parport_pc.ko
++drivers/pps/pps_core.ko
++drivers/ptp/ptp.ko
++drivers/net/ethernet/dec/tulip/*
++drivers/scsi/BusLogic.ko
++drivers/scsi/device_handler/scsi_dh.ko
++drivers/scsi/iscsi_tcp.ko
++drivers/scsi/libiscsi.ko
++drivers/scsi/libiscsi_tcp.ko
++drivers/scsi/libsas/*
++drivers/scsi/osd/osd.ko
++drivers/scsi/osd/libosd.ko
++drivers/scsi/qla1280.ko
++drivers/scsi/raid_class.ko
++drivers/scsi/scsi_transport_fc.ko
++drivers/scsi/scsi_transport_iscsi.ko
++drivers/scsi/scsi_transport_sas.ko
++drivers/scsi/scsi_tgt.ko
++drivers/scsi/vmw_pvscsi.ko
++drivers/scsi/hv_storvsc.ko
++drivers/usb/storage/usb-storage.ko
++drivers/video/cirrusfb.ko
++drivers/video/output.ko
++drivers/video/syscopyarea.ko
++drivers/video/sysfillrect.ko
++drivers/video/sysimgblt.ko
++drivers/video/vesafb.ko
++drivers/video/vga16fb.ko
++drivers/video/vgastate.ko
++drivers/video/xen-fbfront.ko
++drivers/video/fb_sys_fops.ko
++drivers/virtio/virtio_balloon.ko
++drivers/watchdog/softdog.ko
++drivers/xen/*
++fs/9p/*
++fs/binfmt_misc.ko
++fs/btrfs/*
++fs/cachefiles/cachefiles.ko
++fs/ceph/*
++fs/configfs/*
++fs/exofs/libore.ko
++fs/ext*/*
++fs/fat/*
++fs/nls/nls_iso8859-1.ko
++fs/isofs/*
++fs/cifs/*
++fs/xfs/*
++fs/ufs/*
++fs/squashfs/*
++fs/nfs/*
++fs/nfsd/*
++fs/nfs_common/*
++fs/fscache/*
++fs/lockd/*
++fs/autofs4/autofs4.ko
++fs/overlayfs/*
++fs/udf/*
++lib/*
++net/802/*
++net/8021q/*
++net/9p/*
++net/appletalk/*
++net/atm/*
++net/ax25/*
++net/bridge/*
++net/can/*
++net/core/*
++net/ceph/libceph.ko
++net/dccp/*
++net/decnet/*
++net/ieee802154/*
++net/ipv4/*
++net/ipv6/*
++net/ipx/*
++net/irda/*
++net/key/*
++net/lapb/*
++net/llc/*
++net/netfilter/*
++net/netrom/*
++net/phonet/*
++net/rose/*
++net/rxrpc/*
++net/sched/*
++net/sctp/*
++net/tipc/*
++net/x25/*
++net/xfrm/*
++net/sunrpc/auth_gss/auth_rpcgss.ko
++net/sunrpc/sunrpc.ko
++sound/soundcore.ko
++sound/core/*
++sound/pci/snd-ens1370.ko
++sound/drivers/pcsp/snd-pcsp.ko
+diff --git a/debian.master/control.d/vars.generic b/debian.master/control.d/vars.generic
+new file mode 100644
+index 0000000..ebd6073
+--- /dev/null
++++ b/debian.master/control.d/vars.generic
+@@ -0,0 +1,6 @@
++arch="i386 amd64 armhf"
++supported="Generic"
++target="Geared toward desktop and server systems."
++desc="=HUMAN= SMP"
++bootloader="grub-pc [i386 amd64 x32] | grub-efi-amd64 [amd64 x32] | grub-efi-ia32 [i386 amd64 x32] | grub [i386 amd64 x32] | lilo (>= 19.1) [i386 amd64 x32] | flash-kernel [armhf arm64]"
++provides="kvm-api-4, redhat-cluster-modules, ivtv-modules"
+diff --git a/debian.master/control.d/vars.generic-lpae b/debian.master/control.d/vars.generic-lpae
+new file mode 100644
+index 0000000..616a7a5
+--- /dev/null
++++ b/debian.master/control.d/vars.generic-lpae
+@@ -0,0 +1,6 @@
++arch="armhf"
++supported="Generic LPAE"
++target="Geared toward desktop and server systems."
++desc="=HUMAN= SMP"
++bootloader="flash-kernel [armhf]"
++provides="kvm-api-4, redhat-cluster-modules, ivtv-modules"
+diff --git a/debian.master/control.stub.in b/debian.master/control.stub.in
+new file mode 100644
+index 0000000..1b04ccc
+--- /dev/null
++++ b/debian.master/control.stub.in
+@@ -0,0 +1,94 @@
++Source: linux
++Section: devel
++Priority: optional
++Maintainer: Ubuntu Kernel Team <kernel-team@lists.ubuntu.com>
++Standards-Version: 3.9.4.0
++Build-Depends: debhelper (>= 5), cpio, module-init-tools, kernel-wedge (>= 2.24ubuntu1), makedumpfile [amd64 i386], libelf-dev, libnewt-dev, binutils-dev, rsync, libdw-dev, libpci-dev, dpkg (>= 1.16.0~ubuntu4), pkg-config, flex, bison, libunwind8-dev, openssl, libaudit-dev, bc, python-dev, gcc-4.7 [armhf], gawk
++Build-Depends-Indep: xmlto, docbook-utils, ghostscript, transfig, bzip2, sharutils, asciidoc
++Vcs-Git: http://kernel.ubuntu.com/git-repos/ubuntu/ubuntu-saucy.git
++XS-Testsuite: autopkgtest
++#XS-Testsuite-Depends: gcc-4.7 binutils
++
++Package: SRCPKGNAME-source-PKGVER
++Architecture: all
++Section: devel
++Priority: optional
++Provides: SRCPKGNAME-source, SRCPKGNAME-source-3
++Depends: ${misc:Depends}, binutils, bzip2, coreutils | fileutils (>= 4.0)
++Recommends: libc-dev, gcc, make
++Suggests: libncurses-dev | ncurses-dev, kernel-package, libqt3-dev
++Description: Linux kernel source for version PKGVER with Ubuntu patches
++ This package provides the source code for the Linux kernel version
++ PKGVER.
++ .
++ This package is mainly meant for other packages to use, in order to build
++ custom flavours.
++ .
++ If you wish to use this package to create a custom Linux kernel, then it
++ is suggested that you investigate the package kernel-package, which has
++ been designed to ease the task of creating kernel image packages.
++ .
++ If you are simply trying to build third-party modules for your kernel,
++ you do not want this package. Install the appropriate linux-headers
++ package instead.
++
++Package: SRCPKGNAME-doc
++Architecture: all
++Section: doc
++Priority: optional
++Depends: ${misc:Depends}
++Conflicts: SRCPKGNAME-doc-3
++Replaces: SRCPKGNAME-doc-3
++Description: Linux kernel specific documentation for version PKGVER
++ This package provides the various documents in the PKGVER kernel
++ Documentation/ subdirectory.  These document kernel subsystems, APIs, device
++ drivers, and so on.  See
++ /usr/share/doc/SRCPKGNAME-doc/00-INDEX for a list of what is
++ contained in each file.
++
++Package: SRCPKGNAME-tools-common
++Architecture: all
++Section: kernel
++Priority: optional
++Depends: ${misc:Depends}
++Replaces: SRCPKGNAME-tools (<= 2.6.32-16.25)
++Description: Linux kernel version specific tools for version PKGVER
++ This package provides the architecture independent parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PGKVER.
++
++Package: SRCPKGNAME-headers-PKGVER-ABINUM
++Architecture: all
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, coreutils | fileutils (>= 4.0)
++Description: Header files related to Linux kernel version PKGVER
++ This package provides kernel header files for version PKGVER, for sites
++ that want the latest kernel headers. Please read
++ /usr/share/doc/SRCPKGNAME-headers-PKGVER-ABINUM/debian.README.gz for details
++
++Package: SRCPKGNAME-libc-dev
++Architecture: i386 amd64 armhf arm64 x32 powerpc
++Depends: ${misc:Depends}
++Conflicts: libc6-dev (<< 2.3.2.ds1-6), libc6.1-dev (<< 2.3.2.ds1-6), dvb-dev (<< 1.0.1-6), amd64-libs-dev (<= 1.1), SRCPKGNAME-kernel-headers
++Replaces: libc6-dev (<< 2.3.2.ds1-6), libc6.1-dev (<< 2.3.2.ds1-6), dvb-dev (<< 1.0.1-6), SRCPKGNAME-kernel-headers, libdrm-dev
++Provides: SRCPKGNAME-kernel-headers
++Multi-Arch: same
++Description: Linux Kernel Headers for development
++ This package provides headers from the Linux kernel.  These headers
++ are used by the installed headers for GNU glibc and other system
++ libraries. They are NOT meant to be used to build third-party modules for
++ your kernel. Use SRCPKGNAME-headers-* packages for that.
++
++Package: SRCPKGNAME-tools-PKGVER-ABINUM
++Architecture: i386 amd64 armhf
++Section: devel
++Priority: optional
++Depends: ${misc:Depends}, ${shlibs:Depends}, linux-tools-common
++Description: Linux kernel version specific tools for version PKGVER-ABINUM
++ This package provides the architecture dependant parts for kernel
++ version locked tools (such as perf and x86_energy_perf_policy) for
++ version PKGVER-ABINUM on
++ =HUMAN=.
++ You probabally want to install linux-tools-PKGVER-ABINUM-<flavour>.
++
+diff --git a/debian.master/copyright b/debian.master/copyright
+new file mode 100644
+index 0000000..d1d04a6
+--- /dev/null
++++ b/debian.master/copyright
+@@ -0,0 +1,29 @@
++This is the Ubuntu prepackaged version of the Linux kernel.
++Linux was written by Linus Torvalds <Linus.Torvalds@cs.Helsinki.FI>
++and others.
++
++This package was put together by the Ubuntu Kernel Team, from
++sources retrieved from upstream linux git.
++The sources may be found at most Linux ftp sites, including 
++ftp://ftp.kernel.org/pub/linux/kernel/
++
++This package is currently maintained by the
++Ubuntu Kernel Team <ubuntu-kernel@lists.ubuntu.com>
++
++Linux is copyrighted by Linus Torvalds and others.
++
++   This program is free software; you can redistribute it and/or modify
++   it under the terms of the GNU General Public License as published by
++   the Free Software Foundation; version 2 dated June, 1991.
++
++   This program is distributed in the hope that it will be useful,
++   but WITHOUT ANY WARRANTY; without even the implied warranty of
++   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
++   GNU General Public License for more details.
++
++   You should have received a copy of the GNU General Public License
++   along with this program; if not, write to the Free Software
++   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
++
++On Ubuntu Linux systems, the complete text of the GNU General
++Public License v2 can be found in `/usr/share/common-licenses/GPL-2'.
+diff --git a/debian.master/d-i/exclude-firmware.armhf-generic b/debian.master/d-i/exclude-firmware.armhf-generic
+new file mode 100644
+index 0000000..ddb5eb8
+--- /dev/null
++++ b/debian.master/d-i/exclude-firmware.armhf-generic
+@@ -0,0 +1,2 @@
++nic-modules
++scsi-modules
+diff --git a/debian.master/d-i/exclude-firmware.armhf-generic-lpae b/debian.master/d-i/exclude-firmware.armhf-generic-lpae
+new file mode 100644
+index 0000000..ddb5eb8
+--- /dev/null
++++ b/debian.master/d-i/exclude-firmware.armhf-generic-lpae
+@@ -0,0 +1,2 @@
++nic-modules
++scsi-modules
+diff --git a/debian.master/d-i/exclude-modules.amd64-virtual b/debian.master/d-i/exclude-modules.amd64-virtual
+new file mode 100644
+index 0000000..f3dc2b2
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.amd64-virtual
+@@ -0,0 +1,15 @@
++pata-modules
++serial-modules
++firewire-core-modules
++plip-modules
++usb-modules
++pcmcia-storage-modules
++input-modules
++nic-pcmcia-modules
++pcmcia-modules
++nic-usb-modules
++nfs-modules
++speakup-modules
++ppp-modules
++sata-modules
++ipmi-modules
+diff --git a/debian.master/d-i/exclude-modules.armhf-generic b/debian.master/d-i/exclude-modules.armhf-generic
+new file mode 100644
+index 0000000..39ab95b
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.armhf-generic
+@@ -0,0 +1,10 @@
++serial-modules
++firewire-core-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++nic-pcmcia-modules
++pcmcia-modules
++pata-modules
++message-modules
++virtio-modules
+diff --git a/debian.master/d-i/exclude-modules.armhf-generic-lpae b/debian.master/d-i/exclude-modules.armhf-generic-lpae
+new file mode 100644
+index 0000000..39ab95b
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.armhf-generic-lpae
+@@ -0,0 +1,10 @@
++serial-modules
++firewire-core-modules
++floppy-modules
++pcmcia-storage-modules
++fb-modules
++nic-pcmcia-modules
++pcmcia-modules
++pata-modules
++message-modules
++virtio-modules
+diff --git a/debian.master/d-i/exclude-modules.i386-virtual b/debian.master/d-i/exclude-modules.i386-virtual
+new file mode 100644
+index 0000000..f3dc2b2
+--- /dev/null
++++ b/debian.master/d-i/exclude-modules.i386-virtual
+@@ -0,0 +1,15 @@
++pata-modules
++serial-modules
++firewire-core-modules
++plip-modules
++usb-modules
++pcmcia-storage-modules
++input-modules
++nic-pcmcia-modules
++pcmcia-modules
++nic-usb-modules
++nfs-modules
++speakup-modules
++ppp-modules
++sata-modules
++ipmi-modules
+diff --git a/debian.master/d-i/firmware/README.txt b/debian.master/d-i/firmware/README.txt
+new file mode 100644
+index 0000000..27a8600
+--- /dev/null
++++ b/debian.master/d-i/firmware/README.txt
+@@ -0,0 +1,4 @@
++#
++# Place the names of udeb modules into this directory that require
++# runtime firmware.
++#
+diff --git a/debian.master/d-i/firmware/kernel-image b/debian.master/d-i/firmware/kernel-image
+new file mode 100644
+index 0000000..a2a6b75
+--- /dev/null
++++ b/debian.master/d-i/firmware/kernel-image
+@@ -0,0 +1,11 @@
++device-tree/highbank.dtb ?
++device-tree/imx6q-sabrelite.dtb ?
++device-tree/omap3-beagle-xm.dtb ?
++device-tree/omap4-panda.dtb ?
++device-tree/omap4-panda-es.dtb ?
++device-tree/tegra20-harmony.dtb ?
++device-tree/tegra20-paz00.dtb ?
++device-tree/tegra20-seaboard.dtb ?
++device-tree/tegra20-trimslice.dtb ?
++device-tree/tegra20-ventana.dtb ?
++device-tree/tegra20-whistler.dtb ?
+diff --git a/debian.master/d-i/firmware/nic-modules b/debian.master/d-i/firmware/nic-modules
+new file mode 100644
+index 0000000..4b70705
+--- /dev/null
++++ b/debian.master/d-i/firmware/nic-modules
+@@ -0,0 +1,14 @@
++e100/d101m_ucode.bin
++e100/d101s_ucode.bin
++e100/d102e_ucode.bin
++bnx2/bnx2-mips-09-6.2.1b.fw
++bnx2/bnx2-rv2p-06-6.0.15.fw
++bnx2/bnx2-mips-06-6.2.3.fw
++bnx2/bnx2-rv2p-09-6.0.17.fw
++bnx2/bnx2-rv2p-09ax-6.0.17.fw
++bnx2x/bnx2x-e1h-7.8.17.0.fw
++bnx2x/bnx2x-e1-7.8.17.0.fw
++bnx2x/bnx2x-e2-7.8.17.0.fw
++tigon/tg3_tso5.bin
++tigon/tg3_tso.bin
++tigon/tg3.bin
+diff --git a/debian.master/d-i/firmware/scsi-modules b/debian.master/d-i/firmware/scsi-modules
+new file mode 100644
+index 0000000..b089c7d
+--- /dev/null
++++ b/debian.master/d-i/firmware/scsi-modules
+@@ -0,0 +1,3 @@
++qlogic/1040.bin
++qlogic/12160.bin
++qlogic/1280.bin
+diff --git a/debian.master/d-i/kernel-versions.in b/debian.master/d-i/kernel-versions.in
+new file mode 100644
+index 0000000..0dca8d7
+--- /dev/null
++++ b/debian.master/d-i/kernel-versions.in
+@@ -0,0 +1,11 @@
++# arch	version		flavour		installedname			suffix	bdep
++amd64	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	
++
++i386	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-	
++
++armhf	PKGVER-ABINUM	generic		PKGVER-ABINUM-generic		-
++
++armhf	PKGVER-ABINUM	generic-lpae		PKGVER-ABINUM-generic-lpae		-
++
++# Ports
++# arch	version		flavour		installedname			suffix	bdep
+diff --git a/debian.master/d-i/modules/block-modules b/debian.master/d-i/modules/block-modules
+new file mode 100644
+index 0000000..546c900
+--- /dev/null
++++ b/debian.master/d-i/modules/block-modules
+@@ -0,0 +1,33 @@
++aoe ?
++aten ?
++bpck ?
++bpck6 ?
++cciss ?
++comm ?
++cpqarray ?
++DAC960 ?
++dstr ?
++epat ?
++epia ?
++fit2 ?
++fit3 ?
++friq ?
++frpw ?
++hpsa ?
++kbic ?
++ktti ?
++nbd ?
++on20 ?
++on26 ?
++paride ?
++pcd ?
++pd ?
++pf ?
++pg ?
++pt ?
++sdhci-tegra ?
++sx8 ?
++umem ?
++virtio_blk ?
++xen-blkfront ?
++mtip32xx ?
+diff --git a/debian.master/d-i/modules/crypto-modules b/debian.master/d-i/modules/crypto-modules
+new file mode 100644
+index 0000000..333f5a5
+--- /dev/null
++++ b/debian.master/d-i/modules/crypto-modules
+@@ -0,0 +1,70 @@
++aesni-intel ?
++aes-x86_64 ?
++af_alg ?
++algif_hash ?
++algif_skcipher ?
++ansi_cprng ?
++anubis ?
++arc4 ?
++async_memcpy ?
++async_pq ?
++async_raid6_recov ?
++async_tx ?
++async_xor ?
++authenc ?
++authencesn ?
++blowfish_common ?
++blowfish_generic ?
++blowfish-x86_64 ?
++camellia ?
++cast5 ?
++cast6 ?
++ccm ?
++cryptd ?
++cryptoloop ?
++crypto_null ?
++crypto_user ?
++ctr ?
++cts ?
++deflate ?
++des_generic ?
++fcrypt ?
++gcm ?
++gf128mul ?
++ghash-clmulni-intel ?
++ghash-generic ?
++khazad ?
++lrw ?
++lzo ?
++md4 ?
++michael_mic ?
++padlock-aes ?
++padlock-sha ?
++pcbc ?
++pcrypt ?
++raid6test ?
++rmd128 ?
++rmd160 ?
++rmd256 ?
++rmd320 ?
++salsa20_generic ?
++salsa20-x86_64 ?
++seed ?
++seqiv ?
++serpent_generic ?
++serpent-sse2-x86_64 ?
++sha1-ssse3 ?
++sha512_generic ?
++tcrypt ?
++tea ?
++tgr192 ?
++twofish_common ?
++twofish_generic ?
++twofish-x86_64 ?
++twofish-x86_64-3way ?
++vmac ?
++wp512 ?
++xcbc ?
++xor ?
++xts ?
++zlib ?
+diff --git a/debian.master/d-i/modules/fat-modules b/debian.master/d-i/modules/fat-modules
+new file mode 100644
+index 0000000..0aa17c3
+--- /dev/null
++++ b/debian.master/d-i/modules/fat-modules
+@@ -0,0 +1,7 @@
++fat ?
++vfat ?
++
++# Supporting modules ?
++nls_cp437 ?
++nls_iso8859-1 ?
++nls_utf8 ?
+diff --git a/debian.master/d-i/modules/fb-modules b/debian.master/d-i/modules/fb-modules
+new file mode 100644
+index 0000000..eae829f
+--- /dev/null
++++ b/debian.master/d-i/modules/fb-modules
+@@ -0,0 +1,3 @@
++fbcon ?
++vesafb ?
++vga16fb ?
+diff --git a/debian.master/d-i/modules/firewire-core-modules b/debian.master/d-i/modules/firewire-core-modules
+new file mode 100644
+index 0000000..dbb9229
+--- /dev/null
++++ b/debian.master/d-i/modules/firewire-core-modules
+@@ -0,0 +1,4 @@
++firewire-core ?
++firewire-ohci ?
++firewire-sbp2 ?
++firewire-net ?
+diff --git a/debian.master/d-i/modules/floppy-modules b/debian.master/d-i/modules/floppy-modules
+new file mode 100644
+index 0000000..ca8d7ff
+--- /dev/null
++++ b/debian.master/d-i/modules/floppy-modules
+@@ -0,0 +1 @@
++floppy ?
+diff --git a/debian.master/d-i/modules/fs-core-modules b/debian.master/d-i/modules/fs-core-modules
+new file mode 100644
+index 0000000..a9c7541
+--- /dev/null
++++ b/debian.master/d-i/modules/fs-core-modules
+@@ -0,0 +1,4 @@
++ext2 ?
++jfs ?
++reiserfs ?
++xfs ?
+diff --git a/debian.master/d-i/modules/fs-secondary-modules b/debian.master/d-i/modules/fs-secondary-modules
+new file mode 100644
+index 0000000..db46bb7
+--- /dev/null
++++ b/debian.master/d-i/modules/fs-secondary-modules
+@@ -0,0 +1,5 @@
++btrfs ?
++fuse ?
++ntfs ?
++hfs ?
++hfsplus ?
+diff --git a/debian.master/d-i/modules/input-modules b/debian.master/d-i/modules/input-modules
+new file mode 100644
+index 0000000..ee0ba88
+--- /dev/null
++++ b/debian.master/d-i/modules/input-modules
+@@ -0,0 +1,23 @@
++hid-a4tech ?
++hid-apple ?
++hid-belkin ?
++hid-bright ?
++hid-cherry ?
++hid-chicony ?
++hid-cypress ?
++hid-dell ?
++hid-ezkey ?
++hid-generic ?
++hid-gyration ?
++hid-logitech ?
++hid-logitech-dj ?
++hid-microsoft ?
++hid-monterey ?
++hid-petalynx ?
++hid-pl ?
++hid-samsung ?
++hid-sony ?
++hid-sunplus ?
++hid-tmff ?
++hid-zpff ?
++usbhid ?
+diff --git a/debian.master/d-i/modules/ipmi-modules b/debian.master/d-i/modules/ipmi-modules
+new file mode 100644
+index 0000000..d539daa
+--- /dev/null
++++ b/debian.master/d-i/modules/ipmi-modules
+@@ -0,0 +1,5 @@
++ipmi_devintf ?
++ipmi_msghandler ?
++ipmi_poweroff ?
++ipmi_si ?
++ipmi_watchdog ?
+diff --git a/debian.master/d-i/modules/irda-modules b/debian.master/d-i/modules/irda-modules
+new file mode 100644
+index 0000000..552e7a7
+--- /dev/null
++++ b/debian.master/d-i/modules/irda-modules
+@@ -0,0 +1,30 @@
++act200l-sir ?
++actisys-sir ?
++ali-ircc ?
++donauboe ?
++esi-sir ?
++girbil-sir ?
++ircomm ?
++ircomm-tty ?
++irda ?
++irda-usb ?
++irlan ?
++irnet ?
++irport ?
++irtty-sir ?
++kingsun-sir ?
++ks959-sir ?
++ksdazzle-sir ?
++litelink-sir ?
++ma600-sir ?
++mcp2120-sir ?
++mcs7780 ?
++nsc-ircc ?
++old_belkin-sir ?
++sir-dev ?
++smsc-ircc2 ?
++stir4200 ?
++tekram-sir ?
++via-ircc ?
++vlsi_ir ?
++w83977af_ir ?
+diff --git a/debian.master/d-i/modules/kernel-image b/debian.master/d-i/modules/kernel-image
+new file mode 100644
+index 0000000..0c0916d
+--- /dev/null
++++ b/debian.master/d-i/modules/kernel-image
+@@ -0,0 +1,24 @@
++gpio-pca953x ?
++gpio-regulator ?
++i2c-mux ?
++i2c-mux-pinctrl ?
++i2c-tegra ?
++max8907 ?
++max8907-regulator ?
++nvec ?
++nvec_kbd ?
++nvec_paz00 ?
++nvec_power ?
++nvec_ps2 ?
++palmas-regulator ?
++rtc-em3027 ?
++rtc-max8907 ?
++rtc-palmas ?
++rtc-tps6586x ?
++rtc-tps65910 ?
++tps51632-regulator ?
++tps62360-regulator ?
++tps65090-charger ?
++tps65090-regulator ?
++tps6586x-regulator ?
++tps65910-regulator ?
+diff --git a/debian.master/d-i/modules/md-modules b/debian.master/d-i/modules/md-modules
+new file mode 100644
+index 0000000..64217bf
+--- /dev/null
++++ b/debian.master/d-i/modules/md-modules
+@@ -0,0 +1,16 @@
++dm-crypt ?
++dm-mirror ?
++dm-raid ?
++dm-snapshot ?
++dm-zero ?
++faulty ?
++linear ?
++multipath ?
++raid0 ?
++raid1 ?
++raid10 ?
++raid456 ?
++
++# Extras
++dm-raid45 ?
++dm-loop ?
+diff --git a/debian.master/d-i/modules/message-modules b/debian.master/d-i/modules/message-modules
+new file mode 100644
+index 0000000..505eea7
+--- /dev/null
++++ b/debian.master/d-i/modules/message-modules
+@@ -0,0 +1,14 @@
++mptbase ?
++mptctl ?
++mptfc ?
++mptlan ?
++mptsas ?
++mpt2sas ?
++mptscsih ?
++mptspi ?
++i2o_block ?
++i2o_bus ?
++i2o_config ?
++i2o_core ?
++i2o_proc ?
++i2o_scsi ?
+diff --git a/debian.master/d-i/modules/mouse-modules b/debian.master/d-i/modules/mouse-modules
+new file mode 100644
+index 0000000..7b06256
+--- /dev/null
++++ b/debian.master/d-i/modules/mouse-modules
+@@ -0,0 +1,2 @@
++psmouse ?
++usbmouse ?
+diff --git a/debian.master/d-i/modules/multipath-modules b/debian.master/d-i/modules/multipath-modules
+new file mode 100644
+index 0000000..3516fde
+--- /dev/null
++++ b/debian.master/d-i/modules/multipath-modules
+@@ -0,0 +1,2 @@
++dm-multipath ?
++dm-round-robin ?
+diff --git a/debian.master/d-i/modules/nfs-modules b/debian.master/d-i/modules/nfs-modules
+new file mode 100644
+index 0000000..a08f538
+--- /dev/null
++++ b/debian.master/d-i/modules/nfs-modules
+@@ -0,0 +1,6 @@
++nfs ?
++nfs_acl ?
++nfsv3 ?
++lockd ?
++sunrpc ?
++cifs ?
+diff --git a/debian.master/d-i/modules/nic-modules b/debian.master/d-i/modules/nic-modules
+new file mode 100644
+index 0000000..30aeab0
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-modules
+@@ -0,0 +1,172 @@
++3c359 ?
++3c501 ?
++3c503 ?
++3c505 ?
++3c507 ?
++3c509 ?
++3c515 ?
++3c523 ?
++3c527 ?
++3c59x ?
++8139cp ?
++8139too ?
++82596 ?
++abyss ?
++ac3200 ?
++adm8211 ?
++airo ?
++airport ?
++alx ?
++amd8111e ?
++arc4 ?
++arcnet ?
++arc-rawmode ?
++arc-rimi ?
++arlan ?
++at1700 ?
++ath5k ?
++ath9k ?
++ath9k_htc ?
++atl1 ?
++atl1c ?
++atl1e ?
++atl2 ?
++atmel ?
++atmel_pci ?
++b44 ?
++be2net ?
++bmac ?
++bnx2 ?
++bnx2x ?
++bonding ?
++brcmfmac ?
++brcmsmac ?
++xgmac ?
++cassini ?
++com20020 ?
++com20020-pci ?
++com90io ?
++com90xx ?
++cs89x0 ?
++de2104x ?
++de4x5 ?
++de600 ?
++de620 ?
++defxx ?
++depca ?
++dl2k ?
++dmfe ?
++dummy ?
++e100 ?
++e1000 ?
++e1000e ?
++e2100 ?
++eepro ?
++eepro100 ?
++eexpress ?
++enic ?
++epic100 ?
++eql ?
++es3210 ?
++eth16i ?
++ewrk3 ?
++fealnx ?
++forcedeth ?
++igb ?
++ps3_gelic ?
++hamachi ?
++hermes ?
++hp ?
++hp100 ?
++hp-plus ?
++ibmtr ?
++ipddp ?
++ipw2100 ?
++ipw2200 ?
++iwl3945 ?
++iwl4965 ?
++iwl-legacy ?
++iwldvm ?
++iwlwifi ?
++ixgb ?
++ixgbe ?
++lance ?
++lanstreamer ?
++lasi_82596 ?
++lne390 ?
++lp486e ?
++mace ?
++mlx4_core ?
++mlx4_en ?
++mv643xx_eth ?
++myri_sbus ?
++natsemi ?
++ne ?
++ne2 ?
++ne2k-pci ?
++ne3210 ?
++netconsole ?
++netxen_nic ?
++ni5010 ?
++ni52 ?
++ni65 ?
++niu ?
++ns83820 ?
++olympic ?
++orinoco ?
++orinoco_pci ?
++orinoco_plx ?
++orinoco_tmd ?
++pcnet32 ?
++qlcnic ?
++r8169 ?
++rate_control ?
++rfc1051 ?
++rfc1201 ?
++rrunner ?
++rt2400 ?
++rt2400pci ?
++rt2500 ?
++rt2500pci ?
++rt2800pci ?
++rt61pci ?
++s2io ?
++shaper ?
++sis190 ?
++sis900 ?
++spidernet ?
++skfp ?
++skge ?
++sk98lin ?
++sky2 ?
++smc9194 ?
++smc-ultra ?
++smc-ultra32 ?
++starfire ?
++strip ?
++sunbmac ?
++sundance ?
++sungem ?
++sungem_phy ?
++sunhme ?
++sunlance ?
++sunqe ?
++sunvnet ?
++tg3 ?
++tlan ?
++tms380tr ?
++tmspci ?
++tulip ?
++tun ?
++typhoon ?
++uli526x ?
++via-rhine ?
++via-velocity ?
++virtio_net ?
++wavelan ?
++wd ?
++winbond-840 ?
++yellowfin ?
++znet ?
++vmxnet3 ?
++xen-netfront ?
+diff --git a/debian.master/d-i/modules/nic-pcmcia-modules b/debian.master/d-i/modules/nic-pcmcia-modules
+new file mode 100644
+index 0000000..1916875
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-pcmcia-modules
+@@ -0,0 +1,19 @@
++3c574_cs ?
++3c589_cs ?
++airo_cs ?
++atmel_cs ?
++axnet_cs ?
++com20020_cs ?
++fmvj18x_cs ?
++ibmtr_cs ?
++netwave_cs ?
++nmclan_cs ?
++orinoco_cs ?
++pcnet_cs ?
++ray_cs ?
++smc91c92_cs ?
++wavelan_cs ?
++wl3501_cs ?
++xirc2ps_cs ?
++xircom_cb ?
++xircom_tulip_cb ?
+diff --git a/debian.master/d-i/modules/nic-shared-modules b/debian.master/d-i/modules/nic-shared-modules
+new file mode 100644
+index 0000000..0ee15aa
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-shared-modules
+@@ -0,0 +1,26 @@
++# PHY
++8390 ?
++mii ?
++
++# CRC modules
++crc-ccitt ?
++crc-itu-t ?
++libcrc32c ?
++
++# mac80211 stuff
++mac80211 ?
++cfg80211 ?
++
++# rt2x00 lib (since rt2x00 is split across usb/pci/cb
++rt2x00lib ?
++rt2800lib ?
++
++# Atheros library (since drivers are split across nic-modules/nic-usb-modules)
++ath ?
++
++# Wireless 802.11 modules
++lib80211 ?
++cfg80211 ?
++lib80211_crypt_ccmp ?
++lib80211_crypt_tkip ?
++lib80211_crypt_wep ?
+diff --git a/debian.master/d-i/modules/nic-usb-modules b/debian.master/d-i/modules/nic-usb-modules
+new file mode 100644
+index 0000000..2dabc2d
+--- /dev/null
++++ b/debian.master/d-i/modules/nic-usb-modules
+@@ -0,0 +1,32 @@
++catc ?
++kaweth ?
++pegasus ?
++prism2_usb ?
++rtl8150 ?
++usbnet ?
++zd1211rw ?
++zd1201 ?
++rt2500usb ?
++rt73usb ?
++rt2570 ?
++rt2800usb ?
++rt2x00usb ?
++cdc_ether ?
++asix ?
++cdc_eem ?
++cdc_ether ?
++cdc-phonet ?
++cdc_subset ?
++dm9601 ?
++gl620a ?
++hso ?
++int51x1 ?
++mcs7830 ?
++net1080 ?
++plusb ?
++rndis_host ?
++smsc95xx ?
++zaurus ?
++carl9170 ?
++smsc75xx ?
++smsc95xx ?
+diff --git a/debian.master/d-i/modules/parport-modules b/debian.master/d-i/modules/parport-modules
+new file mode 100644
+index 0000000..75fe0b9
+--- /dev/null
++++ b/debian.master/d-i/modules/parport-modules
+@@ -0,0 +1,2 @@
++parport ?
++parport_pc ?
+diff --git a/debian.master/d-i/modules/pata-modules b/debian.master/d-i/modules/pata-modules
+new file mode 100644
+index 0000000..a58c30a
+--- /dev/null
++++ b/debian.master/d-i/modules/pata-modules
+@@ -0,0 +1,47 @@
++pata_ali.ko ?
++pata_amd.ko ?
++pata_artop.ko ?
++pata_atiixp.ko ?
++pata_atp867x.ko ?
++pata_cmd640.ko ?
++pata_cmd64x.ko ?
++pata_cs5520.ko ?
++pata_cs5530.ko ?
++pata_cs5535.ko ?
++pata_cs5536.ko ?
++pata_cypress.ko ?
++pata_efar.ko ?
++pata_hpt366.ko ?
++pata_hpt37x.ko ?
++pata_hpt3x2n.ko ?
++pata_hpt3x3.ko ?
++pata_isapnp.ko ?
++pata_it8213.ko ?
++pata_it821x.ko ?
++pata_jmicron.ko ?
++pata_legacy.ko ?
++pata_macio.ko ?
++pata_marvell.ko ?
++pata_mpiix.ko ?
++pata_netcell.ko ?
++pata_ninja32.ko ?
++pata_ns87410.ko ?
++pata_ns87415.ko ?
++pata_oldpiix.ko ?
++pata_optidma.ko ?
++pata_opti.ko ?
++pata_pcmcia.ko ?
++pata_pdc2027x.ko ?
++pata_pdc202xx_old.ko ?
++pata_qdi.ko ?
++pata_radisys.ko ?
++pata_rdc.ko ?
++pata_rz1000.ko ?
++pata_sc1200.ko ?
++pata_sch.ko ?
++pata_serverworks.ko ?
++pata_sil680.ko ?
++pata_sl82c105.ko ?
++pata_triflex.ko ?
++pata_via.ko ?
++pata_winbond.ko ?
+diff --git a/debian.master/d-i/modules/pcmcia-modules b/debian.master/d-i/modules/pcmcia-modules
+new file mode 100644
+index 0000000..06a5031
+--- /dev/null
++++ b/debian.master/d-i/modules/pcmcia-modules
+@@ -0,0 +1,8 @@
++i82092 ?
++i82365 ?
++pcmcia ?
++pcmcia_core ?
++pd6729 ?
++rsrc_nonstatic ?
++tcic ?
++yenta_socket ?
+diff --git a/debian.master/d-i/modules/pcmcia-storage-modules b/debian.master/d-i/modules/pcmcia-storage-modules
+new file mode 100644
+index 0000000..bb042a6
+--- /dev/null
++++ b/debian.master/d-i/modules/pcmcia-storage-modules
+@@ -0,0 +1,6 @@
++pata_pcmcia ?
++qlogic_cs ?
++fdomain_cs ?
++aha152x_cs ?
++nsp_cs ?
++sym53c500_cs ?
+diff --git a/debian.master/d-i/modules/plip-modules b/debian.master/d-i/modules/plip-modules
+new file mode 100644
+index 0000000..446e2bd
+--- /dev/null
++++ b/debian.master/d-i/modules/plip-modules
+@@ -0,0 +1 @@
++plip ?
+diff --git a/debian.master/d-i/modules/ppp-modules b/debian.master/d-i/modules/ppp-modules
+new file mode 100644
+index 0000000..d4f6a92
+--- /dev/null
++++ b/debian.master/d-i/modules/ppp-modules
+@@ -0,0 +1,6 @@
++ppp_async ?
++ppp_deflate ?
++ppp_mppe ?
++pppoe ?
++pppox ?
++ppp_synctty ?
+diff --git a/debian.master/d-i/modules/sata-modules b/debian.master/d-i/modules/sata-modules
+new file mode 100644
+index 0000000..9fc63cd
+--- /dev/null
++++ b/debian.master/d-i/modules/sata-modules
+@@ -0,0 +1,17 @@
++sata_inic162x.ko ?
++sata_mv.ko ?
++sata_nv.ko ?
++sata_promise.ko ?
++sata_qstor.ko ?
++sata_sil24.ko ?
++sata_sil.ko ?
++sata_sis.ko ?
++sata_svw.ko ?
++sata_sx4.ko ?
++sata_uli.ko ?
++sata_via.ko ?
++sata_vsc.ko ?
++ahci_platform ?
++ahci ?
++acard-ahci ?
++libahci ?
+diff --git a/debian.master/d-i/modules/scsi-modules b/debian.master/d-i/modules/scsi-modules
+new file mode 100644
+index 0000000..cde24b6
+--- /dev/null
++++ b/debian.master/d-i/modules/scsi-modules
+@@ -0,0 +1,126 @@
++# SCSI
++raid_class ?
++scsi_transport_spi ?
++scsi_transport_fc ?
++scsi_transport_iscsi ?
++scsi_transport_sas ?
++iscsi_tcp ?
++libiscsi ?
++amiga7xx ?
++a3000 ?
++a2091 ?
++gvp11 ?
++mvme147 ?
++sgiwd93 ?
++cyberstorm ?
++cyberstormII ?
++blz2060 ?
++blz1230 ?
++fastlane ?
++oktagon_esp_mod ?
++atari_scsi ?
++mac_scsi ?
++mac_esp ?
++sun3_scsi ?
++mvme16x ?
++bvme6000 ?
++sim710 ?
++advansys ?
++psi240i ?
++BusLogic ?
++dpt_i2o ?
++u14-34f ?
++ultrastor ?
++aha152x ?
++aha1542 ?
++aha1740 ?
++aic7xxx_old ?
++ips ?
++fd_mcs ?
++fdomain ?
++fnic ?
++in2000 ?
++g_NCR5380 ?
++g_NCR5380_mmio ?
++NCR53c406a ?
++NCR_D700 ?
++NCR_Q720_mod ?
++sym53c416 ?
++qlogicfas408 ?
++qla1280 ?
++pas16 ?
++seagate ?
++seagate ?
++t128 ?
++dmx3191d ?
++dtc ?
++zalon7xx ?
++eata_pio ?
++wd7000 ?
++mca_53c9x ?
++ibmmca ?
++eata ?
++dc395x ?
++tmscsim ?
++megaraid ?
++atp870u ?
++esp ?
++gdth ?
++initio ?
++a100u2w ?
++qlogicpti ?
++ide-scsi ?
++mesh ?
++mac53c94 ?
++pluto ?
++dec_esp ?
++3w-xxxx ?
++3w-9xxx ?
++ppa ?
++imm ?
++jazz_esp ?
++sun3x_esp ?
++fcal ?
++lasi700 ?
++nsp32 ?
++ipr ?
++hptiop ?
++stex ?
++osst ?
++sg ?
++ch ?
++scsi_debug ?
++aacraid ?
++aic7xxx ?
++aic79xx ?
++aic94xx ?
++arcmsr ?
++acornscsi_mod ?
++arxescsi ?
++cumana_1 ?
++cumana_2 ?
++ecoscsi ?
++oak ?
++powertec ?
++eesox ?
++ibmvscsic ?
++libsas ?
++lpfc ?
++megaraid_mm ?
++megaraid_mbox ?
++megaraid_sas ?
++qla2xxx ?
++sym53c8xx ?
++qla4xxx ?
++mvsas ?
++vmw_pvscsi ?
++ums-cypress ?
++be2iscsi ?
++3w-sas ?
++isci ?
++
++# device handlers
++scsi_dh_alua ?
++scsi_dh_emc ?
++scsi_dh_rdac ?
++scsi_dh_hp_sw ?
+diff --git a/debian.master/d-i/modules/serial-modules b/debian.master/d-i/modules/serial-modules
+new file mode 100644
+index 0000000..81ef801
+--- /dev/null
++++ b/debian.master/d-i/modules/serial-modules
+@@ -0,0 +1,3 @@
++generic_serial ?
++serial_cs ?
++synclink_cs ?
+diff --git a/debian.master/d-i/modules/speakup-modules b/debian.master/d-i/modules/speakup-modules
+new file mode 100644
+index 0000000..c3bef91
+--- /dev/null
++++ b/debian.master/d-i/modules/speakup-modules
+@@ -0,0 +1,16 @@
++speakup ?
++speakup_acntpc ?
++speakup_acntsa ?
++speakup_apollo ?
++speakup_audptr ?
++speakup_bns ?
++speakup_decext ?
++speakup_dectlk ?
++speakup_dtlk ?
++speakup_dummy ?
++speakup_keypc ?
++speakup_ltlk ?
++speakup_soft ?
++speakup_spkout ?
++speakup_txprt ?
++speakup_decpc ?
+diff --git a/debian.master/d-i/modules/squashfs-modules b/debian.master/d-i/modules/squashfs-modules
+new file mode 100644
+index 0000000..b0c5ed0
+--- /dev/null
++++ b/debian.master/d-i/modules/squashfs-modules
+@@ -0,0 +1 @@
++squashfs ?
+diff --git a/debian.master/d-i/modules/storage-core-modules b/debian.master/d-i/modules/storage-core-modules
+new file mode 100644
+index 0000000..2abfc06
+--- /dev/null
++++ b/debian.master/d-i/modules/storage-core-modules
+@@ -0,0 +1,10 @@
++# Core stacks
++usb-storage ?
++
++# Block level
++
++# Loop modules
++cryptoloop ?
++
++# Needs to be here for better cdrom initrd layout
++isofs ?
+diff --git a/debian.master/d-i/modules/usb-modules b/debian.master/d-i/modules/usb-modules
+new file mode 100644
+index 0000000..e242f5a
+--- /dev/null
++++ b/debian.master/d-i/modules/usb-modules
+@@ -0,0 +1,10 @@
++ehci-hcd ?
++isp116x-hcd ?
++isp1760 ?
++ohci-hcd ?
++r8a66597-hcd ?
++sl811_cs ?
++sl811-hcd ?
++u132-hcd ?
++uhci-hcd ?
++xhci-hcd ?
+diff --git a/debian.master/d-i/modules/virtio-modules b/debian.master/d-i/modules/virtio-modules
+new file mode 100644
+index 0000000..67bddfc
+--- /dev/null
++++ b/debian.master/d-i/modules/virtio-modules
+@@ -0,0 +1,9 @@
++virtio_balloon ?
++virtio_pci ?
++virtio_ring ?
++virtio-rng ?
++hv_vmbus ?
++hv_utils ?
++hv_netvsc ?
++hv_mouse ?
++hv_storvsc ?
+diff --git a/debian.master/d-i/modules/vlan-modules b/debian.master/d-i/modules/vlan-modules
+new file mode 100644
+index 0000000..3d65a55
+--- /dev/null
++++ b/debian.master/d-i/modules/vlan-modules
+@@ -0,0 +1,3 @@
++slp ?
++garp ?
++8021q ?
+diff --git a/debian.master/d-i/package-list b/debian.master/d-i/package-list
+new file mode 100644
+index 0000000..4079b08
+--- /dev/null
++++ b/debian.master/d-i/package-list
+@@ -0,0 +1,201 @@
++Package: kernel-image
++Provides: ext3-modules, ext4-modules
++Provides_amd64: efi-modules, ext3-modules, ext4-modules
++Provides_i386: efi-modules, ext3-modules, ext4-modules
++
++Package: fat-modules
++Depends: kernel-image
++Priority: standard
++Description: FAT filesystem support
++ This includes Windows FAT and VFAT support.
++
++Package: fb-modules
++Depends: kernel-image
++Priority: standard
++Description: Framebuffer modules
++
++Package: firewire-core-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: Firewire (IEEE-1394) Support
++
++Package: floppy-modules
++Depends: kernel-image
++Priority: standard
++Description: Floppy driver support
++
++Package: fs-core-modules
++Depends: kernel-image
++Priority: standard
++Provides: ext2-modules, jfs-modules, reiserfs-modules, xfs-modules
++Description: Base filesystem modules
++ This includes jfs, reiserfs and xfs.
++
++Package: fs-secondary-modules
++Depends: kernel-image, fat-modules
++Priority: standard
++Provides: btrfs-modules, ntfs-modules, hfs-modules
++Description: Extra filesystem modules
++ This includes support for Windows NTFS and MacOS HFS/HFSPlus
++
++Package: input-modules
++Depends: kernel-image, usb-modules
++Priority: standard
++Description: Support for various input methods
++
++Package: irda-modules
++Depends: kernel-image, nic-shared-modules
++Priority: standard
++Description: Support for Infrared protocols
++
++Package: md-modules
++Depends: kernel-image
++Priority: standard
++Provides: crypto-dm-modules
++Description: Multi-device support (raid, device-mapper, lvm)
++
++Package: nic-modules
++Depends: kernel-image, nic-shared-modules, virtio-modules
++Priority: standard
++Description: Network interface support
++
++Package: nic-pcmcia-modules
++Depends: kernel-image, nic-shared-modules, nic-modules
++Priority: standard
++Description: PCMCIA network interface support
++
++Package: nic-usb-modules
++Depends: kernel-image, nic-shared-modules, usb-modules
++Priority: standard
++Description: USB network interface support
++
++Package: nic-shared-modules
++Depends: kernel-image, crypto-modules
++Priority: standard
++Description: nic shared modules
++  This package contains modules which support nic modules
++
++Package: parport-modules
++Depends: kernel-image
++Priority: standard
++Description: Parallel port support
++
++Package: pata-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: PATA support modules
++
++Package: pcmcia-modules
++Depends: kernel-image
++Priority: standard
++Description: PCMCIA Modules
++
++Package: pcmcia-storage-modules
++Depends: kernel-image, scsi-modules
++Priority: standard
++Description: PCMCIA storage support
++
++Package: plip-modules
++Depends: kernel-image, nic-shared-modules, parport-modules
++Priority: standard
++Description: PLIP (parallel port) networking support
++
++Package: ppp-modules
++Depends: kernel-image, nic-shared-modules, serial-modules
++Priority: standard
++Description: PPP (serial port) networking support
++
++Package: sata-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: SATA storage support
++
++Package: scsi-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: SCSI storage support
++
++Package: serial-modules
++Depends: kernel-image
++Priority: standard
++Description: Serial port support
++
++Package: storage-core-modules
++Depends: kernel-image
++Priority: standard
++Provides: loop-modules
++Description: Core storage support
++ Includes core SCSI, LibATA, USB-Storage. Also includes related block
++ devices for CD, Disk and Tape medium (and IDE Floppy).
++
++Package: usb-modules
++Depends: kernel-image, storage-core-modules
++Priority: standard
++Description: Core USB support
++
++Package: nfs-modules
++Priority: standard
++Depends: kernel-image
++Description: NFS filesystem drivers
++ Includes the NFS client driver, and supporting modules.
++
++Package: block-modules
++Priority: standard
++Provides: nbd-modules
++Depends: kernel-image, storage-core-modules, parport-modules, virtio-modules
++Description: Block storage devices
++ This package contains the block storage devices, including DAC960 and
++ paraide.
++
++Package: message-modules
++Priority: standard
++Depends: kernel-image, storage-core-modules, scsi-modules
++Description: Fusion and i2o storage modules
++ This package containes the fusion and i2o storage modules.
++
++Package: crypto-modules
++Priority: extra
++Depends: kernel-image
++Description: crypto modules
++ This package contains crypto modules.
++
++Package: virtio-modules
++Priority: standard
++Depends: kernel-image
++Description: VirtIO Modules
++ Includes modules for VirtIO (virtual machine, generally kvm guests)
++
++Package: socket-modules
++Depends: kernel-image
++Priority: standard
++Description: Unix socket support
++
++Package: mouse-modules
++Depends: kernel-image, input-modules, usb-modules
++Priority: extra
++Description: Mouse support
++ This package contains mouse drivers for the Linux kernel.
++
++Package: squashfs-modules
++Depends: kernel-image
++Priority: extra
++Description: squashfs modules
++ This package contains squashfs modules.
++
++Package: vlan-modules
++Depends: kernel-image
++Priority: extra
++Description: vlan modules
++ This package contains vlan (8021.Q) modules.
++
++Package: ipmi-modules
++Depends: kernel-image
++Priority: standard
++Description: ipmi modules
++
++Package: multipath-modules
++Depends: kernel-image
++Priority: extra
++Description: DM-Multipath support
++  This package contains modules for device-mapper multipath support.
++
+diff --git a/debian.master/etc/getabis b/debian.master/etc/getabis
+new file mode 100644
+index 0000000..e6781b1
+--- /dev/null
++++ b/debian.master/etc/getabis
+@@ -0,0 +1,16 @@
++repo_list=(
++	"http://archive.ubuntu.com/ubuntu/pool/main/l/linux"
++	"http://ports.ubuntu.com/ubuntu-ports/pool/main/l/linux"
++	"http://archive.ubuntu.com/ubuntu/pool/universe/l/linux"
++	"http://ports.ubuntu.com/ubuntu-ports/pool/universe/l/linux"
++	"http://ppa.launchpad.net/canonical-kernel-team/ppa/ubuntu/pool/main/l/linux"
++)
++
++package_prefixes linux-image linux-image-extra
++
++getall armhf generic
++getall armhf generic-lpae
++getall amd64 generic
++getall i386 generic
++
++# Ports arches and flavours.
+diff --git a/debian.master/etc/kernelconfig b/debian.master/etc/kernelconfig
+new file mode 100644
+index 0000000..7fd9fc9
+--- /dev/null
++++ b/debian.master/etc/kernelconfig
+@@ -0,0 +1,7 @@
++if [ "$variant" = "ports" ]; then
++	archs=""
++	family='ports'
++else
++	archs="amd64 i386 armhf"
++	family='ubuntu'
++fi
+diff --git a/debian.master/rules.d/amd64.mk b/debian.master/rules.d/amd64.mk
+new file mode 100644
+index 0000000..0519998
+--- /dev/null
++++ b/debian.master/rules.d/amd64.mk
+@@ -0,0 +1,16 @@
++human_arch	= 64 bit x86
++build_arch	= x86_64
++header_arch	= $(build_arch)
++defconfig	= defconfig
++flavours	= generic
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++no_dumpfile	= true
++uefi_signed     = true
++do_tools_cpupower = true
++do_tools_perf   = true
++do_tools_x86	= true
++do_tools_hyperv	= true
++do_extras_package = true
+diff --git a/debian.master/rules.d/arm64.mk b/debian.master/rules.d/arm64.mk
+new file mode 100644
+index 0000000..5f9b0d69
+--- /dev/null
++++ b/debian.master/rules.d/arm64.mk
+@@ -0,0 +1,13 @@
++human_arch	= ARMv8
++build_arch	= arm64
++header_arch	= arm64
++defconfig	= defconfig
++flavours	= 
++build_image	= zImage
++kernel_file	= arch/$(build_arch)/boot/zImage
++install_file	= vmlinuz
++no_dumpfile = true
++
++loader		= grub
++do_tools	= false
++do_flavour_image_package = false
+diff --git a/debian.master/rules.d/armhf.mk b/debian.master/rules.d/armhf.mk
+new file mode 100644
+index 0000000..dd19b14
+--- /dev/null
++++ b/debian.master/rules.d/armhf.mk
+@@ -0,0 +1,31 @@
++human_arch	= ARM (hard float)
++build_arch	= arm
++header_arch	= arm
++defconfig	= defconfig
++flavours	= generic generic-lpae
++build_image	= zImage
++kernel_file	= arch/$(build_arch)/boot/zImage
++install_file	= vmlinuz
++no_dumpfile	= true
++
++loader		= grub
++do_tools	= true
++do_tools_cpupower = true
++do_tools_perf	= true
++gcc		= gcc-4.7
++
++# Flavour specific configuration.
++dtb_files_generic	+= highbank.dtb
++dtb_files_generic	+= imx6q-sabrelite.dtb
++dtb_files_generic	+= omap3-beagle-xm.dtb
++dtb_files_generic	+= omap4-panda.dtb
++dtb_files_generic	+= omap4-panda-es.dtb
++dtb_files_generic	+= tegra20-harmony.dtb
++dtb_files_generic	+= tegra20-paz00.dtb
++dtb_files_generic	+= tegra20-seaboard.dtb
++dtb_files_generic	+= tegra20-trimslice.dtb
++dtb_files_generic	+= tegra20-ventana.dtb
++dtb_files_generic	+= tegra20-whistler.dtb
++
++dtb_files_generic-lpae   += highbank.dtb
++dtb_files_generic-lpae	 += vexpress-v2p-ca15-tc1.dtb
+diff --git a/debian.master/rules.d/i386.mk b/debian.master/rules.d/i386.mk
+new file mode 100644
+index 0000000..23b86bf
+--- /dev/null
++++ b/debian.master/rules.d/i386.mk
+@@ -0,0 +1,15 @@
++human_arch	= 32 bit x86
++build_arch	= i386
++header_arch	= x86_64
++defconfig	= defconfig
++flavours        = generic
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++no_dumpfile	= true
++do_tools_common = true
++do_tools_cpupower = true
++do_tools_perf   = true
++do_tools_x86	= true
++do_extras_package = true
+diff --git a/debian.master/rules.d/powerpc.mk b/debian.master/rules.d/powerpc.mk
+new file mode 100644
+index 0000000..0fec80f
+--- /dev/null
++++ b/debian.master/rules.d/powerpc.mk
+@@ -0,0 +1,12 @@
++human_arch	= PowerPC
++build_arch	= powerpc
++header_arch	= $(build_arch)
++defconfig	= pmac32_defconfig
++flavours	=
++build_image	= vmlinux
++kernel_file	= $(build_image)
++install_file	= $(build_image)
++no_dumpfile	= true
++do_tools	= false
++loader		= yaboot
++do_flavour_image_package = false
+diff --git a/debian.master/rules.d/ppc64el.mk b/debian.master/rules.d/ppc64el.mk
+new file mode 100644
+index 0000000..b9a6ace
+--- /dev/null
++++ b/debian.master/rules.d/ppc64el.mk
+@@ -0,0 +1,13 @@
++human_arch	= PowerPC 64el
++build_arch	= powerpc
++header_arch	= $(build_arch)
++defconfig	= ppc64_defconfig
++flavours	=
++build_image	= vmlinux
++kernel_file	= $(build_image)
++install_file	= $(build_image)
++no_dumpfile	= true
++loader		= yaboot
++
++do_tools	= false
++do_flavour_image_package = false
+diff --git a/debian.master/rules.d/x32.mk b/debian.master/rules.d/x32.mk
+new file mode 100644
+index 0000000..b079c565
+--- /dev/null
++++ b/debian.master/rules.d/x32.mk
+@@ -0,0 +1,14 @@
++human_arch	= 64 bit x86 (32 bit userspace)
++build_arch	= x86_64
++header_arch	= $(build_arch)
++defconfig	= defconfig
++flavours	= 
++build_image	= bzImage
++kernel_file	= arch/$(build_arch)/boot/bzImage
++install_file	= vmlinuz
++loader		= grub
++no_dumpfile	= true
++uefi_signed     = true
++
++do_tools       = false
++do_flavour_image_package = false
+diff --git a/debian/commit-templates/bumpabi b/debian/commit-templates/bumpabi
+new file mode 100644
+index 0000000..6c373c9
+--- /dev/null
++++ b/debian/commit-templates/bumpabi
+@@ -0,0 +1,3 @@
++UBUNTU: Bump ABI
++
++Ignore: yes
+diff --git a/debian/commit-templates/config-updates b/debian/commit-templates/config-updates
+new file mode 100644
+index 0000000..4b62c29
+--- /dev/null
++++ b/debian/commit-templates/config-updates
+@@ -0,0 +1,15 @@
++#
++# This template is used for commit messages that don't need to
++# show up in debian/changelog. Administrative stuff like config
++# updates, ABI bumps, etc. Setting 'Ignore: yes' prevents
++# 'debian/rules insertchanges' from inserting this commit meesage
++# as a changelog entry.
++#
++# Please give a one-line description of the config change followed
++# by a detailed explanation if necessary
++
++UBUNTU: [Config] XXXX
++
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/commit-templates/external-driver b/debian/commit-templates/external-driver
+new file mode 100644
+index 0000000..decdc89
+--- /dev/null
++++ b/debian/commit-templates/external-driver
+@@ -0,0 +1,20 @@
++# Ubuntu external driver commit.
++#
++# NOTE: This gets reformatted for README.Ubuntu-External-Drivers and
++# debian/changelog.
++#
++# This is only needed when a driver is added, updated or removed. It is
++# not needed when patches or fixes are applied to the driver. If the
++# driver is being removed, add the line:
++#
++# Removing: yes
++#
++# to the commit, and you can remove all other tags (except UBUNTU:).
++#
++UBUNTU: 
++
++ExternalDriver: 
++Description:
++Url:
++Mask:
++Version:
+diff --git a/debian/commit-templates/missing-modules b/debian/commit-templates/missing-modules
+new file mode 100644
+index 0000000..f4872e7
+--- /dev/null
++++ b/debian/commit-templates/missing-modules
+@@ -0,0 +1,3 @@
++UBUNTU: build/modules: Add modules that have intentionally gone missing
++
++Ignore: yes
+diff --git a/debian/commit-templates/newrelease b/debian/commit-templates/newrelease
+new file mode 100644
+index 0000000..5f8931c
+--- /dev/null
++++ b/debian/commit-templates/newrelease
+@@ -0,0 +1,3 @@
++UBUNTU: Start new release
++
++Ignore: yes
+diff --git a/debian/commit-templates/sauce-patch b/debian/commit-templates/sauce-patch
+new file mode 100644
+index 0000000..08720a8
+--- /dev/null
++++ b/debian/commit-templates/sauce-patch
+@@ -0,0 +1,40 @@
++# Ubuntu commit template.
++#
++# NOTE: This gets reformatted for debian/changelog
++#
++#
++# SAUCE refers to the fact that this patch might not go upstream, but we need to
++# carry it to successive releases. In most cases you DONOT want to use this
++# template. 
++#
++# An example of a SAUCE patch is the ACPI DSDT-in-initramfs patch which has been
++# refused upstream, but still provides useful functionality to users with broken
++# BIOSes.
++#
++#-------------------------------------------------------------------------
++#
++# The initial UBUNTU is a flag that this is an Ubuntu commit. It will be
++# referenced to the Author in the debian/changelog entry.
++#
++# The text following is the short message that will be placed in the
++# changelog. Extra text on the following lines will be ignored, but left
++# in the git commit. Lines with # will be ignored in the commit.
++#
++# OriginalAuthor allows for alternate attribution.
++#
++# OriginalLocation allows for a URL or description of where the patch came
++# from.
++#
++# BugLink is a URL to a Malone bug.
++#
++# Ignore: yes will keep this commit from showing up in the changelog.
++#
++UBUNTU: SAUCE: 
++
++<Why is this patch not going upstream?>
++
++# OriginalAuthor: 
++# OriginalLocation: 
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/commit-templates/upstream-patch b/debian/commit-templates/upstream-patch
+new file mode 100644
+index 0000000..671ab6a
+--- /dev/null
++++ b/debian/commit-templates/upstream-patch
+@@ -0,0 +1,27 @@
++# Ubuntu commit template.
++#
++# NOTE: This gets reformatted for debian/changelog
++#
++# The initial UBUNTU is a flag that this is an Ubuntu commit. It will be
++# referenced to the Author in the debian/changelog entry.
++#
++# The text following is the short message that will be placed in the
++# changelog. Extra text on the following lines will be ignored, but left
++# in the git commit. Lines with # will be ignored in the commit.
++#
++# OriginalAuthor allows for alternate attribution.
++#
++# OriginalLocation allows for a URL or description of where the patch came
++# from.
++#
++# BugLink is a URL to a Malone bug.
++#
++# Ignore: yes will keep this commit from showing up in the changelog.
++#
++UBUNTU: [Upstream]
++
++# OriginalAuthor: 
++# OriginalLocation: 
++# BugLink: http://bugs.launchpad.net/bugs/<enter bug# here>
++# Ignore: yes
++# Other text below here.
+diff --git a/debian/compat b/debian/compat
+new file mode 100644
+index 0000000..7ed6ff8
+--- /dev/null
++++ b/debian/compat
+@@ -0,0 +1 @@
++5
+diff --git a/debian/control-scripts/headers-postinst b/debian/control-scripts/headers-postinst
+new file mode 100644
+index 0000000..2fb2be8
+--- /dev/null
++++ b/debian/control-scripts/headers-postinst
+@@ -0,0 +1,126 @@
++#!/usr/bin/perl
++#                              -*- Mode: Cperl -*- 
++# debian.postinst ---
++# Author           : Manoj Srivastava ( srivasta@pilgrim.umass.edu )
++# Created On       : Sat Apr 27 05:42:43 1996
++# Created On Node  : melkor.pilgrim.umass.edu
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sat Aug  5 13:20:22 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 45
++# Status           : Unknown, Use with caution!
++# HISTORY          :
++# Description      :
++#
++#
++#
++#  arch-tag: 1c716174-2f0a-476d-a626-a1322e62503a
++#
++
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $kimage            = "=K";
++my $package_name    = "linux-image-$version";
++
++
++# Ignore all invocations uxcept when called on to configure.
++exit 0 unless ($ARGV[0] && $ARGV[0] =~ /configure/);
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/boot/";
++my $silent_modules  = '';
++my $modules_base    = '/lib/modules';
++my $CONF_LOC        = '/etc/kernel-img.conf';
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++chdir '/usr/src' or die "Could not chdir to /usr/src:$!";
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $header_postinst_hook   = "$1"  if /^\s*header_postinst_hook\s*=\s*(\S+)/ig;
++    }
++    close CONF;
++  }
++}
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++## Run user hook script here, if any
++if (-x "$header_postinst_hook") {
++  &run_hook("postinst", $header_postinst_hook);
++}
++
++if (-d "/etc/kernel/header_postinst.d") {
++  print STDERR "Examining /etc/kernel/header_postinst.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/header_postinst.d") &&
++            die "Failed to process /etc/kernel/header_postinst.d";
++}
++
++if (-d "/etc/kernel/header_postinst.d/$version") {
++  print STDERR "Examining /etc/kernel/header_postinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/header_postinst.d/$version") &&
++            die "Failed to process /etc/kernel/header_postinst.d/$version";
++}
++
++exit 0;
++
++__END__
+diff --git a/debian/control-scripts/postinst b/debian/control-scripts/postinst
+new file mode 100644
+index 0000000..b6ed9f8
+--- /dev/null
++++ b/debian/control-scripts/postinst
+@@ -0,0 +1,1095 @@
++#! /usr/bin/perl
++# OriginalAuthor : Manoj Srivastava ( srivasta@pilgrim.umass.edu )
++#
++# Customized for Ubuntu by: Ben Collins <bcollins@ubuntu.com>
++
++#use strict; #for debugging
++use Cwd 'abs_path';
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $link_in_boot      = "";  # Should be empty, mostly
++my $no_symlink        = "";   # Should be empty, mostly
++my $reverse_symlink   = "";   # Should be empty, mostly
++my $do_symlink        = "Yes";  # target machine defined
++my $do_boot_enable    = "Yes";  # target machine defined
++my $do_bootfloppy     = "Yes";  # target machine defined
++my $do_bootloader     = "Yes";  # target machine defined
++my $move_image        = '';     # target machine defined
++my $kimage            = "=K";   # Should be empty, mostly
++my $loader            = "=L"; # lilo, silo, quik, palo, vmelilo, nettrom, arcboot or delo
++my $image_dir         = "/boot";        # where the image is located
++my $clobber_modules   = '';          # target machine defined
++my $relative_links    = "";          # target machine defined
++my $initrd            = "YES";        # initrd kernel
++my $do_initrd         = '';     # Normally we do not
++my $use_hard_links    = ''; # hardlinks do not work across fs boundaries
++my $postinst_hook     = '';          #Normally we do not
++my $postrm_hook       = '';          #Normally we do not
++my $preinst_hook      = '';          #Normally we do not
++my $prerm_hook        = '';          #Normally we do not
++my $minimal_swap      = '';          # Do not swap symlinks
++my $ignore_depmod_err = '';          # normally we do not
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";  # List of tools to create initial ram fs.
++my $notifier          = "/usr/share/update-notifier/notify-reboot-required";
++my $package_name      = "linux-image-$version";
++my $explicit_do_loader = 'Yes';
++
++my $Loader          = "NoLOADER"; #
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++$Loader             = "ARCBOOT"  if $loader =~ /^arcboot/io;
++$Loader             = "DELO"     if $loader =~ /^delo/io;
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $silent_modules  = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++my $modules_base    = '/lib/modules';
++my $CONF_LOC        = '/etc/kernel-img.conf';
++
++# Ignore all invocations except when called on to configure.
++exit 0 unless $ARGV[0] =~ /configure/;
++
++my $DEBUG = 0;
++
++# Do some preliminary sanity checks here to ensure we actually have an
++# valid image dir
++chdir('/')           or die "could not chdir to /:$!\n";
++die "Internal Error: ($image_dir) is not a directory!\n"
++  unless -d $image_dir;
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++die "Internal Error: ($realimageloc) is not a directory!\n"
++  unless -d $realimageloc;
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlink\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $explicit_do_loader = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_modules  = '' if /^\s*silent_modules\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $explicit_do_loader = "YES" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_modules  = 'Yes' if /^\s*silent_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++
++
++# For some versions of kernel-package, we had this warning in the
++# postinst, but the rules did not really interpolate the value in.
++# Here is a sanity check.
++my $pattern = "=" . "I";
++$initrd=~ s/^$pattern$//;
++
++if ($link_in_boot) {
++  $image_dest = "/$image_dir/"; # same as realimageloc
++}
++
++# Tack on at least one trainling /
++$image_dest = "$image_dest/";
++$image_dest =~ s|^/*|/|o;
++$image_dest =~ s|/+$|/|o;
++
++if (! -d "$image_dest") {
++  die "Expected Image Destination dir ($image_dest) to be a valid directory!\n";
++}
++
++# sanity
++if (!($do_bootfloppy || $do_bootloader)) {
++  $do_boot_enable = '';
++}
++if ($do_symlink && $no_symlink) {
++  warn "Both do_symlinks and no_symlinks options enabled; disabling no_symlinks\n";
++  $no_symlink = 0;
++}
++
++# most of our work is done in $image_dest (nominally /)
++chdir("$image_dest") or die "could not chdir to $image_dest:$!\n";
++
++# Paranoid check to make sure that the correct value is put in there
++if    (! $kimage)                 { $kimage = "vmlinuz"; } # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) { $kimage = "vmlinuz"; } # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) { $kimage = "vmlinuz"; } # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;   }
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;   }
++else                              { $kimage = "vmlinuz"; } # Default
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++
++die "Internal Error: Could not find image (" . $realimageloc
++  . "$kimage-$version)\n" unless -e $realimageloc
++  . "$kimage-$version";
++
++# search for the boot loader in the path
++my $loader_exec;
++($loader_exec = $loader)  =~ s|.*/||;
++my ($loaderloc) = grep -x, map "$_/$loader_exec",
++  map { length($_) ? $_ : "." }  split /:/, $ENV{PATH};
++
++
++######################################################################
++######################################################################
++###########        Test whether a relative symlinkwould be OK #######
++######################################################################
++######################################################################
++sub test_relative {
++  my %params = @_;
++  my $cwd;
++
++  die "Internal Error: Missing Required paramater 'Old Dir' "
++    unless $params{'Old Dir'};
++  die "Internal Error: Missing Required paramater New Dir' "
++    unless $params{'New Dir'};
++
++
++  die "Internal Error: No such dir $params{'Old Dir'} "
++    unless -d $params{'Old Dir'};
++  die "Internal Error: No such dir $params{'New Dir'} "
++    unless -d $params{'New Dir'};
++
++  warn "Test relative: testing $params{'Old Dir'} -> $params{'New Dir'}"
++    if $DEBUG;
++  chomp($cwd = `pwd`);
++  chdir ($params{'New Dir'}) or die "Could not chdir to $params{'New Dir'}:$!";
++  my $ok = 0;
++  $params{'Old Dir'}  =~ s|^/*||o;
++  if (-d $params{'Old Dir'} ) {
++    if (defined $params{'Test File'}) {
++      if (-e $params{'Old Dir'} . $params{'Test File'}) {
++        $ok  = 1;
++      }
++    } else {
++      $ok = 1;                  # well, backward compatibility
++    }
++  }
++  chdir ($cwd) or die "Could not chdir to $params{'New Dir'}:$!";
++  return $ok;
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++# sub CanonicalizePath {
++#   my $path = join '/', @_;
++#   my @work = split '/', $path;
++#   my @out;
++#   my $is_absolute;
++
++#   if (@work && $work[0] eq "") {
++#     $is_absolute = 1; shift @work;
++#   }
++
++#   while (@work) {
++#     my $seg = shift @work;
++#     if ($seg eq "." || $seg eq "") {
++#     } 
++#     elsif ($seg eq "..") {
++#       if (@out && $out[-1] ne "..") {
++#         pop @out;
++#       } 
++#       else {
++#         # Leading "..", or "../..", etc.
++#         push @out, $seg;
++#       }
++#     } 
++#     else {
++#       push @out, $seg;
++#     }
++#   }
++
++#   unshift @out, "" if $is_absolute;
++#   return join('/', @out);
++# }
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++
++sub spath {
++  my %params = @_;
++
++  die "Missing Required paramater 'Old'" unless $params{'Old'};
++  die "Missing Required paramater 'New'" unless  $params{'New'};
++
++  my @olddir  = split '/', `readlink -q -m $params{'Old'}`;
++  my @newdir  = split '/', `readlink -q -m $params{'New'}`;
++  my @outdir  = @olddir;
++
++  my $out = '';
++  my $i;
++  for ($i = 0; $i <= $#olddir && $i <= $#newdir; $i++) {
++    $out++ if ($olddir[$i] ne $newdir[$i]);
++    shift @outdir unless $out;
++    unshift @outdir, ".." if $out;
++  }
++  if ($#newdir > $#olddir) {
++    for ($i=0; $i < $#newdir; $i++) {
++      unshift @outdir, "..";
++    }
++  }
++  return join ('/', @outdir);
++}
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++
++
++# This routine actually moves the kernel image
++# From: $realimageloc/$kimage-$version (/boot/vmlinuz-2.6.12)
++# To:   $image_dest/$kimage-$version   (/vmlinuz-2.6.12)
++# Note that the image is moved to a versioned destination, but ordinary
++# symlinks we create otherwise are not normally versioned
++sub really_move_image {
++  my $src_dir  = $_[0];
++  my $target   = $_[1];
++  my $dest_dir = $_[2];
++
++  warn "Really move image: src_dir=$src_dir, target=$target,\n destdir=$dest_dir"
++    if $DEBUG;
++  if (-e "$target") {
++    # we should be in dir $dest_dir == $image_dest /, normally
++    rename("$target", "$target.$$") ||
++      die "failed to move " . $dest_dir . "$target:$!";
++    warn "mv $target $target.$$" if $DEBUG;
++  }
++  warn "mv -f $src_dir$target $target" if $DEBUG;
++  my $ret = system("mv -f " . $src_dir . "$target " .
++                   " $target");
++  if ($ret) {
++    die("Failed to move " . $src_dir . "$target to "
++        . $dest_dir . "$target");
++  }
++  # Ok, now we may clobber the previous .old files
++  if (-e "$target.$$") {
++    rename("$target.$$", "$target.old") ||
++      die "failed to move " . $dest_dir . "$target:$!";
++    warn "mv $target.$$ $target " if $DEBUG;
++  }
++}
++
++# Normally called after really_move_image; and only called if we asked for 
++# reversed link this routine reverses the symbolic link that is notmally 
++# created. Since the real kernel image has been moved over to 
++# $image_dest/$kimage-$version. So, this routine links
++# From:   $image_dest/$kimage-$version   (/vmlinuz-2.6.12)
++# To:     $realimageloc/$kimage-$version (/boot/vmlinuz-2.6.12)
++sub really_reverse_link {
++  my $src_dir    = $_[0];
++  my $link_name  = $_[1];
++  my $dest_dir   = $_[2];
++  warn "Really reverse link: src_dir=$src_dir, link name=$link_name\n" .
++    "\tdestdir=$dest_dir" if $DEBUG;
++
++  my $Old = $dest_dir;
++  if (test_relative ('Old Dir' => $Old, 'New Dir' => $src_dir,
++                     'Test File' => "$link_name")) {
++    $Old   =~ s|^/*||o;
++  }
++  # Special case is they are in the same dir
++  my $rel_path = spath('Old' => "$Old", 'New' => "$src_dir" );
++  $Old ="" if $rel_path =~ m/^\s*$/o;
++
++  if ($use_hard_links =~ m/YES/i) {
++    link($Old . "$link_name", $src_dir . "$link_name") ||
++      die("Failed to link " . $dest_dir . "$link_name to " . $src_dir . 
++          "$link_name:$!");
++    warn "ln " . $Old . "$link_name " . $src_dir . "$link_name"  if $DEBUG;
++  }
++  else {
++    symlink($Old . "$link_name", $src_dir . "$link_name") ||
++      die("Failed to symbolic-link " . $dest_dir . "$link_name to " . $src_dir
++          . "$link_name:$!");
++    warn "ln -s " . $Old . "$link_name " . $src_dir . "$link_name" if $DEBUG;
++  }
++}
++
++# This routine is invoked if there is a symbolic link in place
++# in $image_dest/$kimage -- so a symlink exists in the destination.
++# What we are trying to determine is if we need to move the symbolic link over
++# to the the .old location
++sub move_p {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  my $force_move = 0;
++  warn "Move?: kimage=$kimage, image_dest=$image_dest, \n" .
++    "\timage_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  if ($no_symlink || $reverse_symlink) {
++    # we do not want links, yet we have a symbolic link here!
++    warn "found a symbolic link in " . $image_dest . "$kimage \n" .
++      "even though no_symlink is defined\n" if $no_symlink;
++    warn "found a symbolic link in " . $image_dest . "$kimage \n" .
++      "even though reverse_symlink is defined\n" if $reverse_symlink;
++    # make sure we change this state of affairs
++    $force_move = 1;
++    return $force_move;
++  }
++
++  warn "DEBUG: OK. We found symlink, and we should have a symlink here.\n"
++    if $DEBUG;
++  my $vmlinuz_target = readlink "$kimage";
++  my $real_target = '';
++  my $target = `readlink -q -m "${realimageloc}${kimage-$version}"`;
++  $real_target = abs_path($vmlinuz_target) if defined($vmlinuz_target);
++
++  if (!defined($vmlinuz_target) || ! -f "$real_target") {
++    # what, a dangling symlink?
++    warn "The link "  . $image_dest . "$kimage is a dangling link" .
++      "to $real_target\n";
++    $force_move = 1;
++    return $force_move;
++  }
++
++
++  warn "DEBUG: The link $kimage points to ($vmlinuz_target)\n" if $DEBUG;
++  warn "DEBUG: ($vmlinuz_target) is really ($real_target)\n" if $DEBUG;
++  my $cwd;
++  chomp ($cwd=`pwd`);
++  if ($vmlinuz_target !~ m|^/|o) {
++    $vmlinuz_target = $cwd . "/" . $vmlinuz_target;
++    $vmlinuz_target =~ s|/+|/|o;
++  }
++  $vmlinuz_target = `readlink -q -m $vmlinuz_target`;
++
++  if ("$vmlinuz_target" ne "$target") {
++    warn "DEBUG: We need to handle this.\n" if $DEBUG;
++    if ($minimal_swap) {
++      warn "DEBUG: Minimal swap.\n" if $DEBUG;
++      if (-l "$kimage.old") {
++        warn "DEBUG: There is an old link at $kimage.old\n" if $DEBUG;
++        my $old_target = readlink "$kimage.old";
++        my $real_old_target = '';
++        $real_old_target=abs_path($old_target) if defined ($old_target);
++
++        if ($real_old_target  && -f "$real_old_target") {
++          if ($old_target !~ m|^/|o) {
++            $old_target = $cwd . "/" . $old_target;
++            $old_target =~ s|/+|/|o;
++          }
++          $old_target = `readlink -q -m $old_target`;
++          if ("$old_target"  ne "$target") {
++            $force_move = 1;
++            warn "DEBUG: Old link ($old_target) does not point to us ($target)\n"
++              if $DEBUG;
++          } 
++          else {            # The .old points to the current
++            warn "$kimage.old --> $target -- doing nothing";
++            $force_move = 0;
++          }
++        } 
++        else { 
++          warn "DEBUG: Well, the old link does not exist -- so we move\n"
++            if $DEBUG;
++          $force_move = 1;
++        }
++      } 
++      else {
++        warn "DEBUG: No .old link -- OK to move\n"
++          if $DEBUG;
++        $force_move = 1;
++      }
++    } 
++    else {
++      warn "DEBUG: ok, minimal swap is no-- so we move.\n"
++        if $DEBUG;
++      $force_move = 1;
++    }
++  }
++  else {                  # already have proper link
++    warn "$kimage($vmlinuz_target) points to $target ($real_target) -- doing nothing";
++    $force_move = 0;
++  }
++  return $force_move;
++}
++
++
++# This routine moves the symbolic link around (/vmlinuz -> /vmlinuz.old)
++# It pays attention to whether we should the fact whether we should be using
++# hard links or not.
++sub really_move_link {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "really_move_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # don't clobber $kimage.old quite yet
++  rename("$kimage", "$kimage.$$") ||
++    die "failed to move " . $image_dest . "$kimage:$!";
++  warn "mv $kimage $kimage.$$" if $DEBUG;
++  my $Old = $src_dir;
++  my $cwd;
++
++  chomp($cwd=`pwd`);
++  if (test_relative ('Old Dir' => $Old, 'New Dir' => $cwd,
++                     'Test File' => "$image_name")) {
++    $Old   =~ s|^/*||o;
++  }
++  # Special case is they are in the same dir
++  my $rel_path = spath('Old' => "$Old", 'New' => "$cwd" );
++  $Old ="" if $rel_path =~ m/^\s*$/o;
++
++  if ($use_hard_links =~ m/YES/i) {
++    warn "ln ${Old}${image_name} $kimage" if $DEBUG;
++    if (! link("${Old}${image_name}", "$kimage")) {
++      rename("$kimage.$$", "$kimage");
++      die("Failed to link ${Old}${image_name} to " .
++          "${image_dest}${kimage}:$!");
++    }
++  } 
++  else {
++    warn "ln -s ${Old}${image_name} $kimage" if $DEBUG;
++    if (! symlink("${Old}${image_name}", "$kimage")) {
++      rename("$kimage.$$", "$kimage");
++      die("Failed to symbolic-link ${Old}${image_name} to " .
++          "${image_dest}${kimage}:$!");
++    }
++  }
++
++  # Ok, now we may clobber the previous .old file
++  if (-l "$kimage.old" || ! -e "$kimage.old" ) {
++    rename("$kimage.$$", "$kimage.old");
++    warn "mv $kimage.$$ $kimage.old" if $DEBUG;
++  }
++  else {
++    warn "$kimage.old is not a symlink, not clobbering\n";
++    warn "rm $kimage.$$";
++    unlink "$kimage.$$" if $DEBUG;
++  }
++}
++
++# This routine handles a request to do symlinks, but there is no
++# symlink file already there.  Either we are supposed to use copy, or we are
++# installing on a pristine system, or the user does not want symbolic links at
++# all.  We use a configuration file to tell the last two cases apart, creating
++# a config file if needed.
++sub handle_missing_link {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "handle_missing_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  if ($no_symlink) {
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc .
++                     "$image_name "   . " $kimage");
++    if ($ret) {
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  } 
++  elsif ($reverse_symlink) {
++    warn "mv -f $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("mv -f " . $realimageloc . "$image_name "
++                     . "$kimage");
++    if ($ret) {
++      die("Failed to move " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  } 
++  else {
++    if (! $have_conffile) {
++      my $ret;
++      my $answer='';
++      $do_symlink = "Yes";
++
++      if (open(CONF, ">$CONF_LOC")) {
++        print CONF "# Kernel Image management overrides\n";
++        print CONF "# See kernel-img.conf(5) for details\n";
++        if ($loader =~ /palo/i) {
++          print CONF "link_in_boot = Yes\n";
++          print CONF "do_symlinks = Yes\n";
++          print CONF "relative_links = Yes\n";
++          print CONF "do_bootloader = No\n";
++        } else {
++          print CONF "do_symlinks = $do_symlink\n";
++        }
++        close CONF;
++      }
++      $have_conffile = "Yes";
++    }
++  }
++
++  if (! $no_symlink && $do_symlink =~ /Yes/i) {
++    my $Old = $realimageloc;
++    my $New = $image_dest;
++    my $Name = "$image_name";
++    my $Link_Dest = "$kimage";
++
++    if ($reverse_symlink) {
++      $Old = $image_dest;
++      $New = $realimageloc;
++      $Name = "$kimage";
++      $Link_Dest = $realimageloc . "$image_name";
++    }
++    if (test_relative ('Old Dir' => $Old,
++                       'New Dir' => $New,
++                       'Test File' => $Name)) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$New" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    symlink($Old . "$Name", "$Link_Dest") ||
++      die("Failed to symbolic-link ${Old}$Name to $Link_Dest:$!");
++    warn "ln -s ${Old}$Name $Link_Dest" if $DEBUG;
++
++  }
++}
++
++# This routine handles the rest of the cases, where the user has requested 
++# non-traditional handling, like using cp, or reverse symlinks, or hard links.
++sub handle_non_symlinks {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = $_[2]; 
++  my $src_dir    = $_[3]; 
++  warn "handle_non_link: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # Save the current image. We do this in all four cases
++  rename("$kimage", "$kimage.$$") || 
++    die "failed to move " . $image_dest . "$kimage:$!";
++  warn "mv $kimage $kimage.$$" if $DEBUG;
++
++  ##,#### 
++  # case One
++  #`####
++  if ($no_symlink) {
++    # Maybe /$image_dest is on a dos system?
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc
++                     . "$image_name " . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        rename("$kimage.$$", "$kimage");
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++      }
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  ##,#### 
++  # case Two
++  #`####
++  elsif ($reverse_symlink) {  # Maybe /$image_dest is on a dos system?
++    warn "mv -f  $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("mv -f " . $realimageloc . "$image_name "
++                     . $image_dest . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        rename("$kimage.$$", "$kimage");
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++      }
++      die("Failed to move " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++    my $Old = $image_dest;
++    if (test_relative ('Old Dir' => $Old, 'New Dir' => $realimageloc,
++                       'Test File' => "$kimage")) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$realimageloc" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    if ($use_hard_links =~ m/YES/i) {
++      warn "ln " . $Old . "$kimage " . $realimageloc . "$image_name" if $DEBUG;
++      if (! link($Old . "$kimage", $realimageloc . "$image_name")) {
++        warn "Could not link " . $image_dest .
++          "$kimage to $image_name :$!";
++      }
++    }
++    else {
++      warn "ln -s " . $Old . "$kimage " . $realimageloc . "$image_name" if $DEBUG;
++      if (! symlink($Old . "$kimage", $realimageloc . "$image_name")) {
++        warn "Could not symlink " . $image_dest .
++          "$kimage to $image_name :$!";
++      }
++    }
++  }
++  ##,####
++  # case Three
++  #`####
++  elsif ($use_hard_links =~ m/YES/i ) {
++    # Ok then. this ought to be a hard link, and hence fair game
++    # don't clobber $kimage.old quite yet
++    my $Old = $realimageloc;
++    my $cwd;
++    chomp($cwd=`pwd`);
++    if (test_relative ('Old Dir' => $Old, 'New Dir' => $cwd,
++                       'Test File' => "$image_name")) {
++      $Old   =~ s|^/*||o;
++    }
++    # Special case is they are in the same dir
++    my $rel_path = spath('Old' => "$Old", 'New' => "$cwd" );
++    $Old ="" if $rel_path =~ m/^\s*$/o;
++
++    warn "ln " . $Old . "$image_name " . "$kimage" if $DEBUG;
++    if (! link($Old . "$image_name", "$kimage")) {
++      warn "mv $kimage.$$ $kimage" if $DEBUG;
++      rename("$kimage.$$", "$kimage");
++      die("Failed to link " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  ##,####
++  # case Four
++  #`####
++  else {
++    # We just use cp
++    warn "cp -a --backup=t $realimageloc$image_name $kimage" if $DEBUG;
++    my $ret = system("cp -a --backup=t " . $realimageloc
++                     . "$image_name " . "$kimage");
++    if ($ret) {
++      if (-e "$kimage.$$") {
++        warn "mv $kimage.$$ $kimage" if $DEBUG;
++        rename("$kimage.$$", "$kimage");
++      }
++      die("Failed to copy " . $realimageloc . "$image_name to "
++          . $image_dest . "$kimage");
++    }
++  }
++  # Ok, now we may clobber the previous .old file
++  warn "mv $kimage.$$ $kimage.old if -e $kimage.$$" if $DEBUG;
++  rename("$kimage.$$", "$kimage.old") if -e "$kimage.$$";
++}
++
++# This routine is responsible for setting up the symbolic links
++# So, the actual kernel image lives in
++# $realimageloc/$image_name (/boot/vmlinuz-2.6.12).
++# This routine creates symbolic links in $image_dest/$kimage (/vmlinuz)
++sub image_magic {
++  my $kimage     = $_[0];       # Name of the symbolic link
++  my $image_dest = $_[1];       # The directory the links goes into
++  my $image_name = "$kimage-$version";
++  my $src_dir    = $realimageloc;
++  warn "image_magic: kimage=$kimage, image_dest=$image_dest\n" .
++    "\t image_name=$image_name, src_dir=$src_dir" if $DEBUG;
++
++  # Well, in any case, if the destination (the symlink we are trying
++  # to create) is a directory, we should do nothing, except throw a
++  # diagnostic.
++  if (-d "$kimage" ) {
++    die ("Hmm. $kimage is a directory, which I did not expect.  I am\n" .
++         "trying to create a symbolic link with that name linked to \n" .
++         "$image_dest . Since a directory exists here, my assumptions \n" .
++         "are way off, and I am aborting.\n" );
++    exit (3);
++  }
++
++  if ($move_image) {   # Maybe $image_dest is in on dos, or something?
++    #                   source dir,    link name,        dest dir
++    really_move_image(  $realimageloc, $image_name, $image_dest);
++    really_reverse_link($realimageloc, $image_name, $image_dest)
++      if $reverse_symlink;
++    return;
++  }
++
++  if (-l "$kimage") {           # There is a symbolic link
++    warn "DEBUG: There is a symlink for $kimage\n" if $DEBUG;
++    my $force_move = move_p($kimage, $image_dest, $image_name, $src_dir);
++
++    if ($force_move) {
++      really_move_link($kimage, $image_dest, $image_name, $src_dir);
++    }
++  }
++  elsif (! -e "$kimage") {
++    # Hmm. Pristine system? How can that be? Installing from scratch?
++    # Or maybe the user does not want a symbolic link here.
++    # Possibly they do not want a link here. (we should be in /
++    # here[$image_dest, really]
++    handle_missing_link($kimage, $image_dest, $image_name, $src_dir);
++  }
++  elsif (-e "$kimage" ) {
++    # OK, $kimage exists -- but is not a link
++    handle_non_symlinks($kimage, $image_dest, $image_name, $src_dir);
++  }
++}
++
++######################################################################
++######################################################################
++######################################################################
++######################################################################
++
++# We may not have any modules installed
++if ( -d "$modules_base/$version" ) {
++  print STDERR "Running depmod.\n";
++  my $ret = system("depmod -a $version");
++  if ($ret) {
++    print STDERR "Failed to run depmod\n";
++    exit(1);
++  }
++}
++
++
++
++sub find_initrd_tool {
++  my $hostversion = shift;
++  my $version = shift;
++  print STDERR "Finding valid ramdisk creators.\n";
++  my @ramdisks =
++    grep {
++      my $args = 
++        "$_ " .
++          "--supported-host-version=$hostversion " .
++            "--supported-target-version=$version " .
++              "1>/dev/null 2>&1"
++                ;
++      system($args) == 0;
++    }
++      split (/[:,\s]+/, $ramdisk);
++}
++
++# The initrd symlink should probably be in the same dir that the
++# symlinks are in
++if ($initrd) {
++  my $success = 0;
++
++  # Update-initramfs is called slightly different than mkinitrd and
++  # mkinitramfs. XXX It should really be made compatible with this stuff
++  # some how.
++  my $upgrading = 1;
++  if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++    $upgrading = 0;
++  }
++  my $ret = system("$ramdisk " . ($upgrading ? "-u" : "-c") . " -k " . $version . " >&2");
++  $success = 1 unless $ret;
++  die "Failed to create initrd image.\n" unless $success;
++  if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++    image_magic("initrd.img", $image_dest);
++  }
++  else {
++    if (! -e "initrd.img") {
++      handle_missing_link("initrd.img", $image_dest, "initrd.img-$version",
++                          $realimageloc);
++    }
++    else {
++      print STDERR
++        "Not updating initrd symbolic links since we are being updated/reinstalled \n";
++      print STDERR
++        "($ARGV[1] was configured last, according to dpkg)\n";
++    }
++  }
++
++  if ($initrd && -l "initrd" ) {
++    unlink "initrd";
++  }
++
++  if ($initrd && -l "$image_dir/initrd" && ! $link_in_boot) {
++    unlink "$image_dir/initrd";
++  }
++}
++else {                        # Not making an initrd emage
++  if (-l "initrd.img") {
++    # Ooh, last image was an initrd image? in any case, we should move it. 
++    my $target = readlink "initrd.img";
++    my $real_target = '';
++    $real_target = abs_path($target) if defined ($target);
++
++    if (!defined($target) || ! -f "$real_target") {
++      # Eh. dangling link. can safely be removed.
++      unlink("initrd.img");
++    } else {
++      if (-l "initrd.img.old" || ! -e "initrd.img.old" ) {
++        rename("initrd.img", "initrd.img.old");
++      } else {
++        warn "initrd.img.old is not a symlink, not clobbering\n";
++        unlink("initrd.img");
++      }
++    }
++  }
++}
++
++# Warn of a reboot
++if (-x $notifier) {
++  system($notifier);
++}
++
++# Let programs know not to hibernate if the kernel that would be used for
++# resume-from-hibernate is likely to differ from the currently running kernel.
++system("mountpoint -q /var/run");
++if ($? eq 0) {
++	system("touch /var/run/do-not-hibernate");
++}
++
++# Only change the symlinks if we are not being upgraded
++if (! defined $ARGV[1] || ! $ARGV[1] || $ARGV[1] =~ m/<unknown>/og) {
++  image_magic($kimage, $image_dest);
++}
++else {
++  if (! -e "$kimage") {
++    handle_missing_link($kimage, $image_dest, "$kimage-$version", 
++                        $realimageloc);
++  }
++  else {
++    print STDERR
++      "Not updating image symbolic links since we are being updated/reinstalled \n";
++    print STDERR
++      "($ARGV[1] was configured last, according to dpkg)\n";
++  }
++}
++
++# We used to have System.* files in /
++if (-e "/System.map" || -e "/System.old") {
++  unlink '/System.map' if -e '/System.map';
++  unlink '/System.old' if -e '/System.old';
++}
++
++# creating some info about kernel and initrd
++if ($DEBUG) {
++  my $ksize=sprintf("%.0f",(stat($realimageloc .
++                                 "$kimage-$version"))[7]/1024)."kB";
++  my $initrdsize='';
++  if ($initrd) {
++    $initrdsize=sprintf("%.0f",(stat($realimageloc .
++                                     "initrd.img-$version"))[7]/1024)."kB";
++  }
++
++  print STDERR <<"EOMSG";
++A new kernel image has been installed at $realimageloc$kimage-$version
++ (Size: $ksize)
++
++Symbolic links, unless otherwise specified, can be found in $image_dest
++
++EOMSG
++  ;
++
++  if ($initrd) {
++    print STDERR <<"EOMSGA";
++
++ Initial rootdisk image: ${realimageloc}initrd.img-$version (Size: $initrdsize)
++EOMSGA
++    ;
++  }
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if ($postinst_hook) {
++  &run_hook("postinst", $postinst_hook);
++}
++
++if (-d "/etc/kernel/postinst.d") {
++  print STDERR "Examining /etc/kernel/postinst.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postinst.d") &&
++            die "Failed to process /etc/kernel/postinst.d";
++}
++
++if (-d "/etc/kernel/postinst.d/$version") {
++  print STDERR "Examining /etc/kernel/postinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postinst.d/$version") &&
++            die "Failed to process /etc/kernel/postinst.d/$version";
++}
++
++LOADER: {
++  last unless $do_boot_enable; # Exit if explicitly asked to
++
++  last if $loader =~ /silo/i; # SILO does not have to be executed.
++  last if $loader =~ /yaboot/i; # yaboot does not have to be executed.
++  last if $loader =~ /milo/i; # MILO does not have to be executed.
++  last if $loader =~ /nettrom/i; # NETTROM does not have to be executed.
++  last if $loader =~ /arcboot/i; # ARCBOOT does not have to be executed.
++  last if $loader =~ /delo/i; # DELO does not have to be executed.
++  last if $loader =~ /quik/i; # maintainer asked quik invocation to be ignored
++
++  last unless $loaderloc;
++  last unless -x $loaderloc;
++  last unless $do_bootloader;
++
++  if (-T "/etc/$loader.conf") {
++    # Trust and use the existing lilo.conf.
++    print STDERR "You already have a $Loader configuration in /etc/$loader.conf\n";
++    my $ret = &run_lilo();
++    exit $ret if $ret;
++  }
++}
++
++
++sub run_lilo (){
++  my $ret;
++  # Try and figure out if the user really wants lilo to be run --
++  # since the default is to run the boot laoder, which is ! grub -- but
++  # the user may be using grub now, and not changed the default.
++
++  # So, if the user has explicitly asked for the loader to be run, or
++  # if there is no postinst hook, or if there is no grub installed --
++  # we are OK. Or else, we ask.
++  if ($explicit_do_loader || (! ($postinst_hook && -x '/usr/sbin/grub')))  {
++    print STDERR "Running boot loader as requested\n";
++  } else {
++    print STDERR "Ok, not running $loader\n";
++  }
++  if ($loader =~ /^lilo/io or $loader =~ /vmelilo/io) {
++    print STDERR "Testing $loader.conf ... \n";
++    unlink $temp_file_name;     # security
++    $ret = system("$loaderloc -t >$temp_file_name 2>&1");
++    if ($ret) {
++      print STDERR "Boot loader test failed\n";
++      return $ret;
++    }
++    unlink "$temp_file_name";
++    print STDERR "Testing successful.\n";
++    print STDERR "Installing the ";
++    print STDERR "partition " if $loader =~ /^lilo/io;
++    print STDERR "boot sector... \n";
++  }
++
++  print STDERR "Running $loaderloc  ... \n";
++  if ($loader =~ /^elilo/io) {
++    $ret = system("$loaderloc 2>&1 | tee $temp_file_name");
++  } else {
++    $ret = system("$loaderloc >$temp_file_name 2>&1");
++  }
++  if ($ret) {
++    print STDERR "Boot loader failed to run\n";
++    return $ret;
++  }
++  unlink $temp_file_name;
++  print STDERR "Installation successful.\n";
++  return 0;
++}
++
++exit 0;
++
++__END__
++
+diff --git a/debian/control-scripts/postrm b/debian/control-scripts/postrm
+new file mode 100644
+index 0000000..227e351
+--- /dev/null
++++ b/debian/control-scripts/postrm
+@@ -0,0 +1,361 @@
++#! /usr/bin/perl
++#                              -*- Mode: Cperl -*- 
++# image.postrm --- 
++# Author           : Manoj Srivastava ( srivasta@glaurung.green-gryphon.com ) 
++# Created On       : Sat May 15 11:05:13 1999
++# Created On Node  : glaurung.green-gryphon.com
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Wed Sep 13 11:26:19 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 57
++# Status           : Unknown, Use with caution!
++# HISTORY          : 
++# Description      : 
++# 
++#     $Id: image.postrm,v 1.31 2003/10/07 16:24:20 srivasta Exp $
++#
++
++
++# 
++#use strict; #for debugging
++use Cwd 'abs_path';
++
++$|=1;
++
++# Predefined values:
++my $version           = "=V";
++my $link_in_boot      = "";	# Should be empty, mostly
++my $no_symlink        = "";	# Should be empty, mostly
++my $reverse_symlink   = "";	# Should be empty, mostly
++my $do_symlink        = "Yes";	# target machine defined
++my $do_boot_enable    = "Yes";	# target machine defined
++my $do_bootfloppy     = "Yes";	# target machine defined
++my $do_bootloader     = "Yes";	# target machine defined
++my $move_image        = '';       # target machine defined
++my $kimage            = "=K";	# Should be empty, mostly
++my $loader            = "=L";     # lilo, silo, quik, palo, vmelilo, or nettrom
++my $image_dir         = "/boot";     # where the image is located
++my $clobber_modules   = '';       # target machine defined
++my $initrd            = "YES";     # initrd kernel
++my $do_initrd         = '';       # Normally, we don't
++my $warn_initrd       = 'YES';    # Normally we do
++my $use_hard_links    = '';       # hardlinks do not work across fs boundaries
++my $postinst_hook     = '';       #Normally we do not
++my $postrm_hook       = '';       #Normally we do not
++my $preinst_hook      = '';       #Normally we do not
++my $prerm_hook        = '';       #Normally we do not
++my $minimal_swap      = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';	# normally we do not
++my $relink_build_link = 'YES';	# There is no harm in checking the link
++my $force_build_link  = '';	# we shall not create a dangling link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; # 
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my @boilerplate     = ();
++my @silotemplate    = ();
++my @quiktemplate    = ();
++my @palotemplate    = ();
++my @vmelilotemplate = ();
++my $bootdevice      = '';
++my $rootdevice      = '';
++my $rootdisk        = '';
++my $rootpartition   = '';
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links = '';
++my $silent_modules  = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++chdir('/')           or die "could not chdir to /:$!\n";
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $warn_initrd     = '' if /^\s*warn_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_modules  = '' if /^\s*silent_modules\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_initrd     = "Yes" if /^\s*warn_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_modules  = 'Yes' if /^\s*silent_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++if ($link_in_boot) {
++  $image_dest = "/$image_dir/";
++  $image_dest =~ s|^/*|/|o;
++}
++
++$image_dest = "$image_dest/";
++$image_dest =~ s|/+$|/|o;
++
++# The destdir may be gone by now.
++if (-d "$image_dest") {
++  chdir("$image_dest") or die "could not chdir to $image_dest:$!\n";
++}
++
++# Paranoid check to make sure that the correct value is put in there
++if (! $kimage)                    {$kimage = "vmlinuz"} # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) {$kimage = "vmlinuz"} # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) {$kimage = "vmlinuz"} # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;}
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;}
++else                              {$kimage = "vmlinuz"} # default
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++sub remove_sym_link {
++  my $bad_image = $_[0];
++
++  warn "Removing symbolic link $bad_image \n";
++  if ($loader =~ /lilo/i) 
++    {
++      warn "Unless you used the optional flag in lilo, \n";
++    }
++  warn " you may need to re-run your boot loader" . ($loader ? "[$loader]":"")
++    . "\n";
++  # Remove the dangling link
++  unlink "$bad_image";
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++sub CanonicalizePath {
++  my $path = join '/', @_;
++  my @work = split '/', $path;
++  my @out;
++  my $is_absolute;
++
++  if (@work && $work[0] eq "") { $is_absolute = 1; shift @work; }
++
++  while (@work) {
++    my $seg = shift @work;
++    if ($seg eq "." || $seg eq "") {
++    } elsif ($seg eq "..") {
++      if (@out && $out[-1] ne "..") {
++        pop @out;
++      } else {
++        # Leading "..", or "../..", etc.
++        push @out, $seg;
++      }
++    } else {
++      push @out, $seg;
++    }
++  }
++
++  unshift @out, "" if $is_absolute;
++  return join('/', @out);
++}
++
++######################################################################
++######################################################################
++############
++######################################################################
++######################################################################
++# This removes dangling symlinks. What do we do about hard links? Surely a 
++# something with the nane $image_dest . "$kimage" ought not to be left behind? 
++sub image_magic {
++  my $kimage = $_[0];
++  my $image_dest = $_[1];
++
++  if (-l "$kimage") {
++    # There is a symbolic link
++    my $force_move = 0;
++    my $vmlinuz_target = readlink "$kimage";
++    my $real_target = '';
++    $real_target = abs_path($vmlinuz_target) if defined ($vmlinuz_target);
++    if (!defined($vmlinuz_target) || ! -f "$real_target") {
++      # what, a dangling symlink?
++      warn "The link "  . $image_dest . "$kimage is a damaged link\n";
++      # Remove the dangling link
++      &remove_sym_link("$kimage");
++    }
++    else {
++      my $canonical_target = CanonicalizePath("$vmlinuz_target");
++      if (! -e $canonical_target) {
++	warn "The link "  . $image_dest . "$kimage is a dangling link\n";
++	&remove_sym_link("$kimage");
++      }
++    }
++  }
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      warn "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    warn "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if ($postrm_hook) {
++  &run_hook("postrm", $postrm_hook);
++}
++if (-d "/etc/kernel/postrm.d") {
++  warn "Examining /etc/kernel/postrm.d .\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postrm.d") &&
++            die "Failed to process /etc/kernel/postrm.d";
++}
++if (-d "/etc/kernel/postrm.d/$version") {
++  warn "Examining /etc/kernel/postrm.d/$version .\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " .
++          "--arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/postrm.d/$version") &&
++            die "Failed to process /etc/kernel/postrm.d/$version";
++}
++
++# check and remove damaged and dangling symlinks
++if ($ARGV[0] !~ /upgrade/) {
++  system("$ramdisk -d -k " . $version . " > /dev/null 2>&1");
++  if (-f $realimageloc . "initrd.img-$version.bak") {
++    unlink $realimageloc . "initrd.img-$version.bak";
++  }
++  image_magic($kimage,          $image_dest);
++  image_magic($kimage . ".old", $image_dest);
++  image_magic("initrd.img",     $image_dest) if $initrd;
++  image_magic("initrd.img.old", $image_dest) if $initrd;
++}
++
++exit 0;
++
++__END__
++
++
++
++
++
++
+diff --git a/debian/control-scripts/preinst b/debian/control-scripts/preinst
+new file mode 100644
+index 0000000..9723776
+--- /dev/null
++++ b/debian/control-scripts/preinst
+@@ -0,0 +1,315 @@
++#! /usr/bin/perl
++#                              -*- Mode: Cperl -*-
++# image.preinst ---
++# Author           : Manoj Srivastava ( srivasta@tiamat.datasync.com )
++# Created On       : Sun Jun 14 03:38:02 1998
++# Created On Node  : tiamat.datasync.com
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sun Sep 24 14:04:42 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 99
++# Status           : Unknown, Use with caution!
++# HISTORY          :
++# Description      :
++#
++#
++
++#
++#use strict; #for debugging
++
++use Debconf::Client::ConfModule qw(:all);
++version('2.0');
++my $capb=capb("backup");
++
++$|=1;
++
++# Predefined values:
++my $version         = "=V";
++my $link_in_boot    = "";     # Should be empty, mostly
++my $no_symlink      = "";     # Should be empty, mostly
++my $reverse_symlink = "";     # Should be empty, mostly
++my $do_symlink      = "Yes";	# target machine defined
++my $do_boot_enable  = "Yes";	# target machine defined
++my $do_bootfloppy   = "Yes";	# target machine defined
++my $do_bootloader   = "Yes";	# target machine defined
++my $move_image      = '';       # target machine defined
++my $kimage          = "=K";     # Should be empty, mostly
++my $loader          = "=L";     # lilo, silo, quik, palo, vmelilo, nettrom
++                                # or elilo
++my $image_dir       = "/boot";     # where the image is located
++my $initrd          = "YES";     # initrd kernel
++my $use_hard_links  = '';       # hardlinks do not wirk across fs boundaries
++my $postinst_hook   = '';       #Normally we do not
++my $postrm_hook     = '';       #Normally we do not
++my $preinst_hook    = '';       #Normally we do not
++my $prerm_hook      = '';       #Normally we do not
++my $minimal_swap    = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';    # normally we do not
++my $relink_src_link   = 'YES';	# There is no harm in checking the link
++my $relink_build_link = 'YES'; # There is no harm in checking the link
++my $force_build_link  = '';	 # There is no harm in checking the link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";  # List of tools to create initial ram fs.
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; #
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++#known variables
++my @boilerplate     = ();
++my @silotemplate    = ();
++my @quiktemplate    = ();
++my @palotemplate    = ();
++my @vmelilotemplate = ();
++my $bootdevice      = '';
++my $rootdevice      = '';
++my $rootdisk        = '';
++my $rootpartition   = '';
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links  = '';
++my $silent_loader   = '';
++my $warn_reboot     = '';        # Warn that we are installing a version of
++                                 # the kernel we are running
++
++my $modules_base    = '/lib/modules';
++
++die "Pre inst Internal error. Aborting." unless $version;
++
++exit 0 if $ARGV[0] =~ /abort-upgrade/;
++exit 1 unless $ARGV[0] =~ /(install|upgrade)/;
++
++$arch = `uname -i`;
++if ($arch =~ m/86/) {
++	system ("grep -q ' pae ' /proc/cpuinfo");
++	if ($?) {
++			print STDERR "This kernel does not support a non-PAE CPU.\n";
++			exit 1;
++	}
++}
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_src_link   = '' if /^\s*relink_src_link\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_src_link   = 'Yes' if /^\s*relink_src_link\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++    $have_conffile = "Yes";	# stop perl complaining
++  }
++}
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++# About to upgrade this package from version $2 TO THIS VERSION.
++# "prerm upgrade" has already been called for the old version of
++# this package.
++
++sub find_initrd_tool {
++  my $hostversion = shift;
++  my $version = shift;
++  my @ramdisks =
++    grep {
++      my $args = 
++        "$_ " .
++          "--supported-host-version=$hostversion " .
++            "--supported-target-version=$version " .
++              "1>/dev/null 2>&1"
++                ;
++      system($args) == 0;
++    }
++      split (/[:,\s]+/, $ramdisk);
++}
++
++sub check {
++  my $version = shift;
++  my $lib_modules="$modules_base/$version";
++  my $message = '';
++
++  if (-d "$lib_modules") {
++    opendir(DIR, $lib_modules) || die "can’t opendir $lib_modules: $!";
++    my @children = readdir(DIR);
++    if ($#children > 1) {
++      my @dirs  = grep { -d "$lib_modules/$_" } @children;
++      if ($#dirs > 1) { # we have subdirs
++        my $dir_message='';
++        for my $dir (@dirs) {
++          if ($dir =~/kernel$/) {
++            $dir_message="An older install was detected.\n";
++          }
++          else {
++            $dir_message="Module sub-directories were detected.\n"
++              unless $dir_message;
++          }
++        }
++        $message += $dir_message if $dir_message;
++      }
++
++      my @links = grep { -l "$lib_modules/$_" } @children;
++      if ($#links > -1) {
++        my $links_message = '';
++        for my $link (@links) {
++          next if ($link =~ /^build$/);
++          next if ($link =~ /^source$/);
++          $links_message = "Symbolic links were detected in $modules_base/$version.\n";
++        }
++        $message += $links_message if $links_message;
++      }
++      my @files = grep { -f "$lib_modules/$_" } @children;
++      $message += "Additional files also exist in $modules_base/$version.\n"
++        if ($#files > -1);
++    }
++  }
++  else { $message .= "$lib_modules does not exist. ";}
++  return $message;
++}
++
++if (-d "$modules_base/$version") {
++  my $errors=check($version);
++  warn "Info:\n$errors\n" if $errors;
++}
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if (-x "$preinst_hook") {
++  &run_hook("preinst", $preinst_hook);
++}
++if (-d "/etc/kernel/preinst.d") {
++  print STDERR "Examining /etc/kernel/preinst.d/\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version" .
++          " /etc/kernel/preinst.d") &&
++            die "Failed to process /etc/kernel/preinst.d";
++}
++if (-d "/etc/kernel/preinst.d/$version") {
++  print STDERR "Examining /etc/kernel/preinst.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version" .
++          " /etc/kernel/preinst.d/$version") &&
++            die "Failed to process /etc/kernel/preinst.d/$version";
++}
++print STDERR "Done.\n";
++
++exit 0;
++
++__END__
++
++
+diff --git a/debian/control-scripts/prerm b/debian/control-scripts/prerm
+new file mode 100644
+index 0000000..07e4146
+--- /dev/null
++++ b/debian/control-scripts/prerm
+@@ -0,0 +1,312 @@
++#! /usr/bin/perl
++#                              -*- Mode: Perl -*- 
++# image.prerm --- 
++# Author           : root ( root@melkor.pilgrim.umass.edu ) 
++# Created On       : Fri May 17 03:28:59 1996
++# Created On Node  : melkor.pilgrim.umass.edu
++# Last Modified By : Manoj Srivastava
++# Last Modified On : Sat Aug  5 13:14:17 2006
++# Last Machine Used: glaurung.internal.golden-gryphon.com
++# Update Count     : 85
++# Status           : Unknown, Use with caution!
++# HISTORY          : 
++# Description      : 
++# 
++#
++#    $Id: image.prerm,v 1.22 2003/10/07 16:24:20 srivasta Exp $
++#
++# 
++#use strict;
++
++$|=1;
++# Predefined values:
++my $version         = "=V";
++my $link_in_boot    = "";	# Should be empty, mostly
++my $no_symlink      = "";	# Should be empty, mostly
++my $reverse_symlink = "";	# Should be empty, mostly
++my $do_symlinks     = "Yes";	# target machine defined
++my $do_boot_enable  = "Yes";	# target machine defined
++my $do_bootfloppy   = "Yes";	# target machine defined
++my $do_bootloader   = "Yes";	# target machine defined
++my $move_image      = '';       # target machine defined
++my $kimage          = "=K";	# Should be empty, mostly
++my $loader          = "=L";     # lilo, silo, quik, palo, vmelilo, or nettrom
++my $image_dir       = "/boot";     # where the image is located
++my $clobber_modules = '';       # target machine defined
++my $initrd          = "YES";     # initrd kernel
++my $use_hard_links  = '';       # hardlinks do not wirk across fs boundaries
++my $postinst_hook   = '';       #Normally we do not
++my $postrm_hook     = '';       #Normally we do not
++my $preinst_hook    = '';       #Normally we do not
++my $prerm_hook      = '';       #Normally we do not
++my $minimal_swap    = '';       # Do not swap symlinks
++my $ignore_depmod_err = '';	# normally we do not
++my $relink_build_link = 'YES';	# There is no harm in checking the link
++my $force_build_link = '';	# There is no harm in checking the link
++my $kernel_arch       = "=B";
++my $ramdisk           = "/usr/sbin/update-initramfs";
++my $package_name    = "linux-image-$version";
++
++my $Loader          = "NoLOADER"; # 
++$Loader             = "LILO"     if $loader =~ /^lilo/io;
++$Loader             = "SILO"     if $loader =~ /^silo/io;
++$Loader             = "QUIK"     if $loader =~ /^quik/io;
++$Loader             = "yaboot"   if $loader =~ /^yaboot/io;
++$Loader             = "PALO"     if $loader =~ /^palo/io;
++$Loader             = "NETTROM"  if $loader =~ /^nettrom/io;
++$Loader             = "VMELILO"  if $loader =~ /^vmelilo/io;
++$Loader             = "ZIPL"     if $loader =~ /^zipl/io;
++$Loader             = "ELILO"    if $loader =~ /^elilo/io;
++
++
++# This should not point to /tmp, because of security risks.
++my $temp_file_name = "/var/log/$loader" . "_log.$$";
++
++#known variables
++my $image_dest      = "/";
++my $realimageloc    = "/$image_dir/";
++my $have_conffile   = "";
++my $CONF_LOC        = '/etc/kernel-img.conf';
++my $relative_links = '';
++my $silent_loader   = '';
++my $warn_reboot     = 'Yes';     # Warn that we are installing a version of
++                                 # the kernel we are running
++
++# remove multiple leading slashes; make sure there is at least one.
++$realimageloc  =~ s|^/*|/|o;
++$realimageloc  =~ s|/+|/|o;
++
++my $DEBUG = 0;
++
++# Variables used
++my $image='';
++my $ret=0;
++my $seen='';
++my $answer='';
++my $running = '';
++my $WouldInvalidate = 0;
++
++if ($ARGV[0] && ($ARGV[0] =~ /remove/ || $ARGV[0] =~ /upgrade/)) {
++  if (-l "/usr/doc/linux-image-$version") {
++    unlink "/usr/doc/linux-image-$version";
++  }
++}
++
++# Ignore all invocations uxcept when called on to remove
++exit 0 unless ($ARGV[0] && $ARGV[0] =~ /remove/) ;
++
++# Paranoid check to make sure that the correct value is put in there
++if (! $kimage)                    { $kimage = "vmlinuz";} # Hmm. empty
++elsif ($kimage =~ m/^b?uImage$/o) { $kimage = "vmlinuz";} # these produce vmlinuz
++elsif ($kimage =~ m/^b?zImage$/o) { $kimage = "vmlinuz";} # these produce vmlinuz
++elsif ($kimage =~ m/^[iI]mage$/o) { my $nop = $kimage;  }
++elsif ($kimage =~ m/^vmlinux$/o)  { my $nop = $kimage;  }
++else                              { $kimage = "vmlinuz";} # Default
++
++if (-r "$CONF_LOC" && -f "$CONF_LOC"  ) {
++  if (open(CONF, "$CONF_LOC")) {
++    while (<CONF>) {
++      chomp;
++      s/\#.*$//g;
++      next if /^\s*$/;
++
++      $do_symlink      = "" if /^\s*do_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $no_symlink      = "" if /^\s*no_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $reverse_symlink = "" if /^\s*reverse_symlinks\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*image_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $link_in_boot    = "" if /^\s*link_in_boot\s*=\s*(no|false|0)\s*$/ig;
++      $move_image      = "" if /^\s*move_image\s*=\s*(no|false|0)\s*$/ig;
++      $clobber_modules = '' if /^\s*clobber_modules\s*=\s*(no|false|0)\s*$/ig;
++      $do_boot_enable  = '' if /^\s*do_boot_enable\s*=\s*(no|false|0)\s*$/ig;
++      $do_bootfloppy   = '' if /^\s*do_bootfloppy\s*=\s*(no|false|0)\s*$/ig;
++      $relative_links  = '' if /^\s*relative_links \s*=\s*(no|false|0)\s*$/ig;
++      $do_bootloader   = '' if /^\s*do_bootloader\s*=\s*(no|false|0)\s*$/ig;
++      $do_initrd       = '' if /^\s*do_initrd\s*=\s*(no|false|0)\s*$/ig;
++      $use_hard_links  = '' if /^\s*use_hard_links\s*=\s*(no|false|0)\s*$/ig;
++      $silent_loader   = '' if /^\s*silent_loader\s*=\s*(no|false|0)\s*$/ig;
++      $warn_reboot     = '' if /^\s*warn_reboot\s*=\s*(no|false|0)\s*$/ig;
++      $minimal_swap    = '' if /^\s*minimal_swap\s*=\s*(no|false|0)\s*$/ig;
++      $ignore_depmod_err = '' if /^\s*ignore_depmod_err\s*=\s*(no|false|0)\s*$/ig;
++      $relink_build_link = '' if /^\s*relink_build_link\s*=\s*(no|false|0)\s*$/ig;
++      $force_build_link = '' if /^\s*force_build_link\s*=\s*(no|false|0)\s*$/ig;
++
++
++      $do_symlink      = "Yes" if /^\s*do_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $no_symlink      = "Yes" if /^\s*no_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $reverse_symlink = "Yes" if /^\s*reverse_symlinks\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*image_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $link_in_boot    = "Yes" if /^\s*link_in_boot\s*=\s*(yes|true|1)\s*$/ig;
++      $move_image      = "Yes" if /^\s*move_image\s*=\s*(yes|true|1)\s*$/ig;
++      $clobber_modules = "Yes" if /^\s*clobber_modules\s*=\s*(yes|true|1)\s*$/ig;
++      $do_boot_enable  = "Yes" if /^\s*do_boot_enable\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootfloppy   = "Yes" if /^\s*do_bootfloppy\s*=\s*(yes|true|1)\s*$/ig;
++      $do_bootloader   = "Yes" if /^\s*do_bootloader\s*=\s*(yes|true|1)\s*$/ig;
++      $relative_links  = "Yes" if /^\s*relative_links\s*=\s*(yes|true|1)\s*$/ig;
++      $do_initrd       = "Yes" if /^\s*do_initrd\s*=\s*(yes|true|1)\s*$/ig;
++      $use_hard_links  = "Yes" if /^\s*use_hard_links\s*=\s*(yes|true|1)\s*$/ig;
++      $silent_loader   = 'Yes' if /^\s*silent_loader\s*=\s*(yes|true|1)\s*$/ig;
++      $warn_reboot     = 'Yes' if /^\s*warn_reboot\s*=\s*(yes|true|1)\s*$/ig;
++      $minimal_swap    = 'Yes' if /^\s*minimal_swap\s*=\s*(yes|true|1)\s*$/ig;
++      $ignore_depmod_err = 'Yes' if /^\s*ignore_depmod_err\s*=\s*(yes|true|1)\s*$/ig;
++      $relink_build_link = 'Yes' if /^\s*relink_build_link\s*=\s*(yes|true|1)\s*$/ig;
++      $force_build_link = 'Yes' if /^\s*force_build_link\s*=\s*(yes|true|1)\s*$/ig;
++
++      $image_dest      = "$1"  if /^\s*image_dest\s*=\s*(\S+)/ig;
++      $postinst_hook   = "$1"  if /^\s*postinst_hook\s*=\s*(\S+)/ig;
++      $postrm_hook     = "$1"  if /^\s*postrm_hook\s*=\s*(\S+)/ig;
++      $preinst_hook    = "$1"  if /^\s*preinst_hook\s*=\s*(\S+)/ig;
++      $prerm_hook      = "$1"  if /^\s*prerm_hook\s*=\s*(\S+)/ig;
++      $ramdisk         = "$1"  if /^\s*ramdisk\s*=\s*(.+)$/ig;
++    }
++    close CONF;
++    $have_conffile = "Yes";
++  }
++}
++
++
++$ENV{KERNEL_ARCH}=$kernel_arch if $kernel_arch;
++
++#check to see if we are trying to remove a running kernel
++# if so we abort right now.
++chop($running=`uname -r`);
++if ($running eq $version) {
++  print STDERR "WARN: Proceeding with removing running kernel image.\n";
++}
++
++#Now, they have an alternate kernel which they are currently running
++
++# This is just us being nice to lilo users.
++
++chdir("/") or die "could not chdir to /:$!\n";
++
++if (-f "/etc/$loader.conf") { #I know, could be a link, but ..
++  open (LILO, "/etc/$loader.conf") || &success(); # this is not critical
++  while (<LILO>) {
++    chop;
++    s/\#.*//;			  # nix the comments
++    next unless /^\s*image\s*=\s(\S+)/o;
++    $image = $1;
++    if ($image && -e $image) {
++      while (defined($image) && -l $image) {
++	$image = readlink ($image);
++      }
++      if (defined($image) && -e $image) {
++	$WouldInvalidate |= $image =~ /$kimage-$version/;
++      }
++      else {
++	&success(); # invalid $loader.conf file
++      }
++    }
++    else {
++      &success(); # invalid $loader.conf file
++    }
++  }
++  close (LILO);
++  if ($WouldInvalidate) {
++    print STFERR "WARN: Proceeding with removing running kernel image.\n";
++    &success();
++  }
++}
++
++
++# set the env var stem
++$ENV{'STEM'} = "linux";
++
++sub exec_script {
++  my $type   = shift;
++  my $script = shift;
++  print STDERR "Running $type hook script $script.\n";
++  system ("$script $version $realimageloc$kimage-$version") &&
++    print STDERR "User $type hook script [$script] ";
++  if ($?) {
++    if ($? == -1) {
++      print STDERR "failed to execute: $!\n";
++    }
++    elsif ($? & 127) {
++      printf STDERR "died with signal %d, %s coredump\n",
++        ($? & 127),  ($? & 128) ? 'with' : 'without';
++    }
++    else {
++      printf STDERR "exited with value %d\n", $? >> 8;
++    }
++    exit $? >> 8;
++  }
++}
++sub run_hook {
++  my $type   = shift;
++  my $script = shift;
++  if ($script =~ m,^/,) {
++    # Full path provided for the hook script
++    if (-x "$script") {
++      &exec_script($type,$script);
++    }
++    else {
++      die "The provided $type hook script [$script] could not be run.\n";
++    }
++  }
++  else {
++    # Look for it in a safe path
++    for my $path ('/bin', '/sbin', '/usr/bin', '/usr/sbin') {
++      if (-x "$path/$script") {
++        &exec_script($type, "$path/$script");
++        return 0;
++      }
++    }
++    # No luck
++    print STDERR "Could not find $type hook script [$script].\n";
++    die "Looked in: '/bin', '/sbin', '/usr/bin', '/usr/sbin'\n";
++  }
++}
++
++
++my $options;
++for (@ARGV) {
++	s,','\\'',g;
++	$options .= " '$_'";
++}
++$ENV{'DEB_MAINT_PARAMS'}="$options";
++
++## Run user hook script here, if any
++if (-x "$prerm_hook") {
++  &run_hook("prerm", $prerm_hook);
++}
++if (-d "/etc/kernel/prerm.d") {
++  print STDERR "Examining /etc/kernel/prerm.d.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version " . 
++          "--arg=$realimageloc$kimage-$version /etc/kernel/prerm.d") &&
++            die "Failed to process /etc/kernel/prerm.d";
++}
++if (-d "/etc/kernel/prerm.d/$version") {
++  print STDERR "Examining /etc/kernel/prerm.d/$version.\n";
++  system ("run-parts --verbose --exit-on-error --arg=$version" .
++          " --arg=$realimageloc$kimage-$version " .
++          "/etc/kernel/prerm.d/$version") &&
++            die "Failed to process /etc/kernel/prerm.d/$version";
++}
++
++sub success () {
++  # NOTE: need to keep this list in sync with rules.d/2-binary-arch.mk
++  my %files_to_keep = (
++	'modules.builtin'	=> 1,
++	'modules.order'		=> 1,
++  );
++  my $short;
++  for my $file (</lib/modules/$version/modules.*>) {
++    $short = $file; $short =~ s,.*/,,;
++    if (!defined $files_to_keep{$short}) {
++      unlink "$file";
++    }
++  }
++  exit 0;
++}
++
++
++
++&success();
++exit 0;
++__END__
++
++
++
++
++
+diff --git a/debian/debian.env b/debian/debian.env
+new file mode 100644
+index 0000000..be31a0c
+--- /dev/null
++++ b/debian/debian.env
+@@ -0,0 +1 @@
++DEBIAN=debian.master
+diff --git a/debian/docs/README.inclusion-list b/debian/docs/README.inclusion-list
+new file mode 100644
+index 0000000..b025393
+--- /dev/null
++++ b/debian/docs/README.inclusion-list
+@@ -0,0 +1,51 @@
++This README describes the reason for, and the use of, module
++inclusion lists.
++
++The original Hardy release had the notion of sub-flavours,
++e.g., a flavour that was constructed as a subset of an existing flavour.
++For example, the virtual flavour was extracted from the server flavour using
++a subset of the server flavour modules. However, there were some difficult
++mainteneance issues with regard to packaging, make rules, and scripts. This
++re-implementation of the sub-flavours philosophy is hopefully simpler,
++and retrofitable to all releases.
++
++A module inclusion list looks at the problem of of constructing a package
++from the perspective of what modules do we _want_ in the package, as opposed
++to what modules we _don't_ want. As the kernel matures, more and more devices are added
++which makes the problem of configuration maintenance a real pain in the ass.
++If we took the approach of disabling all of the config options that we don't want,
++then the differences between flavours will quickly become quite large, making
++it difficult to quickly compare the individual flavour configs.  Each time a
++new config option is added then we also have to make a decision about disabling in
++order to continue to keep the minimal number of modules.
++
++A module inclusion list is applied on a per-flavour basis. For example,
++debian.<BRANCH>/control.d/${flavour}.inclusion-list. For example, the
++config for virtual is very close to server and generic, but the inclusion list
++causes the virtual package to be constructed with _only_ the modules described 
++in the inclusion list.
++
++The inclusion list format is a simple bash regular expression list of files. For example,
++
++arch/*/{crypto,kernel,oprofile}
++drivers/acpi/*
++drivers/ata/ahci.ko
++
++These 3 regular expression forms are suitable for expansion by bash and as inputs to 'find'.
++See debian/scripts/module-inclusion for details.
++
++There are 2 log files created as a side effect of the application of the module
++inclusion list; $(flavour).inclusion-list.log and $(flavour).depmod.log.
++
++$(flavour).inclusion-list.log : This log is created while the inclusion list
++modules are being copied. If any are missing, then those warnings go in this log.
++While its not considered a fatal error, you should endevour to correct your inclusion
++list such that there are no missing modules.
++
++$(flavour).depmod.log : The log is created as a result of running depmod on the
++resulting set of modules. If there are missing symbols then you'll find that information
++here. Again, you should modify your inclusion list such that there are no missing
++symbols.
++
++Tim Gardner <tim.gardner@canonical.com>
++June 2, 2010
+diff --git a/debian/rules b/debian/rules
+new file mode 100755
+index 0000000..2d3358b6
+--- /dev/null
++++ b/debian/rules
+@@ -0,0 +1,252 @@
++#!/usr/bin/make -f
++#
++# $(DEBIAN)/rules for Ubuntu linux
++#
++# Use this however you want, just give credit where credit is due.
++#
++# Copyright (c) 2007 Ben Collins <bcollins@ubuntu.com>
++#
++
++DEBIAN=$(shell awk -F= '($$1 == "DEBIAN") { print $$2 }' <debian/debian.env)
++
++# dpkg-buildpackage passes options that are incomptatible
++# with the kernel build.
++unexport CFLAGS
++unexport LDFLAGS
++
++export LC_ALL=C
++export SHELL=/bin/bash -e
++
++# Where do we find the common configuration.
++export DROOT=debian
++
++# Common variables for all architectures
++include $(DROOT)/rules.d/0-common-vars.mk
++
++# Pull in some arch specific stuff
++-include $(DEBIAN)/rules.d/$(arch).mk
++
++# Maintainer targets
++include $(DROOT)/rules.d/1-maintainer.mk
++
++# Don't build tools in a cross compile environment.
++ifneq ($(DEB_HOST_ARCH),$(DEB_BUILD_ARCH))
++	do_tools = false
++endif
++
++# Stages -- support both DEB_STAGE=stage1 and DEB_BUILD_PROFILE=bootstrap
++ifeq ($(DEB_STAGE),stage1)
++    DEB_BUILD_PROFILE=bootstrap
++endif
++ifeq ($(DEB_BUILD_PROFILE),bootstrap)
++    do_tools=false
++    do_doc_package=false
++    do_source_package=false
++    do_flavour_image_package=false
++    do_flavour_header_package=false
++endif
++
++# autopkgtest -- rebuild support
++#  only build the first flavour on the assumption it is representative
++ifeq ($(DEB_BUILD_PROFILE),autopkgtest)
++flavours := $(firstword $(flavours))
++endif
++
++# Debian Build System targets
++binary: binary-indep binary-arch
++
++build: build-arch build-indep
++
++clean: debian/control
++	dh_testdir
++	dh_testroot
++	dh_clean
++
++	# d-i stuff
++	rm -rf $(DEBIAN)/d-i-$(arch)
++
++	# normal build junk
++	rm -rf $(DEBIAN)/abi/$(release)-$(revision)
++	rm -rf $(builddir)
++	rm -f $(stampdir)/stamp-*
++	rm -rf $(DEBIAN)/linux-*
++
++	# This gets rid of the d-i packages in control
++	cp -f $(DEBIAN)/control.stub $(DEBIAN)/control
++	cp $(DEBIAN)/changelog debian/changelog
++
++	# Install the copyright information.
++	cp $(DEBIAN)/copyright debian/copyright
++
++distclean: clean
++	rm -rf $(DEBIAN)/control $(DEBIAN)/control.stub \
++		$(DEBIAN)/d-i/kernel-versions debian/changelog \
++		debian/control debian/control.stub debian/copyright
++
++# Builds the image, arch headers and debug packages
++include $(DROOT)/rules.d/2-binary-arch.mk
++
++# Rules for building the udebs ($(DEBIAN)-installer)
++include $(DROOT)/rules.d/5-udebs.mk
++
++# Builds the source, doc and linux-headers indep packages
++include $(DROOT)/rules.d/3-binary-indep.mk
++
++# Various checks to be performed on builds
++include $(DROOT)/rules.d/4-checks.mk
++
++# Misc stuff
++.PHONY: $(DEBIAN)/control.stub
++$(DEBIAN)/control.stub: $(DEBIAN)/d-i/kernel-versions.in	\
++		$(DROOT)/scripts/control-create		\
++		$(DEBIAN)/control.stub.in			\
++		$(DEBIAN)/changelog			\
++		$(wildcard $(DEBIAN)/control.d/* $(DEBIAN)/sub-flavours/*.vars)
++	for i in $(DEBIAN)/d-i/kernel-versions.in $(DEBIAN)/control.stub.in; do	\
++	  new=`echo $$i | sed 's/\.in$$//'`;					\
++	  cat $$i | sed -e 's/PKGVER/$(release)/g'                              \
++	        -e 's/ABINUM/$(abinum)/g'                                       \
++		-e 's/SRCPKGNAME/$(src_pkg_name)/g'                             \
++		-e 's/=HUMAN=/$(human_arch)/g'                                    \
++	  > $$new;								\
++	done
++	flavours="$(wildcard $(DEBIAN)/control.d/vars.* $(DEBIAN)/sub-flavours/*.vars)";\
++	for i in $$flavours; do							\
++	  $(SHELL) $(DROOT)/scripts/control-create $$i |				\
++		sed -e 's/PKGVER/$(release)/g'                                  \
++		-e 's/ABINUM/$(abinum)/g'                                       \
++		-e 's/SRCPKGNAME/$(src_pkg_name)/g'                             \
++		-e 's/=HUMAN=/$(human_arch)/g'                                    \
++		>> $(DEBIAN)/control.stub;						\
++	done
++	cp $(DEBIAN)/control.stub $(DEBIAN)/control
++
++.PHONY: debian/control
++debian/control: $(DEBIAN)/control.stub
++	rm -rf $(builddir)/modules $(builddir)/firmware			\
++		$(builddir)/kernel-versions $(builddir)/package-list	\
++		$(builddir)/$(DEBIAN)
++	mkdir -p $(builddir)/modules/$(arch)/
++	cp $(DEBIAN)/d-i/modules/* $(builddir)/modules/$(arch)/
++	mkdir -p $(builddir)/firmware/$(arch)/
++	cp $(DEBIAN)/d-i/firmware/* $(builddir)/firmware/$(arch)/
++	cp $(DEBIAN)/d-i/package-list $(DEBIAN)/d-i/kernel-versions $(builddir)/
++	touch $(builddir)/modules/$(arch)/kernel-image
++	# kernel-wedge needs to poke around in $(DEBIAN)/
++	ln -nsf $(CURDIR)/debian $(builddir)/debian
++
++	# Some files may need to differ between architectures
++	if [ -d $(DEBIAN)/d-i/modules-$(arch) ]; then			\
++	    cp $(DEBIAN)/d-i/modules-$(arch)/* \
++		$(builddir)/modules/$(arch)/;				\
++	fi
++	if [ -d $(DEBIAN)/d-i/firmware-$(arch) ]; then			\
++	    cp $(DEBIAN)/d-i/firmware-$(arch)/* \
++		$(builddir)/firmware/$(arch)/;				\
++	fi
++
++	# Remove unwanted stuff for this architecture
++	if [ -r "$(DEBIAN)/d-i/exclude-modules.$(arch)" ]; then		\
++	    (cat $(DEBIAN)/d-i/exclude-modules.$(arch);			\
++	     ls $(builddir)/modules/$(arch)/) | sort | uniq -d |	\
++		(cd $(builddir)/modules/$(arch)/; xargs rm -f);		\
++	fi
++	if [ -r "$(DEBIAN)/d-i/exclude-firmware.$(arch)" ]; then		\
++	    (cat $(DEBIAN)/d-i/exclude-firmware.$(arch);			\
++	     ls $(builddir)/firmware/$(arch)/) | sort | uniq -d |	\
++		(cd $(builddir)/firmware/$(arch)/; xargs rm -f);	\
++	fi
++
++	# Per flavour module lists
++	flavour_modules=`ls $(DEBIAN)/d-i/modules.$(arch)-* 2>/dev/null`	\
++		|| true;						\
++	if [ "$$flavour_modules" != "" ]; then				\
++	    for flav in $$flavour_modules; do				\
++		name=`echo $$flav | sed 's/.*\/modules.$(arch)-//'`;	\
++		mkdir $(builddir)/modules/$(arch)-$$name;		\
++		(cd $(builddir)/modules/; tar cf - `cat ../$$flav`) |	\
++		    (cd $(builddir)/modules/$(arch)-$$name/; tar xf -);	\
++		touch $(builddir)/modules/$(arch)-$$name/kernel-image;	\
++	    done;							\
++	fi
++	flavour_firmware=`ls $(DEBIAN)/d-i/firmware.$(arch)-* 2>/dev/null`	\
++		|| true;						\
++	if [ "$$flavour_firmware" != "" ]; then				\
++	    for flav in $$flavour_firmware; do				\
++		name=`echo $$flav | sed 's/.*\/firmware.$(arch)-//'`;	\
++		mkdir $(builddir)/firmware/$(arch)-$$name;		\
++		(cd $(builddir)/firmware/; tar cf - `cat ../$$flav`) |	\
++		    (cd $(builddir)/firmware/$(arch)-$$name/; tar xf -);\
++		touch $(builddir)/firmware/$(arch)-$$name/kernel-image;	\
++	    done;							\
++	fi
++
++	# Some files may need to differ between flavours
++	flavour_module_dirs=`ls -d $(DEBIAN)/d-i/modules-$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_module_dirs" ]; then				\
++	    for flav in $$flavour_module_dirs; do			\
++		name=`echo $$flav | sed 's/.*\/modules-$(arch)-//'`;	\
++		[ -d $(builddir)/modules/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/modules/$(arch)			\
++			modules/$(arch)-$$name;				\
++		cp $$flav/* $(builddir)/modules/$(arch)-$$name/;	\
++	    done;							\
++	fi
++	flavour_firmware_dirs=`ls -d $(DEBIAN)/d-i/firmware-$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_firmware_dirs" ]; then				\
++	    for flav in $$flavour_firmware_dirs; do			\
++		name=`echo $$flav | sed 's/.*\/firmware-$(arch)-//'`;	\
++		[ -d $(builddir)/firmware/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/firmware/$(arch)			\
++			firmware/$(arch)-$$name;			\
++		cp $$flav/* $(builddir)/firmware/$(arch)-$$name/;	\
++	    done;							\
++	fi
++
++	# Remove unwanted stuff for each flavour
++	flavour_exclude=`ls $(DEBIAN)/d-i/exclude-modules.$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_exclude" ]; then				\
++	    for flav in $$flavour_exclude; do				\
++		name=`echo $$flav | sed 's/.*\/exclude-modules.$(arch)-//'`;\
++		[ -d $(builddir)/modules/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/modules/$(arch) 			\
++			$(builddir)/modules/$(arch)-$$name;		\
++		(cat $$flav;						\
++		 ls $(builddir)/modules/$(arch)-$$name) |		\
++		 sort |	uniq -d |					\
++		    (cd $(builddir)/modules/$(arch)-$$name/;		\
++		     xargs rm -f);					\
++	    done;							\
++	fi
++	flavour_exclude=`ls $(DEBIAN)/d-i/exclude-firmware.$(arch)-* 2>/dev/null`\
++		|| true;						\
++	if [ "$$flavour_exclude" ]; then				\
++	    for flav in $$flavour_exclude; do				\
++		name=`echo $$flav | sed 's/.*\/exclude-firmware.$(arch)-//'`;\
++		[ -d $(builddir)/firmware/$(arch)-$$name ] ||		\
++		    cp -a $(builddir)/firmware/$(arch) 			\
++			$(builddir)/firmware/$(arch)-$$name;		\
++		(cat $$flav;						\
++		 ls $(builddir)/firmware/$(arch)-$$name) |		\
++		 sort |	uniq -d |					\
++		    (cd $(builddir)/firmware/$(arch)-$$name/;		\
++		     xargs rm -f);					\
++	    done;							\
++	fi
++
++	if [ ! -d $(builddir)/modules/$(build_arch) ]; then		\
++		mkdir -p $(builddir)/modules/$(build_arch);		\
++		cp $(builddir)/modules/$(arch)/*			\
++			$(builddir)/modules/$(build_arch);		\
++	fi
++	if [ ! -d $(builddir)/firmware/$(build_arch) ]; then		\
++		mkdir -p $(builddir)/firmware/$(build_arch);		\
++		cp $(builddir)/firmware/$(arch)/*			\
++			$(builddir)/firmware/$(build_arch);		\
++	fi
++
++	cp $(DEBIAN)/control.stub debian/control.stub
++	cd $(builddir) && kernel-wedge gen-control > $(CURDIR)/debian/control
+diff --git a/debian/rules.d/0-common-vars.mk b/debian/rules.d/0-common-vars.mk
+new file mode 100644
+index 0000000..2cda5b9
+--- /dev/null
++++ b/debian/rules.d/0-common-vars.mk
+@@ -0,0 +1,233 @@
++#
++# The source package name will be the first token from $(DEBIAN)/changelog
++#
++src_pkg_name=$(shell sed -n '1s/^\(.*\) (.*).*$$/\1/p' $(DEBIAN)/changelog)
++
++# Get some version info
++release := $(shell sed -n '1s/^$(src_pkg_name).*(\(.*\)-.*).*$$/\1/p' $(DEBIAN)/changelog)
++revisions := $(shell sed -n 's/^$(src_pkg_name)\ .*($(release)-\(.*\)).*$$/\1/p' $(DEBIAN)/changelog | tac)
++revision ?= $(word $(words $(revisions)),$(revisions))
++prev_revisions := $(filter-out $(revision),0.0 $(revisions))
++prev_revision := $(word $(words $(prev_revisions)),$(prev_revisions))
++
++prev_fullver ?= $(shell dpkg-parsechangelog -l$(DEBIAN)/changelog -o1 -c1 | sed -ne 's/^Version: *//p')
++
++family=ubuntu
++
++# This is an internally used mechanism for the daily kernel builds. It
++# creates packages whose ABI is suffixed with a minimal representation of
++# the current git HEAD sha. If .git/HEAD is not present, then it uses the
++# uuidgen program,
++#
++# AUTOBUILD can also be used by anyone wanting to build a custom kernel
++# image, or rebuild the entire set of Ubuntu packages using custom patches
++# or configs.
++AUTOBUILD=
++
++ifneq ($(AUTOBUILD),)
++skipabi		= true
++skipmodule	= true
++skipdbg		= true
++gitver=$(shell if test -f .git/HEAD; then cat .git/HEAD; else uuidgen; fi)
++gitverpre=$(shell echo $(gitver) | cut -b -3)
++gitverpost=$(shell echo $(gitver) | cut -b 38-40)
++abi_suffix = -$(gitverpre)$(gitverpost)
++endif
++
++ifneq ($(NOKERNLOG),)
++ubuntu_log_opts += --no-kern-log
++endif
++ifneq ($(PRINTSHAS),)
++ubuntu_log_opts += --print-shas
++endif
++
++# Get the kernels own extra version to be added to the release signature.
++raw_kernelversion=$(shell make kernelversion)
++
++#
++# full_build -- are we doing a full buildd style build
++#
++ifeq ($(wildcard /CurrentlyBuilding),)
++full_build?=false
++else
++full_build?=true
++endif
++
++#
++# The debug packages are ginormous, so you probably want to skip
++# building them (as a developer).
++#
++ifeq ($(full_build),false)
++skipdbg=true
++endif
++
++abinum		:= $(shell echo $(revision) | sed -e 's/\..*//')$(abi_suffix)
++prev_abinum	:= $(shell echo $(prev_revision) | sed -e 's/\..*//')$(abi_suffix)
++abi_release	:= $(release)-$(abinum)
++
++uploadnum	:= $(shell echo $(revision) | sed -e 's/.*\.//')
++ifneq ($(full_build),false)
++  uploadnum	:= $(uploadnum)-Ubuntu
++endif
++
++# XXX: linux-libc-dev got bumped to -803.N inadvertantly by a ti-omap4 upload
++#      shift our version higher for this package only.  Ensure this only
++#      occurs for the v2.6.35 kernel so that we do not propogate this into
++#      any other series.
++raw_uploadnum	:= $(shell echo $(revision) | sed -e 's/.*\.//')
++libc_dev_version :=
++ifeq ($(DEBIAN),debian.master)
++ifeq ($(release),2.6.35)
++libc_dev_version := -v$(release)-$(shell expr "$(abinum)" + 1000).$(raw_uploadnum)
++endif
++endif
++
++DEB_HOST_MULTIARCH = $(shell dpkg-architecture -qDEB_HOST_MULTIARCH)
++DEB_HOST_GNU_TYPE  = $(shell dpkg-architecture -qDEB_HOST_GNU_TYPE)
++DEB_BUILD_GNU_TYPE = $(shell dpkg-architecture -qDEB_BUILD_GNU_TYPE)
++DEB_HOST_ARCH = $(shell dpkg-architecture -qDEB_HOST_ARCH)
++DEB_BUILD_ARCH = $(shell dpkg-architecture -qDEB_BUILD_ARCH)
++
++#
++# Detect invocations of the form 'fakeroot debian/rules binary arch=armhf'
++# within an x86'en schroot. This only gets you part of the way since the
++# packaging phase fails, but you can at least compile the kernel quickly.
++#
++arch := $(DEB_HOST_ARCH)
++ifneq ($(arch),$(DEB_HOST_ARCH))
++	CROSS_COMPILE ?= $(shell dpkg-architecture -a$(arch) -qDEB_HOST_GNU_TYPE -f 2>/dev/null)-
++endif
++
++#
++# Detect invocations of the form 'dpkg-buildpackage -B -aarmhf' within
++# an x86'en schroot. This is the only way to build all of the packages
++# (except for tools).
++#
++ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
++	CROSS_COMPILE ?= $(DEB_HOST_GNU_TYPE)-
++endif
++
++abidir		:= $(CURDIR)/$(DEBIAN)/abi/$(release)-$(revision)/$(arch)
++prev_abidir	:= $(CURDIR)/$(DEBIAN)/abi/$(release)-$(prev_revision)/$(arch)
++commonconfdir	:= $(CURDIR)/$(DEBIAN)/config
++archconfdir	:= $(CURDIR)/$(DEBIAN)/config/$(arch)
++sharedconfdir	:= $(CURDIR)/debian.master/config
++builddir	:= $(CURDIR)/debian/build
++stampdir	:= $(CURDIR)/debian/stamps
++
++#
++# The binary package name always starts with linux-image-$KVER-$ABI.$UPLOAD_NUM. There
++# are places that you'll find linux-image hard coded, but I guess thats OK since the
++# assumption that the binary package always starts with linux-image will never change.
++#
++bin_pkg_name=linux-image-$(abi_release)
++extra_pkg_name=linux-image-extra-$(abi_release)
++hdrs_pkg_name=linux-headers-$(abi_release)
++indep_hdrs_pkg_name=$(src_pkg_name)-headers-$(abi_release)
++
++#
++# The generation of content in the doc package depends on both 'AUTOBUILD=' and
++# 'do_doc_package_content=true'. There are usually build errors during the development
++# cycle, so its OK to leave 'do_doc_package_content=false' until those build
++# failures get sorted out. Finally, the doc package doesn't really need to be built
++# for developer testing (its kind of slow), so only do it if on a buildd.
++do_doc_package=true
++do_doc_package_content=true
++ifeq ($(full_build),false)
++do_doc_package_content=false
++endif
++doc_pkg_name=$(src_pkg_name)-doc
++
++#
++# Similarly with the linux-source package, you need not build it as a developer. Its
++# somewhat I/O intensive and utterly useless.
++#
++do_source_package=true
++do_source_package_content=true
++ifeq ($(full_build),false)
++do_source_package_content=false
++endif
++
++# linux-libc-dev may not be needed, default to building it.
++do_libc_dev_package=true
++
++# common headers normally is built as an indep package, but may be arch
++do_common_headers_indep=true
++
++# add a 'full source' mode
++do_full_source=false
++
++# build tools
++ifneq ($(wildcard $(CURDIR)/tools),)
++	ifeq ($(do_tools),)
++		ifneq ($(DEB_BUILD_GNU_TYPE),$(DEB_HOST_GNU_TYPE))
++			do_tools=false
++		endif
++	endif
++	do_tools?=true
++else
++	do_tools?=false
++endif
++do_tools_common?=false
++tools_pkg_name=$(src_pkg_name)-tools-$(abi_release)
++tools_common_pkg_name=$(src_pkg_name)-tools-common
++tools_flavour_pkg_name=linux-tools-$(abi_release)
++
++# The general flavour specific image package.
++do_flavour_image_package=true
++
++# The general flavour specific header package.
++do_flavour_header_package=true
++
++# Support parallel=<n> in DEB_BUILD_OPTIONS (see #209008)
++#
++# These 2 environment variables set the -j value of the kernel build. For example,
++# CONCURRENCY_LEVEL=16 fakeroot $(DEBIAN)/rules binary-debs
++# or
++# DEB_BUILD_OPTIONS=parallel=16 fakeroot $(DEBIAN)/rules binary-debs
++#
++# The default is to use the number of CPUs.
++#
++COMMA=,
++DEB_BUILD_OPTIONS_PARA = $(subst parallel=,,$(filter parallel=%,$(subst $(COMMA), ,$(DEB_BUILD_OPTIONS))))
++ifneq (,$(DEB_BUILD_OPTIONS_PARA))
++  CONCURRENCY_LEVEL := $(DEB_BUILD_OPTIONS_PARA)
++endif
++
++ifeq ($(CONCURRENCY_LEVEL),)
++  # Check the environment
++  CONCURRENCY_LEVEL := $(shell echo $$CONCURRENCY_LEVEL)
++  # No? Then build with the number of CPUs on the host.
++  ifeq ($(CONCURRENCY_LEVEL),)
++      CONCURRENCY_LEVEL := $(shell expr `getconf _NPROCESSORS_ONLN` \* 1)
++  endif
++  # Oh hell, give 'em one
++  ifeq ($(CONCURRENCY_LEVEL),)
++    CONCURRENCY_LEVEL := 1
++  endif
++endif
++
++conc_level		= -j$(CONCURRENCY_LEVEL)
++
++# target_flavour is filled in for each step
++kmake = make ARCH=$(build_arch) \
++	CROSS_COMPILE=$(CROSS_COMPILE) \
++	KERNELVERSION=$(abi_release)-$(target_flavour) \
++	CONFIG_DEBUG_SECTION_MISMATCH=y \
++	KBUILD_BUILD_VERSION="$(uploadnum)" \
++	LOCALVERSION= localver-extra= \
++	CFLAGS_MODULE="-DPKG_ABI=$(abinum)"
++ifneq ($(LOCAL_ENV_CC),)
++kmake += CC=$(LOCAL_ENV_CC) DISTCC_HOSTS=$(LOCAL_ENV_DISTCC_HOSTS)
++endif
++
++# Locking is required in parallel builds to prevent loss of contents
++# of the debian/files.
++lockme_file = $(CURDIR)/debian/.LOCK
++lockme_cmd = flock -w 60
++lockme = $(lockme_cmd) $(lockme_file)
++
++# Checks if a var is overriden by the custom rules. Called with var and
++# flavour as arguments.
++custom_override = \
++ $(shell if [ -n "$($(1)_$(2))" ]; then echo "$($(1)_$(2))"; else echo "$($(1))"; fi)
+diff --git a/debian/rules.d/1-maintainer.mk b/debian/rules.d/1-maintainer.mk
+new file mode 100644
+index 0000000..02f9d22
+--- /dev/null
++++ b/debian/rules.d/1-maintainer.mk
+@@ -0,0 +1,120 @@
++# The following targets are for the maintainer only! do not run if you don't
++# know what they do.
++
++.PHONY: printenv updateconfigs printchanges insertchanges startnewrelease diffupstream help updateportsconfigs editportsconfigs
++
++help:
++	@echo "These are the targets in addition to the normal $(DEBIAN) ones:"
++	@echo
++	@echo "  printenv        : Print some variables used in the build"
++	@echo
++	@echo "  updateconfigs        : Update core arch configs"
++	@echo
++	@echo "  editconfigs          : Update core arch configs interractively"
++	@echo "  genconfigs           : Generate core arch configs in CONFIGS/*"
++	@echo
++	@echo "  updateportsconfigs   : Update ports arch configs"
++	@echo
++	@echo "  editportsconfigs     : Update ports arch configs interactivly"
++	@echo "  genportconfigs       : Generate ports arch configs in CONFIGS/*"
++	@echo
++	@echo "  printchanges    : Print the current changelog entries (from git)"
++	@echo
++	@echo "  insertchanges   : Insert current changelog entries (from git)"
++	@echo
++	@echo "  startnewrelease : Start a new changelog set"
++	@echo
++	@echo "  diffupstream    : Diff stock kernel code against upstream (git)"
++	@echo
++	@echo "  help            : If you are kernel hacking, you need the professional"
++	@echo "                    version of this"
++	@echo
++	@echo "Environment variables:"
++	@echo
++	@echo "  NOKERNLOG       : Do not add upstream kernel commits to changelog"
++	@echo "  CONCURRENCY_LEVEL=X"
++	@echo "                  : Use -jX for kernel compile"
++	@echo "  PRINTSHAS       : Include SHAs for commits in changelog"
++
++printdebian:
++	@echo "$(DEBIAN)"
++
++updateconfigs defaultconfigs editconfigs genconfigs dumpconfigs:
++	dh_testdir;
++	$(SHELL) $(DROOT)/scripts/misc/kernelconfig $@
++	rm -rf build
++
++updateportsconfigs defaultportsconfigs editportsconfigs genportsconfigs askconfigs:
++	dh_testdir;
++	$(SHELL) $(DROOT)/scripts/misc/kernelconfig $@ ports
++	rm -rf build
++
++printenv:
++	dh_testdir
++	@echo "src package name  = $(src_pkg_name)"
++	@echo "release           = $(release)"
++	@echo "revisions         = $(revisions)"
++	@echo "revision          = $(revision)"
++	@echo "uploadnum         = $(uploadnum)"
++	@echo "prev_revisions    = $(prev_revisions)"
++	@echo "prev_revision     = $(prev_revision)"
++	@echo "abinum            = $(abinum)"
++	@echo "gitver            = $(gitver)"
++	@echo "flavours          = $(flavours)"
++	@echo "skipabi           = $(skipabi)"
++	@echo "skipmodule        = $(skipmodule)"
++	@echo "skipdbg           = $(skipdbg)"
++	@echo "ubuntu_log_opts   = $(ubuntu_log_opts)"
++	@echo "CONCURRENCY_LEVEL = $(CONCURRENCY_LEVEL)"
++	@echo "bin package name  = $(bin_pkg_name)"
++	@echo "hdr package name  = $(hdrs_pkg_name)"
++	@echo "doc package name  = $(doc_pkg_name)"
++	@echo "do_doc_package            = $(do_doc_package)"
++	@echo "do_doc_package_content    = $(do_doc_package_content)"
++	@echo "do_source_package         = $(do_source_package)"
++	@echo "do_source_package_content = $(do_source_package_content)"
++	@echo "do_libc_dev_package       = $(do_libc_dev_package)"
++	@echo "do_flavour_image_package  = $(do_flavour_image_package)"
++	@echo "do_flavour_header_package = $(do_flavour_header_package)"
++	@echo "do_common_headers_indep   = $(do_common_headers_indep)"
++	@echo "do_full_source            = $(do_full_source)"
++	@echo "do_tools                  = $(do_tools)"
++	@echo "full_build                = $(full_build)"
++	@echo "libc_dev_version		 = $(libc_dev_version)"
++	@echo "DEB_HOST_GNU_TYPE         = $(DEB_HOST_GNU_TYPE)"
++	@echo "DEB_BUILD_GNU_TYPE        = $(DEB_BUILD_GNU_TYPE)"
++	@echo "DEB_HOST_ARCH             = $(DEB_HOST_ARCH)"
++	@echo "DEB_BUILD_ARCH            = $(DEB_BUILD_ARCH)"
++	@echo "arch                      = $(arch)"
++	@echo "kmake                     = $(kmake)"
++
++printchanges:
++	@baseCommit=$$(git log --pretty=format:'%H %s' | \
++		gawk '/UBUNTU: '".*Ubuntu-$(prev_fullver)"'$$/ { print $$1; exit }'); \
++		git log "$$baseCommit"..HEAD | \
++		perl -w -f $(DROOT)/scripts/misc/git-ubuntu-log $(ubuntu_log_opts)
++
++insertchanges:
++	@perl -w -f $(DROOT)/scripts/misc/insert-changes.pl $(DROOT) $(DEBIAN) 
++
++diffupstream:
++	@git diff-tree -p refs/remotes/linux-2.6/master..HEAD $(shell ls | grep -vE '^(ubuntu|$(DEBIAN)|\.git.*)')
++
++startnewrelease:
++	dh_testdir
++	@nextminor=$(shell expr `echo $(revision) | gawk -F. '{print $$2}'` + 1); \
++	nextmajor=$(shell expr `echo $(revision) | awk -F. '{print $$1}'` + 1); \
++	now="$(shell date -R)"; \
++	echo "Creating new changelog set for $(release)-$$nextmajor.$$nextminor..."; \
++	echo -e "$(src_pkg_name) ($(release)-$$nextmajor.$$nextminor) UNRELEASED; urgency=low\n" > $(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Do not edit directly. Autogenerated at release." >> \
++		$(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Use the printchanges target to see the curent changes." \
++		>> $(DEBIAN)/changelog.new; \
++	echo "  CHANGELOG: Use the insertchanges target to create the final log." \
++		>> $(DEBIAN)/changelog.new; \
++	echo -e "\n -- $$DEBFULLNAME <$$DEBEMAIL>  $$now\n" >> \
++		$(DEBIAN)/changelog.new ; \
++	cat $(DEBIAN)/changelog >> $(DEBIAN)/changelog.new; \
++	mv $(DEBIAN)/changelog.new $(DEBIAN)/changelog
++
+diff --git a/debian/rules.d/2-binary-arch.mk b/debian/rules.d/2-binary-arch.mk
+new file mode 100644
+index 0000000..497d770
+--- /dev/null
++++ b/debian/rules.d/2-binary-arch.mk
+@@ -0,0 +1,586 @@
++# We don't want make removing intermediary stamps
++.SECONDARY :
++
++# Prepare the out-of-tree build directory
++ifeq ($(do_full_source),true)
++build_cd = cd $(builddir)/build-$*; #
++build_O  =
++else
++build_cd =
++build_O  = O=$(builddir)/build-$*
++endif
++
++# Typically supplied from the arch makefile, e.g., debian.master/control.d/armhf.mk
++ifneq ($(gcc),)
++kmake += CC=$(CROSS_COMPILE)$(gcc)
++endif
++
++$(stampdir)/stamp-prepare-%: config-prepare-check-%
++	@echo Debug: $@
++	@touch $@
++$(stampdir)/stamp-prepare-tree-%: target_flavour = $*
++$(stampdir)/stamp-prepare-tree-%: $(commonconfdir)/config.common.$(family) $(archconfdir)/config.common.$(arch) $(archconfdir)/config.flavour.%
++	@echo Debug: $@
++	install -d $(builddir)/build-$*
++	touch $(builddir)/build-$*/ubuntu-build
++	[ "$(do_full_source)" != 'true' ] && true || \
++		rsync -a --exclude debian --exclude debian.master --exclude $(DEBIAN) * $(builddir)/build-$*
++	cat $^ | sed -e 's/.*CONFIG_VERSION_SIGNATURE.*/CONFIG_VERSION_SIGNATURE="Ubuntu $(release)-$(revision)-$* $(raw_kernelversion)"/' > $(builddir)/build-$*/.config
++	find $(builddir)/build-$* -name "*.ko" | xargs rm -f
++	$(build_cd) $(kmake) $(build_O) -j1 silentoldconfig prepare scripts
++	touch $@
++
++# Used by developers as a shortcut to prepare a tree for compilation.
++prepare-%: $(stampdir)/stamp-prepare-%
++	@echo Debug: $@
++# Used by developers to allow efficient pre-building without fakeroot.
++build-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++
++# Do the actual build, including image and modules
++$(stampdir)/stamp-build-%: target_flavour = $*
++$(stampdir)/stamp-build-%: bldimg = $(call custom_override,build_image,$*)
++$(stampdir)/stamp-build-%: dtb_target = $(dtb_files_$*)
++$(stampdir)/stamp-build-%: $(stampdir)/stamp-prepare-%
++	@echo Debug: $@ build_image $(build_image) bldimg $(bldimg)
++	$(build_cd) $(kmake) $(build_O) $(conc_level) $(bldimg) modules $(dtb_target)
++	@touch $@
++
++# Install the finished build
++install-%: pkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*
++install-%: pkgdir_ex = $(CURDIR)/debian/$(extra_pkg_name)-$*
++install-%: bindoc = $(pkgdir)/usr/share/doc/$(bin_pkg_name)-$*
++install-%: dbgpkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*-dbgsym
++install-%: signed = $(CURDIR)/debian/$(bin_pkg_name)-signed
++install-%: toolspkgdir = $(CURDIR)/debian/$(tools_flavour_pkg_name)-$*
++install-%: basepkg = $(hdrs_pkg_name)
++install-%: indeppkg = $(indep_hdrs_pkg_name)
++install-%: kernfile = $(call custom_override,kernel_file,$*)
++install-%: instfile = $(call custom_override,install_file,$*)
++install-%: hdrdir = $(CURDIR)/debian/$(basepkg)-$*/usr/src/$(basepkg)-$*
++install-%: target_flavour = $*
++install-%: dtb_files = $(dtb_files_$*)
++install-%: checks-%
++	@echo Debug: $@ kernel_file $(kernel_file) kernfile $(kernfile) install_file $(install_file) instfile $(instfile)
++	dh_testdir
++	dh_testroot
++	dh_clean -k -p$(bin_pkg_name)-$*
++	dh_clean -k -p$(hdrs_pkg_name)-$*
++ifneq ($(skipdbg),true)
++	dh_clean -k -p$(dbg_pkg_name)-$*
++endif
++
++	# The main image
++	# compress_file logic required because not all architectures
++	# generate a zImage automatically out of the box
++ifeq ($(compress_file),)
++	install -m600 -D $(builddir)/build-$*/$(kernfile) \
++		$(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++else
++	install -d $(pkgdir)/boot
++	gzip -c9v $(builddir)/build-$*/$(kernfile) > \
++		$(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++	chmod 600 $(pkgdir)/boot/$(instfile)-$(abi_release)-$*
++endif
++
++ifeq ($(arch),amd64)
++ifeq ($(uefi_signed),true)
++	install -d $(signed)/$(release)-$(revision)
++	# Check to see if this supports handoff, if not do not sign it.
++	# Check the identification area magic and version >= 0x020b
++	handoff=`dd if="$(pkgdir)/boot/$(instfile)-$(abi_release)-$*" bs=1 skip=514 count=6 2>/dev/null | od -s | gawk '($$1 == 0 && $$2 == 25672 && $$3 == 21362 && $$4 >= 523) { print "GOOD" }'`; \
++	if [ "$$handoff" = "GOOD" ]; then \
++		cp -p $(pkgdir)/boot/$(instfile)-$(abi_release)-$* \
++			$(signed)/$(release)-$(revision)/$(instfile)-$(abi_release)-$*.efi; \
++	fi
++endif
++endif
++
++	install -m644 $(builddir)/build-$*/.config \
++		$(pkgdir)/boot/config-$(abi_release)-$*
++	install -m644 $(abidir)/$* \
++		$(pkgdir)/boot/abi-$(abi_release)-$*
++	install -m600 $(builddir)/build-$*/System.map \
++		$(pkgdir)/boot/System.map-$(abi_release)-$*
++	if [ "$(dtb_files)" ]; then \
++		install -d $(pkgdir)/lib/firmware/$(abi_release)-$*/device-tree; \
++		for dtb_file in $(dtb_files); do \
++			install -m644 $(builddir)/build-$*/arch/$(build_arch)/boot/dts/$$dtb_file \
++				$(pkgdir)/lib/firmware/$(abi_release)-$*/device-tree/$$dtb_file; \
++		done \
++	fi
++ifeq ($(no_dumpfile),)
++	makedumpfile -g $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$* \
++		-x $(builddir)/build-$*/vmlinux
++	chmod 0600 $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$*
++endif
++
++	$(build_cd) $(kmake) $(build_O) $(conc_level) modules_install \
++		INSTALL_MOD_STRIP=1 INSTALL_MOD_PATH=$(pkgdir)/ \
++		INSTALL_FW_PATH=$(pkgdir)/lib/firmware/$(abi_release)-$*
++
++ifeq ($(do_extras_package),true)
++	#
++	# Remove all modules not in the inclusion list.
++	#
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then \
++		mkdir -p $(pkgdir_ex)/lib/modules/$(abi_release)-$*; \
++		mv $(pkgdir)/lib/modules/$(abi_release)-$*/kernel \
++			$(pkgdir_ex)/lib/modules/$(abi_release)-$*/kernel; \
++		$(SHELL) $(DROOT)/scripts/module-inclusion --master \
++			$(pkgdir_ex)/lib/modules/$(abi_release)-$*/kernel \
++			$(pkgdir)/lib/modules/$(abi_release)-$*/kernel \
++			$(DEBIAN)/control.d/$(target_flavour).inclusion-list 2>&1 | \
++				tee $(target_flavour).inclusion-list.log; \
++		/sbin/depmod -b $(pkgdir) -ea -F $(pkgdir)/boot/System.map-$(abi_release)-$* \
++			$(abi_release)-$* 2>&1 |tee $(target_flavour).depmod.log; \
++		if [ `grep -c 'unknown symbol' $(target_flavour).depmod.log` -gt 0 ]; then \
++			echo "EE: Unresolved module dependencies in base package!"; \
++			exit 1; \
++		fi \
++	fi
++endif
++
++ifeq ($(no_dumpfile),)
++	makedumpfile -g $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$* \
++		-x $(builddir)/build-$*/vmlinux
++	chmod 0600 $(pkgdir)/boot/vmcoreinfo-$(abi_release)-$*
++endif
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/build
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/source
++
++	# Some initramfs-tools specific modules
++	install -d $(pkgdir)/lib/modules/$(abi_release)-$*/initrd
++	if [ -f $(pkgdir)/lib/modules/$(abi_release)-$*/kernel/drivers/video/vesafb.ko ]; then\
++	  ln -f $(pkgdir)/lib/modules/$(abi_release)-$*/kernel/drivers/video/vesafb.ko \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/initrd/; \
++	fi
++
++	# Now the image scripts
++	install -d $(pkgdir)/DEBIAN
++	for script in postinst postrm preinst prerm; do				\
++	  sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'		\
++	      -e 's/=L/$(loader)/g'         -e 's@=B@$(build_arch)@g'		\
++	       $(DROOT)/control-scripts/$$script > $(pkgdir)/DEBIAN/$$script;	\
++	  chmod 755 $(pkgdir)/DEBIAN/$$script;					\
++	done
++ifeq ($(do_extras_package),true)
++	# Install the postinit/postrm scripts in the extras package.
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then	\
++		install -d $(pkgdir_ex)/DEBIAN;					\
++		for script in postinst postrm ; do				\
++			sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'		\
++			    -e 's/=L/$(loader)/g'         -e 's@=B@$(build_arch)@g'		\
++			    debian/control-scripts/$$script > $(pkgdir_ex)/DEBIAN/$$script; \
++			chmod 755 $(pkgdir_ex)/DEBIAN/$$script;			\
++		done;								\
++	fi
++endif
++
++	# Install the full changelog.
++ifeq ($(do_doc_package),true)
++	install -d $(bindoc)
++	cat $(DEBIAN)/changelog $(DEBIAN)/changelog.historical | \
++		gzip -9 >$(bindoc)/changelog.Debian.old.gz
++	chmod 644 $(bindoc)/changelog.Debian.old.gz
++endif
++
++ifneq ($(skipsub),true)
++	for sub in $($(*)_sub); do					\
++		if ! (TO=$$sub FROM=$* ABI_RELEASE=$(abi_release) $(SHELL)		\
++			$(DROOT)/scripts/sub-flavour); then exit 1; fi;		\
++		/sbin/depmod -b debian/$(bin_pkg_name)-$$sub		\
++			-ea -F debian/$(bin_pkg_name)-$$sub/boot/System.map-$(abi_release)-$* \
++			$(abi_release)-$*;					\
++		install -d debian/$(bin_pkg_name)-$$sub/DEBIAN;	\
++		for script in postinst postrm preinst prerm; do			\
++			sed -e 's/=V/$(abi_release)-$*/g'			\
++			    -e 's/=K/$(instfile)/g'				\
++			    -e 's/=L/$(loader)/g'				\
++			    -e 's@=B@$(build_arch)@g'				\
++				$(DROOT)/control-scripts/$$script >		\
++				debian/$(bin_pkg_name)-$$sub/DEBIAN/$$script;\
++			chmod 755  debian/$(bin_pkg_name)-$$sub/DEBIAN/$$script;\
++		done;								\
++	done
++endif
++
++ifneq ($(skipdbg),true)
++	# Debug image is simple
++	install -m644 -D $(builddir)/build-$*/vmlinux \
++		$(dbgpkgdir)/usr/lib/debug/boot/vmlinux-$(abi_release)-$*
++	$(build_cd) $(kmake) $(build_O) modules_install \
++		INSTALL_MOD_PATH=$(dbgpkgdir)/usr/lib/debug
++	# Add .gnu_debuglink sections to each stripped .ko
++	# pointing to unstripped verson
++	find $(pkgdir) -name '*.ko' | sed 's|$(pkgdir)||'| while read module ; do \
++		if [[ -f "$(dbgpkgdir)/usr/lib/debug/$$module" ]] ; then \
++			$(CROSS_COMPILE)objcopy \
++				--add-gnu-debuglink=$(dbgpkgdir)/usr/lib/debug/$$module \
++				$(pkgdir)/$$module; \
++		fi; \
++	done
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/build
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/source
++	rm -f $(dbgpkgdir)/usr/lib/debug/lib/modules/$(abi_release)-$*/modules.*
++	rm -fr $(dbgpkgdir)/usr/lib/debug/lib/firmware
++endif
++
++	# The flavour specific headers image
++	# TODO: Would be nice if we didn't have to dupe the original builddir
++	install -d -m755 $(hdrdir)
++	cat $(builddir)/build-$*/.config | \
++		sed -e 's/.*CONFIG_DEBUG_INFO=.*/# CONFIG_DEBUG_INFO is not set/g' > \
++		$(hdrdir)/.config
++	chmod 644 $(hdrdir)/.config
++	$(kmake) O=$(hdrdir) -j1 silentoldconfig prepare scripts
++	# We'll symlink this stuff
++	rm -f $(hdrdir)/Makefile
++	rm -rf $(hdrdir)/include2 $(hdrdir)/source
++	# Copy over the compilation version.
++	cp "$(builddir)/build-$*/include/generated/compile.h" \
++		"$(hdrdir)/include/generated/compile.h"
++	# powerpc seems to need some .o files for external module linking. Add them in.
++ifeq ($(arch),powerpc)
++	mkdir -p $(hdrdir)/arch/powerpc/lib
++	cp $(builddir)/build-$*/arch/powerpc/lib/*.o $(hdrdir)/arch/powerpc/lib
++endif
++	# Script to symlink everything up
++	$(SHELL) $(DROOT)/scripts/link-headers "$(hdrdir)" "$(indeppkg)" "$*"
++	# The build symlink
++	install -d debian/$(basepkg)-$*/lib/modules/$(abi_release)-$*
++	ln -s /usr/src/$(basepkg)-$* \
++		debian/$(basepkg)-$*/lib/modules/$(abi_release)-$*/build
++	# And finally the symvers
++	install -m644 $(builddir)/build-$*/Module.symvers \
++		$(hdrdir)/Module.symvers
++
++	# Now the header scripts
++	install -d $(CURDIR)/debian/$(basepkg)-$*/DEBIAN
++	for script in postinst; do						\
++	  sed -e 's/=V/$(abi_release)-$*/g' -e 's/=K/$(instfile)/g'	\
++		$(DROOT)/control-scripts/headers-$$script > 			\
++			$(CURDIR)/debian/$(basepkg)-$*/DEBIAN/$$script;		\
++	  chmod 755 $(CURDIR)/debian/$(basepkg)-$*/DEBIAN/$$script;		\
++	done
++
++	# At the end of the package prep, call the tests
++	DPKG_ARCH="$(arch)" KERN_ARCH="$(build_arch)" FLAVOUR="$*"	\
++	 VERSION="$(abi_release)" REVISION="$(revision)"		\
++	 PREV_REVISION="$(prev_revision)" ABI_NUM="$(abinum)"		\
++	 PREV_ABI_NUM="$(prev_abinum)" BUILD_DIR="$(builddir)/build-$*"	\
++	 INSTALL_DIR="$(pkgdir)" SOURCE_DIR="$(CURDIR)"			\
++	 run-parts -v $(DROOT)/tests-build
++
++	#
++	# Remove files which are generated at installation by postinst,
++	# except for modules.order and modules.builtin
++	# 
++	# NOTE: need to keep this list in sync with postrm
++	#
++	mkdir $(pkgdir)/lib/modules/$(abi_release)-$*/_
++	mv $(pkgdir)/lib/modules/$(abi_release)-$*/modules.order \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/_
++	if [ -f $(pkgdir)/lib/modules/$(abi_release)-$*/modules.builtin ] ; then \
++	    mv $(pkgdir)/lib/modules/$(abi_release)-$*/modules.builtin \
++		$(pkgdir)/lib/modules/$(abi_release)-$*/_; \
++	fi
++	rm -f $(pkgdir)/lib/modules/$(abi_release)-$*/modules.*
++	mv $(pkgdir)/lib/modules/$(abi_release)-$*/_/* \
++		$(pkgdir)/lib/modules/$(abi_release)-$*
++	rmdir $(pkgdir)/lib/modules/$(abi_release)-$*/_
++
++ifeq ($(do_tools),true)
++	# Create the linux-tools version-flavour link
++	install -d $(toolspkgdir)/usr/lib/linux-tools
++	ln -s ../$(src_pkg_name)-tools-$(abi_release) $(toolspkgdir)/usr/lib/linux-tools/$(abi_release)-$*
++endif
++
++headers_tmp := $(CURDIR)/debian/tmp-headers
++headers_dir := $(CURDIR)/debian/linux-libc-dev
++
++hmake := $(MAKE) -C $(CURDIR) O=$(headers_tmp) \
++	KERNELVERSION=$(abi_release) INSTALL_HDR_PATH=$(headers_tmp)/install \
++	SHELL="$(SHELL)" ARCH=$(header_arch)
++
++install-arch-headers:
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++	dh_clean -k -plinux-libc-dev
++
++	rm -rf $(headers_tmp)
++	install -d $(headers_tmp) $(headers_dir)/usr/include/
++
++	$(hmake) $(defconfig)
++	mv $(headers_tmp)/.config $(headers_tmp)/.config.old
++	sed -e 's/^# \(CONFIG_MODVERSIONS\) is not set$$/\1=y/' \
++	  -e 's/.*CONFIG_LOCALVERSION_AUTO.*/# CONFIG_LOCALVERSION_AUTO is not set/' \
++	  $(headers_tmp)/.config.old > $(headers_tmp)/.config
++	$(hmake) silentoldconfig
++	$(hmake) headers_install
++
++	( cd $(headers_tmp)/install/include/ && \
++		find . -name '.' -o -name '.*' -prune -o -print | \
++                cpio -pvd --preserve-modification-time \
++			$(headers_dir)/usr/include/ )
++	mkdir $(headers_dir)/usr/include/$(DEB_HOST_MULTIARCH)
++	mv $(headers_dir)/usr/include/asm $(headers_dir)/usr/include/$(DEB_HOST_MULTIARCH)/
++
++	rm -rf $(headers_tmp)
++
++binary-arch-headers: install-arch-headers
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++ifeq ($(do_libc_dev_package),true)
++ifneq ($(DEBIAN),debian.master)
++	echo "non-master branch building linux-libc-dev, aborting"
++	exit 1
++endif
++	dh_installchangelogs -plinux-libc-dev
++	dh_installdocs -plinux-libc-dev
++	dh_compress -plinux-libc-dev
++	dh_fixperms -plinux-libc-dev
++	dh_installdeb -plinux-libc-dev
++	$(lockme) dh_gencontrol -plinux-libc-dev -- $(libc_dev_version)
++	dh_md5sums -plinux-libc-dev
++	dh_builddeb -plinux-libc-dev
++endif
++
++binary-%: pkgimg = $(bin_pkg_name)-$*
++binary-%: pkgimg_ex = $(extra_pkg_name)-$*
++binary-%: pkghdr = $(hdrs_pkg_name)-$*
++binary-%: dbgpkg = $(bin_pkg_name)-$*-dbgsym
++binary-%: dbgpkgdir = $(CURDIR)/debian/$(bin_pkg_name)-$*-dbgsym
++binary-%: pkgtools = $(tools_flavour_pkg_name)-$*
++binary-%: target_flavour = $*
++binary-%: install-%
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++
++	dh_installchangelogs -p$(pkgimg)
++	dh_installdocs -p$(pkgimg)
++	dh_compress -p$(pkgimg)
++	dh_fixperms -p$(pkgimg) -X/boot/
++	dh_installdeb -p$(pkgimg)
++	dh_shlibdeps -p$(pkgimg)
++	$(lockme) dh_gencontrol -p$(pkgimg)
++	dh_md5sums -p$(pkgimg)
++	dh_builddeb -p$(pkgimg) -- -Zbzip2 -z9
++
++ifeq ($(do_extras_package),true)
++	if [ -f $(DEBIAN)/control.d/$(target_flavour).inclusion-list ] ; then \
++		dh_installchangelogs -p$(pkgimg_ex); \
++		dh_installdocs -p$(pkgimg_ex); \
++		dh_compress -p$(pkgimg_ex); \
++		dh_fixperms -p$(pkgimg_ex) -X/boot/; \
++		dh_installdeb -p$(pkgimg_ex); \
++		dh_shlibdeps -p$(pkgimg_ex); \
++		$(lockme) dh_gencontrol -p$(pkgimg_ex); \
++		dh_md5sums -p$(pkgimg_ex); \
++		dh_builddeb -p$(pkgimg_ex) -- -Zbzip2 -z9; \
++	fi
++endif
++
++	dh_installchangelogs -p$(pkghdr)
++	dh_installdocs -p$(pkghdr)
++	dh_compress -p$(pkghdr)
++	dh_fixperms -p$(pkghdr)
++	dh_shlibdeps -p$(pkghdr)
++	dh_installdeb -p$(pkghdr)
++	$(lockme) dh_gencontrol -p$(pkghdr)
++	dh_md5sums -p$(pkghdr)
++	dh_builddeb -p$(pkghdr)
++
++ifneq ($(skipsub),true)
++	@set -e; for sub in $($(*)_sub); do		\
++		pkg=$(bin_pkg_name)-$$sub;	\
++		dh_installchangelogs -p$$pkg;		\
++		dh_installdocs -p$$pkg;			\
++		dh_compress -p$$pkg;			\
++		dh_fixperms -p$$pkg -X/boot/;		\
++		dh_shlibdeps -p$$pkg;			\
++		dh_installdeb -p$$pkg;			\
++		$(lockme) dh_gencontrol -p$$pkg;			\
++		dh_md5sums -p$$pkg;			\
++		dh_builddeb -p$$pkg;			\
++	done
++endif
++
++ifneq ($(skipdbg),true)
++	dh_installchangelogs -p$(dbgpkg)
++	dh_installdocs -p$(dbgpkg)
++	dh_compress -p$(dbgpkg)
++	dh_fixperms -p$(dbgpkg)
++	dh_installdeb -p$(dbgpkg)
++	$(lockme) dh_gencontrol -p$(dbgpkg)
++	dh_md5sums -p$(dbgpkg)
++	dh_builddeb -p$(dbgpkg)
++
++	# Hokay...here's where we do a little twiddling...
++	# Renaming the debug package prevents it from getting into
++	# the primary archive, and therefore prevents this very large
++	# package from being mirrored. It is instead, through some
++	# archive admin hackery, copied to http://ddebs.ubuntu.com.
++	#
++	mv ../$(dbgpkg)_$(release)-$(revision)_$(arch).deb \
++		../$(dbgpkg)_$(release)-$(revision)_$(arch).ddeb
++	set -e; \
++	( \
++		$(lockme_cmd) 9 || exit 1; \
++		if grep -qs '^Build-Debug-Symbols: yes$$' /CurrentlyBuilding; then \
++			sed -i '/^$(dbgpkg)_/s/\.deb /.ddeb /' debian/files; \
++		else \
++			grep -v '^$(dbgpkg)_.*$$' debian/files > debian/files.new; \
++			mv debian/files.new debian/files; \
++		fi; \
++	) 9>$(lockme_file)
++	# Now, the package wont get into the archive, but it will get put
++	# into the debug system.
++endif
++
++ifeq ($(do_tools),true)
++	dh_installchangelogs -p$(pkgtools)
++	dh_installdocs -p$(pkgtools)
++	dh_compress -p$(pkgtools)
++	dh_fixperms -p$(pkgtools)
++	dh_shlibdeps -p$(pkgtools)
++	dh_installdeb -p$(pkgtools)
++	$(lockme) dh_gencontrol -p$(pkgtools)
++	dh_md5sums -p$(pkgtools)
++	dh_builddeb -p$(pkgtools)
++endif
++
++ifneq ($(full_build),false)
++	# Clean out this flavours build directory.
++	rm -rf $(builddir)/build-$*
++	# Clean out the debugging package source directory.
++	rm -rf $(dbgpkgdir)
++endif
++
++#
++# per-architecture packages
++#
++builddirpa = $(builddir)/tools-perarch
++
++$(stampdir)/stamp-prepare-perarch:
++	@echo Debug: $@
++ifeq ($(do_tools),true)
++	rm -rf $(builddirpa)
++	install -d $(builddirpa)
++	for i in *; do ln -s $(CURDIR)/$$i $(builddirpa); done
++	rm $(builddirpa)/tools
++	rsync -a tools/ $(builddirpa)/tools/
++endif
++	touch $@
++
++$(stampdir)/stamp-build-perarch: $(stampdir)/stamp-prepare-perarch
++	@echo Debug: $@
++ifeq ($(do_tools),true)
++
++ifeq ($(do_tools_cpupower),true)
++	# Allow for multiple installed versions of cpupower and libcpupower.so:
++	# Override LIB_MIN in order to to generate a versioned .so named
++	# libcpupower.so.$(abi_release) and link cpupower with that.
++	make -C $(builddirpa)/tools/power/cpupower \
++		ARCH=$(arch) \
++		CROSS=$(CROSS_COMPILE) \
++		LIB_MIN=$(abi_release) CPUFREQ_BENCH=false
++endif
++
++ifeq ($(do_tools_perf),true)
++	cd $(builddirpa)/tools/perf && \
++		make prefix=/usr ARCH=$(arch) HAVE_CPLUS_DEMANGLE=1 CROSS_COMPILE=$(CROSS_COMPILE) NO_LIBPYTHON=1 NO_LIBPERL=1 PYTHON=python2.7
++endif
++ifeq ($(do_tools_x86),true)
++	cd $(builddirpa)/tools/power/x86/x86_energy_perf_policy && make ARCH=$(arch) CROSS_COMPILE=$(CROSS_COMPILE)
++	cd $(builddirpa)/tools/power/x86/turbostat && make ARCH=$(arch) CROSS_COMPILE=$(CROSS_COMPILE)
++endif
++ifeq ($(do_tools_hyperv),true)
++	cd $(builddirpa)/tools/hv && make ARCH=$(arch) CROSS_COMPILE=$(CROSS_COMPILE)
++endif
++endif
++	@touch $@
++
++install-perarch: toolspkgdir = $(CURDIR)/debian/$(tools_pkg_name)
++install-perarch: $(stampdir)/stamp-build-perarch
++	@echo Debug: $@
++	# Add the tools.
++ifeq ($(do_tools),true)
++	install -d $(toolspkgdir)/usr/lib
++	install -d $(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++
++ifeq ($(do_tools_cpupower),true)
++	install -m755 $(builddirpa)/tools/power/cpupower/cpupower \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	# Install only the full versioned libcpupower.so.$(abi_release), not
++	# the usual symlinks to it.
++	install -m644 $(builddirpa)/tools/power/cpupower/libcpupower.so.$(abi_release) \
++		$(toolspkgdir)/usr/lib/
++endif
++
++ifeq ($(do_tools_perf),true)
++	install -m755 $(builddirpa)/tools/perf/perf $(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++ifeq ($(do_tools_x86),true)
++	install -m755 $(builddirpa)/tools/power/x86/x86_energy_perf_policy/x86_energy_perf_policy \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/power/x86/turbostat/turbostat \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++ifeq ($(do_tools_hyperv),true)
++	install -m755 $(builddirpa)/tools/hv/hv_kvp_daemon \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++	install -m755 $(builddirpa)/tools/hv/hv_vss_daemon \
++		$(toolspkgdir)/usr/lib/$(src_pkg_name)-tools-$(abi_release)
++endif
++endif
++
++binary-perarch: toolspkg = $(tools_pkg_name)
++binary-perarch: install-perarch
++	@echo Debug: $@
++ifeq ($(do_tools),true)
++	dh_strip -p$(toolspkg)
++	dh_installchangelogs -p$(toolspkg)
++	dh_installdocs -p$(toolspkg)
++	dh_compress -p$(toolspkg)
++	dh_fixperms -p$(toolspkg)
++	dh_shlibdeps -p$(toolspkg)
++	dh_installdeb -p$(toolspkg)
++	$(lockme) dh_gencontrol -p$(toolspkg)
++	dh_md5sums -p$(toolspkg)
++	dh_builddeb -p$(toolspkg)
++endif
++
++binary-debs: signed = $(CURDIR)/debian/$(bin_pkg_name)-signed
++binary-debs: signedv = $(CURDIR)/debian/$(bin_pkg_name)-signed/$(release)-$(revision)
++binary-debs: signed_tar = $(src_pkg_name)_$(release)-$(revision)_$(arch).tar.gz
++binary-debs: binary-perarch $(addprefix binary-,$(flavours))
++	@echo Debug: $@
++ifeq ($(arch),amd64)
++ifeq ($(uefi_signed),true)
++	echo $(release)-$(revision) > $(signedv)/version
++	cd $(signedv) && ls *.efi >flavours
++	cd $(signed) && tar czvf ../../../$(signed_tar) .
++	dpkg-distaddfile $(signed_tar) raw-uefi -
++endif
++endif
++
++build-arch-deps-$(do_flavour_image_package) += $(addprefix $(stampdir)/stamp-build-,$(flavours))
++build-arch: $(build-arch-deps-true)
++	@echo Debug: $@
++
++ifeq ($(AUTOBUILD),)
++binary-arch-deps-$(do_flavour_image_package) += binary-udebs
++else
++binary-arch-deps-$(do_flavour_image_package) = binary-debs
++endif
++binary-arch-deps-$(do_libc_dev_package) += binary-arch-headers
++ifneq ($(do_common_headers_indep),true)
++binary-arch-deps-$(do_flavour_header_package) += binary-headers
++endif
++binary-arch: $(binary-arch-deps-true)
++	@echo Debug: $@
++
+diff --git a/debian/rules.d/3-binary-indep.mk b/debian/rules.d/3-binary-indep.mk
+new file mode 100644
+index 0000000..be82eb1
+--- /dev/null
++++ b/debian/rules.d/3-binary-indep.mk
+@@ -0,0 +1,149 @@
++build-indep:
++	@echo Debug: $@
++
++# The binary-indep dependency chain is:
++#
++# install-headers <- install-doc <- install-source <- install-tools <- install-indep <- binary-indep
++# install-headers <- binary-headers
++#
++indep_hdrpkg = $(indep_hdrs_pkg_name)
++indep_hdrdir = $(CURDIR)/debian/$(indep_hdrpkg)/usr/src/$(indep_hdrpkg)
++install-headers:
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++	dh_prep
++
++ifeq ($(do_flavour_header_package),true)
++	install -d $(indep_hdrdir)
++	find . -path './debian' -prune -o -path './$(DEBIAN)' -prune \
++	  -o -path './include/*' -prune \
++	  -o -path './scripts/*' -prune -o -type f \
++	  \( -name 'Makefile*' -o -name 'Kconfig*' -o -name 'Kbuild*' -o \
++	     -name '*.sh' -o -name '*.pl' -o -name '*.lds' \) \
++	  -print | cpio -pd --preserve-modification-time $(indep_hdrdir)
++	cp -a scripts include $(indep_hdrdir)
++	(find arch -name include -type d -print | \
++		xargs -n1 -i: find : -type f) | \
++		cpio -pd --preserve-modification-time $(indep_hdrdir)
++endif
++
++docpkg = $(doc_pkg_name)
++docdir = $(CURDIR)/debian/$(docpkg)/usr/share/doc/$(docpkg)
++install-doc: install-headers
++	@echo Debug: $@
++ifeq ($(do_doc_package),true)
++	dh_testdir
++	dh_testroot
++
++	install -d $(docdir)
++ifeq ($(do_doc_package_content),true)
++	# First the html docs. We skip these for autobuilds
++	if [ -z "$(AUTOBUILD)" ]; then \
++		install -d $(docdir)/$(doc_pkg_name)-tmp; \
++		$(kmake) O=$(docdir)/$(doc_pkg_name)-tmp htmldocs; \
++		mv $(docdir)/$(doc_pkg_name)-tmp/Documentation/DocBook \
++			$(docdir)/html; \
++		rm -rf $(docdir)/$(doc_pkg_name)-tmp; \
++	fi
++endif
++	# Copy the rest
++	cp -a Documentation/* $(docdir)
++	rm -rf $(docdir)/DocBook
++	find $(docdir) -name .gitignore | xargs rm -f
++endif
++
++srcpkg = $(src_pkg_name)-source-$(release)
++srcdir = $(CURDIR)/debian/$(srcpkg)/usr/src/$(srcpkg)
++balldir = $(CURDIR)/debian/$(srcpkg)/usr/src/$(srcpkg)/$(srcpkg)
++install-source: install-doc
++	@echo Debug: $@
++ifeq ($(do_source_package),true)
++
++	install -d $(srcdir)
++ifeq ($(do_source_package_content),true)
++	find . -path './debian' -prune -o -path './$(DEBIAN)' -prune -o \
++		-path './.*' -prune -o -print | \
++		cpio -pd --preserve-modification-time $(balldir)
++	(cd $(srcdir); tar cf - $(srcpkg)) | bzip2 -9c > \
++		$(srcdir)/$(srcpkg).tar.bz2
++	rm -rf $(balldir)
++	find './debian' './$(DEBIAN)' \
++		-path './debian/linux-*' -prune -o \
++		-path './debian/$(src_pkg_name)-*' -prune -o \
++		-path './debian/build' -prune -o \
++		-path './debian/files' -prune -o \
++		-path './debian/stamps' -prune -o \
++		-path './debian/tmp' -prune -o \
++		-print | \
++		cpio -pd --preserve-modification-time $(srcdir)
++	ln -s $(srcpkg)/$(srcpkg).tar.bz2 $(srcdir)/..
++endif
++endif
++
++install-tools: toolspkg = $(tools_common_pkg_name)
++install-tools: toolsbin = $(CURDIR)/debian/$(toolspkg)/usr/bin
++install-tools: toolssbin = $(CURDIR)/debian/$(toolspkg)/usr/sbin
++install-tools: toolsman = $(CURDIR)/debian/$(toolspkg)/usr/share/man
++install-tools: install-source $(stampdir)/stamp-build-perarch
++	@echo Debug: $@
++ifeq ($(do_tools_common),true)
++	install -d $(toolsbin)
++	install -d $(toolsman)/man1
++
++	install -m755 debian/tools/generic $(toolsbin)/cpupower
++	install -m644 $(CURDIR)/tools/power/cpupower/man/*.1 $(toolsman)/man1/
++
++	install -m755 debian/tools/generic $(toolsbin)/perf
++
++	install -m755 debian/tools/generic $(toolsbin)/x86_energy_perf_policy
++	install -m755 debian/tools/generic $(toolsbin)/turbostat
++
++	install -d $(toolssbin)
++	install -m755 debian/tools/generic $(toolssbin)/hv_kvp_daemon
++	install -m755 debian/tools/generic $(toolssbin)/hv_vss_daemon
++
++	rm -rf $(builddir)/tools
++	install -d $(builddir)/tools
++	for i in *; do ln -s $(CURDIR)/$$i $(builddir)/tools/; done
++	rm $(builddir)/tools/tools
++	rsync -a tools/ $(builddir)/tools/tools/
++
++	cd $(builddir)/tools/tools/perf && make man
++	install -m644 $(builddir)/tools/tools/perf/Documentation/*.1 \
++		$(toolsman)/man1
++
++	install -d $(toolsman)/man8
++	install -m644 $(CURDIR)/tools/power/x86/x86_energy_perf_policy/*.8 $(toolsman)/man8
++	install -m644 $(CURDIR)/tools/power/x86/turbostat/*.8 $(toolsman)/man8
++
++	install -m644 $(CURDIR)/tools/hv/*.8 $(toolsman)/man8
++endif
++
++install-indep: install-tools
++	@echo Debug: $@
++
++# This is just to make it easy to call manually. Normally done in
++# binary-indep target during builds.
++binary-headers: install-headers
++	@echo Debug: $@
++	dh_installchangelogs -p$(indep_hdrpkg)
++	dh_installdocs -p$(indep_hdrpkg)
++	dh_compress -p$(indep_hdrpkg)
++	dh_fixperms -p$(indep_hdrpkg)
++	dh_installdeb -p$(indep_hdrpkg)
++	$(lockme) dh_gencontrol -p$(indep_hdrpkg)
++	dh_md5sums -p$(indep_hdrpkg)
++	dh_builddeb -p$(indep_hdrpkg)
++
++binary-indep: install-indep
++	@echo Debug: $@
++
++	dh_installchangelogs -i
++	dh_installdocs -i
++	dh_compress -i
++	dh_fixperms -i
++	dh_installdeb -i
++	$(lockme) dh_gencontrol -i
++	dh_md5sums -i
++	dh_builddeb -i
+diff --git a/debian/rules.d/4-checks.mk b/debian/rules.d/4-checks.mk
+new file mode 100644
+index 0000000..a3c8ed9
+--- /dev/null
++++ b/debian/rules.d/4-checks.mk
+@@ -0,0 +1,27 @@
++# Check ABI for package against last release (if not same abinum)
++abi-check-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++	install -d $(abidir)
++	sed -e 's/^\(.\+\)[[:space:]]\+\(.\+\)[[:space:]]\(.\+\)$$/\3 \2 \1/'	\
++		$(builddir)/build-$*/Module.symvers | sort > $(abidir)/$*
++	@perl -f $(DROOT)/scripts/abi-check "$*" "$(prev_abinum)" "$(abinum)" \
++		"$(prev_abidir)" "$(abidir)" "$(skipabi)"
++
++# Check the module list against the last release (always)
++module-check-%: $(stampdir)/stamp-build-%
++	@echo Debug: $@
++	install -d $(abidir)
++	find $(builddir)/build-$*/ -name \*.ko | \
++		sed -e 's/.*\/\([^\/]*\)\.ko/\1/' | sort > $(abidir)/$*.modules
++	@perl -f $(DROOT)/scripts/module-check "$*" \
++		"$(prev_abidir)" "$(abidir)" $(skipmodule)
++
++checks-%: module-check-% abi-check-%
++	@echo Debug: $@
++
++# Check the config against the known options list.
++config-prepare-check-%: $(stampdir)/stamp-prepare-tree-%
++	@echo Debug: $@
++	@perl -f $(DROOT)/scripts/config-check \
++		$(builddir)/build-$*/.config "$(arch)" "$*" "$(sharedconfdir)" "$(skipconfig)"
++
+diff --git a/debian/rules.d/5-udebs.mk b/debian/rules.d/5-udebs.mk
+new file mode 100644
+index 0000000..daf87f6
+--- /dev/null
++++ b/debian/rules.d/5-udebs.mk
+@@ -0,0 +1,67 @@
++# Do udebs if not disabled in the arch-specific makefile
++binary-udebs: binary-debs
++	@echo Debug: $@
++ifeq ($(disable_d_i),)
++	@$(MAKE) --no-print-directory -f $(DROOT)/rules DEBIAN=$(DEBIAN) \
++		do-binary-udebs
++endif
++
++do-binary-udebs: debian/control
++	@echo Debug: $@
++	dh_testdir
++	dh_testroot
++
++	# unpack the kernels into a temporary directory
++	mkdir -p debian/d-i-${arch}
++
++	imagelist=$$(cat $(builddir)/kernel-versions | grep ^${arch} | gawk '{print $$4}') && \
++	for i in $$imagelist; do \
++	  dpkg -x $$(ls ../linux-image-$$i\_$(release)-$(revision)_${arch}.deb) \
++		debian/d-i-${arch}; \
++	  if [ -f ../linux-image-extra-$$i\_$(release)-$(revision)_${arch}.deb ] ; then \
++	    dpkg -x ../linux-image-extra-$$i\_$(release)-$(revision)_${arch}.deb \
++		  debian/d-i-${arch}; \
++	  fi; \
++	  /sbin/depmod -b debian/d-i-${arch} $$i; \
++	done
++
++	# kernel-wedge will error if no modules unless this is touched
++	touch $(CURDIR)/debian/build/no-modules
++
++	touch ignore-dups
++	export SOURCEDIR=$(CURDIR)/debian/d-i-${arch} && \
++	  cd $(builddir) && \
++	  kernel-wedge install-files && \
++	  kernel-wedge check
++
++        # Build just the udebs
++	dilist=$$(dh_listpackages -s | grep "\-di$$") && \
++	[ -z "$dilist" ] || \
++	for i in $$dilist; do \
++	  dh_fixperms -p$$i; \
++	  $(lockme) dh_gencontrol -p$$i; \
++	  dh_builddeb -p$$i; \
++	done
++	
++	# Generate the meta-udeb dependancy lists.
++	@gawk '								\
++		/Package: /		{ package=$$2 }			\
++		(/Package-Type: udeb/ && package !~ /^'$(src_pkg_name)'-udebs-/) { 	\
++			match(package, "'$(release)'-'$(abinum)'-(.*)-di", bits);	\
++			flavour = bits[1];				\
++			udebs[flavour] = udebs[flavour] package ", ";	\
++		}							\
++		END {							\
++			for (flavour in udebs) {				\
++				package="'$(src_pkg_name)'-udebs-" flavour;	\
++				file="debian/" package ".substvars";		\
++				print("udeb:Depends=" udebs[flavour]) > file;	\
++				metas="'$(builddir)'/udeb-meta-packages";	\
++				print(package) >metas			\
++			}						\
++		}							\
++	' <$(CURDIR)/debian/control
++	@while read i; do \
++		$(lockme) dh_gencontrol -p$$i; \
++		dh_builddeb -p$$i; \
++	done <$(builddir)/udeb-meta-packages
+diff --git a/debian/scripts/abi-check b/debian/scripts/abi-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/abi-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/config-check b/debian/scripts/config-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/config-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/control-create b/debian/scripts/control-create
+new file mode 100755
+index 0000000..f8ee9a2
+--- /dev/null
++++ b/debian/scripts/control-create
+@@ -0,0 +1,25 @@
++#!/bin/bash
++
++. debian/debian.env
++
++vars=$1
++
++. $vars
++
++if [ "$is_sub" = "" ]; then
++	flavour=$(basename $vars | sed 's/.*\.//')
++	stub=${DEBIAN}/control.d/flavour-control.stub
++else
++	flavour=$(basename $vars .vars)
++	stub=${DEBIAN}/sub-flavours/control.stub
++fi
++
++cat $stub | grep -v '^#' | sed			\
++	-e "s#FLAVOUR#$flavour#g"		\
++	-e "s#DESC#$desc#g"			\
++	-e "s#ARCH#$arch#g"			\
++	-e "s#SUPPORTED#$supported#g"		\
++	-e "s#TARGET#$target#g"			\
++	-e "s#BOOTLOADER#$bootloader#g" 	\
++	-e "s#=PROVIDES=#$provides#g"		\
++	-e "s#=CONFLICTS=#$conflicts#g"
+diff --git a/debian/scripts/link-headers b/debian/scripts/link-headers
+new file mode 100755
+index 0000000..fb42dbd
+--- /dev/null
++++ b/debian/scripts/link-headers
+@@ -0,0 +1,42 @@
++#!/bin/bash -e
++
++. debian/debian.env
++
++hdrdir="$1"
++symdir="$2"
++flavour="$3"
++
++echo "Symlinking and copying headers for $flavour..."
++
++excludes="( -path ./debian -prune -o -path ./${DEBIAN} -prune -o -path ./.git ) -prune -o"
++
++(
++find . $excludes  -type f \
++	\( -name 'Makefile*' -o -name 'Kconfig*' -o -name 'Kbuild*' -o \
++	-name '*.sh' -o -name '*.pl' -o -name '*.lds' \) -print
++find ./include ./scripts -name .gitignore -prune -o -type f -print
++find ./include -mindepth 1 -maxdepth 1 $excludes -type d -print
++) | (
++while read file; do
++	dir=$file
++	lastdir=$file
++
++	if [ -e "$hdrdir/$file" -o -L "$hdrdir/$file" ]; then
++		continue
++	fi
++
++	while [ ! -e "$hdrdir/$dir" -a ! -L "$hdrdir/$dir" ]; do
++		lastdir=$dir
++		dir=`dirname $dir`
++	done
++	# If the last item to exist is a symlink we assume all is good
++	if [ ! -L "$hdrdir/$dir" ]; then
++		# Turns things like "./foo" into "../"
++		deref="`echo -n $lastdir | sed -e 's/^\.//' -e's,/[^/]*,../,g'`"
++		item="`echo -n $lastdir | sed -e 's/^\.\///'`"
++		ln -s $deref$symdir/$item $hdrdir/$item
++	fi
++done
++)
++
++exit
+diff --git a/debian/scripts/misc/find-obsolete-firmware b/debian/scripts/misc/find-obsolete-firmware
+new file mode 100755
+index 0000000..97a1f30
+--- /dev/null
++++ b/debian/scripts/misc/find-obsolete-firmware
+@@ -0,0 +1,91 @@
++#!/bin/bash
++#
++# Find all duplicate or obsolete firmware that is being carried
++# in the kernel firmware directory. Compare these files against
++# the linux-firmware package for the approriate release. For example,
++# assuming this is raring, then compare the kernel firmware files
++# against the raring branch of linux-firmware.
++#
++# Example: $0 ~/ubuntu/linux-firmware-raring
++
++USEAGE="$0 LINUX-FIRMWARE"
++
++. debian/debian.env
++
++NFWINFO="`find $DEBIAN -name fwinfo|wc -l`"
++if [ ! "$NFWINFO" = "1" ]
++then
++	echo Your repo is hosed. There can only be one fwinfo file.
++	find $DEBIAN -name fwinfo
++	exit 1
++fi
++
++FWINFO="`pwd`/`find $DEBIAN -name fwinfo`"
++
++if [ "$1" = "" ]
++then
++	echo $USEAGE
++	exit 1
++fi
++FW="$1"
++
++if [ ! -f $FW/WHENCE ]
++then
++	echo Bogus linux-firmware directory
++	exit 1
++fi
++if ! egrep -q "^firmware:" $FWINFO
++then
++	echo Bogus firmware info file
++	exit 1
++fi
++
++#
++# Prepare the tree and make firmware.
++#
++TEE="tee -a"
++LO=`pwd`/firmware.txt
++LF=`pwd`/lib/firmware
++rm -rf debian/build $LF $LO
++fakeroot debian/rules clean prepare-generic
++cp debian/build/build-generic/.config .
++mkdir -p $LF
++make firmware_install INSTALL_MOD_PATH=`pwd`
++
++(cd $LF
++find . -type f | while read f
++do
++	BN="`basename $f`"
++
++	if ! grep -q $BN $FWINFO
++	then
++		echo "Unused firmware: $f" | $TEE $LO
++	else
++		if [ -f $FW/$f ]
++		then
++			if ! cmp $FW/$f $f
++			then
++				echo "$f differs" | $TEE $LO
++			else
++				echo "$f is duplicated" | $TEE $LO
++			fi
++		else
++			echo "$f does not exist in $FW" | $TEE $LO
++		fi
++	fi
++done)
++
++#
++# Check for firmware files referenced by the kernel
++# that do not exist in either location.
++#
++cat $FWINFO | while read fwi f
++do
++	if [ -s lib/firmware/$f ] || [ -s $FW/$f ]
++	then
++		continue
++	else
++		echo "Missing firmware $f" | $TEE $LO
++	fi
++done
++
+diff --git a/debian/scripts/misc/fw-to-ihex.sh b/debian/scripts/misc/fw-to-ihex.sh
+new file mode 100755
+index 0000000..a63fe67
+--- /dev/null
++++ b/debian/scripts/misc/fw-to-ihex.sh
+@@ -0,0 +1,18 @@
++#!/bin/bash
++
++F=$1
++if [ "$F" = "" ]
++then
++	echo You must supply a firmware file.
++	exit 1
++fi
++
++echo "unsigned char d[] = {" > $F.c
++hexdump -v -e '"\t" 8/1 "0x%02x, " "\n"' $F >> $F.c
++echo "};" >> $F.c
++sed -i 's/0x .*$//' $F.c
++
++O="`dirname $F`/`basename $F`.o"
++gcc -o $O -c $F.c
++objcopy -Oihex $F.o $F.ihex
++
+diff --git a/debian/scripts/misc/get-firmware b/debian/scripts/misc/get-firmware
+new file mode 100755
+index 0000000..b1ed8e6
+--- /dev/null
++++ b/debian/scripts/misc/get-firmware
+@@ -0,0 +1,62 @@
++#!/bin/bash
++#
++# Find all files in linux-firmware that are new or different since the previous release
++# and copy them into the kernel firmware directory. You should only do this on the
++# backport branch since it would be redundant on the released kernel. It assumed you've
++# unpacked linux-firmware from each release into separate directories.
++#
++# Example: $0 ~/ubuntu/linux-firmware-precise ~/ubuntu/linux-firmware-quantal
++
++if [ "$1" = "" ] || [ "$2" = "" ] || [ ! -f $1/WHENCE ] || [ ! -f $2/WHENCE ]
++then
++	echo You must supply 2 firmware directories.
++	exit 1
++fi
++
++if [ ! -f debian/debian.env ]
++then
++	echo You must run this script from the root of the repo
++	exit 1
++fi
++. debian/debian.env
++
++NFWINFO="`find $DEBIAN -name fwinfo|wc -l`"
++if [ ! "$NFWINFO" = "1" ]
++then
++	echo Your repo is hosed. There can only be one fwinfo file.
++	find $DEBIAN -name fwinfo
++	exit 1
++fi
++
++FWINFO="`pwd`/`find $DEBIAN -name fwinfo`"
++
++CDIR=`pwd`
++OFW=$1
++NFW=$2
++
++cd $NFW
++#
++# Find all files in $NFW that are new or different from $1
++#
++(find . -type f | egrep -v "debian|git|LICEN|WHEN|READ|Make|configure" | sed 's;\./;;' | \
++while read f
++do
++	if grep -q $f $FWINFO
++	then
++		if [ ! -f $OFW/$f ]
++		then
++			echo $f
++		elif ! cmp $f $OFW/$f > /dev/null
++		then
++			echo $f
++		fi
++	fi
++done) |\
++while read f
++do
++	mkdir -p $CDIR/firmware/`dirname $f`
++	if [ ! -f $CDIR/firmware/`dirname $f`/`basename $f`.ihex ]
++	then
++		cp -v $f $CDIR/firmware/`dirname $f`
++	fi
++done
+diff --git a/debian/scripts/misc/getabis b/debian/scripts/misc/getabis
+new file mode 100755
+index 0000000..aa8ed7f
+--- /dev/null
++++ b/debian/scripts/misc/getabis
+@@ -0,0 +1,130 @@
++#!/bin/bash
++
++if [ "$#" != "2" ]; then
++	echo "Usage: $0 <release> <revision>" 1>&2
++	exit 1
++fi
++
++if [ "$DEBIAN" = "" ]; then
++	. debian/debian.env
++fi
++
++ver=$1
++revision=$2
++abi=$(echo $revision | gawk -F. '{print $1}')
++
++verabi=$ver-$abi
++verfull=$ver-$revision
++
++WGET="wget --tries=1 --timeout=10 --quiet -c"
++
++abidir="`pwd`/$DEBIAN/abi/$verfull"
++tmpdir="`pwd`/abi-tmp-$verfull"
++origdir="`pwd`"
++fwinfo=$abidir/fwinfo
++
++test -d $tmpdir || mkdir $tmpdir
++
++package_prefixes() {
++	__package_prefixes="$@"
++}
++
++getall() {
++	arch=$1
++	shift
++
++	mkdir -p $abidir/$arch
++
++	for sub in $@; do
++		if [ -f $abidir/$arch/$sub ]; then
++			echo "Exists: $sub"
++			continue
++		fi
++		echo -n "Fetching $sub($arch)..."
++		prefixes=""
++		filenames=""
++		cd $tmpdir
++		for prefix in $__package_prefixes
++		do
++			filename=${prefix}-${verabi}-${sub}_${verfull}_${arch}.deb
++			for r in "${repo_list[@]}"
++			do
++				if ! [ -f $filename ]; then
++					$WGET $r/$filename
++				fi
++				if [ -f $filename ]; then
++					prefixes="$prefixes $prefix"
++					filenames="$filenames $filename"
++					break
++				fi
++			done
++		done
++		if [ "$filenames" != "" ]; then
++			echo -n "extracting$prefixes..."
++			for filename in $filenames
++			do
++				dpkg-deb --extract $filename tmp
++			done
++			find tmp -name "*.ko" | while read f; do
++				modinfo $f | grep ^firmware >> $fwinfo
++			done
++			if [ -f tmp/boot/abi-* ]; then
++				mv tmp/boot/abi-* $abidir/$arch/$sub
++			else
++				echo -n "NO ABI FILE..."
++			fi
++			(cd tmp; find lib/modules/$verabi-$sub/kernel -name '*.ko') | \
++				sed -e 's/.*\/\([^\/]*\)\.ko/\1/' | sort > \
++				$abidir/$arch/$sub.modules
++			(
++				cd tmp;
++				# Prevent exposing some errors when called by python scripts. SIGPIPE seems to get
++				# exposed when using the `find ...` form of the command.
++				ko=$(find lib/modules/$verabi-$sub/kernel \
++					-name '*.ko' | head -1)
++				readelf -p .comment "$ko" | gawk '
++					($1 == "[") {
++						printf("%s", $3);
++						for (n=4; n<=NF; n++) {
++							printf(" %s", $n);
++						}
++						print ""
++					}' | sort -u >$abidir/$arch/$sub.compiler
++				version=`cat $abidir/$arch/$sub.compiler`
++				echo -n "$version..."
++			)
++			rm -rf tmp $filenames
++			echo "done."
++		else
++			echo "FAILED."
++		fi
++		cd $origdir
++	done
++}
++
++# MAIN
++
++# Setup abi directory
++mkdir -p $abidir
++echo $abi > $abidir/abiname
++
++# NOTE: The flavours are hardcoded, because they may have changed from the
++# current build.
++
++__package_prefixes="linux-image"
++
++. $DEBIAN/etc/getabis
++
++compilers=`cat $abidir/*/*.compiler | sort -u | wc -l`
++if [ "$compilers" != 1 ]; then
++	echo "WARNING: inconsistant compiler versions detected" 1>&2
++fi
++
++sort < $fwinfo | uniq > fwinfo.tmp
++mv fwinfo.tmp $fwinfo
++
++rmdir $tmpdir
++
++# Add the new ABI directory, remove the old
++git add $abidir
++find $DEBIAN/abi/* -maxdepth 0 -type d | grep -v $verfull | while read f; do git rm -r $f;done
+diff --git a/debian/scripts/misc/git-ubuntu-log b/debian/scripts/misc/git-ubuntu-log
+new file mode 100755
+index 0000000..2967d87
+--- /dev/null
++++ b/debian/scripts/misc/git-ubuntu-log
+@@ -0,0 +1,232 @@
++#!/usr/bin/perl -w
++
++use strict;
++use Text::Wrap;
++
++my $kernel_auth = "Upstream Kernel Changes";
++
++my (%map, @reverts);
++my $pstate = 1;
++my $no_kern_log = 0;
++my $print_shas = 0;
++my $first_print = 1;
++
++while (@ARGV) {
++	my $opt = $ARGV[0];
++	shift;
++	if ($opt eq "--no-kern-log") {
++		$no_kern_log = 1;
++	} elsif ($opt eq "--print-shas") {
++		$print_shas = 1;
++	} else {
++		print STDERR "Unknown options: $opt\n";
++		exit(1);
++	}
++}
++
++sub check_reverts($) {
++	my ($entry) = @_;
++	my ($check);
++
++	foreach $check (reverse @reverts) {
++		my $desc = "Revert \"" . $entry->{'desc'} . "\"";
++		if ($check->{'desc'} eq $desc) {
++			@reverts = grep($_->{'desc'} ne $desc, @reverts);
++			return 1;
++		}
++	}
++
++	return 0;
++}
++
++sub add_entry($) {
++	my ($entry) = @_;
++	my $key = $entry->{'author'};
++
++        # store description in array, in email->{desc list} map
++        if (exists $map{$key}) {
++                # grab ref
++                my $obj = $map{$key};
++
++                # add desc to array
++                push(@$obj, $entry);
++        } else {
++                # create new array, containing 1 item
++                my @arr = ($entry);
++
++                # store ref to array
++                $map{$key} = \@arr;
++        }
++}
++
++sub shortlog_entry($$$$$) {
++	my ($name, $desc, $bug, $cve, $commit) = @_;
++	my $entry;
++
++	$desc =~ s#/pub/scm/linux/kernel/git/#/.../#g;
++	$desc =~ s#\[PATCH\] ##g;
++
++	$desc =~ s#^\s*##g;
++	$desc =~ s# *UBUNTU: ##g;
++
++	$entry->{'desc'} = $desc;
++	if ($bug ne '') {
++		$entry->{'bugno'} = $bug;
++	}
++	$entry->{'cve'} = $cve;
++	$entry->{'commit'} = $commit;
++	$entry->{'author'} = $name;
++
++	if ($desc =~ /^Revert "/) {
++		push(@reverts, $entry);
++		return;
++	}
++
++	return if check_reverts($entry);
++
++	add_entry($entry);
++}
++
++# sort comparison function
++sub by_name($$) {
++	my ($a, $b) = @_;
++
++	uc($a) cmp uc($b);
++}
++
++sub shortlog_output {
++	my ($obj, $key, $entry);
++
++	foreach $key (sort by_name keys %map) {
++		next if $key eq $kernel_auth and $no_kern_log;
++
++		print "\n" unless $first_print;
++		$first_print = 0;
++
++		# output author
++		printf "  [ %s ]\n\n", $key;
++
++		# output author's 1-line summaries
++		$obj = $map{$key};
++		foreach $entry (reverse @$obj) {
++			print wrap("  * ", "    ", $entry->{'desc'}) . "\n";
++			# For non upstream changes, add other info.
++			if ($key ne $kernel_auth) {
++				if ($print_shas) {
++					print "    - GIT-SHA " . $entry->{'commit'} .
++						"\n";
++				}
++			}
++			if (defined($entry->{'bugno'})) {
++				print "    - LP: #" .  $entry->{'bugno'} . "\n";
++			}
++			if (defined($entry->{'cve'})) {
++				print "    - " . $entry->{'cve'} . "\n";
++			}
++		}
++	}
++}
++
++sub changelog_input {
++	my ($author, $desc, $commit, $entry, $cve);
++
++	while (<STDIN>) {
++		# get commit
++		if ($pstate == 1) {
++			next unless /^commit (.*)/;
++
++			$commit = $1;
++
++			$pstate++;
++		}
++
++		# get author and email
++		elsif ($pstate == 2) {
++			my ($email);
++
++			next unless /^[Aa]uthor:?\s*(.*?)\s*<(.*)>/;
++
++			$author = $1;
++			$email = $2;
++			$desc = undef;
++			$cve = undef;
++
++			# cset author fixups
++			if (!$author) {
++				$author = $email;
++			}
++			$pstate++;
++		}
++
++		# skip to blank line
++		elsif ($pstate == 3) {
++			next unless /^\s*$/;
++			$pstate++;
++		}
++
++		# skip to non-blank line
++		elsif ($pstate == 4) {
++			next unless /^\s*?(.*)/;
++			my $ignore = 0;
++			my $do_ignore = 0;
++			my $bug = undef;
++			my %bugz = ();
++			my $k;
++
++			# skip lines that are obviously not
++			# a 1-line cset description
++			next if /^\s*From: /;
++
++			chomp;
++			$desc = $1;
++
++			if ($desc =~ /^ *(Revert "|)UBUNTU:/) {
++				$do_ignore = 1;
++			} else {
++				$do_ignore = 0;
++				$author = $kernel_auth;
++				$ignore = 1 if $desc =~ /Merge /;
++			}
++			while (<STDIN>) {
++				$ignore  =  1 if ($do_ignore && /^ *Ignore: yes/i);
++				if    (/^ *Bug: *(#|)([0-9#,\s]*)\s*$/i) {
++					foreach $k (split('(,|\s)\s*(#|)', $2)) {
++						$bugz{$k} = 1 if (($k ne '') and ($k =~ /[0-9]+/));
++					}
++				}
++				elsif (/^ *BugLink: *http.*:\/\/.*\/([0-9]+)/i) {
++					$bugz{$1} = 1;
++				}
++				elsif (/^ *(CVE-.*)/) {
++					$cve = $1
++				}
++				last if /^commit /;
++			}
++
++                        $bug = join(", #", sort keys(%bugz));
++			if (!$ignore) {
++				&shortlog_entry($author, $desc, $bug,
++						$cve, $commit, 0);
++			}
++
++			$pstate = 1;
++			if ($_ && /^commit (.*)/) {
++				$commit = $1;
++				$pstate++;
++			}
++		}
++	
++		else {
++			die "invalid parse state $pstate";
++		}
++	}
++
++	foreach $entry (@reverts) {
++		add_entry($entry);
++	}	
++}
++
++&changelog_input;
++&shortlog_output;
++
++exit(0);
+diff --git a/debian/scripts/misc/insert-changes.pl b/debian/scripts/misc/insert-changes.pl
+new file mode 100755
+index 0000000..c820597
+--- /dev/null
++++ b/debian/scripts/misc/insert-changes.pl
+@@ -0,0 +1,36 @@
++#!/usr/bin/perl -w
++
++my $debian;
++$droot = $ARGV[0] if (defined $ARGV[0]);
++$droot = 'debian' if (!defined $droot);
++$debian = $ARGV[1] if (defined $ARGV[1]);
++$debian = 'debian.master' if (!defined $debian);
++
++system("make -s -f $droot/rules printchanges > $debian/changes");
++
++open(CHANGELOG, "< $debian/changelog") or die "Cannot open changelog";
++open(CHANGES, "< $debian/changes") or die "Cannot open new changes";
++open(NEW, "> $debian/changelog.new") or die "Cannot open new changelog";
++
++$printed = 0;
++
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		next if $printed;
++
++		while (<CHANGES>) {
++			print NEW;
++		}
++
++		$printed = 1;
++	} else {
++		print NEW;
++	}
++}
++
++close(NEW);
++close(CHANGES);
++close(CHANGELOG);
++
++rename("$debian/changelog.new", "$debian/changelog");
++unlink("$debian/changes");
+diff --git a/debian/scripts/misc/insert-mainline-changes b/debian/scripts/misc/insert-mainline-changes
+new file mode 100755
+index 0000000..5678b10
+--- /dev/null
++++ b/debian/scripts/misc/insert-mainline-changes
+@@ -0,0 +1,42 @@
++#!/usr/bin/perl
++
++if ($#ARGV != 2) {
++	warn "Usage: $0 <changelog> <to> <range>\n";
++	die  "       $0 debian.master/changelog v3.2.3 v3.2.2..v3.2.3\n";
++}
++my ($changelog, $to, $range) = @ARGV;
++
++my @changes = ();
++
++push(@changes, "\n");
++push(@changes, "  [ Upstream Kernel Changes ]\n\n");
++push(@changes, "  * rebase to $to\n");
++
++open(LOG, "git log '$range'|") || die "$0: git log failed: - $!\n";
++while (<LOG>) {
++	if (m@BugLink: .*launchpad.net/.*/([0-9]+)\s$@) {
++		push(@changes, "    - LP: #$1\n");
++	}
++}
++close(LOG);
++
++open(CHANGELOG, "< $changelog") or die "Cannot open changelog";
++open(NEW, "> $changelog.new") or die "Cannot open new changelog";
++
++$printed = 3;
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		$printed--;
++		print NEW;
++		if ($printed == 0) {
++			print NEW @changes;
++		}
++		next;
++	}
++	print NEW;
++}
++
++close(NEW);
++close(CHANGELOG);
++
++rename("$changelog.new", "$changelog");
+diff --git a/debian/scripts/misc/insert-ubuntu-changes b/debian/scripts/misc/insert-ubuntu-changes
+new file mode 100755
+index 0000000..9ede7f3
+--- /dev/null
++++ b/debian/scripts/misc/insert-ubuntu-changes
+@@ -0,0 +1,58 @@
++#!/usr/bin/perl
++
++if ($#ARGV != 2) {
++	die "Usage: $0 <changelog> <stop at> <start at>\n";
++}
++my ($changelog, $end, $start) = @ARGV;
++
++$end =~ s/.*\.//;
++$start =~ s/.*\.//;
++
++my @changes = ();
++my $output = 0;
++open(CHG, "<debian.master/changelog") ||
++	open(CHG, "<debian/changelog") ||
++	die "$0: debian/changelog: open failed - $!\n";
++while (<CHG>) {
++	if (/^\S+\s+\((.*\.(\d+))\)/) {
++		if ($2 <= $end) {
++			last;
++		}
++		if ($2 == $start) {
++			$output = 1;
++		}
++		if ($output) {
++			push(@changes, "\n  [ Ubuntu: $1 ]\n\n");
++			next;
++		}
++	}
++	next if ($output == 0);
++
++	next if (/^\s*$/);
++	next if (/^\s--/);
++	next if (/^\s\s[^\*\s]/);
++
++	push(@changes, $_);
++}
++close(CHG);
++
++open(CHANGELOG, "< $changelog") or die "Cannot open changelog";
++open(NEW, "> $changelog.new") or die "Cannot open new changelog";
++
++$printed = 3;
++while (<CHANGELOG>) {
++	if (/^  CHANGELOG: /) {
++		$printed--;
++		print NEW;
++		if ($printed == 0) {
++			print NEW @changes;
++		}
++		next;
++	}
++	print NEW;
++}
++
++close(NEW);
++close(CHANGELOG);
++
++rename("$changelog.new", "$changelog");
+diff --git a/debian/scripts/misc/kernelconfig b/debian/scripts/misc/kernelconfig
+new file mode 100755
+index 0000000..310d1f8
+--- /dev/null
++++ b/debian/scripts/misc/kernelconfig
+@@ -0,0 +1,172 @@
++#!/bin/bash
++
++. debian/debian.env
++
++# Script to merge all configs and run 'make silentoldconfig' on it to wade out bad juju.
++# Then split the configs into distro-commmon and flavour-specific parts
++
++# We have to be in the top level kernel source directory
++if [ ! -f MAINTAINERS ] || [ ! -f Makefile ]; then
++	echo "This does not appear to be the kernel source directory." 1>&2
++	exit 1
++fi
++
++mode=${1:?"Usage: $0 [oldconfig|editconfig]"}
++yes=0
++case "$mode" in
++    update*configs)  mode='silentoldconfig' ;;
++    default*configs) mode='oldconfig'; yes=1 ;;
++    edit*configs)    ;; # All is good
++    gen*configs)     mode='genconfigs' ;; # All is good
++    dump*configs)    mode='config'; yes=1 ;;
++    *) echo "$0 called with invalid mode" 1>&2
++       exit 1 ;;
++esac
++kerneldir="`pwd`"
++confdir="$kerneldir/${DEBIAN}/config"
++sharedconfdir="$kerneldir/debian.master/config"
++variant="$2"
++
++. $DEBIAN/etc/kernelconfig
++
++bindir="`pwd`/${DROOT}/scripts/misc"
++common_conf="$confdir/config.common.$family"
++tmpdir=`mktemp -d`
++mkdir "$tmpdir/CONFIGS"
++
++if [ "$mode" = "genconfigs" ]; then
++	keep=1
++	mode="oldconfig"
++	test -d CONFIGS || mkdir CONFIGS
++fi
++
++for arch in $archs; do
++	rm -rf build
++	mkdir build
++
++	# Map debian archs to kernel archs
++	case "$arch" in
++		ppc64)		kernarch="powerpc"	;;
++		amd64)		kernarch="x86_64"	;;
++		lpia)		kernarch="x86" 		;;
++		sparc)		kernarch="sparc64"	;;
++		armel|armhf)	kernarch="arm"		;;
++		*)		kernarch="$arch"	;;
++	esac
++
++	archconfdir=$confdir/$arch
++	flavourconfigs=$(cd $archconfdir && ls config.flavour.*)
++
++	# Merge configs
++	# We merge config.common.ubuntu + config.common.<arch> +
++	# config.flavour.<flavour>
++
++	for config in $flavourconfigs; do
++		fullconf="$tmpdir/$arch-$config-full"
++		case $config in
++		*)
++			: >"$fullconf"
++			if [ -f $common_conf ]; then
++				cat $common_conf >> "$fullconf"
++			fi
++			if [ -f $archconfdir/config.common.$arch ]; then
++				cat $archconfdir/config.common.$arch >> "$fullconf"
++			fi
++			cat "$archconfdir/$config" >>"$fullconf"
++			if [ -f $confdir/OVERRIDES ]; then
++				cat $confdir/OVERRIDES >> "$fullconf"
++			fi
++			;;
++		esac
++	done
++
++	for config in $flavourconfigs; do
++		if [ -f $archconfdir/$config ]; then
++			fullconf="$tmpdir/$arch-$config-full"
++			cat "$fullconf" > build/.config
++			# Call oldconfig or menuconfig
++			case "$mode" in
++			    editconfigs)
++				# Interactively edit config parameters
++				while : ; do
++					echo -n "Do you want to edit config: $arch/$config? [Y/n] "
++					read choice
++					
++					case "$choice" in
++					y* | Y* | "" )
++						make O=`pwd`/build ARCH=$kernarch menuconfig
++						break ;;
++					n* | N* )
++						break ;;
++					*)
++						echo "Entry not valid"
++					esac
++				done
++				;;
++			    *)
++				echo "* Run $mode (yes=$yes) on $arch/$config ..."
++				if [ "$yes" -eq 1 ]; then
++					yes "" | make O=`pwd`/build ARCH=$kernarch "$mode"
++				else
++					make O=`pwd`/build ARCH=$kernarch "$mode"
++				fi ;;
++			esac
++			cat build/.config > $archconfdir/$config
++			cat build/.config > "$tmpdir/CONFIGS/$arch-$config"
++			if [ "$keep" = "1" ]; then
++				cat build/.config > CONFIGS/$arch-$config
++			fi
++		else
++			echo "!! Config not found $archconfdir/$config..."
++		fi
++	done
++
++	echo "Running splitconfig.pl for $arch"
++	echo
++
++	# Can we make this more robust by avoiding $tmpdir completely?
++	# This approach was used for now because I didn't want to change
++	# splitconfig.pl
++	(cd $archconfdir; $bindir/splitconfig.pl config.flavour.*; mv config.common \
++	 config.common.$arch; cp config.common.$arch $tmpdir)
++done
++
++rm -f $common_conf
++
++# Now run splitconfig.pl on all the config.common.<arch> copied to
++# $tmpdir
++(cd $tmpdir; $bindir/splitconfig.pl *)
++(
++	cd $confdir;
++	rm -f *-full
++	grep -v 'is UNMERGABLE' <$tmpdir/config.common >$common_conf
++	for arch in $archs; do
++		grep -v 'is UNMERGABLE' <$tmpdir/config.common.$arch \
++			>$arch/config.common.$arch
++	done
++)
++
++echo ""
++echo "Running config-check for all configurations ..."
++echo ""
++fail=0
++for arch in $archs; do
++	archconfdir=$confdir/$arch
++	flavourconfigs=$(cd $archconfdir && ls config.flavour.*)
++	for config in $flavourconfigs; do
++		flavour="${config##*.}"
++		if [ -f $archconfdir/$config ]; then
++			fullconf="$tmpdir/CONFIGS/$arch-$config"
++			"$bindir/../config-check" "$fullconf" "$arch" "$flavour" "$sharedconfdir" "0" || let "fail=$fail+1"
++		fi
++	done
++done
++
++if [ "$fail" != 0 ]; then
++	echo ""
++	echo "*** ERROR: $fail config-check failures detected"
++	echo ""
++fi
++
++rm -rf build
++
+diff --git a/debian/scripts/misc/retag b/debian/scripts/misc/retag
+new file mode 100755
+index 0000000..94cf169
+--- /dev/null
++++ b/debian/scripts/misc/retag
+@@ -0,0 +1,34 @@
++#!/usr/bin/perl -w
++
++open(TAGS, "git tag -l |") or die "Could not get list of tags";
++@tags = <TAGS>;
++close(TAGS);
++
++open(LOGS, "git log --pretty=short |") or die "ERROR: Calling git log";
++my $commit = "";
++
++while (<LOGS>) {
++	my $origtag;
++
++	if (m|^commit (.*)$|) {
++		$commit = $1;
++		next;
++	}
++
++	m|\s*UBUNTU: (Ubuntu-2\.6\..*)| or next;
++
++	$tag = $1;
++
++	($origtag) = grep(/^$tag.orig$/, @tags);
++
++	if (!defined($origtag)) {
++		print "I: Adding original tag for $tag\n";
++		system("git tag -m $tag $tag.orig $tag");
++	}
++
++	print "I: Tagging $tag => $commit\n";
++
++	system("git tag -f -m $tag $tag $commit");
++}
++
++close(LOGS);
+diff --git a/debian/scripts/misc/splitconfig.pl b/debian/scripts/misc/splitconfig.pl
+new file mode 100755
+index 0000000..3270ede
+--- /dev/null
++++ b/debian/scripts/misc/splitconfig.pl
+@@ -0,0 +1,107 @@
++#!/usr/bin/perl -w
++
++%allconfigs = ();
++%common = ();
++
++print "Reading config's ...\n";
++
++for $config (@ARGV) {
++	# Only config.*
++	next if $config !~ /^config\..*/;
++	# Nothing that is disabled, or remnant
++	next if $config =~ /.*\.(default|disabled|stub)$/;
++
++	%{$allconfigs{$config}} = ();
++
++	print "  processing $config ... ";
++
++	open(CONFIG, "< $config");
++
++	while (<CONFIG>) {
++		# Skip comments
++		/^#*\s*CONFIG_(\w+)[\s=](.*)$/ or next;
++
++		${$allconfigs{$config}}{$1} = $2;
++
++		$common{$1} = $2;
++	}
++
++	close(CONFIG);
++
++	print "done.\n";
++}
++
++print "\n";
++
++print "Merging lists ... \n";
++
++# %options - pointer to flavour config inside the allconfigs array
++for $config (keys(%allconfigs)) {
++	my %options = %{$allconfigs{$config}};
++
++	print "   processing $config ... ";
++
++	for $key (keys(%common)) {
++		next if not defined $common{$key};
++
++		# If we don't have the common option, then it isn't
++		# common. If we do have that option, it must have the same
++		# value.  EXCEPT where this file does not have a value at all
++		# which may safely be merged with any other value; the value
++		# will be elided during recombination of the parts.
++		if (!defined($options{$key})) {
++			# Its ok really ... let it merge
++		} elsif (not defined($options{$key})) {
++			undef $common{$key};
++		} elsif ($common{$key} ne $options{$key}) {
++			undef $common{$key};
++		}
++	}
++
++	print "done.\n";
++}
++
++print "\n";
++
++print "Creating common config ... ";
++
++open(COMMON, "> config.common");
++print COMMON "#\n# Common config options automatically generated by splitconfig.pl\n#\n";
++
++for $key (sort(keys(%common))) {
++	if (not defined $common{$key}) {
++		print COMMON "# CONFIG_$key is UNMERGABLE\n";
++	} elsif ($common{$key} eq "is not set") {
++		print COMMON "# CONFIG_$key is not set\n";
++	} else {
++		print COMMON "CONFIG_$key=$common{$key}\n";
++	}
++}
++close(COMMON);
++
++print "done.\n\n";
++
++print "Creating stub configs ...\n";
++
++for $config (keys(%allconfigs)) {
++	my %options = %{$allconfigs{$config}};
++
++	print "  processing $config ... ";
++
++	open(STUB, "> $config");
++	print STUB "#\n# Config options for $config automatically generated by splitconfig.pl\n#\n";
++
++	for $key (sort(keys(%options))) {
++		next if defined $common{$key};
++
++		if ($options{$key} =~ /^is /) {
++			print STUB "# CONFIG_$key $options{$key}\n";
++		} else {
++			print STUB "CONFIG_$key=$options{$key}\n";
++		}
++	}
++
++	close(STUB);
++
++	print "done.\n";
++}
+diff --git a/debian/scripts/module-check b/debian/scripts/module-check
+new file mode 100755
+index 0000000..039e4d0
+--- /dev/null
++++ b/debian/scripts/module-check
+@@ -0,0 +1,2 @@
++#!/bin/sh
++exit 0
+diff --git a/debian/scripts/module-inclusion b/debian/scripts/module-inclusion
+new file mode 100755
+index 0000000..deb07a8
+--- /dev/null
++++ b/debian/scripts/module-inclusion
+@@ -0,0 +1,60 @@
++#!/bin/bash
++
++#
++# Build a new directory of modules based on an inclusion list.
++# The includsion list format must be a bash regular expression.
++#
++# usage: $0 ROOT INCLUSION_LIST
++# example: $0 debian/build/build-virtual \
++#       debian/build/build-virtual-ALL debian/build/build-virtual \
++#	debian.master/control.d/virtual.inclusion-list
++master=0
++if [ "$1" = "--master" ]; then
++	master=1
++	shift
++fi
++
++ROOT=$1
++NROOT=$2
++ILIST=$3
++
++#
++# Prep a destination directory.
++#
++mkdir -p ${NROOT}
++
++# Copy over the framework...
++if  [ "$master" -eq 1 ]; then
++	(cd ${ROOT}; find . ! -name "*.ko" -type f) | \
++	while read f
++	do
++		mkdir -p ${NROOT}/`dirname $f`
++		mv ${ROOT}/$f ${NROOT}/$f
++	done
++fi
++
++cat ${ILIST} |while read i
++do
++	#
++	# 'find' blurts a warning if it cannot find any ko files.
++	#
++	if echo "$i" | grep '\*' > /dev/null
++	then
++		(cd ${ROOT}; eval find "${i}" -name "*.ko") |while read f
++		do
++			mkdir -p ${NROOT}/`dirname $f`
++			mv ${ROOT}/$f ${NROOT}/$f
++		done
++	else
++		if [ -f "${ROOT}/$i" ]
++		then
++			mkdir -p ${NROOT}/`dirname $i`
++			mv ${ROOT}/$i ${NROOT}/$i
++		else
++			echo Warning: Could not find ${ROOT}/$i
++		fi
++	fi
++
++done
++
++exit 0
+diff --git a/debian/scripts/sub-flavour b/debian/scripts/sub-flavour
+new file mode 100644
+index 0000000..0100493
+--- /dev/null
++++ b/debian/scripts/sub-flavour
+@@ -0,0 +1,69 @@
++#!/bin/bash
++
++. debian/debian.env
++
++echo "SUB_PROCESS $FROM => $TO"
++
++export from_pkg="linux-image-$ABI_RELEASE-$FROM"
++export to_pkg="linux-image-$ABI_RELEASE-$TO"
++
++from_moddir="debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM"
++to_moddir="debian/$to_pkg/lib/modules/$ABI_RELEASE-$FROM"
++
++install -d "debian/$to_pkg/boot"
++install -m644 debian/$from_pkg/boot/config-$ABI_RELEASE-$FROM \
++	debian/$to_pkg/boot/
++install -m600 debian/$from_pkg/boot/{vmlinuz,System.map}-$ABI_RELEASE-$FROM \
++	debian/$to_pkg/boot/
++
++#
++# Print some warnings if there are files in the sub-flavours list
++# that do not actually exist.
++#
++cat ${DEBIAN}/sub-flavours/$TO.list | while read line
++do
++(
++	cd debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM/kernel;
++	#
++	# If its a wildcard, then check that there are files that match.
++	#
++	if echo "$line" | grep '\*' > /dev/null
++	then
++		if [ `eval find "$line" -name '*.ko' 2>/dev/null|wc -l` -lt 1 ]
++		then
++			echo SUB_INST Warning - No files in $line
++		fi
++	#
++	# Else it should be a single file reference.
++	#
++	elif [ ! -f "$line" ]
++	then
++		echo SUB_INST Warning - could not find "$line"
++	fi
++)
++done
++
++cat ${DEBIAN}/sub-flavours/$TO.list | while read line; do
++	(
++	cd debian/$from_pkg/lib/modules/$ABI_RELEASE-$FROM/kernel;
++	if echo "$line" | grep '\*' > /dev/null
++	then
++		eval find "$line" -name '*.ko' 2>/dev/null || true
++	elif [ -f "$line" ]
++	then
++		echo "$line"
++	fi
++	);
++done | while read mod; do
++	echo "SUB_INST checking: $mod"
++	fromdir="/lib/modules/$ABI_RELEASE-$FROM/"
++	egrep "^($fromdir)?kernel/$mod:" \
++		$from_moddir/modules.dep | sed -e "s|^$fromdir||" -e 's/://' -e 's/ /\n/g' | \
++	while read m; do
++		m="${fromdir}$m"
++		test -f debian/$to_pkg/$m && continue
++		echo "SUB_INST installing: $m"
++		install -D -m644 debian/$from_pkg/$m \
++			debian/$to_pkg/$m
++	done
++done
+diff --git a/debian/source/format b/debian/source/format
+new file mode 100644
+index 0000000..d3827e7
+--- /dev/null
++++ b/debian/source/format
+@@ -0,0 +1 @@
++1.0
+diff --git a/debian/stamps/keep-dir b/debian/stamps/keep-dir
+new file mode 100644
+index 0000000..5c38d4a
+--- /dev/null
++++ b/debian/stamps/keep-dir
+@@ -0,0 +1 @@
++Place holder
+diff --git a/debian/tests-build/README b/debian/tests-build/README
+new file mode 100644
+index 0000000..c74d1c4
+--- /dev/null
++++ b/debian/tests-build/README
+@@ -0,0 +1,21 @@
++Scripts placed in this directory get called one at a time by run-parts(8).
++The scripts are expected to perform some sort of sanity checks on the
++finished build. Scripts will be called once for each flavour.
++
++Some environment variables are exported to make life a little easier:
++
++DPKG_ARCH     : The dpkg architecture (e.g. "amd64")
++KERN_ARCH     : The kernel architecture (e.g. "x86_64")
++FLAVOUR       : The specific flavour for this run (e.g. "generic")
++VERSION       : The full version of this build (e.g. 2.6.22-1)
++REVISION      : The exact revision of this build (e.g. 1.3)
++PREV_REVISION : The revision prior to this one
++ABI_NUM       : The specific ABI number for this build (e.g. 2)
++PREV_ABI_NUM  : The previous ABI number. Can be the same as ABI_NUM.
++BUILD_DIR     : The directory where this build took place
++INSTALL_DIR   : The directory where the package is prepared
++SOURCE_DIR    : Where the main kernel source is
++
++Scripts are expected to have a zero exit status when no problems occur,
++and non-zero when an error occurs that should stop the build. Scripts
++should print whatever info they deem needed to deduce the problem.
+diff --git a/debian/tests-build/check-aliases b/debian/tests-build/check-aliases
+new file mode 100755
+index 0000000..b85118f
+--- /dev/null
++++ b/debian/tests-build/check-aliases
+@@ -0,0 +1,24 @@
++#!/usr/bin/perl -w
++
++my %map;
++
++print "Checking for dupe aliases in $ENV{'FLAVOUR'}...\n";
++
++$aliases =
++  "$ENV{'INSTALL_DIR'}/lib/modules/$ENV{'VERSION'}-$ENV{'FLAVOUR'}/modules.alias";
++
++open(ALIASES, "< $aliases") or die "Could not open $aliases";
++
++while (<ALIASES>) {
++	chomp;
++	my ($junk, $alias, $module) = split;
++
++	if (defined($map{$alias})) {
++		printf("%s %20s / %-20s : %s \n", ("$map{$alias}" eq "$module")
++			? "INT" : "   ", $map{$alias}, $module, $alias);
++	} else {
++		$map{$alias} = $module;
++	}
++}
++
++exit(0);
+diff --git a/debian/tests/control b/debian/tests/control
+new file mode 100644
+index 0000000..eb022dc
+--- /dev/null
++++ b/debian/tests/control
+@@ -0,0 +1,3 @@
++Tests: rebuild
++Depends: build-essential
++Restrictions: build-needed
+diff --git a/debian/tests/rebuild b/debian/tests/rebuild
+new file mode 100755
+index 0000000..b23e556
+--- /dev/null
++++ b/debian/tests/rebuild
+@@ -0,0 +1 @@
++#!/bin/true
+diff --git a/debian/tools/generic b/debian/tools/generic
+new file mode 100644
+index 0000000..4aa5649
+--- /dev/null
++++ b/debian/tools/generic
+@@ -0,0 +1,30 @@
++#!/bin/bash
++full_version=`uname -r`
++
++# First check for a fully qualified version.
++this="/usr/lib/linux-tools/$full_version/`basename $0`"
++if [ -f "$this" ]; then
++	exec "$this" "$@"
++fi
++
++# FALLBACK for older kernel layouts
++# Removing flavour from version i.e. generic or server.
++flavour_abi=${full_version#*-}
++flavour=${flavour_abi#*-}
++version=${full_version%-$flavour}
++this="$0_$version"
++if [ -f "$this" ]; then
++	exec "$this" "$@"
++fi
++
++# If we have the appropriate package installed but no
++# tool then the tool does not exist.
++if [ -d "/usr/lib/linux-tools/$full_version" ]; then
++	echo "`basename $0` not available for kernel $version" >&2
++	exit 2
++fi
++
++# Give them a hint as to what to install.
++echo "`basename $0` not found for kernel $version" >&2
++echo "You may need to install linux-tools-$version-$flavour" >&2
++exit 2
+-- 
+1.7.9.5
+
diff --git a/buffalo/ubuntu/0002-debian-changelog.patch b/buffalo/ubuntu/0002-debian-changelog.patch
new file mode 100644
index 00000000..376538d
--- /dev/null
+++ b/buffalo/ubuntu/0002-debian-changelog.patch
@@ -0,0 +1,10105 @@
+From 598e6cbc914537a7c556585e2ae9b8b7f4eb10aa Mon Sep 17 00:00:00 2001
+From: Andy Whitcroft <apw@gomeisa.buildd>
+Date: Wed, 20 Nov 2013 15:36:29 -0500
+Subject: [PATCH 2/3] debian changelog
+
+---
+ debian.master/changelog |10086 +----------------------------------------------
+ 1 file changed, 3 insertions(+), 10083 deletions(-)
+
+diff --git a/debian.master/changelog b/debian.master/changelog
+index 0029ecc..3b99d81 100644
+--- a/debian.master/changelog
++++ b/debian.master/changelog
+@@ -1,10085 +1,5 @@
+-linux (3.11.0-14.21) saucy; urgency=low
++linux (3.10.20-031020.201311201536) saucy; urgency=low
+ 
+-  [Brad Figg]
++  * Mainline build at commit: v3.10.20
+ 
+-  * Release Tracking Bug
+-    - LP: #1250540
+-
+-  [ Anthony Wong ]
+-
+-  * SAUCE: Work around broken ACPI backlight on Dell Inspiron 5537
+-    - LP: #1231305
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: eCryptfs: fix 32 bit corruption issue
+-    - LP: #1243636
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: ext4: fix performance regression in ext4_writepages
+-    - LP: #1242812
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "bridge: only expire the mdb entry when query is received"
+-    - LP: #1249081
+-  * ext4: fix performance regression in writeback of random writes
+-    - LP: #1242812
+-  * be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd
+-    - LP: #1234019
+-  * tcp: TSO packets automatic sizing
+-    - LP: #1249081
+-  * tcp: TSQ can use a dynamic limit
+-    - LP: #1249081
+-  * tcp: must unclone packets before mangling them
+-    - LP: #1249081
+-  * tcp: do not forget FIN in tcp_shifted_skb()
+-    - LP: #1249081
+-  * tcp: fix incorrect ca_state in tail loss probe
+-    - LP: #1249081
+-  * net: do not call sock_put() on TIMEWAIT sockets
+-    - LP: #1249081
+-  * batman-adv: set up network coding packet handlers during module init
+-    - LP: #1249081
+-  * l2tp: fix kernel panic when using IPv4-mapped IPv6 addresses
+-    - LP: #1249081
+-  * l2tp: Fix build warning with ipv6 disabled.
+-    - LP: #1249081
+-  * net: mv643xx_eth: update statistics timer from timer context only
+-    - LP: #1249081
+-  * net: mv643xx_eth: fix orphaned statistics timer crash
+-    - LP: #1249081
+-  * net: heap overflow in __audit_sockaddr()
+-    - LP: #1249081
+-  * sit: amend "allow to use rtnl ops on fb tunnel"
+-    - LP: #1249081
+-  * proc connector: fix info leaks
+-    - LP: #1249081
+-  * ipv4: fix ineffective source address selection
+-    - LP: #1249081
+-  * can: dev: fix nlmsg size calculation in can_get_size()
+-    - LP: #1249081
+-  * net: secure_seq: Fix warning when CONFIG_IPV6 and CONFIG_INET are not
+-    selected
+-    - LP: #1249081
+-  * xen-netback: Don't destroy the netdev until the vif is shut down
+-    - LP: #1249081
+-  * net/mlx4_en: Rename name of mlx4_en_rx_alloc members
+-    - LP: #1249081
+-  * net/mlx4_en: Fix pages never dma unmapped on rx
+-    - LP: #1249081
+-  * net: vlan: fix nlmsg size calculation in vlan_get_size()
+-    - LP: #1249081
+-  * bridge: update mdb expiration timer upon reports.
+-    - LP: #1249081
+-  * vti: get rid of nf mark rule in prerouting
+-    - LP: #1249081
+-  * l2tp: must disable bh before calling l2tp_xmit_skb()
+-    - LP: #1249081
+-  * netem: update backlog after drop
+-    - LP: #1249081
+-  * netem: free skb's in tree on reset
+-    - LP: #1249081
+-  * farsync: fix info leak in ioctl
+-    - LP: #1249081
+-  * unix_diag: fix info leak
+-    - LP: #1249081
+-  * connector: use nlmsg_len() to check message length
+-    - LP: #1249081
+-  * bnx2x: record rx queue for LRO packets
+-    - LP: #1249081
+-  * virtio-net: don't respond to cpu hotplug notifier if we're not ready
+-    - LP: #1249081
+-  * virtio-net: refill only when device is up during setting queues
+-    - LP: #1249081
+-  * bridge: Correctly clamp MAX forward_delay when enabling STP
+-    - LP: #1249081
+-  * net: dst: provide accessor function to dst->xfrm
+-    - LP: #1249081
+-  * sctp: Use software crc32 checksum when xfrm transform will happen.
+-    - LP: #1249081
+-  * sctp: Perform software checksum if packet has to be fragmented.
+-    - LP: #1249081
+-  * wanxl: fix info leak in ioctl
+-    - LP: #1249081
+-  * net: unix: inherit SOCK_PASS{CRED, SEC} flags from socket to fix race
+-    - LP: #1249081
+-  * net: fix cipso packet validation when !NETLABEL
+-    - LP: #1249081
+-  * inet: fix possible memory corruption with UDP_CORK and UFO
+-    - LP: #1249081
+-  * ipv6: always prefer rt6i_gateway if present
+-    - LP: #1249081
+-  * ipv6: fill rt6i_gateway with nexthop address
+-    - LP: #1249081
+-  * netfilter: nf_conntrack: fix rt6i_gateway checks for H.323 helper
+-    - LP: #1249081
+-  * ipv6: probe routes asynchronous in rt6_probe
+-    - LP: #1249081
+-  * davinci_emac.c: Fix IFF_ALLMULTI setup
+-    - LP: #1249081
+-  * ARM: 7851/1: check for number of arguments in
+-    syscall_get/set_arguments()
+-    - LP: #1249081
+-  * ARM: integrator: deactivate timer0 on the Integrator/CP
+-    - LP: #1249081
+-  * ext[34]: fix double put in tmpfile
+-    - LP: #1249081
+-  * gpio/lynxpoint: check if the interrupt is enabled in IRQ handler
+-    - LP: #1249081
+-  * dm snapshot: fix data corruption
+-    - LP: #1249081
+-    - CVE-2013-4299
+-  * i2c: ismt: initialize DMA buffer
+-    - LP: #1249081
+-  * mm: migration: do not lose soft dirty bit if page is in migration state
+-    - LP: #1249081
+-  * mm/zswap: bugfix: memory leak when re-swapon
+-    - LP: #1249081
+-  * mm: fix BUG in __split_huge_page_pmd
+-    - LP: #1249081
+-  * ALSA: us122l: Fix pcm_usb_stream mmapping regression
+-    - LP: #1249081
+-  * ALSA: hda - Fix inverted internal mic not indicated on some machines
+-    - LP: #1227491, #1239392, #1249081
+-  * writeback: fix negative bdi max pause
+-    - LP: #1249081
+-  * w1 - call request_module with w1 master mutex unlocked
+-    - LP: #1249081
+-  * wireless: radiotap: fix parsing buffer overrun
+-    - LP: #1249081
+-  * wireless: cw1200: acquire hwbus lock around cw1200_irq_handler() call.
+-    - LP: #1249081
+-  * serial: vt8500: add missing braces
+-    - LP: #1249081
+-  * USB: serial: ti_usb_3410_5052: add Abbott strip port ID to combined
+-    table as well.
+-    - LP: #1249081
+-  * USB: serial: option: add support for Inovia SEW858 device
+-    - LP: #1249081
+-  * usb: serial: option: blacklist Olivetti Olicard200
+-    - LP: #1249081
+-  * Linux 3.11.7
+-    - LP: #1249081
+-  * tg3: Add support for new 57786 device id.
+-    - LP: #1242610
+-
+- -- Brad Figg <brad.figg@canonical.com>  Tue, 12 Nov 2013 08:10:21 -0800
+-
+-linux (3.11.0-13.20) saucy; urgency=low
+-
+-  [ Brad Figg ]
+-
+-  * Release Tracking Bug
+-    - LP: #1242793
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] amhf: VIRTIO_CONSOLE=y
+-    - LP: #1237982
+-  * [Config] AHCI_IMX=y
+-    - LP: #1240038
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_USB_OTG=n for all arches
+-    - LP: #1047527
+-  * dm-raid4-5: Fix compile issues
+-    - LP: #1241086
+-  * [Config] CONFIG_DM_RAID45=m
+-    - LP: #1241086
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "cw1200: Don't perform SPI transfers in interrupt context"
+-    - LP: #1237530
+-  * block: Fix bio_copy_data()
+-    - LP: #1237530
+-  * sysv: Add forgotten superblock lock init for v7 fs
+-    - LP: #1237530
+-  * bcache: Fix a dumb journal discard bug
+-    - LP: #1237530
+-  * bcache: Strip endline when writing the label through sysfs
+-    - LP: #1237530
+-  * bcache: Fix for when no journal entries are found
+-    - LP: #1237530
+-  * bcache: Fix a writeback performance regression
+-    - LP: #1237530
+-  * bcache: Fix a flush/fua performance bug
+-    - LP: #1237530
+-  * bcache: Fix a dumb CPU spinning bug in writeback
+-    - LP: #1237530
+-  * bcache: Fix a shrinker deadlock
+-    - LP: #1237530
+-  * bcache: Fix for handling overlapping extents when reading in a btree
+-    node
+-    - LP: #1237530
+-  * bcache: Fix flushes in writeback mode
+-    - LP: #1237530
+-  * kernel/reboot.c: re-enable the function of variable reboot_default
+-    - LP: #1237530
+-  * x86/reboot: Add quirk to make Dell C6100 use reboot=pci automatically
+-    - LP: #1237530
+-  * tools lib lk: Uninclude linux/magic.h in debugfs.c
+-    - LP: #1237530
+-  * x86, efi: Don't map Boot Services on i386
+-    - LP: #1237530
+-  * mei: make me client counters less error prone
+-    - LP: #1237530
+-  * mei: bus: stop wait for read during cl state transition
+-    - LP: #1237530
+-  * mei: cancel stall timers in mei_reset
+-    - LP: #1237530
+-  * tty: Fix SIGTTOU not sent with tcflush()
+-    - LP: #1237530
+-  * serial: tegra: fix tty-kref leak
+-    - LP: #1237530
+-  * serial: pch_uart: fix tty-kref leak in rx-error path
+-    - LP: #1237530
+-  * serial: pch_uart: fix tty-kref leak in dma-rx path
+-    - LP: #1237530
+-  * ARM: 7837/3: fix Thumb-2 bug in AES assembler code
+-    - LP: #1237530
+-  * staging: vt6656: [BUG] main_usb.c oops on device_close move flag
+-    earlier.
+-    - LP: #1237530
+-  * staging: vt6656: [BUG] iwctl_siwencodeext return if device not open
+-    - LP: #1237530
+-  * drm/i915/tv: clear adjusted_mode.flags
+-    - LP: #1237530
+-  * cw1200: Use a threaded oneshot irq handler for cw1200_spi
+-    - LP: #1237530
+-  * xhci: Ensure a command structure points to the correct trb on the
+-    command ring
+-    - LP: #1237530
+-  * xhci: Fix oops happening after address device timeout
+-    - LP: #1237530
+-  * USB: fix PM config symbol in uhci-hcd, ehci-hcd, and xhci-hcd
+-    - LP: #1237530
+-  * xhci: Fix race between ep halt and URB cancellation
+-    - LP: #1237530
+-  * USB: OHCI: accept very late isochronous URBs
+-    - LP: #1237530
+-  * USB: UHCI: accept very late isochronous URBs
+-    - LP: #1237530
+-  * USB: Fix breakage in ffs_fs_mount()
+-    - LP: #1237530
+-  * fsl/usb: Resolve PHY_CLK_VLD instability issue for ULPI phy
+-    - LP: #1237530
+-  * usb: dwc3: pci: add support for BayTrail
+-    - LP: #1237530
+-  * usb: dwc3: add support for Merrifield
+-    - LP: #1237530
+-  * usb/core/devio.c: Don't reject control message to endpoint with wrong
+-    direction bit
+-    - LP: #1237530
+-  * driver core : Fix use after free of dev->parent in device_shutdown
+-    - LP: #1237530
+-  * dm snapshot: workaround for a false positive lockdep warning
+-    - LP: #1237530
+-  * dm-snapshot: fix performance degradation due to small hash size
+-    - LP: #1237530
+-  * dm mpath: disable WRITE SAME if it fails
+-    - LP: #1237530
+-  * drm/i915: preserve pipe A quirk in i9xx_set_pipeconf
+-    - LP: #1237530
+-  * drm/i915/dp: increase i2c-over-aux retry interval on AUX DEFER
+-    - LP: #1237530
+-  * drm/radeon/cik: Fix printing of client name on VM protection fault
+-    - LP: #1237530
+-  * drm/radeon/cik: Fix encoding of number of banks in tiling configuration
+-    info
+-    - LP: #1237530
+-  * drm/radeon/cik: fix overflow in vram fetch
+-    - LP: #1237530
+-  * drm/radeon: avoid UVD corruption on AGP cards using GPU gart
+-    - LP: #1237530
+-  * drm/radeon: Make r100_cp_ring_info() and radeon_ring_gfx() safe (v2)
+-    - LP: #1237530
+-  * drm/radeon: don't set default clocks for SI when DPM is disabled
+-    - LP: #1237530
+-  * drm/radeon: disable tests/benchmarks if accel is disabled
+-    - LP: #1237530
+-  * drm/radeon: add missing hdmi callbacks for rv6xx
+-    - LP: #1237530
+-  * drm/radeon: fix hdmi audio on DCE3.0/3.1 asics
+-    - LP: #1237530
+-  * hwmon: (applesmc) Check key count before proceeding
+-    - LP: #1237530
+-  * ALSA: compress: Fix compress device unregister.
+-    - LP: #1237530
+-  * irq: Always define devm_{request_threaded,free}_irq()
+-    - LP: #1237530
+-  * Linux 3.11.4
+-    - LP: #1237530
+-  * ARM: dtsi: enable ahci sata on imx6q platforms
+-    - LP: #1240038
+-  * nfsd4: fix leak of inode reference on delegation failure
+-    - LP: #1240072
+-  * HID: fix data access in implement()
+-    - LP: #1240072
+-  * HID: fix unused rsize usage
+-    - LP: #1240072
+-  * sh_eth: fix napi_{en|dis}able() calls racing against interrupts
+-    - LP: #1240072
+-  * caif: Add missing braces to multiline if in cfctrl_linkup_request
+-    - LP: #1240072
+-  * tcp: Add missing braces to do_tcp_setsockopt
+-    - LP: #1240072
+-  * ipv6/exthdrs: accept tlv which includes only padding
+-    - LP: #1240072
+-  * net: fib: fib6_add: fix potential NULL pointer dereference
+-    - LP: #1240072
+-  * net: sctp: fix bug in sctp_poll for SOCK_SELECT_ERR_QUEUE
+-    - LP: #1240072
+-  * net: sctp: fix smatch warning in sctp_send_asconf_del_ip
+-    - LP: #1240072
+-  * net: fix multiqueue selection
+-    - LP: #1240072
+-  * net: flow_dissector: fix thoff for IPPROTO_AH
+-    - LP: #1240072
+-  * net_sched: htb: fix a typo in htb_change_class()
+-    - LP: #1240072
+-  * r8169: enforce RX_MULTI_EN for the 8168f.
+-    - LP: #1240072
+-  * netpoll: Should handle ETH_P_ARP other than ETH_P_IP in
+-    netpoll_neigh_reply
+-    - LP: #1240072
+-  * netpoll: fix NULL pointer dereference in netpoll_cleanup
+-    - LP: #1240072
+-  * tuntap: correctly handle error in tun_set_iff()
+-    - LP: #1240072
+-  * net: sctp: fix ipv6 ipsec encryption bug in sctp_v6_xmit
+-    - LP: #1240072
+-  * xen-netback: count number required slots for an skb more carefully
+-    - LP: #1240072
+-  * resubmit bridge: fix message_age_timer calculation
+-    - LP: #1240072
+-  * bridge: Clamp forward_delay when enabling STP
+-    - LP: #1240072
+-  * bridge: use br_port_get_rtnl within rtnl lock
+-    - LP: #1240072
+-  * bridge: fix NULL pointer deref of br_port_get_rcu
+-    - LP: #1240072
+-  * ip6_tunnels: raddr and laddr are inverted in nl msg
+-    - LP: #1240072
+-  * net: sctp: rfc4443: do not report ICMP redirects to user space
+-    - LP: #1240072
+-  * ethernet/arc/arc_emac: Fix huge delays in large file copies
+-    - LP: #1240072
+-  * vxlan: Avoid creating fdb entry with NULL destination
+-    - LP: #1240072
+-  * batman-adv: set the TAG flag for the vid passed to BLA
+-    - LP: #1240072
+-  * net:dccp: do not report ICMP redirects to user space
+-    - LP: #1240072
+-  * ip: use ip_hdr() in __ip_make_skb() to retrieve IP header
+-    - LP: #1240072
+-  * ip: generate unique IP identificator if local fragmentation is allowed
+-    - LP: #1240072
+-  * skge: fix invalid value passed to pci_unmap_sigle
+-    - LP: #1240072
+-  * ipv6: udp packets following an UFO enqueued packet need also be handled
+-    by UFO
+-    - LP: #1240072
+-  * via-rhine: fix VLAN priority field (PCP, IEEE 802.1p)
+-    - LP: #1240072
+-  * IPv6 NAT: Do not drop DNATed 6to4/6rd packets
+-    - LP: #1240072
+-  * net: net_secret should not depend on TCP
+-    - LP: #1240072
+-  * ip_tunnel: Do not use stale inner_iph pointer.
+-    - LP: #1240072
+-  * dm9601: fix IFF_ALLMULTI handling
+-    - LP: #1240072
+-  * bonding: Fix broken promiscuity reference counting issue
+-    - LP: #1240072
+-  * ipv6: gre: correct calculation of max_headroom
+-    - LP: #1240072
+-  * ipv4 igmp: use in_dev_put in timer handlers instead of __in_dev_put
+-    - LP: #1240072
+-  * ipv6 mcast: use in6_dev_put in timer handlers instead of __in6_dev_put
+-    - LP: #1240072
+-  * ll_temac: Reset dma descriptors indexes on ndo_open
+-    - LP: #1240072
+-  * ip_tunnel: Fix a memory corruption in ip_tunnel_xmit
+-    - LP: #1240072
+-  * ip_tunnel_core: Change __skb_push back to skb_push
+-    - LP: #1240072
+-  * sit: allow to use rtnl ops on fb tunnel
+-    - LP: #1240072
+-  * ip6tnl: allow to use rtnl ops on fb tunnel
+-    - LP: #1240072
+-  * avr32: fix clockevents kernel warning
+-    - LP: #1240072
+-  * regulator: ti-abb: Fix bias voltage glitch in transition to bypass mode
+-    - LP: #1240072
+-  * fs/binfmt_elf.c: prevent a coredump with a large vm_map_count from
+-    Oopsing
+-    - LP: #1240072
+-  * gpio/omap: maintain GPIO and IRQ usage separately
+-    - LP: #1240072
+-  * gpio/omap: auto-setup a GPIO when used as an IRQ
+-    - LP: #1240072
+-  * ASoC: max98095: a couple array underflows
+-    - LP: #1240072
+-  * ASoC: 88pm860x: array overflow in snd_soc_put_volsw_2r_st()
+-    - LP: #1240072
+-  * ASoC: ab8500-codec: info leak in anc_status_control_put()
+-    - LP: #1240072
+-  * ARM: kvm: rename cpu_reset to avoid name clash
+-    - LP: #1240072
+-  * ARM: mach-integrator: Add stub for pci_v3_early_init() for !CONFIG_PCI
+-    - LP: #1240072
+-  * iommu/arm-smmu: fix a signedness bug
+-    - LP: #1240072
+-  * iommu/arm-smmu: fix iommu_present() test in init
+-    - LP: #1240072
+-  * iommu/arm-smmu: don't enable SMMU device until probing has completed
+-    - LP: #1240072
+-  * powerpc/iommu: Use GFP_KERNEL instead of GFP_ATOMIC in
+-    iommu_init_table()
+-    - LP: #1240072
+-  * powerpc/perf: Fix handling of FAB events
+-    - LP: #1240072
+-  * powerpc/tm: Switch out userspace PPR and DSCR sooner
+-    - LP: #1240072
+-  * powerpc/tm: Turn interrupts hard off in tm_reclaim()
+-    - LP: #1240072
+-  * powerpc/vio: Fix modalias_show return values
+-    - LP: #1240072
+-  * powerpc: Fix parameter clobber in csum_partial_copy_generic()
+-    - LP: #1240072
+-  * powerpc: Fix memory hotplug with sparse vmemmap
+-    - LP: #1240072
+-  * powerpc/sysfs: Disable writing to PURR in guest mode
+-    - LP: #1240072
+-  * powerpc: Restore registers on error exit from
+-    csum_partial_copy_generic()
+-    - LP: #1240072
+-  * fuse: wait for writeback in fuse_file_fallocate()
+-    - LP: #1240072
+-  * fuse: fix fallocate vs. ftruncate race
+-    - LP: #1240072
+-  * brcmfmac: obtain platform data upon module initialization
+-    - LP: #1240072
+-  * Bluetooth: Fix security level for peripheral role
+-    - LP: #1240072
+-  * Bluetooth: Fix encryption key size for peripheral role
+-    - LP: #1240072
+-  * Bluetooth: Add a new PID/VID 0cf3/e005 for AR3012.
+-    - LP: #1240072
+-  * Bluetooth: Add support for BCM20702A0 [0b05, 17cb]
+-    - LP: #1240072
+-  * Bluetooth: Introduce a new HCI_RFKILLED flag
+-    - LP: #1240072
+-  * Bluetooth: Fix rfkill functionality during the HCI setup stage
+-    - LP: #1240072
+-  * nilfs2: fix issue with race condition of competition between segments
+-    for dirty blocks
+-    - LP: #1240072
+-  * ipc/sem.c: fix race in sem_lock()
+-    - LP: #1240072
+-  * ipc,msg: prevent race with rmid in msgsnd,msgrcv
+-    - LP: #1240072
+-  * ipc: fix race with LSMs
+-    - LP: #1240072
+-  * sparc64: Fix buggy strlcpy() conversion in ldom_reboot().
+-    - LP: #1240072
+-  * sparc: fix ldom_reboot buffer overflow harder
+-    - LP: #1240072
+-  * sparc64: Remove RWSEM export leftovers
+-    - LP: #1240072
+-  * sparc64: Fix ITLB handler of null page
+-    - LP: #1240072
+-  * esp_scsi: Fix tag state corruption when autosensing.
+-    - LP: #1240072
+-  * sparc64: Fix off by one in trampoline TLB mapping installation loop.
+-    - LP: #1240072
+-  * sparc64: Fix not SRA'ed %o5 in 32-bit traced syscall
+-    - LP: #1240072
+-  * sparc32: Fix exit flag passed from traced sys_sigreturn
+-    - LP: #1240072
+-  * mm: Fix generic hugetlb pte check return type.
+-    - LP: #1240072
+-  * mm/bounce.c: fix a regression where MS_SNAP_STABLE (stable pages
+-    snapshotting) was ignored
+-    - LP: #1240072
+-  * kernel/kmod.c: check for NULL in call_usermodehelper_exec()
+-    - LP: #1240072
+-  * staging: comedi: ni_65xx: (bug fix) confine insn_bits to one subdevice
+-    - LP: #1240072
+-  * NFSv4.1: nfs4_fl_prepare_ds - fix bugs when the connect attempt fails
+-    - LP: #1240072
+-  * mwifiex: fix NULL pointer dereference in usb suspend handler
+-    - LP: #1240072
+-  * mwifiex: fix hang issue for USB chipsets
+-    - LP: #1240072
+-  * mwifiex: fix PCIe hs_cfg cancel cmd timeout
+-    - LP: #1240072
+-  * usb: chipidea: add Intel Clovertrail pci id
+-    - LP: #1240072
+-  * USB: serial: option: Ignore card reader interface on Huawei E1750
+-    - LP: #1240072
+-  * xen/hvc: allow xenboot console to be used again
+-    - LP: #1240072
+-  * ib_srpt: Destroy cm_id before destroying QP.
+-    - LP: #1240072
+-  * ib_srpt: always set response for task management
+-    - LP: #1240072
+-  * rtlwifi: Align private space in rtl_priv struct
+-    - LP: #1240072
+-  * p54usb: add USB ID for Corega WLUSB2GTST USB adapter
+-    - LP: #1240072
+-  * mm: avoid reinserting isolated balloon pages into LRU lists
+-    - LP: #1240072
+-  * iscsi-target: Only perform wait_for_tasks when performing shutdown
+-    - LP: #1240072
+-  * net: Update the sysctl permissions handler to test effective uid/gid
+-    - LP: #1240072
+-  * irq: Force hardirq exit's softirq processing on its own stack
+-    - LP: #1240072
+-  * drm/radeon: fix hdmi callbacks for rv6xx (incorrectly added to r520)
+-    - LP: #1240072
+-  * dmaengine: imx-dma: fix lockdep issue between irqhandler and tasklet
+-    - LP: #1240072
+-  * dmaengine: imx-dma: fix callback path in tasklet
+-    - LP: #1240072
+-  * dmaengine: imx-dma: fix slow path issue in prep_dma_cyclic
+-    - LP: #1240072
+-  * ACPI / IPMI: Fix atomic context requirement of ipmi_msg_handler()
+-    - LP: #1240072
+-  * xfs: fix node forward in xfs_node_toosmall
+-    - LP: #1240072
+-  * drm/nouveau/bios/init: stub opcode 0xaa
+-    - LP: #1240072
+-  * ARM: tegra: unify Tegra's Kconfig a bit more
+-    - LP: #1240072
+-  * ALSA: hda - Fix GPIO for Acer Aspire 3830TG
+-    - LP: #1240072
+-  * ARM: multi_v7_defconfig: enable ARM_ATAG_DTB_COMPAT
+-    - LP: #1240072
+-  * HID: wiimote: fix FF deadlock
+-    - LP: #1240072
+-  * mmc: fix null pointer use in mmc_blk_remove_req
+-    - LP: #1240072
+-  * tile: use a more conservative __my_cpu_offset in CONFIG_PREEMPT
+-    - LP: #1240072
+-  * s390: fix system call restart after inferior call
+-    - LP: #1240072
+-  * Btrfs: reset ret in record_one_backref
+-    - LP: #1240072
+-  * Btrfs: change how we queue blocks for backref checking
+-    - LP: #1240072
+-  * Btrfs: skip subvol entries when checking if we've created a dir already
+-    - LP: #1240072
+-  * Btrfs: remove ourselves from the cluster list under lock
+-    - LP: #1240072
+-  * HID: roccat: add support for KonePureOptical v2
+-    - LP: #1240072
+-  * HID: add Holtek USB ID 04d9:a081 SHARKOON DarkGlider
+-    - LP: #1240072
+-  * HID: uhid: add devname module alias
+-    - LP: #1240072
+-  * HID: uhid: allocate static minor
+-    - LP: #1240072
+-  * net: qmi_wwan: add new Qualcomm devices
+-    - LP: #1240072
+-  * bcache: Fix a null ptr deref regression
+-    - LP: #1240072
+-  * Linux 3.11.5
+-    - LP: #1240072
+-  * ALSA: snd-usb-usx2y: remove bogus frame checks
+-    - LP: #1242700
+-  * ALSA: hda - hdmi: Fix channel map switch not taking effect
+-    - LP: #1242700
+-  * ALSA: hda - Add fixup for ASUS N56VZ
+-    - LP: #1242700
+-  * ALSA: hda - Fix microphone for Sony VAIO Pro 13 (Haswell model)
+-    - LP: #1227093, #1242700
+-  * random: run random_int_secret_init() run after all late_initcalls
+-    - LP: #1242700
+-  * vfs: allow O_PATH file descriptors for fstatfs()
+-    - LP: #1242700
+-  * i2c: omap: Clear ARDY bit twice
+-    - LP: #1242700
+-  * hwmon: (applesmc) Always read until end of data
+-    - LP: #1242700
+-  * Btrfs: use right root when checking for hash collision
+-    - LP: #1242700
+-  * ext4: fix memory leak in xattr
+-    - LP: #1242700
+-  * KVM: PPC: Book3S HV: Fix typo in saving DSCR
+-    - LP: #1242700
+-  * parisc: fix interruption handler to respect pagefault_disable()
+-    - LP: #1242700
+-  * ARC: Fix __udelay calculation
+-    - LP: #1242700
+-  * ARC: Handle zero-overhead-loop in unaligned access handler
+-    - LP: #1242700
+-  * ARC: Fix 32-bit wrap around in access_ok()
+-    - LP: #1242700
+-  * ARC: Workaround spinlock livelock in SMP SystemC simulation
+-    - LP: #1242700
+-  * ARC: Fix signal frame management for SA_SIGINFO
+-    - LP: #1242700
+-  * ARC: Ignore ptrace SETREGSET request for synthetic register "stop_pc"
+-    - LP: #1242700
+-  * watchdog: ts72xx_wdt: locking bug in ioctl
+-    - LP: #1242700
+-  * watchdog: kempld_wdt: Fix bit mask definition
+-    - LP: #1242700
+-  * MIPS: stack protector: Fix per-task canary switch
+-    - LP: #1242700
+-  * drm/radeon/dpm/btc: off by one in btc_set_mc_special_registers()
+-    - LP: #1242700
+-  * compiler/gcc4: Add quirk for 'asm goto' miscompilation bug
+-    - LP: #1242700
+-  * ALSA: hda - Fix mono speakers and headset mic on Dell Vostro 5470
+-    - LP: #1236228, #1242700
+-  * drm/i915/hsw: Disable L3 caching of atomic memory operations.
+-    - LP: #1242700
+-  * drm/i915: Only apply DPMS to the encoder if enabled
+-    - LP: #1242700
+-  * drm/i915: fix rps.vlv_work initialization
+-    - LP: #1242700
+-  * drm/radeon/dpm: off by one in si_set_mc_special_registers()
+-    - LP: #1242700
+-  * drm/radeon: forever loop on error in radeon_do_test_moves()
+-    - LP: #1242700
+-  * drm/radeon: fix typo in CP DMA register headers
+-    - LP: #1242700
+-  * drm/radeon: fix hw contexts for SUMO2 asics
+-    - LP: #1242700
+-  * ipc,shm: introduce lockless functions to obtain the ipc object
+-    - LP: #1242700
+-  * ipc,shm: shorten critical region in shmctl_down
+-    - LP: #1242700
+-  * ipc: drop ipcctl_pre_down
+-    - LP: #1242700
+-  * ipc,shm: introduce shmctl_nolock
+-    - LP: #1242700
+-  * ipc,shm: make shmctl_nolock lockless
+-    - LP: #1242700
+-  * ipc,shm: shorten critical region for shmctl
+-    - LP: #1242700
+-  * ipc,shm: cleanup do_shmat pasta
+-    - LP: #1242700
+-  * ipc,shm: shorten critical region for shmat
+-    - LP: #1242700
+-  * ipc: rename ids->rw_mutex
+-    - LP: #1242700
+-  * ipc,msg: drop msg_unlock
+-    - LP: #1242700
+-  * ipc: document general ipc locking scheme
+-    - LP: #1242700
+-  * ipc, shm: guard against non-existant vma in shmdt(2)
+-    - LP: #1242700
+-  * ipc: drop ipc_lock_by_ptr
+-    - LP: #1242700
+-  * ipc, shm: drop shm_lock_check
+-    - LP: #1242700
+-  * ipc: drop ipc_lock_check
+-    - LP: #1242700
+-  * ipc/sem.c: optimize sem_lock()
+-    - LP: #1242700
+-  * ipc/sem.c: synchronize the proc interface
+-    - LP: #1242700
+-  * ipc/sem.c: update sem_otime for all operations
+-    - LP: #1242700
+-  * x86: avoid remapping data in parse_setup_data()
+-    - LP: #1242700
+-  * Linux 3.11.6
+-    - LP: #1242700
+-
+- -- Brad Figg <brad.figg@canonical.com>  Mon, 21 Oct 2013 10:21:14 -0700
+-
+-linux (3.11.0-12.19) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] fix linux-libc-dev generation for arm64
+-  * [Config] fix linux-libc-dev generation for x32
+-  * [Config] add linux-libc-dev generation for ppc64el
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 09 Oct 2013 12:33:07 +0100
+-
+-linux (3.11.0-12.18) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packing] tools -- when tools are off they are off
+-  * [config] tools -- linux-tools-common really is common
+-  * [Packaging] tools -- make cpupower optional
+-  * [Packaging] tools -- fix crosscompilation
+-  * [config] tools -- enable cpupower
+-  * SAUCE: storvsc -- host takes MAINTENANCE_IN commands badly elide them
+-    - LP: #1234417
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: apparmor: fix unix domain sockets to be mediated on connection
+-    - LP: #1208988
+-  * SAUCE: apparmor: allocate path lookup buffers during init
+-    - LP: #1208988
+-  * SAUCE: apparmor: fix memleak of the profile hash
+-    - LP: #1235523
+-  * SAUCE: apparmor: fix memleak of replacedby struct
+-    - LP: #1235973
+-  * SAUCE: apparmor: fix bad lock balance when introspecting policy
+-    - LP: #1235977
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] arm: VIRTIO_[BLK|NET|MMIO]=y
+-
+-  [ Rob Herring ]
+-
+-  * SAUCE: (no-up) net: calxedaxgmac: fix clearing of old filter addresses
+-    - LP: #1235272
+-  * SAUCE: (no-up) net: calxedaxgmac: add uc and mc filter addresses in
+-    promiscuous mode
+-    - LP: #1235272
+-  * SAUCE: (no-up) net: calxedaxgmac: determine number of address filters
+-    at runtime
+-    - LP: #1235272
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ANDROID=n
+-    - LP: #1235161
+-  * [Config] CONFIG_L2TP_V3=y
+-    - LP: #1235914
+-  * Release tracker
+-    - LP: #1236999
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "HID: core: fix reporting of raw events"
+-    - LP: #1218004
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Oct 2013 13:08:59 +0100
+-
+-linux (3.11.0-11.17) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] tools -- only build common tools package in master
+-  * SAUCE: tools -- report when tool is not available
+-    - LP: #1233376
+-  * [Packaging] tools -- common tools must carry all possible tools
+-    - LP: #1233376
+-
+-  [ Colin Ian King ]
+-
+-  * [Config] Fix power and performance regression
+-    - LP: #1233681
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Clean up various udeb Provides
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11.3
+-  * Release tracker
+-    - LP: #1233808
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Add CS4208 codec support for MacBook 6,1 and 6,2
+-    - LP: #1233623
+-  * ALSA: hda - Add fixup for MacBook Air 6,1 and 6,2 with CS4208 codec
+-    - LP: #1233623
+-  * NVMe: Remove "process_cq did something" message
+-    - LP: #1233686
+-  * Drivers: hv: balloon: Initialize the transaction ID just before sending the packet
+-    - LP: #1233466
+-  * cciss: fix info leak in cciss_ioctl32_passthru()
+-    - LP: #1188355
+-    - CVE-2013-2147
+-  * cpqarray: fix info leak in ida_locked_ioctl()
+-    - LP: #1188355
+-    - CVE-2013-2147
+-  * Drivers: hv: util: Fix a bug in version negotiation code for util services
+-    - LP: #1233433
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 01 Oct 2013 07:24:27 -0600
+-
+-linux (3.11.0-9.16) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ
+-    CAPACITY (16) at SPC-2"
+-  * Revert "SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at
+-    SPC-2"
+-  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request READ
+-    CAPACITY (16) be preferred"
+-  * Revert "SAUCE: (no-up) scsi: add scsi device flag to request VPD pages
+-    be used at SPC-2"
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (no-up) ACPI: Disable Windows 8 compatibility for some Lenovo
+-    ThinkPads
+-    - LP: #1183856
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_CRYPTO_CRCT10DIF=y, CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
+-  * [packaging] Bump ABI for every new release
+-  * rebase to v3.11.2
+-  * Release tracker
+-    - LP: #1231999
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * scsi: hyper-v storsvc switch up to SPC-3
+-  * perf/x86: Add Silvermont (22nm Atom) support
+-    - LP: #1091539
+-  * perf/x86/intel: Fix Silvermont offcore masks
+-    - LP: #1091539
+-  * modules: add support for soft module dependencies
+-    - LP: #1188010
+-  * Reinstate "crypto: crct10dif - Wrap crc_t10dif function all to use
+-    crypto transform framework"
+-    - LP: #1188010
+-  * skge: fix broken driver
+-    - LP: #1216745
+-  * Input: cypress_ps2 - Return zero finger count if palm is detected.
+-    - LP: #1229361
+-  * udf: Standardize return values in mount sequence
+-    - LP: #1228751
+-  * udf: Refuse RW mount of the filesystem instead of making it RO
+-    - LP: #1228751
+-  * rebase to v3.11.2
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 23 Sep 2013 07:41:07 -0600
+-
+-linux (3.11.0-8.15) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1227969
+-
+-  * Update lttng
+-    Updated to git://git.lttng.org/lttng-modules.git 9998f5216f4641a79e158135
+-    Version 2.3.0+
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * igb: Add additional get_phy_id call for i354 devices
+-    - LP: #1219619
+-  * igb: Read flow control for i350 from correct EEPROM section
+-    - LP: #1219619
+-  * timekeeping: Fix HRTICK related deadlock from ntp lock changes
+-    Required for lttng update.
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 19 Sep 2013 07:41:49 -0600
+-
+-linux (3.11.0-7.14) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] sort out linux-tools naming
+-    - LP: #1205284
+-  * [Packaging] linux-tools: switch to common generic version helper
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] highbank: ecx1000: CPU_IDLE causes instabilities, disable it
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1226160
+-
+-  [ Tony Lindgren ]
+-
+-  * SAUCE: ARM: dts: Fix muxing and regulator for wl12xx on the SDIO bus
+-    for pandaboard
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * USB: handle LPM errors during device suspend correctly
+-    - LP: #1011415
+-  * usb: don't check pm qos NO_POWER_OFF flag in usb_port_suspend()
+-    - LP: #1011415
+-  * usb: Don't fail port power resume on device disconnect.
+-    - LP: #1011415
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 11 Sep 2013 07:30:17 -0600
+-
+-linux (3.11.0-7.13) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1223545
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: (no-up) scsi: add scsi device flag to request VPD pages be used at SPC-2
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: add scsi device flag to request READ CAPACITY (16) be preferred
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: hyper-v storage -- mark as VPD capable at SPC-2
+-    - LP: #1223499
+-  * SAUCE: (no-up) scsi: hyper-v storage -- mark as preferring READ CAPACITY (16) at SPC-2
+-    - LP: #1223499
+-
+-  [ Maximiliano Curia ]
+-
+-  * SAUCE: (no-up) Only let characters through when there are active readers.
+-    - LP: #1208740
+-
+-  [ Tim Gardner ]
+-
+-  * [Debian] getabis: Commit new ABI directory, remove the old
+-  * [Config] CONFIG_EFIVAR_FS=y
+-    - LP: #1223195
+-  * [Config] CONFIG_EFI_VARS_PSTORE=m,
+-    CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE=n
+-  * SAUCE: (no-up) USB: input: cm109.c: Convert high volume dev_err() to dev_err_ratelimited()
+-    - LP: #1222850
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Intel xhci: refactor EHCI/xHCI port switching
+-    - LP: #1210858
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 10 Sep 2013 09:00:19 -0600
+-
+-linux (3.11.0-6.12) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1222893
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
+-    - LP: #1222407
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] restore mmc boot on panda
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: apparmor: Use shash crypto API interface for profile hashes
+-    - LP: #1216294
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * net: calxedaxgmac: remove NETIF_F_FRAGLIST setting
+-  * net: calxedaxgmac: read correct field in xgmac_desc_get_buf_len
+-  * net: calxedaxgmac: fix race between xgmac_tx_complete and xgmac_tx_err
+-  * net: calxedaxgmac: fix possible skb free before tx complete
+-  * net: calxedaxgmac: update ring buffer tx_head after barriers
+-  * net: calxedaxgmac: fix race with tx queue stop/wake
+-  * net: calxedaxgmac: enable interrupts after napi_enable
+-  * net: calxedaxgmac: fix various errors in xgmac_set_rx_mode
+-  * net: calxedaxgmac: remove some unused statistic counters
+-  * net: calxedaxgmac: fix rx DMA mapping API size mismatches
+-  * net: calxedaxgmac: fix xgmac_xmit DMA mapping error handling
+-  * mfd: rtsx: Read vendor setting from config space
+-    - LP: #1201698
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 09 Sep 2013 07:21:06 -0600
+-
+-linux (3.11.0-5.11) saucy; urgency=low
+-
+-  * Release tracker
+-    - LP: #1221886
+-
+-  [ Adam Lee ]
+-
+-  * SAUCE: Bluetooth: Add support for 04ca:2007
+-    - LP: #1153448
+-  * SAUCE: Bluetooth: Add support for 105b:e065
+-    - LP: #1161261
+-
+-  [ Gavin Guo ]
+-
+-  * SAUCE: Bluetooth: Add support for Broadcom 413c:8143
+-    - LP: #1166113
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * igb: Reset the link when EEE setting changed
+-    - LP: #1219619
+-  * igb: Read register for latch_on without return value
+-    - LP: #1219619
+-  * igb: Added rcu_lock to avoid race
+-    - LP: #1219619
+-  * igb: don't allow SR-IOV without MSI-X
+-    - LP: #1219619
+-  * igb: Update MTU so that it is always at least a standard frame size
+-    - LP: #1219619
+-  * igb: Refactor of init_nvm_params
+-    - LP: #1219619
+-  * igb: Refactor NVM read functions to accommodate devices with no flash
+-    - LP: #1219619
+-  * igb: Add device support for flashless SKU of i210 device
+-    - LP: #1219619
+-  * igb: Fix get_fw_version function for all parts
+-    - LP: #1219619
+-  * igb: Add macro for size of RETA indirection table
+-    - LP: #1219619
+-  * igb: Expose RSS indirection table for ethtool
+-    - LP: #1219619
+-  * igb: Don't look for a PBA in the iNVM when flashless
+-    - LP: #1219619
+-  * igb: Implementation of 1-sec delay for i210 devices
+-    - LP: #1219619
+-  * igb: New PHY_ID for i354 device
+-    - LP: #1219619
+-  * igb: M88E1543 PHY downshift implementation
+-    - LP: #1219619
+-  * igb: No PHPM support in i354 devices
+-    - LP: #1219619
+-  * igb: Support to get 2_5G link status for appropriate media type
+-    - LP: #1219619
+-  * igb: Get speed and duplex for 1G non_copper devices
+-    - LP: #1219619
+-  * igb: Implementation to report advertised/supported link on i354 devices
+-    - LP: #1219619
+-  * igb: Update version number
+-    - LP: #1219619
+-  * Bluetooth: Take proper tty_struct references
+-    - LP: #1189998
+-  * Bluetooth: Remove the device from the list in the destructor
+-    - LP: #1189998
+-  * Bluetooth: Move the tty initialization and cleanup out of open/close
+-    - LP: #1189998
+-  * Bluetooth: Implement .activate, .shutdown and .carrier_raised methods
+-    - LP: #1189998
+-  * Bluetooth: Fix the reference counting of tty_port
+-    - LP: #1189998
+-  * Bluetooth: Purge the dlc->tx_queue to avoid circular dependency
+-    - LP: #1189998
+-
+-  [ Wen-chien Jesse Sung ]
+-
+-  * SAUCE: Bluetooth: Support for loading broadcom patchram firmware
+-    - LP: #1065400
+-  * SAUCE: Bluetooth: Add support for 13d3:3388 and 13d3:3389
+-    - LP: #1065400
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 05 Sep 2013 08:06:17 -0600
+-
+-linux (3.11.0-5.10) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release tracker
+-    - LP: #1220222
+-  * Revert "[Config] Fix ubuntu directoy Kbuilds"
+-  * Revert "aufs update dropped some Kbuild files"
+-  * Revert "ubuntu: AUFS -- follow rename of loop.h into drivers/block"
+-  * Revert "ubuntu: AUFS -- update to
+-    8e503d4142c189ed6c47a2177ad2cd058e8d340e"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch"
+-  * Revert "ubuntu: (no-squash) AUFS3 -- aufs3-base.patch"
+-  * rebase to v3.11 final
+-  * [Config] clean up ubuntu/Kconfig and ubuntu/Makefile
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-base.patch
+-  * ubuntu: (no-squash) AUFS3 -- aufs3-standalone.patch
+-  * ubuntu: AUFS -- update to 5ac5fe26a90a818218310e208d17688fddb07622
+-  * ubuntu: (no-squash) AUFS -- enable aufs
+-  * ubuntu: AUFS -- fix remaining d_count references to use accessor
+-  * ubuntu: lttng -- follow rename of pid_ns
+-  * SAUCE: disable stack-protector for ARM compressed bootloader
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] ARM_ATAG_DTB_COMPAT=y
+-
+-  [ Rob Herring ]
+-
+-  * [Config] Enable KVM and virtio for armhf generic-lpae
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ARPD=y
+-  * [Config] CONFIG_ZSWAP=y
+-    - LP: #1215379
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * uvcvideo: quirk PROBE_DEF for Dell SP2008WFP monitor.
+-    - LP: #1217957
+-  * ARM: use phys_addr_t for DMA zone sizes
+-  * ARM: highbank: enable DMA zone for LPAE
+-  * ARM: highbank: select ARCH_HAS_HOLES_MEMORYMODEL
+-  * ARM: highbank: select required errata work-arounds
+-  * DMA: fix AMBA PL08x compilation issue with 64bit DMA address type
+-  * DMA: fix printk warning in AMBA PL08x DMA driver
+-  * ARM: highbank: select ARCH_DMA_ADDR_T_64BIT for LPAE
+-  * ARM: move outer_cache declaration out of ifdef
+-  * ARM: highbank: avoid L2 cache smc calls when PL310 is not present
+-  * ARM: highbank: clean-up some unused includes
+-  * ARM: xen: only set pm function ptrs for Xen guests
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 03 Sep 2013 17:08:06 +0100
+-
+-linux (3.11.0-4.9) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc7
+-  * Release tracker
+-    - LP: #1216962
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mwifiex: do not create AP and P2P interfaces upon driver loading
+-    - LP: #1212720
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 26 Aug 2013 06:25:35 -0600
+-
+-linux (3.11.0-3.8) saucy; urgency=low
+-
+-  [ Johannes Berg ]
+-
+-  * SAUCE: mac80211: ignore (E)CSA in probe response frames
+-    - LP: #1201470
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 23 Aug 2013 09:47:36 -0600
+-
+-linux (3.11.0-3.7) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: (no-up) hv_vss_daemon -- prevent self-daemonising to allow
+-    upstart to track
+-  * SAUCE: (no-up) hv -- bodge hv_vss_daemon so it can use the local
+-    linux/hyperv.h
+-  * SAUCE: hv: Add vss daemon to Makefile
+-  * [Debian] Add hv_vss_daemon to tools package
+-    - LP: #1213282
+-  * [Config] Fix ubuntu directoy Kbuilds
+-    - LP: #1181755
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 20 Aug 2013 08:34:05 -0600
+-
+-linux (3.11.0-3.6) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] tools: conditionalise x86 and hyper-v tools sensibly
+-  * [Config] tools: enable x86 and hyper-v
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable
+-    snapshot"
+-  * Revert "SAUCE: (no-up) apparmor: fix apparmor module status for none
+-    root users"
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 - alpha 4 snapshot
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: (no-up) intel_ips: blacklist ASUSTek G60JX laptops
+-    - LP: #1210848
+-
+-  [ Kamal Mostafa ]
+-
+-  * [debian] tools: ship 'cpupower' in linux-tools
+-    - LP: #1158668
+-  * [Config] Build-dep on libpci-dev for cpu tools
+-    - LP: #1158668
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc6
+-  * Release tracker
+-    - LP: #1213941
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 16 Aug 2013 07:02:07 -0600
+-
+-linux (3.11.0-2.5) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_PM_DEBUG=y
+-    - LP: #1210539
+-  * rebase to v3.11-rc5
+-  * Release tracker
+-    - LP: #1211378
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 12 Aug 2013 06:10:39 -0600
+-
+-linux (3.11.0-1.4) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Bump ABI when making changes to the inclusion list lest
+-    you cause conflicts with existing installed kernel
+-    packages.
+-    - LP: #1210331
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 09 Aug 2013 03:03:51 +0100
+-
+-linux (3.11.0-0.3) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Include rbd and kvm in the virtual inclusion list
+-    - LP: #1206961
+-  * [Config] Removed obsolete inclusion list entries
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Aug 2013 08:52:14 +0100
+-
+-linux (3.11.0-0.2) saucy; urgency=low
+-
+-  [ Bruce Allan ]
+-
+-  * SAUCE: (no-up) e1000e: fix I217/I218 PHY initialization flow
+-    - LP: #1206757
+-  * SAUCE: (no-up) e1000e: enable support for new device IDs
+-    - LP: #1206757
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
+-
+-  [ Paolo Pisati ]
+-
+-  * build vexpress a15 dtb
+-  * [Config] disable Broadcom bcm support (ARCH_BCM)
+-  * [Config] disable Allwinner a1x support (ARCH_SUNXI)
+-  * [Config] disable WonderMedia WM8850 support (ARCH_WM8850)
+-  * [Config] disable Rockchip support (ARCH_ROCKCHIP)
+-  * [Config] disable STMicroelectronics STiH41x SOCs (ARCH_STI)
+-  * [Config] disable TI Keystone, AM43xx and OMAP5 support
+-  * [Config] ARM_APPENDED_DTB=y
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.11-rc4
+-  * overlayfs: Update to v19
+-  * [Config] Enable overlayfs
+-  * SAUCE: Fix lttng compile errors
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.11-rc4
+-    - LP: #1163720
+-    - LP: #1162026
+-    - LP: #1195636
+-    - LP: #1195597
+-    - LP: #1180409
+-    - LP: #1168430
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Sun, 04 Aug 2013 03:45:31 -0600
+-
+-linux (3.11.0-0.1) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 64ccccf8525fee499625b517c0faadf784c79e93
+-    - LP: #1163720
+-    - LP: #1162026
+-    - LP: #1195636
+-    - LP: #1195597
+-    - LP: #1180409
+-    - LP: #1168430
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 08 Jul 2013 08:50:46 -0600
+-
+-linux (3.10.0-2.10) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_INTEL_MEI*=m
+-    - LP: #1196155
+-  * [Config] CONFIG_DEBUG_INFO=y
+-
+-  [ Stephen Warren ]
+-
+-  * [Config] fix Calxeda xgmac module filename
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "serial: 8250_pci: add support for another kind of NetMos
+-    Technology PCI 9835 Multi-I/O Controller"
+-    - LP: #1190967
+-  * mfd: lpc_ich: Add support for Intel Avoton SoC
+-    - LP: #1196658
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jul 2013 18:08:02 +0100
+-
+-linux (3.10.0-2.9) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: (no-up) apparmor: Fix quieting of audit messages for
+-    network mediation"
+-  * Revert "SAUCE: (no-up) apparmor: Fix compile warnings"
+-  * Revert "SAUCE: (no-up) AppArmor: basic networking rules"
+-  * Revert "SAUCE: (no-up) apparmor: Add the ability to mediate mount"
+-  * Revert "SAUCE: (no-up) AppArmor: Add profile introspection file to
+-    interface"
+-  * Revert "SAUCE: (no-up) AppArmor: Disable Add PR_{GET,SET}_NO_NEW_PRIVS
+-    to prevent execve from granting privs"
+-  * SAUCE: (no-up) apparmor: Sync to apparmor 3 dev stable snapshot
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Jul 2013 17:42:29 +0100
+-
+-linux (3.10.0-1.8) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Release Tracking Bug
+-    - LP: #1195717
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: overlayfs -- follow change to do_splice_direct
+-    interface"
+-  * Revert "ubuntu: overlayfs -- expose do_splice_direct prototype"
+-  * Revert "SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path
+-    reference"
+-  * Revert "ubuntu: overlayfs -- add FS_ALIAS"
+-  * Revert "ubuntu: overlayfs --
+-    overlayfs-copy-up-i_uid-i_gid-from-the-underlying-inode"
+-  * Revert "ubuntu: overlayfs -- ovl-switch-to-inode_permission"
+-  * Revert "ubuntu: overlayfs -- vfs-export-inode_permission-to-modules"
+-  * Revert "ubuntu: overlayfs -- overlayfs-create-new-inode-in-ovl_link"
+-  * Revert "ubuntu: overlayfs --
+-    overlayfs-fix-possible-leak-in-ovl_new_inode"
+-  * Revert "ubuntu: overlayfs -- fs-limit-filesystem-stacking-depth"
+-  * Revert "ubuntu: overlayfs -- overlay-overlay-filesystem-documentation"
+-  * Revert "ubuntu: overlayfs -- overlayfs-implement-show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs-add-statfs-support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- vfs-introduce-clone_private_mount"
+-  * Revert "ubuntu: overlayfs -- vfs-export-do_splice_direct-to-modules"
+-  * Revert "ubuntu: overlayfs -- vfs-add-i_op-dentry_open"
+-  * ubuntu: overlayfs v18 -- -- overlayfs: add statfs support
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs v18 -- -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs v18 -- -- vfs: add i_op->dentry_open()
+-  * ubuntu: overlayfs v18 -- -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs v18 -- -- vfs: export __inode_permission() to modules
+-  * ubuntu: overlayfs v18 -- -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs v18 -- -- overlay filesystem
+-  * ubuntu: overlayfs v18 -- -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs v18 -- -- overlay: overlay filesystem documentation
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SUNRPC_DEBUG=y
+-    - LP: #1127319
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jun 2013 10:26:52 +0100
+-
+-linux (3.10.0-0.7) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * autopkgtest: switch Depends: to build-essential
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 25 Jun 2013 08:40:55 +0100
+-
+-linux (3.10.0-0.6) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_ARCH_TEGRA to fix FTBFS on armhf
+-  * SAUCE: ubuntu: overlayfs -- ovl_path_open should not take path reference
+-    - LP: #1098378
+-  * ubuntu: AUFS -- update to 4f14cef47eb7c23eda7198931fbab1040866b6ee
+-  * ubuntu: overlayfs -- expose do_splice_direct prototype
+-  * ubuntu: overlayfs -- follow change to do_splice_direct interface
+-  * [Config] flip CONFIG_NO_HZ_FULL_ALL off as it is overheating machines
+-    - LP: #1192691
+-
+-  [ Stefan Bader ]
+-
+-  * (d-i) Add dm-snapshot to md-modules
+-    - LP: #1191726
+-
+-  [ Tim Gardner ]
+-
+-  * Release tracker
+-    - LP: #1194149
+-  * [Config] CONFIG_WIL6210=n for armhf
+-  * [Config] d-i: Add calxedaxgmac to nic-modules
+-    - LP: #1192358
+-  * [debian] Use dh_strip
+-    - LP: #1192759
+-  * [Config] Enable perf for armhf
+-  * do_tools=false when cross compiling
+-  * [Config] CONFIG_CORE_DUMP_DEFAULT_ELF_HEADERS=y
+-    - LP: #1108082
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * nsp32: switch reset delay to msleep() as it is tooo long
+-  * alx: add a simple AR816x/AR817x device driver
+-    Plucked from linux-next. replaces ubuntu/alx in favor of
+-    'to be merged' version in 3.11.
+-  * rebase to v3.10-rc7
+-    - LP: #1189363
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Jun 2013 18:10:31 -0600
+-
+-linux (3.10.0-0.5) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc6
+-  * [Config] updateconfigs following rebase to v3.10-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Jun 2013 11:12:39 +0100
+-
+-linux (3.10.0-0.4) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] updateconfigs following rebase to v3.10-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 11:42:28 +0100
+-
+-linux (3.10.0-0.3) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc5
+-    - LP: #1186170
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 10 Jun 2013 09:23:31 +0100
+-
+-linux (3.10.0-0.2) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.10-rc4
+-  * [Config] CONFIG_BINFMT_SCRIPT=y to fix booting initramfs scripts
+-  * [Config] enable SND_PCM_DEBUG SND_PCM_XRUN_DEBUG
+-    - LP: #1187744
+-  * [Config] enforce CONFIG_BINFMT_SCRIPT=y
+-
+-  [ Dave Chiluk ]
+-
+-  * SAUCE: ncpfs: fix rmdir returns Device or resource busy
+-    - LP: #1035226
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.10-rc3
+-  * [Config] sparc be gone
+-  * [Config] ia64 be gone
+-  * d-i: block-modules provides nbd-modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc4
+-  * rebase to v3.10-rc3
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 May 2013 06:16:46 -0600
+-
+-linux (3.10.0-0.1) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * UBUNTU: Disabled lttng
+-  * UBUNTU: Disable aufs for FTBS
+-  * UBUNTU: Disabled alx
+-  * UBUNTU: alx: rename NETIF_F_HW_VLAN_* feature flags to NETIF_F_HW_VLAN_CTAG_*
+-  * UBUNTU: rebase to v3.10-rc2
+-  * UBUNTU: SAUCE: uvcvideo: quirk PROBE_DEF for Alienware X51 OmniVision webcam
+-
+-  [ Andy Whitcroft ]
+-
+-  * UBUNTU: [Config] update standards version to 3.9.4.0
+-  * UBUNTU: [Config] squash duplicate package description (long and short)
+-  * UBUNTU: [Config] fix up Vcs-git: to point to saucy
+-  * UBUNTU: [Config] drop depenancy on util-linux as is Essential
+-  * UBUNTU: [Config] drop redundant Build-Conficts:
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc2
+-    - LP: #1180351
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.10-rc1
+-    - LP: #1172151
+-    - LP: #1089795
+-    - LP: #1167270
+-    - LP: #1128840
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 14 May 2013 13:41:07 -0600
+-
+-linux (3.10.0-0.0) saucy; urgency=low
+-
+-  * Dummy
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
+-
+-linux (3.9.0-2.6) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.9.2
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 09 May 2013 20:30:40 +0100
+-
+-linux (3.9.0-1.5) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.9.1
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Wed, 08 May 2013 12:49:45 -0400
+-
+-linux (3.9.0-0.4) saucy; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- add FS_ALIAS
+-
+-  [ Tim Gardner ]
+-
+-  * Added lttng
+-    - LP: #1175784
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 02 May 2013 17:17:13 -0400
+-
+-linux (3.9.0-0.3) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 18:20:00 -0400
+-
+-linux (3.9.0-0.2) saucy; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Enable extras packaging for amd64/i386.
+-    Fixes build depenencies with brittany and linux-meta.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 29 Apr 2013 05:37:01 -0600
+-
+-linux (3.9.0-0.1) saucy; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc8
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc7
+-    - LP: #1128840
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc4
+-    - LP: #1095315
+-    - LP: #886975
+-    - LP: #1086921
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc3
+-    - LP: #1155016
+-    - LP: #1103594
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc2
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.9-rc1
+-    - LP: #901105
+-    - LP: #961286
+-    - LP: #1011792
+-    - LP: #1128934
+-    - LP: #886975
+-    - LP: #978807
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 20 Feb 2013 09:12:39 -0700
+-
+-linux (3.8.0-7.14) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_RCU_USER_QS=n
+-  * [Config] CONFIG_MTD_ONENAND_SIM=n
+-  * annotations: add annotations for CONFIG_CC_STACKPROTECTOR
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1130111
+-  * UBUNTU: SAUCE: rt2x00: rt2x00pci_regbusy_read() - only print register access failure once
+-    - LP: #1128840
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 18 Feb 2013 09:25:56 -0700
+-
+-linux (3.8.0-6.13) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1125364
+-  * Add ahci modules to d-i
+-    - LP: #1124415
+-
+-
+-  [ Chris Wilson ]
+-
+-  * SAUCE: drm/i915: Wait for pending flips to complete before tearing down
+-    the encoders
+-    - LP: #1097315
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 12:16:48 -0700
+-
+-linux (3.8.0-6.12) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * perf: NO_LIBPERL=1
+-  * Fix linux-headers dependency
+-  * Release Tracking Bug
+-    - LP: #1124362
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_AUFS_EXPORT to allow nfs exports
+-    - LP: #1121699
+-
+-  [ Daniel Vetter ]
+-
+-  * SAUCE: drm/i915: write backlight harder
+-    - LP: #954661
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 13 Feb 2013 10:25:11 -0700
+-
+-linux (3.8.0-6.11) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1122071
+-  * rebase to v3.8-rc7
+-  * Add libaudit-dev as a build dependency
+-  * Build perf with NO_LIBPYTHON=1 to avoid a python build dependency.
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Remove CONFIG_SATA_AHCI annotation
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Fri, 08 Feb 2013 07:41:13 -0500
+-
+-linux (3.8.0-5.10) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1118568
+-
+-  * Bump ABI to fix install issue with 3.8.0-4.8.
+-    Moving drivers/ata/*ahci* to linux-image caused an
+-    install conflict with linux-image-extras without an
+-    ABI bump.
+-
+-  [ Jan Beulich ]
+-
+-  * SAUCE: xen-pciback: rate limit error messages from
+-    xen_pcibk_enable_msi{, x}()
+-    - LP: #1117336
+-    - CVE-2013-0231
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 07 Feb 2013 05:38:12 -0700
+-
+-linux (3.8.0-4.9) raring; urgency=low
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * d-i: Add mellanox ethernet drivers to nic-modules
+-    - LP: #1015339
+-
+-  [ Joseph Salisbury ]
+-
+-  * SAUCE: ACPI: Add DMI entry for Sony VGN-FW41E_H
+-    - LP: #1113547
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: alx driver import script
+-
+-  [ Qualcomm Atheros, Inc ]
+-
+-  * SAUCE: alx: Update to heads/master
+-
+-  [ Tim Gardner ]
+-
+-  * Release Tracking Bug
+-    - LP: #1117673
+-
+-  * [debian] Remove dangling symlink from headers package
+-    - LP: #1112442
+-  * [config] CONFIG_ALX=m
+-  * [Config] Add alx to d-i nic-modules
+-  * [Config] CONFIG_SATA_AHCI=m
+-    - LP: #1056563
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Feb 2013 05:54:32 -0800
+-
+-linux (3.8.0-4.8) raring; urgency=low
+-
+-  [ Allen Ibara ]
+-
+-  * SAUCE: imx6: dts: Add IMX6Q AHCI support
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.8-rc6
+-  * updateconfigs following rebase to v3.8-rc6
+-
+-  [Leann Ogasawara]
+-
+-  * Release Tracking Bug
+-    - LP: #1112573
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: imx6: enable sata clk if SATA_AHCI_PLATFORM
+-  * [Config] SERIAL_AMBA_PL011=y (vexpress serial console)
+-  * [Config] MMC_ARMMMCI=y (vexpress mmc)
+-  * [Config] FB_ARMCLCD=y (vexpress framebuffer)
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] CONFIG_MAC80211_MESSAGE_TRACING=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc6
+-    - LP: #1107477
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 01 Feb 2013 07:20:59 -0800
+-
+-linux (3.8.0-3.7) raring; urgency=low
+-
+-  [ Andy Green ]
+-
+-  * SAUCE: ARM: OMAP2+: add cpu id register to MAC address helper
+-  * SAUCE: ARM: omap2 add mac address allocation register api
+-  * SAUCE: ARM: omap2 panda register ethernet and wlan for automatic mac
+-    allocation
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.8-rc5
+-  * Release Tracking Bug
+-    - LP: #1111486
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: davinci: vpss: compilation fix
+-  * [Config] enable TI OMAP4 support (Pandaboard/ES)
+-  * [Config] OMAP_USB2=y (since TWL6030_USB depends on it)
+-  * [Config] enable Freescale IMX6 support (SabreLite)
+-  * [Config] SERIAL_IMX_CONSOLE=y
+-  * [Config] MMC_*_IMX=y
+-  * [Config] disable USB_SUSPEND
+-  * [Config] USB_MXS_PHY=y
+-  * [Config] USB_CHIPIDEA=y
+-  * SAUCE: DTB: add support for multiple DTBs
+-  * SAUCE: DTB: build imx6q-sabrelite
+-  * SAUCE: DTB: build beaglexm
+-  * SAUCE: DTB: build panda/panda es
+-  * [Config] disable CPU_FREQ
+-  * [Config] PANEL_TFP410=y (video DVI output)
+-  * [Config] SND_OMAP_SOC*=y
+-  * [Config] SND_IMX_SOC*=y
+-  * [Config] I2C_IMX=y
+-  * [Config] SPI_IMX=m
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Move 9p modules into generic package
+-    - LP: #1107658
+-
+-  [ Tony Lindgren ]
+-
+-  * SAUCE: ARM: OMAP2+: Limit omap initcalls to omap only on multiplatform
+-    kernels
+-  * SAUCE: ARM: OMAP2+: Use omap initcalls
+-  * SAUCE: ARM: OMAP: Fix i2c cmdline initcall for multiplatform
+-  * SAUCE: ARM: OMAP: Fix dmaengine init for multiplatform
+-  * SAUCE: ARM: OMAP2+: Add multiplatform debug_ll support
+-  * SAUCE: ARM: OMAP2+: Disable code that currently does not work with
+-    multiplaform
+-  * SAUCE: ARM: OMAP2+: Enable ARCH_MULTIPLATFORM support
+-  * SAUCE: ARM: OMAP2+: Add minimal support for booting vexpress
+-  * SAUCE: ARM: OMAP2+: Remove now obsolete uncompress.h and debug-macro.S
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc5
+-    - LP: #1096789
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Jan 2013 06:44:52 -0800
+-
+-linux (3.8.0-2.6) raring; urgency=low
+-
+-  [ Adam Conrad ]
+-
+-  * Fix up linux-tools -> SRCPKGNAME-tools rename
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] re-disable CONFIG_SOUND_OSS
+-    - LP: #1105230
+-
+-  [ Arend van Spriel ]
+-
+-  * SAUCE: brcmsmac: fix tx status processing
+-
+-  [Leann Ogasawara]
+-
+-  * Release Tracking Bug
+-    - LP: #1105104
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 Jan 2013 11:56:30 -0800
+-
+-linux (3.8.0-1.5) raring; urgency=low
+-
+-  [Tim Gardner]
+-
+-  * Release Tracking Bug
+-    - LP: #1101235
+-
+-  [ Dudley Du ]
+-
+-  * SAUCE: Input: add support for Cypress PS/2 Trackpads
+-    - LP: #978807
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: Input: increase struct ps2dev cmdbuf[] to 8 bytes
+-  * SAUCE: Input: Cypress PS/2 Trackpad simulated multitouch
+-  * [Config] Add CONFIG_PS2_CYPRESS
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.8-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc4
+-    - LP: #1095315
+-    - LP: #886975
+-    - LP: #1086921
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jan 2013 10:50:22 -0800
+-
+-linux (3.8.0-0.4) raring; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Update CONFIG_TOUCHSCREEN_EGALAX build annotation
+-  * [Config] Update CONFIG_IIO build annotation
+-  * [Config] Update CONFIG_TOUCHSCREEN_EETI annotation
+-  * [Config] Remove CONFIG_SPI_DW_MMIO annotation
+-  * [Config] Remove CONFIG_SPI_PL022 annotation
+-  * [Config] Update CONFIG_EZX_PCAP annotation
+-  * [Config] Update CONFIG_SENSORS_AK8975 annotation
+-  * [Config] Disable CONFIG_DRM_MGAG200
+-    - LP: #1042903
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 Jan 2013 10:01:50 -0800
+-
+-linux (3.8.0-0.3) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: (no-up) trace: add trace events for open(), exec() and
+-    uselib()"
+-
+-  [ Scott James Remnant ]
+-
+-  * SAUCE: (no-up) trace: add trace events for open(), exec() and uselib()
+-    (for v3.7+)
+-    - LP: #1085766, #462111
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Jan 2013 16:57:27 +0000
+-
+-linux (3.8.0-0.2) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [packaging] Add macro to selectively disable building perf
+-  * [packaging] Cannot depend on universe package libaudit-dev
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Jan 2013 12:43:24 -0700
+-
+-linux (3.8.0-0.1) raring; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc3
+-    - LP: #1096789
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.8-rc2
+-    - LP: #1082357
+-    - LP: #1075882
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 17 Dec 2012 10:35:09 +0000
+-
+-linux (3.7.0-7.15) raring; urgency=low
+-
+-  [ Chris J Arges ]
+-
+-  * SAUCE: add eeprom_bad_csum_allow module parameter
+-    - LP: #1070182
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add ceph to linux-image for virtual instances
+-    - LP: #1063784
+-
+-  [ Serge Hallyn ]
+-
+-  * SAUCE: net: dev_change_net_namespace: send a KOBJ_REMOVED/KOBJ_ADD
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SLUB_DEBUG=y
+-    - LP: #1090308
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[SCSI] sd: Implement support for WRITE SAME"
+-    - LP: #1089818
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 Dec 2012 06:50:20 -0800
+-
+-linux (3.7.0-6.14) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] annotations: all new annotations scheme including defaults
+-  * [Configs] apply annotation updates to main configs (top section)
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm
+-    build"
+-  * Revert "SAUCE: [arm] fixup __aeabi_uldivmod undefined build error"
+-  * Temporarily disable module check for build
+-
+-  [ Stefan Bader ]
+-
+-  * ubuntu: dm-raid45: Adapt to upstream interface changes
+-  * Re-enable build of dm-raid45
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Moved scripts/fw-to-ihex.sh to debian/scripts/misc
+-  * SAUCE: ACPICA: Fix ACPI mutex object allocation memory leak on error
+-  * SAUCE: drm: Fix possible EDID memory allocation oops
+-  * SAUCE: ttm: Fix possible _manager memory allocation oops
+-  * SAUCE: iwlwifi: iwlagn_request_scan: Fix check for priv->scan_request
+-  * SAUCE: i915: intel_set_mode: Reduce stack allocation from 500 bytes to
+-    2 pointers
+-
+-  [ Tomas Hozza ]
+-
+-  * SAUCE: tools: hv: Netlink source address validation allows DoS
+-    - LP: #1084777
+-    - CVE-2012-5532
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 05 Dec 2012 14:11:12 -0800
+-
+-linux (3.7.0-5.13) raring; urgency=low
+-
+-  [ Lino Sanfilippo ]
+-
+-  * SAUCE: inotify, fanotify: replace fsnotify_put_group() with
+-    fsnotify_destroy_group()
+-    - LP: #922906
+-  * SAUCE: fsnotify: introduce fsnotify_get_group()
+-    - LP: #922906
+-  * SAUCE: fsnotify: use reference counting for groups
+-    - LP: #922906
+-  * SAUCE: fsnotify: take groups mark_lock before mark lock
+-    - LP: #922906
+-  * SAUCE: fanotify: add an extra flag to mark_remove_from_mask that
+-    indicates wheather a mark should be destroyed
+-    - LP: #922906
+-  * SAUCE: fsnotify: use a mutex instead of a spinlock to protect a groups
+-    mark list
+-    - LP: #922906
+-  * SAUCE: fsnotify: pass group to fsnotify_destroy_mark()
+-    - LP: #922906
+-  * SAUCE: fsnotify: introduce locked versions of fsnotify_add_mark() and
+-    fsnotify_remove_mark()
+-    - LP: #922906
+-  * SAUCE: fsnotify: dont put marks on temporary list when clearing marks
+-    by group
+-    - LP: #922906
+-  * SAUCE: fsnotify: change locking order
+-    - LP: #922906
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NFC_LLCP=y
+-  * [Config] get-firmware: Filter new files through fwinfo
+-  * [Config] CONFIG_MTD_NAND_DOCG4=m for all arches
+-  * [Config] CONFIG_DRM_EXYNOS_HDMI=y
+-  * [Config] CONFIG_XEN=y for all arches
+-  * [Config] CONFIG_SND_OMAP_SOC_ZOOM2=m
+-  * [Config] CONFIG_MMC_DW_EXYNOS=m
+-  * [Config] CONFIG_GPIO_ADNP=m
+-  * [Config] find-obsolete-firmware: Use correct path
+-  * rebase to v3.7-rc8
+-    - LP: #1084640
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "VFS: don't do protected {sym,hard}links by default"
+-    - LP: #1084192
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 28 Nov 2012 16:07:08 +0000
+-
+-linux (3.7.0-4.12) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "[Config] Use -j1 for headers_install"
+-  * Revert "[Config] install-arch-headers needs a valid config"
+-    Strayed into the weeds in search of the root cause of the periodic
+-    build failure.
+-    Fixes powerpc FTBS introduced in -4.11.
+-  * [Config] hmake -j1
+-    The kernel makefile appears to have parallel dependency
+-    problems for the install_headers target. This appears to be root
+-    cause for a periodic build failure on N-way machines.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 27 Nov 2012 12:33:06 -0800
+-
+-linux (3.7.0-4.11) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Use -j1 for headers_install
+-    Also fixes a powerpc FTBS introduced by
+-    "[Config] install-arch-headers needs a valid config".
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 27 Nov 2012 10:19:30 -0700
+-
+-linux (3.7.0-4.10) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add rebuild-test support for autopkgtest
+-    - LP: #1081500
+-  * [tests] move build tests out of the way
+-    - LP: #1081500
+-  * [tests] add an autopkgtest rebuild test
+-    - LP: #1081500
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.7-rc7
+-  * SAUCE: Remove emi62 files duplicated in linux-firmware
+-  * SAUCE: Remove sb16 files duplicated in linux-firmware
+-  * SAUCE: Remove whiteheat files duplicated in linux-firmware
+-  * SAUCE: Remove yamaha files duplicated in linux-firmware
+-  * SAUCE: Remove dsp56k files used only by m68k
+-  * SAUCE: firmware: Remove last vestiges of dabusb
+-  * SAUCE: Remove vicam files duplicated in linux-firmware
+-  * [Config] install-arch-headers needs a valid config
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc7
+-    - LP: #1076840
+-    - LP: #1081466
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 21 Nov 2012 06:07:23 -0800
+-
+-linux (3.7.0-3.9) raring; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_X86_CPUFREQ_NFORCE2=y
+-    - LP: #1079900
+-  * Add nfsv3 to nfs-modules udeb
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] SND_OMAP_SOC*=y
+-    - LP: #1019321
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: (no-up) xen/netfront: handle compound page fragments on transmit
+-    - LP: #1078926
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: SECCOMP: audit: always report seccomp violations"
+-    - LP: #1079469
+-  * Revert "SAUCE: omap3 clocks .dev_id = NULL"
+-  * rebase to v3.7-rc6
+-  * SAUCE: script to detect obsolete firmware
+-  * SAUCE: Remove yam files duplicated in linux-firmware
+-  * SAUCE: Remove tehuti files duplicated in linux-firmware
+-  * SAUCE: Remove matrox files duplicated in linux-firmware
+-  * SAUCE: Remove cxgb3 files duplicated in linux-firmware
+-  * SAUCE: Remove r128 files duplicated in linux-firmware
+-  * SAUCE: Remove acenic files duplicated in linux-firmware
+-  * SAUCE: Remove keyspan files duplicated in linux-firmware
+-  * SAUCE: Remove sun files duplicated in linux-firmware
+-  * SAUCE: Remove radeon files duplicated in linux-firmware
+-  * SAUCE: Update bnx2x firmware to 7.8.2.0
+-  * [Config] generic.inclusion-list: econet has disappeared
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * seccomp: forcing auditing of kill condition
+-    - LP: #1079469
+-  * rebase to v3.7-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Nov 2012 12:28:55 -0800
+-
+-linux (3.7.0-2.8) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "overlayfs: disable until FTBS is fixed"
+-  * Revert "ubuntu: overlayfs"
+-  * Revert "ubuntu: AUFS"
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- ovl: switch to __inode_permission()
+-  * ubuntu: overlayfs -- overlayfs: copy up i_uid/i_gid from the underlying
+-    inode
+-    - LP: #944386
+-  * ubuntu: AUFS (no-squash): basic framework and update machinary
+-  * ubuntu: AUFS (no-squash) -- aufs3-base.patch
+-  * ubuntu: AUFS (no-squash) -- aufs3-standalone.patch
+-  * ubuntu: AUFS: aufs-update -- follow the uapi header changes
+-  * ubuntu: AUFS -- update to f2873474324d0a31af4340554b9715f51331bc7f
+-  * ubuntu: AUFS (no-squash) -- reenable
+-    - LP: #1079193
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: add i_op->dentry_open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-  * ubuntu: overlayfs -- vfs: export __inode_permission() to modules
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Robin Dong ]
+-
+-  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
+-  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 15 Nov 2012 13:35:12 +0000
+-
+-linux (3.7.0-1.7) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Drop dependency on libaudit-dev
+-    Its a universe package which causes an FTBS on the builders.
+-    libaudit-dev is not strictly required for the perf tools build.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 14 Nov 2012 10:08:13 -0700
+-
+-linux (3.7.0-1.6) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enforce -- switch CONFIG_NVRAM to more readable form
+-  * [Config] better encode the CONFIG_NVRAM constaint
+-  * enforcer -- fix debugging output
+-
+-  [ Ben Collins ]
+-
+-  * [Config] Add custom_override rule to allow for alternate kernel
+-    file/install
+-  * [Config] Use SRCPKGNAME as prefix for indep linux headers package
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped armel
+-  * Drop highbank from ABI fetch list
+-  * [Config] Use dh_prep instead of 'dh_clean -k'
+-  * [Config] Build depend on libaudit-dev, libunwind8-dev for tools
+-  * [Config] Document binary-indep dependency chain
+-  * rebase to v3.7-rc5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc5
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 13 Nov 2012 07:13:37 -0500
+-
+-linux (3.7.0-0.5) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_AMD_IOMMU_V2=m
+-    - LP: #1071520
+-  * [Config] CONFIG_MTD_ONENAND_SIM=n for armel
+-    Fixes FTBS
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 15:45:39 -0500
+-
+-linux (3.7.0-0.4) raring; urgency=low
+-
+-  [ Ben Collins ]
+-
+-  * [Config] Update enforce rule for CONFIG_NVRAM to better suit flavours
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] do_tools=false for arm
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Nov 2012 05:39:51 -0700
+-
+-linux (3.7.0-0.3) raring; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_DRM_EXYNOS_HDMI=n for armhf
+-  * [Config] CONFIG_MTD_NAND_DOCG4=n for armel/armhf
+-  * [Config] Drop highbank harder
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 07 Nov 2012 18:11:45 +0000
+-
+-linux (3.7.0-0.2) raring; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add fs/udf to linux-image to support DVD/CD formats in virtual
+-    instances
+-    - LP: #1066921
+-  * [Config] drop highbank builds
+-
+-  [ Jeremy Kerr ]
+-
+-  * SAUCE: efivarfs: Implement exclusive access for {get, set}_variable
+-    - LP: #1063061
+-
+-  [ Leann Ogasawara ]
+-
+-  * Reinstate dropped.txt from Ubuntu-3.7.0-0.1-rc1
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped powerpc/ppc64 in favour of the community kernel
+-  * [Config] CONFIG_MODULE_SIG=y for amd64,i386, and highbank
+-  * rebase to v3.7-rc4
+-  * SAUCE: MODSIGN: Emit error for incorrectly signed module
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc4
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 05 Nov 2012 05:35:41 -0700
+-
+-linux (3.7.0-0.1) raring; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc3
+-    - LP: #1056078
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.7-rc2
+-    - LP: #1060729
+-    - LP: #1059523
+-    - LP: #1006690
+-    - LP: #1049623
+-    - LP: #1046512
+-    - LP: #1052499
+-    - LP: #1037642
+-    - LP: #559939
+-    - LP: #1052460
+-    - LP: #939161
+-    - LP: #1046734
+-
+- -- Tim Gardner <tim.gardner@canonical.com>  Tue, 02 Oct 2012 08:13:07 -0600
+-
+-linux (3.6.0-0.1) UNRELEASED; urgency=low
+-
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc6
+-    - LP: #1000424
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc5
+-    - LP: #1040077
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.6-rc3
+-    - LP: #1038651
+-    - LP: #1034779
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 24 Jul 2012 06:37:09 -0700
+-
+-linux (3.5.0-6.6) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_INET6_XFRM_MODE_ROUTEOPTIMIZATION enable IPv6
+-    experimental features
+-  * SAUCE: highbank -- export clock functions for modules
+-  * [Config] highbank -- reenable CONFIG_TOUCHSCREEN_W90X900
+-  * [Config] highbank -- renenable CONFIG_SERIO_AMBAKMI
+-  * [Config] highbank -- reenable CONFIG_RFKILL_GPIO
+-  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
+-  * [Config] highbank -- reenable CONFIG_MMC_SDHCI_PXAV3
+-  * [Config] highbank -- reenable CONFIG_KEYBOARD_SAMSUNG
+-  * [Config] highbank -- reenable CONFIG_FB_ARMCLCD
+-  * [Config] highbank -- reenable CONFIG_DW_DMAC
+-  * [Config] highbank -- reenable CONFIG_USB_R8A66597_HCD
+-  * [Config] highbank -- reenable CONFIG_USB_MV_UDC
+-  * [Config] highbank -- reenable CONFIG_USB_DWC3
+-  * [Config] highbank -- reenable CONFIG_SATA_MV
+-  * [Config] highbank -- reenable CONFIG_PATA_ARASAN_CF
+-  * [Config] highbank -- CONFIG_CAN_C_CAN_PLATFORM
+-  * [Config] highbank -- reenable CONFIG_MMC_ARMMMCI
+-  * [Config] highbank -- reenable CONFIG_SERIAL_AMBA_PL010
+-  * [Config] highbank -- reenable CONFIG_ATMEL_PWM
+-  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
+-  * [Config] highbank -- enable CONFIG_EXPERT
+-  * [Config] highbank -- enable CONFIG_CHECKPOINT_RESTORE
+-  * [Config] enable CONFIG_USB_DYNAMIC_MINORS
+-  * [Config] enable CONFIG_USB_EHCI_TT_NEWSCHED
+-  * [Config] enable CONFIG_USB_ETH_EEM
+-  * [Config] enable CONFIG_USB_HCD_BCMA/CONFIG_USB_HCD_SSB
+-  * [Config] disable CONFIG_USB_M66592
+-  * [Config] enable CONFIG_USB_NET2272
+-  * [Config] enable CONFIG_USB_R8A66597
+-  * [Config] annotate: CONFIG_USB_OMAP not required for our h/w
+-  * [Config] set CONFIG_USB_MUSB_HDRC=m for omap
+-  * [Config] annotate: CONFIG_USB_G_MULTI fix rule
+-  * [Config] CONFIG_USB_GPIO_VBUS=m for OMAP
+-  * [Config] Enable CONFIG_DRM_AST/_CIRRUS_QEMU/_MGAG200
+-  * [Config] sync configuration armhf omap -> armel omap
+-  * [Config] annotate: CONFIG_IIO triggers build failures on OMAP4
+-  * [Config] disable CONFIG_OMAP_IOVMM is deprecated
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] change default IO scheduler from CFQ to Deadline
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc"
+-  * [Config] Disable CONFIG_MOUSE_INPORT
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: firmware: Update bnx2x to current firmware version 7.2.51
+-  * [Config] Add bnx2x firmware to nic-modules udeb
+-  * SAUCE: Add script to convert firmware to ihex format
+-  * SAUCE: firmware: Upgrade bnx2 to current versions
+-  * [Config] Add tigon firmware to nic-modules udeb
+-  * [Config] CONFIG_EARLY_PRINTK_DBGP=y
+-    - LP: #1026761
+-  * SAUCE: Remove redundant cis firmware
+-  * SAUCE: Remove redundant emi26 firmware
+-  * SAUCE: Remove redundant ttusb-budget firmware
+-  * SAUCE: Remove redundant sun/cassini firmware
+-  * SAUCE: Remove redundant ositech/Xilinx7OD firmware
+-  * SAUCE: Remove redundant 3com/typhoon.bin firmware
+-  * SAUCE: Remove redundant yamaha/ds1 firmware
+-  * SAUCE: Remove redundant keyspan_pda firmware
+-  * rebase to v3.5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5
+-    - LP: #1027828
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Jul 2012 05:57:04 -0700
+-
+-linux (3.5.0-5.5) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] annotations: initial import of configuration annotations
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] enforcer -- add CONFIG_I2C_DESIGNWARE_PLATFORM enforce checker
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc7
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Bluetooth: btusb: Add vendor specific ID (0a5c:21f4) BCM20702A0
+-    - LP: #1010281
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] enable CONFIG_I2C_HELPER_AUTO for all flavours as policy
+-    expects
+-  * [Config] CONFIG_I2O_CONFIG_OLD_IOCTL=n
+-  * [Config] CONFIG_BRIDGE_EBT_ULOG=n
+-  * [Config] CONFIG_IP_NF_QUEUE=n
+-  * [Config] CONFIG_MTD_DOC2000=n
+-  * [Config] CONFIG_PRINT_QUOTA_WARNING=n
+-  * [Config] CONFIG_PRISM54=n
+-  * [Config] CONFIG_SCx200_I2C=n
+-  * [Config] CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jul 2012 15:38:41 -0700
+-
+-linux (3.5.0-4.4) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Packaging] getabis should be extracting all packages
+-    - LP: #1021174
+-  * [Config] getabis -- series uses linux-image-extra
+-    - LP: #1021174
+-  * rebase to v3.5-rc6
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] built-in CONFIG_MICREL_PHY as other PHY drivers for all
+-    flavours
+-  * [Config] sync CONFIG_MOUSE_PS2_ config for all flavours
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_RT2800USB_RT35XX and CONFIG_RT2800USB_RT53XX
+-    - LP: #1019561
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] SND_OMAP_SOC, SND_OMAP_SOC_MCBSP and SND_OMAP_SOC_OMAP3_BEAGLE =y
+-    - LP: #1019321
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: (pre-up) net: dont use __netdev_alloc_skb for bounce buffer
+-    - LP: #1018456
+-  * (config) Disable ACPI_PROCFS_POWER
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_ACPI_BGRT=y
+-  * Extract firmware module info during getabi
+-    - LP: #1021174
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Jul 2012 08:50:20 -0700
+-
+-linux (3.5.0-3.3) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_MEMTEST=y
+-    - LP: #1004535
+-  * [Config] config-check: add support for a cut operation
+-  * [Config] enforcer -- switch to cut where appropriate
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc5
+-  * [Config] Updateconfigs after rebase to v3.5-rc5
+-
+-  [ Luis Henriques ]
+-
+-  * SAUCE: ocfs2: Fix NULL pointer dereferrence in
+-    __ocfs2_change_file_space
+-    - LP: #1006012
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.5) drm/i915: ignore pipe select bit when checking
+-    for LVDS register initialization
+-    - LP: #1012800
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc5
+-    - LP: #1013183
+-    - LP: #1017017
+-    - LP: #884652
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 02 Jul 2012 06:41:58 -0700
+-
+-linux (3.5.0-2.2) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.5-rc4
+-
+-  [ Arend van Spriel ]
+-
+-  * SAUCE: (drop after 3.5) brcmsmac: fix NULL pointer crash in
+-    brcms_c_regd_init()
+-    - LP: #950320
+-
+-  [ Bryan Wu ]
+-
+-  * [Config] Sync CONFIG_CGROUP_MEM_RES_CTLR_SWAP for ARM
+-
+-  [ Chris J Arges ]
+-
+-  * PACKAGING: add .gnu_debuglink sections to .ko files
+-    - LP: #669641
+-
+-  [ Leann Ogasawara ]
+-
+-  * d-i: Add hid-generic to input-modules
+-    - LP: #1017879
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: Revert "mmc: omap_hsmmc: Enable Auto CMD12"
+-    - LP: #1017717, #225
+-
+-  [ Paolo Pisati ]
+-
+-  * SAUCE: Revert "Fix OMAP EHCI suspend/resume failure (i693)"
+-    - LP: #1017718
+-  * [Config] Disable generic USB_EHCI_HCD_PLATFORM on omap3
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.5) brcm80211: smac: don't set up tx power limits
+-    during initialization
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: always set channel specified
+-    by mac80211
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: remove unused code for 40MHz
+-    channels
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: clean up channel.c
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: inform mac80211 of the X2
+-    regulatory domain
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: enable/disable radio on
+-    regulatory updates
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: use mac80211 channel data for
+-    tx power limits
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: don't validate channels
+-    against internal regulatory data
+-    - LP: #950320
+-  * SAUCE: (drop after 3.5) brcm80211: smac: use current regulatory domain
+-    when checking whether OFDM is allowed
+-    - LP: #950320
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable CONFIG_CGROUPS for highbank
+-    - LP: #1014692
+-  * [Config] FB_OMAP*=y and PANEL_TFP410=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 26 Jun 2012 06:21:05 -0700
+-
+-linux (3.5.0-1.1) quantal-proposed; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] highbank -- enable CONFIG_RFKILL=y and CONFIG_CAN=m
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.5-rc1
+-  * [Config] Remove USB_DEVICEFS from the config enforcer
+-  * [Config] Updateconfigs after rebase to v3.5-rc1
+-  * [Config] Temporarily disable CONFIG_MACH_NOKIA_RX51 on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
+-  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
+-  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
+-  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
+-  * [Config] Temporarily disable CONFIG_GPIO_EM on arm
+-  * [Config] Temporarily disable CONFIG_SERIAL_8250_EM on armhf
+-  * [Config] Temporarily disable CONFIG_STMMAC_ETH on armhf
+-  * [Config] Temporarily disable CONFIG_HW_RANDOM_ATMEL on armhf
+-  * Rebase to v3.5-rc2
+-  * [Config] Updateconfigs after rebase to v3.5-rc2
+-  * [Config] Temporarily disable CONFIG_MV643XX_ETH on powerpc
+-  * Rebase to v3.5-rc3
+-  * [Config] Updateconfigs after rebase to v3.5-rc3
+-
+-  [ Paul Mundt ]
+-
+-  * SAUCE: fix bug.h's inclusion of kernel.h
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Fix compile failures of dm-raid45
+-  * [Config] Enable dm-raid45
+-  * Move dependency on crda to extra package
+-    - LP: #657901
+-  * SAUCE: Mask CR4 writes on older Xen hypervisors
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.5-rc3
+-    - LP: #993162
+-    - LP: #925577
+-  * rebase to v3.5-rc2
+-  * rebase to v3.5-rc1
+-    - LP: #955892
+-    - LP: #978038
+-    - LP: #987371
+-    - LP: #929545
+-    - LP: #942316
+-    - LP: #903853
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 08 Jun 2012 14:28:46 -0700
+-
+-linux (3.4.0-5.11) quantal-proposed; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_ARM_LPAE
+-    - LP: #1009061
+-
+-  [ Oleksij Rempel ]
+-
+-  * SAUCE: b43: do not call ieee80211_unregister_hw if we are not registred
+-    - LP: #1008905
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] omap3: MFD_OMAP_USB_HOST is usb host in omap2+.
+-    - LP: #1009061
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 05 Jun 2012 08:06:28 -0700
+-
+-linux (3.4.0-4.10) quantal; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temporarily disable ABI and module check
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 20:27:31 -0700
+-
+-linux (3.4.0-4.9) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] fix config split to avoid the shared config
+-  * [Config] updateconfigs following split config fix
+-  * [Config] linux-image-extras needs full postinst
+-  * [Config] CONFIG_BLK_DEV_NVME commonise across architectures
+-  * [Config] CONFIG_HP_WATCHDOG enable as module
+-  * [Config] CONFIG_PDC_ADMA is not boot essential
+-  * [Config] CONFIG_XEN_ACPI_PROCESSOR should be enabled on x86
+-  * [Config] CONFIG_VT6655/CONFIG_VT6656=m
+-  * [Config] CONFIG_TRANZPORT=m commonise
+-  * [Config] CONFIG_R3964=m commonise
+-  * [Config] CONFIG_SCSI_DH=m commonise
+-  * [Config] CONFIG_SCSI_IBMVSCSIS=m commonise
+-  * [Config] CONFIG_AMD_PHY=y phys are not autoloadable
+-  * [Config] CONFIG_SCSI_QLA_ISCSI=m commonise
+-  * [Config] CONFIG_SCSI_SPI_ATTR=m commonise
+-  * [Config] CONFIG_USB_SN9C102 is deprecated disable
+-  * [Config] CONFIG_USB_SI470X=m commonise
+-  * [Config] CONFIG_USB_ET61X251=m commonise
+-  * [Config] CONFIG_RTS_PSTOR=m commonise
+-  * [Config] CONFIG_SCANLOG=m commonise
+-  * [Config] CONFIG_SCSI_SYM53C8XX_2=m commonise
+-  * [Config] CONFIG_SM_FTL=m commonise
+-  * [Config] CONFIG_SOLO6X10=m commonise
+-  * [Config] CONFIG_SND_PCM_OSS=n using pulseaudio emulation instead
+-  * [Config] CONFIG_SPI_DESIGNWARE=m commonise
+-  * [Config] CONFIG_SPI_SPIDEV=m commonise
+-  * [Config] CONFIG_TABLET_USB_WACOM=m commonise
+-  * [Config] CONFIG_TPS65010=m commonise
+-  * [Config] CONFIG_STE10XP=y commonise
+-  * [Config] CONFIG_X25_ASY=m commonise
+-  * [Config] CONFIG_USB_MON=m commonise
+-  * [Config] CONFIG_VME_BUS=m commonise
+-  * [Config] CONFIG_W35UND=m commonise
+-  * [Config] -CONFIG_TCG_TPM=y commonise
+-  * [Config] highbank -- commonise filesystems
+-  * [Config] highbank -- commonise subsystems
+-  * [Config] highbank -- commonise network protocols
+-  * [Config] highbank -- commonise input drivers
+-  * [Config] highbank -- commonise CRYPTO options
+-  * [Config] highbank -- commonise HID options
+-  * [Config] highbank -- commonise sensors options
+-  * [Config] highbank -- commonise EXPORTFS/FHANDLE
+-  * [Config] highbank -- commonise CONFIG_CRYPTO_LZO
+-  * [Config] highbank -- commonise ENCRYPTED_KEYS
+-  * [Config] highbank -- commonise CONFIG_ATALK
+-  * [Config] highbank -- commonise INET/INET6
+-  * [Config] highbank -- commonise NLS
+-  * [Config] highbank -- commonise BLK/CHR
+-  * [Config] highbank -- CONFIG_EXT2_FS=y boot essential on highbank
+-  * [Config] highbank -- commonise INET/INET6 part 2
+-  * [Config] highbank -- commonise PHY settings
+-  * [Config] highbank -- commonise CRC settings
+-  * [Config] highbank -- commonise BINFMT settings
+-  * [Config] highbank -- commonise DM settings
+-  * [Config] highbank -- commonise RTC_DRV settings
+-  * [Config] highbank -- commonise KEYBOARD/MOUSE settings
+-  * [Config] highbank -- commonise USB settings
+-  * [Config] highbank -- commonise GPIO settings
+-  * [Config] highbank -- commonise I2C settings
+-  * [Config] highbank -- commonise numerous subsystem selectors
+-  * [Config] highbank -- commonise A-C modules missmatches
+-  * [Config] highbank -- commonise D-F modules missmatches
+-  * [Config] CONFIG_AUDIT_LOGINUID_IMMUTABLE incompatible with upstart
+-  * [Config] highbank -- commonise G-I modules missmatches
+-  * [Config] highbank -- commonise J-L modules missmatches
+-  * [Config] highbank -- commonise M modules missmatches
+-  * [Config] highbank -- commonise N-P modules missmatches
+-  * [Config] highbank -- commonise Q-R modules missmatches
+-  * [Config] highbank -- commonise S modules missmatches -- part 1
+-  * [Config] highbank -- commonise S modules missmatches -- part 2
+-  * [Config] highbank -- commonise T modules missmatches
+-  * [Config] highbank -- commonise U-Z modules missmatches
+-
+-  [ Ike Panhc ]
+-
+-  * [Config] add highbank flavour
+-    - LP: #1000831
+-
+-  [ Mark Langsdorf ]
+-
+-  * SAUCE: arm highbank: add support for pl320-ipc driver
+-    - LP: #1000831
+-
+-  [ Rob Herring ]
+-
+-  * SAUCE: input: add a key driver for highbank
+-    - LP: #1000831
+-  * SAUCE: ARM: highbank: Add smc calls to enable/disable the L2
+-    - LP: #1000831
+-  * SAUCE: force DMA buffers to non-bufferable on highbank
+-    - LP: #1000831
+-  * SAUCE: net: calxedaxgmac: fix net timeout recovery
+-    - LP: #1000831
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_IWLWIFI_EXPERIMENTAL_MFP=n
+-  * [Config] CONFIG_PCI_REALLOC_ENABLE_AUTO=y
+-  * [Config] CONFIG_CIFS_EXPERIMENTAL has disappeared
+-  * [Config] Homogenize CIFS configs across all arches
+-  * [Config] armhf should not be skipabi or skipmodules
+-    - LP: #1006913
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 04 Jun 2012 05:52:49 -0700
+-
+-linux (3.4.0-3.8) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] include include/generated/compile.h
+-    - LP: #942569
+-  * [Config] fix up postinst to ensure we know which error is which
+-    - LP: #1002388
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: async_populate_rootfs: fix build warnings
+-    - LP: #1003417
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: AppArmor: Add the ability to mediate mount"
+-  * SAUCE: apparmor: Add the ability to mediate mount
+-  * SAUCE: AppArmor: basic networking rules
+-  * SAUCE: apparmor: fix profile lookup for unconfined
+-    - LP: #978038, #987371
+-  * SAUCE: apparmor: fix long path failure due to disconnected path
+-    - LP: #955892
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: dell-laptop: rfkill blacklist Dell XPS 13z, 15
+-    - LP: #901410
+-
+-  [ Stefan Bader ]
+-
+-  * (config) Built-in xen-acpi-processor
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NET_DSA=m
+-    - LP: #1004148
+-  * [Config] Ensure CONFIG_XEN_ACPI_PROCESSOR=y for amd64
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 25 May 2012 11:38:33 -0700
+-
+-linux (3.4.0-3.7) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] drop the virtual flavour in favour of a split generic et al
+-  * [Config] enforcer -- drop IDLE enforcement
+-  * [Config] enable CONFIG_SCSI_VIRTIO=m for amd64
+-  * [Config] updateconfigs following removal of -virtual
+-
+-  [ Leann Ogasawara ]
+-
+-  * Rebase to v3.4
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] disable CONFIG_B43_BCMA_EXTRA
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Check for extras when building udebs
+-  * [Config] Collapsed generic-pae into generic [i386]
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 May 2012 07:23:47 -0700
+-
+-linux (3.4.0-2.6) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: overlayfs -- overlayfs: update touch_atime() usage"
+-  * Revert "ubuntu: overlayfs -- overlayfs: switch from d_alloc_root() to
+-    d_make_root()"
+-  * Revert "ubuntu: overlayfs -- overlayfs: follow header cleanup"
+-  * Revert "ubuntu: overlayfs -- overlayfs: apply device cgroup and
+-    security permissions to overlay files"
+-  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- vfs: introduce clone_private_mount()"
+-  * Revert "ubuntu: overlayfs -- vfs: export do_splice_direct() to modules"
+-  * Revert "ubuntu: overlayfs -- vfs: add i_op->open()"
+-  * Revert "ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()"
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- inode_only_permission: export inode level
+-    permissions checks
+-  * ubuntu: overlayfs -- overlayfs: switch to use inode_only_permissions
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Robin Dong ]
+-
+-  * ubuntu: overlayfs -- overlayfs: fix possible leak in ovl_new_inode
+-  * ubuntu: overlayfs -- overlayfs: create new inode in ovl_link
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] perarch and indep tools builds need separate build directories
+-  * Prevent upgrading a non-PAE CPU
+-  * perf is not parallel build safe
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 May 2012 08:43:18 -0700
+-
+-linux (3.4.0-2.5) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] perarch and indep tools builds need separate build directories
+-
+-  [ Tim Gardner ]
+-
+-  * Prevent upgrading a non-PAE CPU
+-  * [Config] build debug
+-  * [Config] perf tools are not parallel build safe
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 15 May 2012 11:37:53 -0700
+-
+-linux (3.4.0-2.4) quantal; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: fsam7400: use UMH_WAIT_PROC consistently"
+-  * Revert "ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86"
+-  * Revert "ubuntu: fsam7400: Depend on CHECK_SIGNATURE"
+-  * Revert "ubuntu: fsam7400 -- Cleanup Makefile"
+-  * Revert "ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M
+-    7400"
+-  * Revert "ubuntu: omnibook: fix source file newline"
+-  * Revert "ubuntu: omnibook -- update BOM"
+-  * Revert "SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5}
+-    depend on X86"
+-  * Revert "ubuntu: omnibook -- Added missing BOM file"
+-  * Revert "ubuntu: omnibook -- support Toshiba (HP) netbooks"
+-  * Revert "ubuntu: nx-emu - i386: mmap randomization for executable
+-    mappings"
+-  * Revert "SAUCE: disable_nx should not be in __cpuinitdata section for
+-    X86_32"
+-  * Revert "ubuntu: nx-emu - i386: NX emulation"
+-  * Revert "ubuntu: rfkill drivers -- version 1.3"
+-  * Temporarily disable module check
+-  * [Config] Remove CONFIG_FSAM7400
+-  * [Config] Remove CONFIG_OMNIBOOK
+-  * [Config] Update configs
+-  * Rebase to v3.4-rc7
+-  * SAUCE: genirq: export handle_edge_irq() and irq_to_desc()
+-
+-  [ Tim Gardner ]
+-
+-  * Updated generic-pae description
+-  * Rebase to v3.4-rc6
+-  * install-tools depends on build targets
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * kconfig: in debug mode some 0 length message prints occur
+-  * rebase to v3.4-rc7
+-  * rebase to v3.3-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 14 May 2012 08:22:56 -0700
+-
+-linux (3.4.0-1.3) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] control.stub is an intermediate product not a dependancy
+-    - LP: #992414
+-
+-  [ Leann Ogasawara ]
+-
+-  * remove i386 generic from getabis
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) b43: only reload config after successful initialization
+-    - LP: #950295
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 May 2012 09:48:14 -0700
+-
+-linux (3.4.0-1.2) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] add build depends for flex, bison and pkg-config
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 01 May 2012 13:15:41 +0100
+-
+-linux (3.4.0-1.1) quantal; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
+-    permissions to overlay files
+-    - LP: #915941, #918212
+-    - CVE-2012-0055
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open Q
+-  * Rebase to v3.4-rc5
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EETI on arm
+-  * [Config] Temporarily disable CONFIG_TOUCHSCREEN_EGALAX on arm
+-  * [Config] Temporarily disable CONFIG_EZX_PCAP on arm
+-  * [Config] Temporarily disable CONFIG_MFD_OMAP_USB_HOST on arm
+-  * [Config] Temporarily disable CONFIG_LIS3L02DQ on arm
+-  * [Config] Temporarily disable CONFIG_USB_EHCI_HCD_PLATFORM on arm
+-  * [Config] Temporarily disable CONFIG_TI_CPSW on arm
+-  * [Config] Temporarily disable CONFIG_AX88796 on arm
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * vfs: pass struct path to __dentry_open()
+-  * vfs: add i_op->open()
+-  * vfs: export do_splice_direct() to modules
+-  * vfs: introduce clone_private_mount()
+-  * overlay filesystem
+-  * overlayfs: add statfs support
+-  * overlayfs: implement show_options
+-  * overlay: overlay filesystem documentation
+-  * fs: limit filesystem stacking depth
+-  * overlayfs: follow header cleanup
+-  * overlayfs: switch from d_alloc_root() to d_make_root()
+-  * overlayfs: update touch_atime() usage
+-  * rebase to v3.4-rc5
+-    - LP: #950490
+-  * rebase to v3.4-rc4
+-  * rebase to v3.4-rc3
+-  * rebase to v3.4-rc2
+-  * rebase to v3.4-rc1
+-  * rebase to v3.3
+-  * rebase to v3.3-rc7
+-  * rebase to v3.3-rc6
+-  * rebase to v3.3-rc5
+-  * rebase to v3.3-rc4
+-    - LP: #900802
+-    - LP: #930842
+-  * rebase to v3.3-rc3
+-    - LP: #924320
+-    - LP: #923316
+-    - LP: #923409
+-    - LP: #918254
+-  * rebase to v3.3-rc2
+-  * rebase to v3.3-rc1
+-    - LP: #795823
+-    - LP: #909419
+-    - LP: #910792
+-    - LP: #878701
+-    - LP: #724831
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 25 Jan 2012 06:50:04 -0800
+-
+-linux (3.2.0-10.18) precise; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: ecryptfs: Print inode on metadata error
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "proc: enable writing to /proc/pid/mem"
+-    - LP: #919115
+-    - CVE-2012-0056
+-  * (pre-stable) ALSA: HDA: Use LPIB position fix for Macbook Pro 7, 1
+-    - LP: #909419
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 24 Jan 2012 10:15:12 +0000
+-
+-linux (3.2.0-10.17) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "SAUCE: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "SAUCE: overlayfs -- overlayfs: implement show_options"
+-  * Revert "SAUCE: overlayfs -- overlayfs: add statfs support"
+-  * Revert "SAUCE: overlayfs -- overlay filesystem"
+-  * Revert "SAUCE: overlayfs -- vfs: introduce clone_private_mount()"
+-  * Revert "SAUCE: overlayfs -- vfs: export do_splice_direct() to modules"
+-  * Revert "SAUCE: overlayfs -- vfs: add i_op->open()"
+-  * ensure debian/ is not excluded from git by default
+-  * add new scripting to handle buglinks in rebases
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * ubuntu: overlayfs -- overlayfs: apply device cgroup and security
+-    permissions to overlay files
+-    - LP: #915941, #918212
+-    - CVE-2012-0055
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: dmar: disable if ricoh multifunction detected"
+-  * [Config] Disable CONFIG_INTEL_IOMMU_DEFAULT_ON
+-    - LP: #907377, #911236
+-  * [Config] Enable CONFIG_IRQ_REMAP
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: pass struct path to __dentry_open()
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) x86/PCI: amd: factor out MMCONFIG discovery
+-    - LP: #647043
+-  * (pre-stable) PNP: work around Dell 1536/1546 BIOS MMCONFIG bug that
+-    breaks USB
+-    - LP: #647043
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 Jan 2012 07:10:08 -0800
+-
+-linux (3.2.0-9.16) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] Enable numerous CONFIG_VIDEO_* cards on ARM
+-  * [Config] pull ARM sound modules =m
+-  * [Config] CONFIG_RTC_DRV_TEST is for testing only
+-  * [Config] CONFIG_USB_DUMMY_HCD is testing only
+-  * [Config] CONFIG_USB_FILE_STORAGE is deprecated
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_CAN_TI_HECC on armel"
+-  * [Config] Enable CONFIG_HW_RANDOM_PASEMI=m
+-  * [Config] Enable CONFIG_MMC_TMIO=m
+-  * [Config] Enable CONFIG_MTD_NAND_FSL_ELBC=m
+-  * [Config] Enable CONFIG_ISI=m
+-  * [Config] Enable CONFIG_MMC=y
+-  * [Config] Enable CONFIG_LIRC_PARALLEL=m
+-  * [Config] Enable CONFIG_MAC_EMUMOUSEBTN=m
+-  * [Config] Enable CONFIG_CHR_DEV_SG=y
+-  * [Config] Enable CONFIG_GPIO_PCA953X=m
+-  * [Config] Enable CONFIG_GPIO_TWL4030=m
+-  * [Config] Enable CONFIG_INET_DIAG=m
+-  * [Config] Enable CONFIG_NLS_ISO8859_1=m
+-  * [Config] Enable CONFIG_NVRAM=m
+-  * [Config] Enable CONFIG_SLIP=m
+-  * [Config] Enable CONFIG_PC300TOO=m
+-  * [Config] Enable CONFIG_TUN=y
+-  * [Config] Enable CONFIG_NET_CLS_CGROUP=m
+-  * [Config] Enable CONFIG_THERMAL=y
+-  * [Config] Enable CONFIG_PPP=y
+-  * [Config] Enable CONFIG_PCI_STUB=m
+-  * Rebase to v3.2.1
+-  * [Config] Enable CONFIG_RTL8192E=m
+-  * [Config] Enable CONFIG_RTS5139=m
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Make CONFIG_VIRTIO_(NET|BLK)=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ARM: restart: add restart hook to machine_desc record
+-  * ARM: restart: allow platforms more flexibility specifying restart mode
+-  * ARM: restart: move reboot failure handing into machine_restart()
+-  * ARM: restart: remove argument to setup_mm_for_reboot()
+-  * ARM: 7159/1: OMAP: Introduce local common.h files
+-  * ARM: restart: only perform setup for restart when soft-restarting
+-  * ARM: 7189/1: OMAP3: Fix build break in cpuidle34xx.c because of irq
+-    function
+-  * ARM: idmap: populate identity map pgd at init time using .init.text
+-  * ARM: suspend: use idmap_pgd instead of suspend_pgd
+-  * ARM: proc-*.S: place cpu_reset functions into .idmap.text section
+-  * ARM: idmap: use idmap_pgd when setting up mm for reboot
+-  * ARM: head.S: only include __turn_mmu_on in the initial identity mapping
+-  * ARM: SMP: use idmap_pgd for mapping MMU enable during secondary booting
+-  * ARM: 7194/1: OMAP: Fix build after a merge between v3.2-rc4 and ARM
+-    restart changes
+-  * ARM: lib: add call_with_stack function for safely changing stack
+-  * ARM: reset: implement soft_restart for jumping to a physical address
+-  * ARM: stop: execute platform callback from cpu_stop code
+-  * ARM: kexec: use soft_restart for branching to the reboot buffer
+-  * ARM: restart: omap: use new restart hook
+-  * topdown mmap support
+-    - LP: #861296
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to v3.2.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 13 Jan 2012 20:32:08 +0100
+-
+-linux (3.2.0-8.15) precise; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_ACPI_PROCFS
+-  * Remove server from getabis
+-  * Temporarily disable module check
+-  * [Config] Disable CONFIG_MTD_TESTS
+-  * [Config] Disable CONFIG_X86_E_POWERSAVER
+-  * [Config] Set CONFIG_ARCNET=m
+-  * [Config] Enable CONFIG_ATM_DUMMY=m
+-  * [Config] Enable CONFIG_BLK_DEV_MD=y
+-  * ubuntu: fsam7400 select CHECK_SIGNATURE and depend on X86
+-  * [Config] Enable CONFIG_BLK_DEV_SD=y
+-  * [Config] Enable CONFIG_BLK_DEV_SR=y
+-  * [Config] Enable CONFIG_BLK_DEV_UB=m
+-  * [Config] Enable CONFIG_COPS=m
+-  * [Config] Enable CONFIG_DVB_USB_EC168=m
+-  * [Config] Enable CONFIG_ENC28J60=m
+-  * [Config] Enable CONFIG_FB_UVESA=m
+-  * [Config] Enable CONFIG_FB_ATY=m
+-  * [Config] Enable CONFIG_BROADCOM_PHY=y
+-  * [Config] Enable CONFIG_CICADA_PHY=y
+-  * [Config] Enable CONFIG_DAVICOM_PHY=y
+-  * [Config] Enable CONFIG_ICPLUS_PHY=y
+-  * [Config] Enable CONFIG_LSI_ET1011C_PHY=y
+-  * [Config] Enable CONFIG_LXT_PHY=y
+-  * [Config] Enable CONFIG_MARVELL_PHY=y
+-  * [Config] Enable CONFIG_NATIONAL_PHY=y
+-  * [Config] Enable CONFIG_QSEMI_PHY=y
+-  * [Config] Enable CONFIG_SMSC_PHY=y
+-  * [Config] Enable CONFIG_VITESSE_PHY=y
+-  * Add 3w-sas to scsi-modules
+-    - LP: #776542
+-
+-  [ Mathieu Trudel-Lapierre ]
+-
+-  * SAUCE: ipv6: make the net.ipv6.conf.all.use_tempaddr sysctl propagate
+-    to interface settings
+-
+-  [ Paolo Pisati ]
+-
+-  * Revert "SAUCE: omap3: beagle: if rev unknown, assume xM revision C"
+-    - LP: #912199
+-  * Revert "SAUCE: omap3: beagle: detect new xM revision B"
+-    - LP: #912199
+-  * Revert "SAUCE: omap3: beaglexm: fix DVI initialization"
+-    - LP: #912199
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Bluetooth: Add support for BCM20702A0 [0a5c:21e3]
+-    - LP: #906832
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 06 Jan 2012 10:02:03 -0800
+-
+-linux (3.2.0-8.14) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_SND_USB_6FIRE
+-    - LP: #912197
+-  * rebase to mainline v3.2 final release
+-  * updateconfigs following rebase to v3.2 final
+-  * ubuntu: AUFS -- add BOM and automated update script
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-  * ubuntu: AUFS -- update aufs-update to track new locations of headers
+-  * ubuntu: AUFS -- clean up the aufs updater and BOM
+-  * ubuntu: AUFS -- documentation on updating aufs2
+-  * ubuntu: AUFS -- aufs3-base.patch
+-  * ubuntu: AUFS -- aufs3-standalone.patch
+-  * ubuntu: AUFS -- fix undefined __devcgroup_inode_permission
+-  * ubuntu: AUFS -- fix undefined security_path_link
+-  * ubuntu: AUFS -- update to 4cf5db36bcd9748e8e7270022f295f84d1fc2245
+-  * ubuntu: AUFS -- updateconfigs following update
+-  * ubuntu: AUFS -- suppress benign plink warning messages
+-    - LP: #621195
+-  * ubuntu: AUFS -- enable in config and makefile
+-  * ubuntu: AUFS -- disable in favor of overlayfs
+-  * [Config] linux-virtual -- should include the extX modules
+-    - LP: #912308
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: eCryptfs: Improve statfs reporting
+-    - LP: #885744
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream v3.2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 26 Dec 2011 20:24:30 -0800
+-
+-linux (3.2.0-7.13) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream 3.2-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 19 Dec 2011 09:14:34 -0800
+-
+-linux (3.2.0-6.12) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream v3.2-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Dec 2011 10:19:02 -0800
+-
+-linux (3.2.0-5.11) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * enforcer -- allow arch and flavour predicates to take lists
+-  * enforcer -- simplify armel/armhf specific options
+-  * enforcer -- fix incorrectly specified flavour matches
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable IRQ_REMAP
+-  * [Config] Enable CONFIG_SENSORS_LM95245=m
+-  * [Config] Enable CONFIG_SENSORS_MAX1668=m
+-  * [Config] Enable CONFIG_SENSORS_NTC_THERMISTOR=m
+-  * [Config] Enable CONFIG_SENSORS_MAX6639=m
+-  * [Config] Enable CONFIG_SENSORS_MAX6642=m
+-  * [Config] Enable CONFIG_SENSORS_LINEAGE=m
+-  * [Config] Enable CONFIG_CRYPTO_SALSA20=m
+-  * [Config] Enable CONFIG_PATA_TOSHIBA=m
+-  * [Config] Enable CONFIG_POHMELFS=m
+-  * [Config] Enable CONFIG_NET_PACKET_ENGINE=y
+-  * [Config] Enable CONFIG_PATA_OPTI=m
+-  * add overlayfs to virtual inclusion list
+-    - LP: #903897
+-  * add veth to virtual inclusion list
+-    - LP: #903897
+-  * SAUCE: resolve WARNING: at drivers/block/floppy.c:2929 do_fd_request
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] DEFAULT_MMAP_MIN_ADDR=32k on arm
+-    - LP: #903346
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_LOCKUP_DETECTOR=y
+-    - LP: #903615
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to upstream 55b02d2f
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 12 Dec 2011 07:08:10 -0800
+-
+-linux (3.2.0-4.10) precise; urgency=low
+-
+-  [ Kyle McMartin ]
+-
+-  * SAUCE: dmar: disable if ricoh multifunction detected
+-    - LP: #894070
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: dell-wmi: Demote unknown WMI event message to pr_debug
+-    - LP: #581312
+-
+-  [ Tim Gardner ]
+-
+-  * Start new release, Bump ABI, rebase to 3.2-rc5
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_SENSORS_AK8975=m
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 10 Dec 2011 08:57:04 -0700
+-
+-linux (3.2.0-3.9) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: ext4: correct partial write discard size calculation
+-    - LP: #894768
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: x86, microcode, AMD: Restrict microcode reporting"
+-    - LP: #892615
+-
+-  [ Matthew Garrett ]
+-
+-  * SAUCE: pci: Rework ASPM disable code
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86: Fix boot failures on older AMD CPU's
+-    - LP: #892615
+-  * EHCI : Fix a regression in the ISO scheduler
+-    - LP: #899165
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 05 Dec 2011 10:37:36 -0800
+-
+-linux (3.2.0-3.8) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- add d-i configuration
+-  * armhf -- disable ABI checks for armhf
+-  * armhf -- add arch to getabis config
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 03 Dec 2011 14:22:52 +0000
+-
+-linux (3.2.0-3.7) precise; urgency=low
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: x86/paravirt: PTE updates in k(un)map_atomic need to be
+-    synchronous, regardless of lazy_mmu mode
+-    - LP: #854050
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to v3.2-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 02 Dec 2011 11:53:56 -0800
+-
+-linux (3.2.0-2.6) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- fix omap flavour to build on armhf
+-  * [Config] CONFIG_PATA_MACIO=y to fix MAC qemu boot
+-
+-  [ Borislav Petkov ]
+-
+-  * SAUCE: x86, microcode, AMD: Restrict microcode reporting
+-    - LP: #892615
+-
+-  [ Colin Watson ]
+-
+-  * Add pata_macio to pata-modules
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Prefer crda over wireless-crda
+-  * [Config] Fix virtual inclusion list.
+-    - LP: #897795
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 30 Nov 2011 06:09:35 -0800
+-
+-linux (3.2.0-2.5) precise; urgency=low
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] PANEL_DVI=y
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Nov 2011 09:13:24 -0800
+-
+-linux (3.2.0-2.4) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v3.2-rc3
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: xen: Do not use pv spinlocks on HVM"
+-  * Revert "fix ERROR: __devcgroup_inode_permission undefined"
+-  * Revert "olpc_dcon_xo_1_5 needs delay.h"
+-  * Revert "olpc_dcon_xo_1 needs delay.h"
+-  * rebase to 6fe4c6d4
+-  * [Config] updateconfigs after rebase to 6fe4c6d4
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Replace wireless-crda with crda,wireless-regdb
+-    - LP: #856421
+-  * [Config] Relax the dependencies on crda
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) HID: bump maximum global item tag report size to 96 bytes
+-    - LP: #724831
+-  * Ubuntu: remove coreutils|fileutils package dependency
+-    - LP: #892814
+-  * iio: iio_event_getfd -- fix ev_int build failure
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to v3.2-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 24 Nov 2011 16:20:45 +0000
+-
+-linux (3.2.0-1.3) precise; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Ubuntu: Add ext2 to fs-core-modules
+-    - LP: #893395
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 20:42:33 -0800
+-
+-linux (3.2.0-1.2) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_NFC and associated devices
+-  * SAUCE: allow brcmsmac and b43 to both build
+-
+-  [ Soren Hansen ]
+-
+-  * Add ixgbe driver to d-i
+-    - LP: #891969
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 21 Nov 2011 08:33:46 -0800
+-
+-linux (3.2.0-1.1) precise; urgency=low
+-  [ Andy Whitcroft ]
+-
+-  * armhf -- enable armhf and create the first flavours
+-  * SAUCE: ensure root is ready before running usermodehelpers in it
+-  * [Config] enforcer -- ensure CONFIG_FAT_FS is built-in on arm
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temporarily ignore module check
+-  * [Config] Enable PCI_IOV on powerpc
+-  * [Config] Temporarily disable CONFIG_PASEMI_MAC on powerpc
+-  * rebase to v3.2-rc2
+-  * SAUCE: include <linux/export.h> for cpuidle34xx arm build
+-  * SAUCE: include <linux/kernel.h> for linux/mtd/map.h arm build
+-  * SAUCE: include <linux/printk.h> and <stdarg.h> for mmc_core arm build
+-  * SAUCE: select ARM_AMBA if OMAP3_EMU
+-  * [Config] updateconfigs after select ARM_AMBA
+-  * [Config] Temporarily disable CONFIG_KVM_BOOK3S_32 on powerpc
+-  * [Config] Enable CONFIG_EXT2_FS=m
+-  * [Config] Build in CONFIG_SATA_AHCI=y
+-  * Resolve linux-image-extra's install dependency
+-
+-  [ Seth Forshee ]
+-
+-  * [Config] Enable EVENT_POWER_TRACING_DEPRECATED=y for powertop
+-  * SAUCE: (drop after 3.2) Input: ALPS - move protocol information to
+-    Documentation
+-  * SAUCE: (drop after 3.2) Input: ALPS - add protocol version field in
+-    alps_model_info
+-  * SAUCE: (drop after 3.2) Input: ALPS - remove assumptions about packet
+-    size
+-  * SAUCE: (drop after 3.2) Input: ALPS - add support for protocol versions
+-    3 and 4
+-  * SAUCE: (drop after 3.2) Input: ALPS - add semi-MT support for v3
+-    protocol
+-  * SAUCE: (drop after 3.2) Input: ALPS - add documentation for protocol
+-    versions 3 and 4
+-
+-  [ Stefan Bader ]
+-
+-  * [Config] Built-in xen-netfront and xen-blkfront
+-  * Fix build of dm-raid45 and re-enable it
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_USB_XHCI_HCD=y
+-    - LP: #886167
+-  * [Config] CONFIG_R6040=m
+-    - LP: #650899
+-  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
+-    - LP: #854399
+-  * [Config] Consolidated amd64 server flavour into generic
+-  * [Config] updateconfigs after rebase to 3.2-rc1
+-  * [Config] Disabled dm-raid4-5
+-  * [Config] Disabled ndiswrapper
+-  * [Config] Disable vt6656
+-  * [Config] exclude ppp-modules for virtual flavour
+-  * [Config] CONFIG_MEMSTICK_R592=m
+-    - LP: #238208
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * CHROMIUM: seccomp_filter: new mode with configurable syscall filters
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filter: add process state reporting
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filter: Document what seccomp_filter is and how it
+-    works.
+-    - LP: #887780
+-  * CHROMIUM: x86: add HAVE_SECCOMP_FILTER and seccomp_execve
+-    - LP: #887780
+-  * CHROMIUM: arm: select HAVE_SECCOMP_FILTER
+-    - LP: #887780
+-  * CHROMIUM: seccomp_filters: move to btrees
+-  * CHROMIUM: enable CONFIG_BTREE
+-  * CHROMIUM: seccomp_filter: kill NR_syscall references
+-  * CHROMIUM: seccomp_filters: guard all ftrace wrapper code
+-  * CHROMIUM: seccomp_filters: clean up warnings; kref mistake
+-  * CHROMIUM: seccomp_filter: remove "skip" from copy and add drop helper
+-  * CHROMIUM: seccomp_filter: allow CAP_SYS_ADMIN management of execve
+-  * CHROMIUM: seccomp_filter: inheritance documentation
+-  * CHROMIUM: seccomp_filter: make inherited filters composable
+-  * CHROMIUM: Fix seccomp_t compile error
+-    - LP: #887780
+-  * CHROMIUM: Fix kref usage
+-    - LP: #887780
+-  * CHROMIUM: enable CONFIG_SECCOMP_FILTER and CONFIG_HAVE_SECCOMP_FILTER
+-  * rebase to v3.2-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 31 Oct 2011 09:24:39 -0400
+-
+-linux (3.1.0-2.3) precise; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * Add postinit and postrm scripts to the extras package
+-    - LP: #882120
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 Oct 2011 12:48:33 -0700
+-
+-linux (3.1.0-2.2) precise; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian: add locking to protect debian/files from parallel update
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.1
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 19 Oct 2011 07:12:38 -0700
+-
+-linux (3.1.0-1.1) precise; urgency=low
+-
+-  [ Andiry Xu ]
+-
+-  * SAUCE: (drop during 3.2 merge) xHCI: AMD isoc link TRB chain bit quirk
+-    - LP: #872811
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: compcache -- follow changes to bd_claim/bd_release"
+-    - LP: #832694
+-  * Revert "ubuntu: compcache -- version 0.5.3"
+-    - LP: #832694
+-  * [Config] standardise CONFIG_NETFILTER_XT_TARGET_TCPOPTSTRIP=m
+-  * [Config] Enable CONFIG_MACVTAP=m
+-    - LP: #822601
+-  * record the compiler in the ABI and check for inconsistant builds
+-  * [Config] move ECRYPT_FS back to =y for all architectures
+-    - LP: #827197
+-  * [Config] enable CONFIG_DRM_VMWGFX=m
+-    - LP: #698009
+-  * [Config] re-fix ECRYPT_FS=y
+-    - LP: #827197
+-  * enforcer -- ensure we have CONFIG_ECRYPT_FS=y
+-    - LP: #827197
+-  * [Config] dropping compcache configuration options
+-  * [Config] standardise on HZ=250
+-  * SAUCE: headers_install: fix #include "..." usage for userspace
+-    - LP: #824377
+-  * make module-inclusion selection retain the left overs
+-  * add a new linux-image-extras package for virtual
+-
+-  [ Colin Watson ]
+-
+-  * Deliver more Atheros, Ralink, and iwlagn NIC drivers to d-i
+-
+-  [ edwin_rong ]
+-
+-  * SAUCE: Staging: add driver for Realtek RTS5139 cardreader
+-    - LP: #824273
+-
+-  [ Greg Kroah-Hartman ]
+-
+-  * SAUCE: staging: rts5139: add vmalloc.h to some files to fix the build.
+-    - LP: #824273
+-
+-  [ Jesse Sung ]
+-
+-  * SAUCE: Unregister input device only if it is registered
+-    - LP: #839238
+-
+-  [ Jiri Kosina ]
+-
+-  * SAUCE: HID: add MacBookAir4, 2 to hid_have_special_driver[]
+-
+-  [ Joshua V. Dillon ]
+-
+-  * SAUCE: HID: add support for MacBookAir4,2 keyboard.
+-
+-  [ Kees Cook ]
+-
+-  * [Config] enable and enforce SECCOMP_FILTER on x86
+-
+-  [ Keng-Yu Lin ]
+-
+-  * [Config] Enable CONFIG_RTS5139=m on i386/amd64
+-    - LP: #824273
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "ubuntu: overlayfs -- ovl: make lower mount read-only"
+-  * Revert "ubuntu: overlayfs -- fs: limit filesystem stacking depth"
+-  * Revert "ubuntu: overlayfs -- ovl: improve stack use of lookup and
+-    readdir"
+-  * Revert "ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs"
+-  * Revert "ubuntu: overlayfs -- overlayfs: implement show_options"
+-  * Revert "ubuntu: overlayfs -- overlayfs: add statfs support"
+-  * Revert "ubuntu: overlayfs -- overlay filesystem"
+-  * Revert "ubuntu: overlayfs -- overlay: overlay filesystem documentation"
+-  * Revert "SAUCE: ARM: OMAP: Add macros for comparing silicon revision"
+-  * Revert "SAUCE: OMAP: DSS2: check for both cpu type and revision, rather
+-    than just revision"
+-  * Revert "SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX"
+-  * Revert "ubuntu: fsam7400 disable driver"
+-    - LP: #876030
+-  * rebase to v3.1-rc1
+-  * [Config] updateconfigs after rebase to v3.1-rc1
+-  * rebase to v3.1-rc2
+-  * [Config] Updateconfigs after rebase to v3.1-rc2
+-  * ubuntu: Yama - update calls to generic_permission() and
+-    inode->i_op->permission()
+-  * ubuntu: ndiswrapper -- remove netdev_priv macro
+-  * ubuntu: aufs -- Temporarily disable due to build failure
+-  * [Config] Diable INTEL_MID_PTI on armel
+-  * [Config] Temporarily disable CONFIG_FTMAC100 on armel
+-  * [Config] Temporarily disable CONFIG_FTGMAC100 on armel
+-  * [Config] Temporarily disable CONFIG_CAN_TI_HECC on armel
+-  * [Config] Temporarily disable CONFIG_VIDEO_OMAP2_VOUT on armel
+-  * [Config] Set CONFIG_DM_MIRROR=m on amd64, i386, and arm
+-  * [Config] Set CONFIG_DM_MULTIPATH=m on amd64, i386, and arm
+-  * [Config] Set CONFIG_DM_SNAPSHOT=m on amd64, i386, and arm
+-  * [Config] Enable CONFIG_EDAC_AMD8111=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_AMD8131=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_CPC925=m on powerpc
+-  * [Config] Enable CONFIG_EDAC_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_ECHO=m on powerpc
+-  * [Config] Enable CONFIG_ET131X=m on powerpc
+-  * [Config] Set CONFIG_FB_MATROX=m
+-  * [Config] Enable CONFIG_FB_UDL=m on powerpc
+-  * [Config] Set CONFIG_FB_VIRTUAL=n
+-  * [Config] Enable CONFIG_FB_VGA16=m on powerpc
+-  * [Config] Enable CONFIG_GPIO_MAX732X=m on arm
+-  * [Config] Enable CONFIG_GPIO_PCF857X=m on arm
+-  * [Config] Set CONFIG_HOTPLUG_PCI_FAKE=m
+-  * [Config] Enable CONFIG_HOTPLUG_PCI=y on powerpc
+-  * [Config] Enable CONFIG_HOTPLUG_PCI_CPCI=y on powerpc
+-  * [Config] Enable CONFIG_HP_ILO=m on powerpc-smp
+-  * [Config] Enable CONFIG_I2C_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_IBM_BSR=m on powerpc
+-  * [Config] Enable CONFIG_IBMVETH=m on powerpc
+-  * [Config] Enable CONFIG_IDE_PHISON=m on powerpc
+-  * [Config] Enable CONFIG_IGB=m on powerpc
+-  * [Config] Enable CONFIG_IIO=m on powerpc
+-  * [Config] Enable CONFIG_INFINIBAND_NES=m
+-  * [Config] Enable CONFIG_IPMI_HANDLER=m on arm
+-  * [Config] Enable CONFIG_IWL3945=m on powerpc
+-  * [Config] Disable CONFIG_KVM_BOOK3S_64
+-  * [Config] Enable CONFIG_LAPBETHER=m on arm
+-  * [Config] Enable CONFIG_LEDS_GPIO=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_CLEVO_MAIL=m all arch's
+-  * [Config] Enable CONFIG_LEDS_PCA9532=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_PCA955X=m on powerpc
+-  * [Config] Enable CONFIG_LEDS_TRIGGER_DEFAULT_ON=m on powerpc
+-  * [Config] Set CONFIG_LEDS_TRIGGER_HEARTBEAT=m on arm and powerpc
+-  * [Config] Set CONFIG_LEDS_TRIGGER_TIMER=m on powerpc
+-  * [Config] Enable CONFIG_LINE6_USB=m on arm and powerpc
+-  * [Config] Enable CONFIG_MEMSTICK=m on arm
+-  * [Config] Enable CONFIG_MTD_AFS_PARTS=m on arm
+-  * [Config] Enable CONFIG_MTD_ALAUDA=m on arm
+-  * [Config] Enable CONFIG_MTD_AR7_PARTS=m on arm
+-  * [Config] Enable CONFIG_MTD_ARM_INTEGRATOR=m on arm
+-  * [Config] Enable CONFIG_MOXA_SMARTIO=m on powerpc
+-  * [Config] Enable CONFIG_MTD_DATAFLASH=m on arm
+-  * [Config] Enable CONFIG_MTD_GPIO_ADDR=m on arm
+-  * [Config] Enable CONFIG_MTD_IMPA7=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_GPIO=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_NANDSIM=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_PASEMI=m on powerpc
+-  * [Config] Enable CONFIG_MTD_NAND_PLATFORM=m on arm
+-  * [Config] Enable CONFIG_MTD_NAND_TMIO=m on arm
+-  * [Config] Enable CONFIG_MTD_SST25L=m on arm
+-  * [Config] Enable CONFIG_NET_CLS_CGROUP=y on arm
+-  * [Config] Enable CONFIG_NET_CLS_FLOW=m on arm
+-  * [Config] Enable CONFIG_NET_CLS_U32=m on arm
+-  * [Config] Enable CONFIG_NET_DCCPPROBE=m on arm
+-  * [Config] Enable CONFIG_NET_SCH_INGRESS=m on arm
+-  * [Config] Enable CONFIG_NET_TCPPROBE=m on arm
+-  * [Config] Enable CONFIG_PASEMI_MAC=m on powerpc
+-  * [Config] Enable CONFIG_PATA_NS87410=m on powerpc
+-  * [Config] Enable CONFIG_I2C_GPIO=m on powerpc64-smp
+-  * [Config] Enable CONFIG_PANEL=m on powerpc
+-  * [Config] Enable CONFIG_PATA_CMD640_PCI=m on powerpc
+-  * SAUCE: x86: reboot: Make Dell Latitude E6520 use reboot=pci
+-    - LP: #833705
+-  * [Config] Add CONFIG_EFI_VARS=y to the enforcer
+-    - LP: #837332
+-  * [Config] Update CONFIG_EFI_VARS enforcer check
+-  * [Config] Add aufs to virtual flavor inclusion list
+-    - LP: #844159
+-  * SAUCE: x86: reboot: Make Dell Optiplex 790 use reboot=pci
+-    - LP: #818933
+-  * SAUCE: x86: reboot: Make Dell Optiplex 990 use reboot=pci
+-    - LP: #768039
+-  * SAUCE: x86: reboot: Make Dell Latitude E6220 use reboot=pci
+-    - LP: #838402
+-  * [Config] Add igbvf to the virtual flavor inclusion list
+-    - LP: #794570
+-  * [Config] Add ixgbevf to the virtual inclusion list
+-    - LP: #872411
+-  * [Config] Transition -generic and -server to be identical
+-  * rebase to v3.1-rc10
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Disable legacy IDE drivers on powerpc
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: fireware: add NO_MSI quirks for o2micro controller
+-    - LP: #801719
+-  * SAUCE: ata_piix: make DVD Drive recognisable on systems with Intel
+-    Sandybridge chipsets(v2)
+-    - LP: #737388, #782389, #794642
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] Compile-in vfat support for armel
+-    - LP: #853783
+-
+-  [ Randy Dunlap ]
+-
+-  * SAUCE: staging: fix rts5139 depends & build
+-    - LP: #824273
+-
+-  [ Rene Bolldorf ]
+-
+-  * SAUCE: (drop after 3.0) ideapad: Check if acpi already handle backlight
+-    power in 'ideapad_backlight_notify_power' to avoid a page fault
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (no-up) Input: elantech - Add v3 hardware support
+-    - LP: #681904
+-  * SAUCE: (drop after 3.1) usb_storage: Don't freeze in usb-stor-scan
+-    - LP: #810020
+-
+-  [ Stefan Bader ]
+-
+-  * (config) Package macvlan and macvtap for virtual
+-  * [Config] Force perf to use libiberty for demangling
+-    - LP: #783660
+-  * SAUCE: xen: Do not use pv spinlocks on HVM
+-    - LP: #838026
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Clean up tools rules
+-  * [Config] Package x86_energy_perf_policy and turbostat
+-    - LP: #797556
+-  * rebase to v3.1-rc3
+-  * [Config] Simplify binary-udebs dependencies
+-  * [Config] kernel preparation cannot be parallelized
+-  * [Config] Linearize module/abi checks
+-  * [Config] Linearize and simplify tree preparation rules
+-  * [Config] Build kernel image in parallel with modules
+-  * [Config] Set concurrency for kmake invocations
+-  * [Config] Improve install-arch-headers speed
+-  * [Config] Fix binary-perarch dependencies
+-  * [Config] Removed stamp-flavours target
+-  * [Config] Serialize binary indep targets
+-  * [Config] Use build stamp directly
+-  * [Config] Restore prepare-% target
+-  * rebase to v3.1-rc4
+-  * rebase to v3.1-rc5
+-  * [Config] Disable makedumpfile for i386/amd64
+-  * rebase to v3.1-rc6
+-  * [Config] Fix binary-% build target
+-  * rebase to v3.1-rc7
+-  * rebase to v3.1-rc8
+-  * SAUCE: Add a new entry (413c:8197) to Bluetooth USB device ID table
+-    - LP: #854399
+-  * [Config] Enable ftrace support in the mac80211 layer
+-    - LP: #865171
+-  * rebase to v3.1-rc9
+-  * SAUCE: usb/core/devio.c: Check for printer class specific request
+-    - LP: #872711
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * overlay filesystem
+-  * overlayfs: add statfs support
+-  * overlayfs: implement show_options
+-  * overlay: overlay filesystem documentation
+-  * fs: limit filesystem stacking depth
+-
+-  [ Will Drewry ]
+-
+-  * SAUCE: seccomp_filter: new mode with configurable syscall filters
+-  * SAUCE: seccomp_filter: add process state reporting
+-  * SAUCE: seccomp_filter: Document what seccomp_filter is and how it
+-    works.
+-  * SAUCE: seccomp_filter: add HAVE_SECCOMP_FILTER and seccomp_execve
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.1-rc1
+-  * rebase to v3.1-rc2
+-  * rebase to v3.1-rc3
+-    +CONFIG_BLK_DEV_BSGLIB=y
+-    +CONFIG_BLK_DEV_LOOP_MIN_COUNT=8
+-    -CONFIG_VIDEO_OMAP2_VOUT_VRFB=y
+-  * rebase to v3.1-rc4
+-  * rebase to v3.1-rc5
+-  * rebase to v3.1-rc6
+-  * rebase to v3.1-rc7
+-  * rebase to v3.1-rc8
+-  * rebase to v3.1-rc9
+-  * rebase to v3.1-rc10
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 15:43:38 -0700
+-
+-linux (3.1.0-1.0) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open P-series
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 10 Aug 2011 13:42:40 -0700
+-
+-linux (3.0.0-8.10) oneiric; urgency=low
+-
+-  [ Adam Jackson ]
+-
+-  * SAUCE: drm/i915/pch: Fix integer math bugs in panel fitting
+-    - LP: #753994
+-
+-  [ John Johansen ]
+-
+-  * [Config] Enable missing IPv6 options
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable config IWLWIFI_DEVICE_SVTOOL
+-    - LP: #819925
+-  * Rebase to 3.0.1
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, intel, power: Correct the MSR_IA32_ENERGY_PERF_BIAS message
+-  * ALSA: hda - Turn on extra EAPDs on Conexant codecs
+-    - LP: #783582
+-  * KVM: Remove SMEP bit from CR4_RESERVED_BITS
+-    - LP: #796476
+-  * KVM: Add SMEP support when setting CR4
+-    - LP: #796476
+-  * KVM: Mask function7 ebx against host capability word9
+-    - LP: #796476
+-  * KVM: Add instruction fetch checking when walking guest page table
+-    - LP: #796476
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.0.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 05 Aug 2011 11:32:25 -0700
+-
+-linux (3.0.0-7.9) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] add local prefix to oss local change_bits"
+-  * Revert "SAUCE: add tracing for user initiated readahead requests"
+-  * Revert "SAUCE: vfs: Add a trace point in the mark_inode_dirty function"
+-  * Revert "SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo
+-    Zhaoyang E47"
+-  * Revert "SAUCE: fix documentation strings for struct input_keymap_entry"
+-  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range checks
+-    (grub)"
+-  * Revert "SAUCE: vt -- fix handoff numbering to 1..n and add range
+-    checks"
+-  * Revert "SAUCE: vt -- allow grub to request automatic vt_handoff"
+-  * Revert "SAUCE: vt -- maintain bootloader screen mode and content until
+-    vt switch"
+-  * [Config] enable CONFIG_MTRR_SANITIZER_ENABLE_DEFAULT=1
+-    - LP: #816035
+-  * ubuntu: Yama: if an underlying filesystem provides a permissions op use
+-    it
+-  * SAUCE: (no-up) add tracing for user initiated readahead requests
+-  * SAUCE: vt -- maintain bootloader screen mode and content until vt
+-    switch
+-  * SAUCE: vt -- allow grub to request automatic vt_handoff
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: (no-up) vfs: Add a trace point in the mark_inode_dirty function
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: (no-up) Disable building the ACPI debugfs source"
+-  * [Config] enforce ACPI_CUSTOM_METHOD disabled
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: (no-up) Input: ALPS - Enable Intellimouse mode for Lenovo
+-    Zhaoyang E47
+-    - LP: #632884, #803005
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_BLK_DEV_CMD64X=m on powerpc
+-    - LP: #513131
+-  * [Config] Enable CONFIG_RT2800PCI_RT53XX=y
+-    - LP: #815064
+-
+-  [ Rezwanul Kabir ]
+-
+-  * SAUCE: (no-up) Add support for Intellimouse Mode in ALPS touchpad on
+-    Dell E2 series Laptops
+-    - LP: #632884
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "yama: if an underlying filesystem provides a permissions op use
+-    it"
+-  * Revert "Add support for Intellimouse Mode in ALPS touchpad on Dell E2
+-    series Laptops"
+-  * Revert "tty: include linux/slab.h for kfree"
+-  * Revert "gpio/ml_ioh_gpio: include linux/slab.h for kfree"
+-  * Revert "pch_dma: add include/slab.h for kfree"
+-  * mmc: Added quirks for Ricoh 1180:e823 lower base clock frequency
+-    - LP: #773524
+-  * oss: rename local change_bits to avoid powerpc bitsops.h definition
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 25 Jul 2011 09:08:01 -0700
+-
+-linux (3.0.0-7.8) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: overlayfs -- overlayfs: add statfs support
+-  * [Config] enable CONFIG_OVERLAYFS
+-
+-  [ Erez Zadok ]
+-
+-  * ubuntu: overlayfs -- overlayfs: implement show_options
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_ALIM7101_WDT=m on powerpc
+-  * [Config] Enable CONFIG_ASUS_OLED=m on powerpc
+-  * [Config] Disable CONFIG_ATM_DUMMY on arm
+-  * [Config] Enable CONFIG_BLK_DEV_DRBD=m on powerpc
+-  * Temporarily disable module check on arm
+-  * Rebase to 3.0 final
+-  * [Config] Enable CONFIG_CAN_TI_HECC=m on arm
+-  * [Config] Set CONFIG_CDROM_PKTCDVD=m on amd64 and i386
+-  * [Config] Enable CONFIG_CRYPTO_CCM=m on powerpc
+-  * [Config] Enable CONFIG_CRYPTO_DEV_HIFN_795X=m on powerpc
+-  * [Config] Enable CONFIG_CRYPTO_GCM=m on powerpc
+-  * [Config] Set CRYPTO_LZO=m on powerpc64-smp
+-  * [Config] Enable CONFIG_DM9000=m on arm
+-  * [Config] Set CONFIG_DISPLAY_SUPPORT=m on arm
+-  * [Config] Enable CONFIG_DL2K=m on amd64 and i386
+-
+-  [ Miklos Szeredi ]
+-
+-  * ubuntu: overlayfs -- vfs: add i_op->open()
+-  * ubuntu: overlayfs -- vfs: export do_splice_direct() to modules
+-  * ubuntu: overlayfs -- vfs: introduce clone_private_mount()
+-  * ubuntu: overlayfs -- overlay filesystem
+-  * ubuntu: overlayfs -- ovl: fix overlayfs over overlayfs
+-  * ubuntu: overlayfs -- ovl: improve stack use of lookup and readdir
+-  * ubuntu: overlayfs -- fs: limit filesystem stacking depth
+-  * ubuntu: overlayfs -- ovl: make lower mount read-only
+-
+-  [ Neil Brown ]
+-
+-  * ubuntu: overlayfs -- overlay: overlay filesystem documentation
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add enic/fnic to udebs
+-    - LP: #801610
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * yama: if an underlying filesystem provides a permissions op use it
+-
+-  [ Major Kernel Changes ]
+-
+-  * Rebase to 3.0 final
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 21 Jul 2011 07:01:32 -0700
+-
+-linux (3.0.0-6.7) oneiric; urgency=low
+-
+-  [ Eagon Yager ]
+-
+-  * [Config] Fix misspelled 'skipmodule' in arm makefile.
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: Input: ALPS - Enable Intellimouse mode for Lenovo Zhaoyang E47
+-    - LP: #632884, #803005
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Temporarily disable CONFIG_SMC91X on armel-omap"
+-  * Revert "[Config] Temporarily Disable CONFIG_BRCMSMAC on arm"
+-  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on powerpc"
+-  * Revert "[Config] Temporarily Disable CONFIG_RTL8192SE on arm"
+-  * Revert "[Config] Temporarily disable CONFIG_BRCMSMAC on powerpc"
+-  * [Config] Set CONFIG_ACPI_PCI_SLOT=m
+-  * [Config] Set CONFIG_ACPI_SBS=m
+-  * [Config] Set CONFIG_ACPI_WMI=m
+-  * [Config] Set CONFIG_AD7150=m on arm
+-  * [Config] Set CONFIG_AD7152=m on arm
+-  * [Config] Drop CONFIG_GPIO_S5PV210
+-  * [Config] Drop CONFIG_GPIO_S5PC100
+-  * [Config] Drop CONFIG_GPIO_PLAT_SAMSUNG
+-  * [Config] Drop CONFIG_GPIO_EXYNOS4
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Re-enable RODATA for i386 virtual
+-    - LP: #809838
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15"
+-  * (drop after 3.0.0) acer-wmi: Add support for Aspire 1830 wlan hotkey
+-    - LP: #771758
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 20 Jul 2011 06:36:02 -0700
+-
+-linux (3.0.0-5.6) oneiric; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_RTL8192CU=m
+-  * Rebase to -rc7
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 Jul 2011 22:13:50 +0100
+-
+-linux (3.0.0-4.5) oneiric; urgency=low
+-
+-  [ Ming Lei ]
+-
+-  * SAUCE: fix yama_ptracer_del lockdep warning
+-    - LP: #791019
+-
+-  [ Seth Forshee ]
+-
+-  * SAUCE: (drop after 3.0) asus-wmi: Add callback for hotkey filtering
+-  * SAUCE: (drop after 3.0) eeepc-wmi: Add support for T101MT Home/Express Gate key
+-  * SAUCE: (drop after 3.0) asus-wmi: Enable autorepeat for hotkey input device
+-  * [Config] CONFIG_{ASUS,ASUS_NB,EEEPC}_WMI=m
+-    - LP: #805218
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs after rebase to -rc6+
+-    Rebased against 4dd1b49c6d215dc41ce50c80b4868388b93f31a3
+-  * Adopt a 3 digit verion, e.g., 3.0.0-x.x
+-  * Revert "UBUNTU: add dependancies for module-init-tools"
+-    This dependency is no longer required for a 3 digit version.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 05 Jul 2011 14:03:04 +0100
+-
+-linux (3.0-3.4) oneiric; urgency=low
+-
+-  [ Keng-Yu Lin ]
+-
+-  * SAUCE: Revert: "dell-laptop: Toggle the unsupported hardware
+-    killswitch"
+-    - LP: #775281
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc5
+-  * [Config] updateconfigs after rebase to 3.0-rc5
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Remove ubuntu/rtl8192se
+-  * [Config] Added armel ABI files
+-  * [Config] Removed armel versatile flavour
+-  * [Config] CONFIG_INTEL_MEI=m
+-    - LP: #716867
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Enable auto-parser as default for Conexant codecs
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v3.0-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 30 Jun 2011 14:27:10 +0100
+-
+-linux (3.0-2.3) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to 0e2bafab74f0d1463383faeb93f9fc5eb8c2c54e
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc4
+-  * [Config] updateconfigs after rebase to 3.0-rc4
+-  * fix ERROR: __devcgroup_inode_permission undefined
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: iscsitarget: Remove driver from the kernel
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: rtl8192se: Force a build for a 2.6/3.0 kernel
+-  * [Config] Add grub-efi as a recommended bootloader for server and
+-    generic
+-    - LP: #800910
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Fix node_start/end_pfn() definition for mm/page_cgroup.c
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 24 Jun 2011 11:51:12 -0700
+-
+-linux (3.0-1.2) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_CAN_CALC_BITTIMING
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc3
+-  * [Config] updateconfigs after rebase to 3.0-rc3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * perf: clear out make flags when calling kernel make kernelver
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Jun 2011 07:25:35 -0700
+-
+-linux (3.0-0.1) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * use the packaging version in the kernel
+-  * use the kernels idea of its version for version_signature
+-  * add dependancies for module-init-tools
+-  * update control files to version 3
+-  * printchanges/insertchanges allow override of prev_release
+-  * correct Vcs-Git: to point to oneiric
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v3.0-rc1
+-  * [Config] updateconfigs after rebase to 3.0-rc1
+-  * ubuntu: dm-raid4-5 fix up build failure
+-  * [Config] Temporarily Disable CONFIG_GPIO_EXYNOS4 on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_PLAT_SAMSUNG on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_S5PC100 on arm
+-  * [Config] Temporarily Disable CONFIG_GPIO_S5PV210 on arm
+-  * [Config] Temporarily disable CONFIG_BRCMSMAC on powerpc
+-  * [Config] Temporarily Disable CONFIG_BRCMSMAC on arm
+-  * [Config] Temporarily Disable CONFIG_RTL8192SE on arm
+-  * [Config] Temporarily Disable CONFIG_RTL8192SE on powerpc
+-  * [Config] Temporarily disable CONFIG_SMC91X on armel-omap
+-  * rebase to v3.0-rc2
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: mmc: Enable MMC card reader for RICOH [1180:e823]
+-    - LP: #790754
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86 idle: EXPORT_SYMBOL(default_idle, pm_idle) only when APM
+-    demands it"
+-  * drm/i915: fix regression after clock gating init split
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39 to v3.0-rc1
+-  * rebase from v3.0-rc1 to v3.0-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Jun 2011 15:18:33 +0100
+-
+-linux (2.6.39-3.10) oneiric; urgency=low
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: S3 early resume debug via keyboard LEDs
+-
+-  [ Ingo Molnar ]
+-
+-  * ubuntu: nx-emu - i386: NX emulation
+-  * ubuntu: nx-emu - i386: mmap randomization for executable mappings
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] Disable CONFIG_FT1000 on powerpc64-smp"
+-  * Revert "[Config] Disable CONFIG_DM_RAID45"
+-  * [Config] enable CONFIG_BRCMFMAC=y
+-  * [Config] enable CONFIG_MDIO_BITBANG=m across all arch's and flavors
+-  * [Config] enable CONFIG_VIDEO_OUTPUT_CONTROL=m on armel-omap
+-
+-  [ Robert Nelson ]
+-
+-  * SAUCE: omap3: beagle: detect new xM revision B
+-    - LP: #770679
+-  * SAUCE: omap3: beagle: detect new xM revision C
+-    - LP: #770679
+-  * SAUCE: omap3: beagle: if rev unknown, assume xM revision C
+-    - LP: #770679
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Convert dm-raid45 to new block plugging
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 May 2011 11:46:43 -0700
+-
+-linux (2.6.39-3.9) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_SCSI_LPFC_DEBUG_FS
+-  * rebase to v2.6.39
+-  * [Config] enable CONFIG_LLC2=m across all arch's and flavours
+-  * [Config] enable CONFIG_INPUT_APANEL=m
+-
+-  [ Thomas Schlichter ]
+-
+-  * SAUCE: vesafb: mtrr module parameter is uint, not bool
+-    - LP: #778043
+-  * SAUCE: vesafb: enable mtrr WC by default
+-    - LP: #778043
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc7 to v2.6.39
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 20 May 2011 09:52:32 +0100
+-
+-linux (2.6.39-2.8) oneiric; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37"
+-  * Revert "ubuntu: AUFS -- aufs2-base.patch aufs2.1-37"
+-  * Revert "[Config] Disable CONFIG_AUFS_FS"
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-39
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-39
+-  * ubuntu: AUFS -- update to c6b76974311efc5bf3eddf921cd015b6aae46935
+-  * ubuntu: AUFS -- clean up the aufs updater and BOM
+-  * ubuntu: AUFS -- documentation on updating aufs2
+-
+-  [ Kees Cook ]
+-
+-  * ubuntu: Yama - LSM hooks
+-  * ubuntu: Yama - create task_free security callback
+-  * ubuntu: Yama - add ptrace relationship tracking interface
+-  * ubuntu: Yama - unconditionally chain to Yama LSM
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: Fix drivers/staging/easycap FTBS"
+-  * Revert "[Config] Disable CONFIG_EASYCAP"
+-  * ubuntu: fsam7400 disable driver
+-  * ubuntu: omnibook disable driver
+-  * ubuntu: rfkill disable driver
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Fix extra reference in fb_open()
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 16 May 2011 09:23:56 -0700
+-
+-linux (2.6.39-2.7) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc7
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc6 to v2.6.39-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 10 May 2011 10:18:28 +0200
+-
+-linux (2.6.39-1.6) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc6
+-  * SAUCE: [arm] fixup __aeabi_uldivmod undefined build error
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs after rebase to 2.6.39-rc6
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc5 to v2.6.39-rc6
+-    - LP: #740126
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 05 May 2011 09:46:12 -0700
+-
+-linux (2.6.39-0.5) oneiric; urgency=low
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: Revert "x86, hibernate: Initialize mmu_cr4_features during boot"
+-    - LP: #764758
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc5
+-  * [Config] updateconfigs following rebase to v2.6.39-rc5
+-
+-  [ Paolo Pisati ]
+-
+-  * [Config] s/USB_MUSB_TUSB6010/USB_MUSB_OMAP2PLUS/ on omap3 to get musb
+-    - LP: #759913
+-
+-  [ Stefan Bader ]
+-
+-  * Include nls_iso8859-1 for virtual images
+-    - LP: #732046
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc4 to v2.6.39-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 27 Apr 2011 06:39:42 -0700
+-
+-linux (2.6.39-0.4) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc4
+-  * [Config] updateconfigs following rebase to v2.6.39-rc4
+-  * fixup powerpc implicit declaration of function
+-    'crash_kexec_wait_realmode'
+-  * [Config] Disable CONFIG_FT1000 on powerpc64-smp
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_TRANSPARENT_HUGEPAGE=y
+-    - LP: #769503
+-  * [Config] Add cachefiles.ko to virtual flavour
+-    - LP: #770430
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc3 to v2.6.39-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 19 Apr 2011 06:25:20 -0700
+-
+-linux (2.6.39-0.3) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc3
+-  * crash_kexec_wait_realmode() undefined when !SMP
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_PM_ADVANCED_DEBUG=y for i386/amd64
+-    - LP: #632327
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc2 to v2.6.39-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 12 Apr 2011 06:52:24 -0700
+-
+-linux (2.6.39-0.2) oneiric; urgency=low
+-
+-  [ Gustavo F. Padovan ]
+-
+-  * SAUCE: Revert "Bluetooth: Add new PID for Atheros 3011"
+-    - LP: #720949
+-
+-  [ John Johansen ]
+-
+-  * AppArmor: Fix masking of capabilities in complain mode
+-    - LP: #748656
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc2
+-  * [Config] updateconfigs following rebase to v2.6.39-rc2
+-  * hv_mouse needs delay.h
+-  * olpc_dcon_xo_1 needs delay.h
+-  * olpc_dcon_xo_1_5 needs delay.h
+-  * Update dropped.txt for Oneiric
+-
+-  [ Steve Langasek ]
+-
+-  * [Config] Make linux-libc-dev coinstallable under multiarch
+-    - LP: #750585
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, hibernate: Initialize mmu_cr4_features during boot
+-    - LP: #752870
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.39-rc1 to v2.6.39-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 06 Apr 2011 11:04:15 -0700
+-
+-linux (2.6.39-0.1) oneiric; urgency=low
+-
+-  [ Brad Figg ]
+-
+-  * [Config] Set CONFIG_NR_CPUS=256 for amd64 generic
+-    - LP: #737124
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: HID: hid-ntrig: add support for 1b96:0006 model
+-  * SAUCE: HID: ntrig: fix suspend/resume on recent models
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: (drop after 2.6.39) v4l: make sure drivers supply a zeroed
+-    struct v4l2_subdev
+-    - LP: #745213
+-
+-  [ Kees Cook ]
+-
+-  * [Config] packaging: adjust perms on vmlinuz as well
+-  * SAUCE: nx-emu: further clarify dmesg reporting
+-    - LP: #745181
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.39-rc1
+-  * [Config] updateconfigs following rebase to v2.6.39-rc1
+-  * [Config] Disable CONFIG_DM_RAID45
+-  * [Config] Disable CONFIG_SCSI_ISCSITARGET
+-  * [Config] Disable CONFIG_EASYCAP
+-  * [Config] Disable CONFIG_AUFS_FS
+-  * update bnx2 firmware files in d-i/firmware/nic-modules
+-  * xhci-pci.c resolve implicit declaration of kzalloc
+-  * [Config] Enable CONFIG_DRM_PSB for only x86
+-  * [Config] Enable CONFIG_RTS_PSTOR for only x86
+-  * mfd/asic3: Fix typo, s/irq_data/data/
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Disable CONFIG_CRASH_DUMP on 32-bit powerpc kernels
+-    - LP: #745358
+-  * [Config] Disable CONFIG_DRM_RADEON_KMS on powerpc kernels
+-  * [Config] Build some framebuffer drivers as modules for powerpc kernels.
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: thinkpad-acpi: module autoloading for newer Lenovo ThinkPads.
+-    - LP: #745217
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: INR_OPEN=4096
+-    - LP: #663090
+-  * SAUCE: Increase the default hard limit for open FDs to 4096
+-    - LP: #663090
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.39-rc1) arm: versatile : Fix typo introduced in irq
+-    namespace cleanup
+-  * (drop after 2.6.39-rc1) [media] staging: altera-jtag needs delay.h
+-  * ALSA: pcm: fix infinite loop in snd_pcm_update_hw_ptr0()
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38 to v2.6.39-rc1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:50:10 -0700
+-
+-linux (2.6.39-0.0) oneiric; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Open Oneiric 
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 31 Mar 2011 12:29:23 -0700
+-
+-linux (2.6.38-7.39) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload.  This is just to rebuild with gcc-4.5.2-7ubuntu1.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Mar 2011 09:27:45 -0700
+-
+-linux (2.6.38-7.38) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload take 2.  2.6.38-7.37 was accidentally uploaded before
+-    gcc-4.5.2-6ubuntu5 finished building on all arches.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 22 Mar 2011 06:12:47 -0700
+-
+-linux (2.6.38-7.37) natty; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No change upload.  This is just to rebuild with gcc-4.5.2-6ubuntu5.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 20 Mar 2011 16:02:48 -0700
+-
+-linux (2.6.38-7.36) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler
+-    optimisation"
+-  * purge last vestiges of maverick
+-  * [Config] switch CONFIG_FB_VESA back to module
+-
+-  [ Chris Wilson ]
+-
+-  * SAUCE: drm/i915: Fix pipelined fencing
+-    - LP: #717114
+-
+-  [ Loïc Minier ]
+-
+-  * Include nls_cp437 module in virtual for fat
+-    - LP: #732046
+-  * Support arch= cross-compilation for any arch
+-  * Fix couple of typos in 0-common-vars.mk
+-  * Enforce DEFAULT_MMAP_MIN_ADDR on armhf
+-  * Add armhf to Debian -> Linux arch map
+-  * Add initial armhf.mk
+-  * Enable common packages for armhf
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Yama: fix default relationship to check thread group
+-    - LP: #737676
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 18 Mar 2011 18:18:02 +0000
+-
+-linux (2.6.38-7.35) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to 2fbfac4e053861925fa3fffcdc327649b09af54c
+-  * rebase fixes bug #715330
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI for powerpc 32bit to fix FTBS
+-  * rebase to v2.6.38 final
+-
+-  [ Herton Ronaldo Krzesinski ]
+-
+-  * SAUCE: Apply OPTION_BLACKLIST_SENDSETUP also for ZTE MF626
+-    - LP: #636091
+-
+-  [ Tim Gardner ]
+-
+-  * [Confg] CONFIG_BOOT_PRINTK_DELAY=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Yama: use thread group leader when creating match
+-    - LP: #729839
+-  * (drop after 2.6.38) ahci: AHCI mode SATA patch for Intel Patsburg SATA
+-    RAID controller
+-    - LP: #735240
+-  * (drop after v2.6.38) x86, quirk: Fix SB600 revision check
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc8 to v2.6.38 final
+-    - LP: #715330
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 15 Mar 2011 19:04:19 +0000
+-
+-linux (2.6.38-6.34) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] normalise CONFIG_INTEL_TXT
+-  * SAUCE: KLUDGE: work around failed 'shrink-wrap' compiler optimisation
+-    - LP: #730860
+-  * rebase to mainline v2.6.38-rc8
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc7 + fb62c00a6d8942775abc23d1621db1252e2d93d1
+-    to v2.6.38-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Mar 2011 11:54:48 +0000
+-
+-linux (2.6.38-6.33) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * d-i -- enable speakup-modules udeb
+-    - LP: #672699
+-  * rebase to 493f3358cb289ccf716c5a14fa5bb52ab75943e5
+-  * [Config] debian PPC64 configuration
+-  * [Config] cleanup powerpc config fixing unexpected inconsistancies
+-  * [Config] resync ppc64 configuration
+-  * SAUCE: match up ENTRY/END naming for 32/64 bit
+-  * rebase to fb62c00a6d8942775abc23d1621db1252e2d93d1
+-  * [Config] update configs after rebase to
+-    fb62c00a6d8942775abc23d1621db1252e2d93d1
+-  * [Config] pps_gen_parport no longer built
+-
+-  [ Corentin Chary ]
+-
+-  * SAUCE: (drop after 2.6.38) eeepc-wmi: reorder keymap
+-    - LP: #689393
+-  * SAUCE: (drop after 2.6.38) eeepc-wmi: add wlan key found on 1015P
+-    - LP: #689393
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: Fix aufs calling of security_path_mknod
+-    - LP: #724456
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: proc: hide kernel addresses via %pK in /proc/<pid>/stack
+-
+-  [ Tim Gardner ]
+-
+-  * rebase to 2.6.38-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "drm/i915: fix corruptions on i8xx due to relaxed fencing"
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc6 to v2.6.38-rc7 +
+-    fb62c00a6d8942775abc23d1621db1252e2d93d1
+-    - LP: #721389
+-    - LP: #722925
+-    - LP: #723672
+-    - LP: #723676
+-    - LP: #715318
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Mar 2011 15:33:17 +0000
+-
+-linux (2.6.38-5.32) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to mainline 6f576d57f1fa0d6026b495d8746d56d949989161
+-  * [Config] updateconfigs following rebase to v2.6.38-rc6
+-  * [Config] enable CONFIG_DMAR
+-    - LP: #552311
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915: skip FDI & PCH enabling for DP_A
+-    - LP: #561802, #600453, #681877
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc5 to v2.6.38-rc6
+-    - LP: #718402
+-    - LP: #719524
+-    - LP: #721126
+-    - LP: #719691
+-    - LP: #722689
+-    - LP: #722310
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 22 Feb 2011 13:28:39 +0000
+-
+-linux (2.6.38-4.31) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * add in bugs closed by upstream patches pulled in by rebases
+-  * rebase to 795abaf1e4e188c4171e3cd3dbb11a9fcacaf505
+-  * [Config] enable CONFIG_VSX to allow use of vector instuctions
+-  * resync with maverick 98defa1c5773a3d7e4c524967eb01d5bae035816
+-  * rebase to mainline v2.6.38-rc5
+-  * SAUCE: ecryptfs: read on a directory should return EISDIR if not
+-    supported
+-    - LP: #719691
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: Dell All-In-One: Remove need for Dell module alias
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: (drop after 2.6.38) add ricoh 0xe823 pci id.
+-    - LP: #717435
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_CRYPTO_CRC32C_INTEL=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Quirk to fix suspend/resume on Lenovo Edge 11,13,14,15
+-    - LP: #702434
+-  * vfs: fix BUG_ON() in fs/namei.c:1461
+-
+-  [ Vladislav P ]
+-
+-  * SAUCE: Release BTM while sleeping to avoid deadlock.
+-    - LP: #713837
+-
+-  [ Major Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc4 to v2.6.38-rc5
+-    - LP: #579276
+-    - LP: #715877
+-    - LP: #713769
+-    - LP: #716811
+-  * resync with Maverick Ubuntu-2.6.35-27.47
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Feb 2011 17:24:09 +0000
+-
+-linux (2.6.38-3.30) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.38-rc4
+-  * ppc64 -- add basic architecture
+-  * ubuntu: AUFS -- update to 65835da20b77c98fb538c9114fc31f5de1328230
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: Add WMI hotkeys support for Dell All-In-One series
+-    - LP: #676997
+-  * SAUCE: Add WMI hotkeys support for another Dell All-In-One series
+-    - LP: #701530
+-  * SAUCE: Dell WMI: Use sparse keymaps and tidy up code.
+-    - LP: #701530
+-
+-  [ Dan Rosenberg ]
+-
+-  * SAUCE: (drop after 2.6.38) Convert net %p usage %pK
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of
+-    attacking"
+-  * SAUCE: (drop after 2.6.38) use %pK for /proc/kallsyms and /proc/modules
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_BLK_CGROUP=y
+-    - LP: #706394
+-  * [Config] CONFIG_DELL_WMI_AIO=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915/lvds: Restore dithering on native modes for gen2/3
+-    - LP: #711568
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc3 to v2.6.38-rc4.
+-    - LP: #701271
+-    - LP: #708521
+-    - LP: #710371
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 08 Feb 2011 02:07:18 +0000
+-
+-linux (2.6.38-2.29) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to 1f0324caefd39985e9fe052fac97da31694db31e
+-  * [Config] updateconfigs following rebase to
+-    1f0324caefd39985e9fe052fac97da31694db31e
+-  * rebase to 70d1f365568e0cdbc9f4ab92428e1830fdb09ab0
+-  * [Config] reenable HIBERNATE
+-    - LP: #710877
+-  * rebase to v2.6.38-rc3
+-  * [Config] reenable CONFIG_CRASH_DUMP
+-
+-  [ Kamal Mostafa ]
+-
+-  * SAUCE: rtl8192se: fix source file perms
+-  * SAUCE: rtl8192se: fix source file newline
+-  * SAUCE: omnibook: fix source file newline
+-
+-  [ Kees Cook ]
+-
+-  * [Config] packaging: really make System.map mode 0600
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * SAUCE: OMAP3630: PM: don't warn the user with a trace in case of
+-    PM34XX_ERRATUM
+-
+-  [ Soren Hansen ]
+-
+-  * SAUCE: nbd: Remove module-level ioctl mutex
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Disable building the ACPI debugfs source
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Set physical start and alignment 1M for virtual i386
+-    - LP: #710754
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase from v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-    to v2.6.38-rc3
+-    - LP: #707902
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 16:30:32 +0000
+-
+-linux (2.6.38-1.28) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to b1cee06249dfa0ab30951e7f06490a75c155b620
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * SAUCE: omap3: beaglexm: fix DVI initialization
+-  * [Config] omap: move CONFIG_PANEL_GENERIC_DPI to build in to make
+-    display work at Beagle
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 28 Jan 2011 10:51:57 +0000
+-
+-linux (2.6.38-1.27) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update aufs-update to track new locations of headers
+-  * ubuntu: AUFS -- update to c5021514085a5d96364e096dbd34cadb2251abfd
+-  * SAUCE: ensure root is ready before running usermodehelpers in it
+-  * correct the Vcs linkage to point to natty
+-  * rebase to linux tip e78bf5e6cbe837daa6ab628a5f679548742994d3
+-  * [Config] update configs following rebase
+-    e78bf5e6cbe837daa6ab628a5f679548742994d3
+-  * SAUCE: Yama: follow changes to generic_permission
+-  * ubuntu: compcache -- follow changes to bd_claim/bd_release
+-  * ubuntu: iscsitarget -- follow changes to open_bdev_exclusive
+-  * ubuntu: ndiswrapper -- fix interaction between __packed and packed
+-  * ubuntu: AUFS -- update to 806051bcbeec27748aae2b7957726a4e63ff308e
+-  * update package version to match payload version
+-  * rebase to e6f597a1425b5af64917be3448b29e2d5a585ac8
+-  * rebase to v2.6.38-rc1
+-  * [Config] updateconfigs following rebase to v2.6.38-rc1
+-  * SAUCE: x86 fix up jiffies/jiffies_64 handling
+-  * rebase to linus tip 2b1caf6ed7b888c95a1909d343799672731651a5
+-  * [Config] updateconfigs following rebase to
+-    2b1caf6ed7b888c95a1909d343799672731651a5
+-  * [Config] disable CONFIG_TRANSPARENT_HUGEPAGE to fix i386 boot crashes
+-  * ubuntu: AUFS -- suppress benign plink warning messages
+-    - LP: #621195
+-  * [Config] CONFIG_NR_CPUS=256 for amd64 -server flavour
+-  * rebase to v2.6.38-rc2
+-  * rebase to mainline d315777b32a4696feb86f2a0c9e9f39c94683649
+-  * rebase to c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-  * [Config] update configs following rebase to
+-    c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-  * [Config] disable CONFIG_AD7152 to fix FTBS on armel versatile
+-  * [Config] disable CONFIG_AD7150 to fix FTBS on armel versatile
+-  * [Config] disable CONFIG_RTL8192CE to fix FTBS on armel omap
+-  * [Config] disable CONFIG_MANTIS_CORE to fix FTBS on armel versatile
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: kernel: make /proc/kallsyms mode 400 to reduce ease of attacking
+-
+-  [ Stefan Bader ]
+-
+-  * Temporarily disable RODATA for virtual i386
+-    - LP: #699828
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NLS_DEFAULT=utf8
+-    - LP: #683690
+-  * [Config] CONFIG_HIBERNATION=n
+-  * update bnx2 firmware files in d-i/firmware/nic-modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "drm/radeon/bo: add some fallback placements for VRAM only
+-    objects."
+-  * packaging: make System.map mode 0600
+-  * thinkpad_acpi: Always report scancodes for hotkeys
+-    - LP: #702407
+-  * sched: tg->se->load should be initialised to tg->shares
+-  * Input: sysrq -- ensure sysrq_enabled and __sysrq_enabled are consistent
+-  * brcm80211: include linux/slab.h for kfree
+-  * pch_dma: add include/slab.h for kfree
+-  * i2c-eg20t: include linux/slab.h for kfree
+-  * gpio/ml_ioh_gpio: include linux/slab.h for kfree
+-  * tty: include linux/slab.h for kfree
+-  * winbond: include linux/delay.h for mdelay et al
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mark the start of v2.6.38 versioning
+-  * rebase v2.6.37 to v2.6.38-rc2 + c723fdab8aa728dc2bf0da6a0de8bb9c3f588d84
+-    - LP: #689886
+-    - LP: #702125
+-    - LP: #608775
+-    - LP: #215802
+-    - LP: #686333
+-    - LP: #677830
+-    - LP: #677652
+-    - LP: #696493
+-    - LP: #697240
+-    - LP: #689036
+-    - LP: #705323
+-    - LP: #686692
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 09 Jan 2011 13:44:52 +0000
+-
+-linux (2.6.37-12.26) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.37-rc8
+-  * [Config] armel -- reenable omap flavour
+-  * [Config] disable CONFIG_MACH_OMAP3517EVM to fix FTBS on armel omap
+-  * [Config] disable CONFIG_GPIO_VX855 to fix FTBS on omap armel
+-  * [Config] disable CONFIG_WESTBRIDGE_ASTORIA to fix FTBS on omap armel
+-  * [Config] disable CONFIG_TI_DAVINCI_EMAC to fix FTBS on omap armel
+-  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
+-  * [Config] track missing modules
+-  * rebase to v2.6.37 final
+-
+-  [ Chase Douglas ]
+-
+-  * SAUCE: (drop after 2.6.37) HID: magicmouse: Don't report REL_{X, Y} for
+-    Magic Trackpad
+-
+-  [ Stefan Bader ]
+-
+-  * Revert "SAUCE: blkfront: default to sd devices"
+-    - LP: #684875
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "SAUCE: (no-up) libata: Ignore HPA by default."
+-    - LP: #380138
+-  * [Config] Added autofs4.ko to -virtual flavour
+-    - LP: #692917
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Add support for Intellimouse Mode in ALPS touchpad on Dell E2 series
+-    Laptops
+-    - LP: #632884
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc8
+-  * rebase to mainline 989d873fc5b6a96695b97738dea8d9f02a60f8ab
+-  * rebase to v2.6.37 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Dec 2010 18:34:13 +0000
+-
+-linux (2.6.37-11.25) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i -- add hpsa to the list of block devices
+-    - LP: #684304
+-  * [Config] add vmw-balloon driver to -virtual flavour
+-    - LP: #592039
+-  * rebase to v2.6.37-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 21 Dec 2010 13:35:28 +0000
+-
+-linux (2.6.37-10.24) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.37-rc6
+-  * updateconfigs following rebase to v2.6.37-rc6
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 16 Dec 2010 12:34:19 +0000
+-
+-linux (2.6.37-9.23) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks
+-    - LP: #689606
+-  * SAUCE: vt -- fix handoff numbering to 1..n and add range checks (grub)
+-    - LP: #689606
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: RO/NX protection for loadable kernel, fix ftrace
+-    - LP: #690190
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 15 Dec 2010 19:29:57 +0000
+-
+-linux (2.6.37-9.22) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.35-rc5
+-  * [Config] updateconfigs following rebase to v2.6.37-rc5
+-  * (no-up) add support for installed header files to ubuntu directory
+-    - LP: #684666
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-  * ubuntu: dm-raid4-5 -- follow changes to bio flags
+-  * ubuntu: dm-raid4-5 -- re-enable
+-  * ubuntu: omnibook -- update BOM
+-  * ubuntu: ndiswrapper -- update BOM to match actual version
+-  * ubuntu: ndiswrapper -- follow removal of the BKL and locked ioctl
+-  * ubuntu: ndiswrapper -- re-enable
+-  * ubuntu: iscsitarget -- re-instate copy_io_context
+-  * ubuntu: iscsitarget -- follow changes to semaphore initialisation
+-  * ubuntu: iscsitarget -- convert NIPQUAD to %pI4
+-  * ubuntu: iscsitarget -- re-enable
+-
+-  [ Kees Cook ]
+-
+-  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Enable jack sense for Thinkpad Edge 13
+-    - LP: #685015
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_9P_FSCACHE=y,CONFIG_9P_FS_POSIX_ACL=y
+-  * [Config] CONFIG_CRYPTO_CRC32C=y
+-    - LP: #681819
+-  * [Config] CONFIG_9P_FSCACHE=n
+-  * [Config] Add nfsd modules to -virtual flavour
+-    - LP: #688070
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Staging: zram: work around oops due to startup ordering snafu"
+-  * NFS: Fix panic after nfs_umount()
+-    - LP: #683938
+-  * x86: Add NX protection for kernel data
+-  * x86: Add RO/NX protection for loadable kernel modules
+-  * x86: Resume trampoline must be executable
+-  * x86: RO/NX protection for loadable kernel, jump_table fix
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.37-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 09 Dec 2010 18:15:35 +0000
+-
+-linux (2.6.37-8.21) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- include the aufs_types.h file in
+-    linux-libc-headers"
+-  * Revert "(no-up) add support for installed header files to ubuntu
+-    directory"
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 05 Dec 2010 17:33:28 +0000
+-
+-linux (2.6.37-8.20) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] drivers/serial/mfd.c: Fix ARM compile error"
+-  * Revert "SAUCE: Nouveau: Disable acceleration on MacBook Pros"
+-  * Revert "SAUCE: Nouveau: Add quirk framework to disable acceleration"
+-  * Revert "SAUCE: i915 -- disable powersave by default"
+-  * SAUCE: enable Marvell 9128 PCIe SATA controller
+-    - LP: #658521
+-  * [Config] evtchn has been renamed
+-  * (no-up) add support for installed header files to ubuntu directory
+-    - LP: #684666
+-  * ubuntu: AUFS -- include the aufs_types.h file in linux-libc-headers
+-    - LP: #684666
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] MISS: evtchn, NEW : xen-evtchn
+-  * rebase to v2.6.37-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drm/i915: Clean conflicting modesetting registers upon init
+-    - LP: #683775
+-  * rebase to v2.6.37-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 03 Dec 2010 18:42:07 +0000
+-
+-linux (2.6.37-7.19) natty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add bnx2 firmware to nic-modules udeb
+-    - LP: #676245
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 26 Nov 2010 17:53:45 +0000
+-
+-linux (2.6.37-7.18) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID"
+-  * Revert "SAUCE: Add extra headers to linux-libc-dev"
+-  * Revert "SAUCE: Enable speedstep for sonoma processors."
+-  * [Config] enable CONFIG_BT_HCIUART_ATH3K
+-  * [Config] enable CONFIG_IWLWIFI_DEBUGFS
+-  * [Config] standardise CONFIG_MII
+-  * [Config] standardise CONFIG_PRISM2_USB
+-  * [Config] standardise CONFIG_SCSI_QLA_ISCSI
+-  * [Config] build in CONFIG_AGP
+-  * [Config] build in CONFIG_AGP_INTEL
+-  * [Config] build in CONFIG_AGP_AMD
+-  * [Config] build in CONFIG_AGP_AMD64
+-  * [Config] build in CONFIG_AGP_NVIDIA
+-  * [Config] build in CONFIG_AGP_VIA
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI for FTBS (arm)
+-  * (no-up): document the new ## scheme
+-  * [Config] harmonise CONFIG_SERIAL_8250_NR_UARTS
+-  * [Config] update CONFIG_SERIAL_8250_RUNTIME_UARTS=32
+-    - LP: #675453
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: ARM: Adding vdd_sdi regulator supply to OMAP3EVM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * nx-emu: fix inverted report of disable_nx
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 23 Nov 2010 21:00:39 +0000
+-
+-linux (2.6.37-6.17) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2-standalone.patch
+-    aufs2.1-36-UNRELEASED-20101103"
+-  * Revert "ubuntu: AUFS -- aufs2-base.patch
+-    aufs2.1-36-UNRELEASED-20101103"
+-  * [Config] standardise CONFIG_BT
+-  * [Config] standardise CONFIG_IRDA
+-  * [Config] standardise CONFIG_LAPB
+-  * [Config] standardise CONFIG_RDS
+-  * [Config] standardise CONFIG_RFKILL
+-  * [Config] standardise CONFIG_TIPC
+-  * [Config] standardise CONFIG_X25
+-  * [Config] standardise CONFIG_INPUT_EVDEV
+-  * [Config] standardise CONFIG_INPUT_JOYDEV
+-  * [Config] standardise CONFIG_INPUT_JOYSTICK
+-  * [Config] standardise CONFIG_INPUT_TOUCHSCREEN
+-  * [Config] CONFIG_INPUT_TOUCHSCREEN=n for FTBS (arm)
+-  * [Config] CONFIG_IRDA=n for FTBS (arm)
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-37
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-37
+-  * ubuntu: AUFS -- update to 097bf62d6f49619359d34bf17f242df38562489a
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Fix drivers/staging/easycap FTBS
+-  * [Config] CONFIG_EASYCAP=m after fixing FTBS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Add NX protection for kernel data"
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 18:09:10 +0000
+-
+-linux (2.6.37-6.16) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] update config for CONFIG_DEBUG_SET_MODULE_RONX"
+-  * rebase to v2.6.37-rc3
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_SCHED_AUTOGROUP=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Add RO/NX protection for loadable kernel modules"
+-  * sched: automated per session task groups
+-  * rebase to v2.6.37-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 22 Nov 2010 10:11:13 +0000
+-
+-linux (2.6.37-6.15) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] standardise CONFIG_CEPH_FS
+-  * [Config] standardise CONFIG_SCSI_LPFC_DEBUG_FS
+-  * [Config] standardise CONFIG_SCSI_PROC_FS
+-  * [Config] standardise CONFIG_UBIFS_FS
+-  * [Config] standardise CONFIG_USB_GADGET_DEBUG_FS
+-
+-  [ Kees Cook ]
+-
+-  * [Config] update config for CONFIG_DEBUG_SET_MODULE_RONX
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Enable jack sense for Thinkpad Edge 11
+-    - LP: #677210
+-  * SAUCE: enable rfkill for rtl8192se driver
+-    - LP: #640992
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_EASYCAP=n for FTBS
+-  * Rebase to v2.6.32-rc2+git
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86: Fix improper large page preservation
+-  * x86: Add NX protection for kernel data
+-  * x86: Add RO/NX protection for loadable kernel modules
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebase to Linus 2.6.37-rc2+git
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 20 Nov 2010 11:40:00 +0000
+-
+-linux (2.6.37-5.14) natty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * PCI: fix offset check for sysfs mmapped files
+-    - LP: #676963
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Nov 2010 18:12:27 +0000
+-
+-linux (2.6.37-5.13) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebased to v2.6.37-rc2
+-  * updateconfigs following rebase to v2.6.37-rc2
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added NFS and related modules to virtual flavour
+-    - LP: #659084
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, cpu: Rename verify_cpu_64.S to verify_cpu.S
+-  * x86, cpu: Clear XD_DISABLED flag on Intel to regain NX
+-  * x86, cpu: Call verify_cpu during 32bit CPU startup
+-  * x86, cpu: Only CPU features determine NX capabilities
+-
+-  [ Upstream Changes ]
+-
+-  * rebased to v2.67.37-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 16 Nov 2010 13:13:29 +0000
+-
+-linux (2.6.37-4.12) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Upstream] HID: magicmouse: add param for scroll speed"
+-  * Revert "[Upstream] HID: magicmouse: properly account for scroll
+-    movement in state"
+-  * Revert "[Upstream] HID: magicmouse: disable and add module param for
+-    scroll acceleration"
+-  * Revert "[Upstream] HID: magicmouse: scroll on entire surface, not just
+-    middle of mouse"
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: hid: ntrig: remove sysfs nodes
+-  * SAUCE: hid: ntrig: Setup input filtering manually
+-  * SAUCE: hid: ntrig: New ghost-filtering event logic
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-    - LP: #348861
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "mmc: fix all hangs related to mmc/sd card insert/removal during
+-    suspend/resume"
+-  * Revert "[ARM] implement arch_randomize_brk()"
+-  * Revert "ARM: stack protector: change the canary value per task"
+-  * Revert "ARM: initial stack protector (-fstack-protector) support"
+-  * Revert "ALSA: hda - Handle pin NID 0x1a on ALC259/269"
+-  * Revert "ALSA: hda - Handle missing NID 0x1b on ALC259 codec"
+-  * Revert "perf probe: Add kernel source path option"
+-  * hid: ntrig: Support single-touch devices
+-  * hid: ntrig: Mask pen switch events
+-  * net: rtnetlink.h -- only include linux/netdevice.h when used by the
+-    kernel
+-    - LP: #673073
+-  * Fix userspace build of linux/fs.h
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 15 Nov 2010 19:31:44 +0000
+-
+-linux (2.6.37-3.11) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- update to
+-    b37c575759dc4535ccc03241c584ad5fe69e3b25"
+-  * Revert "ubuntu: AUFS -- track changes to the arguements to fop fsync()"
+-  * Revert "ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601"
+-  * Revert "ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601"
+-  * Revert "ubuntu: AUFS -- aufs2 base patch for linux-2.6.34"
+-  * [Config] Disable intel_idle for -virtual kernels
+-    - LP: #651370
+-  * [Config] enforcer -- ensure we never enable CONFIG_IMA
+-  * debian -- pass the correct flavour name when checking configs
+-  * [Config] enforcer -- ensure CONFIG_INTEL_IDLE is off for -virtual
+-  * [Config] ensure CONFIG_IPV6=y for powerpc
+-  * [Config] enforcer -- ensure CONFIG_IPV6=y
+-  * ubuntu: AUFS -- aufs2-base.patch aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- aufs2-standalone.patch aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- update to aufs2.1-36-UNRELEASED-20101103
+-  * ubuntu: AUFS -- re-enable
+-  * ubuntu: AUFS -- track changes to work queue initialisation
+-  * ubuntu: AUFS -- track changes to llseek in v2.6.37-rc1
+-  * SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-    - LP: #614008
+-  * SAUCE: drm -- stop early access to drm devices
+-
+-  [ Jeremy Kerr ]
+-
+-  * [Config] Build-in powermac ZILOG serial driver
+-    - LP: #673346
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: nx-emu: use upstream ASLR when possible
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Use correct be2iscsi module name in d-i/modules/scsi-modules
+-    - LP: #628776
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * i386: NX emulation
+-  * nx-emu: drop exec-shield sysctl, merge with disable_nx
+-  * nx-emu: standardize boottime message prefix
+-  * mmap randomization for executable mappings on 32-bit
+-  * exec-randomization: brk away from exec rand area
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 11 Nov 2010 23:46:37 +0000
+-
+-linux (2.6.37-2.10) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * reinstate armel config changes:
+-   * [Config] CONFIG_GPIO_PCH=n for armel FTBS
+-   * [Config] CONFIG_GPIO_VX855=n for armel FTBS
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Nov 2010 22:20:35 +0000
+-
+-linux (2.6.37-2.9) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * config -- fix genportsconfig
+-  * [Config] move powerpc over from ports to distro
+-  * bump master version number to match contained kernel
+-  * SAUCE: fix documentation strings for struct input_keymap_entry
+-  * usb: gadget: goku_udc: add registered flag bit
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Nov 2010 15:14:11 +0000
+-
+-linux (2.6.36-2.8) natty; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config]: fix changed CONFIG_SYSFS_DEPRECATED_V2 enforcement rules
+-  * [Config]: TWL4030_CORE=n for FTBS
+-  * [Config]: CONFIG_ATH6K_LEGACY=n for FTBS
+-  * [Config]: CONFIG_SOLO6X10=n for FTBS
+-  * [Config]: CONFIG_GPIO_PCH=n for armel FTBS
+-  * [Config]: CONFIG_GPIO_VX855=n for armel FTBS
+-  * [Config]: CONFIG_DRM_NOUVEAU=n for armel FTBS
+-  * [Config]: CONFIG_LINE6_USB=n for armel FTBS
+-  * [Config]: CONFIG_SENSORS_AK8975=n for armel FTBS
+-  * [Config]: CONFIG_I2C_I801=n for armel FTBS
+-  * UBUNTU: SAUCE: AppArmor: Fix unpack of network tables.
+-  * AppArmor: compatibility patch for v5 interface
+-  * AppArmor: compatibility patch for v5 network controll
+-  * Dropped (pre-stable): input: Support Clickpad devices in ClickZone mode
+-  * Dropped: UBUNTU: SAUCE: libata: Add ALPM power state accounting to the AHCI driver
+-  * Dropped: UBUNTU: SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-  * Dropped: hid: 3m: Convert to MT slots
+-  * Dropped: HID: magicmouse: don't allow hidinput to initialize the device
+-  * Dropped: HID: magicmouse: simplify touch data bit manipulation
+-  * Dropped: HID: magicmouse: simplify touch down logic
+-  * Dropped: HID: magicmouse: enable Magic Trackpad support
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: remove sysfs nodes
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: Setup input filtering manually
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: New ghost-filtering event logic
+-  * Dropped: UBUNTU: SAUCE: hid: ntrig: identify firmware version (wiggled)
+-  * Dropped: UBUNTU: (pre-stable): input: Support Clickpad devices in ClickZone mode
+-  * Dropped: UBUNTU: SAUCE: KMS: cache the EDID information of the LVDS
+-  * Dropped: UBUNTU: SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * Dropped: UBUNTU: SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-  * Dropped: UBUNTU: SAUCE: x86: implement cs-limit nx-emulation for ia32
+-  * Dropped: UBUNTU: SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
+-  * Dropped: UBUNTU: SAUCE: [um] Don't use nx_enabled under UML
+-  * Dropped: UBUNTU: SAUCE: x86: brk away from exec rand area
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased against 2.6.27-rc1
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 22 Oct 2010 19:35:05 -0600
+-
+-linux (2.6.36-1.7) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebased to v2.6.36 final
+-  * [Config] update configs following rebase to v2.6.36 final
+-  * [Config] update ports configs following rebase to v2.6.36 final
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to v2.6.36 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 21 Oct 2010 14:28:57 +0100
+-
+-linux (2.6.36-1.6) natty; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drop broadcom staging driver preview:
+-   * Revert "Staging: Add initial release of brcm80211 - Broadcom 802.11n
+-     wireless LAN driver."
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 20 Oct 2010 10:41:25 +0100
+-
+-linux (2.6.36-1.5) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.36-rc8
+-  * updateconfigs following rebase to v2.6.36-rc8
+-  * updateportsconfigs following rebase to v2.6.36-rc8
+-  * config -- simplify the kernelconfig interface
+-  * config -- add new config mode 'dumpconfigs'
+-
+-  [ Tim Gardner ]
+-
+-  * Simplify the use of CROSS_COMPILER
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * drop broadcom staging driver preview:
+-   * Revert "staging: brcm80211: Make compiling of brcm80211.ko and
+-     brcmfmac.ko mutually exclusive."
+-   * Revert "staging: brcm80211: Fix compile issue when BRCM80211_PCI is not
+-     set."
+-   * Revert "Staging: brcm80211: remove driver specific -W options"
+-   * Revert "Staging: brcm80211: clean up makefile cflag lines"
+-   * Revert "staging: brcm80211: add fullmac driver"
+-   * Revert "staging: brcm80211: use string native library"
+-   * Revert "staging: brcm80211: use native ctype library"
+-   * Revert "staging: brcm80211: fix remaining checkpatch errors."
+-   * Revert "staging: brcm80211: fix "ERROR: trailing whitespace.""
+-   * Revert "staging: brcm80211: fix "ERROR: spaces required around that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: spaces prohibited around that
+-     ':' ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required before that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required after that ...""
+-   * Revert "staging: brcm80211: fix "ERROR: space required after that close
+-     brace""
+-   * Revert "staging: brcm80211: fix "ERROR: space prohibited before
+-     ...close square bracket""
+-   * Revert "staging: brcm80211: fix "ERROR: space prohibited after that
+-     ...""
+-   * Revert "staging: brcm80211: fix "ERROR: need consistent spacing around
+-     '*'""
+-   * Revert "staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'"
+-   * Revert "staging: brcm80211: fix "ERROR: Macros w/ mult. statements ...
+-     do - while loop""
+-   * Revert "staging: brcm80211: fix "ERROR: Macros w/ complex values ...
+-     parenthesis""
+-   * Revert "staging: brcm80211: fix "ERROR: do not initialise statics to 0
+-     or NULL""
+-   * Revert "staging: brcm80211: fix "ERROR: do not initialise globals to 0
+-    or NULL""
+-   * Revert "staging: brcm80211: fix "ERROR: while should follow close brace
+-     '}'""
+-   * Revert "staging: brcm80211: fix "ERROR: that open brace { ... prev
+-     line""
+-   * Revert "staging: brcm80211: fix "ERROR: trailing statements should be
+-     on next line""
+-   * Revert "staging: brcm80211: fix "ERROR: do not use assignment in if
+-     condition""
+-   * Revert "staging: brcm80211: fix "ERROR: return is not a function,
+-     paren...""
+-   * Revert "staging: brcm80211: fix "ERROR: open brace '{' following
+-     function dec...""
+-   * Revert "staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo
+-     *bar"'"
+-   * Revert "staging: brcm80211: Fix URLs for firmware files."
+-   * Revert "staging: brcm80211: use '%pM' format to print MAC address"
+-   * Revert "staging: brcm80211: Add contact info to TODO list."
+-   * Revert "staging: brcm80211: Fix some initialisation failure paths"
+-  * Export dump_{write,seek} to binary loader modules
+-  * rebase to v2.6.36-rc8.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Oct 2010 18:58:11 +0100
+-
+-linux (2.6.36-0.4) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: perf: increase stack footprint to avoid stack-protector warning
+-    (fixes FTBS on powerpc)
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 13:16:16 +0100
+-
+-linux (2.6.36-0.3) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable CONFIG_SCSI_QLA_ISCSI to fix FTBS on powerpc
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 14 Oct 2010 03:01:30 +0100
+-
+-linux (2.6.36-0.2) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] updateportsconfigs following rebase to 2.6.36-rc7
+-    (fix FTBS on powerpc)
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 13 Oct 2010 23:25:12 +0100
+-
+-linux (2.6.36-0.1) natty; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * reduce disk usage during buildd builds
+-    - LP: #645653
+-  * [Config] enforcer -- ensure CONFIG_INIT_PASS_ALL_PARAMS is y
+-  * [Config] armel -- drop omap flavour
+-
+-  [ Tim Gardner ]
+-
+-  * Added dropped patch list
+-  * more dropped patches
+-  * [Config] Disable aufs, dmraid-4.5, ndis-wrapper
+-  * [Config] Add support for cross compiling armel
+-  * [Config] CONFIG_SCSI_QLA_ISCSI=n for armel
+-  * [Upstream] drivers/serial/mfd.c: Fix ARM compile error
+-  * [Config]: updateconfigs after adding brcm80211
+-  * staging: brcm80211: Fix Makefile syntax error
+-  * rebased to v2.6.36-rc7
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (upstream) IPS driver: don't toggle CPU turbo on unsupported CPUs
+-  * (upstream) IPS driver: verify BIOS provided limits
+-  * intel_ips: Print MCP limit exceeded values.
+-  * Staging: Add initial release of brcm80211 - Broadcom 802.11n wireless
+-    LAN driver.
+-  * staging: brcm80211: Fix some initialisation failure paths
+-  * staging: brcm80211: Add contact info to TODO list.
+-  * staging: brcm80211: use '%pM' format to print MAC address
+-  * staging: brcm80211: Fix URLs for firmware files.
+-  * staging: brcm80211: fix 'ERROR: "foo * bar" should be "foo *bar"'
+-  * staging: brcm80211: fix "ERROR: open brace '{' following function
+-    dec..."
+-  * staging: brcm80211: fix "ERROR: return is not a function, paren..."
+-  * staging: brcm80211: fix "ERROR: do not use assignment in if condition"
+-  * staging: brcm80211: fix "ERROR: trailing statements should be on next
+-    line"
+-  * staging: brcm80211: fix "ERROR: that open brace { ... prev line"
+-  * staging: brcm80211: fix "ERROR: while should follow close brace '}'"
+-  * staging: brcm80211: fix "ERROR: do not initialise globals to 0 or NULL"
+-  * staging: brcm80211: fix "ERROR: do not initialise statics to 0 or NULL"
+-  * staging: brcm80211: fix "ERROR: Macros w/ complex values ...
+-    parenthesis"
+-  * staging: brcm80211: fix "ERROR: Macros w/ mult. statements ... do -
+-    while loop"
+-  * staging: brcm80211: fix 'ERROR: "(foo*)" should be "(foo *)"'
+-  * staging: brcm80211: fix "ERROR: need consistent spacing around '*'"
+-  * staging: brcm80211: fix "ERROR: space prohibited after that ..."
+-  * staging: brcm80211: fix "ERROR: space prohibited before ...close square
+-    bracket"
+-  * staging: brcm80211: fix "ERROR: space required after that close brace"
+-  * staging: brcm80211: fix "ERROR: space required after that ..."
+-  * staging: brcm80211: fix "ERROR: space required before that ..."
+-  * staging: brcm80211: fix "ERROR: spaces prohibited around that ':' ..."
+-  * staging: brcm80211: fix "ERROR: spaces required around that ..."
+-  * staging: brcm80211: fix "ERROR: trailing whitespace."
+-  * staging: brcm80211: fix remaining checkpatch errors.
+-  * staging: brcm80211: use native ctype library
+-  * staging: brcm80211: use string native library
+-  * staging: brcm80211: add fullmac driver
+-  * Staging: brcm80211: clean up makefile cflag lines
+-  * Staging: brcm80211: remove driver specific -W options
+-  * staging: brcm80211: Fix compile issue when BRCM80211_PCI is not set.
+-  * staging: brcm80211: Make compiling of brcm80211.ko and brcmfmac.ko
+-    mutually exclusive.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 12 Oct 2010 16:00:27 +0100
+-
+-linux (2.6.35-22.33) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: Add support for Intellimouse Mode in ALPS touchpad on
+-    Dell E2 series Laptops"
+-    - LP: #641320
+-
+-  [ Brian Rogers ]
+-
+-  * SAUCE: ir-core: Fix null dereferences in the protocols sysfs interface
+-    - LP: #624701
+-
+-  [ Christopher James Halse Rogers ]
+-
+-  * SAUCE: Nouveau: Add quirk framework to disable acceleration
+-    - LP: #544088, #546393
+-  * SAUCE: Nouveau: Disable acceleration on MacBook Pros
+-    - LP: #546393
+-
+-  [ John Johansen ]
+-
+-  * Revert "SAUCE: AppArmor: allow newer tools to load policy on older
+-    kernels"
+-  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
+-    - LP: #639758
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: Adding vdd_sdi regulator supply to OMAP3EVM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: HDA: Enable internal speaker on Dell M101z
+-    - LP: #640254
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 17 Sep 2010 13:21:28 -0700
+-
+-linux (2.6.35-22.32) maverick; urgency=low
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: libata: Add ALPM power state accounting to the AHCI driver
+-
+-  [ David Henningsson ]
+-
+-  * SAUCE: ALSA: HDA: Enable internal mic on Dell E6410 and Dell E6510
+-    - LP: #605047, #628961
+-
+-  [ John Johansen ]
+-
+-  * [Upstream] AppArmor: Fix splitting an fqname into separate namespace
+-    and profile names
+-    - LP: #615947
+-  * [Upstream] AppArmor: Fix locking from removal of profile namespace
+-    - LP: #615947
+-  * SAUCE: AppArmor: allow newer tools to load policy on older kernels
+-    - LP: #639758
+-  * SAUCE: Improve Amazon EBS performance for EC2
+-    - LP: #634316
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: i915 KMS -- blacklist i855"
+-  * Revert "SAUCE: i915 KMS -- blacklist i845g"
+-  * Revert "SAUCE: i915 KMS -- blacklist i830"
+-  * Revert "SAUCE: i915 KMS -- support disabling KMS for known broken
+-    devices"
+-  * execute module-inclusion within a subshell
+-    - LP: #621175
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) bounce: call flush_dcache_page() after bounce_copy_vec()
+-    - LP: #633227
+-  * (pre-stable) drm/i915: don't enable self-refresh on Ironlake
+-    - LP: #629711
+-  * (pre-stable) mm: Move vma_stack_continue into mm.h
+-  * x86, hwmon: Fix unsafe smp_processor_id() in thermal_throttle_add_dev
+-    - LP: #601073
+-  * PM / Runtime: Make runtime_status attribute not debug-only (v. 2)
+-  * PM / Runtime: Add runtime PM statistics (v3)
+-  * compat: Make compat_alloc_user_space() incorporate the access_ok()
+-    - CVE-2010-3081
+-  * x86-64, compat: Test %rax for the syscall number, not %eax
+-    - CVE-2010-3301
+-  * x86-64, compat: Retruncate rax after ia32 syscall entry tracing
+-    - CVE-2010-3301
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 14 Sep 2010 08:46:49 -0700
+-
+-linux (2.6.35-21.31) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * bodge linux-libc-dev package version due to ti-omap4 error
+-  * linux-libc-dev -- ensure we can only build this on debian.master
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 13 Sep 2010 09:54:31 -0700
+-
+-linux (2.6.35-21.30) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: fbcon -- fix OOPs triggered by race prevention fixes
+-    - LP: #614008
+-
+-  [ Daniel Lezcano ]
+-
+-  * SAUCE: fix compilation warning when CONFIG_SECURITY is not set
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: Input: wacom - add fuzz parameters to features
+-  * SAUCE: Input: wacom - collect device quirks into single function
+-  * SAUCE: Input: wacom - add support for the Bamboo Touch trackpad
+-  * SAUCE: Input: wacom - add a quirk for low resolution Bamboo devices
+-  * SAUCE: hid: ntrig: Remove unused device ids
+-  * SAUCE: hid: ntrig: remove sysfs nodes
+-  * SAUCE: hid: ntrig: Correct logic for quirks
+-  * SAUCE: hid: ntrig: zero-initialize ntrig struct
+-  * SAUCE: hid: ntrig: Setup input filtering manually
+-  * SAUCE: hid: ntrig: New ghost-filtering event logic
+-
+-  [ Leann Ogasawara ]
+-
+-  * SAUCE: ndiswrapper: Initialize buffer index and check its value
+-    - LP: #613796
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Add support for Intellimouse Mode in ALPS touchpad on Dell E2
+-    series Laptops
+-    - LP: #632884
+-
+-  [ Ping Cheng ]
+-
+-  * SAUCE: Input: wacom - parse the Bamboo device family
+-
+-  [ Rafi Rubin ]
+-
+-  * SAUCE: hid: ntrig: identify firmware version (wiggled)
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NL80211_TESTMODE=n
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "input: mt: Add support for the Bamboo Touch trackpad"
+-  * e1000e: initial support for 82579 LOMs
+-  * e1000e: correct MAC-PHY interconnect register offset for 82579
+-  * (pre-stable) ALSA: hda - Add a new hp-laptop model for Conexant 5066,
+-    tested on HP G60
+-    - LP: #587388
+-  * DSS2: Don't power off a panel twice
+-    - LP: #588243
+-  * mmc: build fix: mmc_pm_notify is only available with CONFIG_PM=y
+-  * Input: i8042 - reset keyboard controller wehen resuming from S2R
+-    - LP: #86820
+-  * ALSA: hda - Fix beep frequency on IDT 92HD73xx and 92HD71Bxx codecs
+-    - LP: #414795
+-  * agp/intel: Support the extended physical addressing bits on
+-    Sandybridge.
+-    - LP: #632488
+-  * drm/i915,intel_agp: Add support for Sandybridge D0
+-    - LP: #632488
+-  * (pre-stable) intel_agp,i915: Add more sandybridge graphics device ids
+-    - LP: #632488
+-  * mmc: omap: fix for bus width which improves SD card's peformance.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 07 Sep 2010 09:58:52 -0700
+-
+-linux (2.6.35-20.29) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: i915 KMS -- support disabling KMS for known broken devices
+-    - LP: #563277
+-  * SAUCE: i915 KMS -- blacklist i830
+-    - LP: #542208, #563277
+-  * SAUCE: i915 KMS -- blacklist i845g
+-    - LP: #541492, #563277
+-  * SAUCE: i915 KMS -- blacklist i855
+-    - LP: #511001, #541511, #563277
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_SENSORS_PKGTEMP=m
+-    - LP: #601073
+-  * ARM: Temporarily disable module check for armel
+-  * rebase to v2.6.35.4
+-  * [Config] update configs following rebase to v2.6.35.4
+-
+-  [ Ricardo Salveti de Araujo ]
+-
+-  * [Config] Change CONFIG_LEDS_TRIGGER_HEARTBEAT from module to built-in
+-    in Omap
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added be2net, be2scsi to udebs
+-    - LP: #628776
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * x86, cpu: Package Level Thermal Control, Power Limit Notification
+-    definitions
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: pkgtemp hwmon driver
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: thermal throttling handler
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: power limit
+-    - LP: #601073
+-  * x86, hwmon: Package Level Thermal/Power: pkgtemp documentation
+-    - LP: #601073
+-  * hid: 3m: Adjust to sequential MT HID protocol
+-  * hid: 3m: Convert to MT slots
+-  * hid: 3m: Correct touchscreen emulation
+-  * hid: 3m: Adjust major / minor axes to scale
+-  * input: bcm5974: Adjust major / minor to scale
+-  * HID: magicmouse: don't allow hidinput to initialize the device
+-  * HID: magicmouse: simplify multitouch feature request
+-  * HID: magicmouse: simplify touch data bit manipulation
+-  * HID: magicmouse: simplify touch down logic
+-  * HID: magicmouse: remove timestamp logic
+-  * HID: magicmouse: enable Magic Trackpad support
+-  * HID: magicmouse: Adjust major / minor axes to scale
+-  * mmc: fix all hangs related to mmc/sd card insert/removal during
+-    suspend/resume
+-    - LP: #477106
+-  * drm/i915: fix VGA plane disable for Ironlake+
+-    - LP: #602281
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 30 Aug 2010 08:38:01 -0700
+-
+-linux (2.6.35-19.28) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No changes from 2.6.35-19.27.  Some armel udebs were accidentally deleted
+-    from the archive and a no-change rebuild was attempted.  However, the ABI
+-    did not get bumped and resulted in build failures for 2.6.35-19.27.  Fix
+-    up the ABI and re-upload.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sat, 28 Aug 2010 16:42:27 -0700
+-
+-linux (2.6.35-19.27) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * No changes from 2.6.35-19.26.  Some armel udebs were accidentally deleted
+-    from the archive.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 27 Aug 2010 08:58:35 -0700
+-
+-linux (2.6.35-19.26) maverick; urgency=low
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ARM: OMAP: Beagle: revision detection
+-  * ARM: OMAP: Beagle: only Cx boards use pin 23 for write protect
+-  * ARM: OMAP: Beagle: no gpio_wp pin connection on xM
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 26 Aug 2010 09:15:09 -0700
+-
+-linux (2.6.35-19.25) maverick; urgency=low
+-
+-  [ Jarod Wilson ]
+-
+-  * SAUCE: Bring in staging/lirc from 2.6.36
+-    - LP: #609234
+-  * SAUCE: Update ir-core to linuxtv/other which should be merged for
+-    2.6.36.
+-    - LP: #609234
+-  * SAUCE: Fix memleaks in imon and mceusb drivers
+-    - LP: #609234
+-  * SAUCE: Bring in streamzap support from linuxtv/other
+-    - LP: #609234
+-
+-  [ Mario Limonciello ]
+-
+-  * Remove ubuntu/lirc in favor of staging/lirc from 2.6.36
+-    - LP: #609234
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: ARM: adding i2c eeprom driver to read EDID
+-    - LP: #608279
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * intel_idle: disable module support
+-    - LP: #615265
+-  * (pre-stable) ALSA: hda - Ensure codec patch files are checked for the
+-    correct codec ID
+-  * (pre-stable) ALSA: hda - Rename iMic to Int Mic on Lenovo NB0763
+-    - LP: #605101
+-  * (pre-stable) ALSA: HDA: Use model=auto for LG R510
+-    - LP: #495134
+-  * (pre-stable) ALSA: HDA: Add Sony VAIO quirk for ALC269
+-    - LP: #519066
+-  * (pre-stable) ALSA: HDA: Fix front mic on Dell Precision M6500
+-    - LP: #519066
+-  * input: mt: Initialize slots to unused (rev2)
+-  * input: mt: Add support for the Bamboo Touch trackpad
+-  * hid: Add a hid quirk for input sync override
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 23 Aug 2010 12:42:52 -0700
+-
+-linux (2.6.35-18.24) maverick; urgency=low
+-
+-  [ Colin Watson ]
+-
+-  * Pass DEB_MAINT_PARAMS to hook scripts
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Add CONFIG_INPUT_UINPUT=y to config enforcer
+-    - LP: #584812
+-  * rebase to v2.6.35.3
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) dell-wmi: Add support for eject key on Dell Studio 1555
+-    - LP: #609234
+-  * can: add limit for nframes and clean up signed/unsigned variables
+-    - CVE-2010-2959
+-  * drm: Initialize ioctl struct when no user data is present
+-    - CVE-2010-2803
+-  * ARM: initial stack protector (-fstack-protector) support
+-  * ARM: stack protector: change the canary value per task
+-  * [ARM] implement arch_randomize_brk()
+-  * [ARM] add address randomization to mmap()
+-  * ARM: fix ASLR of PIE executables
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 22 Aug 2010 19:22:04 -0700
+-
+-linux (2.6.35-17.23) maverick; urgency=low
+-
+-  [ Jeremy Kerr ]
+-
+-  * [Config] build-in uinput module
+-    - LP: #584812
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS"
+-  * Revert "[Config] [FTBS] ia64: Temporarily disable gpiolib"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_MTD_NAND_DENALI"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_MFD_JANZ_CMODIO"
+-  * Revert "[Config] [FTBS] sparc: Temporarily disable
+-    CONFIG_INFINIBAND_QIB"
+-  * [Config] Enable INTEL_IPS
+-    - LP: #601057
+-  * Remove ia64 support
+-  * [Config] Update portsconfigs after removing ia64 support
+-  * Remove sparc support
+-  * [Config] Update portsconfigs after removing sparc support
+-
+-  [ Linus Torvalds ]
+-
+-  * (pre-stable) mm: fix page table unmap for stack guard page properly
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: (no-up) ARM: Resetting power_mode to its original value.
+-    - LP: #591941
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * timer: add on-stack deferrable timer interfaces
+-    - LP: #601057
+-  * x86 platform driver: intelligent power sharing driver
+-    - LP: #601057
+-  * IPS driver: add GPU busy and turbo checking
+-    - LP: #601057
+-  * X86: intel_ips, check for kzalloc properly
+-    - LP: #601057
+-  * ips driver: make it less chatty
+-    - LP: #601057
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 17 Aug 2010 09:38:08 -0700
+-
+-linux (2.6.35-16.22) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian -- more agressivly clean up after depmod on purge
+-    - LP: #618591
+-
+-  [ Henrik Rydberg ]
+-
+-  * SAUCE: hid: 3m: Simplify touchsreen emulation logic
+-
+-  [ Leann Ogasawara ]
+-
+-  * ubuntu: iscsitarget -- version 1.4.20.2
+-  * ubuntu: rtl8192se -- update to version 0017.0507.2010
+-  * rebase to v2.6.35.2
+-  * [Config] update configs following rebase to v2.6.35.2
+-  * [Config] update ports configs following rebase to v2.6.35.2
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Enable new firewire stack on powerpc
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * SAUCE: (drop after 2.6.35) ARM: Using gpmc function to init nand flash.
+-    - LP: #608266
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 12 Aug 2010 09:58:01 -0700
+-
+-linux (2.6.35-15.21) maverick; urgency=low
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_SND_USB_UA101=m for all architectures
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Input: introduce MT event slots
+-  * Input: document the MT event slot protocol
+-  * (pre-stable) sched: Revert nohz_ratelimit() for now
+-  * (pre-stable) drm/radeon/kms: add missing copy from user
+-    - LP: #606081
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35.1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 09 Aug 2010 09:24:04 -0700
+-
+-linux (2.6.35-14.20) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * update Vcs-Git to point to maverick repo
+-  * debian -- include the debian packaging in the -source package
+-    - LP: #608674
+-  * select debian source format 1.0
+-  * add support for building selected stages of kernel
+-    - LP: #603087
+-  * cleanup conditional dependancy handling
+-    - LP: #603087
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Handle missing NID 0x1b on ALC259 codec
+-    - LP: #582199, #586418, #588031
+-  * ALSA: hda - Handle pin NID 0x1a on ALC259/269
+-    - LP: #582199, #586418, #588031
+-  * sched: Revert nohz_ratelimit() for now
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 03 Aug 2010 08:46:47 -0700
+-
+-linux (2.6.35-14.19) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 01 Aug 2010 10:35:56 -0700
+-
+-linux (2.6.35-13.18) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: (no-up) Modularize vesafb -- fix initialisation
+-  * SAUCE: add tracing for user initiated readahead requests
+-  * SAUCE: vt -- maintain bootloader screen mode and content until vt
+-    switch
+-  * SAUCE: vt -- allow grub to request automatic vt_handoff
+-  * SAUCE: fbcon -- fix race between open and removal of framebuffers
+-  * SAUCE: drm -- stop early access to drm devices
+-
+-  [ Bryan Wu ]
+-
+-  * CONFIG: compile in OTG driver and Transceiver driver
+-    - LP: #566645
+-  * remove OTG modules from modules list file
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-27
+-    - LP: #581525, #599450
+-  * SAUCE: AppArmor: -- sync to AppArmor mainline 2010-07-29
+-  * SAUCE: AppArmor 2.4 compatibility patch
+-  * SAUCE: AppArmor: Allow dfa backward compatibility with broken userspace
+-  * SAUCE: fix pv-ops for legacy Xen
+-  * SAUCE: blkfront: default to sd devices
+-  * [Config] Build in drivers required for Xen pv-ops
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Upstream] i915: Use the correct mask to detect i830 aperture
+-    size."
+-
+-  [ Lee Jones ]
+-
+-  * SAUCE: ARM: OMAP: Add macros for comparing silicon revision
+-    - LP: #608095
+-  * SAUCE: OMAP: DSS2: check for both cpu type and revision, rather than
+-    just revision
+-    - LP: #608095
+-  * SAUCE: OMAP: DSS2: enable hsclk in dsi_pll_init for OMAP36XX
+-    - LP: #608095
+-  * SAUCE: ARM: OMAP: Beagle: support twl gpio differences on xM
+-    - LP: #608095
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * agp/intel: Use the correct mask to detect i830 aperture size.
+-    - LP: #597075
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Jul 2010 15:46:59 -0700
+-
+-linux (2.6.35-12.17) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc6
+-  * [Config] update configs following rebase to v2.6.35-rc6
+-  * [Config] update ports configs following rebase to v2.6.35-rc6
+-  * SAUCE: [FTBS] armel: define KEY_F10 and KEYF11
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 16:16:38 +0200
+-
+-linux (2.6.35-11.16) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Bump ABI for new compiler update 
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 23 Jul 2010 10:24:58 +0200
+-
+-linux (2.6.35-10.15) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: ensure vga16fb loads if no other driver claims the VGA
+-    device"
+-  * [Config] Enable CONFIG_M686=y
+-    - LP: #592495
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * tracing: Add alignment to syscall metadata declarations
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 20 Jul 2010 18:18:49 +0200
+-
+-linux (2.6.35-9.14) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- add BOM and automated update script
+-  * ubuntu: AUFS -- update to b37c575759dc4535ccc03241c584ad5fe69e3b25
+-
+-  [ John Johansen ]
+-
+-  * [Config] Enable DRBD as a module
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Yama: verify inode is symlink to avoid bind mounts
+-    - LP: #604407
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Disable CONFIG_DRM_VMWGFX (staging driver)
+-    - LP: #606139
+-  * [Config] ports: Disable CONFIG_DRM_VMWGFX (staging driver)
+-    - LP: #606139
+-  * [Config] Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
+-  * [Config] ports: Enable CONFIG_DEBUG_STRICT_USER_COPY_CHECKS=y
+-
+-  [ Lee Jones ]
+-
+-  * Stop ARM boards crashing when CUPS is loaded
+-    - LP: #601226
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * perf probe: Support tracing an entry of array
+-  * perf probe: Support static and global variables
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 16 Jul 2010 14:38:17 -0700
+-
+-linux (2.6.35-8.13) maverick; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Yama: check PTRACE using thread group leader
+-  * SAUCE: Yama: search for PTRACE exceptions via thread group leader
+-    - LP: #603716
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc5
+-  * [Config] update configs following rebase to v2.6.35-rc5
+-
+-  [ Nicolas Pitre ]
+-
+-  * SAUCE: make ndiswrapper available on X86 only
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added ums-cypress to udeb
+-    - LP: #576066
+-  * SAUCE: fix build error with CONFIG_BLK_DEV_INITRD=n
+-  * [Config] CONFIG_NDISWRAPPER=m across all configs
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * HID: magicmouse: report last touch up
+-  * rebase to 2.6.35-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Jul 2010 18:57:59 -0700
+-
+-linux (2.6.35-7.12) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] i915: Use the correct mask to detect i830 aperture size.
+-    - LP: #597075
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.35) drm/radeon/kms: add ioport register access
+-    (squashed)
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 08 Jul 2010 09:53:13 -0600
+-
+-linux (2.6.35-7.11) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_X86_MRST=n
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (drop after 2.6.35-rc5) writeback: remove writeback_inodes_wbc
+-  * (drop after 2.6.35-rc5) writeback: split writeback_inodes_wb
+-  * (drop after 2.6.35-rc5) writeback: simplify the write back thread queue
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 06 Jul 2010 18:39:08 -0600
+-
+-linux (2.6.35-7.10) maverick; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: security: create task_free security callback
+-  * SAUCE: Yama: add PTRACE exception tracking and interface
+-  * SAUCE: security: unconditionally chain to Yama LSM
+-  * Revert "SAUCE: ptrace: restrict ptrace scope to children"
+-  * Revert "SAUCE: fs: block hardlinks to non-accessible sources"
+-  * Revert "SAUCE: fs: block cross-uid sticky symlinks"
+-  * [Upstream] security: Yama LSM
+-  * [Config] Enable CONFIG_SECURITY_YAMA=y
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs/updateportsconfigs after rebase to 2.6.35-rc4
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to 2.6.35-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 01 Jul 2010 08:55:57 -0700
+-
+-linux (2.6.35-6.9) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] direct_splice_actor() should not use pos in sd
+-    - LP: #588861
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 28 Jun 2010 12:35:49 -0700
+-
+-linux (2.6.35-6.8) maverick; urgency=low
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * ARM: Adding regulator supply for vdds_sdi.
+-    - LP: #597904
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Sun, 27 Jun 2010 16:34:43 -0700
+-
+-linux (2.6.35-6.7) maverick; urgency=low
+-
+-  [ Alberto Milone ]
+-
+-  * [Upstream] Add support for the ATIF ACPI method to the radeon driver
+-
+-  [ Chase Douglas ]
+-
+-  * [Upstream] HID: magicmouse: scroll on entire surface, not just middle
+-    of mouse
+-  * [Upstream] HID: magicmouse: disable and add module param for scroll
+-    acceleration
+-  * [Upstream] HID: magicmouse: properly account for scroll movement in
+-    state
+-  * [Upstream] HID: magicmouse: add param for scroll speed
+-  * [Upstream] HID: magicmouse: enable horizontal scrolling
+-
+-  [ Henrik Rydberg ]
+-
+-  * [Upstream] Input: evdev - convert to dynamic event buffer
+-  * [Upstream] Input: evdev - use driver hint to compute size of event
+-    buffer
+-  * [Upstream] Input: bcm5974 - set the average number of events per MT
+-    event packet
+-  * [Upstream] Input: hid-input - use a larger event buffer for MT devices
+-  * [Upstream] Input: evdev - never leave the client buffer empty after
+-    write
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: -- mainline 2010-06-23
+-  * SAUCE: AppArmor 2.4 compatibility patch
+-  * SAUCE: fs: block hardlinks to non-accessible sources AppArmor portion
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] Enable CONFIG_INTR_REMAP=y
+-    - LP: #597091
+-  * [Config] Enable CONFIG_X86_X2APIC
+-    - LP: #597091
+-
+-  [ Mathieu J. Poirier ]
+-
+-  * [Config] ARM: Turning off CONFIG_CPU_IDLE on omap
+-    - LP: #594382
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 24 Jun 2010 12:19:48 -0700
+-
+-linux (2.6.35-5.6) maverick; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] update omap flavour description
+-
+-  [ Andy Whitcroft ]
+-
+-  * update to ubuntu-debian:508b7aa34b578c0d1e51bfb571f2bfb824dc65ac
+-    - LP: #570500, #576274
+-  * SAUCE: add option to hand off all kernel parameters to init
+-    - LP: #586386
+-  * [Config] enable passing all kernel command line to init
+-    - LP: #586386
+-  * [Config] disable CONFIG_VMI
+-    - LP: #537601
+-  * [Config] enable CONFIG_IPV6_SIT_6RD
+-    - LP: #591869
+-  * [Config] enable CONFIG_VMWARE_BALOON as module
+-    - LP: #592039
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: pm: Config option to disable handling of console during
+-    suspend/resume"
+-    - LP: #594885
+-  * [Config] Remove CONFIG_PM_DISABLE_CONSOLE
+-  * [Config] ports: enable passing all kernel command line to init
+-    - LP: #586386
+-  * [Config] Enable CONFIG_FB_VESA=y for x86
+-  * [Config] Add CONFIG_FRAMEBUFFER_CONSOLE=y to config enforcer
+-  * [Config] Add CONFIG_FB_VESA=y for x86 to config enforcer
+-  * [Config] Enable CONFIG_TASK_DELAY_ACCT=y
+-    - LP: #493156
+-
+-  [ Mathieu Poirier ]
+-
+-  * ARM: Adding MosChip MCS7830 to nic-usb
+-    - LP: #584920
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[Upstream] docbook: need xmldoclinks for all doc types"
+-  * docbook: need xmldoclinks for all doc types
+-  * perf probe: Add kernel source path option
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 17 Jun 2010 08:05:29 -0700
+-
+-linux (2.6.35-4.5) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "[Upstream] (evdev) Use driver hint to compute the evdev buffer
+-    size (rev2)"
+-  * Revert "[Upstream] (evdev) Convert to dynamic event buffer (rev4)"
+-  * Revert "[Upstream] (evdev) Use multi-reader buffer to save space
+-    (rev4)"
+-  * Revert "SAUCE: drivers: Remove some duplicate device entries in various
+-    modules"
+-  * [Upstream] USB: option: Remove duplicate AMOI_VENDOR_ID
+-  * [Upstream] Revert "USB: Adding support for HTC Smartphones to ipaq"
+-  * [Upstream] p54usb: Comment out duplicate Medion MD40900 device id
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_NFS_FSCACHE=y
+-    - LP: #440522
+-  * [Config] CONFIG_FSCACHE_STATS=y, CONFIG_FSCACHE_HISTOGRAM=y
+-    - LP: #440522
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 16 Jun 2010 08:43:07 -0700
+-
+-linux (2.6.35-3.4) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * debian -- ensure the version number is clean
+-
+-  [ Henrik Rydberg ]
+-
+-  * [Upstream] Introduce MT event slots (rev 5)
+-  * [Upstream] Document the MT event slot protocol (rev5)
+-  * [Upstream] (evdev) Use multi-reader buffer to save space (rev4)
+-  * [Upstream] (evdev) Convert to dynamic event buffer (rev4)
+-  * [Upstream] (evdev) Use driver hint to compute the evdev buffer size
+-    (rev2)
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: Add MODULE_ALIAS for Dell WMI module"
+-  * Revert "SAUCE: hostap: send events on data interface as well as master
+-    interface"
+-  * Revert "Fix webcam having USB ID 0ac8:303b"
+-  * Revert "SAUCE: toshiba_acpi -- pull in current -dev version of driver"
+-  * rebase to v2.6.35-rc3
+-
+-  [ Maxim Levitsky ]
+-
+-  * [Config] Enable new Smartmedia/xD translation layer
+-    - LP: #202490
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * net: fix deliver_no_wcard regression on loopback device
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 10 Jun 2010 16:15:22 -0700
+-
+-linux (2.6.35-2.3) maverick; urgency=low
+-
+-  [ Bryan Wu ]
+-
+-  * CONFIG: enforce -- make sure we disable CONFIG_LOCALVERSION_AUTO
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] armel: Enable CONFIG_BNX2=m
+-  * [Config] ports: Enable CONFIG_BNX2X=m
+-  * SAUCE: armel: define get_dma_ops to fix FTBS
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] net: Print num_rx_queues imbalance warning only when there
+-    are allocated queues
+-    - LP: #591416
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 09 Jun 2010 08:27:41 -0700
+-
+-linux (2.6.35-2.2) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] d-i: make armel configuration versatile flavour specific
+-    - LP: #588805
+-  * [Config] d-i: enable .udebs for omap flavour
+-    - LP: #588805
+-
+-  [ Kees Cook ]
+-
+-  * ptrace: limit scope to attach only (allow read)
+-    - LP: #589656
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc2
+-  * [Config] update configs following rebase to v2.6.35-rc2
+-  * [Config] update port configs following rebase to v2.6.35-rc2
+-
+-  [ Lee Jones ]
+-
+-  * Enable perf to be more helpful when perf_<version> does not exist.
+-    - LP: #570500
+-  * 'fdr editconfig' modification. Easily skip over unwanted menuconfigs.
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Update bnx2 udeb firmware files
+-    - LP: #589304
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Mon, 07 Jun 2010 09:45:04 -0700
+-
+-linux (2.6.35-1.1) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ubuntu: AUFS -- update to standalone 2.6.35-rcN as at 20100601
+-    - LP: #587888
+-  * ubuntu: AUFS -- track changes to the arguements to fop fsync()
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.35-rc1
+-  * [Config] update configs following rebase to v2.6.35-rc1
+-  * [Config] update port configs following rebase to v2.6.35-rc1
+-  * SAUCE: lirc: rename usb_buffer_alloc() and usb_buffer_free()
+-  * SAUCE: ndiswrapper: rename usb_buffer_alloc() and usb_buffer_free()
+-  * SAUCE: ndiswrapper: convert multicast list to list_head
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_GPIO_JANZ_TTL
+-  * [Config] [FTBS] ia64: Temporarily disable gpiolib
+-  * [Config] [FTBS] ia64: Temporarily disable CONFIG_CEPH_FS
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_INFINIBAND_QIB
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MFD_JANZ_CMODIO
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_MFD_JANZ_CMODIO
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_DT3155
+-  * [Config] [FTBS] sparc: Temporarily disable CONFIG_MTD_NAND_DENALI
+-  * [Config] [FTBS] armel: Temporarily disable bnx2
+-  * [Config] [FTBS] armel: Temporarily disable CONFIG_SERIAL_UARTLITE
+-  * SAUCE: [FTBS] armel: Don't include asm/agp.h for ttm
+-  * SAUCE: [FTBS] armel: include linux/dma-mapping.h
+-  * SAUCE: [FTBS] armel: replace omap_set_gpio_debounce with
+-    gpio_set_debounce
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * of/usb: fix build error due to of_node pointer move
+-  * n2_crypto: Fix build after of_device/of_platform_driver changes.
+-  * powerpc/fsl-booke: fix the case where we are not in the first page
+-  * powerpc/fsl-booke: Move the entry setup code into a seperate file
+-  * powerpc/kexec: Add support for FSL-BookE
+-  * greth: Fix build after OF device conversions.
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.35-rc1
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 04 Jun 2010 23:01:52 -0700
+-
+-linux (2.6.35-1.0) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Null entry.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 15:17:41 -0700
+-
+-linux (2.6.34-5.14) maverick; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added module inclusion support
+-  * [Config] Added virtual flavour module inclusion list and d-i package
+-    definitions
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 02 Jun 2010 12:58:14 -0700
+-
+-linux (2.6.34-5.13) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "ubuntu: AUFS -- aufs2 20091209"
+-  * Revert "ubuntu: AUFS -- export various core functions
+-    (aufs2-standalone.patch)"
+-  * Revert "ubuntu: AUFS -- export various core functions
+-    (aufs2-base.patch)"
+-  * ubuntu: AUFS -- aufs2 base patch for linux-2.6.34
+-    - LP: #587888
+-  * ubuntu: AUFS -- aufs2 standalone patch for linux-2.6.34
+-    - LP: #587888
+-  * ubuntu: AUFS -- update to standalone 2.6.34 as at 20100601
+-    - LP: #587888
+-  * [Config] AUFS -- enable aufs options
+-    - LP: #587888
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 01 Jun 2010 08:56:43 -0700
+-
+-linux (2.6.34-5.12) maverick; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * enforce -- ensure SYSFS compatibility is disabled
+-
+-  [ Chase Douglas ]
+-
+-  * build with libdw-dev for perf probe symbol support
+-  * maverick ftrace configuration changes
+-
+-  [ Kees Cook ]
+-
+-  * Revert "SAUCE: x86: brk away from exec rand area"
+-  * Revert "SAUCE: [um] Don't use nx_enabled under UML"
+-  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
+-  * SAUCE: x86: implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-  * SAUCE: x86: more tightly confine cs-limit nx-emulation to ia32 only
+-  * SAUCE: x86: brk away from exec rand area
+-    - LP: #452175
+-  * SAUCE: ptrace: restrict ptrace scope to children
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add new omap flavour to getabis
+-  * [Config] Enable CONFIG_FRAMEBUFFER_CONSOLE=y for all archs
+-    - LP: #585490
+-  * build/modules: Temorarily add ignore.modules
+-  * ubuntu: iscsitarget -- version 1.4.20.1
+-
+-  [ Loïc Minier ]
+-
+-  * SAUCE: [um] Don't use nx_enabled under UML
+-    - LP: #524849
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 28 May 2010 08:27:17 -0700
+-
+-linux (2.6.34-4.11) maverick; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * SAUCE: omap: remove calls to usb_nop_xceiv_register from board files
+-  * [Config] Add support for OMAP-mainline flavour
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: powerpc: fix compile error when ptrace.h is included from
+-    userspace
+-    - LP: #583733
+-
+-  [ Chase Douglas ]
+-
+-  * Revert "SAUCE: Don't register vga16fb framebuffer if other framebuffers
+-    are present"
+-  * Revert "SAUCE: Disable function tracing after hitting __schedule_bug"
+-  * Revert "SAUCE: drm/i915: don't change DRM configuration when releasing
+-    load detect pipe"
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: fs: block cross-uid sticky symlinks
+-  * SAUCE: fs: block hardlinks to non-accessible sources
+-
+-  [ Koen Kooi ]
+-
+-  * SAUCE: board-omap3-beagle: add DSS2 support
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "staging/go7007 -- disable"
+-  * Revert "[Config] staging/winbond -- disable"
+-  * Revert "Disable 4MB page tables for Atom, work around errata AAE44"
+-  * Revert "SAUCE: sync before umount to reduce time taken by ext4 umount"
+-  * Revert "SAUCE: Enable an e1000e Intel Corporation 82567 Gigabit
+-    controller"
+-  * Revert "SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT"
+-  * Revert "SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros"
+-  * Revert "SAUCE: input/mouse/alps: Do not call psmouse_reset() for alps"
+-  * Revert "SAUCE: r8169: disable TSO by default for RTL8111/8168B
+-    chipsets."
+-  * Revert "[Upstream] b43: Declare all possible firmware files."
+-  * Revert "add Breaks: against hardy lvm2"
+-  * Revert "SAUCE: Guest OS does not recognize a lun with non zero target
+-    id on Vmware ESX Server"
+-  * Revert "SAUCE: Catch nonsense keycodes and silently ignore"
+-  * [Config] Enable CONFIG_ECRYPT_FS=y for ports
+-  * [Config] Enable CONFIG_USB=y for armel and sparc
+-  * [Config] Enable CONFIG_SCSI=y for ia64 and sparc
+-  * [Config] Enable CONFIG_RFKILL=y for ports
+-  * [Config] Enable CONFIG_ATH9K_DEBUGFS=y
+-  * [Config] Enable CONFIG_IWMC3200TOP_DEBUGFS=y
+-  * [Config] Enable CONFIG_RCU_FAST_NO_HZ=y
+-  * [Config] Enable CONFIG_IWLWIFI_DEVICE_TRACING=y
+-  * [Config] Enable CONFIG_LIBERTAS_MESH=y
+-  * [Config] Enable CONFIG_MMC_RICOH_MMC=y
+-  * [Config] CONFIG_RT2800USB_UNKNOWN=y
+-  * [Config] Enable CONFIG_VGA_SWITCHEROO=y
+-  * [Config] Enable CONFIG_CEPH_FS=m
+-  * [Config] Enable CONFIG_CRYPTO_PCRYPT=m
+-  * [Config] Enable CONFIG_EEEPC_WMI=m
+-  * [Config] Enable CONFIG_RT2800PCI=m
+-  * [Config] Enable CONFIG_SCSI_HPSA=m
+-  * [Config] Enable CONFIG_VHOST_NET=m
+-  * [Config] Disable CONFIG_SND_HDA_INPUT_BEEP_MODE by default
+-    - LP: #582350
+-  * [Config] Disable CONFIG_SOUND_OSS* and CONFIG_SND_*OSS
+-    - LP: #579300
+-  * [Config] Enable CONFIG_PCIEASPM=y
+-    - LP: #333990
+-  * [Config] updateconfigs for OMAP flavour
+-
+-  [ Loïc Minier ]
+-
+-  * Enable perf tools on armel
+-
+-  [ Tim Gardner ]
+-
+-  * SAUCE: Updated ndiswrapper to 1.56
+-    - LP: #582555
+-  * [Config] Added virtual flavour
+-  * [Config] Remove support for sub-flavours
+-  * [Config] Removed amd64 preempt flavour
+-  * [Config] updateconfigs, updateportsconfigs after flavour munging
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 25 May 2010 09:34:55 -0700
+-
+-linux (2.6.34-3.10) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 18 May 2010 17:35:35 -0700
+-
+-linux (2.6.34-2.9) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] [FTBS] Disable comedi for armel
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 23:20:55 +0200
+-
+-linux (2.6.34-2.8) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Drop lpia
+-  * [Config] [FTBS] disable KVM
+-  * [Config] [FTBS] disable ipr for armel
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 13 May 2010 16:07:52 +0200
+-
+-linux (2.6.34-2.7) maverick; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Config] disable CONFIG_SCSI_IPR on powerpc
+-  * [Config] Remove 386 flavour per UDS discussion
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 12 May 2010 18:26:43 +0200
+-
+-linux (2.6.34-1.6) maverick; urgency=low
+-
+-  [ Chase Douglas ]
+-
+-  * enforce CONFIG_TMPFS_POSIX_ACL=y
+-    - LP: #575940
+-  * don't force module dependency checking
+-    - LP: #577029
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: mmap_min_addr check CAP_SYS_RAWIO only for write
+-    - LP: #568844
+-
+-  [ Leann Ogasawara ]
+-
+-  * Revert "SAUCE: ata: blacklist FUJITSU MHW2160BH PL"
+-  * rebase to v2.6.34-rc7
+-  * [Config] update configs following rebase to v2.6.34-rc7
+-  * [Config] update port configs following rebase to v2.6.34-rc7
+-  * Add btrfs to the udebs
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add atl1c to nic-modules udeb
+-    - LP: #557130
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc7
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 11 May 2010 11:29:08 +0200
+-
+-linux (2.6.34-1.5) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc6
+-  * [Config] update configs following rebase to v2.6.34-rc6
+-  * [Config] update port configs following rebase to v2.6.34-rc6
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc6
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Fri, 30 Apr 2010 15:54:05 +0100
+-
+-linux (2.6.34-1.4) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc5
+-  * [Config] update ports configs following rebase to v2.6.34-rc5
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc5
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Thu, 22 Apr 2010 15:36:12 -0700
+-
+-linux (2.6.34-1.3) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc4
+-  * [Config] update configs following rebase to v2.6.34-rc4
+-  * [Config] update port configs following rebase to v2.6.34-rc4
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc4
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc4
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 13 Apr 2010 18:33:44 -0700
+-
+-linux (2.6.34-1.2) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Temorarily disable building linux-doc
+-  * rebase to v2.6.34-rc3
+-  * [Config] update configs following rebase to v2.6.34-rc3
+-  * [Config] update port configs following rebase to v2.6.34-rc3
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc3
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 30 Mar 2010 16:55:44 -0700
+-
+-linux (2.6.34-1.1) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * rebase to v2.6.34-rc2
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.34-rc2
+-  * [Config] update port configs following rebase to v2.6.34-rc2
+-  * [Config] update configs following rebase to v2.6.34-rc2
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.34-rc2
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 24 Mar 2010 23:00:39 -0700
+-
+-linux (2.6.33-1.1) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * ubuntu: dm-raid4-5 -- update to compile with 2.6.33
+-  * ubuntu: lirc -- drop explicit include of linux/autoconf.h
+-  * ubuntu: lirc -- pass kfifo to kfifo_alloc and move spinlock
+-  * ubuntu: lirc -- rename kfifo_put and kfifo_get
+-  * ubuntu: iscsitarget -- rename daddr inet_sock field
+-  * rebased to v2.6.33
+-  * [Config] update configs following rebase to v2.6.33
+-  * [Config] update ports configs following rebase to v2.6.33
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.33
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Tue, 23 Mar 2010 03:55:46 -0700
+-
+-linux (2.6.33-0.0) UNRELEASED; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * Null entry.
+-
+- -- Leann Ogasawara <leann.ogasawara@canonical.com>  Wed, 17 Mar 2010 07:48:56 -0700
+-
+-linux (2.6.32-16.25) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * linux-tools -- move to Suggests: with explicit seeding
+-    - LP: #534635
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] CONFIG_HID=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * (pre-stable) sched: Fix SMT scheduler regression in
+-    find_busiest_queue()
+-  * KVM: introduce kvm_vcpu_on_spin
+-  * KVM: VMX: Add support for Pause-Loop Exiting
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 09 Mar 2010 14:13:51 +0000
+-
+-linux (2.6.32-16.24) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * armel -- perf userspace does not support arm
+-  * ia64 -- libelf-dev/binutils-dev to not provide necessary libraries
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 06 Mar 2010 11:42:12 +0000
+-
+-linux (2.6.32-16.23) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times -- move config
+-  * update to standards version 3.8.4.0
+-  * printenv -- expose all of the package selectors
+-  * source package -- cleanup source content control
+-  * doc package -- ensure we do build package content on buildd
+-  * lintian -- correct the address in the debian/copyright
+-  * lintian -- update debhelper package version dependancy
+-  * lintian -- fix ghostscript dependancy
+-  * lintian -- add required misc:Depends
+-  * lintian -- move our debhelper compat level to debian/compat
+-  * perf -- build the kernel carried tools
+-  * perf -- add linux-tools carrying the version switches and manuals
+-  * SAUCE: fix up Kconfig for staging drivers
+-  * [Config] enable NOUVEAU etc following drm backport
+-  * update DRM to mainline v2.6.33
+-  * [Config] Remove AppArmor config options that no longer exist (ports)
+-  * [Config] updateportsconfigs following drm update
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- update to mainline 2010-03-04
+-  * SAUCE: AppArmor: Reintroduce AppArmor 2.4 compatibility
+-  * SAUCE: AppArmor: replace strim with strstrip for 2.6.32 kernels
+-  * [Config] Remove AppArmor config options that no longer exist
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: rtl8192se -- version 2010-0115,0014
+-    - LP: #530275
+-  * [Config] added CONFIG_RTL8192SE module.
+-    - LP: #530275
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Added vmw_pvscsi to d-i/scsi-modules
+-    - LP: #531017
+-  * [Upstream] netfilter: xt_recent: Add an entry reaper
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "KVM: x86 emulator: Check CPL level during privilege instruction
+-    emulation"
+-  * Revert "KVM: x86 emulator: Fix popf emulation"
+-  * Revert "KVM: x86 emulator: Check IOPL level during io instruction
+-    emulation"
+-  * Revert "KVM: x86 emulator: Add Virtual-8086 mode of emulation"
+-  * Revert "KVM: fix memory access during x86 emulation."
+-  * Add vlan (8021.Q) module package for d-i.
+-  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
+-    Inspiron 700m
+-    - LP: #515246
+-  * [Upstream] docbook: need xmldoclinks for all doc types
+-  * x86: set_personality_ia32() misses force_personality32
+-  * lib: Introduce generic list_sort function
+-  * drm/nv50: Implement ctxprog/state generation.
+-  * drm/nv50: Remove redundant/incorrect ctxvals initialisation.
+-  * (pre-stable) drm/i915: blacklist lid status: Sony VGN-BX196VP, Dell
+-    Inspiron 700m
+-    - LP: #515246
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Mar 2010 15:40:38 +0000
+-
+-linux (2.6.32-15.22) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT"
+-  * Revert "SAUCE: PM report driver and device suspend/resume times."
+-  * [Config] set CONFIG_SR_REPORT_TIME_LIMIT
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 02 Mar 2010 01:35:37 +0000
+-
+-linux (2.6.32-15.21) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) drm/i915: Increase fb alignment to 64k"
+-  * Revert "[Config] lenovo-sl-laptop -- enable"
+-  * Revert "ubuntu: lenovo-sl-laptop -- git tip (b19a08f81f)"
+-  * armel -- cramfs module will no longer be built
+-  * d-i -- make all modules optional
+-  * rename the debug packages to match archive standard
+-    - LP: #527837
+-  * lenovo-sl-laptop is no longer built
+-
+-  [ Colin Ian King ]
+-
+-  * Disable 4MB page tables for Atom, work around errata AAE44
+-    - LP: #523112
+-
+-  [ Colin Watson ]
+-
+-  * ubuntu: dm-raid4-5: Depend on XOR_BLOCKS
+-  * ubuntu: fsam7400: Depend on CHECK_SIGNATURE
+-
+-  [ Jesse Barnes ]
+-
+-  * SAUCE: drm/i915: don't change DRM configuration when releasing load
+-    detect pipe
+-    - LP: #488328
+-
+-  [ Loïc Minier ]
+-
+-  * [Config] armel Update versatile initrd configs
+-    - LP: #524893
+-  * SAUCE: [um] Don't use nx_enabled under UML
+-    - LP: #524849
+-
+-  [ Manoj Iyer ]
+-
+-  * [Config] added new config option CONFIG_SR_REPORT_TIME_LIMIT
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: v3 - Add Dell Business Class Netbook LED driver
+-
+-  [ Rafael J. Wysocki ]
+-
+-  * SAUCE: PM report driver and device suspend/resume times.
+-
+-  [ Surbhi Palande ]
+-
+-  * Revert "[Upstream] e1000e: enhance frame fragment detection"
+-    - CVE-2009-4538
+-  * Revert "[Upstream] e1000: enhance frame fragment detection"
+-    - CVE-2009-4536
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CONFIG_LEDS_DELL_NETBOOKS=m
+-  * SAUCE: (pre-stable) netfilter: xt_recent: fix buffer overflow
+-  * SAUCE: (pre-stable) netfilter: xt_recent: fix false match
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "(pre-stable) eCryptfs: Add getattr function"
+-  * Fix potential crash with sys_move_pages
+-  * futex_lock_pi() key refcnt fix
+-  * futex: Handle user space corruption gracefully
+-  * futex: Handle futex value corruption gracefully
+-  * Fix race in tty_fasync() properly
+-  * hwmon: (w83781d) Request I/O ports individually for probing
+-  * hwmon: (lm78) Request I/O ports individually for probing
+-  * hwmon: (adt7462) Wrong ADT7462_VOLT_COUNT
+-  * ALSA: ctxfi - fix PTP address initialization
+-  * drm/i915: disable hotplug detect before Ironlake CRT detect
+-  * drm/i915: enable self-refresh on 965
+-  * drm/i915: Disable SR when more than one pipe is enabled
+-  * drm/i915: Fix DDC on some systems by clearing BIOS GMBUS setup.
+-  * drm/i915: Add HP nx9020/SamsungSX20S to ACPI LID quirk list
+-  * drm/i915: Fix the incorrect DMI string for Samsung SX20S laptop
+-  * drm/i915: Add MALATA PC-81005 to ACPI LID quirk list
+-  * usb: r8a66597-hcd: Flush the D-cache for the pipe-in transfer buffers.
+-  * i2c-tiny-usb: Fix on big-endian systems
+-  * drm/i915: handle FBC and self-refresh better
+-  * drm/i915: Increase fb alignment to 64k
+-  * drm/i915: Update write_domains on active list after flush.
+-  * regulator: Fix display of null constraints for regulators
+-  * ALSA: hda-intel: Avoid divide by zero crash
+-  * CPUFREQ: Fix use after free of struct powernow_k8_data
+-  * freeze_bdev: don't deactivate successfully frozen MS_RDONLY sb
+-  * cciss: Make cciss_seq_show handle holes in the h->drv[] array
+-  * ioat: fix infinite timeout checking in ioat2_quiesce
+-  * resource: add helpers for fetching rlimits
+-  * fs/exec.c: restrict initial stack space expansion to rlimit
+-  * cifs: fix length calculation for converted unicode readdir names
+-  * NFS: Fix a reference leak in nfs_wb_cancel_page()
+-  * NFS: Try to commit unstable writes in nfs_release_page()
+-  * NFSv4: Don't allow posix locking against servers that don't support it
+-  * NFSv4: Ensure that the NFSv4 locking can recover from stateid errors
+-  * NFS: Fix an Oops when truncating a file
+-  * NFS: Fix a umount race
+-  * NFS: Fix a bug in nfs_fscache_release_page()
+-  * NFS: Fix the mapping of the NFSERR_SERVERFAULT error
+-  * md: fix 'degraded' calculation when starting a reshape.
+-  * V4L/DVB: dvb-core: fix initialization of feeds list in demux filter
+-  * Export the symbol of getboottime and mmonotonic_to_bootbased
+-  * kvmclock: count total_sleep_time when updating guest clock
+-  * KVM: PIT: control word is write-only
+-  * tpm_infineon: fix suspend/resume handler for pnp_driver
+-  * amd64_edac: Do not falsely trigger kerneloops
+-  * netfilter: nf_conntrack: fix memory corruption with multiple namespaces
+-  * netfilter: nf_conntrack: per netns nf_conntrack_cachep
+-  * netfilter: nf_conntrack: restrict runtime expect hashsize modifications
+-  * netfilter: xtables: compat out of scope fix
+-  * netfilter: nf_conntrack: fix hash resizing with namespaces
+-  * drm/i915: remove full registers dump debug
+-  * drm/i915: add i915_lp_ring_sync helper
+-  * drm/i915: Don't wait interruptible for possible plane buffer flush
+-  * dasd: remove strings from s390dbf
+-  * crypto: padlock-sha - Add import/export support
+-  * wmi: Free the allocated acpi objects through wmi_get_event_data
+-  * dell-wmi, hp-wmi, msi-wmi: check wmi_get_event_data() return value
+-  * /dev/mem: introduce size_inside_page()
+-  * devmem: check vmalloc address on kmem read/write
+-  * devmem: fix kmem write bug on memory holes
+-  * SCSI: mptfusion : mptscsih_abort return value should be SUCCESS instead
+-    of value 0.
+-  * sh: Couple kernel and user write page perm bits for CONFIG_X2TLB
+-  * ALSA: hda - use WARN_ON_ONCE() for zero-division detection
+-  * dst: call cond_resched() in dst_gc_task()
+-  * ALSA: hda - Improved MacBook (Pro) 5,1 / 5,2 support
+-  * befs: fix leak
+-  * rtc-fm3130: add missing braces
+-  * Call flush_dcache_page after PIO data transfers in libata-sff.c
+-  * ahci: add Acer G725 to broken suspend list
+-  * pktgen: Fix freezing problem
+-  * x86/amd-iommu: Fix IOMMU-API initialization for iommu=pt
+-  * x86/amd-iommu: Fix deassignment of a device from the pt_domain
+-  * x86: Re-get cfg_new in case reuse/move irq_desc
+-  * Staging: fix rtl8187se compilation errors with mac80211
+-  * ALSA: usb-audio - Avoid Oops after disconnect
+-  * serial: 8250: add serial transmitter fully empty test
+-  * sysfs: sysfs_sd_setattr set iattrs unconditionally
+-  * class: Free the class private data in class_release
+-  * USB: usbfs: only copy the actual data received
+-  * USB: usbfs: properly clean up the as structure on error paths
+-  * rtl8187: Add new device ID
+-  * ACPI: Add NULL pointer check in acpi_bus_start
+-  * ACPI: fix High cpu temperature with 2.6.32
+-  * drm/radeon/kms: use udelay for short delays
+-  * NFS: Too many GETATTR and ACCESS calls after direct I/O
+-  * eCryptfs: Add getattr function
+-  * b43: Fix throughput regression
+-  * ath9k: Fix sequence numbers for PAE frames
+-  * mac80211: Fix probe request filtering in IBSS mode
+-  * iwlwifi: Fix to set correct ht configuration
+-  * dm stripe: avoid divide by zero with invalid stripe count
+-  * dm log: userspace fix overhead_size calcuations
+-  * Linux 2.6.32.9
+-  * sfc: Fix SFE4002 initialisation
+-  * sfc: Fix sign of efx_mcdi_poll_reboot() error in efx_mcdi_poll()
+-  * sfc: SFE4002/SFN4112F: Widen temperature and voltage tolerances
+-  * (pre-stable) HID: handle joysticks with large number of buttons
+-    - LP: #492056
+-  * (pre-stable) HID: extend mask for BUTTON usage page
+-    - LP: #492056
+-  * PM: Measure device suspend and resume times
+-  * e1000: enhance frame fragment detection
+-    - CVE-2009-4536
+-  * e1000e: enhance frame fragment detection
+-    - CVE-2009-4538
+-  * KVM: fix memory access during x86 emulation.
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Add Virtual-8086 mode of emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Check IOPL level during io instruction emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Fix popf emulation
+-    - CVE-2010-0306
+-  * KVM: x86 emulator: Check CPL level during privilege instruction
+-    emulation
+-    - CVE-2010-0306
+-  * Input: wacom - ensure the device is initialized properly upon resume
+-  * Input: wacom - add defines for packet lengths of various devices
+-  * Input: wacom - add support for new LCD tablets
+-    - LP: #516777
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 01 Mar 2010 22:56:28 +0000
+-
+-linux (2.6.32-14.20) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebuild following the GCC update to match compiler for out of tree modules
+-  * Revert "[Config] drbd -- enable"
+-  * Revert "ubuntu: drbd -- version 8.3.1"
+-  * SAUCE: khubd -- switch USB product/manufacturer/serial handling to RCU
+-    - LP: #510937
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 19 Feb 2010 18:47:18 +0000
+-
+-linux (2.6.32-14.19) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * ensure we build the source package contents when enabled
+-    - LP: #522308
+-  * [Config] enable CONFIG_X86_MCE_XEON75XX
+-  * SAUCE: AppArmor -- add linux/kref.h for struct kref
+-  * [Config] enable CONFIG_HID_ORTEK
+-  * enable udeb generation for arm versatile flavour
+-    - LP: #522515
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- update to mainline 2010-02-18
+-    - LP: #439560, #496110, #507069
+-
+-  [ Johnathon Harris ]
+-
+-  * SAUCE: HID: add support for Ortek WKB-2000
+-    - LP: #405390
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * tpm_tis: TPM_STS_DATA_EXPECT workaround
+-    - LP: #490487
+-  * x86, mce: Xeon75xx specific interface to get corrected memory error
+-    information
+-  * x86, mce: Rename cpu_specific_poll to mce_cpu_specific_poll
+-  * x86, mce: Make xeon75xx memory driver dependent on PCI
+-  * drm/edid: Unify detailed block parsing between base and extension
+-    blocks
+-    - LP: #500999
+-  * (pre-stable) eCryptfs: Add getattr function
+-    - LP: #390833
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 18 Feb 2010 19:22:02 +0000
+-
+-linux (2.6.32-13.18) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "enforcer -- make the enforcement configuration common"
+-  * Revert "(pre-stable) Input: ALPS - add interleaved protocol support
+-    (Dell E6x00 series)"
+-  * Revert "(pre-stable) driver-core: fix devtmpfs crash on s390"
+-  * Revert "(pre-stable) Driver-Core: devtmpfs - set root directory mode to
+-    0755"
+-  * Revert "SAUCE: Adds support for COMPAL JHL90 webcam"
+-  * Revert "SAUCE: fix kernel oops in VirtualBox during paravirt patching"
+-  * Revert "SAUCE: make fc transport removal of target configurable"
+-  * enforcer -- make the enforcement configuration common
+-  * getabis -- add preempt flavour to the list
+-  * [Config] enforce DEVTMPFS options
+-  * [Config] armel -- cleanup to-be builtin modules
+-  * [Config] cleanup ports configs
+-  * [Config] enable CRYPTO_GHASH_CLMUL_NI_INTEL
+-    - LP: #485536
+-  * add printdebian target to find branch target
+-  * distclean -- do not remove debian.env
+-  * [Config] generic-pae switch to M586TSC
+-    - LP: #519448
+-  * git-ubuntu-log -- commonise duplicated log handling
+-  * git-ubuntu-log -- tighten up Bug: NNNN matching
+-  * git-ubuntu-log -- sort the bug numbers
+-
+-  [ Chris Wilson ]
+-
+-  * (pre-stable) drm/i915: Increase fb alignment to 64k
+-    - LP: #404064
+-
+-  [ Eric Miao ]
+-
+-  * arm -- enable ubuntu/ directory
+-
+-  [ Huang Ying ]
+-
+-  * SAUCE: crypto: ghash - Add PCLMULQDQ accelerated implementation
+-  * SAUCE: crypto: ghash-intel - Fix building failure on x86_32
+-
+-  [ Loïc Minier ]
+-
+-  * [Config] cleanup preempt configuration
+-  * [Config] versatile: Fix video output
+-    - LP: #517594
+-  * [Config] armel DEFAULT_MMAP_MIN_ADDR=32768
+-  * [Config] Large update to armel/versatile
+-  * [Config] versatile: Add RTC support
+-  * [Config] armel: Enable NEON
+-  * [Config] versatile: Builtin MMC support
+-  * [Config] versatile Builtin SCSI controller
+-  * [Config] armel Disable dma_cache_sync callers
+-  * [Config] armel Disable asm/time.h users
+-  * [Config] armel Disable out of range udelay()
+-  * [Config] armel Disable flush_cache_range() users
+-  * [Config] armel -- Enable ubuntu/ drivers
+-
+-  [ Steve Conklin ]
+-
+-  * SAUCE: drm/i915: Add display hotplug event on Ironlake
+-  * SAUCE: drm/i915: Add ACPI OpRegion support for Ironlake
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "[Upstream]: oprofile/x86: add Xeon 7500 series support"
+-  * Revert "Revert "[Bluetooth] Eliminate checks for impossible conditions
+-    in IRQ handler""
+-  * clockevent: Don't remove broadcast device when cpu is dead
+-  * clockevents: Add missing include to pacify sparse
+-  * ACPI: don't cond_resched if irq is disabled
+-  * be2net: Add support for next generation of BladeEngine device.
+-  * be2net: Add the new PCI IDs to PCI_DEVICE_TABLE.
+-  * mpt2sas: New device SAS2208 support is added
+-  * ar9170: Add support for D-Link DWA 160 A2
+-  * powerpc/fsl: Add PCI device ids for new QoirQ chips
+-  * davinci: dm646x: Add support for 3.x silicon revision
+-  * Input: ALPS - add interleaved protocol support (Dell E6x00 series)
+-  * Driver-Core: devtmpfs - set root directory mode to 0755
+-  * driver-core: fix devtmpfs crash on s390
+-  * vfs: get_sb_single() - do not pass options twice
+-  * ALSA: hda - Add PCI IDs for Nvidia G2xx-series
+-  * V4L/DVB (13569): smsusb: add autodetection support for five additional
+-    Hauppauge USB IDs
+-  * USB: mos7840: add device IDs for B&B electronics devices
+-  * USB: ftdi_sio: add USB device ID's for B&B Electronics line
+-  * V4L/DVB (13168): Add support for Asus Europa Hybrid DVB-T card (SAA7134
+-    SubVendor ID: 0x1043 Device ID: 0x4847)
+-  * iTCO_wdt: Add support for Intel Ibex Peak
+-  * atl1c:use common_task instead of reset_task and link_chg_task
+-  * atl1e:disable NETIF_F_TSO6 for hardware limit
+-  * V4L/DVB (13680a): DocBook/media: copy images after building HTML
+-  * V4L/DVB (13680b): DocBook/media: create links for included sources
+-  * netfilter: xtables: fix conntrack match v1 ipt-save output
+-  * partitions: read whole sector with EFI GPT header
+-  * partitions: use sector size for EFI GPT
+-  * ALSA: ice1724 - Patch for suspend/resume for ESI Juli@
+-  * sched: Fix isolcpus boot option
+-  * sched: Fix missing sched tunable recalculation on cpu add/remove
+-  * nohz: Prevent clocksource wrapping during idle
+-  * nfsd: Fix sort_pacl in fs/nfsd/nf4acl.c to actually sort groups
+-  * timers, init: Limit the number of per cpu calibration bootup messages
+-  * PCI: Always set prefetchable base/limit upper32 registers
+-  * iscsi class: modify handling of replacement timeout
+-  * NFS: Revert default r/wsize behavior
+-  * HID: fixup quirk for NCR devices
+-  * scsi_devinfo: update Hitachi entries (v2)
+-  * scsi_dh: create sysfs file, dh_state for all SCSI disk devices
+-  * scsi_transport_fc: remove invalid BUG_ON
+-  * lpfc: fix hang on SGI ia64 platform
+-  * libfc: fix typo in retry check on received PRLI
+-  * libfc: fix ddp in fc_fcp for 0 xid
+-  * fcoe: remove redundant checking of netdev->netdev_ops
+-  * libfc: Fix wrong scsi return status under FC_DATA_UNDRUN
+-  * libfc: lport: fix minor documentation errors
+-  * libfc: don't WARN_ON in lport_timeout for RESET state
+-  * fcoe: initialize return value in fcoe_destroy
+-  * libfc: Fix frags in frame exceeding SKB_MAX_FRAGS in fc_fcp_send_data
+-  * libfc: fix memory corruption caused by double frees and bad error
+-    handling
+-  * libfc: fix free of fc_rport_priv with timer pending
+-  * libfc: remote port gets stuck in restart state without really
+-    restarting
+-  * fcoe, libfc: fix an libfc issue with queue ramp down in libfc
+-  * fcoe: Fix checking san mac address
+-  * fcoe: Fix getting san mac for VLAN interface
+-  * qlge: Remove explicit setting of PCI Dev CTL reg.
+-  * qlge: Set PCIE max read request size.
+-  * qlge: Don't fail open when port is not initialized.
+-  * qlge: Add handler for DCBX firmware event.
+-  * qlge: Bonding fix for mode 6.
+-  * PCI: AER: fix aer inject result in kernel oops
+-  * DMI: allow omitting ident strings in DMI tables
+-  * Input: i8042 - remove identification strings from DMI tables
+-  * Input: i8042 - add Gigabyte M1022M to the noloop list
+-  * Input: i8042 - add Dritek quirk for Acer Aspire 5610.
+-  * ALSA: hda - select IbexPeak handler for Calpella
+-  * ALSA: hda - Fix quirk for Maxdata obook4-1
+-  * ALSA: hda - Add missing Line-Out and PCM switches as slave
+-  * iTCO_wdt.c - cleanup chipset documentation
+-  * iTCO_wdt: add PCI ID for the Intel EP80579 (Tolapai) SoC
+-  * iTCO_wdt: Add Intel Cougar Point and PCH DeviceIDs
+-  * ahci: disable SNotification capability for ich8
+-  * ata_piix: fix MWDMA handling on PIIX3
+-  * md: fix small irregularity with start_ro module parameter
+-  * V4L/DVB (13826): uvcvideo: Fix controls blacklisting
+-  * cio: fix double free in case of probe failure
+-  * cio: dont panic in non-fatal conditions
+-  * netiucv: displayed TX bytes value much too high
+-  * ipc ns: fix memory leak (idr)
+-  * ALSA: hda - Fix HP T5735 automute
+-  * hwmon: (fschmd) Fix a memleak on multiple opens of /dev/watchdog
+-  * UBI: fix memory leak in update path
+-  * UBI: initialise update marker
+-  * ASoC: fix a memory-leak in wm8903
+-  * mac80211: check that ieee80211_set_power_mgmt only handles STA
+-    interfaces.
+-  * cfg80211: fix channel setting for wext
+-  * KVM: S390: fix potential array overrun in intercept handling
+-  * KVM: only allow one gsi per fd
+-  * KVM: Fix race between APIC TMR and IRR
+-  * KVM: MMU: bail out pagewalk on kvm_read_guest error
+-  * KVM: x86: Fix host_mapping_level()
+-  * KVM: x86: Fix probable memory leak of vcpu->arch.mce_banks
+-  * KVM: x86: Fix leak of free lapic date in kvm_arch_vcpu_init()
+-  * KVM: fix lock imbalance in kvm_*_irq_source_id()
+-  * KVM: only clear irq_source_id if irqchip is present
+-  * IPoIB: Clear ipoib_neigh.dgid in ipoib_neigh_alloc()
+-  * x86: Reenable TSC sync check at boot, even with NONSTOP_TSC
+-  * ACPI: enable C2 and Turbo-mode on Nehalem notebooks on A/C
+-    - LP: #516325
+-  * iwlwifi: Fix throughput stall issue in HT mode for 5000
+-  * fnctl: f_modown should call write_lock_irqsave/restore
+-  * x86, msr/cpuid: Pass the number of minors when unregistering MSR and
+-    CPUID drivers.
+-  * Linux 2.6.32.7
+-  * scsi_lib: Fix bug in completion of bidi commands
+-  * mptsas: Fix issue with chain pools allocation on katmai
+-  * mm: add new 'read_cache_page_gfp()' helper function
+-  * drm/i915: Selectively enable self-reclaim
+-  * firewire: ohci: fix crashes with TSB43AB23 on 64bit systems
+-  * S390: fix single stepped svcs with TRACE_IRQFLAGS=y
+-  * x86: Set hotpluggable nodes in nodes_possible_map
+-  * x86: Remove "x86 CPU features in debugfs" (CONFIG_X86_CPU_DEBUG)
+-  * libata: retry FS IOs even if it has failed with AC_ERR_INVALID
+-  * zcrypt: Do not remove coprocessor for error 8/72
+-  * dasd: fix possible NULL pointer errors
+-  * ACPI: Add a generic API for _OSC -v2
+-  * ACPI: Add platform-wide _OSC support.
+-  * ACPI: fix OSC regression that caused aer and pciehp not to load
+-  * ACPI: Advertise to BIOS in _OSC: _OST on _PPC changes
+-  * UBI: fix volume creation input checking
+-  * e1000/e1000e: don't use small hardware rx buffers
+-  * drm/i915: Reload hangcheck timer too for Ironlake
+-  * Fix a leak in affs_fill_super()
+-  * Fix failure exits in bfs_fill_super()
+-  * fix oops in fs/9p late mount failure
+-  * fix leak in romfs_fill_super()
+-  * Fix remount races with symlink handling in affs
+-  * fix affs parse_options()
+-  * Fix failure exit in ipathfs
+-  * mm: fix migratetype bug which slowed swapping
+-  * FDPIC: Respect PT_GNU_STACK exec protection markings when creating
+-    NOMMU stack
+-  * Split 'flush_old_exec' into two functions
+-  * sparc: TIF_ABI_PENDING bit removal
+-  * x86: get rid of the insane TIF_ABI_PENDING bit
+-  * Input: winbond-cir - remove dmesg spam
+-  * x86: Disable HPET MSI on ATI SB700/SB800
+-  * iwlwifi: set default aggregation frame count limit to 31
+-  * drm/i915: only enable hotplug for detected outputs
+-  * firewire: core: add_descriptor size check
+-  * SECURITY: selinux, fix update_rlimit_cpu parameter
+-  * regulator: Specify REGULATOR_CHANGE_STATUS for WM835x LED constraints
+-  * x86: Add Dell OptiPlex 760 reboot quirk
+-    - LP: #488319
+-  * x86: Add quirk for Intel DG45FC board to avoid low memory corruption
+-  * x86/amd-iommu: Fix possible integer overflow
+-  * clocksource: fix compilation if no GENERIC_TIME
+-  * tcp: update the netstamp_needed counter when cloning sockets
+-  * sky2: Fix oops in sky2_xmit_frame() after TX timeout
+-  * net: restore ip source validation
+-  * af_packet: Don't use skb after dev_queue_xmit()
+-  * ax25: netrom: rose: Fix timer oopses
+-  * KVM: allow userspace to adjust kvmclock offset
+-  * oprofile/x86: add Xeon 7500 series support
+-  * oprofile/x86: fix crash when profiling more than 28 events
+-  * libata: retry link resume if necessary
+-  * mm: percpu-vmap fix RCU list walking
+-  * mm: purge fragmented percpu vmap blocks
+-  * block: fix bio_add_page for non trivial merge_bvec_fn case
+-  * Fix 'flush_old_exec()/setup_new_exec()' split
+-  * random: drop weird m_time/a_time manipulation
+-  * random: Remove unused inode variable
+-  * block: fix bugs in bio-integrity mempool usage
+-  * usb: r8a66597-hdc disable interrupts fix
+-  * connector: Delete buggy notification code.
+-  * be2net: Bug fix to support newer generation of BE ASIC
+-  * be2net: Fix memset() arg ordering.
+-  * mm: flush dcache before writing into page to avoid alias
+-  * mac80211: fix NULL pointer dereference when ftrace is enabled
+-  * imxfb: correct location of callbacks in suspend and resume
+-  * mx3fb: some debug and initialisation fixes
+-  * starfire: clean up properly if firmware loading fails
+-  * kernel/cred.c: use kmem_cache_free
+-  * uartlite: fix crash when using as console
+-  * pktcdvd: removing device does not remove its sysfs dir
+-  * ath9k: fix eeprom INI values override for 2GHz-only cards
+-  * ath9k: fix beacon slot/buffer leak
+-  * powerpc: TIF_ABI_PENDING bit removal
+-  * NET: fix oops at bootime in sysctl code
+-  * Linux 2.6.32.8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 10 Feb 2010 18:56:52 +0000
+-
+-linux (2.6.32-12.17) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * restore linux-image prefix -- master
+-  * enforce -- we require SELINUX enabled -- master
+-  * enforce -- ensure APPARMOR is our default LSM -- master
+-  * make doc package completely optional -- master
+-  * make source package completely optional -- master
+-  * make linux-libc-dev completly optional -- master
+-  * convert package disable to a deps list -- master
+-  * allow common headers to switch from indep to arch -- master
+-  * convert binary package disable to a deps list -- master
+-  * add configuration option for a full source build tree -- master
+-  * add support for uImage kernels in package control scripts
+-  * getabis -- cleanup and parameterise repository list -- master
+-  * getabis -- move configuration to etc/getabi -- master
+-  * kernelconfig -- move configuration to etc -- master
+-  * rules -- make debian/debian.env master for branch name
+-  * set the current branch name -- master
+-  * pull back common debian.master files into debian -- master
+-  * enforcer -- make the enforcement configuration common
+-  * insert-changes -- correctly link to debian/rules in DROOT
+-
+-  [ Colin Watson ]
+-
+-  * future-proof ddeb handling against buildd changes
+-
+-  [ Eric Miao ]
+-
+-  * SAUCE: Make CONFIG_{OMNIBOOK, AVERATEC_5100P, PACKARDBELL_E5} depend on
+-    X86
+-
+-  [ Loïc Minier ]
+-
+-  * Add modules.builtin.bin to prerm rm list
+-    - LP: #516584
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Implement the amd64 preempt flavour
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * syslog: distinguish between /proc/kmsg and syscalls
+-    - LP: #515623
+-  * sfc: Fix polling for slow MCDI operations
+-  * sfc: Fix conditions for MDIO self-test
+-  * sfc: QT202x: Remove unreliable MMD check at initialisation
+-  * sfc: Add workspace for GMAC bug workaround to MCDI MAC_STATS buffer
+-  * sfc: Use fixed-size buffers for MCDI NVRAM requests
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Feb 2010 07:09:31 +0000
+-
+-linux (2.6.32-12.16) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: acpi battery -- delay first lookup of the battery until
+-    first use"
+-  * SAUCE: acpi battery -- move first lookup asynchronous
+-    - LP: #507211
+-  * [Config] update configs to cleanup generic configs
+-  * [Config] disable CONFIG_X86_CPU_DEBUG for amd64
+-  * [Config] enable USER_NS
+-    - LP: #480739, #509808
+-
+-  [ Heiko Carstens ]
+-
+-  * (pre-stable) driver-core: fix devtmpfs crash on s390
+-    - LP: #512370
+-
+-  [ John Johansen ]
+-
+-  * [Config] for server and virtual flavours make CONFIG_SCSI_SYM53C8XX_2=y
+-    - LP: #494565
+-  * [Config] VIRTIO=y for server/virtual flavours
+-    - LP: #494565
+-
+-  [ Kay Sievers ]
+-
+-  * (pre-stable) Driver-Core: devtmpfs - set root directory mode to 0755
+-    - LP: #512370
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: x86: brk away from exec rand area
+-    - LP: #452175
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] e1000: enhance frame fragment detection
+-    - CVE-2009-4536
+-  * [Upstream] e1000e: enhance frame fragment detection
+-    - CVE-2009-4538
+-
+-  [ Sebastian Kapfer ]
+-
+-  * (pre-stable) Input: ALPS - add interleaved protocol support (Dell E6x00
+-    series)
+-    - LP: #296610
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * inotify: do not reuse watch descriptors
+-    - LP: #485556
+-  * inotify: only warn once for inotify problems
+-  * revert "drivers/video/s3c-fb.c: fix clock setting for Samsung SoC
+-    Framebuffer"
+-  * memcg: ensure list is empty at rmdir
+-  * drm/i915: remove loop in Ironlake interrupt handler
+-  * block: Fix incorrect reporting of partition alignment
+-  * x86, mce: Thermal monitoring depends on APIC being enabled
+-  * futexes: Remove rw parameter from get_futex_key()
+-  * page allocator: update NR_FREE_PAGES only when necessary
+-  * x86, apic: use physical mode for IBM summit platforms
+-  * edac: i5000_edac critical fix panic out of bounds
+-  * x86: SGI UV: Fix mapping of MMIO registers
+-  * mfd: WM835x GPIO direction register is not locked
+-  * mfd: Correct WM835x ISINK ramp time defines
+-  * ALSA: hda - Fix missing capture mixer for ALC861/660 codecs
+-  * V4L/DVB (13868): gspca - sn9c20x: Fix test of unsigned.
+-  * reiserfs: truncate blocks not used by a write
+-  * HID: add device IDs for new model of Apple Wireless Keyboard
+-  * PCI/cardbus: Add a fixup hook and fix powerpc
+-  * Input: pmouse - move Sentelic probe down the list
+-  * asus-laptop: add Lenovo SL hotkey support
+-  * sched: Fix cpu_clock() in NMIs, on !CONFIG_HAVE_UNSTABLE_SCHED_CLOCK
+-  * sparc64: Fix NMI programming when perf events are active.
+-  * sparc64: Fix Niagara2 perf event handling.
+-  * i2c: Do not use device name after device_unregister
+-  * i2c/pca: Don't use *_interruptible
+-  * serial/8250_pnp: add a new Fujitsu Wacom Tablet PC device
+-  * sched: Fix task priority bug
+-  * vfs: Fix vmtruncate() regression
+-  * Linux 2.6.32.5
+-  * x86, msr/cpuid: Register enough minors for the MSR and CPUID drivers
+-  * V4L/DVB (13900): gspca - sunplus: Fix bridge exchanges.
+-  * Staging: asus_oled: fix oops in 2.6.32.2
+-  * Staging: hv: fix smp problems in the hyperv core code
+-  * tty: fix race in tty_fasync
+-  * ecryptfs: use after free
+-  * ecryptfs: initialize private persistent file before dereferencing
+-    pointer
+-  * nozomi: quick fix for the close/close bug
+-  * serial: 8250_pnp: use wildcard for serial Wacom tablets
+-  * usb: serial: fix memory leak in generic driver
+-  * USB: fix bitmask merge error
+-  * USB: Don't use GFP_KERNEL while we cannot reset a storage device
+-  * USB: EHCI: fix handling of unusual interrupt intervals
+-  * USB: EHCI & UHCI: fix race between root-hub suspend and port resume
+-  * USB: add missing delay during remote wakeup
+-  * USB: add speed values for USB 3.0 and wireless controllers
+-  * ACPI: EC: Accelerate query execution
+-  * ACPI: EC: Add wait for irq storm
+-  * SCSI: enclosure: fix oops while iterating enclosure_status array
+-  * drm/i915: Read the response after issuing DDC bus switch command
+-  * drm/i915: try another possible DDC bus for the SDVO device with
+-    multiple outputs
+-  * block: bdev_stack_limits wrapper
+-  * DM: Fix device mapper topology stacking
+-  * x86/PCI/PAT: return EINVAL for pci mmap WC request for !pat_enabled
+-  * USB: fix usbstorage for 2770:915d delivers no FAT
+-  * vmalloc: remove BUG_ON due to racy counting of VM_LAZY_FREE
+-  * perf timechart: Use tid not pid for COMM change
+-  * perf events: Dont report side-band events on each cpu for
+-    per-task-per-cpu events
+-  * perf: Honour event state for aux stream data
+-  * Linux 2.6.32.6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 27 Jan 2010 16:40:23 +0000
+-
+-linux (2.6.32-11.15) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) drm/radeon/kms: fix crtc vblank update for r600"
+-  * Revert "(pre-stable) sched: Fix balance vs hotplug race"
+-  * Revert "[Upstream] acerhdf: Limit modalias matching to supported
+-    boards"
+-  * Revert "[Upstream] mmc: prevent dangling block device from accessing
+-    stale queues"
+-  * Revert "SAUCE: Fix nx_enable reporting"
+-  * Revert "SAUCE: [x86] fix report of cs-limit nx-emulation"
+-  * Revert "SAUCE: [x86] implement cs-limit nx-emulation for ia32"
+-  * SAUCE: i915 -- disable powersave by default
+-    - LP: #492392
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-  * SAUCE: [x86] fix report of cs-limit nx-emulation
+-    - LP: #454285
+-  * SAUCE: Fix nx_enable reporting
+-    - LP: #454285
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] b43: Declare all possible firmware files.
+-    - LP: #488636
+-  * [Config] updateconfigs after adding pvscsi
+-    - LP: #497156
+-  * [Config] CONFIG_BT=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "x86: Side-step lguest problem by only building cmpxchg8b_emu
+-    for pre-Pentium"
+-  * SCSI: ipr: fix EEH recovery
+-  * SCSI: qla2xxx: dpc thread can execute before scsi host has been added
+-  * SCSI: st: fix mdata->page_order handling
+-  * SCSI: fc class: fix fc_transport_init error handling
+-  * sched: Fix task_hot() test order
+-  * x86, cpuid: Add "volatile" to asm in native_cpuid()
+-  * sched: Select_task_rq_fair() must honour SD_LOAD_BALANCE
+-  * clockevents: Prevent clockevent_devices list corruption on cpu hotplug
+-  * pata_hpt3x2n: fix clock turnaround
+-  * pata_cmd64x: fix overclocking of UDMA0-2 modes
+-  * ASoC: wm8974: fix a wrong bit definition
+-  * sound: sgio2audio/pdaudiocf/usb-audio: initialize PCM buffer
+-  * ALSA: hda - Fix missing capsrc_nids for ALC88x
+-  * acerhdf: limit modalias matching to supported
+-    - LP: #435958
+-  * ACPI: EC: Fix MSI DMI detection
+-  * ACPI: Use the return result of ACPI lid notifier chain correctly
+-  * powerpc: Handle VSX alignment faults correctly in little-endian mode
+-  * ASoC: Do not write to invalid registers on the wm9712.
+-  * drm/radeon: fix build on 64-bit with some compilers.
+-  * USB: emi62: fix crash when trying to load EMI 6|2 firmware
+-  * USB: option: support hi speed for modem Haier CE100
+-  * USB: Fix a bug on appledisplay.c regarding signedness
+-  * USB: musb: gadget_ep0: avoid SetupEnd interrupt
+-  * Bluetooth: Prevent ill-timed autosuspend in USB driver
+-  * USB: rename usb_configure_device
+-  * USB: fix bugs in usb_(de)authorize_device
+-  * drivers/net/usb: Correct code taking the size of a pointer
+-  * x86: SGI UV: Fix writes to led registers on remote uv hubs
+-  * md: Fix unfortunate interaction with evms
+-  * dma: at_hdmac: correct incompatible type for argument 1 of
+-    'spin_lock_bh'
+-  * dma-debug: Do not add notifier when dma debugging is disabled.
+-  * dma-debug: Fix bug causing build warning
+-  * cifs: NULL out tcon, pSesInfo, and srvTcp pointers when chasing DFS
+-    referrals
+-  * x86/amd-iommu: Fix initialization failure panic
+-  * ioat3: fix p-disabled q-continuation
+-  * ioat2,3: put channel hardware in known state at init
+-  * KVM: MMU: remove prefault from invlpg handler
+-  * KVM: LAPIC: make sure IRR bitmap is scanned after vm load
+-  * Libertas: fix buffer overflow in lbs_get_essid()
+-  * iwmc3200wifi: fix array out-of-boundary access
+-  * mac80211: fix propagation of failed hardware reconfigurations
+-  * mac80211: fix WMM AP settings application
+-  * mac80211: Fix IBSS merge
+-  * cfg80211: fix race between deauth and assoc response
+-  * ath5k: fix SWI calibration interrupt storm
+-  * ath9k: wake hardware for interface IBSS/AP/Mesh removal
+-  * ath9k: Fix TX queue draining
+-  * ath9k: fix missed error codes in the tx status check
+-  * ath9k: wake hardware during AMPDU TX actions
+-  * ath9k: fix suspend by waking device prior to stop
+-  * ath9k_hw: Fix possible OOB array indexing in gen_timer_index[] on
+-    64-bit
+-  * ath9k_hw: Fix AR_GPIO_INPUT_EN_VAL_BT_PRIORITY_BB and its shift value
+-    in 0x4054
+-  * iwl3945: disable power save
+-  * iwl3945: fix panic in iwl3945 driver
+-  * iwlwifi: fix EEPROM/OTP reading endian annotations and a bug
+-  * iwlwifi: fix more eeprom endian bugs
+-  * iwlwifi: fix 40MHz operation setting on cards that do not allow it
+-  * mac80211: fix race with suspend and dynamic_ps_disable_work
+-  * NOMMU: Optimise away the {dac_,}mmap_min_addr tests
+-  * 'sysctl_max_map_count' should be non-negative
+-  * kernel/sysctl.c: fix the incomplete part of
+-    sysctl_max_map_count-should-be-non-negative.patch
+-  * V4L/DVB (13596): ov511.c typo: lock => unlock
+-  * x86/ptrace: make genregs[32]_get/set more robust
+-  * memcg: avoid oom-killing innocent task in case of use_hierarchy
+-  * e100: Fix broken cbs accounting due to missing memset.
+-  * ipv6: reassembly: use seperate reassembly queues for conntrack and
+-    local delivery
+-  * netfilter: fix crashes in bridge netfilter caused by fragment jumps
+-  * hwmon: (sht15) Off-by-one error in array index + incorrect constants
+-  * b43: avoid PPC fault during resume
+-  * Keys: KEYCTL_SESSION_TO_PARENT needs TIF_NOTIFY_RESUME architecture
+-    support
+-  * sched: Fix balance vs hotplug race
+-  * drm/radeon/kms: fix crtc vblank update for r600
+-  * drm: disable all the possible outputs/crtcs before entering KMS mode
+-  * S390: dasd: support DIAG access for read-only devices
+-  * xen: fix is_disconnected_device/exists_disconnected_device
+-  * xen: improvement to wait_for_devices()
+-  * xen: wait up to 5 minutes for device connetion
+-  * orinoco: fix GFP_KERNEL in orinoco_set_key with interrupts disabled
+-  * udf: Try harder when looking for VAT inode
+-  * Add unlocked version of inode_add_bytes() function
+-  * quota: decouple fs reserved space from quota reservation
+-  * ext4: Convert to generic reserved quota's space management.
+-  * ext4: fix sleep inside spinlock issue with quota and dealloc (#14739)
+-  * x86, msr: Unify rdmsr_on_cpus/wrmsr_on_cpus
+-  * cpumask: use modern cpumask style in drivers/edac/amd64_edac.c
+-  * amd64_edac: unify MCGCTL ECC switching
+-  * x86, msr: Add support for non-contiguous cpumasks
+-  * x86, msr: msrs_alloc/free for CONFIG_SMP=n
+-  * amd64_edac: fix driver instance freeing
+-  * amd64_edac: make driver loading more robust
+-  * amd64_edac: fix forcing module load/unload
+-  * sched: Sched_rt_periodic_timer vs cpu hotplug
+-  * ext4: Update documentation to correct the inode_readahead_blks option
+-    name
+-  * lguest: fix bug in setting guest GDT entry
+-  * vmscan: do not evict inactive pages when skipping an active list scan
+-  * ksm: fix mlockfreed to munlocked
+-  * rt2x00: Disable powersaving for rt61pci and rt2800pci.
+-  * generic_permission: MAY_OPEN is not write access
+-  * Linux 2.6.32.3
+-  * untangle the do_mremap() mess
+-  * fasync: split 'fasync_helper()' into separate add/remove functions
+-  * ASoC: fix params_rate() macro use in several codecs
+-  * modules: Skip empty sections when exporting section notes
+-  * exofs: simple_write_end does not mark_inode_dirty
+-  * nfsd: make sure data is on disk before calling ->fsync
+-  * sunrpc: fix peername failed on closed listener
+-  * SUNRPC: Fix up an error return value in
+-    gss_import_sec_context_kerberos()
+-  * SUNRPC: Fix the return value in gss_import_sec_context()
+-  * sunrpc: on successful gss error pipe write, don't return error
+-  * drm/i915: Update LVDS connector status when receiving ACPI LID event
+-  * drm/i915: fix order of fence release wrt flushing
+-  * drm/i915: Permit pinning whilst the device is 'suspended'
+-  * drm: remove address mask param for drm_pci_alloc()
+-  * drm/i915: Enable/disable the dithering for LVDS based on VBT setting
+-  * drm/i915: Make the BPC in FDI rx/transcoder be consistent with that in
+-    pipeconf on Ironlake
+-  * drm/i915: Select the correct BPC for LVDS on Ironlake
+-  * drm/i915: fix unused var
+-  * rtc_cmos: convert shutdown to new pnp_driver->shutdown
+-  * drivers/cpuidle/governors/menu.c: fix undefined reference to
+-    `__udivdi3'
+-  * cgroups: fix 2.6.32 regression causing BUG_ON() in cgroup_diput()
+-  * lib/rational.c needs module.h
+-  * dma-debug: allow DMA_BIDIRECTIONAL mappings to be synced with
+-    DMA_FROM_DEVICE and
+-  * kernel/signal.c: fix kernel information leak with print-fatal-signals=1
+-  * mmc_block: add dev_t initialization check
+-  * mmc_block: fix probe error cleanup bug
+-  * mmc_block: fix queue cleanup
+-  * ALSA: hda - Fix ALC861-VD capture source mixer
+-  * ALSA: ac97: Add Dell Dimension 2400 to Headphone/Line Jack Sense
+-    blacklist
+-  * ALSA: atiixp: Specify codec for Foxconn RC4107MA-RS2
+-    - LP: #498863
+-  * ASoC: Fix WM8350 DSP mode B configuration
+-  * netfilter: ebtables: enforce CAP_NET_ADMIN
+-  * netfilter: nf_ct_ftp: fix out of bounds read in update_nl_seq()
+-  * hwmon: (coretemp) Fix TjMax for Atom N450/D410/D510 CPUs
+-  * hwmon: (adt7462) Fix pin 28 monitoring
+-  * quota: Fix dquot_transfer for filesystems different from ext4
+-  * xen: fix hang on suspend.
+-  * iwlwifi: fix iwl_queue_used bug when read_ptr == write_ptr
+-  * ath5k: Fix eeprom checksum check for custom sized eeproms
+-  * cfg80211: fix syntax error on user regulatory hints
+-  * iwl: off by one bug
+-  * mac80211: add missing sanity checks for action frames
+-  * drm/i915: remove render reclock support
+-  * libertas: Remove carrier signaling from the scan code
+-  * kernel/sysctl.c: fix stable merge error in NOMMU mmap_min_addr
+-  * mac80211: fix skb buffering issue (and fixes to that)
+-  * fix braindamage in audit_tree.c untag_chunk()
+-  * fix more leaks in audit_tree.c tag_chunk()
+-  * module: handle ppc64 relocating kcrctabs when CONFIG_RELOCATABLE=y
+-  * ipv6: skb_dst() can be NULL in ipv6_hop_jumbo().
+-  * agp/intel-agp: Clear entire GTT on startup
+-  * Linux 2.6.32.4
+-  * ethtool: Add reset operation
+-  * gro: Name the GRO result enumeration type
+-  * gro: Change all receive functions to return GRO result codes
+-  * sfc: 10Xpress: Initialise pause advertising flags
+-  * sfc: 10Xpress: Report support for pause frames
+-  * sfc: Remove redundant header gmii.h
+-  * sfc: Remove redundant hardware initialisation
+-  * sfc: Rename Falcon-specific board code and types
+-  * sfc: Remove boards.h, moving last remaining declaration to falcon.h
+-  * sfc: Remove versioned bitfield macros
+-  * sfc: Move RX data FIFO thresholds out of struct efx_nic_type
+-  * sfc: Update hardware definitions for Siena
+-  * sfc: Rename register I/O header and functions used by both Falcon and
+-    Siena
+-  * sfc: Eliminate indirect lookups of queue size constants
+-  * sfc: Define DMA address mask explicitly in terms of descriptor field
+-    width
+-  * sfc: Move all TX DMA length limiting into tx.c
+-  * sfc: Change order of device removal to reverse of probe order
+-  * sfc: Remove declarations of nonexistent functions
+-  * sfc: Move efx_xmit_done() declaration into correct stanza
+-  * sfc: Move shared members of struct falcon_nic_data into struct efx_nic
+-  * sfc: Maintain interrupt moderation values in ticks, not microseconds
+-  * sfc: Removed kernel-doc for nonexistent member of efx_phy_operations
+-  * sfc: Remove pointless abstraction of memory BAR number
+-  * sfc: Remove incorrect assertion from efx_pci_remove_main()
+-  * sfc: Remove unnecessary tests of efx->membase
+-  * sfc: Move MTD probe after netdev registration and name allocation
+-  * sfc: Remove unused code for non-autoneg speed/duplex switching
+-  * sfc: Rename 'xfp' file and functions to reflect reality
+-  * sfc: Really allow RX checksum offload to be disabled
+-  * sfc: Feed GRO result into RX allocation policy and interrupt moderation
+-  * sfc: Enable heuristic selection between page and skb RX buffers
+-  * sfc: Remove pointless abstraction of memory BAR number (2)
+-  * sfc: Remove redundant gotos from __efx_rx_packet()
+-  * sfc: Remove ridiculously paranoid assertions
+-  * sfc: Move assertions and buffer cleanup earlier in efx_rx_packet_lro()
+-  * sfc: Record RX queue number on GRO path
+-  * sfc: SFT9001: Reset LED configuration correctly after blinking
+-  * sfc: Use a single blink implementation
+-  * sfc: Rename efx_board::init_leds to init_phy and use for SFN4111T
+-  * sfc: Make board information explicitly Falcon-specific
+-  * sfc: Move definition of struct falcon_nic_data into falcon.h
+-  * sfc: Move struct falcon_board into struct falcon_nic_data
+-  * sfc: Move all I2C stuff into struct falcon_board
+-  * sfc: Gather link state fields in struct efx_nic into new struct
+-    efx_link_state
+-  * sfc: Remove unnecessary casts to struct sk_buff *
+-  * sfc: Remove redundant efx_xmit() function
+-  * sfc: Combine high-level header files
+-  * sfc: Log interrupt and reset type names, not numbers
+-  * sfc: Fix descriptor cache sizes
+-  * sfc: Treat all MAC registers as 128-bit
+-  * sfc: Strengthen EFX_ASSERT_RESET_SERIALISED
+-  * sfc: Comment corrections
+-  * sfc: Remove unused constant
+-  * sfc: Clean up struct falcon_board and struct falcon_board_data
+-  * sfc: Fix bugs in RX queue flushing
+-  * sfc: Remove unused function efx_flush_queues()
+-  * sfc: Only switch Falcon MAC clocks as necessary
+-  * sfc: Hold MAC lock for longer in efx_init_port()
+-  * sfc: Split MAC stats DMA initiation and completion
+-  * sfc: Move Falcon board/PHY/MAC monitoring code to falcon.c
+-  * sfc: Simplify XMAC link polling
+-  * sfc: Change MAC promiscuity and multicast hash at the same time
+-  * sfc: Move inline comment into kernel-doc
+-  * sfc: Do not set net_device::trans_start in self-test
+-  * sfc: Simplify PHY polling
+-  * sfc: QT202x: Reset before reading PHY id
+-  * sfc: Replace MDIO spinlock with mutex
+-  * sfc: Always start Falcon using the XMAC
+-  * sfc: Limit some hardware workarounds to Falcon
+-  * sfc: Remove EFX_WORKAROUND_9141 macro
+-  * sfc: Remove another unused workaround macro
+-  * sfc: Remove some redundant whitespace
+-  * sfc: Decouple NIC revision number from Falcon PCI revision number
+-  * sfc: Move descriptor cache base addresses to struct efx_nic_type
+-  * sfc: Clean up RX event handling
+-  * sfc: Remove redundant writes to INT_ADR_KER
+-  * sfc: Remove duplicate hardware structure definitions
+-  * sfc: Turn pause frame generation on and off at the MAC, not the RX FIFO
+-  * sfc: Move Falcon NIC operations to efx_nic_type
+-  * sfc: Refactor link configuration
+-  * sfc: Generalise link state monitoring
+-  * sfc: Add power-management and wake-on-LAN support
+-  * sfc: Implement ethtool reset operation
+-  * sfc: Add efx_nic_type operation for register self-test
+-  * sfc: Add efx_nic_type operation for NVRAM self-test
+-  * sfc: Add efx_nic_type operation for identity LED control
+-  * sfc: Separate shared NIC code from Falcon-specific and rename
+-    accordingly
+-  * sfc: Fold falcon_probe_nic_variant() into falcon_probe_nic()
+-  * sfc: Extend loopback mode enumeration
+-  * sfc: Remove static PHY data and enumerations
+-  * sfc: Extend MTD driver for use with new NICs
+-  * sfc: Allow for additional checksum offload features
+-  * sfc: Rename falcon.h to nic.h
+-  * sfc: Move shared NIC code from falcon.c to new source file nic.c
+-  * sfc: Add firmware protocol definitions (MCDI)
+-  * sfc: Add support for SFC9000 family (1)
+-  * sfc: Add support for SFC9000 family (2)
+-  * sfc: Implement TSO for TCP/IPv6
+-  * sfc: Update version, copyright dates, authors
+-  * drivers/net/sfc: Correct code taking the size of a pointer
+-  * sfc: Move PHY software state initialisation from init() into probe()
+-  * sfc: Include XGXS in XMAC link status check except in XGMII loopback
+-  * sfc: Fix DMA mapping cleanup in case of an error in TSO
+-  * sfc: QT2025C: Work around PHY bug
+-  * sfc: QT2025C: Switch into self-configure mode when not in loopback
+-  * sfc: QT2025C: Work around PHY firmware initialisation bug
+-  * sfc: QT2025C: Add error message for suspected bad SFP+ cables
+-  * sfc: Disable TX descriptor prefetch watchdog
+-  * [SCSI] vmw_pvscsi: SCSI driver for VMware's virtual HBA.
+-    - LP: #497156
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 19 Jan 2010 16:12:47 +0000
+-
+-linux (2.6.32-10.14) lucid; urgency=low
+-
+-  [ Alex Deucher ]
+-
+-  * SAUCE: drm/radeon/kms: fix LVDS setup on r4xx
+-    - LP: #493795
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "(pre-stable) acpi: Use the ARB_DISABLE for the CPU which model
+-    id is less than 0x0f."
+-  * config-check -- ensure the checks get run at build time
+-  * config-check -- check the processed config during updateconfigs
+-  * config-check -- CONFIG_SECCOMP may not be present
+-  * TUN is now built in ignore
+-  * SAUCE: acpi battery -- delay first lookup of the battery until first
+-    use
+-  * SAUCE: async_populate_rootfs: move rootfs init earlier
+-  * ubuntu: AppArmor -- update to mainline 2010-01-06
+-  * SAUCE: move RLIMIT_CORE pipe dumper marker to 1
+-    - LP: #498525
+-
+-  [ Dave Airlie ]
+-
+-  * (pre-stable) drm/radeon/kms: fix crtc vblank update for r600
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add asix to nic-usb-modules file
+-    - LP: #499785
+-
+-  [ Peter Zijlstra ]
+-
+-  * (pre-stable) sched: Fix balance vs hotplug race
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable CONFIG_FUNCTION_TRACER
+-    - LP: #497989
+-  * [Config] Drop lpia from getabis
+-  * [Config] Build in TUN/TAP driver
+-    - LP: #499491
+-  * [Config] DH_COMPAT=5
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "(pre-stable) drm/i915: Avoid NULL dereference with
+-    component_only tv_modes"
+-  * Revert "(pre-stable) drm/i915: Fix sync to vblank when VGA output is
+-    turned off"
+-  * USB: usb-storage: fix bug in fill_inquiry
+-  * USB: option: add pid for ZTE
+-  * firewire: ohci: handle receive packets with a data length of zero
+-  * rcu: Prepare for synchronization fixes: clean up for non-NO_HZ handling
+-    of ->completed counter
+-  * rcu: Fix synchronization for rcu_process_gp_end() uses of ->completed
+-    counter
+-  * rcu: Fix note_new_gpnum() uses of ->gpnum
+-  * rcu: Remove inline from forward-referenced functions
+-  * perf_event: Fix invalid type in ioctl definition
+-  * perf_event: Initialize data.period in perf_swevent_hrtimer()
+-  * perf: Don't free perf_mmap_data until work has been done
+-  * PM / Runtime: Fix lockdep warning in __pm_runtime_set_status()
+-  * sched: Check for an idle shared cache in select_task_rq_fair()
+-  * sched: Fix affinity logic in select_task_rq_fair()
+-  * sched: Rate-limit newidle
+-  * sched: Fix and clean up rate-limit newidle code
+-  * x86/amd-iommu: attach devices to pre-allocated domains early
+-  * x86/amd-iommu: un__init iommu_setup_msi
+-  * x86, Calgary IOMMU quirk: Find nearest matching Calgary while walking
+-    up the PCI tree
+-  * x86: Fix iommu=nodac parameter handling
+-  * x86: GART: pci-gart_64.c: Use correct length in strncmp
+-  * x86: ASUS P4S800 reboot=bios quirk
+-    - LP: #366682
+-  * x86, apic: Enable lapic nmi watchdog on AMD Family 11h
+-  * ssb: Fix range check in sprom write
+-  * ath5k: allow setting txpower to 0
+-  * ath5k: enable EEPROM checksum check
+-  * hrtimer: Fix /proc/timer_list regression
+-  * ALSA: hrtimer - Fix lock-up
+-  * ALSA: hda - Terradici HDA controllers does not support 64-bit mode
+-  * KVM: x86 emulator: limit instructions to 15 bytes
+-  * KVM: s390: Fix prefix register checking in arch/s390/kvm/sigp.c
+-  * KVM: s390: Make psw available on all exits, not just a subset
+-  * KVM: fix irq_source_id size verification
+-  * KVM: x86: include pvclock MSRs in msrs_to_save
+-  * x86: Prevent GCC 4.4.x (pentium-mmx et al) function prologue wreckage
+-  * x86: Use -maccumulate-outgoing-args for sane mcount prologues
+-  * x86, mce: don't restart timer if disabled
+-  * x86/mce: Set up timer unconditionally
+-  * x86: SGI UV: Fix BAU initialization
+-  * x86: Fix duplicated UV BAU interrupt vector
+-  * x86: Add new Intel CPU cache size descriptors
+-  * x86: Fix typo in Intel CPU cache size descriptor
+-  * pata_hpt{37x|3x2n}: fix timing register masks (take 2)
+-  * s390: clear high-order bits of registers after sam64
+-  * V4L/DVB: Fix test in copy_reg_bits()
+-  * bsdacct: fix uid/gid misreporting
+-  * UBI: flush wl before clearing update marker
+-  * jbd2: don't wipe the journal on a failed journal checksum
+-  * USB: xhci: Add correct email and files to MAINTAINERS entry.
+-  * USB: musb_gadget_ep0: fix unhandled endpoint 0 IRQs, again
+-  * USB: option.c: add support for D-Link DWM-162-U5
+-  * USB: usbtmc: repeat usb_bulk_msg until whole message is transfered
+-  * USB: usb-storage: add BAD_SENSE flag
+-  * USB: Close usb_find_interface race v3
+-  * pxa/em-x270: fix usb hub power up/reset sequence
+-  * hfs: fix a potential buffer overflow
+-  * SUNRPC: IS_ERR/PTR_ERR confusion
+-  * NFS: Fix nfs_migrate_page()
+-  * md/bitmap: protect against bitmap removal while being updated.
+-  * futex: Take mmap_sem for get_user_pages in fault_in_user_writeable
+-  * devpts_get_tty() should validate inode
+-  * debugfs: fix create mutex racy fops and private data
+-  * Driver core: fix race in dev_driver_string
+-  * Serial: Do not read IIR in serial8250_start_tx when UART_BUG_TXEN
+-  * mac80211: Fix bug in computing crc over dynamic IEs in beacon
+-  * mac80211: Fixed bug in mesh portal paths
+-  * mac80211: Revert 'Use correct sign for mesh active path refresh'
+-  * mac80211: fix scan abort sanity checks
+-  * wireless: correctly report signal value for IEEE80211_HW_SIGNAL_UNSPEC
+-  * rtl8187: Fix wrong rfkill switch mask for some models
+-  * x86: Fix bogus warning in apic_noop.apic_write()
+-  * mm: hugetlb: fix hugepage memory leak in mincore()
+-  * mm: hugetlb: fix hugepage memory leak in walk_page_range()
+-  * powerpc/windfarm: Add detection for second cpu pump
+-  * powerpc/therm_adt746x: Record pwm invert bit at module load time]
+-  * powerpc: Fix usage of 64-bit instruction in 32-bit altivec code
+-  * drm/radeon/kms: Add quirk for HIS X1300 board
+-  * drm/radeon/kms: handle vblanks properly with dpms on
+-  * drm/radeon/kms: fix legacy crtc2 dpms
+-  * drm/radeon/kms: fix vram setup on rs600
+-  * drm/radeon/kms: rs6xx/rs740: clamp vram to aperture size
+-  * drm/ttm: Fix build failure due to missing struct page
+-  * drm/i915: Set the error code after failing to insert new offset into mm
+-    ht.
+-  * drm/i915: Add the missing clonemask for display port on Ironlake
+-  * xen/xenbus: make DEVICE_ATTR()s static
+-  * xen: re-register runstate area earlier on resume.
+-  * xen: restore runstate_info even if !have_vcpu_info_placement
+-  * xen: correctly restore pfn_to_mfn_list_list after resume
+-  * xen: register timer interrupt with IRQF_TIMER
+-  * xen: register runstate on secondary CPUs
+-  * xen: don't call dpm_resume_noirq() with interrupts disabled.
+-  * xen: register runstate info for boot CPU early
+-  * xen: call clock resume notifier on all CPUs
+-  * xen: improve error handling in do_suspend.
+-  * xen: don't leak IRQs over suspend/resume.
+-  * xen: use iret for return from 64b kernel to 32b usermode
+-  * xen: explicitly create/destroy stop_machine workqueues outside
+-    suspend/resume region.
+-  * Xen balloon: fix totalram_pages counting.
+-  * xen: try harder to balloon up under memory pressure.
+-  * dm exception store: free tmp_store on persistent flag error
+-  * dm snapshot: only take lock for statustype info not table
+-  * dm crypt: move private iv fields to structs
+-  * dm crypt: restructure essiv error path
+-  * dm: avoid _hash_lock deadlock
+-  * dm snapshot: cope with chunk size larger than origin
+-  * dm crypt: separate essiv allocation from initialisation
+-  * dm crypt: make wipe message also wipe essiv key
+-  * slc90e66: fix UDMA handling
+-  * tcp: Stalling connections: Fix timeout calculation routine
+-  * ip_fragment: also adjust skb->truesize for packets not owned by a
+-    socket
+-  * b44 WOL setup: one-bit-off stack corruption kernel panic fix
+-  * sparc64: Don't specify IRQF_SHARED for LDC interrupts.
+-  * sparc64: Fix overly strict range type matching for PCI devices.
+-  * sparc64: Fix stack debugging IRQ stack regression.
+-  * sparc: Set UTS_MACHINE correctly.
+-  * b43legacy: avoid PPC fault during resume
+-  * tracing: Fix event format export
+-  * ath9k: Fix TX hang poll routine
+-  * ath9k: fix processing of TX PS null data frames
+-  * ath9k: Fix maximum tx fifo settings for single stream devices
+-  * ath9k: fix tx status reporting
+-  * mac80211: Fix dynamic power save for scanning.
+-  * drm/i915: Fix sync to vblank when VGA output is turned off
+-  * memcg: fix memory.memsw.usage_in_bytes for root cgroup
+-  * thinkpad-acpi: fix default brightness_mode for R50e/R51
+-  * thinkpad-acpi: preserve rfkill state across suspend/resume
+-  * ipw2100: fix rebooting hang with driver loaded
+-  * matroxfb: fix problems with display stability
+-  * acerhdf: add new BIOS versions
+-  * asus-laptop: change light sens default values.
+-  * vmalloc: conditionalize build of pcpu_get_vm_areas()
+-  * ACPI: Use the ARB_DISABLE for the CPU which model id is less than 0x0f.
+-  * net: Fix userspace RTM_NEWLINK notifications.
+-  * ext3: Fix data / filesystem corruption when write fails to copy data
+-  * V4L/DVB (13116): gspca - ov519: Webcam 041e:4067 added.
+-  * bcm63xx_enet: fix compilation failure after get_stats_count removal
+-  * x86: Under BIOS control, restore AP's APIC_LVTTHMR to the BSP value
+-  * drm/i915: Avoid NULL dereference with component_only tv_modes
+-  * drm/i915: PineView only has LVDS and CRT ports
+-  * drm/i915: Fix LVDS stability issue on Ironlake
+-  * mm: sigbus instead of abusing oom
+-  * ipvs: zero usvc and udest
+-  * jffs2: Fix long-standing bug with symlink garbage collection.
+-  * intel-iommu: Detect DMAR in hyperspace at probe time.
+-  * intel-iommu: Apply BIOS sanity checks for interrupt remapping too.
+-  * intel-iommu: Check for an RMRR which ends before it starts.
+-  * intel-iommu: Fix oops with intel_iommu=igfx_off
+-  * intel-iommu: ignore page table validation in pass through mode
+-  * netfilter: xtables: document minimal required version
+-  * perf_event: Fix incorrect range check on cpu number
+-  * implement early_io{re,un}map for ia64
+-  * Linux 2.6.32.2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 07 Jan 2010 15:28:43 +0000
+-
+-linux (2.6.32-9.13) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_B43_PHY_LP
+-    - LP: #493059
+-  * include modules.builtin in the binary debs
+-  * config-check -- add a configuration enforcer
+-  * config-check -- add a unit-test suite to the checker
+-  * [Config] Enable CONFIG_SYN_COOKIES for versatile
+-  * [Config] Enable CONFIG_SECURITY_SMACK for ports
+-  * [Config] Enable CONFIG_SECURITY_FILE_CAPABILITIES for ports
+-  * [Config] Disable CONFIG_COMPAT_BRK for ports
+-  * getabis -- add armel versatile to the list
+-
+-  [ Brad Figg ]
+-
+-  * SAUCE: Increase the default prealloc buffer for HDA audio devices
+-    (non-modem)
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: onmibook -- Added missing BOM file
+-
+-  [ Tim Gardner ]
+-
+-  * ubuntu: fsam7400 -- Cleanup Makefile
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT"
+-  * signal: Fix alternate signal stack check
+-  * SCSI: scsi_lib_dma: fix bug with dma maps on nested scsi objects
+-  * SCSI: osd_protocol.h: Add missing #include
+-  * SCSI: megaraid_sas: fix 64 bit sense pointer truncation
+-  * ext4: fix potential buffer head leak when add_dirent_to_buf() returns
+-    ENOSPC
+-  * ext4: avoid divide by zero when trying to mount a corrupted file system
+-  * ext4: fix the returned block count if EXT4_IOC_MOVE_EXT fails
+-  * ext4: fix lock order problem in ext4_move_extents()
+-  * ext4: fix possible recursive locking warning in EXT4_IOC_MOVE_EXT
+-  * ext4: plug a buffer_head leak in an error path of ext4_iget()
+-  * ext4: make sure directory and symlink blocks are revoked
+-  * ext4: fix i_flags access in ext4_da_writepages_trans_blocks()
+-  * ext4: journal all modifications in ext4_xattr_set_handle
+-  * ext4: don't update the superblock in ext4_statfs()
+-  * ext4: fix uninit block bitmap initialization when s_meta_first_bg is
+-    non-zero
+-  * ext4: fix block validity checks so they work correctly with meta_bg
+-  * ext4: avoid issuing unnecessary barriers
+-  * ext4: fix error handling in ext4_ind_get_blocks()
+-  * ext4: make trim/discard optional (and off by default)
+-  * ext4: make "norecovery" an alias for "noload"
+-  * ext4: Fix double-free of blocks with EXT4_IOC_MOVE_EXT
+-  * ext4: initialize moved_len before calling ext4_move_extents()
+-  * ext4: move_extent_per_page() cleanup
+-  * jbd2: Add ENOMEM checking in and for
+-    jbd2_journal_write_metadata_buffer()
+-  * ext4: Return the PTR_ERR of the correct pointer in
+-    setup_new_group_blocks()
+-  * ext4: Avoid data / filesystem corruption when write fails to copy data
+-  * ext4: wait for log to commit when umounting
+-  * ext4: remove blocks from inode prealloc list on failure
+-  * ext4: ext4_get_reserved_space() must return bytes instead of blocks
+-  * ext4: quota macros cleanup
+-  * ext4: fix incorrect block reservation on quota transfer.
+-  * ext4: Wait for proper transaction commit on fsync
+-  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
+-  * ext4: Fix potential fiemap deadlock (mmap_sem vs. i_data_sem)
+-  * Linux 2.6.32.1
+-  * kbuild: generate modules.builtin
+-  * (pre-stable) drm/i915: Fix sync to vblank when VGA output is turned off
+-    - LP: #494461
+-  * (pre-stable) drm/i915: Avoid NULL dereference with component_only
+-    tv_modes
+-    - LP: #494045
+-
+-  [ Zhao Yakui ]
+-
+-  * (pre-stable) acpi: Use the ARB_DISABLE for the CPU which model id is
+-    less than 0x0f.
+-    - LP: #481765
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 17 Dec 2009 15:41:21 +0000
+-
+-linux (2.6.32-8.12) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: AppArmor -- add linux/err.h for ERR_PTR
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 12 Dec 2009 10:56:16 +0000
+-
+-linux (2.6.32-8.11) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches
+-    up"
+-  * Revert "SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
+-    transition."
+-  * Revert "SAUCE: AppArmor: Fix refcounting bug causing leak of creds"
+-  * Revert "SAUCE: AppArmor: Fix cap audit_caching preemption disabling"
+-  * Revert "SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds"
+-  * Revert "SAUCE: AppArmor: Fix oops after profile removal"
+-  * Revert "SAUCE: AppArmor: AppArmor disallows truncate of deleted files."
+-  * Revert "SAUCE: AppArmor: AppArmor fails to audit change_hat correctly"
+-  * Revert "SAUCE: AppArmor: Policy load and replacement can fail to alloc
+-    mem"
+-  * Revert "SAUCE: AppArmor: AppArmor wrongly reports allow perms as
+-    denied"
+-  * Revert "SAUCE: AppArmor: Fix mediation of "deleted" paths"
+-  * Revert "SAUCE: AppArmor: Fix off by 2 error in getprocattr mem
+-    allocation"
+-  * Revert "SAUCE: AppArmor: Set error code after structure
+-    initialization."
+-  * Revert "AppArmor -- fix pstrace_may_access rename"
+-  * Revert "ubuntu: AppArmor security module"
+-  * Revert "SAUCE: Add config option to set a default LSM"
+-  * Revert "ubuntu: fsam7400 -- sw kill switch driver"
+-  * Revert "[Config] fsam7400 -- enable"
+-  * Revert "[Config] AUFS -- enable"
+-  * Revert "ubuntu: AUFS -- aufs2-30 20090727"
+-  * Revert "ubuntu: AUFS -- export various core functions -- fixes"
+-  * Revert "ubuntu: AUFS -- export various core functions"
+-  * Revert "[Config] ubuntu/iscsitarget -- disable"
+-  * Revert "[Config] iscsitarget -- enable"
+-  * Revert "ubuntu: iscsitarget -- SVN revision r214"
+-  * update Vcs-Git to point to the correct repository
+-    - LP: #493589
+-  * update build environment overrides to lucid
+-    - LP: #493589
+-  * [Config] enable CONFIG_DEVTMPFS
+-  * [Config] update all configs following AppArmor 2009-12-08 update
+-  * SAUCE: isapnp_init: make isa PNP scans occur async
+-  * [Config] fsam7400 -- enable
+-  * [Config] omnibook -- enable
+-  * [Config] cleanup CONFIG_AUDIT
+-  * ubuntu: AUFS -- export various core functions (aufs2-base.patch)
+-  * ubuntu: AUFS -- export various core functions (aufs2-standalone.patch)
+-  * ubuntu: AUFS -- aufs2 20091209
+-  * [Config] AUFS -- enable
+-  * [Config] iscsitarget -- enable
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: KMS: cache the EDID information of the LVDS
+-
+-  [ Colin Watson ]
+-
+-  * bnx2: update d-i firmware filenames
+-    - LP: #494052
+-  * add cdc_ether to nic-usb-modules udeb
+-    - LP: #495060
+-
+-  [ John Johansen ]
+-
+-  * ubuntu: AppArmor -- mainline 2009-10-08
+-
+-  [ Manoj Iyer ]
+-
+-  * ubuntu: fsam7400 -- kill switch for Fujitsu Siemens Amilo M 7400
+-  * ubuntu: omnibook -- support Toshiba (HP) netbooks
+-  * ubuntu: iscsitarget --- version 1.4.19
+-    - LP: #494693
+-
+-  [ Surbhi Palande ]
+-
+-  * SAUCE: Make populate_rootfs asynchronous
+-
+-  [ Tim Gardner ]
+-
+-  * Parallelize flavour builds and packaging
+-  * [Config] Enable CONFIG_KSM
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Config option to set a default LSM
+-  * LSM: Add security_path_chroot().
+-  * LSM: Add security_path_chroot().
+-  * LSM: Move security_path_chmod()/security_path_chown() to after
+-    mutex_lock().
+-  * ext4: Fix insufficient checks in EXT4_IOC_MOVE_EXT
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 11 Dec 2009 17:45:19 +0000
+-
+-linux (2.6.32-7.10) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable CONFIG_THUMB2_KERNEL to fix arm FTBFS
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sun, 06 Dec 2009 12:56:48 +0000
+-
+-linux (2.6.32-7.9) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: set /proc/acpi/video/*/DOS to 4 by default
+-    - LP: #458982
+-  * SAUCE: ensure vga16fb loads if no other driver claims the VGA device
+-  * [Config] update configs following versatile switch to V7
+-  * rebased to v2.6.32
+-  * [Config] update configs following rebase to v2.6.32
+-  * [Config] update ports configs following rebase to v2.6.32
+-  * SAUCE: default ATI Radeon KMS to off until userspace catches up
+-
+-  [ Arjan van de Ven ]
+-
+-  * SAUCE: vfs: Add a trace point in the mark_inode_dirty function
+-
+-  [ Leann Ogasawara ]
+-
+-  * [SCSI] megaraid_sas: remove sysfs poll_mode_io world writeable
+-    permissions
+-    - CVE-2009-3939
+-
+-  [ Loic Minier ]
+-
+-  * SAUCE: select a v7 CPU for versatile
+-
+-  [ Takashi Iwai ]
+-
+-  * SAUCE: ALSA: hda - Add power on/off counter
+-
+-  [ Upstream changes ]
+-
+-  * rebased to v2.6.32
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 04 Dec 2009 10:44:50 +0000
+-
+-linux (2.6.32-6.8) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] disable SSB devices for armel
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 28 Nov 2009 12:16:40 +0000
+-
+-linux (2.6.32-6.7) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: default ATI Radeon KMS to off until userspace catches up"
+-  * Revert "SAUCE: Dell XPS710 reboot quirk"
+-  * Revert "SAUCE: Link acpi-cpufreq.o first"
+-  * Revert "SAUCE: LPIA  Logical reset of USB port on resume"
+-  * Revert "SAUCE: LPIA Reboot fix for Intel Crownbeach development boards"
+-  * Revert "SAUCE: Enable HDMI audio codec on Studio XPS 1340"
+-  * Revert "SAUCE: Dell laptop digital mic does not work, PCI 1028:0271"
+-  * Revert "Add Dell Dimension 9200 reboot quirk"
+-  * Revert "SAUCE: Correctly blacklist Thinkpad r40e in ACPI"
+-  * Revert "SAUCE: tulip: Define ULI PCI ID's"
+-  * Revert "SAUCE: Lower warning level of some PCI messages"
+-  * Revert "mac80211: fix two issues in debugfs"
+-    Drop a number of known redundant commits as identified in the Ubuntu
+-    delta review blueprint.
+-
+-  * reenable armel versatile flavour
+-  * [Config] disable CONFIG_USB_DEVICEFS
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] udeb: Add squashfs to fs-core-modules
+-    - LP: #352615
+-  * [Config] Create a real squashfs udeb
+-    - LP: #352615
+-
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 27 Nov 2009 17:31:16 +0000
+-
+-linux (2.6.32-5.6) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc8
+-  * update configs following rebase to v2.6.32-rc8
+-  * update ports configs since rebase to v2.6.32-rc8
+-  * [Config] enable cgroup options
+-    - LP: #480739
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 23 Nov 2009 11:16:14 +0000
+-
+-linux (2.6.32-4.5) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
+-  * rebase to v2.6.32-rc7
+-  * resync with Karmic proposed
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Fix oops after profile removal
+-    - LP: #475619
+-  * SAUCE: AppArmor: Fix Oops when in apparmor_bprm_set_creds
+-    - LP: #437258
+-  * SAUCE: AppArmor: Fix cap audit_caching preemption disabling
+-    - LP: #479102
+-  * SAUCE: AppArmor: Fix refcounting bug causing leak of creds
+-    - LP: #479115
+-  * SAUCE: AppArmor: Fix oops there is no tracer and doing unsafe
+-    transition.
+-    - LP: #480112
+-
+-  [ Ubuntu Changes ]
+-
+-  * resync with Karmic proposed (ddbc670a86a3dee18541a3734149f250ff307adf)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 13 Nov 2009 11:35:13 +0000
+-
+-linux (2.6.32-3.4) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] SERIO_LIBPS2 and SERIO_I8042 must match
+-  * [Upstream] add local prefix to oss local change_bits
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mtd/maps: gpio-addr-flash: pull in linux/ headers rather than asm/
+-  * mtd/maps: gpio-addr-flash: depend on GPIO arch support
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 11 Nov 2009 14:47:04 +0000
+-
+-linux (2.6.32-3.3) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc6
+-  * [Config] update configs following rebase to v2.6.32-rc6
+-  * [Config] update ports configs following rebase to v2.6.32-rc6
+-  * resync with Karmic Ubuntu-2.6.31-15.49
+-  * [Config] add module ignores for broken drivers
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: AppArmor wrongly reports allow perms as denied
+-    - LP: #453335
+-  * SAUCE: AppArmor: Policy load and replacement can fail to alloc mem
+-    - LP: #458299
+-  * SAUCE: AppArmor: AppArmor fails to audit change_hat correctly
+-    - LP: #462824
+-  * SAUCE: AppArmor: AppArmor disallows truncate of deleted files.
+-    - LP: #451375
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: Fix nx_enable reporting
+-    - LP: #454285
+-
+-  [ Scott James Remnant ]
+-
+-  * Revert "SAUCE: trace: add trace_event for the open() syscall"
+-  * SAUCE: trace: add trace events for open(), exec() and uselib()
+-    - LP: #462111
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: Fix sub-flavour script to not stop on missing directories
+-    - LP: #453073
+-
+-  [ Ubuntu Changes ]
+-
+-  * resync with Karmic Ubuntu-2.6.31-15.49
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc6
+-    - LP: #464552
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 10 Nov 2009 15:00:57 +0000
+-
+-linux (2.6.32-2.2) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * install the full changelog with the binary package
+-  * changelog -- explicitly note rebases and clean history
+-  * reinstate armel.mk with no flavours
+-    - LP: #449637
+-  * [Upstream] block: silently error unsupported empty barriers too
+-    - LP: #420423
+-  * [Config] udate configs following karmic resync
+-  * [Config] update ports configs following karmic resync
+-  * [Upstream] lirc -- follow removal of .id element
+-
+-  [ Colin Watson ]
+-
+-  * Use section 'admin' rather than 'base'
+-  * Add more e100 firmware to nic-modules
+-    - LP: #451872
+-  * Add qla1280 firmware to scsi-modules
+-    - LP: #381037
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Set error code after structure initialization.
+-    - LP: #427948
+-  * SAUCE: AppArmor: Fix off by 2 error in getprocattr mem allocation
+-    - LP: #446595
+-  * SAUCE: AppArmor: Fix mediation of "deleted" paths
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] fix report of cs-limit nx-emulation
+-    - LP: #454285
+-
+-  [ Leann Ogasawara ]
+-
+-  * SAUCE: (drop after 2.6.31) input: Add support for filtering input
+-    events
+-    - LP: #430809
+-  * SAUCE: (drop after 2.6.31) dell-laptop: Trigger rfkill updates on wifi
+-    toggle switch press
+-    - LP: #430809
+-
+-  [ Luke Yelavich ]
+-
+-  * SAUCE: Add sr_mod to the scsi-modules udeb for powerpc
+-  * [Config] Add sd_mod to scsi-modules udeb for powerpc
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: Update to LIRC 0.8.6
+-    - LP: #432678
+-  * SAUCE: dell-laptop: Store the HW switch status internally rather than
+-    requerying every time
+-    - LP: #430809
+-  * SAUCE: dell-laptop: Blacklist machines not supporting dell-laptop
+-    - LP: #430809
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] acerhdf: Limit modalias matching to supported boards
+-    - LP: #435958
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] i915: Fix i2c init message
+-    - LP: #409361
+-  * [Config] Add sym53c8xx.ko to virtual sub-flavour
+-    - LP: #439415
+-  * [Config] Add d101m_ucode.bin to d-i/firmware/nic-modules
+-    - LP: #439456
+-  * [Config] Set default I/O scheduler back to CFQ for desktop flavours
+-    - LP: #381300
+-  * SAUCE: Created MODULE_EXPORT/MODULE_IMPORT macros
+-    - LP: #430694
+-  * SAUCE: Use MODULE_IMPORT macro to tie intel_agp to i915
+-    - LP: #430694
+-  * [Config] CONFIG_GFS2_FS_LOCKING_DLM=y
+-    - LP: #416325
+-  * SAUCE: Fix MODULE_IMPORT/MODULE_EXPORT
+-    - LP: #430694
+-  * SAUCE: Raise the default console 'quiet' level to 2
+-  * [Config] CONFIG_X86_PAT=y
+-  * [Config] Add armel arch to linux-libc-dev arches.
+-    - LP: #449637
+-  * [Config] CONFIG_X86_MCE
+-  * [Upstream] (drop after 2.6.31) Input: synaptics - add another Protege
+-    M300 to rate blacklist
+-    - LP: #433801
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * sgi-gru: Fix kernel stack buffer overrun, CVE-2009-2584
+-  * drm/i915: Fix FDI M/N setting according with correct color depth
+-    - LP: #416792
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 22 Oct 2009 16:53:33 +0100
+-
+-linux (2.6.32-1.1) lucid; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.32-rc3
+-  * [Config] update configs following rebase to 2.6.32-rc3
+-  * [Config] update ports configs following rebase to 2.6.32-rc3
+-  * AppArmor -- fix pstrace_may_access rename
+-  * staging/android -- disable
+-  * ubuntu: dm-raid-45 -- update to compile with 2.6.32
+-  * ubuntu: drbd -- disable
+-  * staging/comdi -- disable
+-  * staging/go7007 -- disable
+-  * [Config] staging/winbond -- disable
+-  * [Config] ubuntu/iscsitarget -- disable
+-  * [d-i] cbc and ecb are builtin make them optional in udebs
+-  * rebase to v2.6.32-rc5
+-  * [Config] update configs following rebase to v2.6.32-rc5
+-  * [Config] update ports configs following rebase to v2.6.31-rc5
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add cpio as a build dependency.
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebase to v2.6.32-rc3
+-  * rebase to v2.6.32-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 05 Oct 2009 15:48:58 +0100
+-
+-linux (2.6.31-11.37) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Increase kernel log buffer to 256K for amd64 flavours
+-    - LP: #424810
+-  * [Config] Set HZ=100 for amd64 flavours
+-    - LP: #438234
+-  * [Upstream] e1000e: Emit notice instead of an error when
+-    pci_enable_pcie_error_reporting() fails
+-    - LP: #436370
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * n_tty: honor opost flag for echoes
+-  * n_tty: move echoctl check and clean up logic
+-    - LP: #438310
+-
+-  * Revert "[Upstream] drm/i915: Check that the relocation points to within
+-    the target" - Use upstream cherry-pick.
+-  * drm/i915: Check that the relocation points to within the target
+-    - LP: #429241
+-
+-  * drm/i915: fix tiling on IGDNG
+-  * drm/i915: add B43 chipset support
+-  * agp/intel: Add B43 chipset support
+-    Intel request from kernel team mailing list.
+-
+-  * HID: completely remove apple mightymouse from blacklist
+-    - LP: #428111
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 28 Sep 2009 11:47:29 -0600
+-
+-linux (2.6.31-11.36) karmic; urgency=low
+-
+-  [ Brian Rogers ]
+-
+-  * SAUCE: (drop after 2.6.31) em28xx: ir-kbd-i2c init data needs a
+-    persistent object
+-  * SAUCE: (drop after 2.6.31) saa7134: ir-kbd-i2c init data needs a
+-    persistent object
+-
+-  [ Takashi Iwai ]
+-
+-  * [Upstream] ALSA: hda - Add another entry for Nvidia HDMI device
+-    - LP: #416482
+-
+-  [ Tyler Hicks ]
+-
+-  * SAUCE: (drop after 2.6.31) eCryptfs: Prevent lower dentry from going
+-    negative during unlink
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * sg: fix oops in the error path in sg_build_indirect()
+-  * mpt2sas : Rescan topology from Interrupt context instead of work thread
+-  * mpt2sas: Prevent sending command to FW while Host Reset
+-  * mpt2sas: setting SDEV into RUNNING state from Interrupt context
+-  * mpt2sas: Raid 10 Volume is showing as Raid 1E in dmesg
+-  * SCSI: fix oops during scsi scanning
+-  * SCSI: libsrp: fix memory leak in srp_ring_free()
+-  * cfg80211: fix looping soft lockup in find_ie()
+-  * ath5k: write PCU registers on initial reset
+-  * binfmt_elf: fix PT_INTERP bss handling
+-  * TPM: Fixup boot probe timeout for tpm_tis driver
+-  * md: Fix "strchr" [drivers/md/dm-log-userspace.ko] undefined!
+-  * x86/amd-iommu: fix broken check in amd_iommu_flush_all_devices
+-  * fix undefined reference to user_shm_unlock
+-  * perf_counter: Fix buffer overflow in perf_copy_attr()
+-  * perf_counter: Start counting time enabled when group leader gets
+-    enabled
+-  * powerpc/perf_counters: Reduce stack usage of power_check_constraints
+-  * powerpc: Fix bug where perf_counters breaks oprofile
+-  * powerpc/ps3: Workaround for flash memory I/O error
+-  * block: don't assume device has a request list backing in nr_requests
+-    store
+-  * agp/intel: remove restore in resume
+-  * ALSA: cs46xx - Fix minimum period size
+-  * ASoC: Fix WM835x Out4 capture enumeration
+-  * sound: oxygen: work around MCE when changing volume
+-  * mlx4_core: Allocate and map sufficient ICM memory for EQ context
+-  * perf stat: Change noise calculation to use stddev
+-  * x86: Fix x86_model test in es7000_apic_is_cluster()
+-  * x86/i386: Make sure stack-protector segment base is cache aligned
+-  * PCI: apply nv_msi_ht_cap_quirk on resume too
+-  * x86, pat: Fix cacheflush address in change_page_attr_set_clr()
+-  * ARM: 5691/1: fix cache aliasing issues between kmap() and kmap_atomic()
+-    with highmem
+-  * KVM guest: do not batch pte updates from interrupt context
+-  * KVM: Fix coalesced interrupt reporting in IOAPIC
+-  * KVM: VMX: Check cpl before emulating debug register access
+-  * KVM guest: fix bogus wallclock physical address calculation
+-  * KVM: x86: Disallow hypercalls for guest callers in rings > 0
+-  * KVM: VMX: Fix cr8 exiting control clobbering by EPT
+-  * KVM: x86 emulator: Implement zero-extended immediate decoding
+-  * KVM: MMU: make __kvm_mmu_free_some_pages handle empty list
+-  * KVM: x86 emulator: fix jmp far decoding (opcode 0xea)
+-  * KVM: limit lapic periodic timer frequency
+-  * libata: fix off-by-one error in ata_tf_read_block()
+-  * PCI quirk: update 82576 device ids in SR-IOV quirks list
+-  * PCI: Unhide the SMBus on the Compaq Evo D510 USDT
+-  * powerpc/pseries: Fix to handle slb resize across migration
+-  * Linux 2.6.31.1
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 24 Sep 2009 13:04:28 -0600
+-
+-linux (2.6.31-10.35) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * Disable CONFIG_UEVENT_HELPER_PATH
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] Enable CONFIG_USB_GADGET_DUMMY_HCD
+-  * remove the tlsup driver
+-  * remove lmpcm logitech driver support
+-
+-  [ Bryan Wu ]
+-
+-  * Add 3 missing files to prerm remove file list
+-    - LP: #345623, #415832
+-
+-  [ Chris Wilson ]
+-
+-  * [Upstream] drm/i915: Check that the relocation points to within the
+-    target
+-    - LP: #429241
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Set CONFIG_EXT4_FS=y on ports architectures
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: Added quirk to recognize GE0301 3G modem as an interface.
+-    - LP: #348861
+-
+-  [ Tim Gardner ]
+-
+-  * Revert "[Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux) white-list"
+-  * Revert "[Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux) white-list"
+-    Upstream suggests that this is not the right approach.
+-
+-  * [Config] Set default I/O scheduler to DEADLINE
+-    CFQ seems to have some load related problems which are often exacerbated by sreadahead.
+-    - LP: #381300
+-
+-  [ ubuntu@tjworld.net ]
+-
+-  * SAUCE: ipw2200: Enable LED by default
+-    - LP: #21367
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ALSA: hda - Add support for new AMD HD audio devices
+-    - LP: #430564
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 16 Sep 2009 15:37:49 +0100
+-
+-linux (2.6.31-10.34) karmic; urgency=low
+-
+-  [ Ted Tso ]
+-
+-  * [Upstream] ext3: Don't update superblock write time when filesystem is
+-    read-only
+-    - LP: #427822
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 16:00:45 -0600
+-
+-linux (2.6.31-10.33) karmic; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] dvb-usb: fix tuning with Cinergy T2
+-    - LP: #421258
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Unconditionally copy files from sub-flavours lists.
+-    (really, really fix it this time)
+-    - LP: #423426
+-  * [Config] Set CONFIG_CACHEFILES=m for all flavours
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * ext4: Don't update superblock write time when filesystem is read-only
+-    - LP: #427822
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 15 Sep 2009 07:50:21 -0600
+-
+-linux (2.6.31-10.32) karmic; urgency=low
+-
+-  [ Eric Miao ]
+-
+-  * [Config] enable module support for memory stick
+-    - LP: #159951
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Unconditionally copy files from sub-flavours lists.
+-    - LP: #423426
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 10 Sep 2009 15:57:55 -0600
+-
+-linux (2.6.31-10.31) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.31 final
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Recommend grub-pc in linux-image
+-    - LP: #385741
+-
+-  [ Ike Panhc ]
+-
+-  * [Upstream] Pull latest update of lenovo-sl-laptop
+-
+-  [ Peter Feuerer ]
+-
+-  * [Upstream] (drop after 2.6.31) acerhdf: fix fan control for AOA150
+-    model
+-    - LP: #426691
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] De-macro some package names.
+-
+-  [ Upstream Changes ]
+-
+-  * rebase to 2.6.31 final.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 10 Sep 2009 09:38:10 +0100
+-
+-linux (2.6.31-10.30) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] Enable CONFIG_USB_DEVICEFS
+-    - LP: #417748
+-  * [Config] Populate the config-update template a bit more
+-
+-  [ Andy Whitcroft ]
+-
+-  * rebase to v2.6.31-rc9
+-  * [Config] update configs following rebase to v2.6.31-rc9
+-  * [Config] update ports configs following rebase to v2.6.31-rc9
+-
+-  [ Colin Ian King ]
+-
+-  * SAUCE: wireless: hostap, fix oops due to early probing interrupt
+-    - LP: #254837
+-
+-  [ Jerone Young ]
+-
+-  * [Upstream] ACPI: Add Thinkpad T400 & Thinkpad T500 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad X200, X200s, X200t to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad X300 & Thinkpad X301 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad R400 & Thinkpad R500 to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-  * [Upstream] ACPI: Add Thinkpad W500, W700, & W700ds to OSI(Linux)
+-    white-list
+-    - LP: #281732
+-
+-  [ John Johansen ]
+-
+-  * SAUCE: AppArmor: Fix profile attachment for regexp based profile names
+-    - LP: #419308
+-  * SAUCE: AppArmor: Return the correct error codes on profile
+-    addition/removal
+-    - LP: #408473
+-  * SAUCE: AppArmor: Fix OOPS in profile listing, and display full list
+-    - LP: #408454
+-  * SAUCE: AppArmor: Fix mapping of pux to new internal permission format
+-    - LP: #419222
+-  * SAUCE: AppArmor: Fix change_profile failure
+-    - LP: #401931
+-  * SAUCE: AppArmor: Tell git to ignore generated include files
+-    - LP: #419505
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] acpi: video: Loosen strictness of video bus detection code
+-    - LP: #333386
+-  * SAUCE: Remove ov511 driver from ubuntu subdirectory
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Exclude char-modules from non-x86 udeb creation
+-  * SAUCE: Notify the ACPI call chain of AC events
+-  * [Config] CONFIG_SATA_VIA=m
+-    - LP: #403385
+-  * [Config] Build in all phylib support modules.
+-  * [Config] Don't fail when sub-flavour files are missing
+-    - LP: #423426
+-  * [Config] Set CONFIG_LSM_MMAP_MIN_ADDR=0
+-    - LP: #423513
+-
+-  [ Upstream ]
+-
+-  * Rebased against v2.6.31-rc9
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 07 Sep 2009 11:33:45 +0100
+-
+-linux (2.6.31-9.29) karmic; urgency=low
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] agp/intel: support for new chip variant of IGDNG mobile
+-    - LP: #419993
+-  * [Config] d-i/modules: Add new char-modules file, initialize with
+-    intel-agp
+-    - LP: #420605
+-
+-  [ Upstream ]
+-
+-  * Rebased against 2.6.31-rc8 plus some inotify regression patches:
+-    up through git://git.kernel.org/pub/scm/linux/kernel/git/torvalds/linux-2.6.git
+-    adda766193ea1cf3137484a9521972d080d0b7af.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 28 Aug 2009 06:31:30 -0600
+-
+-linux (2.6.31-8.28) karmic; urgency=low
+-
+-  [ Ike Panhc ]
+-
+-  * [Config] Let nic-shared-modules depends on crypto-modules
+-    - LP: #360966
+-
+-  [ Leann Ogasawara ]
+-
+-  * [Upstream] (drop after 2.6.31) drm/i915: increase default latency
+-    constant
+-    - LP: #412492
+-
+-  [ Mario Limonciello ]
+-
+-  * [Upstream]: (drop after 2.6.31) dell-laptop: don't change softblock
+-    status if HW switch is disabled
+-    - LP: #418721
+-  * [Upstream]: (drop after 2.6.31) compal-laptop: Add support for known
+-    Compal made Dell laptops
+-  * [Upstream]: (drop after 2.6.31) compal-laptop: Replace sysfs support
+-    with rfkill support
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Add acpiphp to virtual sub-flavour
+-    - LP: #364916
+-  * Drop KSM patch set for now because of instabilities with encrypted swap.
+-    - LP: #418781
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Wed, 26 Aug 2009 08:14:26 -0600
+-
+-linux (2.6.31-7.27) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] updateconfigs updateportsconfigs after 2.6.31-rc7 rebase
+-  * SAUCE: (drop after 2.6.31) Added KSM from mmotm-2009-08-20-19-18
+-    Replaces previous ksm patches from 2.6.31-6.25
+-  * [Config] KSM=y
+-
+-  [ Upstream ]
+-
+-  * Rebased against v2.6.31-rc7
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sat, 22 Aug 2009 20:32:11 -0600
+-
+-linux (2.6.31-6.26) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] enable CONFIG_AUFS_BR_RAMFS
+-    - LP: #414738
+-  * split out debian directory ready for abstraction
+-  * add printdebian target to find branch target
+-  * abstracted debian -- debian/files is not abstracted
+-  * abstracted debian -- packages must be built in debian/<pkg>
+-  * abstracted debian -- kernel-wedge needs to work in debian/
+-  * abstracted debian -- ensure we install the copyright file
+-  * abstracted-debian -- drop the debian directories from headers
+-  * abstracted-debian -- drop the debian directories from headers part 2
+-  * SAUCE: ubuntu-insert-changes -- follow abstracted debian
+-  * [Upstream] aoe: ensure we initialise the request_queue correctly V2
+-    - LP: #410198
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Ports: Disable CONFIG_CPU_FREQ_DEBUG on powerpc-smp
+-  * [Config] Ports: Re-enable windfarm modules on powerpc64-smp
+-    - LP: #413150
+-  * [Config] Ports: Build all cpu frequency scaling governors into ports
+-    kernels
+-  * [Config] Ports: Build ext2 and ext3 modules into ports kernels
+-  * [Config] Ports: CONFIG_PACKET=y for all ports kernels
+-  * [Config] Ports: Enable PS3 network driver
+-
+-  [ Stefan Bader ]
+-
+-  * abstracted debian -- call $(DEBIAN)/rules using make
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Abstract the debian directory
+-  * SAUCE: Improve error reporting in postinst
+-    - LP: #358564
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Sun, 16 Aug 2009 20:33:28 -0600
+-
+-linux (2.6.31-6.25) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * script to generate Ubuntu changes from changelog
+-  * [Config] standardise ANDROID options
+-  * [Config] standardise CONFIG_ATM as module
+-  * [Config] standardise CONFIG_LIB80211 as module
+-  * [Config] disable CONFIG_PRINT_QUOTA_WARNING
+-  * [Config] set CONFIG_CRAMFS as module
+-  * [Config] enable CONFIG_DAB and modules
+-  * [Config] set CONFIG_MAC80211_HWSIM as module
+-  * [Config] set CONFIG_NET_CLS_FLOW as module
+-  * [Config] set CONFIG_NF_CONNTRACK_SANE as module
+-  * [Config] set CONFIG_NF_CT_PROTO_DCCP as module
+-  * [Config] set CONFIG_RTC_DRV_DS1511 as module
+-  * [Config] set CONFIG_RTC_DRV_R9701 as module
+-  * [Config] set CONFIG_RTC_DRV_S35390A as module
+-  * [Config] set CONFIG_TOIM3232_DONGLE as module
+-  * [Config] standardise CONFIG_USB_MIDI_GADGET as module
+-  * [Config] standardise CONFIG_USB_G_PRINTER as module
+-  * [Config] standardise CONFIG_USB_SERIAL_IR as module
+-  * [Config] set CONFIG_USB_SERIAL_IUU as module
+-  * [Config] standardise CONFIG_USB_STORAGE_CYPRESS_ATACB as module
+-  * [Config] standardise CONFIG_USB_STORAGE_ONETOUCH as module
+-  * cleanup remains of dm-loop
+-  * drop thinkpad ec and smapi support
+-  * drop appleir
+-  * [Config] update configs following rebase to v2.6.31-rc6
+-  * rebase to v2.6.31-rc6
+-
+-  [ Hugh Dickins ]
+-
+-  * SAUCE: ksm patch 1, drop after 2.6.31
+-  * SAUCE: ksm patch 2, drop after 2.6.31
+-  * SAUCE: ksm patch 3, drop after 2.6.31
+-  * SAUCE: ksm patch 4, drop after 2.6.31
+-  * SAUCE: ksm patch 5, drop after 2.6.31
+-  * SAUCE: ksm patch 7, drop after 2.6.31
+-
+-  [ Izik Eidus ]
+-
+-  * SAUCE: ksm patch 0, drop after 2.6.31
+-  * SAUCE: ksm patch 6, drop after 2.6.31
+-  * SAUCE: ksm patch 8, drop after 2.6.31
+-  * SAUCE: ksm patch 9, drop after 2.6.31
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Ports: Re-add PS3 modules to udebs
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] Update SPARC config and d-i files to reflect what can be built
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Removed armel package support
+-  * [Config] Enabled CONFIG_KSM=y
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Rebased against v2.6.31-rc6
+-  * ARM: Cleanup: Revert "ARM: Add more cache memory types macros"
+-  * ARM: Cleanup: Revert "Do not use OOB with MLC NAND"
+-  * ARM: Cleanup: Revert "ARM: Make ARM arch aware of ubuntu/ drivers"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make video capture drivers compile"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix isl29003 HWMON driver for i2c
+-    changes"
+-  * ARM: Cleanup: Revert "ARM: IMX51: IPU irq handler deadlock fix"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Babbage 2.5 needs a different system
+-    revision"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Compile-in the IMX51 cpufreq driver
+-    by default"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Enable ZONE_DMA for ARCH_MXC"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make ARCH_MXC auto-enable
+-    ARCH_MXC_CANONICAL"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Unconditionally disable
+-    CONFIG_GPIOLIB"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Minimal changes for USB to work on
+-    2.6.31"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix plat-mxc/timer.c to handle imx51"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Make it compile."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Clean-up the craziness of including
+-    mxc_uart.h _everywhere_"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Move board-mx51* header files to the
+-    correct location"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Changed from snd_card_new to
+-    snd_card_create"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Fix up merge error in Kconfig"
+-  * ARM: Cleanup: Revert "ARM: IMX51: mxc_timer_init prototype"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Removed the mxc_gpio_port structure."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Added external declaration for
+-    mxc_map_io."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
+-  * ARM: Cleanup: Revert "ARM: IMX51: Get to bus_id by calling dev_name."
+-  * ARM: Cleanup: Revert "ARM: IMX51: snd_soc_machine structure replaced
+-    with snd_soc_card."
+-  * ARM: Cleanup: Revert "ARM: IMX51: codec structure was moved to the card
+-    structure"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Hack to add defines for
+-    DMA_MODE_READ/WRITE/MASK"
+-  * ARM: Cleanup: Revert "ARM: IMX51: Add SoC and board support for
+-    Freescale mx51 platform"
+-  * Driver core: add new device to bus's list before probing
+-  * [Upstream] (drop after 2.6.31) ALSA: hda - Reduce click noise at
+-    power-saving
+-    - LP: #381693, #399750, #380892
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 14 Aug 2009 11:32:23 +0100
+-
+-linux (2.6.31-5.24) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * ARM: IMX51: Make video capture drivers compile
+-  * [Config] IMX51: Config updates
+-
+-  [ Andy Whitcroft ]
+-
+-  * remove leftovers of dm-bbr
+-
+-  [ Leann Ogasawara ]
+-
+-  * Add pata_cs5535 to pata-modules
+-    - LP: #318805
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_PPC64=y for powerpc64-smp
+-  * [Config] Set the maximum number of CPUs to 1024 for powerpc64-smp
+-  * [Config] CONFIG_PPC_PS3=y for powerpc64-smp
+-  * [Config] CONFIG_PPC_MAPLE=y on powerpc64-smp
+-  * [Config] CONFIG_PPC_PASEMI=y on powerpc64-smp
+-  * [Config] CONFIG_CPU_FREQ_PMAC64=y on powerpc64-smp
+-  * [Config] Enable all PS3 drivers in powerpc64-smp
+-
+-  [ Mario Limonciello ]
+-
+-  * LIRC -- fix lirc-i2c 2.6.31 compilation
+-
+-  [ Matthew Garrett ]
+-
+-  * [Upstream] dell-laptop: Fix rfkill state queries
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Ignore armel ABI and module changes
+-  * [Config] Update configs after rebase against 2.6.31-rc5
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc5
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 28 Jul 2009 10:10:09 +0100
+-
+-linux (2.6.31-4.23) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * AUFS -- update to aufs2-30 20090727
+-  * [Config] enable AUFS FUSE support
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] CONFIG_JFS_FS=m on sparc
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] dell-laptop: Fix rfkill state setting.
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 27 Jul 2009 11:11:47 +0100
+-
+-linux (2.6.31-4.22) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * ARM: IMX51: Add SoC and board support for Freescale mx51 platform
+-  * ARM: IMX51: Move board-mx51* header files to the correct location
+-  * ARM: IMX51: Clean-up the craziness of including mxc_uart.h _everywhere_
+-  * ARM: IMX51: Make it compile.
+-  * ARM: IMX51: Unconditionally disable CONFIG_GPIOLIB
+-  * ARM: IMX51: Make ARCH_MXC auto-enable ARCH_MXC_CANONICAL
+-  * ARM: IMX51: Enable ZONE_DMA for ARCH_MXC
+-  * ARM: IMX51: Compile-in the IMX51 cpufreq driver by default
+-  * ARM: IMX51: Fix isl29003 HWMON driver for i2c changes
+-  * ARM: USB: musb: Refer to musb_otg_timer_func under correct #ifdef
+-  * ARM: staging: udlfb: Add vmalloc.h include
+-  * UBUNTU [Config]: Bring imx51 config upto date with other flavours
+-
+-  [ Brad Figg ]
+-
+-  * ARM: IMX51: Hack to add defines for DMA_MODE_READ/WRITE/MASK
+-  * ARM: IMX51: codec structure was moved to the card structure
+-  * ARM: IMX51: snd_soc_machine structure replaced with snd_soc_card.
+-  * ARM: IMX51: Get to bus_id by calling dev_name.
+-  * ARM: IMX51: Get to bus_id by calling dev_name.
+-  * ARM: IMX51: Added external declaration for mxc_map_io.
+-  * ARM: IMX51: Removed the mxc_gpio_port structure.
+-  * ARM: IMX51: mxc_timer_init prototype
+-  * ARM: IMX51: Fix up merge error in Kconfig
+-  * ARM: IMX51: Changed from snd_card_new to snd_card_create
+-
+-  [ Dinh Nguyen ]
+-
+-  * ARM: IMX51: Fix plat-mxc/timer.c to handle imx51
+-  * ARM: IMX51: Minimal changes for USB to work on 2.6.31
+-  * ARM: IMX51: Babbage 2.5 needs a different system revision
+-  * ARM: IMX51: IPU irq handler deadlock fix
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CONFIG_CAN=m
+-    - LP: #327243
+-  * [Config] Enabled CONFIG_SERIAL=m
+-    - LP: #397189
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 24 Jul 2009 06:19:10 -0600
+-
+-linux (2.6.31-4.21) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * dm-raid-4-5: Add missing brackets around test_bit()
+-
+-  [ John Johansen ]
+-
+-  * AppArmor: Fix change_profile failing lpn401931
+-  * AppArmor: Fix determination of forced AUDIT messages.
+-  * AppArmor: Fix oops in auditing of the policy interface offset
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 19:18:30 +0100
+-
+-linux (2.6.31-4.20) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: iscsitarget -- update to SVN revision r214
+-  * SAUCE: iscsitarget -- renable driver
+-  * [Config] consolidate lpia/lpia and i386/generic configs
+-  * [Config] enable CRYPTO modules for all architectures
+-  * [Config] enable cryptoloop
+-  * [Config] enable various filesystems for armel
+-  * [Config] sync i386 generic and generic-pae
+-  * [Config] add the 386 (486 processors and above) flavour
+-  * [Config] re-set DEFAULT_MMAP_MIN_ADDR
+-    - LP: #399914
+-  * add genconfigs/genportsconfigs to extract the built configs
+-  * updateconfigs -- alter concatenation order allow easier updates
+-  * intelfb -- INTELFB now conflicts with DRM_I915
+-  * printchanges -- rebase tree does not have stable tags use changelog
+-  * AppArmor: fix argument size missmatch on 64 bit builds
+-
+-  [ Ike Panhc ]
+-
+-  * Ship bnx2x firmware in nic-modules udeb
+-    - LP: #360966
+-
+-  [ Jeff Mahoney ]
+-
+-  * AppArmor: fix build failure on ia64
+-
+-  [ John Johansen ]
+-
+-  * AppArmour: ensure apparmor enabled parmater is off if AppArmor fails to
+-    initialize.
+-  * AppArmour: fix auditing of domain transitions to include target profile
+-    information
+-  * AppArmor: fix C99 violation
+-  * AppArmor: revert reporting of create to write permission.
+-  * SAUCE: Add config option to set a default LSM
+-  * [Config] enable AppArmor by default
+-  * AppArmor: Fix NULL pointer dereference oops in profile attachment.
+-
+-  [ Keith Packard ]
+-
+-  * SAUCE: drm/i915: Allow frame buffers up to 4096x4096 on 915/945 class
+-    hardware
+-    - LP: #351756
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] add .o files found in arch/powerpc/lib to all powerpc kernel
+-    header packages
+-    - LP: #355344
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] update SPARC config files to allow success build
+-
+-  [ Scott James Remnant ]
+-
+-  * SAUCE: trace: add trace_event for the open() syscall
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: jfs: Fix early release of acl in jfs_get_acl
+-    - LP: #396780
+-
+-  [ Tim Gardner ]
+-
+-  * [Upstream] Fix Soltech TA12 volume hotkeys not sending key release
+-    - LP: #397499
+-  * [Upstream] USB Option driver - Add USB ID for Novatel MC727/U727/USB727
+-    refresh
+-    - LP: #365291
+-  * [Config] SSB/B44 are common across all arches/flavours.
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc4
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 23 Jul 2009 08:41:39 +0100
+-
+-linux (2.6.31-3.19) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "[Config] Disabled NDISWRAPPER"
+-  * ndiswrapper -- fix i386 compilation failures on cmpxchg8b
+-  * AUFS -- export various core functions
+-  * AUFS -- export various core functions -- fixes
+-  * AUFS -- core filesystem
+-  * AUFS -- track changes in v2.6.31
+-  * [Config] Enable AUFS
+-  * droppped 'iwl3945: do not send scan command if channel count zero' as it
+-    is already upstream but failed to auto-drop on rebase.
+-
+-  [ Eric Paris ]
+-
+-  * SAUCE: fsnotify: use def_bool in kconfig instead of letting the user
+-    choose
+-  * SAUCE: inotify: check filename before dropping repeat events
+-  * SAUCE: fsnotify: fix inotify tail drop check with path entries
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 14 Jul 2009 12:52:55 +0100
+-
+-linux (2.6.31-3.18) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "Add splice-2.6.23.patch from AUFS to export a symbol needed by
+-    AUFS"
+-  * Revert "Add put_filp.patch from AUFS to export a symbol needed by AUFS"
+-  * Revert "Add sec_perm-2.6.24.patch from AUFS - export
+-    security_inode_permission"
+-  * clear out left over AUFS files and modifications
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] Enable CONFIG_USB_ISP116X_HCD on sparc
+-  * SAUCE: Explicitly include header files to allow apparmor to build on
+-    powerpc
+-  * [Config] Enable CONFIG_BLK_DEV_IDECD on powerpc
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Dropped ubuntu/misc/wireless/acx
+-  * [Config] Disabled NDISWRAPPER until the compile issues are fixed.
+-
+-  [ Upstream ]
+-
+-  * Rebased to 2.6.31-rc3
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 18:59:33 +0100
+-
+-linux (2.6.31-2.17) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_BLK_DEV_CRYPTOLOOP=m for sparc
+-  * compcache -- remove redundant Kconfig entries part 2
+-  * compcache -- clean up CCFLAGS declarations
+-  * [Config] enable AppArmor
+-  * AppArmor: fix operator precidence issue in as_path_link
+-
+-  [ John Johansen ]
+-
+-  * AppArmor security module
+-  * AppArmor: Correct mapping of file permissions.
+-  * AppArmor: Turn auditing of ptrace on
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] disable CONFIG_DM_RAID45 on powerpc
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 10 Jul 2009 15:02:05 +0100
+-
+-linux (2.6.31-2.16) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * compcache -- remove redundant Kconfig entries
+-    added ignore and ignore.modules for all arches since the compcache update
+-    changes the modules names as well as some compcache ABI values.
+-
+-  [ Manoj Iyer ]
+-
+-  * SAUCE: updated dm-raid45 module version to 2009.04.24 (2.6.30-rc3)
+-  * SAUCE: update compcache version to 0.5.3
+-
+-  [ Tim Gardner ]
+-
+-  * [Config]: Fix sparc FTBS by adding ignore.modules
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 06 Jul 2009 13:35:29 -0600
+-
+-linux (2.6.31-2.15) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * SAUCE: default ATI Radeon KMS to off until userspace catches up
+-  * [Config] Update configs following rebase to 2.6.31-rc2
+-  * [Config] update ports configs following update to 2.6.31-rc2
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] powerpc - Disable CONFIG_RDS
+-
+-  [ Matt Zimmerman ]
+-
+-  * Rename linux-doc-PKGVER to linux-doc and clean up its description
+-    - LP: #382115
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to mainline 2.6.31-rc2
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 04 Jul 2009 17:39:13 +0100
+-
+-linux (2.6.31-1.14) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * update ndiswrapper to 1.55
+-  * remove leftovers of gfs
+-  * [Config] powerpc: enable CONFIG_PPC_DISABLE_WERROR
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] re-enable and build the ide-pmac driver into powerpc kernels
+-  * [Config] Build the ServerWorks Frodo / Apple K2 SATA driver into the
+-    kernel
+-
+-  [ Manoj Iyer ]
+-
+-  * Remove snd-bt-sco ubuntu driver
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] updates ia64 config and d-i folders to allow succesful build
+-  * [Config] Update powerpc and sparc for 2.6.31
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * intel-iommu: fix Identity Mapping to be arch independent
+-    - LP: #384695
+-  * ACPI: video: prevent NULL deref in acpi_get_pci_dev()
+-
+- -- Andy Whitcroft <apw@canonical.com>  Tue, 30 Jun 2009 17:47:32 +0100
+-
+-linux (2.6.31-1.13) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * REBASE: rebased to mainline 2.6.31-rc1
+-    - "UBUNTU: SAUCE: UHCI USB quirk for resume"
+-      no longer applies, using deprecated interfaces, LPIA only, dropped
+-    - "UBUNTU: SAUCE: Mask off garbage in Dell WMI scan code data"
+-      changes now upstream, dropped
+-  * [Config] Update configs following rebase to 2.6.31-rc1
+-  * [Config] update ports configs following update to 2.6.31-rc1
+-
+-  * [Config] disable broken staging driver CONFIG_STLC45XX
+-  * SAUCE: fix compcache to use updates accessors
+-  * [Config] disable staging driver CONFIG_VT6655
+-  * SAUCE: fix DRDB to use updates accessors
+-  * [Disable] ndiswrapper needs update
+-  * [Disable] LIRC I2C needs update
+-  * [Disable] CONFIG_LENOVO_SL_LAPTOP needs update
+-  * [Config] disable I2C_DESIGNWARE does not compile
+-  * [Config] disable CONFIG_TLSUP for lpia
+-  * [Config] disable CONFIG_FB_UDL for arm
+-  * SAUCE: disable adding scsi headers to linux-libc-dev
+-
+-  [ Mario Limonciello ]
+-
+-  * SAUCE: Add LIRC drivers
+-
+- -- Andy Whitcroft <apw@canonical.com>  Thu, 25 Jun 2009 12:06:22 +0100
+-
+-linux (2.6.30-10.12) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] split out the ports configs into their own family
+-  * [Config] update configs following introduction of ports family
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * Revert "Rename linux-doc-PKGVER to linux-doc and clean up its
+-    description". Fixes linux-doc package name conflicts for now.
+-    - LP: #382115
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 22 Jun 2009 09:17:14 -0600
+-
+-linux (2.6.30-10.11) karmic; urgency=low
+-
+-  [ Amit Kucheria ]
+-
+-  * [Config] Comment splitconfig.pl and misc cleanup
+-  * [Config] Rename all configs to the new naming scheme
+-  * [Config] Splitconfig rework
+-  * [Config] Rename scripts/misc/oldconfig to kernelconfig
+-  * [Config] Fix build system for new config split
+-  * [Config] Run updateconfigs after the splitconfig rework
+-
+-  [ Andy Whitcroft ]
+-
+-  * Revert "SAUCE: Default to i915.modeset=0 if CONFIG_DRM_I915_KMS=y"
+-  * [Config] standardise CONFIG_STAGING=y
+-  * [Config] standardise CONFIG_RD_LZMA=y
+-  * [Config] CONFIG_PCI_IOV=y
+-  * [Config] CONFIG_PCI_STUB=m
+-  * [Config] merge kernel configs more agressively
+-
+-  [ Colin Watson ]
+-
+-  * [Config] Run kernel-wedge in $(builddir) rather than at the top level
+-  * [Config] Add support for including firmware in udebs
+-  * [Config] Ship bnx2 firmware in nic-modules udeb
+-    - LP: #384861
+-
+-  [ Luke Yelavich ]
+-
+-  * [Config] ports - Import of ports architectures into kernel packaging
+-    infrastructure
+-  * [Config] ports - Do not update ports kernel configurations by default
+-  * [Config] ports - Disable ABI checking for ports architectures
+-  * [Config] ports - Build drivers in ubuntu sub-directory on powerpc
+-  * [Config] ports - Add control.d/vars.* files for ports architectures
+-  * [Config] ports - Add ports architectures for linux-libc-dev
+-  * [Config] ports - Create powerpc specific message-modules and
+-    block-modules udebs
+-  * [Config] ports - Add configuration files for ports architectures
+-
+-  [ Manoj Iyer ]
+-
+-  * [Config] Enable CONFIG_BLK_DEV_AEC62XX=m for amd64 and i386
+-    - LP: #329864
+-
+-  [ Michael Casadevall ]
+-
+-  * [Config] ports - Fix compression of kernels
+-
+-  [ Stefan Bader ]
+-
+-  * [Upstream] mmc: prevent dangling block device from accessing stale
+-    queues
+-    - LP: #383668
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Recommend grub-pc in linux-image
+-    - LP: #385741
+-  * [Config] Implement i386 generic and generic-pae flavours
+-  * [Config] ports - Add control info after integrating ports arches
+-  * [Config] Removed auto-generated files from git
+-  * [Config] Added netxen_nic to nic-modules
+-    - LP: #389603
+-
+-  [ Matt Zimmerman ]
+-
+-  * Rename linux-doc-PKGVER to linux-doc and clean up its description
+-    - LP: #382115
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 15 Jun 2009 14:38:26 -0600
+-
+-linux (2.6.30-9.10) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * [Config] CONFIG_SECURITY_TOMOYO=y (amd64, i386, lpia)
+-  * [Config] CONFIG_KEXEC_JUMP=y (amd64, lpia)
+-  * [Config] CONFIG_LENOVO_SL_LAPTOP=m (amd64, lpia)
+-  * [Config] CONFIG_POHMELFS_CRYPTO=y (i386, amd64)
+-  * [Config] CONFIG_SERIAL_MAX3100=m (i386, amd64, lpia)
+-  * [Config] CONFIG_VIDEO_GO7007=m (amd64, i386)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30 final
+-
+- -- Andy Whitcroft <apw@canonical.com>  Fri, 05 Jun 2009 11:42:53 +0100
+-
+-linux (2.6.30-8.9) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Config update removed the following options:
+-        CONFIG_EDAC_AMD8111=m
+-        CONFIG_EDAC_AMD8131=m
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc8
+-
+- -- Andy Whitcroft <apw@canonical.com>  Wed, 03 Jun 2009 09:21:13 +0100
+-
+-linux (2.6.30-7.8) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Enabled NEW configration options:
+-      Paravirtualization layer for spinlocks (PARAVIRT_SPINLOCKS) [N/y/?] Y
+-      Cisco FNIC Driver (FCOE_FNIC) [N/m/y/?] M
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc7
+-
+- -- Andy Whitcroft <apw@canonical.com>  Sat, 23 May 2009 23:47:24 +0100
+-
+-linux (2.6.30-6.7) karmic; urgency=low
+-
+-  [ Andy Whitcroft ]
+-
+-  * Dropped: UBUNTU: SAUCE: input: Blacklist digitizers from joydev.c (now
+-    upstream)
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc6
+-
+- -- Andy Whitcroft <apw@canonical.com>  Mon, 18 May 2009 18:05:54 +0100
+-
+-linux (2.6.30-5.6) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enable Keyspan USB serial device firmware in kernel module
+-    - LP: #334285
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc5
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Mon, 11 May 2009 12:02:16 -0600
+-
+-linux (2.6.30-4.5) karmic; urgency=low
+-
+-  [ Colin Watson ]
+-
+-  * Build-Conflict with findutils (= 4.4.1-1ubuntu1), to avoid
+-    /usr/include/asm/* going missing
+-    - LP: #373214
+-
+- -- Stefan Bader <stefan.bader@canonical.com>  Fri, 08 May 2009 11:09:08 +0200
+-
+-linux (2.6.30-3.4) karmic; urgency=low
+-
+-  [ Kees Cook ]
+-
+-  * SAUCE: [x86] implement cs-limit nx-emulation for ia32
+-    - LP: #369978
+-
+-  [ Stefan Bader ]
+-
+-  * SAUCE: input: Blacklist digitizers from joydev.c
+-    - LP: #300143
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Fri, 01 May 2009 14:00:42 -0600
+-
+-linux (2.6.30-2.3) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] Enabled CC_STACKPROTECTOR=y for all x86en
+-    - LP: #369152
+-  * SAUCE: Default to i915_modeset=0 if CONFIG_DRM_I915_KMS=y
+-  * [Config] CONFIG_DRM_I915_KMS=y
+-  * [Config] Set CONFIG_SECURITY_DEFAULT_MMAP_MIN_ADDR to appropriate ARCH
+-    minimums
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * rebased to 2.6.30-rc4
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 30 Apr 2009 09:17:05 -0600
+-
+-linux (2.6.30-1.2) karmic; urgency=low
+-
+-  [ Tim Gardner ]
+-
+-  * [Config] armel: disable staging drivers, fixes FTBS
+-  * [Config] armel imx51: Disable CONFIG_MTD_NAND_MXC, fixes FTBS
+-
+-  [ Upstream Kernel Changes ]
+-
+-  * mpt2sas: Change reset_type enum to avoid namespace collision.
+-    Submitted upstream.
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Tue, 28 Apr 2009 16:54:41 -0600
+-
+-linux (2.6.30-1.1) karmic; urgency=low
+-
+-  * Initial release after rebasing against v2.6.30-rc3
+-
+- --  Tim Gardner <tim.gardner@canonical.com>  Thu, 12 Mar 2009 19:16:07 -0600
++ -- Andy Whitcroft <apw@gomeisa.buildd>  Wed, 20 Nov 2013 15:36:29 -0500
+-- 
+1.7.9.5
+
diff --git a/buffalo/ubuntu/0003-configs-based-on-Ubuntu-3.10.0-2.10.patch b/buffalo/ubuntu/0003-configs-based-on-Ubuntu-3.10.0-2.10.patch
new file mode 100644
index 00000000..9a17ca0
--- /dev/null
+++ b/buffalo/ubuntu/0003-configs-based-on-Ubuntu-3.10.0-2.10.patch
@@ -0,0 +1,1895 @@
+From 5def51eadb67034f78c02fe286a05cc8e407966c Mon Sep 17 00:00:00 2001
+From: Andy Whitcroft <apw@gomeisa.buildd>
+Date: Wed, 20 Nov 2013 15:36:40 -0500
+Subject: [PATCH 3/3] configs (based on Ubuntu-3.10.0-2.10)
+
+---
+ debian.master/config/amd64/config.common.amd64     |   13 +-
+ debian.master/config/annotations                   |    2 +-
+ debian.master/config/armhf/config.common.armhf     |   13 +-
+ debian.master/config/armhf/config.flavour.generic  |   12 +-
+ .../config/armhf/config.flavour.generic-lpae       |   14 +-
+ debian.master/config/config.common.ubuntu          |  352 ++++++--------------
+ debian.master/config/enforce                       |    3 +-
+ debian.master/config/i386/config.common.i386       |   13 +-
+ 8 files changed, 134 insertions(+), 288 deletions(-)
+
+diff --git a/debian.master/config/amd64/config.common.amd64 b/debian.master/config/amd64/config.common.amd64
+index 77bf324..bda2471 100644
+--- a/debian.master/config/amd64/config.common.amd64
++++ b/debian.master/config/amd64/config.common.amd64
+@@ -4,7 +4,6 @@
+ CONFIG_64BIT=y
+ CONFIG_AC97_BUS=m
+ CONFIG_ACPI_BLACKLIST_YEAR=0
+-CONFIG_AHCI_IMX=m
+ CONFIG_ARCH_DEFCONFIG="arch/x86/configs/x86_64_defconfig"
+ CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-rdi -fcall-saved-rsi -fcall-saved-rdx -fcall-saved-rcx -fcall-saved-r8 -fcall-saved-r9 -fcall-saved-r10 -fcall-saved-r11"
+ # CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
+@@ -19,7 +18,6 @@ CONFIG_CPU_FREQ=y
+ CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
+ CONFIG_EZX_PCAP=y
+ CONFIG_FB_BACKLIGHT=y
+-CONFIG_FB_BOOT_VESA_SUPPORT=y
+ CONFIG_FB_DDC=m
+ CONFIG_FB_SVGALIB=m
+ CONFIG_FB_SYS_COPYAREA=m
+@@ -28,7 +26,6 @@ CONFIG_FB_SYS_IMAGEBLIT=m
+ # CONFIG_FONTS is not set
+ CONFIG_FUNCTION_TRACER=y
+ CONFIG_GPIO_GENERIC=m
+-CONFIG_GPIO_TWL6040=m
+ # CONFIG_HAVE_AOUT is not set
+ CONFIG_HAVE_BOOTMEM_INFO_NODE=y
+ # CONFIG_HAVE_GENERIC_DMA_COHERENT is not set
+@@ -56,6 +53,7 @@ CONFIG_MTD_SM_COMMON=m
+ CONFIG_MUSB_PIO_ONLY=y
+ CONFIG_NL80211_TESTMODE=y
+ CONFIG_NOP_USB_XCEIV=m
++# CONFIG_NO_HZ_IDLE is not set
+ CONFIG_NR_CPUS=256
+ CONFIG_OMAP_CONTROL_USB=m
+ CONFIG_OUTPUT_FORMAT="elf64-x86-64"
+@@ -71,7 +69,6 @@ CONFIG_REGULATOR_FIXED_VOLTAGE=m
+ CONFIG_RT2800USB_UNKNOWN=y
+ # CONFIG_RT2X00_LIB_DEBUGFS is not set
+ CONFIG_RTC_DRV_CMOS=y
+-CONFIG_SATA_AHCI_PLATFORM=m
+ # CONFIG_SATA_HIGHBANK is not set
+ CONFIG_SCHED_SMT=y
+ CONFIG_SCSI_SPI_ATTRS=y
+@@ -84,7 +81,6 @@ CONFIG_SND_OPL3_LIB_SEQ=m
+ CONFIG_SND_PCM=m
+ # CONFIG_SND_SBAWE_SEQ is not set
+ CONFIG_SND_SOC=m
+-CONFIG_SND_SOC_HDMI_CODEC=m
+ CONFIG_SND_SOC_I2C_AND_SPI=m
+ CONFIG_SND_SOC_SGTL5000=m
+ CONFIG_SND_SOC_TWL6040=m
+@@ -94,8 +90,8 @@ CONFIG_SPARSEMEM_MANUAL=y
+ CONFIG_SPI_PXA2XX_PCI=m
+ CONFIG_STACK_TRACER=y
+ # CONFIG_STANDALONE is not set
+-# CONFIG_TICK_CPU_ACCOUNTING is not set
+ # CONFIG_TWL4030_CORE is not set
++CONFIG_USB_ARCH_HAS_XHCI=y
+ CONFIG_USB_CHIPIDEA=m
+ CONFIG_USB_EHCI_HCD_PLATFORM=y
+ CONFIG_USB_GADGET=m
+@@ -107,8 +103,11 @@ CONFIG_USB_MUSB_TUSB6010=m
+ CONFIG_USB_OHCI_HCD_PLATFORM=y
+ CONFIG_VFIO_IOMMU_TYPE1=m
+ CONFIG_VGASTATE=m
+-CONFIG_VIRTIO_CONSOLE=m
++CONFIG_VIRTIO=y
++CONFIG_VIRTIO_BALLOON=m
++CONFIG_VIRTIO_BLK=y
+ CONFIG_VIRTIO_MMIO=m
++CONFIG_VIRTIO_NET=y
+ CONFIG_WIL6210=m
+ CONFIG_X86_MINIMUM_CPU_FAMILY=64
+ CONFIG_X86_SPEEDSTEP_LIB=m
+diff --git a/debian.master/config/annotations b/debian.master/config/annotations
+index fa9d6ca..7e5722d 100644
+--- a/debian.master/config/annotations
++++ b/debian.master/config/annotations
+@@ -351,7 +351,7 @@ CONFIG_USB_EHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
+ CONFIG_USB_OHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
+ CONFIG_USB_UHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
+ CONFIG_USB_XHCI_HCD				y note<ensures USB 2.0/1.1 probe ordering>
+-CONFIG_USB_OTG					n note<triggers breakage on x86>
++CONFIG_USB_OTG					p policy<(arch armel armhf &/ value y) | value n> note<triggers breakage on x86>
+ #  options:
+ CONFIG_BRCMFMAC_USB				y
+ CONFIG_COMEDI_USB_DRIVERS			y
+diff --git a/debian.master/config/armhf/config.common.armhf b/debian.master/config/armhf/config.common.armhf
+index b9bc1ca..f9d97cb 100644
+--- a/debian.master/config/armhf/config.common.armhf
++++ b/debian.master/config/armhf/config.common.armhf
+@@ -8,7 +8,6 @@ CONFIG_BCH=y
+ # CONFIG_CPU_FREQ is not set
+ CONFIG_DEFAULT_MMAP_MIN_ADDR=32768
+ # CONFIG_EZX_PCAP is not set
+-# CONFIG_FB_BOOT_VESA_SUPPORT is not set
+ CONFIG_FB_SYS_COPYAREA=y
+ CONFIG_FB_SYS_FILLRECT=y
+ CONFIG_FB_SYS_IMAGEBLIT=y
+@@ -17,9 +16,10 @@ CONFIG_FONTS=y
+ # CONFIG_HAVE_AOUT is not set
+ # CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
+ CONFIG_HAVE_GENERIC_DMA_COHERENT=y
++# CONFIG_HUGETLB_PAGE is not set
+ CONFIG_HZ=100
+ # CONFIG_KSM is not set
+-CONFIG_KVM=y
++# CONFIG_KVM is not set
+ # CONFIG_LIBERTAS_MESH is not set
+ # CONFIG_LIS3L02DQ is not set
+ CONFIG_LOG_BUF_SHIFT=17
+@@ -37,6 +37,7 @@ CONFIG_MTD_NAND_ECC=y
+ CONFIG_MTD_NAND_IDS=y
+ # CONFIG_NL80211_TESTMODE is not set
+ CONFIG_NOP_USB_XCEIV=y
++CONFIG_NO_HZ_IDLE=y
+ CONFIG_NR_CPUS=4
+ CONFIG_OMAP_CONTROL_USB=y
+ # CONFIG_PCCARD is not set
+@@ -65,7 +66,6 @@ CONFIG_SND_TIMER=y
+ CONFIG_SOUND=y
+ # CONFIG_STACK_TRACER is not set
+ CONFIG_STANDALONE=y
+-CONFIG_TICK_CPU_ACCOUNTING=y
+ CONFIG_TWL4030_CORE=y
+ CONFIG_USB_CHIPIDEA=y
+ # CONFIG_USB_EHCI_HCD_PLATFORM is not set
+@@ -77,6 +77,9 @@ CONFIG_USB_MUSB_HDRC=y
+ # CONFIG_USB_MUSB_TUSB6010 is not set
+ # CONFIG_USB_OHCI_HCD_PLATFORM is not set
+ # CONFIG_VFIO_IOMMU_TYPE1 is not set
+-CONFIG_VIRTIO_CONSOLE=y
+-CONFIG_VIRTIO_MMIO=y
++# CONFIG_VIRTIO_BALLOON is not set
++# CONFIG_VIRTIO_BLK is not set
++# CONFIG_VIRTIO_MMIO is not set
++# CONFIG_VIRTIO_NET is not set
+ # CONFIG_WIL6210 is not set
++CONFIG_ZONE_DMA_FLAG=0
+diff --git a/debian.master/config/armhf/config.flavour.generic b/debian.master/config/armhf/config.flavour.generic
+index bf21d99..14a1146 100644
+--- a/debian.master/config/armhf/config.flavour.generic
++++ b/debian.master/config/armhf/config.flavour.generic
+@@ -2,7 +2,6 @@
+ # Config options for config.flavour.generic automatically generated by splitconfig.pl
+ #
+ CONFIG_AC97_BUS=y
+-CONFIG_AHCI_IMX=y
+ CONFIG_ARCH_MXC=y
+ CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED=y
+ CONFIG_ARCH_NR_GPIO=1024
+@@ -10,28 +9,23 @@ CONFIG_ARCH_OMAP3=y
+ CONFIG_ARCH_OMAP4=y
+ # CONFIG_ARCH_PHYS_ADDR_T_64BIT is not set
+ CONFIG_ARCH_TEGRA=y
+-CONFIG_ARM_ATAG_DTB_COMPAT=y
+ # CONFIG_ARM_LPAE is not set
+ # CONFIG_COMPACTION is not set
+-# CONFIG_CPU_IDLE_CALXEDA is not set
+ CONFIG_FB_BACKLIGHT=y
+ CONFIG_FB_DDC=m
+ CONFIG_FB_SVGALIB=m
+ CONFIG_GPIO_GENERIC=y
+-CONFIG_GPIO_TWL6040=y
+-# CONFIG_HUGETLB_PAGE is not set
+ CONFIG_MTD_SM_COMMON=m
+ # CONFIG_MUSB_PIO_ONLY is not set
+ CONFIG_PCI_SYSCALL=y
+ # CONFIG_PHYS_ADDR_T_64BIT is not set
+-CONFIG_SATA_AHCI_PLATFORM=y
+ CONFIG_SND_EMU10K1_SEQ=m
+ CONFIG_SND_OPL3_LIB_SEQ=m
+-CONFIG_SND_SOC_HDMI_CODEC=y
+ CONFIG_SND_SOC_SGTL5000=y
+-CONFIG_SND_SOC_TWL4030=y
+ CONFIG_SND_SOC_TWL6040=y
+ CONFIG_SPI_PXA2XX_PCI=m
+ CONFIG_TEGRA_HOST1X=m
++CONFIG_USB_ARCH_HAS_XHCI=y
++CONFIG_USB_INVENTRA_DMA=y
+ CONFIG_VGASTATE=m
+-CONFIG_ZONE_DMA_FLAG=0
++CONFIG_VIRTIO=y
+diff --git a/debian.master/config/armhf/config.flavour.generic-lpae b/debian.master/config/armhf/config.flavour.generic-lpae
+index d5c1b40..c1f7537 100644
+--- a/debian.master/config/armhf/config.flavour.generic-lpae
++++ b/debian.master/config/armhf/config.flavour.generic-lpae
+@@ -2,36 +2,30 @@
+ # Config options for config.flavour.generic-lpae automatically generated by splitconfig.pl
+ #
+ CONFIG_AC97_BUS=m
+-CONFIG_AHCI_IMX=m
+ # CONFIG_ARCH_MXC is not set
+ # CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
+-CONFIG_ARCH_NR_GPIO=0
++CONFIG_ARCH_NR_GPIO=512
+ # CONFIG_ARCH_OMAP3 is not set
+ # CONFIG_ARCH_OMAP4 is not set
+ CONFIG_ARCH_PHYS_ADDR_T_64BIT=y
+ # CONFIG_ARCH_TEGRA is not set
+-# CONFIG_ARM_ATAG_DTB_COMPAT is not set
+ CONFIG_ARM_LPAE=y
+ CONFIG_COMPACTION=y
+-CONFIG_CPU_IDLE_CALXEDA=y
+ # CONFIG_FB_BACKLIGHT is not set
+ # CONFIG_FB_DDC is not set
+ # CONFIG_FB_SVGALIB is not set
+ CONFIG_GPIO_GENERIC=m
+-CONFIG_GPIO_TWL6040=m
+-CONFIG_HUGETLB_PAGE=y
+ # CONFIG_MTD_SM_COMMON is not set
+ CONFIG_MUSB_PIO_ONLY=y
+ # CONFIG_PCI_SYSCALL is not set
+ CONFIG_PHYS_ADDR_T_64BIT=y
+-CONFIG_SATA_AHCI_PLATFORM=m
+ # CONFIG_SND_EMU10K1_SEQ is not set
+ # CONFIG_SND_OPL3_LIB_SEQ is not set
+-CONFIG_SND_SOC_HDMI_CODEC=m
+ CONFIG_SND_SOC_SGTL5000=m
+-CONFIG_SND_SOC_TWL4030=m
+ CONFIG_SND_SOC_TWL6040=m
+ # CONFIG_SPI_PXA2XX_PCI is not set
+ # CONFIG_TEGRA_HOST1X is not set
++# CONFIG_USB_ARCH_HAS_XHCI is not set
++# CONFIG_USB_INVENTRA_DMA is not set
+ # CONFIG_VGASTATE is not set
+-CONFIG_ZONE_DMA_FLAG=1
++CONFIG_VIRTIO=m
+diff --git a/debian.master/config/config.common.ubuntu b/debian.master/config/config.common.ubuntu
+index d6ae2f7..23d4a32 100644
+--- a/debian.master/config/config.common.ubuntu
++++ b/debian.master/config/config.common.ubuntu
+@@ -13,7 +13,6 @@ CONFIG_8139TOO_PIO=y
+ CONFIG_9P_FS=m
+ # CONFIG_9P_FSCACHE is not set
+ CONFIG_9P_FS_POSIX_ACL=y
+-CONFIG_9P_FS_SECURITY=y
+ CONFIG_AB3100_CORE=y
+ CONFIG_AB3100_OTP=m
+ CONFIG_ABX500_CORE=y
+@@ -99,7 +98,6 @@ CONFIG_AD7266=m
+ CONFIG_AD7280=m
+ CONFIG_AD7291=m
+ CONFIG_AD7298=m
+-CONFIG_AD7303=m
+ CONFIG_AD7476=m
+ CONFIG_AD7606=m
+ CONFIG_AD7606_IFACE_PARALLEL=m
+@@ -185,7 +183,6 @@ CONFIG_AIC7XXX_RESET_DELAY_MS=15000
+ CONFIG_AIO=y
+ CONFIG_AIRO=m
+ CONFIG_AIRO_CS=m
+-CONFIG_AIX_PARTITION=y
+ CONFIG_AK8975=m
+ CONFIG_ALIGNMENT_TRAP=y
+ CONFIG_ALIM1535_WDT=m
+@@ -204,7 +201,13 @@ CONFIG_AMD_NUMA=y
+ CONFIG_AMD_PHY=y
+ CONFIG_AMIGA_PARTITION=y
+ CONFIG_AMILO_RFKILL=m
+-# CONFIG_ANDROID is not set
++CONFIG_ANDROID=y
++CONFIG_ANDROID_BINDER_IPC=y
++CONFIG_ANDROID_INTF_ALARM_DEV=y
++CONFIG_ANDROID_LOGGER=m
++CONFIG_ANDROID_LOW_MEMORY_KILLER=y
++CONFIG_ANDROID_TIMED_GPIO=m
++CONFIG_ANDROID_TIMED_OUTPUT=y
+ CONFIG_ANON_INODES=y
+ CONFIG_APB_TIMER=y
+ CONFIG_APDS9802ALS=m
+@@ -219,7 +222,7 @@ CONFIG_APPLE_GMUX=m
+ CONFIG_APPLICOM=m
+ CONFIG_AR5523=m
+ # CONFIG_ARCH_AT91 is not set
+-# CONFIG_ARCH_BCM is not set
++CONFIG_ARCH_BCM=y
+ CONFIG_ARCH_BINFMT_ELF_RANDOMIZE_PIE=y
+ CONFIG_ARCH_CLOCKSOURCE_DATA=y
+ # CONFIG_ARCH_CLPS711X is not set
+@@ -237,7 +240,6 @@ CONFIG_ARCH_FLATMEM_ENABLE=y
+ # CONFIG_ARCH_FOOTBRIDGE is not set
+ # CONFIG_ARCH_GEMINI is not set
+ CONFIG_ARCH_HAS_ATOMIC64_DEC_IF_POSITIVE=y
+-CONFIG_ARCH_HAS_BANDGAP=y
+ CONFIG_ARCH_HAS_CACHE_LINE_SIZE=y
+ CONFIG_ARCH_HAS_CPUFREQ=y
+ CONFIG_ARCH_HAS_CPU_AUTOPROBE=y
+@@ -257,7 +259,6 @@ CONFIG_ARCH_HIGHBANK=y
+ # CONFIG_ARCH_IOP32X is not set
+ # CONFIG_ARCH_IOP33X is not set
+ # CONFIG_ARCH_IXP4XX is not set
+-# CONFIG_ARCH_KEYSTONE is not set
+ # CONFIG_ARCH_KIRKWOOD is not set
+ # CONFIG_ARCH_KS8695 is not set
+ # CONFIG_ARCH_LPC32XX is not set
+@@ -283,7 +284,6 @@ CONFIG_ARCH_PROC_KCORE_TEXT=y
+ CONFIG_ARCH_RANDOM=y
+ # CONFIG_ARCH_REALVIEW is not set
+ CONFIG_ARCH_REQUIRE_GPIOLIB=y
+-# CONFIG_ARCH_ROCKCHIP is not set
+ # CONFIG_ARCH_RPC is not set
+ # CONFIG_ARCH_S3C24XX is not set
+ # CONFIG_ARCH_S3C64XX is not set
+@@ -296,8 +296,7 @@ CONFIG_ARCH_REQUIRE_GPIOLIB=y
+ # CONFIG_ARCH_SIRF is not set
+ # CONFIG_ARCH_SOCFPGA is not set
+ CONFIG_ARCH_SPARSEMEM_ENABLE=y
+-# CONFIG_ARCH_STI is not set
+-# CONFIG_ARCH_SUNXI is not set
++CONFIG_ARCH_SUNXI=y
+ CONFIG_ARCH_SUPPORTS_DEBUG_PAGEALLOC=y
+ CONFIG_ARCH_SUPPORTS_MEMORY_FAILURE=y
+ CONFIG_ARCH_SUPPORTS_MSI=y
+@@ -308,6 +307,7 @@ CONFIG_ARCH_SUSPEND_POSSIBLE=y
+ CONFIG_ARCH_TEGRA_114_SOC=y
+ CONFIG_ARCH_TEGRA_2x_SOC=y
+ CONFIG_ARCH_TEGRA_3x_SOC=y
++# CONFIG_ARCH_U300 is not set
+ # CONFIG_ARCH_U8500 is not set
+ CONFIG_ARCH_USES_NUMA_PROT_NONE=y
+ CONFIG_ARCH_USES_PG_UNCACHED=y
+@@ -316,18 +316,16 @@ CONFIG_ARCH_USE_BUILTIN_BSWAP=y
+ CONFIG_ARCH_VEXPRESS=y
+ CONFIG_ARCH_VEXPRESS_CA9X4=y
+ CONFIG_ARCH_VEXPRESS_CORTEX_A5_A9_ERRATA=y
+-CONFIG_ARCH_VEXPRESS_DCSCB=y
+ CONFIG_ARCH_VIRT=y
++CONFIG_ARCH_VT8500=y
+ # CONFIG_ARCH_W90X900 is not set
+ CONFIG_ARCH_WANTS_PROT_NUMA_PROT_NONE=y
+ CONFIG_ARCH_WANT_COMPAT_IPC_PARSE_VERSION=y
+ CONFIG_ARCH_WANT_FRAME_POINTERS=y
+-CONFIG_ARCH_WANT_GENERAL_HUGETLB=y
+-CONFIG_ARCH_WANT_HUGE_PMD_SHARE=y
+ CONFIG_ARCH_WANT_IPC_PARSE_VERSION=y
+ CONFIG_ARCH_WANT_OLD_COMPAT_IPC=y
+ CONFIG_ARCH_WANT_OPTIONAL_GPIOLIB=y
+-# CONFIG_ARCH_WM8850 is not set
++CONFIG_ARCH_WM8850=y
+ # CONFIG_ARCH_ZYNQ is not set
+ CONFIG_ARCNET=m
+ CONFIG_ARCNET_1051=m
+@@ -341,15 +339,11 @@ CONFIG_ARCNET_COM90xx=m
+ CONFIG_ARCNET_COM90xxIO=m
+ CONFIG_ARCNET_RAW=m
+ CONFIG_ARCNET_RIM_I=m
+-CONFIG_ARC_EMAC=m
+ CONFIG_ARM=y
+ CONFIG_ARM_AMBA=y
+-CONFIG_ARM_APPENDED_DTB=y
++# CONFIG_ARM_APPENDED_DTB is not set
+ CONFIG_ARM_ARCH_TIMER=y
+ CONFIG_ARM_AT91_ETHER=m
+-CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_EXTEND=y
+-# CONFIG_ARM_ATAG_DTB_COMPAT_CMDLINE_FROM_BOOTLOADER is not set
+-CONFIG_ARM_CCI=y
+ CONFIG_ARM_CHARLCD=y
+ CONFIG_ARM_CPU_SUSPEND=y
+ CONFIG_ARM_CPU_TOPOLOGY=y
+@@ -369,14 +363,14 @@ CONFIG_ARM_L1_CACHE_SHIFT_6=y
+ CONFIG_ARM_NR_BANKS=8
+ CONFIG_ARM_PATCH_PHYS_VIRT=y
+ CONFIG_ARM_PSCI=y
+-# CONFIG_ARM_SMMU is not set
+ CONFIG_ARM_SP805_WATCHDOG=m
+ CONFIG_ARM_THUMB=y
+ # CONFIG_ARM_THUMBEE is not set
+ CONFIG_ARM_TIMER_SP804=y
+ CONFIG_ARM_UNWIND=y
+ CONFIG_ARM_VIRT_EXT=y
+-CONFIG_ARPD=y
++# CONFIG_ARPD is not set
++CONFIG_ASHMEM=y
+ CONFIG_ASN1=y
+ CONFIG_ASUS_LAPTOP=m
+ CONFIG_ASUS_NB_WMI=m
+@@ -405,11 +399,6 @@ CONFIG_ATA_OVER_ETH=m
+ CONFIG_ATA_PIIX=y
+ CONFIG_ATA_SFF=y
+ CONFIG_ATA_VERBOSE_ERROR=y
+-CONFIG_ATH10K=m
+-# CONFIG_ATH10K_DEBUG is not set
+-CONFIG_ATH10K_DEBUGFS=y
+-CONFIG_ATH10K_PCI=m
+-CONFIG_ATH10K_TRACING=y
+ CONFIG_ATH5K=m
+ # CONFIG_ATH5K_DEBUG is not set
+ CONFIG_ATH5K_PCI=y
+@@ -428,6 +417,7 @@ CONFIG_ATH9K_HTC=m
+ CONFIG_ATH9K_HTC_DEBUGFS=y
+ CONFIG_ATH9K_HW=m
+ CONFIG_ATH9K_LEGACY_RATE_CONTROL=y
++# CONFIG_ATH9K_MAC_DEBUG is not set
+ CONFIG_ATH9K_PCI=y
+ CONFIG_ATH_CARDS=m
+ CONFIG_ATH_COMMON=m
+@@ -484,25 +474,6 @@ CONFIG_AUDIT_GENERIC=y
+ # CONFIG_AUDIT_LOGINUID_IMMUTABLE is not set
+ CONFIG_AUDIT_TREE=y
+ CONFIG_AUDIT_WATCH=y
+-CONFIG_AUFS_BDEV_LOOP=y
+-# CONFIG_AUFS_BRANCH_MAX_1023 is not set
+-CONFIG_AUFS_BRANCH_MAX_127=y
+-# CONFIG_AUFS_BRANCH_MAX_32767 is not set
+-# CONFIG_AUFS_BRANCH_MAX_511 is not set
+-CONFIG_AUFS_BR_FUSE=y
+-CONFIG_AUFS_BR_HFSPLUS=y
+-CONFIG_AUFS_BR_RAMFS=y
+-# CONFIG_AUFS_DEBUG is not set
+-CONFIG_AUFS_EXPORT=y
+-CONFIG_AUFS_FS=m
+-# CONFIG_AUFS_HNOTIFY is not set
+-CONFIG_AUFS_INO_T_64=y
+-CONFIG_AUFS_POLL=y
+-# CONFIG_AUFS_PROC_MAP is not set
+-# CONFIG_AUFS_RDU is not set
+-CONFIG_AUFS_SBILIST=y
+-# CONFIG_AUFS_SHWH is not set
+-# CONFIG_AUFS_SP_IATTR is not set
+ CONFIG_AUTOFS4_FS=m
+ CONFIG_AUTO_ZRELADDR=y
+ CONFIG_AUXDISPLAY=y
+@@ -524,6 +495,7 @@ CONFIG_B43LEGACY_PCI_AUTOSELECT=y
+ CONFIG_B43LEGACY_PIO=y
+ # CONFIG_B43LEGACY_PIO_MODE is not set
+ CONFIG_B43_BCMA=y
++# CONFIG_B43_BCMA_EXTRA is not set
+ CONFIG_B43_BCMA_PIO=y
+ # CONFIG_B43_DEBUG is not set
+ CONFIG_B43_HWRNG=y
+@@ -934,6 +906,7 @@ CONFIG_CODA_FS=m
+ CONFIG_COMEDI=m
+ CONFIG_COMEDI_8255=m
+ CONFIG_COMEDI_8255_PCI=m
++CONFIG_COMEDI_ACL7225B=m
+ CONFIG_COMEDI_ADDI_APCI_035=m
+ CONFIG_COMEDI_ADDI_APCI_1032=m
+ CONFIG_COMEDI_ADDI_APCI_1500=m
+@@ -1038,12 +1011,14 @@ CONFIG_COMEDI_PARPORT=m
+ CONFIG_COMEDI_PCI_DRIVERS=y
+ CONFIG_COMEDI_PCL711=m
+ CONFIG_COMEDI_PCL724=m
++CONFIG_COMEDI_PCL725=m
+ CONFIG_COMEDI_PCL726=m
+ CONFIG_COMEDI_PCL730=m
+ CONFIG_COMEDI_PCL812=m
+ CONFIG_COMEDI_PCL816=m
+ CONFIG_COMEDI_PCL818=m
+ CONFIG_COMEDI_PCM3724=m
++CONFIG_COMEDI_PCM3730=m
+ CONFIG_COMEDI_PCMAD=m
+ CONFIG_COMEDI_PCMCIA_DRIVERS=y
+ CONFIG_COMEDI_PCMDA12=m
+@@ -1080,14 +1055,13 @@ CONFIG_COMPAT_FOR_U64_ALIGNMENT=y
+ CONFIG_COMPAT_NETLINK_MESSAGES=y
+ CONFIG_COMPAT_OLD_SIGACTION=y
+ # CONFIG_COMPAT_VDSO is not set
+-# CONFIG_COMPILE_TEST is not set
+ CONFIG_CONFIGFS_FS=m
+ CONFIG_CONNECTOR=y
+ CONFIG_CONSOLE_POLL=y
+ CONFIG_CONSOLE_TRANSLATIONS=y
+ CONFIG_CONTEXT_SWITCH_TRACER=y
+ CONFIG_CONTEXT_TRACKING=y
+-# CONFIG_CONTEXT_TRACKING_FORCE is not set
++CONFIG_CONTEXT_TRACKING_FORCE=y
+ CONFIG_COPS=m
+ CONFIG_COPS_DAYNA=y
+ CONFIG_COPS_TANGENT=y
+@@ -1125,6 +1099,7 @@ CONFIG_CPU_FREQ_TABLE=y
+ CONFIG_CPU_HAS_ASID=y
+ # CONFIG_CPU_ICACHE_DISABLE is not set
+ CONFIG_CPU_IDLE=y
++CONFIG_CPU_IDLE_CALXEDA=y
+ CONFIG_CPU_IDLE_GOV_LADDER=y
+ CONFIG_CPU_IDLE_GOV_MENU=y
+ CONFIG_CPU_IDLE_MULTIPLE_DRIVERS=y
+@@ -1193,8 +1168,6 @@ CONFIG_CRYPTO_CRC32=m
+ CONFIG_CRYPTO_CRC32C=y
+ CONFIG_CRYPTO_CRC32C_INTEL=y
+ CONFIG_CRYPTO_CRC32_PCLMUL=m
+-CONFIG_CRYPTO_CRCT10DIF=y
+-CONFIG_CRYPTO_CRCT10DIF_PCLMUL=m
+ CONFIG_CRYPTO_CRYPTD=m
+ CONFIG_CRYPTO_CTR=m
+ CONFIG_CRYPTO_CTS=m
+@@ -1208,7 +1181,6 @@ CONFIG_CRYPTO_DEV_OMAP_SHAM=m
+ CONFIG_CRYPTO_DEV_PADLOCK=y
+ CONFIG_CRYPTO_DEV_PADLOCK_AES=m
+ CONFIG_CRYPTO_DEV_PADLOCK_SHA=m
+-CONFIG_CRYPTO_DEV_SAHARA=m
+ CONFIG_CRYPTO_DEV_TEGRA_AES=m
+ CONFIG_CRYPTO_ECB=y
+ CONFIG_CRYPTO_FCRYPT=m
+@@ -1223,8 +1195,6 @@ CONFIG_CRYPTO_HMAC=y
+ CONFIG_CRYPTO_HW=y
+ CONFIG_CRYPTO_KHAZAD=m
+ CONFIG_CRYPTO_LRW=m
+-CONFIG_CRYPTO_LZ4=m
+-CONFIG_CRYPTO_LZ4HC=m
+ CONFIG_CRYPTO_LZO=y
+ CONFIG_CRYPTO_MANAGER=y
+ CONFIG_CRYPTO_MANAGER2=y
+@@ -1283,10 +1253,8 @@ CONFIG_CRYSTALHD=m
+ # CONFIG_CS5535_MFGPT is not set
+ CONFIG_CS89x0=m
+ CONFIG_CS89x0_PLATFORM=y
++CONFIG_CSR_WIFI=m
+ CONFIG_CUSE=m
+-CONFIG_CW1200=m
+-CONFIG_CW1200_WLAN_SDIO=m
+-CONFIG_CW1200_WLAN_SPI=m
+ CONFIG_CXT1E1=m
+ CONFIG_CYCLADES=m
+ CONFIG_CYPRESS_FIRMWARE=m
+@@ -1352,13 +1320,11 @@ CONFIG_DEBUG_SET_MODULE_RONX=y
+ # CONFIG_DEBUG_VIRTUAL is not set
+ # CONFIG_DEBUG_VM is not set
+ # CONFIG_DEBUG_WRITECOUNT is not set
+-# CONFIG_DEBUG_WW_MUTEX_SLOWPATH is not set
+ CONFIG_DECNET=m
+ CONFIG_DECNET_NF_GRABULATOR=m
+ # CONFIG_DECNET_ROUTER is not set
+ CONFIG_DECOMPRESS_BZIP2=y
+ CONFIG_DECOMPRESS_GZIP=y
+-CONFIG_DECOMPRESS_LZ4=y
+ CONFIG_DECOMPRESS_LZMA=y
+ CONFIG_DECOMPRESS_LZO=y
+ CONFIG_DECOMPRESS_XZ=y
+@@ -1402,18 +1368,6 @@ CONFIG_DEV_APPLETALK=m
+ CONFIG_DE_AOC=y
+ CONFIG_DGRP=m
+ CONFIG_DIRECT_GBPAGES=y
+-CONFIG_DISPLAY_CONNECTOR_ANALOG_TV=m
+-CONFIG_DISPLAY_CONNECTOR_DVI=m
+-CONFIG_DISPLAY_CONNECTOR_HDMI=m
+-CONFIG_DISPLAY_ENCODER_TFP410=m
+-CONFIG_DISPLAY_ENCODER_TPD12S015=m
+-CONFIG_DISPLAY_PANEL_DPI=m
+-CONFIG_DISPLAY_PANEL_DSI_CM=m
+-CONFIG_DISPLAY_PANEL_LGPHILIPS_LB035Q02=m
+-CONFIG_DISPLAY_PANEL_NEC_NL8048HL11=m
+-CONFIG_DISPLAY_PANEL_SHARP_LS037V7DW01=m
+-CONFIG_DISPLAY_PANEL_SONY_ACX565AKM=m
+-CONFIG_DISPLAY_PANEL_TPO_TD043MTEA1=m
+ CONFIG_DL2K=m
+ CONFIG_DLCI=m
+ CONFIG_DLCI_MAX=8
+@@ -1453,9 +1407,7 @@ CONFIG_DM_MULTIPATH_QL=m
+ CONFIG_DM_MULTIPATH_ST=m
+ CONFIG_DM_PERSISTENT_DATA=m
+ CONFIG_DM_RAID=m
+-CONFIG_DM_RAID45=m
+ CONFIG_DM_SNAPSHOT=m
+-CONFIG_DM_SWITCH=m
+ CONFIG_DM_THIN_PROVISIONING=m
+ CONFIG_DM_UEVENT=y
+ CONFIG_DM_VERITY=m
+@@ -1482,7 +1434,12 @@ CONFIG_DRM_I2C_SIL164=m
+ CONFIG_DRM_I810=m
+ CONFIG_DRM_I915=m
+ CONFIG_DRM_I915_KMS=y
+-# CONFIG_DRM_IMX is not set
++CONFIG_DRM_IMX=m
++CONFIG_DRM_IMX_FB_HELPER=m
++CONFIG_DRM_IMX_IPUV3=m
++CONFIG_DRM_IMX_IPUV3_CORE=m
++CONFIG_DRM_IMX_PARALLEL_DISPLAY=m
++CONFIG_DRM_IMX_TVE=m
+ CONFIG_DRM_KMS_CMA_HELPER=y
+ CONFIG_DRM_KMS_HELPER=m
+ CONFIG_DRM_LOAD_EDID_FIRMWARE=y
+@@ -1496,9 +1453,7 @@ CONFIG_DRM_QXL=m
+ CONFIG_DRM_R128=m
+ CONFIG_DRM_RADEON=m
+ CONFIG_DRM_RADEON_UMS=y
+-CONFIG_DRM_RCAR_DU=m
+ CONFIG_DRM_SAVAGE=m
+-CONFIG_DRM_SHMOBILE=m
+ CONFIG_DRM_SIS=m
+ CONFIG_DRM_TDFX=m
+ CONFIG_DRM_TEGRA=y
+@@ -1682,11 +1637,10 @@ CONFIG_DVB_ZL10039=m
+ CONFIG_DVB_ZL10353=m
+ CONFIG_DW_APB_TIMER=y
+ CONFIG_DW_DMAC=m
+-CONFIG_DW_DMAC_CORE=m
+-CONFIG_DW_DMAC_PCI=m
++# CONFIG_DW_DMAC_BIG_ENDIAN_IO is not set
+ CONFIG_DW_WATCHDOG=m
+ CONFIG_DX_SEP=m
+-CONFIG_DYNAMIC_DEBUG=y
++# CONFIG_DYNAMIC_DEBUG is not set
+ CONFIG_DYNAMIC_FTRACE=y
+ CONFIG_DYNAMIC_FTRACE_WITH_REGS=y
+ CONFIG_E100=m
+@@ -1735,12 +1689,11 @@ CONFIG_EEPROM_AT25=m
+ CONFIG_EEPROM_LEGACY=m
+ CONFIG_EEPROM_MAX6875=m
+ CONFIG_EFI=y
+-CONFIG_EFIVAR_FS=y
++CONFIG_EFIVAR_FS=m
+ CONFIG_EFI_PARTITION=y
+ CONFIG_EFI_STUB=y
+ CONFIG_EFI_VARS=y
+-CONFIG_EFI_VARS_PSTORE=m
+-# CONFIG_EFI_VARS_PSTORE_DEFAULT_DISABLE is not set
++# CONFIG_EFI_VARS_PSTORE is not set
+ CONFIG_EFS_FS=m
+ CONFIG_EISA=y
+ CONFIG_EISA_NAMES=y
+@@ -1793,13 +1746,11 @@ CONFIG_EXTCON_ARIZONA=m
+ CONFIG_EXTCON_GPIO=m
+ CONFIG_EXTCON_MAX77693=m
+ CONFIG_EXTCON_MAX8997=m
+-CONFIG_EXTCON_PALMAS=m
+ CONFIG_EXTRA_FIRMWARE=""
+ CONFIG_EXYNOS_ADC=y
+ CONFIG_EXYNOS_VIDEO=y
+ CONFIG_F2FS_FS=m
+ CONFIG_F2FS_FS_POSIX_ACL=y
+-CONFIG_F2FS_FS_SECURITY=y
+ CONFIG_F2FS_FS_XATTR=y
+ CONFIG_F2FS_STAT_FS=y
+ CONFIG_F71808E_WDT=m
+@@ -1829,6 +1780,7 @@ CONFIG_FB_ATY_GX=y
+ CONFIG_FB_AUO_K1900=m
+ CONFIG_FB_AUO_K1901=m
+ CONFIG_FB_AUO_K190X=m
++# CONFIG_FB_BOOT_VESA_SUPPORT is not set
+ CONFIG_FB_BROADSHEET=m
+ CONFIG_FB_CARILLO_RANCH=m
+ CONFIG_FB_CARMINE=m
+@@ -1914,14 +1866,17 @@ CONFIG_FB_TMIO_ACCELL=y
+ CONFIG_FB_TRIDENT=m
+ CONFIG_FB_UDL=m
+ CONFIG_FB_UVESA=m
+-CONFIG_FB_VESA=m
++# CONFIG_FB_VESA is not set
+ CONFIG_FB_VGA16=m
+ CONFIG_FB_VIA=m
+ # CONFIG_FB_VIA_DIRECT_PROCFS is not set
+ CONFIG_FB_VIA_X_COMPATIBILITY=y
+ # CONFIG_FB_VIRTUAL is not set
+ CONFIG_FB_VOODOO1=m
++CONFIG_FB_VT8500=y
+ CONFIG_FB_VT8623=m
++CONFIG_FB_WM8505=y
++CONFIG_FB_WMT_GE_ROPS=y
+ CONFIG_FB_XGI=m
+ CONFIG_FCOE=m
+ CONFIG_FCOE_FNIC=m
+@@ -1946,11 +1901,6 @@ CONFIG_FIX_EARLYCON_MEM=y
+ CONFIG_FLATMEM=y
+ CONFIG_FLATMEM_MANUAL=y
+ CONFIG_FLAT_NODE_MEM_MAP=y
+-CONFIG_FMC=m
+-CONFIG_FMC_CHARDEV=m
+-CONFIG_FMC_FAKEDEV=m
+-CONFIG_FMC_TRIVIAL=m
+-CONFIG_FMC_WRITE_EEPROM=m
+ # CONFIG_FONT_10x18 is not set
+ # CONFIG_FONT_6x11 is not set
+ # CONFIG_FONT_7x14 is not set
+@@ -1961,9 +1911,8 @@ CONFIG_FONT_ACORN_8x8=y
+ # CONFIG_FONT_PEARL_8x8 is not set
+ # CONFIG_FONT_SUN12x22 is not set
+ # CONFIG_FONT_SUN8x16 is not set
+-CONFIG_FONT_SUPPORT=y
+ CONFIG_FORCEDETH=m
+-CONFIG_FORCE_MAX_ZONEORDER=11
++CONFIG_FORCE_MAX_ZONEORDER=12
+ # CONFIG_FPE_FASTFPE is not set
+ CONFIG_FPE_NWFPE=y
+ # CONFIG_FPE_NWFPE_XP is not set
+@@ -2042,11 +1991,9 @@ CONFIG_GENERIC_IRQ_CHIP=y
+ CONFIG_GENERIC_IRQ_PROBE=y
+ CONFIG_GENERIC_IRQ_SHOW=y
+ CONFIG_GENERIC_ISA_DMA=y
+-CONFIG_GENERIC_NET_UTILS=y
+ CONFIG_GENERIC_PCI_IOMAP=y
+ CONFIG_GENERIC_PENDING_IRQ=y
+ CONFIG_GENERIC_PINCONF=y
+-CONFIG_GENERIC_SCHED_CLOCK=y
+ CONFIG_GENERIC_SMP_IDLE_THREAD=y
+ CONFIG_GENERIC_STRNCPY_FROM_USER=y
+ CONFIG_GENERIC_STRNLEN_USER=y
+@@ -2113,6 +2060,7 @@ CONFIG_GPIO_TPS65910=y
+ CONFIG_GPIO_TPS65912=m
+ CONFIG_GPIO_TS5500=m
+ CONFIG_GPIO_TWL4030=y
++CONFIG_GPIO_TWL6040=m
+ CONFIG_GPIO_UCB1400=y
+ CONFIG_GPIO_VIPERBOARD=m
+ CONFIG_GPIO_VX855=m
+@@ -2136,7 +2084,6 @@ CONFIG_HAVE_ARCH_KGDB=y
+ CONFIG_HAVE_ARCH_KMEMCHECK=y
+ CONFIG_HAVE_ARCH_PFN_VALID=y
+ CONFIG_HAVE_ARCH_SECCOMP_FILTER=y
+-CONFIG_HAVE_ARCH_SOFT_DIRTY=y
+ CONFIG_HAVE_ARCH_TRACEHOOK=y
+ CONFIG_HAVE_ARCH_TRANSPARENT_HUGEPAGE=y
+ CONFIG_HAVE_ARM_ARCH_TIMER=y
+@@ -2144,6 +2091,7 @@ CONFIG_HAVE_ARM_SCU=y
+ CONFIG_HAVE_ARM_TWD=y
+ CONFIG_HAVE_ATOMIC_IOMAP=y
+ CONFIG_HAVE_BPF_JIT=y
++CONFIG_HAVE_CAN_FLEXCAN=y
+ CONFIG_HAVE_CLK=y
+ CONFIG_HAVE_CLK_PREPARE=y
+ CONFIG_HAVE_CMPXCHG_DOUBLE=y
+@@ -2151,7 +2099,6 @@ CONFIG_HAVE_CMPXCHG_LOCAL=y
+ CONFIG_HAVE_CONTEXT_TRACKING=y
+ CONFIG_HAVE_C_RECORDMCOUNT=y
+ CONFIG_HAVE_DEBUG_KMEMLEAK=y
+-CONFIG_HAVE_DEBUG_STACKOVERFLOW=y
+ CONFIG_HAVE_DMA_API_DEBUG=y
+ CONFIG_HAVE_DMA_ATTRS=y
+ CONFIG_HAVE_DMA_CONTIGUOUS=y
+@@ -2176,7 +2123,6 @@ CONFIG_HAVE_IOREMAP_PROT=y
+ CONFIG_HAVE_IRQ_TIME_ACCOUNTING=y
+ CONFIG_HAVE_KERNEL_BZIP2=y
+ CONFIG_HAVE_KERNEL_GZIP=y
+-CONFIG_HAVE_KERNEL_LZ4=y
+ CONFIG_HAVE_KERNEL_LZMA=y
+ CONFIG_HAVE_KERNEL_LZO=y
+ CONFIG_HAVE_KERNEL_XZ=y
+@@ -2239,21 +2185,18 @@ CONFIG_HID_ACRUX_FF=y
+ CONFIG_HID_APPLE=m
+ CONFIG_HID_APPLEIR=m
+ CONFIG_HID_AUREAL=m
+-CONFIG_HID_BATTERY_STRENGTH=y
+ CONFIG_HID_BELKIN=m
+ CONFIG_HID_CHERRY=m
+ CONFIG_HID_CHICONY=m
+ CONFIG_HID_CYPRESS=m
+ CONFIG_HID_DRAGONRISE=m
+ CONFIG_HID_ELECOM=m
+-CONFIG_HID_ELO=m
+ CONFIG_HID_EMS_FF=m
+ CONFIG_HID_EZKEY=m
+ CONFIG_HID_GENERIC=m
+ CONFIG_HID_GREENASIA=m
+ CONFIG_HID_GYRATION=m
+ CONFIG_HID_HOLTEK=m
+-CONFIG_HID_HUION=m
+ CONFIG_HID_HYPERV_MOUSE=m
+ CONFIG_HID_ICADE=m
+ CONFIG_HID_KENSINGTON=m
+@@ -2280,6 +2223,7 @@ CONFIG_HID_PICOLCD_LEDS=y
+ CONFIG_HID_PID=y
+ CONFIG_HID_PRIMAX=m
+ CONFIG_HID_PRODIKEYS=m
++CONFIG_HID_PS3REMOTE=m
+ CONFIG_HID_ROCCAT=m
+ CONFIG_HID_SAITEK=m
+ CONFIG_HID_SAMSUNG=m
+@@ -2305,6 +2249,7 @@ CONFIG_HID_UCLOGIC=m
+ CONFIG_HID_WACOM=m
+ CONFIG_HID_WALTOP=m
+ CONFIG_HID_WIIMOTE=m
++CONFIG_HID_WIIMOTE_EXT=y
+ CONFIG_HID_ZEROPLUS=m
+ CONFIG_HID_ZYDACRON=m
+ CONFIG_HIGHMEM=y
+@@ -2366,6 +2311,7 @@ CONFIG_HOSTAP_FIRMWARE_NVRAM=y
+ CONFIG_HOSTAP_PCI=m
+ CONFIG_HOSTAP_PLX=m
+ CONFIG_HOSTESS_SV11=m
++CONFIG_HOTPLUG=y
+ CONFIG_HOTPLUG_CPU=y
+ CONFIG_HOTPLUG_PCI=y
+ CONFIG_HOTPLUG_PCI_ACPI=y
+@@ -2459,9 +2405,9 @@ CONFIG_I2C_HELPER_AUTO=y
+ CONFIG_I2C_HID=m
+ CONFIG_I2C_I801=m
+ CONFIG_I2C_IMX=y
++CONFIG_I2C_INTEL_MID=m
+ CONFIG_I2C_ISCH=m
+ CONFIG_I2C_ISMT=m
+-CONFIG_I2C_KEMPLD=m
+ CONFIG_I2C_MUX=m
+ CONFIG_I2C_MUX_GPIO=m
+ CONFIG_I2C_MUX_PCA9541=m
+@@ -2543,7 +2489,7 @@ CONFIG_IIO_ADIS_LIB_BUFFER=y
+ CONFIG_IIO_BUFFER=y
+ CONFIG_IIO_BUFFER_CB=y
+ CONFIG_IIO_CONSUMERS_PER_TRIGGER=2
+-CONFIG_IIO_INTERRUPT_TRIGGER=m
++CONFIG_IIO_GPIO_TRIGGER=m
+ CONFIG_IIO_KFIFO_BUF=m
+ CONFIG_IIO_PERIODIC_RTC_TRIGGER=m
+ CONFIG_IIO_SIMPLE_DUMMY=m
+@@ -2558,9 +2504,6 @@ CONFIG_IIO_ST_GYRO_SPI_3AXIS=m
+ CONFIG_IIO_ST_MAGN_3AXIS=m
+ CONFIG_IIO_ST_MAGN_I2C_3AXIS=m
+ CONFIG_IIO_ST_MAGN_SPI_3AXIS=m
+-CONFIG_IIO_ST_PRESS=m
+-CONFIG_IIO_ST_PRESS_I2C=m
+-CONFIG_IIO_ST_PRESS_SPI=m
+ CONFIG_IIO_ST_SENSORS_CORE=m
+ CONFIG_IIO_ST_SENSORS_I2C=m
+ CONFIG_IIO_ST_SENSORS_SPI=m
+@@ -2572,7 +2515,6 @@ CONFIG_IIO_TRIGGERED_BUFFER=m
+ # CONFIG_IMX2_WDT is not set
+ # CONFIG_IMX_DMA is not set
+ # CONFIG_IMX_SDMA is not set
+-CONFIG_IMX_WEIM=y
+ CONFIG_INET=y
+ CONFIG_INET6_AH=m
+ CONFIG_INET6_ESP=m
+@@ -2615,7 +2557,6 @@ CONFIG_INFINIBAND_NES=m
+ # CONFIG_INFINIBAND_NES_DEBUG is not set
+ CONFIG_INFINIBAND_OCRDMA=m
+ CONFIG_INFINIBAND_QIB=m
+-CONFIG_INFINIBAND_QIB_DCA=y
+ CONFIG_INFINIBAND_SRP=m
+ CONFIG_INFINIBAND_SRPT=m
+ CONFIG_INFINIBAND_USER_ACCESS=m
+@@ -2695,7 +2636,6 @@ CONFIG_INPUT_YEALINK=m
+ CONFIG_INSTRUCTION_DECODER=y
+ CONFIG_INTEGRITY=y
+ CONFIG_INTEGRITY_ASYMMETRIC_KEYS=y
+-CONFIG_INTEGRITY_AUDIT=y
+ CONFIG_INTEGRITY_SIGNATURE=y
+ CONFIG_INTEL_IDLE=y
+ CONFIG_INTEL_IOATDMA=m
+@@ -2712,11 +2652,9 @@ CONFIG_INTEL_MID_POWER_BUTTON=m
+ CONFIG_INTEL_MID_PTI=m
+ CONFIG_INTEL_OAKTRAIL=m
+ CONFIG_INTEL_POWERCLAMP=m
+-CONFIG_INTEL_RST=m
+ CONFIG_INTEL_SCU_IPC=y
+ CONFIG_INTEL_SCU_IPC_UTIL=m
+ CONFIG_INTEL_SCU_WATCHDOG=y
+-CONFIG_INTEL_SMARTCONNECT=m
+ CONFIG_INTEL_TXT=y
+ CONFIG_INTERVAL_TREE_TEST=m
+ CONFIG_INV_MPU6050_IIO=m
+@@ -2972,6 +2910,7 @@ CONFIG_IWLMVM=m
+ CONFIG_IWLWIFI=m
+ # CONFIG_IWLWIFI_DEBUG is not set
+ CONFIG_IWLWIFI_DEBUGFS=y
++CONFIG_IWLWIFI_DEVICE_TESTMODE=y
+ CONFIG_IWLWIFI_DEVICE_TRACING=y
+ CONFIG_IWLWIFI_OPMODE_MODULAR=y
+ # CONFIG_IWLWIFI_P2P is not set
+@@ -3043,10 +2982,8 @@ CONFIG_KALLSYMS_ALL=y
+ CONFIG_KARMA_PARTITION=y
+ CONFIG_KDB_CONTINUE_CATASTROPHIC=0
+ CONFIG_KDB_KEYBOARD=y
+-CONFIG_KEMPLD_WDT=m
+ # CONFIG_KERNEL_BZIP2 is not set
+ CONFIG_KERNEL_GZIP=y
+-# CONFIG_KERNEL_LZ4 is not set
+ # CONFIG_KERNEL_LZMA is not set
+ # CONFIG_KERNEL_LZO is not set
+ # CONFIG_KERNEL_XZ is not set
+@@ -3110,10 +3047,7 @@ CONFIG_KTIME_SCALAR=y
+ CONFIG_KUSER_HELPERS=y
+ CONFIG_KVM_AMD=m
+ CONFIG_KVM_APIC_ARCHITECTURE=y
+-CONFIG_KVM_ARM_HOST=y
+-CONFIG_KVM_ARM_MAX_VCPUS=4
+-CONFIG_KVM_ARM_TIMER=y
+-CONFIG_KVM_ARM_VGIC=y
++CONFIG_KVM_ARM_MAX_VCPUS=0
+ CONFIG_KVM_ASYNC_PF=y
+ CONFIG_KVM_DEVICE_ASSIGNMENT=y
+ CONFIG_KVM_GUEST=y
+@@ -3123,9 +3057,7 @@ CONFIG_KVM_MMIO=y
+ CONFIG_KXSD9=m
+ CONFIG_L2TP=m
+ CONFIG_L2TP_DEBUGFS=m
+-CONFIG_L2TP_ETH=m
+-CONFIG_L2TP_IP=m
+-CONFIG_L2TP_V3=y
++# CONFIG_L2TP_V3 is not set
+ CONFIG_LANCE=m
+ CONFIG_LANMEDIA=m
+ CONFIG_LAPB=m
+@@ -3263,9 +3195,6 @@ CONFIG_LSI_ET1011C_PHY=y
+ CONFIG_LSM_MMAP_MIN_ADDR=0
+ CONFIG_LTPC=m
+ CONFIG_LXT_PHY=y
+-CONFIG_LZ4HC_COMPRESS=m
+-CONFIG_LZ4_COMPRESS=m
+-CONFIG_LZ4_DECOMPRESS=y
+ CONFIG_LZO_COMPRESS=y
+ CONFIG_LZO_DECOMPRESS=y
+ CONFIG_M25PXX_USE_FAST_READ=y
+@@ -3309,8 +3238,10 @@ CONFIG_MACH_OMAP3EVM=y
+ CONFIG_MACH_OMAP3_BEAGLE=y
+ CONFIG_MACH_OMAP3_PANDORA=y
+ CONFIG_MACH_OMAP3_TORPEDO=y
++CONFIG_MACH_OMAP4_PANDA=y
+ CONFIG_MACH_OMAP_3430SDP=y
+ CONFIG_MACH_OMAP_3630SDP=y
++CONFIG_MACH_OMAP_4430SDP=y
+ CONFIG_MACH_OMAP_GENERIC=y
+ CONFIG_MACH_OMAP_LDP=y
+ CONFIG_MACH_OMAP_ZOOM2=y
+@@ -3339,7 +3270,6 @@ CONFIG_MAX8925_POWER=m
+ CONFIG_MAX_RAW_DEVS=256
+ # CONFIG_MCORE2 is not set
+ CONFIG_MCP2120_DONGLE=m
+-CONFIG_MCP320X=m
+ CONFIG_MCP4725=m
+ CONFIG_MCPM=y
+ # CONFIG_MCRUSOE is not set
+@@ -3432,8 +3362,6 @@ CONFIG_MEMSTICK_REALTEK_PCI=m
+ CONFIG_MEMSTICK_TIFM_MS=m
+ # CONFIG_MEMSTICK_UNSAFE_RESUME is not set
+ CONFIG_MEMTEST=y
+-CONFIG_MEM_SOFT_DIRTY=y
+-CONFIG_MEN_A21_WDT=m
+ CONFIG_MFD_88PM800=m
+ CONFIG_MFD_88PM805=m
+ CONFIG_MFD_88PM860X=y
+@@ -3453,7 +3381,6 @@ CONFIG_MFD_DA9052_SPI=y
+ CONFIG_MFD_DA9055=y
+ CONFIG_MFD_INTEL_MSIC=y
+ CONFIG_MFD_JANZ_CMODIO=m
+-CONFIG_MFD_KEMPLD=m
+ CONFIG_MFD_LM3533=m
+ CONFIG_MFD_LP8788=y
+ CONFIG_MFD_MAX77686=y
+@@ -3508,7 +3435,6 @@ CONFIG_MFD_WM8350=y
+ CONFIG_MFD_WM8350_I2C=y
+ CONFIG_MFD_WM8400=y
+ CONFIG_MFD_WM8994=y
+-CONFIG_MFD_WM8997=y
+ # CONFIG_MGEODEGX1 is not set
+ # CONFIG_MGEODE_LX is not set
+ CONFIG_MG_DISK=m
+@@ -3517,14 +3443,14 @@ CONFIG_MICREL_KS8995MA=m
+ CONFIG_MICREL_PHY=y
+ CONFIG_MICROCODE=m
+ CONFIG_MICROCODE_AMD=y
+-# CONFIG_MICROCODE_AMD_EARLY is not set
++CONFIG_MICROCODE_EARLY=y
+ CONFIG_MICROCODE_INTEL=y
+-# CONFIG_MICROCODE_INTEL_EARLY is not set
++CONFIG_MICROCODE_INTEL_EARLY=y
+ CONFIG_MICROCODE_INTEL_LIB=y
+ CONFIG_MICROCODE_OLD_INTERFACE=y
+ CONFIG_MIGHT_HAVE_CACHE_L2X0=y
+ CONFIG_MIGRATION=y
+-CONFIG_MII=m
++CONFIG_MII=y
+ CONFIG_MINIX_FS=m
+ CONFIG_MINIX_SUBPARTITION=y
+ CONFIG_MISC_FILESYSTEMS=y
+@@ -3551,9 +3477,6 @@ CONFIG_MLX4_CORE=m
+ CONFIG_MLX4_EN=m
+ CONFIG_MLX4_EN_DCB=y
+ CONFIG_MLX4_INFINIBAND=m
+-CONFIG_MLX5_CORE=m
+-# CONFIG_MLX5_DEBUG is not set
+-CONFIG_MLX5_INFINIBAND=m
+ CONFIG_MMC=y
+ CONFIG_MMC_ARMMMCI=y
+ CONFIG_MMC_BLOCK_BOUNCE=y
+@@ -3566,7 +3489,6 @@ CONFIG_MMC_DW_EXYNOS=m
+ # CONFIG_MMC_DW_IDMAC is not set
+ CONFIG_MMC_DW_PCI=m
+ CONFIG_MMC_DW_PLTFM=m
+-CONFIG_MMC_DW_SOCFPGA=m
+ # CONFIG_MMC_MXC is not set
+ CONFIG_MMC_OMAP=m
+ CONFIG_MMC_OMAP_HS=y
+@@ -3590,6 +3512,7 @@ CONFIG_MMC_USHC=m
+ CONFIG_MMC_VIA_SDMMC=m
+ CONFIG_MMC_VUB300=m
+ CONFIG_MMC_WBSD=m
++CONFIG_MMC_WMT=m
+ CONFIG_MMIOTRACE=y
+ # CONFIG_MMIOTRACE_TEST is not set
+ CONFIG_MMU=y
+@@ -3636,6 +3559,7 @@ CONFIG_MOUSE_VSXXXAA=m
+ CONFIG_MOVABLE_NODE=y
+ CONFIG_MOXA_INTELLIO=m
+ CONFIG_MOXA_SMARTIO=m
++CONFIG_MPCORE_WATCHDOG=m
+ # CONFIG_MPENTIUM4 is not set
+ # CONFIG_MPENTIUMII is not set
+ # CONFIG_MPENTIUMIII is not set
+@@ -3950,7 +3874,6 @@ CONFIG_NET_EMATCH_STACK=32
+ CONFIG_NET_EMATCH_TEXT=m
+ CONFIG_NET_EMATCH_U32=m
+ CONFIG_NET_FC=y
+-CONFIG_NET_FLOW_LIMIT=y
+ CONFIG_NET_IPGRE=m
+ CONFIG_NET_IPGRE_BROADCAST=y
+ CONFIG_NET_IPGRE_DEMUX=m
+@@ -3959,12 +3882,10 @@ CONFIG_NET_IPVTI=m
+ CONFIG_NET_IP_TUNNEL=m
+ CONFIG_NET_KEY=m
+ # CONFIG_NET_KEY_MIGRATE is not set
+-CONFIG_NET_MPLS_GSO=m
+ CONFIG_NET_NS=y
+ CONFIG_NET_PACKET_ENGINE=y
+ CONFIG_NET_PKTGEN=m
+ CONFIG_NET_POLL_CONTROLLER=y
+-CONFIG_NET_RX_BUSY_POLL=y
+ CONFIG_NET_SB1000=m
+ CONFIG_NET_SCHED=y
+ CONFIG_NET_SCH_ATM=m
+@@ -3999,7 +3920,6 @@ CONFIG_NET_VENDOR_8390=y
+ CONFIG_NET_VENDOR_ADAPTEC=y
+ CONFIG_NET_VENDOR_ALTEON=y
+ CONFIG_NET_VENDOR_AMD=y
+-CONFIG_NET_VENDOR_ARC=y
+ CONFIG_NET_VENDOR_ATHEROS=y
+ CONFIG_NET_VENDOR_BROADCOM=y
+ CONFIG_NET_VENDOR_BROCADE=y
+@@ -4047,13 +3967,11 @@ CONFIG_NFC_MICROREAD=m
+ CONFIG_NFC_MICROREAD_I2C=m
+ CONFIG_NFC_MICROREAD_MEI=m
+ CONFIG_NFC_NCI=m
+-CONFIG_NFC_NCI_SPI=y
+ CONFIG_NFC_PN533=m
+ CONFIG_NFC_PN544=m
+ CONFIG_NFC_PN544_I2C=m
+ CONFIG_NFC_PN544_MEI=m
+ CONFIG_NFC_SHDLC=y
+-CONFIG_NFC_SIM=m
+ CONFIG_NFC_WILINK=m
+ CONFIG_NFSD=m
+ # CONFIG_NFSD_FAULT_INJECTION is not set
+@@ -4061,7 +3979,6 @@ CONFIG_NFSD_V2_ACL=y
+ CONFIG_NFSD_V3=y
+ CONFIG_NFSD_V3_ACL=y
+ CONFIG_NFSD_V4=y
+-CONFIG_NFSD_V4_SECURITY_LABEL=y
+ CONFIG_NFS_ACL_SUPPORT=m
+ CONFIG_NFS_COMMON=y
+ CONFIG_NFS_DEBUG=y
+@@ -4076,8 +3993,6 @@ CONFIG_NFS_V3_ACL=y
+ CONFIG_NFS_V4=m
+ CONFIG_NFS_V4_1=y
+ CONFIG_NFS_V4_1_IMPLEMENTATION_ID_DOMAIN="kernel.org"
+-CONFIG_NFS_V4_2=y
+-CONFIG_NFS_V4_SECURITY_LABEL=y
+ CONFIG_NFTL=m
+ CONFIG_NFTL_RW=y
+ CONFIG_NF_CONNTRACK=m
+@@ -4131,7 +4046,6 @@ CONFIG_NI65=m
+ CONFIG_NILFS2_FS=m
+ CONFIG_NIU=m
+ CONFIG_NLATTR=y
+-CONFIG_NLMON=m
+ CONFIG_NLS=y
+ CONFIG_NLS_ASCII=m
+ CONFIG_NLS_CODEPAGE_1250=m
+@@ -4195,8 +4109,8 @@ CONFIG_NOZOMI=m
+ CONFIG_NO_BOOTMEM=y
+ CONFIG_NO_HZ=y
+ CONFIG_NO_HZ_COMMON=y
+-# CONFIG_NO_HZ_FULL is not set
+-CONFIG_NO_HZ_IDLE=y
++CONFIG_NO_HZ_FULL=y
++# CONFIG_NO_HZ_FULL_ALL is not set
+ CONFIG_NO_IOPORT=y
+ CONFIG_NS83820=m
+ CONFIG_NSC_FIR=m
+@@ -4226,6 +4140,7 @@ CONFIG_OCFS2_FS_USERSPACE_CLUSTER=m
+ CONFIG_OC_ETM=y
+ CONFIG_OF=y
+ CONFIG_OF_ADDRESS=y
++CONFIG_OF_DEVICE=y
+ CONFIG_OF_EARLY_FLATTREE=y
+ CONFIG_OF_FLATTREE=y
+ CONFIG_OF_GPIO=y
+@@ -4242,7 +4157,6 @@ CONFIG_OID_REGISTRY=y
+ CONFIG_OLD_BELKIN_DONGLE=m
+ CONFIG_OLD_SIGACTION=y
+ CONFIG_OLD_SIGSUSPEND3=y
+-CONFIG_OMAP2PLUS_MBOX=m
+ CONFIG_OMAP2_DSS=y
+ # CONFIG_OMAP2_DSS_DEBUG is not set
+ # CONFIG_OMAP2_DSS_DEBUGFS is not set
+@@ -4259,30 +4173,27 @@ CONFIG_OMAP3_EMU=y
+ # CONFIG_OMAP3_SDRC_AC_TIMING is not set
+ CONFIG_OMAP4_DSS_HDMI=y
+ CONFIG_OMAP4_DSS_HDMI_AUDIO=y
+-CONFIG_OMAP4_THERMAL=y
+ CONFIG_OMAP_32K_TIMER=y
+ CONFIG_OMAP_DM_TIMER=y
+ CONFIG_OMAP_INTERCONNECT=y
+ CONFIG_OMAP_IOMMU=y
+ # CONFIG_OMAP_IOVMM is not set
+-CONFIG_OMAP_MBOX=m
+-CONFIG_OMAP_MBOX_KFIFO_SIZE=256
+ CONFIG_OMAP_MUX=y
+ # CONFIG_OMAP_MUX_DEBUG is not set
+ CONFIG_OMAP_MUX_WARNINGS=y
+ CONFIG_OMAP_OCP2SCP=m
+ CONFIG_OMAP_PACKAGE_CBB=y
++CONFIG_OMAP_PACKAGE_CBL=y
+ CONFIG_OMAP_PACKAGE_CBP=y
++CONFIG_OMAP_PACKAGE_CBS=y
+ CONFIG_OMAP_PACKAGE_CUS=y
+ CONFIG_OMAP_PM_NOOP=y
+-CONFIG_OMAP_REMOTEPROC=m
+ CONFIG_OMAP_RESET_CLOCKS=y
+ CONFIG_OMAP_USB2=y
+ CONFIG_OMAP_USB3=m
+ CONFIG_OMAP_WATCHDOG=m
+ CONFIG_OMFS_FS=m
+ CONFIG_OPENVSWITCH=m
+-CONFIG_OPENVSWITCH_GRE=y
+ CONFIG_OPROFILE=m
+ # CONFIG_OPROFILE_EVENT_MULTIPLEX is not set
+ CONFIG_OPROFILE_NMI_TIMER=y
+@@ -4293,7 +4204,6 @@ CONFIG_ORINOCO_USB=m
+ CONFIG_OSF_PARTITION=y
+ CONFIG_OUTER_CACHE=y
+ CONFIG_OUTER_CACHE_SYNC=y
+-CONFIG_OVERLAYFS_FS=m
+ CONFIG_P54_COMMON=m
+ CONFIG_P54_LEDS=y
+ CONFIG_P54_PCI=m
+@@ -4498,15 +4408,19 @@ CONFIG_PHYSICAL_START=0x1000000
+ CONFIG_PID_NS=y
+ CONFIG_PINCONF=y
+ CONFIG_PINCTRL=y
++CONFIG_PINCTRL_EXYNOS=y
++# CONFIG_PINCTRL_EXYNOS5440 is not set
+ CONFIG_PINCTRL_IMX=y
+ CONFIG_PINCTRL_IMX6Q=y
+-CONFIG_PINCTRL_IMX6SL=y
+-CONFIG_PINCTRL_SINGLE=y
++CONFIG_PINCTRL_SAMSUNG=y
++CONFIG_PINCTRL_SINGLE=m
++CONFIG_PINCTRL_SUNXI=y
+ CONFIG_PINCTRL_TEGRA=y
+ CONFIG_PINCTRL_TEGRA114=y
+ CONFIG_PINCTRL_TEGRA20=y
+ CONFIG_PINCTRL_TEGRA30=y
+-CONFIG_PINCTRL_VF610=y
++CONFIG_PINCTRL_WM8850=y
++CONFIG_PINCTRL_WMT=y
+ CONFIG_PINMUX=y
+ CONFIG_PL310_ERRATA_588369=y
+ CONFIG_PL310_ERRATA_727915=y
+@@ -4525,21 +4439,16 @@ CONFIG_PMBUS=m
+ CONFIG_PMIC_ADP5520=y
+ CONFIG_PMIC_DA903X=y
+ CONFIG_PMIC_DA9052=y
+-CONFIG_PM_ADVANCED_DEBUG=y
+ # CONFIG_PM_AUTOSLEEP is not set
+ CONFIG_PM_CLK=y
+-CONFIG_PM_DEBUG=y
++# CONFIG_PM_DEBUG is not set
+ CONFIG_PM_DEVFREQ=y
+ CONFIG_PM_NOTIFIER_ERROR_INJECT=m
+ CONFIG_PM_OPP=y
+ CONFIG_PM_RUNTIME=y
+ CONFIG_PM_SLEEP=y
+-CONFIG_PM_SLEEP_DEBUG=y
+ CONFIG_PM_SLEEP_SMP=y
+ CONFIG_PM_STD_PARTITION=""
+-# CONFIG_PM_TEST_SUSPEND is not set
+-CONFIG_PM_TRACE=y
+-CONFIG_PM_TRACE_RTC=y
+ CONFIG_PM_WAKELOCKS_GC=y
+ CONFIG_PM_WAKELOCKS_LIMIT=100
+ CONFIG_PNFS_BLOCK=m
+@@ -4615,11 +4524,13 @@ CONFIG_PUBLIC_KEY_ALGO_RSA=y
+ CONFIG_PVPANIC=m
+ CONFIG_PWM=y
+ # CONFIG_PWM_IMX is not set
+-CONFIG_PWM_PCA9685=m
+-CONFIG_PWM_SYSFS=y
+ CONFIG_PWM_TEGRA=m
++CONFIG_PWM_TIECAP=m
++CONFIG_PWM_TIEHRPWM=m
++CONFIG_PWM_TIPWMSS=y
+ CONFIG_PWM_TWL=m
+ CONFIG_PWM_TWL_LED=m
++CONFIG_PWM_VT8500=m
+ CONFIG_QFMT_V1=m
+ CONFIG_QFMT_V2=m
+ CONFIG_QLA3XXX=m
+@@ -4677,6 +4588,7 @@ CONFIG_RAPIDIO_DISC_TIMEOUT=30
+ CONFIG_RAPIDIO_DMA_ENGINE=y
+ # CONFIG_RAPIDIO_ENABLE_RX_TX_PORTS is not set
+ CONFIG_RAPIDIO_ENUM_BASIC=m
++CONFIG_RAPIDIO_TSI500=y
+ CONFIG_RAPIDIO_TSI568=y
+ CONFIG_RAPIDIO_TSI57X=y
+ CONFIG_RAPIDIO_TSI721=y
+@@ -4689,8 +4601,6 @@ CONFIG_RCU_CPU_STALL_TIMEOUT=60
+ CONFIG_RCU_FANOUT_LEAF=16
+ CONFIG_RCU_FAST_NO_HZ=y
+ CONFIG_RCU_NOCB_CPU_ALL=y
+-# CONFIG_RCU_NOCB_CPU_NONE is not set
+-# CONFIG_RCU_NOCB_CPU_ZERO is not set
+ CONFIG_RCU_STALL_COMMON=y
+ # CONFIG_RCU_TORTURE_TEST is not set
+ # CONFIG_RCU_TRACE is not set
+@@ -4706,7 +4616,6 @@ CONFIG_RDS_RDMA=m
+ CONFIG_RDS_TCP=m
+ CONFIG_RD_BZIP2=y
+ CONFIG_RD_GZIP=y
+-CONFIG_RD_LZ4=y
+ CONFIG_RD_LZMA=y
+ CONFIG_RD_LZO=y
+ CONFIG_RD_XZ=y
+@@ -4745,7 +4654,6 @@ CONFIG_REGULATOR_LP8755=m
+ CONFIG_REGULATOR_LP8788=y
+ CONFIG_REGULATOR_MAX1586=m
+ CONFIG_REGULATOR_MAX77686=m
+-CONFIG_REGULATOR_MAX77693=m
+ CONFIG_REGULATOR_MAX8649=m
+ CONFIG_REGULATOR_MAX8660=m
+ CONFIG_REGULATOR_MAX8907=m
+@@ -4763,7 +4671,6 @@ CONFIG_REGULATOR_PCF50633=m
+ CONFIG_REGULATOR_RC5T583=m
+ CONFIG_REGULATOR_S2MPS11=m
+ CONFIG_REGULATOR_S5M8767=m
+-CONFIG_REGULATOR_TI_ABB=y
+ CONFIG_REGULATOR_TPS51632=m
+ CONFIG_REGULATOR_TPS6105X=m
+ CONFIG_REGULATOR_TPS62360=m
+@@ -4818,7 +4725,6 @@ CONFIG_ROMFS_FS=m
+ CONFIG_ROMFS_ON_BLOCK=y
+ CONFIG_ROSE=m
+ CONFIG_RPCSEC_GSS_KRB5=m
+-CONFIG_RPMSG=m
+ CONFIG_RPS=y
+ CONFIG_RT2400PCI=m
+ CONFIG_RT2500PCI=m
+@@ -4890,10 +4796,10 @@ CONFIG_RTC_DRV_MAX8998=m
+ CONFIG_RTC_DRV_MC13XXX=m
+ CONFIG_RTC_DRV_MSM6242=m
+ # CONFIG_RTC_DRV_MXC is not set
++CONFIG_RTC_DRV_OMAP=m
+ CONFIG_RTC_DRV_PALMAS=m
+ CONFIG_RTC_DRV_PCAP=m
+ CONFIG_RTC_DRV_PCF2123=m
+-CONFIG_RTC_DRV_PCF2127=m
+ CONFIG_RTC_DRV_PCF50633=m
+ CONFIG_RTC_DRV_PCF8523=m
+ CONFIG_RTC_DRV_PCF8563=m
+@@ -4920,6 +4826,7 @@ CONFIG_RTC_DRV_TPS80031=m
+ CONFIG_RTC_DRV_TWL4030=y
+ CONFIG_RTC_DRV_V3020=m
+ CONFIG_RTC_DRV_VRTC=m
++CONFIG_RTC_DRV_VT8500=m
+ CONFIG_RTC_DRV_WM831X=m
+ CONFIG_RTC_DRV_WM8350=m
+ CONFIG_RTC_DRV_X1205=m
+@@ -4949,9 +4856,6 @@ CONFIG_RTLLIB_CRYPTO_TKIP=m
+ CONFIG_RTLLIB_CRYPTO_WEP=m
+ CONFIG_RTLWIFI=m
+ # CONFIG_RTLWIFI_DEBUG is not set
+-CONFIG_RTLWIFI_PCI=m
+-CONFIG_RTLWIFI_USB=m
+-CONFIG_RTL_CARDS=m
+ CONFIG_RTS5139=m
+ # CONFIG_RTS5139_DEBUG is not set
+ CONFIG_RT_GROUP_SCHED=y
+@@ -4969,13 +4873,13 @@ CONFIG_SAMSUNG_USB3PHY=m
+ CONFIG_SAMSUNG_USBPHY=m
+ CONFIG_SATA_ACARD_AHCI=m
+ CONFIG_SATA_AHCI=m
++CONFIG_SATA_AHCI_PLATFORM=m
+ CONFIG_SATA_INIC162X=m
+ CONFIG_SATA_MV=m
+ CONFIG_SATA_NV=m
+ CONFIG_SATA_PMP=y
+ CONFIG_SATA_PROMISE=m
+ CONFIG_SATA_QSTOR=m
+-CONFIG_SATA_RCAR=m
+ CONFIG_SATA_SIL=m
+ CONFIG_SATA_SIL24=m
+ CONFIG_SATA_SIS=m
+@@ -5133,6 +5037,7 @@ CONFIG_SCSI_ULTRASTOR=m
+ CONFIG_SCSI_VIRTIO=m
+ CONFIG_SCTP_COOKIE_HMAC_MD5=y
+ CONFIG_SCTP_COOKIE_HMAC_SHA1=y
++# CONFIG_SCTP_DBG_MSG is not set
+ # CONFIG_SCTP_DBG_OBJCNT is not set
+ # CONFIG_SCTP_DEFAULT_COOKIE_HMAC_MD5 is not set
+ # CONFIG_SCTP_DEFAULT_COOKIE_HMAC_NONE is not set
+@@ -5152,9 +5057,6 @@ CONFIG_SECURITY=y
+ CONFIG_SECURITYFS=y
+ CONFIG_SECURITY_APPARMOR=y
+ CONFIG_SECURITY_APPARMOR_BOOTPARAM_VALUE=1
+-CONFIG_SECURITY_APPARMOR_HASH=y
+-# CONFIG_SECURITY_APPARMOR_STATS is not set
+-CONFIG_SECURITY_APPARMOR_UNCONFINED_INIT=y
+ # CONFIG_SECURITY_DMESG_RESTRICT is not set
+ CONFIG_SECURITY_NETWORK=y
+ # CONFIG_SECURITY_NETWORK_XFRM is not set
+@@ -5225,7 +5127,6 @@ CONFIG_SENSORS_F75375S=m
+ CONFIG_SENSORS_FAM15H_POWER=m
+ CONFIG_SENSORS_FSCHMD=m
+ CONFIG_SENSORS_G760A=m
+-CONFIG_SENSORS_G762=m
+ CONFIG_SENSORS_GL518SM=m
+ CONFIG_SENSORS_GL520SM=m
+ CONFIG_SENSORS_GPIO_FAN=m
+@@ -5360,7 +5261,6 @@ CONFIG_SERIAL_ARC=m
+ CONFIG_SERIAL_ARC_NR_PORTS=1
+ CONFIG_SERIAL_CORE=y
+ CONFIG_SERIAL_CORE_CONSOLE=y
+-CONFIG_SERIAL_FSL_LPUART=m
+ # CONFIG_SERIAL_IFX6X60 is not set
+ CONFIG_SERIAL_IMX=y
+ CONFIG_SERIAL_IMX_CONSOLE=y
+@@ -5372,7 +5272,7 @@ CONFIG_SERIAL_MAX310X=y
+ CONFIG_SERIAL_MFD_HSU=m
+ CONFIG_SERIAL_MRST_MAX3110=m
+ CONFIG_SERIAL_NONSTANDARD=y
+-CONFIG_SERIAL_OF_PLATFORM=y
++CONFIG_SERIAL_OF_PLATFORM=m
+ CONFIG_SERIAL_OMAP=y
+ CONFIG_SERIAL_OMAP_CONSOLE=y
+ CONFIG_SERIAL_PCH_UART=m
+@@ -5383,6 +5283,8 @@ CONFIG_SERIAL_SCCNXP_CONSOLE=y
+ CONFIG_SERIAL_TEGRA=m
+ CONFIG_SERIAL_TIMBERDALE=m
+ CONFIG_SERIAL_UARTLITE=m
++CONFIG_SERIAL_VT8500=y
++CONFIG_SERIAL_VT8500_CONSOLE=y
+ CONFIG_SERIAL_XILINX_PS_UART=m
+ CONFIG_SERIO=y
+ CONFIG_SERIO_ALTERA_PS2=m
+@@ -5393,7 +5295,6 @@ CONFIG_SERIO_CT82C710=m
+ CONFIG_SERIO_I8042=y
+ CONFIG_SERIO_LIBPS2=y
+ CONFIG_SERIO_NVEC_PS2=m
+-CONFIG_SERIO_OLPC_APSP=m
+ CONFIG_SERIO_PARKBD=m
+ CONFIG_SERIO_PCIPS2=m
+ CONFIG_SERIO_PS2MULT=m
+@@ -5407,7 +5308,6 @@ CONFIG_SFI=y
+ CONFIG_SGI_IOC4=m
+ CONFIG_SGI_PARTITION=y
+ CONFIG_SHMEM=y
+-CONFIG_SH_ETH=m
+ CONFIG_SIGMATEL_FIR=m
+ CONFIG_SIGNALFD=y
+ CONFIG_SIGNATURE=y
+@@ -5429,7 +5329,6 @@ CONFIG_SLIP_MODE_SLIP6=y
+ CONFIG_SLIP_SMART=y
+ # CONFIG_SLOB is not set
+ CONFIG_SLUB=y
+-CONFIG_SLUB_CPU_PARTIAL=y
+ CONFIG_SLUB_DEBUG=y
+ # CONFIG_SLUB_DEBUG_ON is not set
+ # CONFIG_SLUB_STATS is not set
+@@ -5538,7 +5437,6 @@ CONFIG_SND_HDA_CODEC_VIA=y
+ CONFIG_SND_HDA_DSP_LOADER=y
+ CONFIG_SND_HDA_GENERIC=y
+ CONFIG_SND_HDA_HWDEP=y
+-CONFIG_SND_HDA_I915=y
+ CONFIG_SND_HDA_INPUT_BEEP=y
+ CONFIG_SND_HDA_INPUT_BEEP_MODE=0
+ CONFIG_SND_HDA_INPUT_JACK=y
+@@ -5575,7 +5473,6 @@ CONFIG_SND_LOLA=m
+ CONFIG_SND_LX6464ES=m
+ CONFIG_SND_MAESTRO3=m
+ CONFIG_SND_MAESTRO3_INPUT=y
+-CONFIG_SND_MAX_CARDS=32
+ CONFIG_SND_MFLD_MACHINE=m
+ CONFIG_SND_MIA=m
+ CONFIG_SND_MIRO=m
+@@ -5657,7 +5554,6 @@ CONFIG_SND_SOC_ALC5623=m
+ CONFIG_SND_SOC_ALC5632=m
+ CONFIG_SND_SOC_ALL_CODECS=m
+ CONFIG_SND_SOC_ARIZONA=m
+-CONFIG_SND_SOC_BT_SCO=m
+ CONFIG_SND_SOC_CS4270=m
+ CONFIG_SND_SOC_CS4271=m
+ CONFIG_SND_SOC_CS42L51=m
+@@ -5668,6 +5564,7 @@ CONFIG_SND_SOC_DA7210=m
+ CONFIG_SND_SOC_DA7213=m
+ CONFIG_SND_SOC_DA732X=m
+ CONFIG_SND_SOC_DA9055=m
++CONFIG_SND_SOC_DFBMCS320=m
+ CONFIG_SND_SOC_DMAENGINE_PCM=y
+ CONFIG_SND_SOC_DMIC=y
+ CONFIG_SND_SOC_FSL_SSI=y
+@@ -5675,10 +5572,10 @@ CONFIG_SND_SOC_FSL_UTILS=y
+ CONFIG_SND_SOC_GENERIC_DMAENGINE_PCM=y
+ CONFIG_SND_SOC_IMX_AUDMUX=y
+ CONFIG_SND_SOC_IMX_MC13783=m
++CONFIG_SND_SOC_IMX_PCM=y
+ CONFIG_SND_SOC_IMX_PCM_DMA=y
+ CONFIG_SND_SOC_IMX_SGTL5000=y
+ CONFIG_SND_SOC_IMX_SSI=m
+-CONFIG_SND_SOC_IMX_WM8962=m
+ CONFIG_SND_SOC_ISABELLE=m
+ CONFIG_SND_SOC_JZ4740_CODEC=m
+ CONFIG_SND_SOC_L3=m
+@@ -5692,13 +5589,12 @@ CONFIG_SND_SOC_MAX9850=m
+ CONFIG_SND_SOC_MAX9877=m
+ CONFIG_SND_SOC_MC13783=m
+ CONFIG_SND_SOC_ML26124=m
++CONFIG_SND_SOC_OMAP_HDMI_CODEC=y
+ CONFIG_SND_SOC_PCM3008=m
+ CONFIG_SND_SOC_RT5631=m
+-CONFIG_SND_SOC_RT5640=m
+ CONFIG_SND_SOC_SI476X=m
+ CONFIG_SND_SOC_SN95031=m
+ CONFIG_SND_SOC_SPDIF=m
+-CONFIG_SND_SOC_SSM2518=m
+ CONFIG_SND_SOC_SSM2602=m
+ CONFIG_SND_SOC_STA32X=m
+ CONFIG_SND_SOC_STA529=m
+@@ -5712,7 +5608,6 @@ CONFIG_SND_SOC_TEGRA20_SPDIF=m
+ CONFIG_SND_SOC_TEGRA30_AHUB=m
+ CONFIG_SND_SOC_TEGRA30_I2S=m
+ CONFIG_SND_SOC_TEGRA_ALC5632=m
+-CONFIG_SND_SOC_TEGRA_RT5640=m
+ CONFIG_SND_SOC_TEGRA_TRIMSLICE=m
+ CONFIG_SND_SOC_TEGRA_WM8753=m
+ CONFIG_SND_SOC_TEGRA_WM8903=m
+@@ -5723,6 +5618,7 @@ CONFIG_SND_SOC_TLV320AIC32X4=m
+ CONFIG_SND_SOC_TLV320AIC3X=m
+ CONFIG_SND_SOC_TLV320DAC33=m
+ CONFIG_SND_SOC_TPA6130A2=m
++CONFIG_SND_SOC_TWL4030=y
+ CONFIG_SND_SOC_UDA134X=m
+ CONFIG_SND_SOC_UDA1380=m
+ CONFIG_SND_SOC_WL1273=m
+@@ -5789,7 +5685,6 @@ CONFIG_SND_USB_6FIRE=m
+ CONFIG_SND_USB_AUDIO=m
+ CONFIG_SND_USB_CAIAQ=m
+ CONFIG_SND_USB_CAIAQ_INPUT=y
+-CONFIG_SND_USB_HIFACE=m
+ CONFIG_SND_USB_UA101=m
+ CONFIG_SND_USB_US122L=m
+ CONFIG_SND_USB_USX2Y=m
+@@ -5806,8 +5701,7 @@ CONFIG_SND_VX_LIB=m
+ CONFIG_SND_WAVEFRONT=m
+ CONFIG_SND_WSS_LIB=m
+ CONFIG_SND_YMFPCI=m
+-# CONFIG_SOC_AM33XX is not set
+-# CONFIG_SOC_AM43XX is not set
++CONFIG_SOC_AM33XX=y
+ CONFIG_SOC_BUS=y
+ CONFIG_SOC_CAMERA=m
+ CONFIG_SOC_CAMERA_IMX074=m
+@@ -5824,16 +5718,14 @@ CONFIG_SOC_CAMERA_OV9640=m
+ CONFIG_SOC_CAMERA_OV9740=m
+ CONFIG_SOC_CAMERA_PLATFORM=m
+ CONFIG_SOC_CAMERA_RJ54N1=m
+-CONFIG_SOC_CAMERA_SCALE_CROP=m
+ CONFIG_SOC_CAMERA_TW9910=m
+ CONFIG_SOC_HAS_OMAP2_SDRC=y
++CONFIG_SOC_HAS_REALTIME_COUNTER=y
+ # CONFIG_SOC_IMX53 is not set
+ CONFIG_SOC_IMX6Q=y
+-CONFIG_SOC_IMX6SL=y
+ CONFIG_SOC_OMAP3430=y
+-# CONFIG_SOC_OMAP5 is not set
++CONFIG_SOC_OMAP5=y
+ CONFIG_SOC_TI81XX=y
+-CONFIG_SOC_VF610=y
+ CONFIG_SOFT_WATCHDOG=m
+ CONFIG_SOLARIS_X86_PARTITION=y
+ CONFIG_SOLO6X10=m
+@@ -5883,7 +5775,7 @@ CONFIG_SPI_IMX=m
+ CONFIG_SPI_LM70_LLP=m
+ CONFIG_SPI_MASTER=y
+ CONFIG_SPI_OC_TINY=m
+-CONFIG_SPI_OMAP24XX=y
++CONFIG_SPI_OMAP24XX=m
+ CONFIG_SPI_PL022=m
+ CONFIG_SPI_PXA2XX=m
+ CONFIG_SPI_PXA2XX_DMA=y
+@@ -5907,6 +5799,7 @@ CONFIG_SQUASHFS_XZ=y
+ CONFIG_SQUASHFS_ZLIB=y
+ CONFIG_SRAM=y
+ CONFIG_SSB=m
++CONFIG_SSBI=m
+ CONFIG_SSB_B43_PCI_BRIDGE=y
+ CONFIG_SSB_BLOCKIO=y
+ # CONFIG_SSB_DEBUG is not set
+@@ -5927,6 +5820,7 @@ CONFIG_STACKTRACE=y
+ CONFIG_STACKTRACE_SUPPORT=y
+ CONFIG_STAGING=y
+ CONFIG_STAGING_MEDIA=y
++CONFIG_STALDRV=y
+ CONFIG_STE10XP=y
+ CONFIG_STE_MODEM_RPROC=m
+ # CONFIG_STMMAC_DA is not set
+@@ -5941,6 +5835,7 @@ CONFIG_STOP_MACHINE=y
+ CONFIG_STP=m
+ CONFIG_STRICT_DEVMEM=y
+ # CONFIG_STRIP_ASM_SYMS is not set
++CONFIG_SUN4I_TIMER=y
+ CONFIG_SUNDANCE=m
+ # CONFIG_SUNDANCE_MMIO is not set
+ CONFIG_SUNGEM=m
+@@ -5958,6 +5853,9 @@ CONFIG_SWAP=y
+ CONFIG_SWIOTLB=y
+ CONFIG_SWIOTLB_XEN=y
+ CONFIG_SWP_EMULATE=y
++CONFIG_SW_SYNC=y
++CONFIG_SW_SYNC_USER=y
++CONFIG_SYNC=y
+ CONFIG_SYNCLINK=m
+ CONFIG_SYNCLINKMP=m
+ CONFIG_SYNCLINK_CS=m
+@@ -5975,7 +5873,6 @@ CONFIG_SYSVIPC_SYSCTL=y
+ CONFIG_SYSV_FS=m
+ CONFIG_SYS_HYPERVISOR=y
+ CONFIG_SYS_SUPPORTS_APM_EMULATION=y
+-CONFIG_SYS_SUPPORTS_HUGETLBFS=y
+ CONFIG_TABLET_USB_ACECAD=m
+ CONFIG_TABLET_USB_AIPTEK=m
+ CONFIG_TABLET_USB_GTCO=m
+@@ -6053,6 +5950,7 @@ CONFIG_THINKPAD_ACPI_HOTKEY_POLL=y
+ CONFIG_THINKPAD_ACPI_VIDEO=y
+ CONFIG_THRUSTMASTER_FF=y
+ # CONFIG_THUMB2_KERNEL is not set
++CONFIG_TICK_CPU_ACCOUNTING=y
+ CONFIG_TICK_ONESHOT=y
+ CONFIG_TIFM_7XX1=m
+ CONFIG_TIFM_CORE=m
+@@ -6065,14 +5963,12 @@ CONFIG_TIPC_MEDIA_IB=y
+ CONFIG_TIPC_PORTS=8191
+ CONFIG_TI_ADC081C=m
+ CONFIG_TI_AM335X_ADC=m
++# CONFIG_TI_CPSW is not set
+ CONFIG_TI_DAC7512=m
+ CONFIG_TI_DAVINCI_CPDMA=m
+ CONFIG_TI_DAVINCI_EMAC=m
+ CONFIG_TI_DAVINCI_MDIO=m
+-CONFIG_TI_EDMA=y
+ CONFIG_TI_EMIF=m
+-CONFIG_TI_PRIV_EDMA=y
+-CONFIG_TI_SOC_THERMAL=m
+ CONFIG_TI_ST=m
+ CONFIG_TLAN=m
+ CONFIG_TMD_HERMES=m
+@@ -6095,9 +5991,6 @@ CONFIG_TOUCHSCREEN_AUO_PIXCIR=m
+ CONFIG_TOUCHSCREEN_BU21013=m
+ CONFIG_TOUCHSCREEN_CLEARPAD_TM1217=m
+ CONFIG_TOUCHSCREEN_CY8CTMG110=m
+-CONFIG_TOUCHSCREEN_CYTTSP4_CORE=m
+-CONFIG_TOUCHSCREEN_CYTTSP4_I2C=m
+-CONFIG_TOUCHSCREEN_CYTTSP4_SPI=m
+ CONFIG_TOUCHSCREEN_CYTTSP_CORE=m
+ CONFIG_TOUCHSCREEN_CYTTSP_I2C=m
+ CONFIG_TOUCHSCREEN_CYTTSP_SPI=m
+@@ -6250,11 +6143,11 @@ CONFIG_USB_ANNOUNCE_NEW_DEVICES=y
+ CONFIG_USB_APPLEDISPLAY=m
+ CONFIG_USB_ARCH_HAS_EHCI=y
+ CONFIG_USB_ARCH_HAS_HCD=y
++CONFIG_USB_ARCH_HAS_OHCI=y
+ CONFIG_USB_ARMLINUX=y
+ CONFIG_USB_ATM=m
+ CONFIG_USB_AUDIO=m
+ CONFIG_USB_BELKIN=y
+-CONFIG_USB_BTMTK=m
+ CONFIG_USB_C67X00_HCD=m
+ CONFIG_USB_CATC=m
+ CONFIG_USB_CDC_COMPOSITE=m
+@@ -6263,16 +6156,6 @@ CONFIG_USB_CDC_PHONET=m
+ CONFIG_USB_CHIPIDEA_HOST=y
+ CONFIG_USB_CHIPIDEA_UDC=y
+ CONFIG_USB_COMMON=y
+-CONFIG_USB_CONFIGFS=m
+-CONFIG_USB_CONFIGFS_ACM=y
+-CONFIG_USB_CONFIGFS_ECM=y
+-CONFIG_USB_CONFIGFS_ECM_SUBSET=y
+-CONFIG_USB_CONFIGFS_EEM=y
+-CONFIG_USB_CONFIGFS_NCM=y
+-CONFIG_USB_CONFIGFS_OBEX=y
+-CONFIG_USB_CONFIGFS_PHONET=y
+-CONFIG_USB_CONFIGFS_RNDIS=y
+-CONFIG_USB_CONFIGFS_SERIAL=y
+ CONFIG_USB_CXACRU=m
+ CONFIG_USB_CYPRESS_CY7C63=m
+ CONFIG_USB_CYTHERM=m
+@@ -6305,7 +6188,6 @@ CONFIG_USB_ETH=m
+ CONFIG_USB_ETH_EEM=y
+ CONFIG_USB_ETH_RNDIS=y
+ CONFIG_USB_EZUSB_FX2=m
+-CONFIG_USB_FOTG210_UDC=m
+ # CONFIG_USB_FSL_USB2 is not set
+ CONFIG_USB_FTDI_ELAN=m
+ CONFIG_USB_FUNCTIONFS=m
+@@ -6313,21 +6195,15 @@ CONFIG_USB_FUNCTIONFS_ETH=y
+ CONFIG_USB_FUNCTIONFS_GENERIC=y
+ CONFIG_USB_FUNCTIONFS_RNDIS=y
+ CONFIG_USB_FUSB300=m
+-CONFIG_USB_FUSBH200_HCD=m
+ CONFIG_USB_F_ACM=m
+-CONFIG_USB_F_ECM=m
+-CONFIG_USB_F_EEM=m
+-CONFIG_USB_F_NCM=m
+ CONFIG_USB_F_OBEX=m
+-CONFIG_USB_F_PHONET=m
+-CONFIG_USB_F_RNDIS=m
+ CONFIG_USB_F_SERIAL=m
+ CONFIG_USB_F_SS_LB=m
+-CONFIG_USB_F_SUBSET=m
+ CONFIG_USB_GADGETFS=m
+ # CONFIG_USB_GADGET_DEBUG is not set
+ # CONFIG_USB_GADGET_DEBUG_FILES is not set
+ # CONFIG_USB_GADGET_DEBUG_FS is not set
++CONFIG_USB_GADGET_MUSB_HDRC=m
+ CONFIG_USB_GADGET_STORAGE_NUM_BUFFERS=2
+ CONFIG_USB_GADGET_TARGET=m
+ CONFIG_USB_GADGET_VBUS_DRAW=2
+@@ -6397,7 +6273,6 @@ CONFIG_USB_HSO=m
+ CONFIG_USB_HWA_HCD=m
+ CONFIG_USB_IDMOUSE=m
+ # CONFIG_USB_IMX21_HCD is not set
+-CONFIG_USB_INVENTRA_DMA=y
+ CONFIG_USB_IOWARRIOR=m
+ CONFIG_USB_IPHETH=m
+ CONFIG_USB_IRDA=m
+@@ -6427,9 +6302,6 @@ CONFIG_USB_MOUSE=m
+ CONFIG_USB_MR800=m
+ # CONFIG_USB_MUSB_AM35X is not set
+ # CONFIG_USB_MUSB_DSPS is not set
+-CONFIG_USB_MUSB_DUAL_ROLE=y
+-# CONFIG_USB_MUSB_GADGET is not set
+-# CONFIG_USB_MUSB_HOST is not set
+ CONFIG_USB_MUSB_OMAP2PLUS=m
+ CONFIG_USB_MUSB_UX500=m
+ CONFIG_USB_MV_U3D=m
+@@ -6463,9 +6335,8 @@ CONFIG_USB_NET_ZAURUS=m
+ # CONFIG_USB_OHCI_BIG_ENDIAN_MMIO is not set
+ CONFIG_USB_OHCI_HCD=y
+ CONFIG_USB_OHCI_HCD_OMAP3=y
+-CONFIG_USB_OHCI_HCD_PCI=m
+ CONFIG_USB_OHCI_LITTLE_ENDIAN=y
+-# CONFIG_USB_OTG is not set
++CONFIG_USB_OTG=y
+ # CONFIG_USB_OTG_BLACKLIST_HUB is not set
+ # CONFIG_USB_OTG_WHITELIST is not set
+ CONFIG_USB_OXU210HP_HCD=m
+@@ -6500,7 +6371,6 @@ CONFIG_USB_SERIAL_EDGEPORT=m
+ CONFIG_USB_SERIAL_EDGEPORT_TI=m
+ CONFIG_USB_SERIAL_EMPEG=m
+ CONFIG_USB_SERIAL_F81232=m
+-CONFIG_USB_SERIAL_FLASHLOADER=m
+ CONFIG_USB_SERIAL_FTDI_SIO=m
+ CONFIG_USB_SERIAL_FUNSOFT=m
+ CONFIG_USB_SERIAL_GARMIN=m
+@@ -6548,7 +6418,6 @@ CONFIG_USB_SERIAL_SIEMENS_MPI=m
+ CONFIG_USB_SERIAL_SIERRAWIRELESS=m
+ CONFIG_USB_SERIAL_SPCP8X5=m
+ CONFIG_USB_SERIAL_SSU100=m
+-CONFIG_USB_SERIAL_SUUNTO=m
+ CONFIG_USB_SERIAL_SYMBOL=m
+ CONFIG_USB_SERIAL_TI=m
+ CONFIG_USB_SERIAL_VISOR=m
+@@ -6595,13 +6464,13 @@ CONFIG_USB_TRANCEVIBRATOR=m
+ CONFIG_USB_U132_HCD=m
+ CONFIG_USB_UEAGLEATM=m
+ CONFIG_USB_UHCI_HCD=y
++CONFIG_USB_UHCI_PLATFORM=y
++CONFIG_USB_UHCI_SUPPORT_NON_PCI_HC=y
+ CONFIG_USB_ULPI=y
+ CONFIG_USB_ULPI_VIEWPORT=y
+ CONFIG_USB_USBNET=m
+ CONFIG_USB_USS720=m
+ # CONFIG_USB_UX500_DMA is not set
+-CONFIG_USB_U_ETHER=m
+-CONFIG_USB_U_RNDIS=m
+ CONFIG_USB_U_SERIAL=m
+ CONFIG_USB_VIDEO_CLASS=m
+ CONFIG_USB_VIDEO_CLASS_INPUT_EVDEV=y
+@@ -6619,6 +6488,7 @@ CONFIG_USB_XUSBATM=m
+ CONFIG_USB_YUREX=m
+ CONFIG_USB_ZD1201=m
+ CONFIG_USB_ZERO=m
++CONFIG_USB_ZERO_HNPTEST=y
+ CONFIG_USB_ZR364XX=m
+ CONFIG_USER_RETURN_NOTIFIER=y
+ CONFIG_USER_STACKTRACE_SUPPORT=y
+@@ -6637,7 +6507,6 @@ CONFIG_V4L_RADIO_ISA_DRIVERS=y
+ CONFIG_V4L_TEST_DRIVERS=y
+ CONFIG_VCNL4000=m
+ CONFIG_VECTORS_BASE=0xffff0000
+-CONFIG_VERSION_SIGNATURE=""
+ CONFIG_VETH=m
+ CONFIG_VEXPRESS_CONFIG=y
+ CONFIG_VFAT_FS=y
+@@ -6646,13 +6515,11 @@ CONFIG_VFIO_PCI=m
+ CONFIG_VFIO_PCI_VGA=y
+ CONFIG_VFP=y
+ CONFIG_VFPv3=y
+-CONFIG_VF_PIT_TIMER=y
+ # CONFIG_VGACON_SOFT_SCROLLBACK is not set
+ CONFIG_VGA_ARB=y
+ CONFIG_VGA_ARB_MAX_GPUS=16
+ CONFIG_VGA_CONSOLE=y
+ CONFIG_VGA_SWITCHEROO=y
+-CONFIG_VHOST=m
+ CONFIG_VHOST_NET=m
+ CONFIG_VHOST_RING=m
+ CONFIG_VHOST_SCSI=m
+@@ -6783,7 +6650,6 @@ CONFIG_VIDEO_TW9906=m
+ CONFIG_VIDEO_UDA1342=m
+ CONFIG_VIDEO_UPD64031A=m
+ CONFIG_VIDEO_UPD64083=m
+-CONFIG_VIDEO_USBTV=m
+ CONFIG_VIDEO_USBVISION=m
+ CONFIG_VIDEO_V4L2=m
+ CONFIG_VIDEO_V4L2_INT_DEVICE=m
+@@ -6803,11 +6669,8 @@ CONFIG_VIDEO_ZORAN_LML33=m
+ CONFIG_VIDEO_ZORAN_LML33R10=m
+ CONFIG_VIDEO_ZORAN_ZR36060=m
+ CONFIG_VIPERBOARD_ADC=m
+-CONFIG_VIRTIO=y
+-CONFIG_VIRTIO_BALLOON=m
+-CONFIG_VIRTIO_BLK=y
++CONFIG_VIRTIO_CONSOLE=m
+ CONFIG_VIRTIO_MMIO_CMDLINE_DEVICES=y
+-CONFIG_VIRTIO_NET=y
+ CONFIG_VIRTIO_PCI=y
+ CONFIG_VIRTUALIZATION=y
+ CONFIG_VIRT_CPU_ACCOUNTING=y
+@@ -6840,6 +6703,7 @@ CONFIG_VSOCKETS=m
+ CONFIG_VT=y
+ CONFIG_VT6655=m
+ CONFIG_VT6656=m
++CONFIG_VT8500_TIMER=y
+ CONFIG_VT_CONSOLE=y
+ CONFIG_VT_CONSOLE_SLEEP=y
+ CONFIG_VT_HW_CONSOLE_BINDING=y
+@@ -6889,7 +6753,6 @@ CONFIG_WEXT_PRIV=y
+ CONFIG_WEXT_PROC=y
+ CONFIG_WEXT_SPY=y
+ CONFIG_WIL6210_ISR_COR=y
+-CONFIG_WIL6210_TRACING=y
+ CONFIG_WILINK_PLATFORM_DATA=y
+ CONFIG_WIMAX=m
+ CONFIG_WIMAX_DEBUG_LEVEL=8
+@@ -6929,7 +6792,6 @@ CONFIG_WM831X_POWER=m
+ CONFIG_WM831X_WATCHDOG=m
+ CONFIG_WM8350_POWER=m
+ CONFIG_WM8350_WATCHDOG=m
+-CONFIG_WQ_POWER_EFFICIENT_DEFAULT=y
+ CONFIG_X25=m
+ CONFIG_X25_ASY=m
+ CONFIG_X509_CERTIFICATE_PARSER=y
+@@ -6954,7 +6816,6 @@ CONFIG_X86_CMPXCHG64=y
+ CONFIG_X86_CPUFREQ_NFORCE2=y
+ CONFIG_X86_CPUID=m
+ CONFIG_X86_DEBUGCTLMSR=y
+-# CONFIG_X86_DEBUG_STATIC_CPU_HAS is not set
+ # CONFIG_X86_DECODER_SELFTEST is not set
+ CONFIG_X86_DEV_DMA_OPS=y
+ CONFIG_X86_EXTENDED_PLATFORM=y
+@@ -6987,7 +6848,6 @@ CONFIG_X86_P4_CLOCKMOD=m
+ CONFIG_X86_PAE=y
+ CONFIG_X86_PAT=y
+ CONFIG_X86_PCC_CPUFREQ=y
+-CONFIG_X86_PKG_TEMP_THERMAL=m
+ CONFIG_X86_PLATFORM_DEVICES=y
+ CONFIG_X86_PM_TIMER=y
+ CONFIG_X86_POWERNOW_K6=m
+@@ -7082,7 +6942,6 @@ CONFIG_YENTA_TI=y
+ CONFIG_YENTA_TOSHIBA=y
+ CONFIG_ZBOOT_ROM_BSS=0x0
+ CONFIG_ZBOOT_ROM_TEXT=0x0
+-CONFIG_ZBUD=y
+ CONFIG_ZCACHE=y
+ # CONFIG_ZCACHE_DEBUG is not set
+ CONFIG_ZD1211RW=m
+@@ -7095,4 +6954,3 @@ CONFIG_ZONE_DMA=y
+ CONFIG_ZRAM=m
+ # CONFIG_ZRAM_DEBUG is not set
+ CONFIG_ZSMALLOC=y
+-CONFIG_ZSWAP=y
+diff --git a/debian.master/config/enforce b/debian.master/config/enforce
+index 41f2391..5dcccc2 100644
+--- a/debian.master/config/enforce
++++ b/debian.master/config/enforce
+@@ -12,7 +12,6 @@ value CONFIG_SECURITY_SMACK y
+ value CONFIG_SECURITY_YAMA y
+ value CONFIG_SYN_COOKIES y
+ value CONFIG_DEFAULT_SECURITY_APPARMOR y
+-value CONFIG_DEBUG_INFO y
+ # For architectures which support this option ensure it is enabled.
+ !exists CONFIG_XEN_ACPI_PROCESSOR | value CONFIG_XEN_ACPI_PROCESSOR y
+ !exists CONFIG_SECCOMP | value CONFIG_SECCOMP y
+@@ -62,7 +61,7 @@ value CONFIG_FB_VESA m | !exists CONFIG_FB_VESA
+ value CONFIG_INPUT_UINPUT y
+ 
+ # upstart relies on getting all of the kernel arguments
+-#value CONFIG_INIT_PASS_ALL_PARAMS y
++value CONFIG_INIT_PASS_ALL_PARAMS y
+ 
+ # Enabling CONFIG_IMA is vastly expensive, ensure it is off
+ value CONFIG_IMA n
+diff --git a/debian.master/config/i386/config.common.i386 b/debian.master/config/i386/config.common.i386
+index bd7149d..aa07638 100644
+--- a/debian.master/config/i386/config.common.i386
++++ b/debian.master/config/i386/config.common.i386
+@@ -4,7 +4,6 @@
+ # CONFIG_64BIT is not set
+ CONFIG_AC97_BUS=m
+ CONFIG_ACPI_BLACKLIST_YEAR=2000
+-CONFIG_AHCI_IMX=m
+ CONFIG_ARCH_DEFCONFIG="arch/x86/configs/i386_defconfig"
+ CONFIG_ARCH_HWEIGHT_CFLAGS="-fcall-saved-ecx -fcall-saved-edx"
+ # CONFIG_ARCH_NEEDS_CPU_IDLE_COUPLED is not set
+@@ -18,7 +17,6 @@ CONFIG_CPU_FREQ=y
+ CONFIG_DEFAULT_MMAP_MIN_ADDR=65536
+ CONFIG_EZX_PCAP=y
+ CONFIG_FB_BACKLIGHT=y
+-CONFIG_FB_BOOT_VESA_SUPPORT=y
+ CONFIG_FB_DDC=m
+ CONFIG_FB_SVGALIB=m
+ CONFIG_FB_SYS_COPYAREA=m
+@@ -27,7 +25,6 @@ CONFIG_FB_SYS_IMAGEBLIT=m
+ # CONFIG_FONTS is not set
+ CONFIG_FUNCTION_TRACER=y
+ CONFIG_GPIO_GENERIC=m
+-CONFIG_GPIO_TWL6040=m
+ CONFIG_HAVE_AOUT=y
+ # CONFIG_HAVE_BOOTMEM_INFO_NODE is not set
+ CONFIG_HAVE_GENERIC_DMA_COHERENT=y
+@@ -55,6 +52,7 @@ CONFIG_MTD_SM_COMMON=m
+ CONFIG_MUSB_PIO_ONLY=y
+ CONFIG_NL80211_TESTMODE=y
+ CONFIG_NOP_USB_XCEIV=m
++CONFIG_NO_HZ_IDLE=y
+ CONFIG_NR_CPUS=8
+ CONFIG_OMAP_CONTROL_USB=m
+ CONFIG_OUTPUT_FORMAT="elf32-i386"
+@@ -69,7 +67,6 @@ CONFIG_REGULATOR_FIXED_VOLTAGE=m
+ CONFIG_RT2800USB_UNKNOWN=y
+ # CONFIG_RT2X00_LIB_DEBUGFS is not set
+ CONFIG_RTC_DRV_CMOS=y
+-CONFIG_SATA_AHCI_PLATFORM=m
+ # CONFIG_SATA_HIGHBANK is not set
+ CONFIG_SCHED_SMT=y
+ CONFIG_SCSI_SPI_ATTRS=y
+@@ -82,7 +79,6 @@ CONFIG_SND_OPL4_LIB_SEQ=m
+ CONFIG_SND_PCM=m
+ CONFIG_SND_SBAWE_SEQ=m
+ CONFIG_SND_SOC=m
+-CONFIG_SND_SOC_HDMI_CODEC=m
+ CONFIG_SND_SOC_I2C_AND_SPI=m
+ CONFIG_SND_SOC_SGTL5000=m
+ CONFIG_SND_SOC_TWL6040=m
+@@ -92,8 +88,8 @@ CONFIG_SOUND=m
+ CONFIG_SPI_PXA2XX_PCI=m
+ CONFIG_STACK_TRACER=y
+ # CONFIG_STANDALONE is not set
+-CONFIG_TICK_CPU_ACCOUNTING=y
+ # CONFIG_TWL4030_CORE is not set
++CONFIG_USB_ARCH_HAS_XHCI=y
+ CONFIG_USB_CHIPIDEA=m
+ CONFIG_USB_EHCI_HCD_PLATFORM=y
+ CONFIG_USB_GADGET=m
+@@ -105,8 +101,11 @@ CONFIG_USB_MUSB_TUSB6010=m
+ CONFIG_USB_OHCI_HCD_PLATFORM=y
+ CONFIG_VFIO_IOMMU_TYPE1=m
+ CONFIG_VGASTATE=m
+-CONFIG_VIRTIO_CONSOLE=m
++CONFIG_VIRTIO=y
++CONFIG_VIRTIO_BALLOON=m
++CONFIG_VIRTIO_BLK=y
+ CONFIG_VIRTIO_MMIO=m
++CONFIG_VIRTIO_NET=y
+ CONFIG_WIL6210=m
+ CONFIG_X86_MINIMUM_CPU_FAMILY=5
+ CONFIG_X86_SPEEDSTEP_LIB=y
+-- 
+1.7.9.5
+
diff --git a/drivers/ata/ahci.c b/drivers/ata/ahci.c
index ed23df8..8d369ed 100644
--- a/drivers/ata/ahci.c
+++ b/drivers/ata/ahci.c
@@ -146,7 +146,11 @@ static const struct ata_port_info ahci_port_info[] = {
 		.flags		= AHCI_FLAG_COMMON,
 		.pio_mask	= ATA_PIO4,
 		.udma_mask	= ATA_UDMA6,
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		.port_ops	= &ahci_al_ops,
+#else /*CONFIG_BUFFALO_ALPINE_PLATFORM*/
 		.port_ops	= &ahci_ops,
+#endif /*CONFIG_BUFFALO_ALPINE_PLATFORM*/
 	},
 	/* by chipsets */
 	[board_ahci_mcp65] = {
@@ -1161,6 +1165,47 @@ static ssize_t al_ahci_store_msix_moder(struct device *dev,
 }
 
 
+static ssize_t al_ahci_show_sss_enabled(struct device *dev,
+		struct device_attribute *attr, char *buf)
+{
+	struct ata_host *host = dev_get_drvdata(dev);
+	struct ahci_host_priv *hpriv = host->private_data;
+	ssize_t rc = 0;
+
+	rc = sprintf(buf, "%d\n", (int)hpriv->sss_enabled);
+
+	return rc;
+}
+
+static ssize_t al_ahci_store_sss_enabled(struct device *dev,
+		struct device_attribute *attr,
+		const char *buf, size_t len)
+{
+	struct ata_host *host = dev_get_drvdata(dev);
+	struct ahci_host_priv *hpriv = host->private_data;
+	unsigned long sss_enabled = 0;
+	int err;
+
+	err = kstrtoul(buf, 10, &sss_enabled);
+	if (err < 0)
+		return err;
+
+	if (sss_enabled == 0)
+		hpriv->sss_enabled = false;
+	else
+		hpriv->sss_enabled = true;
+
+	return len;
+}
+
+
+static struct device_attribute dev_attr_sss = {
+	.attr = {.name = "sss_enabled", .mode = (S_IRUGO | S_IWUSR)},
+	.show = al_ahci_show_sss_enabled,
+	.store = al_ahci_store_sss_enabled,
+};
+
+
 static struct device_attribute dev_attr_moder = {
 	.attr = {.name = "msix_moder", .mode = (S_IRUGO | S_IWUSR)},
 	.show = al_ahci_show_msix_moder,
@@ -1173,6 +1218,9 @@ int al_ahci_sysfs_init(
 	if (device_create_file(dev, &dev_attr_moder))
 		dev_err(dev, "failed to create msix interrupt moderation sysfs entry");
 
+	if (device_create_file(dev, &dev_attr_sss))
+		dev_err(dev, "failed to create sss support sysfs entry");
+
 	return 0;
 }
 
@@ -1400,6 +1448,7 @@ static int ahci_init_one(struct pci_dev *pdev, const struct pci_device_id *ent)
 	struct ata_host *host;
 #ifdef CONFIG_ARCH_ALPINE
 	struct device_node	*np;
+	extern unsigned int al_sss_enable;
 #endif
 	int n_ports, n_msis, i, rc;
 	int ahci_pci_bar = AHCI_PCI_BAR_STANDARD;
@@ -1516,6 +1565,8 @@ static int ahci_init_one(struct pci_dev *pdev, const struct pci_device_id *ent)
 	ahci_set_em_messages(hpriv, &pi);
 
 #ifdef CONFIG_ARCH_ALPINE
+	hpriv->sss_enabled = (bool)al_sss_enable;
+
 	for (i = 0; i < AHCI_MAX_PORTS; i++)
 		hpriv->led_gpio[i] = -1;
 
diff --git a/drivers/ata/ahci.h b/drivers/ata/ahci.h
index 2c27bce..5d3dafe 100644
--- a/drivers/ata/ahci.h
+++ b/drivers/ata/ahci.h
@@ -324,10 +324,14 @@ struct ahci_host_priv {
 	u32			em_msg_type;	/* EM message type */
 	struct clk		*clk;		/* Only for platforms supporting clk */
 
+#ifdef CONFIG_ARCH_ALPINE
 	struct msix_entry *msix_entries;
 	unsigned int msix_vecs;
 	unsigned int		int_moderation;
 	int			led_gpio[AHCI_MAX_PORTS];
+
+	bool 		sss_enabled;
+#endif
 };
 
 extern int ahci_ignore_sss;
diff --git a/drivers/ata/libahci.c b/drivers/ata/libahci.c
index 96656b6..c81c598 100644
--- a/drivers/ata/libahci.c
+++ b/drivers/ata/libahci.c
@@ -93,7 +93,7 @@ static void ahci_postreset(struct ata_link *link, unsigned int *class);
 static void ahci_error_handler(struct ata_port *ap);
 static void ahci_post_internal_cmd(struct ata_queued_cmd *qc);
 static void ahci_dev_config(struct ata_device *dev);
-#ifdef CONFIG_PM
+#if defined(CONFIG_PM) || defined (CONFIG_ARCH_ALPINE)
 static int ahci_port_suspend(struct ata_port *ap, pm_message_t mesg);
 #endif
 static ssize_t ahci_activity_show(struct ata_device *dev, char *buf);
@@ -414,6 +414,11 @@ void ahci_save_initial_config(struct device *dev,
 	 * reset.  Values without are used for driver operation.
 	 */
 	hpriv->saved_cap = cap = readl(mmio + HOST_CAP);
+#ifdef CONFIG_ARCH_ALPINE
+	/*Enable staggered spin up support*/
+	cap |= HOST_CAP_SSS;
+	hpriv->saved_cap |= HOST_CAP_SSS;
+#endif
 	hpriv->saved_port_map = port_map = readl(mmio + HOST_PORTS_IMPL);
 
 	/* CAP2 register is only defined for AHCI 1.2 and later */
@@ -916,7 +921,11 @@ static void ahci_sw_activity_blink(unsigned long arg)
 
 		if ((ata_phys_link_online(link)) || (emp->blink_policy == BLINK_OFF))
 			led_message |= (1 << 16);
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+		mod_timer(&emp->timer, jiffies + msecs_to_jiffies(200));
+#else /* CONFIG_BUFFALO_ALPINE_PLATFORM */
 		mod_timer(&emp->timer, jiffies + msecs_to_jiffies(500));
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
 	}
 	spin_unlock_irqrestore(ap->lock, flags);
 	ap->ops->transmit_led_message(ap, led_message, 4);
@@ -928,6 +937,11 @@ static void ahci_init_sw_activity(struct ata_link *link)
 	struct ahci_port_priv *pp = ap->private_data;
 	struct ahci_em_priv *emp = &pp->em_priv[link->pmp];
 
+#ifdef CONFIG_BUFFALO_ALPINE_PLATFORM
+	/* ahci_start_port() can be called multiply on Alpine platform */
+	if (timer_pending(&emp->timer))
+		return;
+#endif /* CONFIG_BUFFALO_ALPINE_PLATFORM */
 	/* init activity stats, setup timer */
 	emp->saved_activity = emp->activity = 0;
 	emp->blink_policy = BLINK_ON;
@@ -2243,7 +2257,53 @@ int ahci_port_resume(struct ata_port *ap)
 }
 EXPORT_SYMBOL_GPL(ahci_port_resume);
 
-#ifdef CONFIG_PM
+#ifdef CONFIG_ARCH_ALPINE
+
+bool al_sss_enabled(struct ata_port *ap)
+{
+	struct ahci_host_priv *hpriv = ap->host->private_data;
+	return hpriv->sss_enabled;
+}
+
+
+void al_ahci_port_activate(struct ata_port *ap)
+{
+	struct ahci_host_priv *hpriv = ap->host->private_data;
+	void __iomem *port_mmio = ahci_port_base(ap);
+	u32 cmd;
+
+	cmd = readl(port_mmio + PORT_CMD) & ~PORT_CMD_ICC_MASK;
+	/* spin up device */
+	if (hpriv->cap & HOST_CAP_SSS) {
+		cmd |= PORT_CMD_SPIN_UP;
+		writel(cmd, port_mmio + PORT_CMD);
+	}
+	/* wake up link */
+	writel(cmd | PORT_CMD_ICC_ACTIVE, port_mmio + PORT_CMD);
+}
+
+
+void al_ahci_port_start(struct ata_port *ap)
+{
+	ahci_start_port(ap);
+
+	if (sata_pmp_attached(ap))
+		ahci_pmp_attach(ap);
+	else
+		ahci_pmp_detach(ap);
+}
+
+void al_ahci_port_stop(struct ata_port *ap)
+{
+	const pm_message_t dummy = {
+		.event = 1,
+	};
+	/*Same as port suspend*/
+	ahci_port_suspend(ap, dummy);
+}
+#endif
+
+#if defined(CONFIG_PM) || defined (CONFIG_ARCH_ALPINE)
 static int ahci_port_suspend(struct ata_port *ap, pm_message_t mesg)
 {
 	const char *emsg = NULL;
diff --git a/drivers/ata/libata-core.c b/drivers/ata/libata-core.c
index adf002a3..bf5568f 100644
--- a/drivers/ata/libata-core.c
+++ b/drivers/ata/libata-core.c
@@ -98,6 +98,13 @@ static unsigned int ata_dev_set_xfermode(struct ata_device *dev);
 static void ata_dev_xfermask(struct ata_device *dev);
 static unsigned long ata_dev_blacklisted(const struct ata_device *dev);
 
+#ifdef CONFIG_ARCH_ALPINE
+void al_ahci_port_start(struct ata_port *ap);
+void al_ahci_port_stop(struct ata_port *ap);
+void al_ahci_port_activate(struct ata_port *ap);
+bool al_sss_enabled(struct ata_port *ap);
+#endif
+
 atomic_t ata_print_id = ATOMIC_INIT(0);
 
 struct ata_force_param {
@@ -169,6 +176,71 @@ MODULE_DESCRIPTION("Library module for ATA devices");
 MODULE_LICENSE("GPL");
 MODULE_VERSION(DRV_VERSION);
 
+#if defined(CONFIG_ARCH_ALPINE)
+
+static inline int al_sata_phy_reset(struct ata_link *link)
+{
+	int rc;
+	u32 scontrol;
+	if ((rc = sata_scr_read(link, SCR_CONTROL, &scontrol)))
+		return rc;
+	/*Speed negotiation is not finished, reset SATA link once again*/
+	scontrol = (scontrol & 0x0f0) | 0x301;
+	if ((rc = sata_scr_write_flush(link, SCR_CONTROL, scontrol)))
+		return rc;
+	ata_msleep(link->ap, 1);
+	scontrol = (scontrol & 0x0f0) | 0x300;
+	return sata_scr_write_flush(link, SCR_CONTROL, scontrol);
+}
+
+static int al_sata_link_hardreset(struct ata_link *link, const unsigned long *timing,
+			unsigned long deadline)
+{
+	u32 sstatus;
+	int i, rc = 0;
+	if ((rc = sata_scr_read(link, SCR_STATUS, &sstatus)))
+		return rc;
+	/*reset to determine link state*/
+	if ((rc = al_sata_phy_reset(link)))
+		return rc;
+
+	if (!(sstatus & 0xF)) {
+		goto out;
+	}
+
+	al_ahci_port_activate(link->ap);
+
+	for (i = 0; i < 10; i++) {
+		udelay(200);
+		if ((rc = sata_scr_read(link, SCR_STATUS, &sstatus)))
+			goto out;
+		/*Check if device is present*/
+		if (!(sstatus & 0x3)) {
+			rc = 0;
+			goto out;
+		}
+		/*Check negotiated speed*/
+		if (sstatus & 0xF0)
+			break;
+		ata_dev_warn(&link->device[0], "WARNING: repeat PHY hardreset for port\n");
+		if ((rc = al_sata_phy_reset(link)))
+			return rc;
+	}
+	/*Check if device is present*/
+	if (sstatus & 0x3) {
+		u32 serror;
+		if ((rc = sata_link_debounce(link, timing, deadline)))
+			goto out;
+		if (!(rc = sata_scr_read(link, SCR_ERROR, &serror)))
+			sata_scr_write(link, SCR_ERROR, serror);
+		al_ahci_port_start(link->ap);
+		return 0;
+	}
+out:
+	al_ahci_port_stop(link->ap);
+	return rc;
+}
+#endif
 
 static bool ata_sstatus_online(u32 sstatus)
 {
@@ -3776,6 +3848,14 @@ int sata_link_hardreset(struct ata_link *link, const unsigned long *timing,
 	}
 
 	/* issue phy wake/reset */
+#ifdef CONFIG_ARCH_ALPINE
+	if (al_sss_enabled(link->ap)) {
+		ata_dev_info(&link->device[0], "AL: PHY hard reset\n");
+		if ((rc = al_sata_link_hardreset(link, timing, deadline)))
+			goto out;
+	} else {
+#endif
+
 	if ((rc = sata_scr_read(link, SCR_CONTROL, &scontrol)))
 		goto out;
 
@@ -3796,6 +3876,9 @@ int sata_link_hardreset(struct ata_link *link, const unsigned long *timing,
 	/* if link is offline nothing more to do */
 	if (ata_phys_link_offline(link))
 		goto out;
+#ifdef CONFIG_ARCH_ALPINE
+	}
+#endif
 
 	/* Link is online.  From this point, -ENODEV too is an error. */
 	if (online)
diff --git a/drivers/ata/libata-eh.c b/drivers/ata/libata-eh.c
index 370462f..77042f3 100644
--- a/drivers/ata/libata-eh.c
+++ b/drivers/ata/libata-eh.c
@@ -590,6 +590,9 @@ void ata_scsi_error(struct Scsi_Host *host)
 	struct ata_port *ap = ata_shost_to_port(host);
 	unsigned long flags;
 	LIST_HEAD(eh_work_q);
+#ifdef CONFIG_BUFFALO_PLATFORM
+	extern int buffalo_booting;
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	DPRINTK("ENTER\n");
 
@@ -603,6 +606,12 @@ void ata_scsi_error(struct Scsi_Host *host)
 	   recover nr_timedout == 0 why exactly are we doing error recovery ? */
 	ata_scsi_port_error_handler(host, ap);
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!buffalo_booting) {
+		/* do nothing */
+	}
+	else
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* finish or retry handled scmd's and clean up */
 	WARN_ON(host->host_failed || !list_empty(&eh_work_q));
 
diff --git a/drivers/crypto/al/al_crypto_alg.c b/drivers/crypto/al/al_crypto_alg.c
index d7c80a2..547af82 100644
--- a/drivers/crypto/al/al_crypto_alg.c
+++ b/drivers/crypto/al/al_crypto_alg.c
@@ -1228,7 +1228,7 @@ static inline int aead_prepare_xaction(enum al_crypto_dir dir,
 		/* set signature buffer for auth */
 		sg = req->dst;
 		while (!sg_is_last(sg))
-			sg_next(sg);
+			sg = sg_next(sg);
 
 		/* assume that auth result is not scattered */
 		BUG_ON(sg_dma_len(sg) < authsize);
@@ -1242,7 +1242,7 @@ static inline int aead_prepare_xaction(enum al_crypto_dir dir,
 	} else {
 		sg = req->src;
 		while (!sg_is_last(sg))
-			sg_next(sg);
+			sg = sg_next(sg);
 
 		/* assume that auth result is not scattered */
 		BUG_ON(sg_dma_len(sg) < authsize);
diff --git a/drivers/infiniband/core/iwcm.c b/drivers/infiniband/core/iwcm.c
index c47c203..4293e89 100644
--- a/drivers/infiniband/core/iwcm.c
+++ b/drivers/infiniband/core/iwcm.c
@@ -46,6 +46,7 @@
 #include <linux/completion.h>
 #include <linux/slab.h>
 #include <linux/module.h>
+#include <linux/sysctl.h>
 
 #include <rdma/iw_cm.h>
 #include <rdma/ib_addr.h>
@@ -65,6 +66,20 @@ struct iwcm_work {
 	struct list_head free_list;
 };
 
+static unsigned int default_backlog = 256;
+
+static struct ctl_table_header *iwcm_ctl_table_hdr;
+static struct ctl_table iwcm_ctl_table[] = {
+	{
+		.procname	= "default_backlog",
+		.data		= &default_backlog,
+		.maxlen		= sizeof(default_backlog),
+		.mode		= 0644,
+		.proc_handler	= proc_dointvec,
+	},
+	{ }
+};
+
 /*
  * The following services provide a mechanism for pre-allocating iwcm_work
  * elements.  The design pre-allocates them  based on the cm_id type:
@@ -419,6 +434,9 @@ int iw_cm_listen(struct iw_cm_id *cm_id, int backlog)
 
 	cm_id_priv = container_of(cm_id, struct iwcm_id_private, id);
 
+	if (!backlog)
+		backlog = default_backlog;
+
 	ret = alloc_work_entries(cm_id_priv, backlog);
 	if (ret)
 		return ret;
@@ -1024,11 +1042,20 @@ static int __init iw_cm_init(void)
 	if (!iwcm_wq)
 		return -ENOMEM;
 
+	iwcm_ctl_table_hdr = register_net_sysctl(&init_net, "net/iw_cm",
+						 iwcm_ctl_table);
+	if (!iwcm_ctl_table_hdr) {
+		pr_err("iw_cm: couldn't register sysctl paths\n");
+		destroy_workqueue(iwcm_wq);
+		return -ENOMEM;
+	}
+
 	return 0;
 }
 
 static void __exit iw_cm_cleanup(void)
 {
+	unregister_net_sysctl_table(iwcm_ctl_table_hdr);
 	destroy_workqueue(iwcm_wq);
 }
 
diff --git a/drivers/infiniband/core/user_mad.c b/drivers/infiniband/core/user_mad.c
index f0d588f..1acb991 100644
--- a/drivers/infiniband/core/user_mad.c
+++ b/drivers/infiniband/core/user_mad.c
@@ -98,7 +98,7 @@ struct ib_umad_port {
 
 struct ib_umad_device {
 	int                  start_port, end_port;
-	struct kref          ref;
+	struct kobject       kobj;
 	struct ib_umad_port  port[0];
 };
 
@@ -134,14 +134,18 @@ static DECLARE_BITMAP(dev_map, IB_UMAD_MAX_PORTS);
 static void ib_umad_add_one(struct ib_device *device);
 static void ib_umad_remove_one(struct ib_device *device);
 
-static void ib_umad_release_dev(struct kref *ref)
+static void ib_umad_release_dev(struct kobject *kobj)
 {
 	struct ib_umad_device *dev =
-		container_of(ref, struct ib_umad_device, ref);
+		container_of(kobj, struct ib_umad_device, kobj);
 
 	kfree(dev);
 }
 
+static struct kobj_type ib_umad_dev_ktype = {
+	.release = ib_umad_release_dev,
+};
+
 static int hdr_size(struct ib_umad_file *file)
 {
 	return file->use_pkey_index ? sizeof (struct ib_user_mad_hdr) :
@@ -780,27 +784,19 @@ static int ib_umad_open(struct inode *inode, struct file *filp)
 {
 	struct ib_umad_port *port;
 	struct ib_umad_file *file;
-	int ret;
+	int ret = -ENXIO;
 
 	port = container_of(inode->i_cdev, struct ib_umad_port, cdev);
-	if (port)
-		kref_get(&port->umad_dev->ref);
-	else
-		return -ENXIO;
 
 	mutex_lock(&port->file_mutex);
 
-	if (!port->ib_dev) {
-		ret = -ENXIO;
+	if (!port->ib_dev)
 		goto out;
-	}
 
+	ret = -ENOMEM;
 	file = kzalloc(sizeof *file, GFP_KERNEL);
-	if (!file) {
-		kref_put(&port->umad_dev->ref, ib_umad_release_dev);
-		ret = -ENOMEM;
+	if (!file)
 		goto out;
-	}
 
 	mutex_init(&file->mutex);
 	spin_lock_init(&file->send_lock);
@@ -814,6 +810,13 @@ static int ib_umad_open(struct inode *inode, struct file *filp)
 	list_add_tail(&file->port_list, &port->file_list);
 
 	ret = nonseekable_open(inode, filp);
+	if (ret) {
+		list_del(&file->port_list);
+		kfree(file);
+		goto out;
+	}
+
+	kobject_get(&port->umad_dev->kobj);
 
 out:
 	mutex_unlock(&port->file_mutex);
@@ -852,7 +855,7 @@ static int ib_umad_close(struct inode *inode, struct file *filp)
 	mutex_unlock(&file->port->file_mutex);
 
 	kfree(file);
-	kref_put(&dev->ref, ib_umad_release_dev);
+	kobject_put(&dev->kobj);
 
 	return 0;
 }
@@ -880,10 +883,6 @@ static int ib_umad_sm_open(struct inode *inode, struct file *filp)
 	int ret;
 
 	port = container_of(inode->i_cdev, struct ib_umad_port, sm_cdev);
-	if (port)
-		kref_get(&port->umad_dev->ref);
-	else
-		return -ENXIO;
 
 	if (filp->f_flags & O_NONBLOCK) {
 		if (down_trylock(&port->sm_sem)) {
@@ -898,17 +897,27 @@ static int ib_umad_sm_open(struct inode *inode, struct file *filp)
 	}
 
 	ret = ib_modify_port(port->ib_dev, port->port_num, 0, &props);
-	if (ret) {
-		up(&port->sm_sem);
-		goto fail;
-	}
+	if (ret)
+		goto err_up_sem;
 
 	filp->private_data = port;
 
-	return nonseekable_open(inode, filp);
+	ret = nonseekable_open(inode, filp);
+	if (ret)
+		goto err_clr_sm_cap;
+
+	kobject_get(&port->umad_dev->kobj);
+
+	return 0;
+
+err_clr_sm_cap:
+	swap(props.set_port_cap_mask, props.clr_port_cap_mask);
+	ib_modify_port(port->ib_dev, port->port_num, 0, &props);
+
+err_up_sem:
+	up(&port->sm_sem);
 
 fail:
-	kref_put(&port->umad_dev->ref, ib_umad_release_dev);
 	return ret;
 }
 
@@ -927,7 +936,7 @@ static int ib_umad_sm_close(struct inode *inode, struct file *filp)
 
 	up(&port->sm_sem);
 
-	kref_put(&port->umad_dev->ref, ib_umad_release_dev);
+	kobject_put(&port->umad_dev->kobj);
 
 	return ret;
 }
@@ -995,6 +1004,7 @@ static int find_overflow_devnum(void)
 }
 
 static int ib_umad_init_port(struct ib_device *device, int port_num,
+			     struct ib_umad_device *umad_dev,
 			     struct ib_umad_port *port)
 {
 	int devnum;
@@ -1027,6 +1037,7 @@ static int ib_umad_init_port(struct ib_device *device, int port_num,
 
 	cdev_init(&port->cdev, &umad_fops);
 	port->cdev.owner = THIS_MODULE;
+	port->cdev.kobj.parent = &umad_dev->kobj;
 	kobject_set_name(&port->cdev.kobj, "umad%d", port->dev_num);
 	if (cdev_add(&port->cdev, base, 1))
 		goto err_cdev;
@@ -1045,6 +1056,7 @@ static int ib_umad_init_port(struct ib_device *device, int port_num,
 	base += IB_UMAD_MAX_PORTS;
 	cdev_init(&port->sm_cdev, &umad_sm_fops);
 	port->sm_cdev.owner = THIS_MODULE;
+	port->sm_cdev.kobj.parent = &umad_dev->kobj;
 	kobject_set_name(&port->sm_cdev.kobj, "issm%d", port->dev_num);
 	if (cdev_add(&port->sm_cdev, base, 1))
 		goto err_sm_cdev;
@@ -1138,7 +1150,7 @@ static void ib_umad_add_one(struct ib_device *device)
 	if (!umad_dev)
 		return;
 
-	kref_init(&umad_dev->ref);
+	kobject_init(&umad_dev->kobj, &ib_umad_dev_ktype);
 
 	umad_dev->start_port = s;
 	umad_dev->end_port   = e;
@@ -1146,7 +1158,8 @@ static void ib_umad_add_one(struct ib_device *device)
 	for (i = s; i <= e; ++i) {
 		umad_dev->port[i - s].umad_dev = umad_dev;
 
-		if (ib_umad_init_port(device, i, &umad_dev->port[i - s]))
+		if (ib_umad_init_port(device, i, umad_dev,
+				      &umad_dev->port[i - s]))
 			goto err;
 	}
 
@@ -1158,7 +1171,7 @@ err:
 	while (--i >= s)
 		ib_umad_kill_port(&umad_dev->port[i - s]);
 
-	kref_put(&umad_dev->ref, ib_umad_release_dev);
+	kobject_put(&umad_dev->kobj);
 }
 
 static void ib_umad_remove_one(struct ib_device *device)
@@ -1172,7 +1185,7 @@ static void ib_umad_remove_one(struct ib_device *device)
 	for (i = 0; i <= umad_dev->end_port - umad_dev->start_port; ++i)
 		ib_umad_kill_port(&umad_dev->port[i]);
 
-	kref_put(&umad_dev->ref, ib_umad_release_dev);
+	kobject_put(&umad_dev->kobj);
 }
 
 static char *umad_devnode(struct device *dev, umode_t *mode)
diff --git a/drivers/infiniband/hw/ehca/ehca_cq.c b/drivers/infiniband/hw/ehca/ehca_cq.c
index 212150c..8cc8375 100644
--- a/drivers/infiniband/hw/ehca/ehca_cq.c
+++ b/drivers/infiniband/hw/ehca/ehca_cq.c
@@ -283,6 +283,7 @@ struct ib_cq *ehca_create_cq(struct ib_device *device, int cqe, int comp_vector,
 			(my_cq->galpas.user.fw_handle & (PAGE_SIZE - 1));
 		if (ib_copy_to_udata(udata, &resp, sizeof(resp))) {
 			ehca_err(device, "Copy to udata failed.");
+			cq = ERR_PTR(-EFAULT);
 			goto create_cq_exit4;
 		}
 	}
diff --git a/drivers/infiniband/hw/ipath/ipath_diag.c b/drivers/infiniband/hw/ipath/ipath_diag.c
index 714293b..45802e97 100644
--- a/drivers/infiniband/hw/ipath/ipath_diag.c
+++ b/drivers/infiniband/hw/ipath/ipath_diag.c
@@ -326,7 +326,7 @@ static ssize_t ipath_diagpkt_write(struct file *fp,
 				   size_t count, loff_t *off)
 {
 	u32 __iomem *piobuf;
-	u32 plen, clen, pbufn;
+	u32 plen, pbufn, maxlen_reserve;
 	struct ipath_diag_pkt odp;
 	struct ipath_diag_xpkt dp;
 	u32 *tmpbuf = NULL;
@@ -335,42 +335,24 @@ static ssize_t ipath_diagpkt_write(struct file *fp,
 	u64 val;
 	u32 l_state, lt_state; /* LinkState, LinkTrainingState */
 
-	if (count < sizeof(odp)) {
-		ret = -EINVAL;
-		goto bail;
-	}
 
 	if (count == sizeof(dp)) {
 		if (copy_from_user(&dp, data, sizeof(dp))) {
 			ret = -EFAULT;
 			goto bail;
 		}
-	} else if (copy_from_user(&odp, data, sizeof(odp))) {
-		ret = -EFAULT;
-		goto bail;
-	}
-
-	/*
-	 * Due to padding/alignment issues (lessened with new struct)
-	 * the old and new structs are the same length. We need to
-	 * disambiguate them, which we can do because odp.len has never
-	 * been less than the total of LRH+BTH+DETH so far, while
-	 * dp.unit (same offset) unit is unlikely to get that high.
-	 * Similarly, dp.data, the pointer to user at the same offset
-	 * as odp.unit, is almost certainly at least one (512byte)page
-	 * "above" NULL. The if-block below can be omitted if compatibility
-	 * between a new driver and older diagnostic code is unimportant.
-	 * compatibility the other direction (new diags, old driver) is
-	 * handled in the diagnostic code, with a warning.
-	 */
-	if (dp.unit >= 20 && dp.data < 512) {
-		/* very probable version mismatch. Fix it up */
-		memcpy(&odp, &dp, sizeof(odp));
-		/* We got a legacy dp, copy elements to dp */
+	} else if (count == sizeof(odp)) {
+		if (copy_from_user(&odp, data, sizeof(odp))) {
+			ret = -EFAULT;
+			goto bail;
+		}
+		dp.len = odp.len;
 		dp.unit = odp.unit;
 		dp.data = odp.data;
-		dp.len = odp.len;
-		dp.pbc_wd = 0; /* Indicate we need to compute PBC wd */
+		dp.pbc_wd = 0;
+	} else {
+		ret = -EINVAL;
+		goto bail;
 	}
 
 	/* send count must be an exact number of dwords */
@@ -379,7 +361,7 @@ static ssize_t ipath_diagpkt_write(struct file *fp,
 		goto bail;
 	}
 
-	clen = dp.len >> 2;
+	plen = dp.len >> 2;
 
 	dd = ipath_lookup(dp.unit);
 	if (!dd || !(dd->ipath_flags & IPATH_PRESENT) ||
@@ -422,16 +404,22 @@ static ssize_t ipath_diagpkt_write(struct file *fp,
 		goto bail;
 	}
 
-	/* need total length before first word written */
-	/* +1 word is for the qword padding */
-	plen = sizeof(u32) + dp.len;
-
-	if ((plen + 4) > dd->ipath_ibmaxlen) {
+	/*
+	 * need total length before first word written, plus 2 Dwords. One Dword
+	 * is for padding so we get the full user data when not aligned on
+	 * a word boundary. The other Dword is to make sure we have room for the
+	 * ICRC which gets tacked on later.
+	 */
+	maxlen_reserve = 2 * sizeof(u32);
+	if (dp.len > dd->ipath_ibmaxlen - maxlen_reserve) {
 		ipath_dbg("Pkt len 0x%x > ibmaxlen %x\n",
-			  plen - 4, dd->ipath_ibmaxlen);
+			  dp.len, dd->ipath_ibmaxlen);
 		ret = -EINVAL;
-		goto bail;	/* before writing pbc */
+		goto bail;
 	}
+
+	plen = sizeof(u32) + dp.len;
+
 	tmpbuf = vmalloc(plen);
 	if (!tmpbuf) {
 		dev_info(&dd->pcidev->dev, "Unable to allocate tmp buffer, "
@@ -473,11 +461,11 @@ static ssize_t ipath_diagpkt_write(struct file *fp,
 	 */
 	if (dd->ipath_flags & IPATH_PIO_FLUSH_WC) {
 		ipath_flush_wc();
-		__iowrite32_copy(piobuf + 2, tmpbuf, clen - 1);
+		__iowrite32_copy(piobuf + 2, tmpbuf, plen - 1);
 		ipath_flush_wc();
-		__raw_writel(tmpbuf[clen - 1], piobuf + clen + 1);
+		__raw_writel(tmpbuf[plen - 1], piobuf + plen + 1);
 	} else
-		__iowrite32_copy(piobuf + 2, tmpbuf, clen);
+		__iowrite32_copy(piobuf + 2, tmpbuf, plen);
 
 	ipath_flush_wc();
 
diff --git a/drivers/infiniband/hw/ipath/ipath_user_sdma.c b/drivers/infiniband/hw/ipath/ipath_user_sdma.c
index f5cb13b..cc04b7b 100644
--- a/drivers/infiniband/hw/ipath/ipath_user_sdma.c
+++ b/drivers/infiniband/hw/ipath/ipath_user_sdma.c
@@ -280,9 +280,7 @@ static int ipath_user_sdma_pin_pages(const struct ipath_devdata *dd,
 	int j;
 	int ret;
 
-	ret = get_user_pages(current, current->mm, addr,
-			     npages, 0, 1, pages, NULL);
-
+	ret = get_user_pages_fast(addr, npages, 0, pages);
 	if (ret != npages) {
 		int i;
 
@@ -811,10 +809,7 @@ int ipath_user_sdma_writev(struct ipath_devdata *dd,
 	while (dim) {
 		const int mxp = 8;
 
-		down_write(&current->mm->mmap_sem);
 		ret = ipath_user_sdma_queue_pkts(dd, pq, &list, iov, dim, mxp);
-		up_write(&current->mm->mmap_sem);
-
 		if (ret <= 0)
 			goto done_unlock;
 		else {
diff --git a/drivers/infiniband/hw/mthca/mthca_provider.c b/drivers/infiniband/hw/mthca/mthca_provider.c
index 5b71d43..42dde06 100644
--- a/drivers/infiniband/hw/mthca/mthca_provider.c
+++ b/drivers/infiniband/hw/mthca/mthca_provider.c
@@ -695,6 +695,7 @@ static struct ib_cq *mthca_create_cq(struct ib_device *ibdev, int entries,
 
 	if (context && ib_copy_to_udata(udata, &cq->cqn, sizeof (__u32))) {
 		mthca_free_cq(to_mdev(ibdev), cq);
+		err = -EFAULT;
 		goto err_free;
 	}
 
diff --git a/drivers/infiniband/hw/nes/nes_verbs.c b/drivers/infiniband/hw/nes/nes_verbs.c
index 8f67fe2e..7510a3c 100644
--- a/drivers/infiniband/hw/nes/nes_verbs.c
+++ b/drivers/infiniband/hw/nes/nes_verbs.c
@@ -1186,7 +1186,7 @@ static struct ib_qp *nes_create_qp(struct ib_pd *ibpd,
 					nes_free_resource(nesadapter, nesadapter->allocated_qps, qp_num);
 					kfree(nesqp->allocated_buffer);
 					nes_debug(NES_DBG_QP, "ib_copy_from_udata() Failed \n");
-					return NULL;
+					return ERR_PTR(-EFAULT);
 				}
 				if (req.user_wqe_buffers) {
 					virt_wqs = 1;
diff --git a/drivers/infiniband/hw/qib/qib_iba7322.c b/drivers/infiniband/hw/qib/qib_iba7322.c
index 3f6b21e..14103ff 100644
--- a/drivers/infiniband/hw/qib/qib_iba7322.c
+++ b/drivers/infiniband/hw/qib/qib_iba7322.c
@@ -2287,6 +2287,11 @@ static int qib_7322_bringup_serdes(struct qib_pportdata *ppd)
 	qib_write_kreg_port(ppd, krp_ibcctrl_a, ppd->cpspec->ibcctrl_a);
 	qib_write_kreg(dd, kr_scratch, 0ULL);
 
+	/* ensure previous Tx parameters are not still forced */
+	qib_write_kreg_port(ppd, krp_tx_deemph_override,
+		SYM_MASK(IBSD_TX_DEEMPHASIS_OVERRIDE_0,
+		reset_tx_deemphasis_override));
+
 	if (qib_compat_ddr_negotiate) {
 		ppd->cpspec->ibdeltainprog = 1;
 		ppd->cpspec->ibsymsnap = read_7322_creg32_port(ppd,
@@ -5853,21 +5858,20 @@ static int setup_txselect(const char *str, struct kernel_param *kp)
 {
 	struct qib_devdata *dd;
 	unsigned long val;
-	int ret;
-
+	char *n;
 	if (strlen(str) >= MAX_ATTEN_LEN) {
 		pr_info("txselect_values string too long\n");
 		return -ENOSPC;
 	}
-	ret = kstrtoul(str, 0, &val);
-	if (ret || val >= (TXDDS_TABLE_SZ + TXDDS_EXTRA_SZ +
+	val = simple_strtoul(str, &n, 0);
+	if (n == str || val >= (TXDDS_TABLE_SZ + TXDDS_EXTRA_SZ +
 				TXDDS_MFG_SZ)) {
 		pr_info("txselect_values must start with a number < %d\n",
 			TXDDS_TABLE_SZ + TXDDS_EXTRA_SZ + TXDDS_MFG_SZ);
-		return ret ? ret : -EINVAL;
+		return -EINVAL;
 	}
-
 	strcpy(txselect_list, str);
+
 	list_for_each_entry(dd, &qib_dev_list, list)
 		if (dd->deviceid == PCI_DEVICE_ID_QLOGIC_IB_7322)
 			set_no_qsfp_atten(dd, 1);
diff --git a/drivers/infiniband/hw/qib/qib_mad.c b/drivers/infiniband/hw/qib/qib_mad.c
index ccb1191..1dd9fcb 100644
--- a/drivers/infiniband/hw/qib/qib_mad.c
+++ b/drivers/infiniband/hw/qib/qib_mad.c
@@ -1028,7 +1028,7 @@ static int set_pkeys(struct qib_devdata *dd, u8 port, u16 *pkeys)
 
 		event.event = IB_EVENT_PKEY_CHANGE;
 		event.device = &dd->verbs_dev.ibdev;
-		event.element.port_num = 1;
+		event.element.port_num = port;
 		ib_dispatch_event(&event);
 	}
 	return 0;
diff --git a/drivers/infiniband/hw/qib/qib_ud.c b/drivers/infiniband/hw/qib/qib_ud.c
index d6c7fe7..3ad651c 100644
--- a/drivers/infiniband/hw/qib/qib_ud.c
+++ b/drivers/infiniband/hw/qib/qib_ud.c
@@ -57,13 +57,20 @@ static void qib_ud_loopback(struct qib_qp *sqp, struct qib_swqe *swqe)
 	struct qib_sge *sge;
 	struct ib_wc wc;
 	u32 length;
+	enum ib_qp_type sqptype, dqptype;
 
 	qp = qib_lookup_qpn(ibp, swqe->wr.wr.ud.remote_qpn);
 	if (!qp) {
 		ibp->n_pkt_drops++;
 		return;
 	}
-	if (qp->ibqp.qp_type != sqp->ibqp.qp_type ||
+
+	sqptype = sqp->ibqp.qp_type == IB_QPT_GSI ?
+			IB_QPT_UD : sqp->ibqp.qp_type;
+	dqptype = qp->ibqp.qp_type == IB_QPT_GSI ?
+			IB_QPT_UD : qp->ibqp.qp_type;
+
+	if (dqptype != sqptype ||
 	    !(ib_qib_state_ops[qp->state] & QIB_PROCESS_RECV_OK)) {
 		ibp->n_pkt_drops++;
 		goto drop;
diff --git a/drivers/infiniband/hw/qib/qib_user_sdma.c b/drivers/infiniband/hw/qib/qib_user_sdma.c
index 8244208..573b460 100644
--- a/drivers/infiniband/hw/qib/qib_user_sdma.c
+++ b/drivers/infiniband/hw/qib/qib_user_sdma.c
@@ -284,8 +284,7 @@ static int qib_user_sdma_pin_pages(const struct qib_devdata *dd,
 	int j;
 	int ret;
 
-	ret = get_user_pages(current, current->mm, addr,
-			     npages, 0, 1, pages, NULL);
+	ret = get_user_pages_fast(addr, npages, 0, pages);
 
 	if (ret != npages) {
 		int i;
@@ -830,10 +829,7 @@ int qib_user_sdma_writev(struct qib_ctxtdata *rcd,
 	while (dim) {
 		const int mxp = 8;
 
-		down_write(&current->mm->mmap_sem);
 		ret = qib_user_sdma_queue_pkts(dd, pq, &list, iov, dim, mxp);
-		up_write(&current->mm->mmap_sem);
-
 		if (ret <= 0)
 			goto done_unlock;
 		else {
diff --git a/drivers/infiniband/ulp/iser/iscsi_iser.c b/drivers/infiniband/ulp/iser/iscsi_iser.c
index 2e84ef8..dd03cfe 100644
--- a/drivers/infiniband/ulp/iser/iscsi_iser.c
+++ b/drivers/infiniband/ulp/iser/iscsi_iser.c
@@ -347,6 +347,7 @@ iscsi_iser_conn_bind(struct iscsi_cls_session *cls_session,
 {
 	struct iscsi_conn *conn = cls_conn->dd_data;
 	struct iscsi_iser_conn *iser_conn;
+	struct iscsi_session *session;
 	struct iser_conn *ib_conn;
 	struct iscsi_endpoint *ep;
 	int error;
@@ -365,7 +366,8 @@ iscsi_iser_conn_bind(struct iscsi_cls_session *cls_session,
 	}
 	ib_conn = ep->dd_data;
 
-	if (iser_alloc_rx_descriptors(ib_conn))
+	session = conn->session;
+	if (iser_alloc_rx_descriptors(ib_conn, session))
 		return -ENOMEM;
 
 	/* binds the iSER connection retrieved from the previously
@@ -419,12 +421,13 @@ iscsi_iser_session_create(struct iscsi_endpoint *ep,
 	struct iscsi_cls_session *cls_session;
 	struct iscsi_session *session;
 	struct Scsi_Host *shost;
-	struct iser_conn *ib_conn;
+	struct iser_conn *ib_conn = NULL;
 
 	shost = iscsi_host_alloc(&iscsi_iser_sht, 0, 0);
 	if (!shost)
 		return NULL;
 	shost->transportt = iscsi_iser_scsi_transport;
+	shost->cmd_per_lun = qdepth;
 	shost->max_lun = iscsi_max_lun;
 	shost->max_id = 0;
 	shost->max_channel = 0;
@@ -441,12 +444,14 @@ iscsi_iser_session_create(struct iscsi_endpoint *ep,
 			   ep ? ib_conn->device->ib_device->dma_device : NULL))
 		goto free_host;
 
-	/*
-	 * we do not support setting can_queue cmd_per_lun from userspace yet
-	 * because we preallocate so many resources
-	 */
+	if (cmds_max > ISER_DEF_XMIT_CMDS_MAX) {
+		iser_info("cmds_max changed from %u to %u\n",
+			  cmds_max, ISER_DEF_XMIT_CMDS_MAX);
+		cmds_max = ISER_DEF_XMIT_CMDS_MAX;
+	}
+
 	cls_session = iscsi_session_setup(&iscsi_iser_transport, shost,
-					  ISCSI_DEF_XMIT_CMDS_MAX, 0,
+					  cmds_max, 0,
 					  sizeof(struct iscsi_iser_task),
 					  initial_cmdsn, 0);
 	if (!cls_session)
@@ -672,6 +677,7 @@ static umode_t iser_attr_is_visible(int param_type, int param)
 		case ISCSI_PARAM_TGT_RESET_TMO:
 		case ISCSI_PARAM_IFACE_NAME:
 		case ISCSI_PARAM_INITIATOR_NAME:
+		case ISCSI_PARAM_DISCOVERY_SESS:
 			return S_IRUGO;
 		default:
 			return 0;
@@ -701,7 +707,7 @@ static struct scsi_host_template iscsi_iser_sht = {
 static struct iscsi_transport iscsi_iser_transport = {
 	.owner                  = THIS_MODULE,
 	.name                   = "iser",
-	.caps                   = CAP_RECOVERY_L0 | CAP_MULTI_R2T,
+	.caps                   = CAP_RECOVERY_L0 | CAP_MULTI_R2T | CAP_TEXT_NEGO,
 	/* session management */
 	.create_session         = iscsi_iser_session_create,
 	.destroy_session        = iscsi_iser_session_destroy,
diff --git a/drivers/infiniband/ulp/iser/iscsi_iser.h b/drivers/infiniband/ulp/iser/iscsi_iser.h
index 4f069c0..6791402 100644
--- a/drivers/infiniband/ulp/iser/iscsi_iser.h
+++ b/drivers/infiniband/ulp/iser/iscsi_iser.h
@@ -78,14 +78,14 @@
 
 #define iser_warn(fmt, arg...)				\
 	do {						\
-		if (iser_debug_level > 1)		\
+		if (iser_debug_level > 0)		\
 			pr_warn(PFX "%s:" fmt,          \
 				__func__ , ## arg);	\
 	} while (0)
 
 #define iser_info(fmt, arg...)				\
 	do {						\
-		if (iser_debug_level > 0)		\
+		if (iser_debug_level > 1)		\
 			pr_info(PFX "%s:" fmt,          \
 				__func__ , ## arg);	\
 	} while (0)
@@ -102,7 +102,13 @@
 
 					/* support up to 512KB in one RDMA */
 #define ISCSI_ISER_SG_TABLESIZE         (0x80000 >> SHIFT_4K)
-#define ISER_DEF_CMD_PER_LUN		ISCSI_DEF_XMIT_CMDS_MAX
+#define ISER_DEF_XMIT_CMDS_DEFAULT		512
+#if ISCSI_DEF_XMIT_CMDS_MAX > ISER_DEF_XMIT_CMDS_DEFAULT
+	#define ISER_DEF_XMIT_CMDS_MAX		ISCSI_DEF_XMIT_CMDS_MAX
+#else
+	#define ISER_DEF_XMIT_CMDS_MAX		ISER_DEF_XMIT_CMDS_DEFAULT
+#endif
+#define ISER_DEF_CMD_PER_LUN		ISER_DEF_XMIT_CMDS_MAX
 
 /* QP settings */
 /* Maximal bounds on received asynchronous PDUs */
@@ -111,9 +117,9 @@
 #define ISER_MAX_TX_MISC_PDUS		6 /* NOOP_OUT(2), TEXT(1),         *
 					   * SCSI_TMFUNC(2), LOGOUT(1) */
 
-#define ISER_QP_MAX_RECV_DTOS		(ISCSI_DEF_XMIT_CMDS_MAX)
+#define ISER_QP_MAX_RECV_DTOS		(ISER_DEF_XMIT_CMDS_MAX)
 
-#define ISER_MIN_POSTED_RX		(ISCSI_DEF_XMIT_CMDS_MAX >> 2)
+#define ISER_MIN_POSTED_RX		(ISER_DEF_XMIT_CMDS_MAX >> 2)
 
 /* the max TX (send) WR supported by the iSER QP is defined by                 *
  * max_send_wr = T * (1 + D) + C ; D is how many inflight dataouts we expect   *
@@ -123,7 +129,7 @@
 
 #define ISER_INFLIGHT_DATAOUTS		8
 
-#define ISER_QP_MAX_REQ_DTOS		(ISCSI_DEF_XMIT_CMDS_MAX *    \
+#define ISER_QP_MAX_REQ_DTOS		(ISER_DEF_XMIT_CMDS_MAX *    \
 					(1 + ISER_INFLIGHT_DATAOUTS) + \
 					ISER_MAX_TX_MISC_PDUS        + \
 					ISER_MAX_RX_MISC_PDUS)
@@ -205,7 +211,7 @@ struct iser_mem_reg {
 	u64  va;
 	u64  len;
 	void *mem_h;
-	int  is_fmr;
+	int  is_mr;
 };
 
 struct iser_regd_buf {
@@ -246,6 +252,9 @@ struct iser_rx_desc {
 
 #define ISER_MAX_CQ 4
 
+struct iser_conn;
+struct iscsi_iser_task;
+
 struct iser_device {
 	struct ib_device             *ib_device;
 	struct ib_pd	             *pd;
@@ -259,6 +268,22 @@ struct iser_device {
 	int                          cq_active_qps[ISER_MAX_CQ];
 	int			     cqs_used;
 	struct iser_cq_desc	     *cq_desc;
+	int                          (*iser_alloc_rdma_reg_res)(struct iser_conn *ib_conn,
+								unsigned cmds_max);
+	void                         (*iser_free_rdma_reg_res)(struct iser_conn *ib_conn);
+	int                          (*iser_reg_rdma_mem)(struct iscsi_iser_task *iser_task,
+							  enum iser_data_dir cmd_dir);
+	void                         (*iser_unreg_rdma_mem)(struct iscsi_iser_task *iser_task,
+							    enum iser_data_dir cmd_dir);
+};
+
+struct fast_reg_descriptor {
+	struct list_head		  list;
+	/* For fast registration - FRWR */
+	struct ib_mr			 *data_mr;
+	struct ib_fast_reg_page_list     *data_frpl;
+	/* Valid for fast registration flag */
+	bool				  valid;
 };
 
 struct iser_conn {
@@ -270,13 +295,13 @@ struct iser_conn {
 	struct iser_device           *device;       /* device context          */
 	struct rdma_cm_id            *cma_id;       /* CMA ID		       */
 	struct ib_qp	             *qp;           /* QP 		       */
-	struct ib_fmr_pool           *fmr_pool;     /* pool of IB FMRs         */
 	wait_queue_head_t	     wait;          /* waitq for conn/disconn  */
+	unsigned		     qp_max_recv_dtos; /* num of rx buffers */
+	unsigned		     qp_max_recv_dtos_mask; /* above minus 1 */
+	unsigned		     min_posted_rx; /* qp_max_recv_dtos >> 2 */
 	int                          post_recv_buf_count; /* posted rx count  */
 	atomic_t                     post_send_buf_count; /* posted tx count   */
 	char 			     name[ISER_OBJECT_NAME_SIZE];
-	struct iser_page_vec         *page_vec;     /* represents SG to fmr maps*
-						     * maps serialized as tx is*/
 	struct list_head	     conn_list;       /* entry in ig conn list */
 
 	char  			     *login_buf;
@@ -285,6 +310,17 @@ struct iser_conn {
 	unsigned int 		     rx_desc_head;
 	struct iser_rx_desc	     *rx_descs;
 	struct ib_recv_wr	     rx_wr[ISER_MIN_POSTED_RX];
+	union {
+		struct {
+			struct ib_fmr_pool      *pool;	   /* pool of IB FMRs         */
+			struct iser_page_vec	*page_vec; /* represents SG to fmr maps*
+							    * maps serialized as tx is*/
+		} fmr;
+		struct {
+			struct list_head	pool;
+			int			pool_size;
+		} frwr;
+	} fastreg;
 };
 
 struct iscsi_iser_conn {
@@ -368,8 +404,10 @@ void iser_free_rx_descriptors(struct iser_conn *ib_conn);
 void iser_finalize_rdma_unaligned_sg(struct iscsi_iser_task *task,
 				     enum iser_data_dir         cmd_dir);
 
-int  iser_reg_rdma_mem(struct iscsi_iser_task *task,
-		       enum   iser_data_dir        cmd_dir);
+int  iser_reg_rdma_mem_fmr(struct iscsi_iser_task *task,
+			   enum iser_data_dir cmd_dir);
+int  iser_reg_rdma_mem_frwr(struct iscsi_iser_task *task,
+			    enum iser_data_dir cmd_dir);
 
 int  iser_connect(struct iser_conn   *ib_conn,
 		  struct sockaddr_in *src_addr,
@@ -380,7 +418,10 @@ int  iser_reg_page_vec(struct iser_conn     *ib_conn,
 		       struct iser_page_vec *page_vec,
 		       struct iser_mem_reg  *mem_reg);
 
-void iser_unreg_mem(struct iser_mem_reg *mem_reg);
+void iser_unreg_mem_fmr(struct iscsi_iser_task *iser_task,
+			enum iser_data_dir cmd_dir);
+void iser_unreg_mem_frwr(struct iscsi_iser_task *iser_task,
+			 enum iser_data_dir cmd_dir);
 
 int  iser_post_recvl(struct iser_conn *ib_conn);
 int  iser_post_recvm(struct iser_conn *ib_conn, int count);
@@ -394,5 +435,9 @@ int iser_dma_map_task_data(struct iscsi_iser_task *iser_task,
 void iser_dma_unmap_task_data(struct iscsi_iser_task *iser_task);
 int  iser_initialize_task_headers(struct iscsi_task *task,
 			struct iser_tx_desc *tx_desc);
-int iser_alloc_rx_descriptors(struct iser_conn *ib_conn);
+int iser_alloc_rx_descriptors(struct iser_conn *ib_conn, struct iscsi_session *session);
+int iser_create_fmr_pool(struct iser_conn *ib_conn, unsigned cmds_max);
+void iser_free_fmr_pool(struct iser_conn *ib_conn);
+int iser_create_frwr_pool(struct iser_conn *ib_conn, unsigned cmds_max);
+void iser_free_frwr_pool(struct iser_conn *ib_conn);
 #endif
diff --git a/drivers/infiniband/ulp/iser/iser_initiator.c b/drivers/infiniband/ulp/iser/iser_initiator.c
index b6d81a8..334f34b 100644
--- a/drivers/infiniband/ulp/iser/iser_initiator.c
+++ b/drivers/infiniband/ulp/iser/iser_initiator.c
@@ -49,6 +49,7 @@ static int iser_prepare_read_cmd(struct iscsi_task *task,
 
 {
 	struct iscsi_iser_task *iser_task = task->dd_data;
+	struct iser_device  *device = iser_task->iser_conn->ib_conn->device;
 	struct iser_regd_buf *regd_buf;
 	int err;
 	struct iser_hdr *hdr = &iser_task->desc.iser_header;
@@ -69,7 +70,7 @@ static int iser_prepare_read_cmd(struct iscsi_task *task,
 		return -EINVAL;
 	}
 
-	err = iser_reg_rdma_mem(iser_task,ISER_DIR_IN);
+	err = device->iser_reg_rdma_mem(iser_task, ISER_DIR_IN);
 	if (err) {
 		iser_err("Failed to set up Data-IN RDMA\n");
 		return err;
@@ -98,6 +99,7 @@ iser_prepare_write_cmd(struct iscsi_task *task,
 		       unsigned int edtl)
 {
 	struct iscsi_iser_task *iser_task = task->dd_data;
+	struct iser_device  *device = iser_task->iser_conn->ib_conn->device;
 	struct iser_regd_buf *regd_buf;
 	int err;
 	struct iser_hdr *hdr = &iser_task->desc.iser_header;
@@ -119,7 +121,7 @@ iser_prepare_write_cmd(struct iscsi_task *task,
 		return -EINVAL;
 	}
 
-	err = iser_reg_rdma_mem(iser_task,ISER_DIR_OUT);
+	err = device->iser_reg_rdma_mem(iser_task, ISER_DIR_OUT);
 	if (err != 0) {
 		iser_err("Failed to register write cmd RDMA mem\n");
 		return err;
@@ -170,8 +172,78 @@ static void iser_create_send_desc(struct iser_conn	*ib_conn,
 	}
 }
 
+static void iser_free_login_buf(struct iser_conn *ib_conn)
+{
+	if (!ib_conn->login_buf)
+		return;
+
+	if (ib_conn->login_req_dma)
+		ib_dma_unmap_single(ib_conn->device->ib_device,
+				    ib_conn->login_req_dma,
+				    ISCSI_DEF_MAX_RECV_SEG_LEN, DMA_TO_DEVICE);
+
+	if (ib_conn->login_resp_dma)
+		ib_dma_unmap_single(ib_conn->device->ib_device,
+				    ib_conn->login_resp_dma,
+				    ISER_RX_LOGIN_SIZE, DMA_FROM_DEVICE);
+
+	kfree(ib_conn->login_buf);
+
+	/* make sure we never redo any unmapping */
+	ib_conn->login_req_dma = 0;
+	ib_conn->login_resp_dma = 0;
+	ib_conn->login_buf = NULL;
+}
+
+static int iser_alloc_login_buf(struct iser_conn *ib_conn)
+{
+	struct iser_device	*device;
+	int			req_err, resp_err;
+
+	BUG_ON(ib_conn->device == NULL);
+
+	device = ib_conn->device;
+
+	ib_conn->login_buf = kmalloc(ISCSI_DEF_MAX_RECV_SEG_LEN +
+				     ISER_RX_LOGIN_SIZE, GFP_KERNEL);
+	if (!ib_conn->login_buf)
+		goto out_err;
+
+	ib_conn->login_req_buf  = ib_conn->login_buf;
+	ib_conn->login_resp_buf = ib_conn->login_buf +
+						ISCSI_DEF_MAX_RECV_SEG_LEN;
+
+	ib_conn->login_req_dma = ib_dma_map_single(ib_conn->device->ib_device,
+				(void *)ib_conn->login_req_buf,
+				ISCSI_DEF_MAX_RECV_SEG_LEN, DMA_TO_DEVICE);
+
+	ib_conn->login_resp_dma = ib_dma_map_single(ib_conn->device->ib_device,
+				(void *)ib_conn->login_resp_buf,
+				ISER_RX_LOGIN_SIZE, DMA_FROM_DEVICE);
+
+	req_err  = ib_dma_mapping_error(device->ib_device,
+					ib_conn->login_req_dma);
+	resp_err = ib_dma_mapping_error(device->ib_device,
+					ib_conn->login_resp_dma);
+
+	if (req_err || resp_err) {
+		if (req_err)
+			ib_conn->login_req_dma = 0;
+		if (resp_err)
+			ib_conn->login_resp_dma = 0;
+		goto free_login_buf;
+	}
+	return 0;
+
+free_login_buf:
+	iser_free_login_buf(ib_conn);
 
-int iser_alloc_rx_descriptors(struct iser_conn *ib_conn)
+out_err:
+	iser_err("unable to alloc or map login buf\n");
+	return -ENOMEM;
+}
+
+int iser_alloc_rx_descriptors(struct iser_conn *ib_conn, struct iscsi_session *session)
 {
 	int i, j;
 	u64 dma_addr;
@@ -179,14 +251,24 @@ int iser_alloc_rx_descriptors(struct iser_conn *ib_conn)
 	struct ib_sge       *rx_sg;
 	struct iser_device  *device = ib_conn->device;
 
-	ib_conn->rx_descs = kmalloc(ISER_QP_MAX_RECV_DTOS *
+	ib_conn->qp_max_recv_dtos = session->cmds_max;
+	ib_conn->qp_max_recv_dtos_mask = session->cmds_max - 1; /* cmds_max is 2^N */
+	ib_conn->min_posted_rx = ib_conn->qp_max_recv_dtos >> 2;
+
+	if (device->iser_alloc_rdma_reg_res(ib_conn, session->scsi_cmds_max))
+		goto create_rdma_reg_res_failed;
+
+	if (iser_alloc_login_buf(ib_conn))
+		goto alloc_login_buf_fail;
+
+	ib_conn->rx_descs = kmalloc(session->cmds_max *
 				sizeof(struct iser_rx_desc), GFP_KERNEL);
 	if (!ib_conn->rx_descs)
 		goto rx_desc_alloc_fail;
 
 	rx_desc = ib_conn->rx_descs;
 
-	for (i = 0; i < ISER_QP_MAX_RECV_DTOS; i++, rx_desc++)  {
+	for (i = 0; i < ib_conn->qp_max_recv_dtos; i++, rx_desc++)  {
 		dma_addr = ib_dma_map_single(device->ib_device, (void *)rx_desc,
 					ISER_RX_PAYLOAD_SIZE, DMA_FROM_DEVICE);
 		if (ib_dma_mapping_error(device->ib_device, dma_addr))
@@ -207,10 +289,14 @@ rx_desc_dma_map_failed:
 	rx_desc = ib_conn->rx_descs;
 	for (j = 0; j < i; j++, rx_desc++)
 		ib_dma_unmap_single(device->ib_device, rx_desc->dma_addr,
-			ISER_RX_PAYLOAD_SIZE, DMA_FROM_DEVICE);
+				    ISER_RX_PAYLOAD_SIZE, DMA_FROM_DEVICE);
 	kfree(ib_conn->rx_descs);
 	ib_conn->rx_descs = NULL;
 rx_desc_alloc_fail:
+	iser_free_login_buf(ib_conn);
+alloc_login_buf_fail:
+	device->iser_free_rdma_reg_res(ib_conn);
+create_rdma_reg_res_failed:
 	iser_err("failed allocating rx descriptors / data buffers\n");
 	return -ENOMEM;
 }
@@ -222,18 +308,27 @@ void iser_free_rx_descriptors(struct iser_conn *ib_conn)
 	struct iser_device *device = ib_conn->device;
 
 	if (!ib_conn->rx_descs)
-		return;
+		goto free_login_buf;
+
+	if (device->iser_free_rdma_reg_res)
+		device->iser_free_rdma_reg_res(ib_conn);
 
 	rx_desc = ib_conn->rx_descs;
-	for (i = 0; i < ISER_QP_MAX_RECV_DTOS; i++, rx_desc++)
+	for (i = 0; i < ib_conn->qp_max_recv_dtos; i++, rx_desc++)
 		ib_dma_unmap_single(device->ib_device, rx_desc->dma_addr,
-			ISER_RX_PAYLOAD_SIZE, DMA_FROM_DEVICE);
+				    ISER_RX_PAYLOAD_SIZE, DMA_FROM_DEVICE);
 	kfree(ib_conn->rx_descs);
+	/* make sure we never redo any unmapping */
+	ib_conn->rx_descs = NULL;
+
+free_login_buf:
+	iser_free_login_buf(ib_conn);
 }
 
 static int iser_post_rx_bufs(struct iscsi_conn *conn, struct iscsi_hdr *req)
 {
 	struct iscsi_iser_conn *iser_conn = conn->dd_data;
+	struct iscsi_session *session = conn->session;
 
 	iser_dbg("req op %x flags %x\n", req->opcode, req->flags);
 	/* check if this is the last login - going to full feature phase */
@@ -248,9 +343,16 @@ static int iser_post_rx_bufs(struct iscsi_conn *conn, struct iscsi_hdr *req)
 	WARN_ON(iser_conn->ib_conn->post_recv_buf_count != 1);
 	WARN_ON(atomic_read(&iser_conn->ib_conn->post_send_buf_count) != 0);
 
-	iser_dbg("Initially post: %d\n", ISER_MIN_POSTED_RX);
+	if (session->discovery_sess) {
+		iser_info("Discovery session, re-using login RX buffer\n");
+		return 0;
+	} else
+		iser_info("Normal session, posting batch of RX %d buffers\n",
+			  iser_conn->ib_conn->min_posted_rx);
+
 	/* Initial post receive buffers */
-	if (iser_post_recvm(iser_conn->ib_conn, ISER_MIN_POSTED_RX))
+	if (iser_post_recvm(iser_conn->ib_conn,
+			    iser_conn->ib_conn->min_posted_rx))
 		return -ENOMEM;
 
 	return 0;
@@ -425,6 +527,8 @@ int iser_send_control(struct iscsi_conn *conn,
 	}
 
 	if (task == conn->login_task) {
+		iser_dbg("op %x dsl %lx, posting login rx buffer\n",
+			 task->hdr->opcode, data_seg_len);
 		err = iser_post_recvl(iser_conn->ib_conn);
 		if (err)
 			goto send_control_error;
@@ -487,9 +591,9 @@ void iser_rcv_completion(struct iser_rx_desc *rx_desc,
 		return;
 
 	outstanding = ib_conn->post_recv_buf_count;
-	if (outstanding + ISER_MIN_POSTED_RX <= ISER_QP_MAX_RECV_DTOS) {
-		count = min(ISER_QP_MAX_RECV_DTOS - outstanding,
-						ISER_MIN_POSTED_RX);
+	if (outstanding + ib_conn->min_posted_rx <= ib_conn->qp_max_recv_dtos) {
+		count = min(ib_conn->qp_max_recv_dtos - outstanding,
+						ib_conn->min_posted_rx);
 		err = iser_post_recvm(ib_conn, count);
 		if (err)
 			iser_err("posting %d rx bufs err %d\n", count, err);
@@ -506,11 +610,12 @@ void iser_snd_completion(struct iser_tx_desc *tx_desc,
 		ib_dma_unmap_single(device->ib_device, tx_desc->dma_addr,
 					ISER_HEADERS_LEN, DMA_TO_DEVICE);
 		kmem_cache_free(ig.desc_cache, tx_desc);
+		tx_desc = NULL;
 	}
 
 	atomic_dec(&ib_conn->post_send_buf_count);
 
-	if (tx_desc->type == ISCSI_TX_CONTROL) {
+	if (tx_desc && tx_desc->type == ISCSI_TX_CONTROL) {
 		/* this arithmetic is legal by libiscsi dd_data allocation */
 		task = (void *) ((long)(void *)tx_desc -
 				  sizeof(struct iscsi_task));
@@ -538,8 +643,8 @@ void iser_task_rdma_init(struct iscsi_iser_task *iser_task)
 
 void iser_task_rdma_finalize(struct iscsi_iser_task *iser_task)
 {
+	struct iser_device *device = iser_task->iser_conn->ib_conn->device;
 	int is_rdma_aligned = 1;
-	struct iser_regd_buf *regd;
 
 	/* if we were reading, copy back to unaligned sglist,
 	 * anyway dma_unmap and free the copy
@@ -553,17 +658,11 @@ void iser_task_rdma_finalize(struct iscsi_iser_task *iser_task)
 		iser_finalize_rdma_unaligned_sg(iser_task, ISER_DIR_OUT);
 	}
 
-	if (iser_task->dir[ISER_DIR_IN]) {
-		regd = &iser_task->rdma_regd[ISER_DIR_IN];
-		if (regd->reg.is_fmr)
-			iser_unreg_mem(&regd->reg);
-	}
+	if (iser_task->dir[ISER_DIR_IN])
+		device->iser_unreg_rdma_mem(iser_task, ISER_DIR_IN);
 
-	if (iser_task->dir[ISER_DIR_OUT]) {
-		regd = &iser_task->rdma_regd[ISER_DIR_OUT];
-		if (regd->reg.is_fmr)
-			iser_unreg_mem(&regd->reg);
-	}
+	if (iser_task->dir[ISER_DIR_OUT])
+		device->iser_unreg_rdma_mem(iser_task, ISER_DIR_OUT);
 
        /* if the data was unaligned, it was already unmapped and then copied */
        if (is_rdma_aligned)
diff --git a/drivers/infiniband/ulp/iser/iser_memory.c b/drivers/infiniband/ulp/iser/iser_memory.c
index 7827baf..1ce0c97 100644
--- a/drivers/infiniband/ulp/iser/iser_memory.c
+++ b/drivers/infiniband/ulp/iser/iser_memory.c
@@ -170,8 +170,8 @@ void iser_finalize_rdma_unaligned_sg(struct iscsi_iser_task *iser_task,
  */
 
 static int iser_sg_to_page_vec(struct iser_data_buf *data,
-			       struct iser_page_vec *page_vec,
-			       struct ib_device *ibdev)
+			       struct ib_device *ibdev, u64 *pages,
+			       int *offset, int *data_size)
 {
 	struct scatterlist *sg, *sgl = (struct scatterlist *)data->buf;
 	u64 start_addr, end_addr, page, chunk_start = 0;
@@ -180,7 +180,7 @@ static int iser_sg_to_page_vec(struct iser_data_buf *data,
 	int i, new_chunk, cur_page, last_ent = data->dma_nents - 1;
 
 	/* compute the offset of first element */
-	page_vec->offset = (u64) sgl[0].offset & ~MASK_4K;
+	*offset = (u64) sgl[0].offset & ~MASK_4K;
 
 	new_chunk = 1;
 	cur_page  = 0;
@@ -204,13 +204,14 @@ static int iser_sg_to_page_vec(struct iser_data_buf *data,
 		   which might be unaligned */
 		page = chunk_start & MASK_4K;
 		do {
-			page_vec->pages[cur_page++] = page;
+			pages[cur_page++] = page;
 			page += SIZE_4K;
 		} while (page < end_addr);
 	}
 
-	page_vec->data_size = total_sz;
-	iser_dbg("page_vec->data_size:%d cur_page %d\n", page_vec->data_size,cur_page);
+	*data_size = total_sz;
+	iser_dbg("page_vec->data_size:%d cur_page %d\n",
+		 *data_size, cur_page);
 	return cur_page;
 }
 
@@ -267,11 +268,8 @@ static void iser_data_buf_dump(struct iser_data_buf *data,
 	struct scatterlist *sg;
 	int i;
 
-	if (iser_debug_level == 0)
-		return;
-
 	for_each_sg(sgl, sg, data->dma_nents, i)
-		iser_warn("sg[%d] dma_addr:0x%lX page:0x%p "
+		iser_dbg("sg[%d] dma_addr:0x%lX page:0x%p "
 			 "off:0x%x sz:0x%x dma_len:0x%x\n",
 			 i, (unsigned long)ib_sg_dma_address(ibdev, sg),
 			 sg_page(sg), sg->offset,
@@ -298,8 +296,10 @@ static void iser_page_vec_build(struct iser_data_buf *data,
 	page_vec->offset = 0;
 
 	iser_dbg("Translating sg sz: %d\n", data->dma_nents);
-	page_vec_len = iser_sg_to_page_vec(data, page_vec, ibdev);
-	iser_dbg("sg len %d page_vec_len %d\n", data->dma_nents,page_vec_len);
+	page_vec_len = iser_sg_to_page_vec(data, ibdev, page_vec->pages,
+					   &page_vec->offset,
+					   &page_vec->data_size);
+	iser_dbg("sg len %d page_vec_len %d\n", data->dma_nents, page_vec_len);
 
 	page_vec->length = page_vec_len;
 
@@ -347,16 +347,41 @@ void iser_dma_unmap_task_data(struct iscsi_iser_task *iser_task)
 	}
 }
 
+static int fall_to_bounce_buf(struct iscsi_iser_task *iser_task,
+			      struct ib_device *ibdev,
+			      enum iser_data_dir cmd_dir,
+			      int aligned_len)
+{
+	struct iscsi_conn    *iscsi_conn = iser_task->iser_conn->iscsi_conn;
+	struct iser_data_buf *mem = &iser_task->data[cmd_dir];
+
+	iscsi_conn->fmr_unalign_cnt++;
+	iser_warn("rdma alignment violation (%d/%d aligned) or FMR not supported\n",
+		  aligned_len, mem->size);
+
+	if (iser_debug_level > 0)
+		iser_data_buf_dump(mem, ibdev);
+
+	/* unmap the command data before accessing it */
+	iser_dma_unmap_task_data(iser_task);
+
+	/* allocate copy buf, if we are writing, copy the */
+	/* unaligned scatterlist, dma map the copy        */
+	if (iser_start_rdma_unaligned_sg(iser_task, cmd_dir) != 0)
+			return -ENOMEM;
+
+	return 0;
+}
+
 /**
- * iser_reg_rdma_mem - Registers memory intended for RDMA,
- * obtaining rkey and va
+ * iser_reg_rdma_mem_fmr - Registers memory intended for RDMA,
+ * using FMR (if possible) obtaining rkey and va
  *
  * returns 0 on success, errno code on failure
  */
-int iser_reg_rdma_mem(struct iscsi_iser_task *iser_task,
-		      enum   iser_data_dir        cmd_dir)
+int iser_reg_rdma_mem_fmr(struct iscsi_iser_task *iser_task,
+			  enum iser_data_dir cmd_dir)
 {
-	struct iscsi_conn    *iscsi_conn = iser_task->iser_conn->iscsi_conn;
 	struct iser_conn     *ib_conn = iser_task->iser_conn->ib_conn;
 	struct iser_device   *device = ib_conn->device;
 	struct ib_device     *ibdev = device->ib_device;
@@ -370,20 +395,13 @@ int iser_reg_rdma_mem(struct iscsi_iser_task *iser_task,
 	regd_buf = &iser_task->rdma_regd[cmd_dir];
 
 	aligned_len = iser_data_buf_aligned_len(mem, ibdev);
-	if (aligned_len != mem->dma_nents ||
-	    (!ib_conn->fmr_pool && mem->dma_nents > 1)) {
-		iscsi_conn->fmr_unalign_cnt++;
-		iser_warn("rdma alignment violation (%d/%d aligned) or FMR not supported\n",
-			  aligned_len, mem->size);
-		iser_data_buf_dump(mem, ibdev);
-
-		/* unmap the command data before accessing it */
-		iser_dma_unmap_task_data(iser_task);
-
-		/* allocate copy buf, if we are writing, copy the */
-		/* unaligned scatterlist, dma map the copy        */
-		if (iser_start_rdma_unaligned_sg(iser_task, cmd_dir) != 0)
-				return -ENOMEM;
+	if (aligned_len != mem->dma_nents) {
+		err = fall_to_bounce_buf(iser_task, ibdev,
+					 cmd_dir, aligned_len);
+		if (err) {
+			iser_err("failed to allocate bounce buffer\n");
+			return err;
+		}
 		mem = &iser_task->data_copy[cmd_dir];
 	}
 
@@ -395,7 +413,7 @@ int iser_reg_rdma_mem(struct iscsi_iser_task *iser_task,
 		regd_buf->reg.rkey = device->mr->rkey;
 		regd_buf->reg.len  = ib_sg_dma_len(ibdev, &sg[0]);
 		regd_buf->reg.va   = ib_sg_dma_address(ibdev, &sg[0]);
-		regd_buf->reg.is_fmr = 0;
+		regd_buf->reg.is_mr = 0;
 
 		iser_dbg("PHYSICAL Mem.register: lkey: 0x%08X rkey: 0x%08X  "
 			 "va: 0x%08lX sz: %ld]\n",
@@ -404,22 +422,159 @@ int iser_reg_rdma_mem(struct iscsi_iser_task *iser_task,
 			 (unsigned long)regd_buf->reg.va,
 			 (unsigned long)regd_buf->reg.len);
 	} else { /* use FMR for multiple dma entries */
-		iser_page_vec_build(mem, ib_conn->page_vec, ibdev);
-		err = iser_reg_page_vec(ib_conn, ib_conn->page_vec, &regd_buf->reg);
+		iser_page_vec_build(mem, ib_conn->fastreg.fmr.page_vec, ibdev);
+		err = iser_reg_page_vec(ib_conn, ib_conn->fastreg.fmr.page_vec,
+					&regd_buf->reg);
 		if (err && err != -EAGAIN) {
 			iser_data_buf_dump(mem, ibdev);
 			iser_err("mem->dma_nents = %d (dlength = 0x%x)\n",
 				 mem->dma_nents,
 				 ntoh24(iser_task->desc.iscsi_header.dlength));
 			iser_err("page_vec: data_size = 0x%x, length = %d, offset = 0x%x\n",
-				 ib_conn->page_vec->data_size, ib_conn->page_vec->length,
-				 ib_conn->page_vec->offset);
-			for (i=0 ; i<ib_conn->page_vec->length ; i++)
+				 ib_conn->fastreg.fmr.page_vec->data_size,
+				 ib_conn->fastreg.fmr.page_vec->length,
+				 ib_conn->fastreg.fmr.page_vec->offset);
+			for (i = 0; i < ib_conn->fastreg.fmr.page_vec->length; i++)
 				iser_err("page_vec[%d] = 0x%llx\n", i,
-					 (unsigned long long) ib_conn->page_vec->pages[i]);
+					 (unsigned long long) ib_conn->fastreg.fmr.page_vec->pages[i]);
 		}
 		if (err)
 			return err;
 	}
 	return 0;
 }
+
+static int iser_fast_reg_mr(struct fast_reg_descriptor *desc,
+			    struct iser_conn *ib_conn,
+			    struct iser_regd_buf *regd_buf,
+			    u32 offset, unsigned int data_size,
+			    unsigned int page_list_len)
+{
+	struct ib_send_wr fastreg_wr, inv_wr;
+	struct ib_send_wr *bad_wr, *wr = NULL;
+	u8 key;
+	int ret;
+
+	if (!desc->valid) {
+		memset(&inv_wr, 0, sizeof(inv_wr));
+		inv_wr.opcode = IB_WR_LOCAL_INV;
+		inv_wr.send_flags = IB_SEND_SIGNALED;
+		inv_wr.ex.invalidate_rkey = desc->data_mr->rkey;
+		wr = &inv_wr;
+		/* Bump the key */
+		key = (u8)(desc->data_mr->rkey & 0x000000FF);
+		ib_update_fast_reg_key(desc->data_mr, ++key);
+	}
+
+	/* Prepare FASTREG WR */
+	memset(&fastreg_wr, 0, sizeof(fastreg_wr));
+	fastreg_wr.opcode = IB_WR_FAST_REG_MR;
+	fastreg_wr.send_flags = IB_SEND_SIGNALED;
+	fastreg_wr.wr.fast_reg.iova_start = desc->data_frpl->page_list[0] + offset;
+	fastreg_wr.wr.fast_reg.page_list = desc->data_frpl;
+	fastreg_wr.wr.fast_reg.page_list_len = page_list_len;
+	fastreg_wr.wr.fast_reg.page_shift = SHIFT_4K;
+	fastreg_wr.wr.fast_reg.length = data_size;
+	fastreg_wr.wr.fast_reg.rkey = desc->data_mr->rkey;
+	fastreg_wr.wr.fast_reg.access_flags = (IB_ACCESS_LOCAL_WRITE  |
+					       IB_ACCESS_REMOTE_WRITE |
+					       IB_ACCESS_REMOTE_READ);
+
+	if (!wr) {
+		wr = &fastreg_wr;
+		atomic_inc(&ib_conn->post_send_buf_count);
+	} else {
+		wr->next = &fastreg_wr;
+		atomic_add(2, &ib_conn->post_send_buf_count);
+	}
+
+	ret = ib_post_send(ib_conn->qp, wr, &bad_wr);
+	if (ret) {
+		if (bad_wr->next)
+			atomic_sub(2, &ib_conn->post_send_buf_count);
+		else
+			atomic_dec(&ib_conn->post_send_buf_count);
+		iser_err("fast registration failed, ret:%d\n", ret);
+		return ret;
+	}
+	desc->valid = false;
+
+	regd_buf->reg.mem_h = desc;
+	regd_buf->reg.lkey = desc->data_mr->lkey;
+	regd_buf->reg.rkey = desc->data_mr->rkey;
+	regd_buf->reg.va = desc->data_frpl->page_list[0] + offset;
+	regd_buf->reg.len = data_size;
+	regd_buf->reg.is_mr = 1;
+
+	return ret;
+}
+
+/**
+ * iser_reg_rdma_mem_frwr - Registers memory intended for RDMA,
+ * using Fast Registration WR (if possible) obtaining rkey and va
+ *
+ * returns 0 on success, errno code on failure
+ */
+int iser_reg_rdma_mem_frwr(struct iscsi_iser_task *iser_task,
+			   enum iser_data_dir cmd_dir)
+{
+	struct iser_conn *ib_conn = iser_task->iser_conn->ib_conn;
+	struct iser_device *device = ib_conn->device;
+	struct ib_device *ibdev = device->ib_device;
+	struct iser_data_buf *mem = &iser_task->data[cmd_dir];
+	struct iser_regd_buf *regd_buf = &iser_task->rdma_regd[cmd_dir];
+	struct fast_reg_descriptor *desc;
+	unsigned int data_size, page_list_len;
+	int err, aligned_len;
+	unsigned long flags;
+	u32 offset;
+
+	aligned_len = iser_data_buf_aligned_len(mem, ibdev);
+	if (aligned_len != mem->dma_nents) {
+		err = fall_to_bounce_buf(iser_task, ibdev,
+					 cmd_dir, aligned_len);
+		if (err) {
+			iser_err("failed to allocate bounce buffer\n");
+			return err;
+		}
+		mem = &iser_task->data_copy[cmd_dir];
+	}
+
+	/* if there a single dma entry, dma mr suffices */
+	if (mem->dma_nents == 1) {
+		struct scatterlist *sg = (struct scatterlist *)mem->buf;
+
+		regd_buf->reg.lkey = device->mr->lkey;
+		regd_buf->reg.rkey = device->mr->rkey;
+		regd_buf->reg.len  = ib_sg_dma_len(ibdev, &sg[0]);
+		regd_buf->reg.va   = ib_sg_dma_address(ibdev, &sg[0]);
+		regd_buf->reg.is_mr = 0;
+	} else {
+		spin_lock_irqsave(&ib_conn->lock, flags);
+		desc = list_first_entry(&ib_conn->fastreg.frwr.pool,
+					struct fast_reg_descriptor, list);
+		list_del(&desc->list);
+		spin_unlock_irqrestore(&ib_conn->lock, flags);
+		page_list_len = iser_sg_to_page_vec(mem, device->ib_device,
+						    desc->data_frpl->page_list,
+						    &offset, &data_size);
+
+		if (page_list_len * SIZE_4K < data_size) {
+			iser_err("fast reg page_list too short to hold this SG\n");
+			err = -EINVAL;
+			goto err_reg;
+		}
+
+		err = iser_fast_reg_mr(desc, ib_conn, regd_buf,
+				       offset, data_size, page_list_len);
+		if (err)
+			goto err_reg;
+	}
+
+	return 0;
+err_reg:
+	spin_lock_irqsave(&ib_conn->lock, flags);
+	list_add_tail(&desc->list, &ib_conn->fastreg.frwr.pool);
+	spin_unlock_irqrestore(&ib_conn->lock, flags);
+	return err;
+}
diff --git a/drivers/infiniband/ulp/iser/iser_verbs.c b/drivers/infiniband/ulp/iser/iser_verbs.c
index 2c4941d..ca37ede 100644
--- a/drivers/infiniband/ulp/iser/iser_verbs.c
+++ b/drivers/infiniband/ulp/iser/iser_verbs.c
@@ -73,6 +73,36 @@ static int iser_create_device_ib_res(struct iser_device *device)
 {
 	int i, j;
 	struct iser_cq_desc *cq_desc;
+	struct ib_device_attr *dev_attr;
+
+	dev_attr = kmalloc(sizeof(*dev_attr), GFP_KERNEL);
+	if (!dev_attr)
+		return -ENOMEM;
+
+	if (ib_query_device(device->ib_device, dev_attr)) {
+		pr_warn("Query device failed for %s\n", device->ib_device->name);
+		goto dev_attr_err;
+	}
+
+	/* Assign function handles  - based on FMR support */
+	if (device->ib_device->alloc_fmr && device->ib_device->dealloc_fmr &&
+	    device->ib_device->map_phys_fmr && device->ib_device->unmap_fmr) {
+		iser_info("FMR supported, using FMR for registration\n");
+		device->iser_alloc_rdma_reg_res = iser_create_fmr_pool;
+		device->iser_free_rdma_reg_res = iser_free_fmr_pool;
+		device->iser_reg_rdma_mem = iser_reg_rdma_mem_fmr;
+		device->iser_unreg_rdma_mem = iser_unreg_mem_fmr;
+	} else
+	if (dev_attr->device_cap_flags & IB_DEVICE_MEM_MGT_EXTENSIONS) {
+		iser_info("FRWR supported, using FRWR for registration\n");
+		device->iser_alloc_rdma_reg_res = iser_create_frwr_pool;
+		device->iser_free_rdma_reg_res = iser_free_frwr_pool;
+		device->iser_reg_rdma_mem = iser_reg_rdma_mem_frwr;
+		device->iser_unreg_rdma_mem = iser_unreg_mem_frwr;
+	} else {
+		iser_err("IB device does not support FMRs nor FRWRs, can't register memory\n");
+		goto dev_attr_err;
+	}
 
 	device->cqs_used = min(ISER_MAX_CQ, device->ib_device->num_comp_vectors);
 	iser_info("using %d CQs, device %s supports %d vectors\n",
@@ -128,6 +158,7 @@ static int iser_create_device_ib_res(struct iser_device *device)
 	if (ib_register_event_handler(&device->event_handler))
 		goto handler_err;
 
+	kfree(dev_attr);
 	return 0;
 
 handler_err:
@@ -147,6 +178,8 @@ pd_err:
 	kfree(device->cq_desc);
 cq_desc_err:
 	iser_err("failed to allocate an IB resource\n");
+dev_attr_err:
+	kfree(dev_attr);
 	return -1;
 }
 
@@ -178,56 +211,23 @@ static void iser_free_device_ib_res(struct iser_device *device)
 }
 
 /**
- * iser_create_ib_conn_res - Creates FMR pool and Queue-Pair (QP)
+ * iser_create_fmr_pool - Creates FMR pool and page_vector
  *
- * returns 0 on success, -1 on failure
+ * returns 0 on success, or errno code on failure
  */
-static int iser_create_ib_conn_res(struct iser_conn *ib_conn)
+int iser_create_fmr_pool(struct iser_conn *ib_conn, unsigned cmds_max)
 {
-	struct iser_device	*device;
-	struct ib_qp_init_attr	init_attr;
-	int			req_err, resp_err, ret = -ENOMEM;
+	struct iser_device *device = ib_conn->device;
 	struct ib_fmr_pool_param params;
-	int index, min_index = 0;
+	int ret = -ENOMEM;
 
-	BUG_ON(ib_conn->device == NULL);
+	ib_conn->fastreg.fmr.page_vec = kmalloc(sizeof(struct iser_page_vec) +
+						(sizeof(u64)*(ISCSI_ISER_SG_TABLESIZE + 1)),
+						GFP_KERNEL);
+	if (!ib_conn->fastreg.fmr.page_vec)
+		return ret;
 
-	device = ib_conn->device;
-
-	ib_conn->login_buf = kmalloc(ISCSI_DEF_MAX_RECV_SEG_LEN +
-					ISER_RX_LOGIN_SIZE, GFP_KERNEL);
-	if (!ib_conn->login_buf)
-		goto out_err;
-
-	ib_conn->login_req_buf  = ib_conn->login_buf;
-	ib_conn->login_resp_buf = ib_conn->login_buf + ISCSI_DEF_MAX_RECV_SEG_LEN;
-
-	ib_conn->login_req_dma = ib_dma_map_single(ib_conn->device->ib_device,
-				(void *)ib_conn->login_req_buf,
-				ISCSI_DEF_MAX_RECV_SEG_LEN, DMA_TO_DEVICE);
-
-	ib_conn->login_resp_dma = ib_dma_map_single(ib_conn->device->ib_device,
-				(void *)ib_conn->login_resp_buf,
-				ISER_RX_LOGIN_SIZE, DMA_FROM_DEVICE);
-
-	req_err  = ib_dma_mapping_error(device->ib_device, ib_conn->login_req_dma);
-	resp_err = ib_dma_mapping_error(device->ib_device, ib_conn->login_resp_dma);
-
-	if (req_err || resp_err) {
-		if (req_err)
-			ib_conn->login_req_dma = 0;
-		if (resp_err)
-			ib_conn->login_resp_dma = 0;
-		goto out_err;
-	}
-
-	ib_conn->page_vec = kmalloc(sizeof(struct iser_page_vec) +
-				    (sizeof(u64) * (ISCSI_ISER_SG_TABLESIZE +1)),
-				    GFP_KERNEL);
-	if (!ib_conn->page_vec)
-		goto out_err;
-
-	ib_conn->page_vec->pages = (u64 *) (ib_conn->page_vec + 1);
+	ib_conn->fastreg.fmr.page_vec->pages = (u64 *)(ib_conn->fastreg.fmr.page_vec + 1);
 
 	params.page_shift        = SHIFT_4K;
 	/* when the first/last SG element are not start/end *
@@ -235,25 +235,144 @@ static int iser_create_ib_conn_res(struct iser_conn *ib_conn)
 	params.max_pages_per_fmr = ISCSI_ISER_SG_TABLESIZE + 1;
 	/* make the pool size twice the max number of SCSI commands *
 	 * the ML is expected to queue, watermark for unmap at 50%  */
-	params.pool_size	 = ISCSI_DEF_XMIT_CMDS_MAX * 2;
-	params.dirty_watermark	 = ISCSI_DEF_XMIT_CMDS_MAX;
+	params.pool_size	 = cmds_max * 2;
+	params.dirty_watermark	 = cmds_max;
 	params.cache		 = 0;
 	params.flush_function	 = NULL;
 	params.access		 = (IB_ACCESS_LOCAL_WRITE  |
 				    IB_ACCESS_REMOTE_WRITE |
 				    IB_ACCESS_REMOTE_READ);
 
-	ib_conn->fmr_pool = ib_create_fmr_pool(device->pd, &params);
-	ret = PTR_ERR(ib_conn->fmr_pool);
-	if (IS_ERR(ib_conn->fmr_pool) && ret != -ENOSYS) {
-		ib_conn->fmr_pool = NULL;
-		goto out_err;
-	} else if (ret == -ENOSYS) {
-		ib_conn->fmr_pool = NULL;
+	ib_conn->fastreg.fmr.pool = ib_create_fmr_pool(device->pd, &params);
+	if (!IS_ERR(ib_conn->fastreg.fmr.pool))
+		return 0;
+
+	/* no FMR => no need for page_vec */
+	kfree(ib_conn->fastreg.fmr.page_vec);
+	ib_conn->fastreg.fmr.page_vec = NULL;
+
+	ret = PTR_ERR(ib_conn->fastreg.fmr.pool);
+	ib_conn->fastreg.fmr.pool = NULL;
+	if (ret != -ENOSYS) {
+		iser_err("FMR allocation failed, err %d\n", ret);
+		return ret;
+	} else {
 		iser_warn("FMRs are not supported, using unaligned mode\n");
-		ret = 0;
+		return 0;
+	}
+}
+
+/**
+ * iser_free_fmr_pool - releases the FMR pool and page vec
+ */
+void iser_free_fmr_pool(struct iser_conn *ib_conn)
+{
+	iser_info("freeing conn %p fmr pool %p\n",
+		  ib_conn, ib_conn->fastreg.fmr.pool);
+
+	if (ib_conn->fastreg.fmr.pool != NULL)
+		ib_destroy_fmr_pool(ib_conn->fastreg.fmr.pool);
+
+	ib_conn->fastreg.fmr.pool = NULL;
+
+	kfree(ib_conn->fastreg.fmr.page_vec);
+	ib_conn->fastreg.fmr.page_vec = NULL;
+}
+
+/**
+ * iser_create_frwr_pool - Creates pool of fast_reg descriptors
+ * for fast registration work requests.
+ * returns 0 on success, or errno code on failure
+ */
+int iser_create_frwr_pool(struct iser_conn *ib_conn, unsigned cmds_max)
+{
+	struct iser_device	*device = ib_conn->device;
+	struct fast_reg_descriptor	*desc;
+	int i, ret;
+
+	INIT_LIST_HEAD(&ib_conn->fastreg.frwr.pool);
+	ib_conn->fastreg.frwr.pool_size = 0;
+	for (i = 0; i < cmds_max; i++) {
+		desc = kmalloc(sizeof(*desc), GFP_KERNEL);
+		if (!desc) {
+			iser_err("Failed to allocate a new fast_reg descriptor\n");
+			ret = -ENOMEM;
+			goto err;
+		}
+
+		desc->data_frpl = ib_alloc_fast_reg_page_list(device->ib_device,
+							 ISCSI_ISER_SG_TABLESIZE + 1);
+		if (IS_ERR(desc->data_frpl)) {
+			ret = PTR_ERR(desc->data_frpl);
+			iser_err("Failed to allocate ib_fast_reg_page_list err=%d\n", ret);
+			goto fast_reg_page_failure;
+		}
+
+		desc->data_mr = ib_alloc_fast_reg_mr(device->pd,
+						     ISCSI_ISER_SG_TABLESIZE + 1);
+		if (IS_ERR(desc->data_mr)) {
+			ret = PTR_ERR(desc->data_mr);
+			iser_err("Failed to allocate ib_fast_reg_mr err=%d\n", ret);
+			goto fast_reg_mr_failure;
+		}
+		desc->valid = true;
+		list_add_tail(&desc->list, &ib_conn->fastreg.frwr.pool);
+		ib_conn->fastreg.frwr.pool_size++;
 	}
 
+	return 0;
+
+fast_reg_mr_failure:
+	ib_free_fast_reg_page_list(desc->data_frpl);
+fast_reg_page_failure:
+	kfree(desc);
+err:
+	iser_free_frwr_pool(ib_conn);
+	return ret;
+}
+
+/**
+ * iser_free_frwr_pool - releases the pool of fast_reg descriptors
+ */
+void iser_free_frwr_pool(struct iser_conn *ib_conn)
+{
+	struct fast_reg_descriptor *desc, *tmp;
+	int i = 0;
+
+	if (list_empty(&ib_conn->fastreg.frwr.pool))
+		return;
+
+	iser_info("freeing conn %p frwr pool\n", ib_conn);
+
+	list_for_each_entry_safe(desc, tmp, &ib_conn->fastreg.frwr.pool, list) {
+		list_del(&desc->list);
+		ib_free_fast_reg_page_list(desc->data_frpl);
+		ib_dereg_mr(desc->data_mr);
+		kfree(desc);
+		++i;
+	}
+
+	if (i < ib_conn->fastreg.frwr.pool_size)
+		iser_warn("pool still has %d regions registered\n",
+			  ib_conn->fastreg.frwr.pool_size - i);
+}
+
+/**
+ * iser_create_ib_conn_res - Queue-Pair (QP)
+ *
+ * returns 0 on success, -1 on failure
+ */
+static int iser_create_ib_conn_res(struct iser_conn *ib_conn)
+{
+	struct iser_device	*device;
+	struct ib_qp_init_attr	init_attr;
+	int			ret = -ENOMEM;
+	int index, min_index = 0;
+
+	BUG_ON(ib_conn->device == NULL);
+
+	device = ib_conn->device;
+
 	memset(&init_attr, 0, sizeof init_attr);
 
 	mutex_lock(&ig.connlist_mutex);
@@ -282,9 +401,9 @@ static int iser_create_ib_conn_res(struct iser_conn *ib_conn)
 		goto out_err;
 
 	ib_conn->qp = ib_conn->cma_id->qp;
-	iser_info("setting conn %p cma_id %p: fmr_pool %p qp %p\n",
+	iser_info("setting conn %p cma_id %p qp %p\n",
 		  ib_conn, ib_conn->cma_id,
-		  ib_conn->fmr_pool, ib_conn->cma_id->qp);
+		  ib_conn->cma_id->qp);
 	return ret;
 
 out_err:
@@ -293,7 +412,7 @@ out_err:
 }
 
 /**
- * releases the FMR pool and QP objects, returns 0 on success,
+ * releases the QP objects, returns 0 on success,
  * -1 on failure
  */
 static int iser_free_ib_conn_res(struct iser_conn *ib_conn)
@@ -301,13 +420,11 @@ static int iser_free_ib_conn_res(struct iser_conn *ib_conn)
 	int cq_index;
 	BUG_ON(ib_conn == NULL);
 
-	iser_info("freeing conn %p cma_id %p fmr pool %p qp %p\n",
+	iser_info("freeing conn %p cma_id %p qp %p\n",
 		  ib_conn, ib_conn->cma_id,
-		  ib_conn->fmr_pool, ib_conn->qp);
+		  ib_conn->qp);
 
 	/* qp is created only once both addr & route are resolved */
-	if (ib_conn->fmr_pool != NULL)
-		ib_destroy_fmr_pool(ib_conn->fmr_pool);
 
 	if (ib_conn->qp != NULL) {
 		cq_index = ((struct iser_cq_desc *)ib_conn->qp->recv_cq->cq_context)->cq_index;
@@ -316,21 +433,7 @@ static int iser_free_ib_conn_res(struct iser_conn *ib_conn)
 		rdma_destroy_qp(ib_conn->cma_id);
 	}
 
-	ib_conn->fmr_pool = NULL;
 	ib_conn->qp	  = NULL;
-	kfree(ib_conn->page_vec);
-
-	if (ib_conn->login_buf) {
-		if (ib_conn->login_req_dma)
-			ib_dma_unmap_single(ib_conn->device->ib_device,
-				ib_conn->login_req_dma,
-				ISCSI_DEF_MAX_RECV_SEG_LEN, DMA_TO_DEVICE);
-		if (ib_conn->login_resp_dma)
-			ib_dma_unmap_single(ib_conn->device->ib_device,
-				ib_conn->login_resp_dma,
-				ISER_RX_LOGIN_SIZE, DMA_FROM_DEVICE);
-		kfree(ib_conn->login_buf);
-	}
 
 	return 0;
 }
@@ -549,9 +652,13 @@ static int iser_disconnected_handler(struct rdma_cm_id *cma_id)
 	/* getting here when the state is UP means that the conn is being *
 	 * terminated asynchronously from the iSCSI layer's perspective.  */
 	if (iser_conn_state_comp_exch(ib_conn, ISER_CONN_UP,
-				      ISER_CONN_TERMINATING))
-		iscsi_conn_failure(ib_conn->iser_conn->iscsi_conn,
-				   ISCSI_ERR_CONN_FAILED);
+					ISER_CONN_TERMINATING)){
+		if (ib_conn->iser_conn)
+			iscsi_conn_failure(ib_conn->iser_conn->iscsi_conn,
+					   ISCSI_ERR_CONN_FAILED);
+		else
+			iser_err("iscsi_iser connection isn't bound\n");
+	}
 
 	/* Complete the termination process if no posts are pending */
 	if (ib_conn->post_recv_buf_count == 0 &&
@@ -694,7 +801,7 @@ int iser_reg_page_vec(struct iser_conn     *ib_conn,
 	page_list = page_vec->pages;
 	io_addr	  = page_list[0];
 
-	mem  = ib_fmr_pool_map_phys(ib_conn->fmr_pool,
+	mem  = ib_fmr_pool_map_phys(ib_conn->fastreg.fmr.pool,
 				    page_list,
 				    page_vec->length,
 				    io_addr);
@@ -709,7 +816,7 @@ int iser_reg_page_vec(struct iser_conn     *ib_conn,
 	mem_reg->rkey  = mem->fmr->rkey;
 	mem_reg->len   = page_vec->length * SIZE_4K;
 	mem_reg->va    = io_addr;
-	mem_reg->is_fmr = 1;
+	mem_reg->is_mr = 1;
 	mem_reg->mem_h = (void *)mem;
 
 	mem_reg->va   += page_vec->offset;
@@ -727,12 +834,18 @@ int iser_reg_page_vec(struct iser_conn     *ib_conn,
 }
 
 /**
- * Unregister (previosuly registered) memory.
+ * Unregister (previosuly registered using FMR) memory.
+ * If memory is non-FMR does nothing.
  */
-void iser_unreg_mem(struct iser_mem_reg *reg)
+void iser_unreg_mem_fmr(struct iscsi_iser_task *iser_task,
+			enum iser_data_dir cmd_dir)
 {
+	struct iser_mem_reg *reg = &iser_task->rdma_regd[cmd_dir].reg;
 	int ret;
 
+	if (!reg->is_mr)
+		return;
+
 	iser_dbg("PHYSICAL Mem.Unregister mem_h %p\n",reg->mem_h);
 
 	ret = ib_fmr_pool_unmap((struct ib_pool_fmr *)reg->mem_h);
@@ -742,6 +855,23 @@ void iser_unreg_mem(struct iser_mem_reg *reg)
 	reg->mem_h = NULL;
 }
 
+void iser_unreg_mem_frwr(struct iscsi_iser_task *iser_task,
+			 enum iser_data_dir cmd_dir)
+{
+	struct iser_mem_reg *reg = &iser_task->rdma_regd[cmd_dir].reg;
+	struct iser_conn *ib_conn = iser_task->iser_conn->ib_conn;
+	struct fast_reg_descriptor *desc = reg->mem_h;
+
+	if (!reg->is_mr)
+		return;
+
+	reg->mem_h = NULL;
+	reg->is_mr = 0;
+	spin_lock_bh(&ib_conn->lock);
+	list_add_tail(&desc->list, &ib_conn->fastreg.frwr.pool);
+	spin_unlock_bh(&ib_conn->lock);
+}
+
 int iser_post_recvl(struct iser_conn *ib_conn)
 {
 	struct ib_recv_wr rx_wr, *rx_wr_failed;
@@ -779,7 +909,7 @@ int iser_post_recvm(struct iser_conn *ib_conn, int count)
 		rx_wr->sg_list	= &rx_desc->rx_sg;
 		rx_wr->num_sge	= 1;
 		rx_wr->next	= rx_wr + 1;
-		my_rx_head = (my_rx_head + 1) & (ISER_QP_MAX_RECV_DTOS - 1);
+		my_rx_head = (my_rx_head + 1) & ib_conn->qp_max_recv_dtos_mask;
 	}
 
 	rx_wr--;
@@ -863,7 +993,11 @@ static int iser_drain_tx_cq(struct iser_device  *device, int cq_index)
 		if (wc.status == IB_WC_SUCCESS) {
 			if (wc.opcode == IB_WC_SEND)
 				iser_snd_completion(tx_desc, ib_conn);
-			else
+			else if (wc.opcode == IB_WC_LOCAL_INV ||
+				 wc.opcode == IB_WC_FAST_REG_MR) {
+				atomic_dec(&ib_conn->post_send_buf_count);
+				continue;
+			} else
 				iser_err("expected opcode %d got %d\n",
 					IB_WC_SEND, wc.opcode);
 		} else {
diff --git a/drivers/infiniband/ulp/isert/Kconfig b/drivers/infiniband/ulp/isert/Kconfig
index ce3fd32..02f9759 100644
--- a/drivers/infiniband/ulp/isert/Kconfig
+++ b/drivers/infiniband/ulp/isert/Kconfig
@@ -1,5 +1,5 @@
 config INFINIBAND_ISERT
-	tristate "iSCSI Extentions for RDMA (iSER) target support"
+	tristate "iSCSI Extensions for RDMA (iSER) target support"
 	depends on INET && INFINIBAND_ADDR_TRANS && TARGET_CORE && ISCSI_TARGET
 	---help---
-	Support for iSCSI Extentions for RDMA (iSER) Target on Infiniband fabrics.
+	Support for iSCSI Extensions for RDMA (iSER) Target on Infiniband fabrics.
diff --git a/drivers/infiniband/ulp/isert/ib_isert.c b/drivers/infiniband/ulp/isert/ib_isert.c
index 5849dc0..eb4588c 100644
--- a/drivers/infiniband/ulp/isert/ib_isert.c
+++ b/drivers/infiniband/ulp/isert/ib_isert.c
@@ -1,7 +1,7 @@
 /*******************************************************************************
  * This file contains iSCSI extentions for RDMA (iSER) Verbs
  *
- * (c) Copyright 2013 RisingTide Systems LLC.
+ * (c) Copyright 2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -22,11 +22,14 @@
 #include <linux/socket.h>
 #include <linux/in.h>
 #include <linux/in6.h>
+#include <linux/llist.h>
 #include <rdma/ib_verbs.h>
 #include <rdma/rdma_cm.h>
 #include <target/target_core_base.h>
 #include <target/target_core_fabric.h>
 #include <target/iscsi/iscsi_transport.h>
+#include <linux/semaphore.h>
+#include <linux/completion.h>
 
 #include "isert_proto.h"
 #include "ib_isert.h"
@@ -39,7 +42,25 @@ static DEFINE_MUTEX(device_list_mutex);
 static LIST_HEAD(device_list);
 static struct workqueue_struct *isert_rx_wq;
 static struct workqueue_struct *isert_comp_wq;
-static struct kmem_cache *isert_cmd_cache;
+static struct workqueue_struct *isert_release_wq;
+
+static void
+isert_unmap_cmd(struct isert_cmd *isert_cmd, struct isert_conn *isert_conn);
+static int
+isert_map_rdma(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+	       struct isert_rdma_wr *wr);
+static void
+isert_unreg_rdma(struct isert_cmd *isert_cmd, struct isert_conn *isert_conn);
+static int
+isert_reg_rdma(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+	       struct isert_rdma_wr *wr);
+static int
+isert_rdma_post_recvl(struct isert_conn *isert_conn);
+static int
+isert_rdma_accept(struct isert_conn *isert_conn);
+struct rdma_cm_id *isert_setup_id(struct isert_np *isert_np);
+
+static void isert_release_work(struct work_struct *work);
 
 static void
 isert_qp_event_callback(struct ib_event *e, void *context)
@@ -80,14 +101,8 @@ isert_conn_setup_qp(struct isert_conn *isert_conn, struct rdma_cm_id *cma_id)
 {
 	struct isert_device *device = isert_conn->conn_device;
 	struct ib_qp_init_attr attr;
-	struct ib_device_attr devattr;
 	int ret, index, min_index = 0;
 
-	memset(&devattr, 0, sizeof(struct ib_device_attr));
-	ret = isert_query_device(cma_id->device, &devattr);
-	if (ret)
-		return ret;
-
 	mutex_lock(&device_list_mutex);
 	for (index = 0; index < device->cqs_used; index++)
 		if (device->cq_active_qps[index] <
@@ -106,9 +121,12 @@ isert_conn_setup_qp(struct isert_conn *isert_conn, struct rdma_cm_id *cma_id)
 	attr.cap.max_recv_wr = ISERT_QP_MAX_RECV_DTOS;
 	/*
 	 * FIXME: Use devattr.max_sge - 2 for max_send_sge as
-	 * work-around for RDMA_READ..
+	 * work-around for RDMA_READs with ConnectX-2.
+	 *
+	 * Also, still make sure to have at least two SGEs for
+	 * outgoing control PDU responses.
 	 */
-	attr.cap.max_send_sge = devattr.max_sge - 2;
+	attr.cap.max_send_sge = max(2, device->dev_attr.max_sge - 2);
 	isert_conn->max_sge = attr.cap.max_send_sge;
 
 	attr.cap.max_recv_sge = 1;
@@ -123,12 +141,18 @@ isert_conn_setup_qp(struct isert_conn *isert_conn, struct rdma_cm_id *cma_id)
 	ret = rdma_create_qp(cma_id, isert_conn->conn_pd, &attr);
 	if (ret) {
 		pr_err("rdma_create_qp failed for cma_id %d\n", ret);
-		return ret;
+		goto err;
 	}
 	isert_conn->conn_qp = cma_id->qp;
 	pr_debug("rdma_create_qp() returned success >>>>>>>>>>>>>>>>>>>>>>>>>.\n");
 
 	return 0;
+err:
+	mutex_lock(&device_list_mutex);
+	device->cq_active_qps[min_index]--;
+	mutex_unlock(&device_list_mutex);
+
+	return ret;
 }
 
 static void
@@ -185,7 +209,7 @@ fail:
 static void
 isert_free_rx_descriptors(struct isert_conn *isert_conn)
 {
-	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct ib_device *ib_dev = isert_conn->conn_device->ib_device;
 	struct iser_rx_desc *rx_desc;
 	int i;
 
@@ -202,7 +226,9 @@ isert_free_rx_descriptors(struct isert_conn *isert_conn)
 	isert_conn->conn_rx_descs = NULL;
 }
 
+static void isert_cq_tx_work(struct work_struct *);
 static void isert_cq_tx_callback(struct ib_cq *, void *);
+static void isert_cq_rx_work(struct work_struct *);
 static void isert_cq_rx_callback(struct ib_cq *, void *);
 
 static int
@@ -210,14 +236,36 @@ isert_create_device_ib_res(struct isert_device *device)
 {
 	struct ib_device *ib_dev = device->ib_device;
 	struct isert_cq_desc *cq_desc;
+	struct ib_device_attr *dev_attr;
 	int ret = 0, i, j;
+	int max_rx_cqe, max_tx_cqe;
+
+	dev_attr = &device->dev_attr;
+	ret = isert_query_device(ib_dev, dev_attr);
+	if (ret)
+		return ret;
+
+	max_rx_cqe = min(ISER_MAX_RX_CQ_LEN, dev_attr->max_cqe);
+	max_tx_cqe = min(ISER_MAX_TX_CQ_LEN, dev_attr->max_cqe);
+
+	/* asign function handlers */
+	if (dev_attr->device_cap_flags & IB_DEVICE_MEM_MGT_EXTENSIONS) {
+		device->use_fastreg = 1;
+		device->reg_rdma_mem = isert_reg_rdma;
+		device->unreg_rdma_mem = isert_unreg_rdma;
+	} else {
+		device->use_fastreg = 0;
+		device->reg_rdma_mem = isert_map_rdma;
+		device->unreg_rdma_mem = isert_unmap_cmd;
+	}
 
 	device->cqs_used = min_t(int, num_online_cpus(),
 				 device->ib_device->num_comp_vectors);
 	device->cqs_used = min(ISERT_MAX_CQ, device->cqs_used);
-	pr_debug("Using %d CQs, device %s supports %d vectors\n",
+	pr_debug("Using %d CQs, device %s supports %d vectors support "
+		 "Fast registration %d\n",
 		 device->cqs_used, device->ib_device->name,
-		 device->ib_device->num_comp_vectors);
+		 device->ib_device->num_comp_vectors, device->use_fastreg);
 	device->cq_desc = kzalloc(sizeof(struct isert_cq_desc) *
 				device->cqs_used, GFP_KERNEL);
 	if (!device->cq_desc) {
@@ -226,47 +274,43 @@ isert_create_device_ib_res(struct isert_device *device)
 	}
 	cq_desc = device->cq_desc;
 
-	device->dev_pd = ib_alloc_pd(ib_dev);
-	if (IS_ERR(device->dev_pd)) {
-		ret = PTR_ERR(device->dev_pd);
-		pr_err("ib_alloc_pd failed for dev_pd: %d\n", ret);
-		goto out_cq_desc;
-	}
-
 	for (i = 0; i < device->cqs_used; i++) {
 		cq_desc[i].device = device;
 		cq_desc[i].cq_index = i;
 
+		INIT_WORK(&cq_desc[i].cq_rx_work, isert_cq_rx_work);
 		device->dev_rx_cq[i] = ib_create_cq(device->ib_device,
 						isert_cq_rx_callback,
 						isert_cq_event_callback,
 						(void *)&cq_desc[i],
-						ISER_MAX_RX_CQ_LEN, i);
-		if (IS_ERR(device->dev_rx_cq[i]))
+						max_rx_cqe, i);
+		if (IS_ERR(device->dev_rx_cq[i])) {
+			ret = PTR_ERR(device->dev_rx_cq[i]);
+			device->dev_rx_cq[i] = NULL;
 			goto out_cq;
+		}
 
+		INIT_WORK(&cq_desc[i].cq_tx_work, isert_cq_tx_work);
 		device->dev_tx_cq[i] = ib_create_cq(device->ib_device,
 						isert_cq_tx_callback,
 						isert_cq_event_callback,
 						(void *)&cq_desc[i],
-						ISER_MAX_TX_CQ_LEN, i);
-		if (IS_ERR(device->dev_tx_cq[i]))
+						max_tx_cqe, i);
+		if (IS_ERR(device->dev_tx_cq[i])) {
+			ret = PTR_ERR(device->dev_tx_cq[i]);
+			device->dev_tx_cq[i] = NULL;
 			goto out_cq;
+		}
 
-		if (ib_req_notify_cq(device->dev_rx_cq[i], IB_CQ_NEXT_COMP))
+		ret = ib_req_notify_cq(device->dev_rx_cq[i], IB_CQ_NEXT_COMP);
+		if (ret)
 			goto out_cq;
 
-		if (ib_req_notify_cq(device->dev_tx_cq[i], IB_CQ_NEXT_COMP))
+		ret = ib_req_notify_cq(device->dev_tx_cq[i], IB_CQ_NEXT_COMP);
+		if (ret)
 			goto out_cq;
 	}
 
-	device->dev_mr = ib_get_dma_mr(device->dev_pd, IB_ACCESS_LOCAL_WRITE);
-	if (IS_ERR(device->dev_mr)) {
-		ret = PTR_ERR(device->dev_mr);
-		pr_err("ib_get_dma_mr failed for dev_mr: %d\n", ret);
-		goto out_cq;
-	}
-
 	return 0;
 
 out_cq:
@@ -282,9 +326,6 @@ out_cq:
 			ib_destroy_cq(device->dev_tx_cq[j]);
 		}
 	}
-	ib_dealloc_pd(device->dev_pd);
-
-out_cq_desc:
 	kfree(device->cq_desc);
 
 	return ret;
@@ -307,8 +348,6 @@ isert_free_device_ib_res(struct isert_device *device)
 		device->dev_tx_cq[i] = NULL;
 	}
 
-	ib_dereg_mr(device->dev_mr);
-	ib_dealloc_pd(device->dev_pd);
 	kfree(device->cq_desc);
 }
 
@@ -363,16 +402,123 @@ isert_device_find_by_ib_dev(struct rdma_cm_id *cma_id)
 	return device;
 }
 
+static void
+isert_conn_free_fastreg_pool(struct isert_conn *isert_conn)
+{
+	struct fast_reg_descriptor *fr_desc, *tmp;
+	int i = 0;
+
+	if (list_empty(&isert_conn->conn_fr_pool))
+		return;
+
+	pr_debug("Freeing conn %p fastreg pool", isert_conn);
+
+	list_for_each_entry_safe(fr_desc, tmp,
+				 &isert_conn->conn_fr_pool, list) {
+		list_del(&fr_desc->list);
+		ib_free_fast_reg_page_list(fr_desc->data_frpl);
+		ib_dereg_mr(fr_desc->data_mr);
+		kfree(fr_desc);
+		++i;
+	}
+
+	if (i < isert_conn->conn_fr_pool_size)
+		pr_warn("Pool still has %d regions registered\n",
+			isert_conn->conn_fr_pool_size - i);
+}
+
+static int
+isert_create_fr_desc(struct ib_device *ib_device, struct ib_pd *pd,
+		     struct fast_reg_descriptor *fr_desc)
+{
+	fr_desc->data_frpl = ib_alloc_fast_reg_page_list(ib_device,
+							 ISCSI_ISER_SG_TABLESIZE);
+	if (IS_ERR(fr_desc->data_frpl)) {
+		pr_err("Failed to allocate data frpl err=%ld\n",
+		       PTR_ERR(fr_desc->data_frpl));
+		return PTR_ERR(fr_desc->data_frpl);
+	}
+
+	fr_desc->data_mr = ib_alloc_fast_reg_mr(pd, ISCSI_ISER_SG_TABLESIZE);
+	if (IS_ERR(fr_desc->data_mr)) {
+		pr_err("Failed to allocate data frmr err=%ld\n",
+		       PTR_ERR(fr_desc->data_mr));
+		ib_free_fast_reg_page_list(fr_desc->data_frpl);
+		return PTR_ERR(fr_desc->data_mr);
+	}
+	pr_debug("Create fr_desc %p page_list %p\n",
+		 fr_desc, fr_desc->data_frpl->page_list);
+
+	fr_desc->valid = true;
+
+	return 0;
+}
+
+static int
+isert_conn_create_fastreg_pool(struct isert_conn *isert_conn)
+{
+	struct fast_reg_descriptor *fr_desc;
+	struct isert_device *device = isert_conn->conn_device;
+	struct se_session *se_sess = isert_conn->conn->sess->se_sess;
+	struct se_node_acl *se_nacl = se_sess->se_node_acl;
+	int i, ret, tag_num;
+	/*
+	 * Setup the number of FRMRs based upon the number of tags
+	 * available to session in iscsi_target_locate_portal().
+	 */
+	tag_num = max_t(u32, ISCSIT_MIN_TAGS, se_nacl->queue_depth);
+	tag_num = (tag_num * 2) + ISCSIT_EXTRA_TAGS;
+
+	isert_conn->conn_fr_pool_size = 0;
+	for (i = 0; i < tag_num; i++) {
+		fr_desc = kzalloc(sizeof(*fr_desc), GFP_KERNEL);
+		if (!fr_desc) {
+			pr_err("Failed to allocate fast_reg descriptor\n");
+			ret = -ENOMEM;
+			goto err;
+		}
+
+		ret = isert_create_fr_desc(device->ib_device,
+					   isert_conn->conn_pd, fr_desc);
+		if (ret) {
+			pr_err("Failed to create fastreg descriptor err=%d\n",
+			       ret);
+			kfree(fr_desc);
+			goto err;
+		}
+
+		list_add_tail(&fr_desc->list, &isert_conn->conn_fr_pool);
+		isert_conn->conn_fr_pool_size++;
+	}
+
+	pr_debug("Creating conn %p fastreg pool size=%d",
+		 isert_conn, isert_conn->conn_fr_pool_size);
+
+	return 0;
+
+err:
+	isert_conn_free_fastreg_pool(isert_conn);
+	return ret;
+}
+
 static int
 isert_connect_request(struct rdma_cm_id *cma_id, struct rdma_cm_event *event)
 {
-	struct iscsi_np *np = cma_id->context;
-	struct isert_np *isert_np = np->np_context;
+	struct isert_np *isert_np = cma_id->context;
+	struct iscsi_np *np = isert_np->np;
 	struct isert_conn *isert_conn;
 	struct isert_device *device;
 	struct ib_device *ib_dev = cma_id->device;
 	int ret = 0;
 
+	spin_lock_bh(&np->np_thread_lock);
+	if (!np->enabled) {
+		spin_unlock_bh(&np->np_thread_lock);
+		pr_debug("iscsi_np is not enabled, reject connect request\n");
+		return rdma_reject(cma_id, NULL, 0);
+	}
+	spin_unlock_bh(&np->np_thread_lock);
+
 	pr_debug("Entering isert_connect_request cma_id: %p, context: %p\n",
 		 cma_id, cma_id->context);
 
@@ -384,13 +530,15 @@ isert_connect_request(struct rdma_cm_id *cma_id, struct rdma_cm_event *event)
 	isert_conn->state = ISER_CONN_INIT;
 	INIT_LIST_HEAD(&isert_conn->conn_accept_node);
 	init_completion(&isert_conn->conn_login_comp);
-	init_waitqueue_head(&isert_conn->conn_wait);
-	init_waitqueue_head(&isert_conn->conn_wait_comp_err);
+	init_completion(&isert_conn->login_req_comp);
+	init_completion(&isert_conn->conn_wait);
+	init_completion(&isert_conn->conn_wait_comp_err);
 	kref_init(&isert_conn->conn_kref);
-	kref_get(&isert_conn->conn_kref);
 	mutex_init(&isert_conn->conn_mutex);
+	spin_lock_init(&isert_conn->conn_lock);
+	INIT_LIST_HEAD(&isert_conn->conn_fr_pool);
+	INIT_WORK(&isert_conn->release_work, isert_release_work);
 
-	cma_id->context = isert_conn;
 	isert_conn->conn_cm_id = cma_id;
 	isert_conn->responder_resources = event->param.conn.responder_resources;
 	isert_conn->initiator_depth = event->param.conn.initiator_depth;
@@ -443,22 +591,48 @@ isert_connect_request(struct rdma_cm_id *cma_id, struct rdma_cm_event *event)
 	}
 
 	isert_conn->conn_device = device;
-	isert_conn->conn_pd = device->dev_pd;
-	isert_conn->conn_mr = device->dev_mr;
+	isert_conn->conn_pd = ib_alloc_pd(isert_conn->conn_device->ib_device);
+	if (IS_ERR(isert_conn->conn_pd)) {
+		ret = PTR_ERR(isert_conn->conn_pd);
+		pr_err("ib_alloc_pd failed for conn %p: ret=%d\n",
+		       isert_conn, ret);
+		goto out_pd;
+	}
+
+	isert_conn->conn_mr = ib_get_dma_mr(isert_conn->conn_pd,
+					   IB_ACCESS_LOCAL_WRITE);
+	if (IS_ERR(isert_conn->conn_mr)) {
+		ret = PTR_ERR(isert_conn->conn_mr);
+		pr_err("ib_get_dma_mr failed for conn %p: ret=%d\n",
+		       isert_conn, ret);
+		goto out_mr;
+	}
 
 	ret = isert_conn_setup_qp(isert_conn, cma_id);
 	if (ret)
 		goto out_conn_dev;
 
+	ret = isert_rdma_post_recvl(isert_conn);
+	if (ret)
+		goto out_conn_dev;
+
+	ret = isert_rdma_accept(isert_conn);
+	if (ret)
+		goto out_conn_dev;
+
 	mutex_lock(&isert_np->np_accept_mutex);
-	list_add_tail(&isert_np->np_accept_list, &isert_conn->conn_accept_node);
+	list_add_tail(&isert_conn->conn_accept_node, &isert_np->np_accept_list);
 	mutex_unlock(&isert_np->np_accept_mutex);
 
-	pr_debug("isert_connect_request() waking up np_accept_wq: %p\n", np);
-	wake_up(&isert_np->np_accept_wq);
+	pr_debug("isert_connect_request() up np_sem np: %p\n", np);
+	up(&isert_np->np_sem);
 	return 0;
 
 out_conn_dev:
+	ib_dereg_mr(isert_conn->conn_mr);
+out_mr:
+	ib_dealloc_pd(isert_conn->conn_pd);
+out_pd:
 	isert_device_try_release(device);
 out_rsp_dma_map:
 	ib_dma_unmap_single(ib_dev, isert_conn->login_rsp_dma,
@@ -470,29 +644,39 @@ out_login_buf:
 	kfree(isert_conn->login_buf);
 out:
 	kfree(isert_conn);
+	rdma_reject(cma_id, NULL, 0);
 	return ret;
 }
 
 static void
 isert_connect_release(struct isert_conn *isert_conn)
 {
-	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
 	struct isert_device *device = isert_conn->conn_device;
 	int cq_index;
+	struct ib_device *ib_dev = device->ib_device;
 
 	pr_debug("Entering isert_connect_release(): >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
 
+	if (device && device->use_fastreg)
+		isert_conn_free_fastreg_pool(isert_conn);
+
+	isert_free_rx_descriptors(isert_conn);
+	if (isert_conn->conn_cm_id)
+		rdma_destroy_id(isert_conn->conn_cm_id);
+
 	if (isert_conn->conn_qp) {
 		cq_index = ((struct isert_cq_desc *)
 			isert_conn->conn_qp->recv_cq->cq_context)->cq_index;
 		pr_debug("isert_connect_release: cq_index: %d\n", cq_index);
+		mutex_lock(&device_list_mutex);
 		isert_conn->conn_device->cq_active_qps[cq_index]--;
+		mutex_unlock(&device_list_mutex);
 
-		rdma_destroy_qp(isert_conn->conn_cm_id);
+		ib_destroy_qp(isert_conn->conn_qp);
 	}
 
-	isert_free_rx_descriptors(isert_conn);
-	rdma_destroy_id(isert_conn->conn_cm_id);
+	ib_dereg_mr(isert_conn->conn_mr);
+	ib_dealloc_pd(isert_conn->conn_pd);
 
 	if (isert_conn->login_buf) {
 		ib_dma_unmap_single(ib_dev, isert_conn->login_rsp_dma,
@@ -513,7 +697,19 @@ isert_connect_release(struct isert_conn *isert_conn)
 static void
 isert_connected_handler(struct rdma_cm_id *cma_id)
 {
-	return;
+	struct isert_conn *isert_conn = cma_id->qp->qp_context;
+
+	pr_info("conn %p\n", isert_conn);
+
+	if (!kref_get_unless_zero(&isert_conn->conn_kref)) {
+		pr_warn("conn %p connect_release is running\n", isert_conn);
+		return;
+	}
+
+	mutex_lock(&isert_conn->conn_mutex);
+	if (isert_conn->state != ISER_CONN_FULL_FEATURE)
+		isert_conn->state = ISER_CONN_UP;
+	mutex_unlock(&isert_conn->conn_mutex);
 }
 
 static void
@@ -534,49 +730,119 @@ isert_put_conn(struct isert_conn *isert_conn)
 	kref_put(&isert_conn->conn_kref, isert_release_conn_kref);
 }
 
+/**
+ * isert_conn_terminate() - Initiate connection termination
+ * @isert_conn: isert connection struct
+ *
+ * Notes:
+ * In case the connection state is FULL_FEATURE, move state
+ * to TEMINATING and start teardown sequence (rdma_disconnect).
+ * In case the connection state is UP, complete flush as well.
+ *
+ * This routine must be called with conn_mutex held. Thus it is
+ * safe to call multiple times.
+ */
 static void
-isert_disconnect_work(struct work_struct *work)
+isert_conn_terminate(struct isert_conn *isert_conn)
 {
-	struct isert_conn *isert_conn = container_of(work,
-				struct isert_conn, conn_logout_work);
+	int err;
 
-	pr_debug("isert_disconnect_work(): >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
-	mutex_lock(&isert_conn->conn_mutex);
-	isert_conn->state = ISER_CONN_DOWN;
+	switch (isert_conn->state) {
+	case ISER_CONN_TERMINATING:
+		break;
+	case ISER_CONN_UP:
+		/*
+		 * No flush completions will occur as we didn't
+		 * get to ISER_CONN_FULL_FEATURE yet, complete
+		 * to allow teardown progress.
+		 */
+		complete(&isert_conn->conn_wait_comp_err);
+	case ISER_CONN_FULL_FEATURE: /* FALLTHRU */
+		pr_info("Terminating conn %p state %d\n",
+			   isert_conn, isert_conn->state);
+		isert_conn->state = ISER_CONN_TERMINATING;
+		err = rdma_disconnect(isert_conn->conn_cm_id);
+		if (err)
+			pr_warn("Failed rdma_disconnect isert_conn %p\n",
+				   isert_conn);
+		break;
+	default:
+		pr_warn("conn %p teminating in state %d\n",
+			   isert_conn, isert_conn->state);
+	}
+}
 
-	if (isert_conn->post_recv_buf_count == 0 &&
-	    atomic_read(&isert_conn->post_send_buf_count) == 0) {
-		pr_debug("Calling wake_up(&isert_conn->conn_wait);\n");
-		mutex_unlock(&isert_conn->conn_mutex);
-		goto wake_up;
+static int
+isert_np_cma_handler(struct isert_np *isert_np,
+		     enum rdma_cm_event_type event)
+{
+	pr_debug("isert np %p, handling event %d\n", isert_np, event);
+
+	switch (event) {
+	case RDMA_CM_EVENT_DEVICE_REMOVAL:
+		isert_np->np_cm_id = NULL;
+		break;
+	case RDMA_CM_EVENT_ADDR_CHANGE:
+		isert_np->np_cm_id = isert_setup_id(isert_np);
+		if (IS_ERR(isert_np->np_cm_id)) {
+			pr_err("isert np %p setup id failed: %ld\n",
+				 isert_np, PTR_ERR(isert_np->np_cm_id));
+			isert_np->np_cm_id = NULL;
+		}
+		break;
+	default:
+		pr_err("isert np %p Unexpected event %d\n",
+			  isert_np, event);
 	}
-	if (!isert_conn->conn_cm_id) {
-		mutex_unlock(&isert_conn->conn_mutex);
+
+	return -1;
+}
+
+static int
+isert_disconnected_handler(struct rdma_cm_id *cma_id,
+			   enum rdma_cm_event_type event)
+{
+	struct isert_np *isert_np = cma_id->context;
+	struct isert_conn *isert_conn;
+	bool terminating = false;
+
+	if (isert_np->np_cm_id == cma_id)
+		return isert_np_cma_handler(cma_id->context, event);
+
+	isert_conn = cma_id->qp->qp_context;
+
+	mutex_lock(&isert_conn->conn_mutex);
+	terminating = (isert_conn->state == ISER_CONN_TERMINATING);
+	isert_conn_terminate(isert_conn);
+	mutex_unlock(&isert_conn->conn_mutex);
+
+	pr_info("conn %p completing conn_wait\n", isert_conn);
+	complete(&isert_conn->conn_wait);
+
+	if (terminating)
+		goto out;
+
+	mutex_lock(&isert_np->np_accept_mutex);
+	if (!list_empty(&isert_conn->conn_accept_node)) {
+		list_del_init(&isert_conn->conn_accept_node);
 		isert_put_conn(isert_conn);
-		return;
-	}
-	if (!isert_conn->logout_posted) {
-		pr_debug("Calling rdma_disconnect for !logout_posted from"
-			 " isert_disconnect_work\n");
-		rdma_disconnect(isert_conn->conn_cm_id);
-		mutex_unlock(&isert_conn->conn_mutex);
-		iscsit_cause_connection_reinstatement(isert_conn->conn, 0);
-		goto wake_up;
+		queue_work(isert_release_wq, &isert_conn->release_work);
 	}
-	mutex_unlock(&isert_conn->conn_mutex);
+	mutex_unlock(&isert_np->np_accept_mutex);
 
-wake_up:
-	wake_up(&isert_conn->conn_wait);
-	isert_put_conn(isert_conn);
+out:
+	return 0;
 }
 
-static void
-isert_disconnected_handler(struct rdma_cm_id *cma_id)
+static int
+isert_connect_error(struct rdma_cm_id *cma_id)
 {
-	struct isert_conn *isert_conn = (struct isert_conn *)cma_id->context;
+	struct isert_conn *isert_conn = cma_id->qp->qp_context;
+
+	isert_conn->conn_cm_id = NULL;
+	isert_put_conn(isert_conn);
 
-	INIT_WORK(&isert_conn->conn_logout_work, isert_disconnect_work);
-	schedule_work(&isert_conn->conn_logout_work);
+	return -1;
 }
 
 static int
@@ -589,32 +855,30 @@ isert_cma_handler(struct rdma_cm_id *cma_id, struct rdma_cm_event *event)
 
 	switch (event->event) {
 	case RDMA_CM_EVENT_CONNECT_REQUEST:
-		pr_debug("RDMA_CM_EVENT_CONNECT_REQUEST: >>>>>>>>>>>>>>>\n");
 		ret = isert_connect_request(cma_id, event);
+		if (ret)
+			pr_err("isert_cma_handler failed RDMA_CM_EVENT: 0x%08x %d\n",
+				event->event, ret);
 		break;
 	case RDMA_CM_EVENT_ESTABLISHED:
-		pr_debug("RDMA_CM_EVENT_ESTABLISHED >>>>>>>>>>>>>>\n");
 		isert_connected_handler(cma_id);
 		break;
-	case RDMA_CM_EVENT_DISCONNECTED:
-		pr_debug("RDMA_CM_EVENT_DISCONNECTED: >>>>>>>>>>>>>>\n");
-		isert_disconnected_handler(cma_id);
-		break;
-	case RDMA_CM_EVENT_DEVICE_REMOVAL:
-	case RDMA_CM_EVENT_ADDR_CHANGE:
+	case RDMA_CM_EVENT_ADDR_CHANGE:    /* FALLTHRU */
+	case RDMA_CM_EVENT_DISCONNECTED:   /* FALLTHRU */
+	case RDMA_CM_EVENT_DEVICE_REMOVAL: /* FALLTHRU */
+	case RDMA_CM_EVENT_TIMEWAIT_EXIT:  /* FALLTHRU */
+		ret = isert_disconnected_handler(cma_id, event->event);
 		break;
+	case RDMA_CM_EVENT_REJECTED:       /* FALLTHRU */
+	case RDMA_CM_EVENT_UNREACHABLE:    /* FALLTHRU */
 	case RDMA_CM_EVENT_CONNECT_ERROR:
+		ret = isert_connect_error(cma_id);
+		break;
 	default:
-		pr_err("Unknown RDMA CMA event: %d\n", event->event);
+		pr_err("Unhandled RDMA CMA event: %d\n", event->event);
 		break;
 	}
 
-	if (ret != 0) {
-		pr_err("isert_cma_handler failed RDMA_CM_EVENT: 0x%08x %d\n",
-		       event->event, ret);
-		dump_stack();
-	}
-
 	return ret;
 }
 
@@ -728,14 +992,33 @@ isert_init_tx_hdrs(struct isert_conn *isert_conn,
 }
 
 static void
-isert_init_send_wr(struct isert_cmd *isert_cmd, struct ib_send_wr *send_wr)
+isert_init_send_wr(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
+		   struct ib_send_wr *send_wr, bool coalesce)
 {
+	struct iser_tx_desc *tx_desc = &isert_cmd->tx_desc;
+
 	isert_cmd->rdma_wr.iser_ib_op = ISER_IB_SEND;
 	send_wr->wr_id = (unsigned long)&isert_cmd->tx_desc;
 	send_wr->opcode = IB_WR_SEND;
-	send_wr->send_flags = IB_SEND_SIGNALED;
-	send_wr->sg_list = &isert_cmd->tx_desc.tx_sg[0];
+	send_wr->sg_list = &tx_desc->tx_sg[0];
 	send_wr->num_sge = isert_cmd->tx_desc.num_sge;
+	/*
+	 * Coalesce send completion interrupts by only setting IB_SEND_SIGNALED
+	 * bit for every ISERT_COMP_BATCH_COUNT number of ib_post_send() calls.
+	 */
+	mutex_lock(&isert_conn->conn_mutex);
+	if (coalesce && isert_conn->state == ISER_CONN_FULL_FEATURE &&
+	    ++isert_conn->conn_comp_batch < ISERT_COMP_BATCH_COUNT) {
+		tx_desc->llnode_active = true;
+		llist_add(&tx_desc->comp_llnode, &isert_conn->conn_comp_llist);
+		mutex_unlock(&isert_conn->conn_mutex);
+		return;
+	}
+	isert_conn->conn_comp_batch = 0;
+	tx_desc->comp_llnode_batch = llist_del_all(&isert_conn->conn_comp_llist);
+	mutex_unlock(&isert_conn->conn_mutex);
+
+	send_wr->send_flags = IB_SEND_SIGNALED;
 }
 
 static int
@@ -803,6 +1086,16 @@ isert_put_login_tx(struct iscsi_conn *conn, struct iscsi_login *login,
 	}
 	if (!login->login_failed) {
 		if (login->login_complete) {
+			if (!conn->sess->sess_ops->SessionType &&
+			    isert_conn->conn_device->use_fastreg) {
+				ret = isert_conn_create_fastreg_pool(isert_conn);
+				if (ret) {
+					pr_err("Conn: %p failed to create"
+					       " fastreg pool\n", isert_conn);
+					return ret;
+				}
+			}
+
 			ret = isert_alloc_rx_descriptors(isert_conn);
 			if (ret)
 				return ret;
@@ -811,7 +1104,10 @@ isert_put_login_tx(struct iscsi_conn *conn, struct iscsi_login *login,
 			if (ret)
 				return ret;
 
-			isert_conn->state = ISER_CONN_UP;
+			/* Now we are in FULL_FEATURE phase */
+			mutex_lock(&isert_conn->conn_mutex);
+			isert_conn->state = ISER_CONN_FULL_FEATURE;
+			mutex_unlock(&isert_conn->conn_mutex);
 			goto post_send;
 		}
 
@@ -828,18 +1124,17 @@ post_send:
 }
 
 static void
-isert_rx_login_req(struct iser_rx_desc *rx_desc, int rx_buflen,
-		   struct isert_conn *isert_conn)
+isert_rx_login_req(struct isert_conn *isert_conn)
 {
+	struct iser_rx_desc *rx_desc = (void *)isert_conn->login_req_buf;
+	int rx_buflen = isert_conn->login_req_len;
 	struct iscsi_conn *conn = isert_conn->conn;
 	struct iscsi_login *login = conn->conn_login;
 	int size;
 
-	if (!login) {
-		pr_err("conn->conn_login is NULL\n");
-		dump_stack();
-		return;
-	}
+	pr_info("conn %p\n", isert_conn);
+
+	WARN_ON_ONCE(!login);
 
 	if (login->first_request) {
 		struct iscsi_login_req *login_req =
@@ -869,46 +1164,37 @@ isert_rx_login_req(struct iser_rx_desc *rx_desc, int rx_buflen,
 		 size, rx_buflen, MAX_KEY_VALUE_PAIRS);
 	memcpy(login->req_buf, &rx_desc->data[0], size);
 
-	complete(&isert_conn->conn_login_comp);
-}
-
-static void
-isert_release_cmd(struct iscsi_cmd *cmd)
-{
-	struct isert_cmd *isert_cmd = container_of(cmd, struct isert_cmd,
-						   iscsi_cmd);
-
-	pr_debug("Entering isert_release_cmd %p >>>>>>>>>>>>>>>.\n", isert_cmd);
-
-	kfree(cmd->buf_ptr);
-	kfree(cmd->tmr_req);
-
-	kmem_cache_free(isert_cmd_cache, isert_cmd);
+	if (login->first_request) {
+		complete(&isert_conn->conn_login_comp);
+		return;
+	}
+	schedule_delayed_work(&conn->login_work, 0);
 }
 
 static struct iscsi_cmd
-*isert_alloc_cmd(struct iscsi_conn *conn, gfp_t gfp)
+*isert_allocate_cmd(struct iscsi_conn *conn)
 {
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct isert_cmd *isert_cmd;
+	struct iscsi_cmd *cmd;
 
-	isert_cmd = kmem_cache_zalloc(isert_cmd_cache, gfp);
-	if (!isert_cmd) {
-		pr_err("Unable to allocate isert_cmd\n");
+	cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
+	if (!cmd) {
+		pr_err("Unable to allocate iscsi_cmd + isert_cmd\n");
 		return NULL;
 	}
+	isert_cmd = iscsit_priv_cmd(cmd);
 	isert_cmd->conn = isert_conn;
-	isert_cmd->iscsi_cmd.release_cmd = &isert_release_cmd;
+	isert_cmd->iscsi_cmd = cmd;
 
-	return &isert_cmd->iscsi_cmd;
+	return cmd;
 }
 
 static int
 isert_handle_scsi_cmd(struct isert_conn *isert_conn,
-		      struct isert_cmd *isert_cmd, struct iser_rx_desc *rx_desc,
-		      unsigned char *buf)
+		      struct isert_cmd *isert_cmd, struct iscsi_cmd *cmd,
+		      struct iser_rx_desc *rx_desc, unsigned char *buf)
 {
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
 	struct iscsi_conn *conn = isert_conn->conn;
 	struct iscsi_scsi_req *hdr = (struct iscsi_scsi_req *)buf;
 	struct scatterlist *sg;
@@ -956,6 +1242,8 @@ sequence_cmd:
 
 	if (!rc && dump_payload == false && unsol_data)
 		iscsit_set_unsoliticed_dataout(cmd);
+	else if (dump_payload && imm_data)
+		target_put_sess_cmd(conn->sess->se_sess, &cmd->se_cmd);
 
 	return 0;
 }
@@ -1014,45 +1302,101 @@ isert_handle_iscsi_dataout(struct isert_conn *isert_conn,
 }
 
 static int
+isert_handle_nop_out(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
+		     struct iscsi_cmd *cmd, struct iser_rx_desc *rx_desc,
+		     unsigned char *buf)
+{
+	struct iscsi_conn *conn = isert_conn->conn;
+	struct iscsi_nopout *hdr = (struct iscsi_nopout *)buf;
+	int rc;
+
+	rc = iscsit_setup_nop_out(conn, cmd, hdr);
+	if (rc < 0)
+		return rc;
+	/*
+	 * FIXME: Add support for NOPOUT payload using unsolicited RDMA payload
+	 */
+
+	return iscsit_process_nop_out(conn, cmd, hdr);
+}
+
+static int
+isert_handle_text_cmd(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
+		      struct iscsi_cmd *cmd, struct iser_rx_desc *rx_desc,
+		      struct iscsi_text *hdr)
+{
+	struct iscsi_conn *conn = isert_conn->conn;
+	u32 payload_length = ntoh24(hdr->dlength);
+	int rc;
+	unsigned char *text_in;
+
+	rc = iscsit_setup_text_cmd(conn, cmd, hdr);
+	if (rc < 0)
+		return rc;
+
+	text_in = kzalloc(payload_length, GFP_KERNEL);
+	if (!text_in) {
+		pr_err("Unable to allocate text_in of payload_length: %u\n",
+		       payload_length);
+		return -ENOMEM;
+	}
+	cmd->text_in_ptr = text_in;
+
+	memcpy(cmd->text_in_ptr, &rx_desc->data[0], payload_length);
+
+	return iscsit_process_text_cmd(conn, cmd, hdr);
+}
+
+static int
 isert_rx_opcode(struct isert_conn *isert_conn, struct iser_rx_desc *rx_desc,
 		uint32_t read_stag, uint64_t read_va,
 		uint32_t write_stag, uint64_t write_va)
 {
 	struct iscsi_hdr *hdr = &rx_desc->iscsi_header;
 	struct iscsi_conn *conn = isert_conn->conn;
+	struct iscsi_session *sess = conn->sess;
 	struct iscsi_cmd *cmd;
 	struct isert_cmd *isert_cmd;
 	int ret = -EINVAL;
 	u8 opcode = (hdr->opcode & ISCSI_OPCODE_MASK);
 
+	if (sess->sess_ops->SessionType &&
+	   (!(opcode & ISCSI_OP_TEXT) || !(opcode & ISCSI_OP_LOGOUT))) {
+		pr_err("Got illegal opcode: 0x%02x in SessionType=Discovery,"
+		       " ignoring\n", opcode);
+		return 0;
+	}
+
 	switch (opcode) {
 	case ISCSI_OP_SCSI_CMD:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = isert_allocate_cmd(conn);
 		if (!cmd)
 			break;
 
-		isert_cmd = container_of(cmd, struct isert_cmd, iscsi_cmd);
+		isert_cmd = iscsit_priv_cmd(cmd);
 		isert_cmd->read_stag = read_stag;
 		isert_cmd->read_va = read_va;
 		isert_cmd->write_stag = write_stag;
 		isert_cmd->write_va = write_va;
 
-		ret = isert_handle_scsi_cmd(isert_conn, isert_cmd,
+		ret = isert_handle_scsi_cmd(isert_conn, isert_cmd, cmd,
 					rx_desc, (unsigned char *)hdr);
 		break;
 	case ISCSI_OP_NOOP_OUT:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = isert_allocate_cmd(conn);
 		if (!cmd)
 			break;
 
-		ret = iscsit_handle_nop_out(conn, cmd, (unsigned char *)hdr);
+		isert_cmd = iscsit_priv_cmd(cmd);
+		ret = isert_handle_nop_out(isert_conn, isert_cmd, cmd,
+					   rx_desc, (unsigned char *)hdr);
 		break;
 	case ISCSI_OP_SCSI_DATA_OUT:
 		ret = isert_handle_iscsi_dataout(isert_conn, rx_desc,
 						(unsigned char *)hdr);
 		break;
 	case ISCSI_OP_SCSI_TMFUNC:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = isert_allocate_cmd(conn);
 		if (!cmd)
 			break;
 
@@ -1060,7 +1404,7 @@ isert_rx_opcode(struct isert_conn *isert_conn, struct iser_rx_desc *rx_desc,
 						(unsigned char *)hdr);
 		break;
 	case ISCSI_OP_LOGOUT:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = isert_allocate_cmd(conn);
 		if (!cmd)
 			break;
 
@@ -1070,6 +1414,15 @@ isert_rx_opcode(struct isert_conn *isert_conn, struct iser_rx_desc *rx_desc,
 						    SECONDS_FOR_LOGOUT_COMP *
 						    HZ);
 		break;
+	case ISCSI_OP_TEXT:
+		cmd = isert_allocate_cmd(conn);
+		if (!cmd)
+			break;
+
+		isert_cmd = iscsit_priv_cmd(cmd);
+		ret = isert_handle_text_cmd(isert_conn, isert_cmd, cmd,
+					    rx_desc, (struct iscsi_text *)hdr);
+		break;
 	default:
 		pr_err("Got unknown iSCSI OpCode: 0x%02x\n", opcode);
 		dump_stack();
@@ -1144,11 +1497,20 @@ isert_rx_completion(struct iser_rx_desc *desc, struct isert_conn *isert_conn,
 		 hdr->opcode, hdr->itt, hdr->flags,
 		 (int)(xfer_len - ISER_HEADERS_LEN));
 
-	if ((char *)desc == isert_conn->login_req_buf)
-		isert_rx_login_req(desc, xfer_len - ISER_HEADERS_LEN,
-				   isert_conn);
-	else
+	if ((char *)desc == isert_conn->login_req_buf) {
+		isert_conn->login_req_len = xfer_len - ISER_HEADERS_LEN;
+		if (isert_conn->conn) {
+			struct iscsi_login *login = isert_conn->conn->conn_login;
+
+			if (login && !login->first_request)
+				isert_rx_login_req(isert_conn);
+		}
+		mutex_lock(&isert_conn->conn_mutex);
+		complete(&isert_conn->login_req_comp);
+		mutex_unlock(&isert_conn->conn_mutex);
+	} else {
 		isert_rx_do_work(desc, isert_conn);
+	}
 
 	ib_dma_sync_single_for_device(ib_dev, rx_dma, rx_buflen,
 				      DMA_FROM_DEVICE);
@@ -1178,26 +1540,65 @@ isert_unmap_cmd(struct isert_cmd *isert_cmd, struct isert_conn *isert_conn)
 	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
 
-	pr_debug("isert_unmap_cmd >>>>>>>>>>>>>>>>>>>>>>>\n");
+	pr_debug("isert_unmap_cmd: %p\n", isert_cmd);
+	if (wr->sge) {
+		pr_debug("isert_unmap_cmd: %p unmap_sg op\n", isert_cmd);
+		ib_dma_unmap_sg(ib_dev, wr->sge, wr->num_sge,
+				(wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+				DMA_TO_DEVICE : DMA_FROM_DEVICE);
+		wr->sge = NULL;
+	}
+
+	if (wr->send_wr) {
+		pr_debug("isert_unmap_cmd: %p free send_wr\n", isert_cmd);
+		kfree(wr->send_wr);
+		wr->send_wr = NULL;
+	}
+
+	if (wr->ib_sge) {
+		pr_debug("isert_unmap_cmd: %p free ib_sge\n", isert_cmd);
+		kfree(wr->ib_sge);
+		wr->ib_sge = NULL;
+	}
+}
+
+static void
+isert_unreg_rdma(struct isert_cmd *isert_cmd, struct isert_conn *isert_conn)
+{
+	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
+	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	LIST_HEAD(unmap_list);
+
+	pr_debug("unreg_fastreg_cmd: %p\n", isert_cmd);
+
+	if (wr->fr_desc) {
+		pr_debug("unreg_fastreg_cmd: %p free fr_desc %p\n",
+			 isert_cmd, wr->fr_desc);
+		spin_lock_bh(&isert_conn->conn_lock);
+		list_add_tail(&wr->fr_desc->list, &isert_conn->conn_fr_pool);
+		spin_unlock_bh(&isert_conn->conn_lock);
+		wr->fr_desc = NULL;
+	}
 
 	if (wr->sge) {
-		ib_dma_unmap_sg(ib_dev, wr->sge, wr->num_sge, DMA_TO_DEVICE);
+		pr_debug("unreg_fastreg_cmd: %p unmap_sg op\n", isert_cmd);
+		ib_dma_unmap_sg(ib_dev, wr->sge, wr->num_sge,
+				(wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+				DMA_TO_DEVICE : DMA_FROM_DEVICE);
 		wr->sge = NULL;
 	}
 
-	kfree(wr->send_wr);
+	wr->ib_sge = NULL;
 	wr->send_wr = NULL;
-
-	kfree(isert_cmd->ib_sge);
-	isert_cmd->ib_sge = NULL;
 }
 
 static void
-isert_put_cmd(struct isert_cmd *isert_cmd)
+isert_put_cmd(struct isert_cmd *isert_cmd, bool comp_err)
 {
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
+	struct iscsi_cmd *cmd = isert_cmd->iscsi_cmd;
 	struct isert_conn *isert_conn = isert_cmd->conn;
 	struct iscsi_conn *conn = isert_conn->conn;
+	struct isert_device *device = isert_conn->conn_device;
 
 	pr_debug("Entering isert_put_cmd: %p\n", isert_cmd);
 
@@ -1205,28 +1606,42 @@ isert_put_cmd(struct isert_cmd *isert_cmd)
 	case ISCSI_OP_SCSI_CMD:
 		spin_lock_bh(&conn->cmd_lock);
 		if (!list_empty(&cmd->i_conn_node))
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 		spin_unlock_bh(&conn->cmd_lock);
 
-		if (cmd->data_direction == DMA_TO_DEVICE)
+		if (cmd->data_direction == DMA_TO_DEVICE) {
 			iscsit_stop_dataout_timer(cmd);
+			/*
+			 * Check for special case during comp_err where
+			 * WRITE_PENDING has been handed off from core,
+			 * but requires an extra target_put_sess_cmd()
+			 * before transport_generic_free_cmd() below.
+			 */
+			if (comp_err &&
+			    cmd->se_cmd.t_state == TRANSPORT_WRITE_PENDING) {
+				struct se_cmd *se_cmd = &cmd->se_cmd;
+
+				target_put_sess_cmd(se_cmd->se_sess, se_cmd);
+			}
+		}
 
-		isert_unmap_cmd(isert_cmd, isert_conn);
+		device->unreg_rdma_mem(isert_cmd, isert_conn);
 		transport_generic_free_cmd(&cmd->se_cmd, 0);
 		break;
 	case ISCSI_OP_SCSI_TMFUNC:
 		spin_lock_bh(&conn->cmd_lock);
 		if (!list_empty(&cmd->i_conn_node))
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 		spin_unlock_bh(&conn->cmd_lock);
 
 		transport_generic_free_cmd(&cmd->se_cmd, 0);
 		break;
 	case ISCSI_OP_REJECT:
 	case ISCSI_OP_NOOP_OUT:
+	case ISCSI_OP_TEXT:
 		spin_lock_bh(&conn->cmd_lock);
 		if (!list_empty(&cmd->i_conn_node))
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 		spin_unlock_bh(&conn->cmd_lock);
 
 		/*
@@ -1245,7 +1660,7 @@ isert_put_cmd(struct isert_cmd *isert_cmd)
 		 * Fall-through
 		 */
 	default:
-		isert_release_cmd(cmd);
+		iscsit_release_cmd(cmd);
 		break;
 	}
 }
@@ -1263,17 +1678,17 @@ isert_unmap_tx_desc(struct iser_tx_desc *tx_desc, struct ib_device *ib_dev)
 
 static void
 isert_completion_put(struct iser_tx_desc *tx_desc, struct isert_cmd *isert_cmd,
-		     struct ib_device *ib_dev)
+		     struct ib_device *ib_dev, bool comp_err)
 {
-	if (isert_cmd->sense_buf_dma != 0) {
-		pr_debug("Calling ib_dma_unmap_single for isert_cmd->sense_buf_dma\n");
-		ib_dma_unmap_single(ib_dev, isert_cmd->sense_buf_dma,
-				    isert_cmd->sense_buf_len, DMA_TO_DEVICE);
-		isert_cmd->sense_buf_dma = 0;
+	if (isert_cmd->pdu_buf_dma != 0) {
+		pr_debug("Calling ib_dma_unmap_single for isert_cmd->pdu_buf_dma\n");
+		ib_dma_unmap_single(ib_dev, isert_cmd->pdu_buf_dma,
+				    isert_cmd->pdu_buf_len, DMA_TO_DEVICE);
+		isert_cmd->pdu_buf_dma = 0;
 	}
 
 	isert_unmap_tx_desc(tx_desc, ib_dev);
-	isert_put_cmd(isert_cmd);
+	isert_put_cmd(isert_cmd, comp_err);
 }
 
 static void
@@ -1281,27 +1696,17 @@ isert_completion_rdma_read(struct iser_tx_desc *tx_desc,
 			   struct isert_cmd *isert_cmd)
 {
 	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
+	struct iscsi_cmd *cmd = isert_cmd->iscsi_cmd;
 	struct se_cmd *se_cmd = &cmd->se_cmd;
-	struct ib_device *ib_dev = isert_cmd->conn->conn_cm_id->device;
+	struct isert_conn *isert_conn = isert_cmd->conn;
+	struct isert_device *device = isert_conn->conn_device;
 
 	iscsit_stop_dataout_timer(cmd);
+	device->unreg_rdma_mem(isert_cmd, isert_conn);
+	cmd->write_data_done = wr->cur_rdma_length;
+	wr->send_wr_num = 0;
 
-	if (wr->sge) {
-		pr_debug("isert_do_rdma_read_comp: Unmapping wr->sge from t_data_sg\n");
-		ib_dma_unmap_sg(ib_dev, wr->sge, wr->num_sge, DMA_TO_DEVICE);
-		wr->sge = NULL;
-	}
-
-	if (isert_cmd->ib_sge) {
-		pr_debug("isert_do_rdma_read_comp: Freeing isert_cmd->ib_sge\n");
-		kfree(isert_cmd->ib_sge);
-		isert_cmd->ib_sge = NULL;
-	}
-
-	cmd->write_data_done = se_cmd->data_length;
-
-	pr_debug("isert_do_rdma_read_comp, calling target_execute_cmd\n");
+	pr_debug("Cmd: %p RDMA_READ comp calling execute_cmd\n", isert_cmd);
 	spin_lock_bh(&cmd->istate_lock);
 	cmd->cmd_flags |= ICF_GOT_LAST_DATAOUT;
 	cmd->i_state = ISTATE_RECEIVED_LAST_DATAOUT;
@@ -1317,7 +1722,7 @@ isert_do_control_comp(struct work_struct *work)
 			struct isert_cmd, comp_work);
 	struct isert_conn *isert_conn = isert_cmd->conn;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
+	struct iscsi_cmd *cmd = isert_cmd->iscsi_cmd;
 
 	switch (cmd->i_state) {
 	case ISTATE_SEND_TASKMGTRSP:
@@ -1327,24 +1732,26 @@ isert_do_control_comp(struct work_struct *work)
 		iscsit_tmr_post_handler(cmd, cmd->conn);
 
 		cmd->i_state = ISTATE_SENT_STATUS;
-		isert_completion_put(&isert_cmd->tx_desc, isert_cmd, ib_dev);
+		isert_completion_put(&isert_cmd->tx_desc, isert_cmd, ib_dev, false);
 		break;
 	case ISTATE_SEND_REJECT:
 		pr_debug("Got isert_do_control_comp ISTATE_SEND_REJECT: >>>\n");
 		atomic_dec(&isert_conn->post_send_buf_count);
 
 		cmd->i_state = ISTATE_SENT_STATUS;
-		isert_completion_put(&isert_cmd->tx_desc, isert_cmd, ib_dev);
+		isert_completion_put(&isert_cmd->tx_desc, isert_cmd, ib_dev, false);
 		break;
 	case ISTATE_SEND_LOGOUTRSP:
 		pr_debug("Calling iscsit_logout_post_handler >>>>>>>>>>>>>>\n");
-		/*
-		 * Call atomic_dec(&isert_conn->post_send_buf_count)
-		 * from isert_free_conn()
-		 */
-		isert_conn->logout_posted = true;
+
+		atomic_dec(&isert_conn->post_send_buf_count);
 		iscsit_logout_post_handler(cmd, cmd->conn);
 		break;
+	case ISTATE_SEND_TEXTRSP:
+		atomic_dec(&isert_conn->post_send_buf_count);
+		cmd->i_state = ISTATE_SENT_STATUS;
+		isert_completion_put(&isert_cmd->tx_desc, isert_cmd, ib_dev, false);
+		break;
 	default:
 		pr_err("Unknown do_control_comp i_state %d\n", cmd->i_state);
 		dump_stack();
@@ -1358,26 +1765,28 @@ isert_response_completion(struct iser_tx_desc *tx_desc,
 			  struct isert_conn *isert_conn,
 			  struct ib_device *ib_dev)
 {
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
+	struct iscsi_cmd *cmd = isert_cmd->iscsi_cmd;
+	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
 
 	if (cmd->i_state == ISTATE_SEND_TASKMGTRSP ||
 	    cmd->i_state == ISTATE_SEND_LOGOUTRSP ||
-	    cmd->i_state == ISTATE_SEND_REJECT) {
+	    cmd->i_state == ISTATE_SEND_REJECT ||
+	    cmd->i_state == ISTATE_SEND_TEXTRSP) {
 		isert_unmap_tx_desc(tx_desc, ib_dev);
 
 		INIT_WORK(&isert_cmd->comp_work, isert_do_control_comp);
 		queue_work(isert_comp_wq, &isert_cmd->comp_work);
 		return;
 	}
-	atomic_dec(&isert_conn->post_send_buf_count);
+	atomic_sub(wr->send_wr_num + 1, &isert_conn->post_send_buf_count);
 
 	cmd->i_state = ISTATE_SENT_STATUS;
-	isert_completion_put(tx_desc, isert_cmd, ib_dev);
+	isert_completion_put(tx_desc, isert_cmd, ib_dev, false);
 }
 
 static void
-isert_send_completion(struct iser_tx_desc *tx_desc,
-		      struct isert_conn *isert_conn)
+__isert_send_completion(struct iser_tx_desc *tx_desc,
+		        struct isert_conn *isert_conn)
 {
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
 	struct isert_cmd *isert_cmd = tx_desc->isert_cmd;
@@ -1407,7 +1816,7 @@ isert_send_completion(struct iser_tx_desc *tx_desc,
 	case ISER_IB_RDMA_READ:
 		pr_debug("isert_send_completion: Got ISER_IB_RDMA_READ:\n");
 
-		atomic_dec(&isert_conn->post_send_buf_count);
+		atomic_sub(wr->send_wr_num, &isert_conn->post_send_buf_count);
 		isert_completion_rdma_read(tx_desc, isert_cmd);
 		break;
 	default:
@@ -1418,31 +1827,96 @@ isert_send_completion(struct iser_tx_desc *tx_desc,
 }
 
 static void
-isert_cq_comp_err(struct iser_tx_desc *tx_desc, struct isert_conn *isert_conn)
+isert_send_completion(struct iser_tx_desc *tx_desc,
+		      struct isert_conn *isert_conn)
+{
+	struct llist_node *llnode = tx_desc->comp_llnode_batch;
+	struct iser_tx_desc *t;
+	/*
+	 * Drain coalesced completion llist starting from comp_llnode_batch
+	 * setup in isert_init_send_wr(), and then complete trailing tx_desc.
+	 */
+	while (llnode) {
+		t = llist_entry(llnode, struct iser_tx_desc, comp_llnode);
+		llnode = llist_next(llnode);
+		__isert_send_completion(t, isert_conn);
+	}
+	__isert_send_completion(tx_desc, isert_conn);
+}
+
+static void
+isert_cq_drain_comp_llist(struct isert_conn *isert_conn, struct ib_device *ib_dev)
+{
+	struct llist_node *llnode;
+	struct isert_rdma_wr *wr;
+	struct iser_tx_desc *t;
+
+	mutex_lock(&isert_conn->conn_mutex);
+	llnode = llist_del_all(&isert_conn->conn_comp_llist);
+	isert_conn->conn_comp_batch = 0;
+	mutex_unlock(&isert_conn->conn_mutex);
+
+	while (llnode) {
+		t = llist_entry(llnode, struct iser_tx_desc, comp_llnode);
+		llnode = llist_next(llnode);
+		wr = &t->isert_cmd->rdma_wr;
+
+		atomic_sub(wr->send_wr_num + 1, &isert_conn->post_send_buf_count);
+		isert_completion_put(t, t->isert_cmd, ib_dev, true);
+	}
+}
+
+static void
+isert_cq_tx_comp_err(struct iser_tx_desc *tx_desc, struct isert_conn *isert_conn)
 {
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct isert_cmd *isert_cmd = tx_desc->isert_cmd;
+	struct llist_node *llnode = tx_desc->comp_llnode_batch;
+	struct isert_rdma_wr *wr;
+	struct iser_tx_desc *t;
 
-	if (tx_desc) {
-		struct isert_cmd *isert_cmd = tx_desc->isert_cmd;
+	while (llnode) {
+		t = llist_entry(llnode, struct iser_tx_desc, comp_llnode);
+		llnode = llist_next(llnode);
+		wr = &t->isert_cmd->rdma_wr;
 
-		if (!isert_cmd)
-			isert_unmap_tx_desc(tx_desc, ib_dev);
-		else
-			isert_completion_put(tx_desc, isert_cmd, ib_dev);
+		atomic_sub(wr->send_wr_num + 1, &isert_conn->post_send_buf_count);
+		isert_completion_put(t, t->isert_cmd, ib_dev, true);
 	}
+	tx_desc->comp_llnode_batch = NULL;
 
-	if (isert_conn->post_recv_buf_count == 0 &&
-	    atomic_read(&isert_conn->post_send_buf_count) == 0) {
-		pr_debug("isert_cq_comp_err >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n");
-		pr_debug("Calling wake_up from isert_cq_comp_err\n");
+	if (!isert_cmd)
+		isert_unmap_tx_desc(tx_desc, ib_dev);
+	else
+		isert_completion_put(tx_desc, isert_cmd, ib_dev, true);
+}
 
-		mutex_lock(&isert_conn->conn_mutex);
-		if (isert_conn->state != ISER_CONN_DOWN)
-			isert_conn->state = ISER_CONN_TERMINATING;
-		mutex_unlock(&isert_conn->conn_mutex);
+static void
+isert_cq_rx_comp_err(struct isert_conn *isert_conn)
+{
+	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct iscsi_conn *conn = isert_conn->conn;
+
+	if (isert_conn->post_recv_buf_count)
+		return;
 
-		wake_up(&isert_conn->conn_wait_comp_err);
+	isert_cq_drain_comp_llist(isert_conn, ib_dev);
+
+	if (conn->sess) {
+		target_sess_cmd_list_set_waiting(conn->sess->se_sess);
+		target_wait_for_sess_cmds(conn->sess->se_sess);
 	}
+
+	while (atomic_read(&isert_conn->post_send_buf_count))
+		msleep(3000);
+
+	mutex_lock(&isert_conn->conn_mutex);
+	isert_conn_terminate(isert_conn);
+	mutex_unlock(&isert_conn->conn_mutex);
+
+	iscsit_cause_connection_reinstatement(isert_conn->conn, 0);
+
+	complete(&isert_conn->conn_wait_comp_err);
 }
 
 static void
@@ -1466,8 +1940,15 @@ isert_cq_tx_work(struct work_struct *work)
 		} else {
 			pr_debug("TX wc.status != IB_WC_SUCCESS >>>>>>>>>>>>>>\n");
 			pr_debug("TX wc.status: 0x%08x\n", wc.status);
-			atomic_dec(&isert_conn->post_send_buf_count);
-			isert_cq_comp_err(tx_desc, isert_conn);
+			pr_debug("TX wc.vendor_err: 0x%08x\n", wc.vendor_err);
+
+			if (wc.wr_id != ISER_FASTREG_LI_WRID) {
+				if (tx_desc->llnode_active)
+					continue;
+
+				atomic_dec(&isert_conn->post_send_buf_count);
+				isert_cq_tx_comp_err(tx_desc, isert_conn);
+			}
 		}
 	}
 
@@ -1479,7 +1960,6 @@ isert_cq_tx_callback(struct ib_cq *cq, void *context)
 {
 	struct isert_cq_desc *cq_desc = (struct isert_cq_desc *)context;
 
-	INIT_WORK(&cq_desc->cq_tx_work, isert_cq_tx_work);
 	queue_work(isert_comp_wq, &cq_desc->cq_tx_work);
 }
 
@@ -1505,11 +1985,13 @@ isert_cq_rx_work(struct work_struct *work)
 			isert_rx_completion(rx_desc, isert_conn, xfer_len);
 		} else {
 			pr_debug("RX wc.status != IB_WC_SUCCESS >>>>>>>>>>>>>>\n");
-			if (wc.status != IB_WC_WR_FLUSH_ERR)
+			if (wc.status != IB_WC_WR_FLUSH_ERR) {
 				pr_debug("RX wc.status: 0x%08x\n", wc.status);
-
+				pr_debug("RX wc.vendor_err: 0x%08x\n",
+					 wc.vendor_err);
+			}
 			isert_conn->post_recv_buf_count--;
-			isert_cq_comp_err(NULL, isert_conn);
+			isert_cq_rx_comp_err(isert_conn);
 		}
 	}
 
@@ -1521,7 +2003,6 @@ isert_cq_rx_callback(struct ib_cq *cq, void *context)
 {
 	struct isert_cq_desc *cq_desc = (struct isert_cq_desc *)context;
 
-	INIT_WORK(&cq_desc->cq_rx_work, isert_cq_rx_work);
 	queue_work(isert_rx_wq, &cq_desc->cq_rx_work);
 }
 
@@ -1546,8 +2027,7 @@ isert_post_response(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd)
 static int
 isert_put_response(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
 {
-	struct isert_cmd *isert_cmd = container_of(cmd,
-					struct isert_cmd, iscsi_cmd);
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
 	struct iscsi_scsi_rsp *hdr = (struct iscsi_scsi_rsp *)
@@ -1564,7 +2044,7 @@ isert_put_response(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
 	    (cmd->se_cmd.se_cmd_flags & SCF_EMULATED_TASK_SENSE))) {
 		struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
 		struct ib_sge *tx_dsg = &isert_cmd->tx_desc.tx_sg[1];
-		u32 padding, sense_len;
+		u32 padding, pdu_len;
 
 		put_unaligned_be16(cmd->se_cmd.scsi_sense_length,
 				   cmd->sense_buffer);
@@ -1572,20 +2052,20 @@ isert_put_response(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
 
 		padding = -(cmd->se_cmd.scsi_sense_length) & 3;
 		hton24(hdr->dlength, (u32)cmd->se_cmd.scsi_sense_length);
-		sense_len = cmd->se_cmd.scsi_sense_length + padding;
+		pdu_len = cmd->se_cmd.scsi_sense_length + padding;
 
-		isert_cmd->sense_buf_dma = ib_dma_map_single(ib_dev,
-				(void *)cmd->sense_buffer, sense_len,
+		isert_cmd->pdu_buf_dma = ib_dma_map_single(ib_dev,
+				(void *)cmd->sense_buffer, pdu_len,
 				DMA_TO_DEVICE);
 
-		isert_cmd->sense_buf_len = sense_len;
-		tx_dsg->addr	= isert_cmd->sense_buf_dma;
-		tx_dsg->length	= sense_len;
+		isert_cmd->pdu_buf_len = pdu_len;
+		tx_dsg->addr	= isert_cmd->pdu_buf_dma;
+		tx_dsg->length	= pdu_len;
 		tx_dsg->lkey	= isert_conn->conn_mr->lkey;
 		isert_cmd->tx_desc.num_sge = 2;
 	}
 
-	isert_init_send_wr(isert_cmd, send_wr);
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
 
 	pr_debug("Posting SCSI Response IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
 
@@ -1596,8 +2076,7 @@ static int
 isert_put_nopin(struct iscsi_cmd *cmd, struct iscsi_conn *conn,
 		bool nopout_response)
 {
-	struct isert_cmd *isert_cmd = container_of(cmd,
-				struct isert_cmd, iscsi_cmd);
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
 
@@ -1606,9 +2085,9 @@ isert_put_nopin(struct iscsi_cmd *cmd, struct iscsi_conn *conn,
 			       &isert_cmd->tx_desc.iscsi_header,
 			       nopout_response);
 	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
-	isert_init_send_wr(isert_cmd, send_wr);
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
 
-	pr_debug("Posting NOPIN Reponse IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
+	pr_debug("Posting NOPIN Response IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
 
 	return isert_post_response(isert_conn, isert_cmd);
 }
@@ -1616,8 +2095,7 @@ isert_put_nopin(struct iscsi_cmd *cmd, struct iscsi_conn *conn,
 static int
 isert_put_logout_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 {
-	struct isert_cmd *isert_cmd = container_of(cmd,
-				struct isert_cmd, iscsi_cmd);
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
 
@@ -1625,7 +2103,7 @@ isert_put_logout_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 	iscsit_build_logout_rsp(cmd, conn, (struct iscsi_logout_rsp *)
 				&isert_cmd->tx_desc.iscsi_header);
 	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
-	isert_init_send_wr(isert_cmd, send_wr);
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
 
 	pr_debug("Posting Logout Response IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
 
@@ -1635,8 +2113,7 @@ isert_put_logout_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 static int
 isert_put_tm_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 {
-	struct isert_cmd *isert_cmd = container_of(cmd,
-				struct isert_cmd, iscsi_cmd);
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
 
@@ -1644,7 +2121,7 @@ isert_put_tm_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 	iscsit_build_task_mgt_rsp(cmd, conn, (struct iscsi_tm_rsp *)
 				  &isert_cmd->tx_desc.iscsi_header);
 	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
-	isert_init_send_wr(isert_cmd, send_wr);
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
 
 	pr_debug("Posting Task Management Response IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
 
@@ -1654,8 +2131,7 @@ isert_put_tm_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 static int
 isert_put_reject(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 {
-	struct isert_cmd *isert_cmd = container_of(cmd,
-				struct isert_cmd, iscsi_cmd);
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
@@ -1668,16 +2144,16 @@ isert_put_reject(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
 
 	hton24(hdr->dlength, ISCSI_HDR_LEN);
-	isert_cmd->sense_buf_dma = ib_dma_map_single(ib_dev,
+	isert_cmd->pdu_buf_dma = ib_dma_map_single(ib_dev,
 			(void *)cmd->buf_ptr, ISCSI_HDR_LEN,
 			DMA_TO_DEVICE);
-	isert_cmd->sense_buf_len = ISCSI_HDR_LEN;
-	tx_dsg->addr	= isert_cmd->sense_buf_dma;
+	isert_cmd->pdu_buf_len = ISCSI_HDR_LEN;
+	tx_dsg->addr	= isert_cmd->pdu_buf_dma;
 	tx_dsg->length	= ISCSI_HDR_LEN;
 	tx_dsg->lkey	= isert_conn->conn_mr->lkey;
 	isert_cmd->tx_desc.num_sge = 2;
 
-	isert_init_send_wr(isert_cmd, send_wr);
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
 
 	pr_debug("Posting Reject IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
 
@@ -1685,11 +2161,51 @@ isert_put_reject(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 }
 
 static int
+isert_put_text_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
+{
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
+	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
+	struct ib_send_wr *send_wr = &isert_cmd->tx_desc.send_wr;
+	struct iscsi_text_rsp *hdr =
+		(struct iscsi_text_rsp *)&isert_cmd->tx_desc.iscsi_header;
+	u32 txt_rsp_len;
+	int rc;
+
+	isert_create_send_desc(isert_conn, isert_cmd, &isert_cmd->tx_desc);
+	rc = iscsit_build_text_rsp(cmd, conn, hdr, ISCSI_INFINIBAND);
+	if (rc < 0)
+		return rc;
+
+	txt_rsp_len = rc;
+	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
+
+	if (txt_rsp_len) {
+		struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+		struct ib_sge *tx_dsg = &isert_cmd->tx_desc.tx_sg[1];
+		void *txt_rsp_buf = cmd->buf_ptr;
+
+		isert_cmd->pdu_buf_dma = ib_dma_map_single(ib_dev,
+				txt_rsp_buf, txt_rsp_len, DMA_TO_DEVICE);
+
+		isert_cmd->pdu_buf_len = txt_rsp_len;
+		tx_dsg->addr	= isert_cmd->pdu_buf_dma;
+		tx_dsg->length	= txt_rsp_len;
+		tx_dsg->lkey	= isert_conn->conn_mr->lkey;
+		isert_cmd->tx_desc.num_sge = 2;
+	}
+	isert_init_send_wr(isert_conn, isert_cmd, send_wr, false);
+
+	pr_debug("Posting Text Response IB_WR_SEND >>>>>>>>>>>>>>>>>>>>>>\n");
+
+	return isert_post_response(isert_conn, isert_cmd);
+}
+
+static int
 isert_build_rdma_wr(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
 		    struct ib_sge *ib_sge, struct ib_send_wr *send_wr,
 		    u32 data_left, u32 offset)
 {
-	struct iscsi_cmd *cmd = &isert_cmd->iscsi_cmd;
+	struct iscsi_cmd *cmd = isert_cmd->iscsi_cmd;
 	struct scatterlist *sg_start, *tmp_sg;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
 	u32 sg_off, page_off;
@@ -1716,8 +2232,8 @@ isert_build_rdma_wr(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
 				ib_sg_dma_len(ib_dev, tmp_sg) - page_off);
 		ib_sge->lkey = isert_conn->conn_mr->lkey;
 
-		pr_debug("RDMA ib_sge: addr: 0x%16llx  length: %u\n",
-			 ib_sge->addr, ib_sge->length);
+		pr_debug("RDMA ib_sge: addr: 0x%16llx  length: %u lkey: %08x\n",
+			 ib_sge->addr, ib_sge->length, ib_sge->lkey);
 		page_off = 0;
 		data_left -= ib_sge->length;
 		ib_sge++;
@@ -1731,223 +2247,404 @@ isert_build_rdma_wr(struct isert_conn *isert_conn, struct isert_cmd *isert_cmd,
 }
 
 static int
-isert_put_datain(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
+isert_map_rdma(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+	       struct isert_rdma_wr *wr)
 {
 	struct se_cmd *se_cmd = &cmd->se_cmd;
-	struct isert_cmd *isert_cmd = container_of(cmd,
-					struct isert_cmd, iscsi_cmd);
-	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
-	struct ib_send_wr *wr_failed, *send_wr;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct ib_send_wr *send_wr;
 	struct ib_sge *ib_sge;
-	struct scatterlist *sg;
-	u32 offset = 0, data_len, data_left, rdma_write_max;
-	int rc, ret = 0, count, sg_nents, i, ib_sge_cnt;
+	struct scatterlist *sg_start;
+	u32 sg_off = 0, sg_nents;
+	u32 offset = 0, data_len, data_left, rdma_write_max, va_offset = 0;
+	int ret = 0, count, i, ib_sge_cnt;
 
-	pr_debug("RDMA_WRITE: data_length: %u\n", se_cmd->data_length);
+	if (wr->iser_ib_op == ISER_IB_RDMA_WRITE) {
+		data_left = se_cmd->data_length;
+	} else {
+		sg_off = cmd->write_data_done / PAGE_SIZE;
+		data_left = se_cmd->data_length - cmd->write_data_done;
+		offset = cmd->write_data_done;
+		isert_cmd->tx_desc.isert_cmd = isert_cmd;
+	}
 
-	sg = &se_cmd->t_data_sg[0];
-	sg_nents = se_cmd->t_data_nents;
+	sg_start = &cmd->se_cmd.t_data_sg[sg_off];
+	sg_nents = se_cmd->t_data_nents - sg_off;
 
-	count = ib_dma_map_sg(ib_dev, sg, sg_nents, DMA_TO_DEVICE);
+	count = ib_dma_map_sg(ib_dev, sg_start, sg_nents,
+			      (wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+			      DMA_TO_DEVICE : DMA_FROM_DEVICE);
 	if (unlikely(!count)) {
-		pr_err("Unable to map put_datain SGs\n");
+		pr_err("Cmd: %p unrable to map SGs\n", isert_cmd);
 		return -EINVAL;
 	}
-	wr->sge = sg;
+	wr->sge = sg_start;
 	wr->num_sge = sg_nents;
-	pr_debug("Mapped IB count: %u sg: %p sg_nents: %u for RDMA_WRITE\n",
-		 count, sg, sg_nents);
+	wr->cur_rdma_length = data_left;
+	pr_debug("Mapped cmd: %p count: %u sg: %p sg_nents: %u rdma_len %d\n",
+		 isert_cmd, count, sg_start, sg_nents, data_left);
 
 	ib_sge = kzalloc(sizeof(struct ib_sge) * sg_nents, GFP_KERNEL);
 	if (!ib_sge) {
-		pr_warn("Unable to allocate datain ib_sge\n");
+		pr_warn("Unable to allocate ib_sge\n");
 		ret = -ENOMEM;
 		goto unmap_sg;
 	}
-	isert_cmd->ib_sge = ib_sge;
-
-	pr_debug("Allocated ib_sge: %p from t_data_ents: %d for RDMA_WRITE\n",
-		 ib_sge, se_cmd->t_data_nents);
+	wr->ib_sge = ib_sge;
 
 	wr->send_wr_num = DIV_ROUND_UP(sg_nents, isert_conn->max_sge);
 	wr->send_wr = kzalloc(sizeof(struct ib_send_wr) * wr->send_wr_num,
 				GFP_KERNEL);
 	if (!wr->send_wr) {
-		pr_err("Unable to allocate wr->send_wr\n");
+		pr_debug("Unable to allocate wr->send_wr\n");
 		ret = -ENOMEM;
 		goto unmap_sg;
 	}
-	pr_debug("Allocated wr->send_wr: %p wr->send_wr_num: %u\n",
-		 wr->send_wr, wr->send_wr_num);
-
-	iscsit_increment_maxcmdsn(cmd, conn->sess);
-	cmd->stat_sn = conn->stat_sn++;
 
 	wr->isert_cmd = isert_cmd;
 	rdma_write_max = isert_conn->max_sge * PAGE_SIZE;
-	data_left = se_cmd->data_length;
 
 	for (i = 0; i < wr->send_wr_num; i++) {
 		send_wr = &isert_cmd->rdma_wr.send_wr[i];
 		data_len = min(data_left, rdma_write_max);
 
-		send_wr->opcode = IB_WR_RDMA_WRITE;
 		send_wr->send_flags = 0;
-		send_wr->wr.rdma.remote_addr = isert_cmd->read_va + offset;
-		send_wr->wr.rdma.rkey = isert_cmd->read_stag;
+		if (wr->iser_ib_op == ISER_IB_RDMA_WRITE) {
+			send_wr->opcode = IB_WR_RDMA_WRITE;
+			send_wr->wr.rdma.remote_addr = isert_cmd->read_va + offset;
+			send_wr->wr.rdma.rkey = isert_cmd->read_stag;
+			if (i + 1 == wr->send_wr_num)
+				send_wr->next = &isert_cmd->tx_desc.send_wr;
+			else
+				send_wr->next = &wr->send_wr[i + 1];
+		} else {
+			send_wr->opcode = IB_WR_RDMA_READ;
+			send_wr->wr.rdma.remote_addr = isert_cmd->write_va + va_offset;
+			send_wr->wr.rdma.rkey = isert_cmd->write_stag;
+			if (i + 1 == wr->send_wr_num)
+				send_wr->send_flags = IB_SEND_SIGNALED;
+			else
+				send_wr->next = &wr->send_wr[i + 1];
+		}
 
 		ib_sge_cnt = isert_build_rdma_wr(isert_conn, isert_cmd, ib_sge,
 					send_wr, data_len, offset);
 		ib_sge += ib_sge_cnt;
 
-		if (i + 1 == wr->send_wr_num)
-			send_wr->next = &isert_cmd->tx_desc.send_wr;
-		else
-			send_wr->next = &wr->send_wr[i + 1];
-
 		offset += data_len;
+		va_offset += data_len;
 		data_left -= data_len;
 	}
-	/*
-	 * Build isert_conn->tx_desc for iSCSI response PDU and attach
-	 */
-	isert_create_send_desc(isert_conn, isert_cmd, &isert_cmd->tx_desc);
-	iscsit_build_rsp_pdu(cmd, conn, false, (struct iscsi_scsi_rsp *)
-			     &isert_cmd->tx_desc.iscsi_header);
-	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
-	isert_init_send_wr(isert_cmd, &isert_cmd->tx_desc.send_wr);
 
-	atomic_inc(&isert_conn->post_send_buf_count);
+	return 0;
+unmap_sg:
+	ib_dma_unmap_sg(ib_dev, sg_start, sg_nents,
+			(wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+			DMA_TO_DEVICE : DMA_FROM_DEVICE);
+	return ret;
+}
 
-	rc = ib_post_send(isert_conn->conn_qp, wr->send_wr, &wr_failed);
-	if (rc) {
-		pr_warn("ib_post_send() failed for IB_WR_RDMA_WRITE\n");
-		atomic_dec(&isert_conn->post_send_buf_count);
+static int
+isert_map_fr_pagelist(struct ib_device *ib_dev,
+		      struct scatterlist *sg_start, int sg_nents, u64 *fr_pl)
+{
+	u64 start_addr, end_addr, page, chunk_start = 0;
+	struct scatterlist *tmp_sg;
+	int i = 0, new_chunk, last_ent, n_pages;
+
+	n_pages = 0;
+	new_chunk = 1;
+	last_ent = sg_nents - 1;
+	for_each_sg(sg_start, tmp_sg, sg_nents, i) {
+		start_addr = ib_sg_dma_address(ib_dev, tmp_sg);
+		if (new_chunk)
+			chunk_start = start_addr;
+		end_addr = start_addr + ib_sg_dma_len(ib_dev, tmp_sg);
+
+		pr_debug("SGL[%d] dma_addr: 0x%16llx len: %u\n",
+			 i, (unsigned long long)tmp_sg->dma_address,
+			 tmp_sg->length);
+
+		if ((end_addr & ~PAGE_MASK) && i < last_ent) {
+			new_chunk = 0;
+			continue;
+		}
+		new_chunk = 1;
+
+		page = chunk_start & PAGE_MASK;
+		do {
+			fr_pl[n_pages++] = page;
+			pr_debug("Mapped page_list[%d] page_addr: 0x%16llx\n",
+				 n_pages - 1, page);
+			page += PAGE_SIZE;
+		} while (page < end_addr);
 	}
-	pr_debug("Posted RDMA_WRITE + Response for iSER Data READ\n");
-	return 1;
 
-unmap_sg:
-	ib_dma_unmap_sg(ib_dev, sg, sg_nents, DMA_TO_DEVICE);
+	return n_pages;
+}
+
+static int
+isert_fast_reg_mr(struct fast_reg_descriptor *fr_desc,
+		  struct isert_conn *isert_conn, struct scatterlist *sg_start,
+		  struct ib_sge *ib_sge, u32 sg_nents, u32 offset,
+		  unsigned int data_len)
+{
+	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct ib_send_wr fr_wr, inv_wr;
+	struct ib_send_wr *bad_wr, *wr = NULL;
+	int ret, pagelist_len;
+	u32 page_off;
+	u8 key;
+
+	sg_nents = min_t(unsigned int, sg_nents, ISCSI_ISER_SG_TABLESIZE);
+	page_off = offset % PAGE_SIZE;
+
+	pr_debug("Use fr_desc %p sg_nents %d offset %u\n",
+		 fr_desc, sg_nents, offset);
+
+	pagelist_len = isert_map_fr_pagelist(ib_dev, sg_start, sg_nents,
+					     &fr_desc->data_frpl->page_list[0]);
+
+	if (!fr_desc->valid) {
+		memset(&inv_wr, 0, sizeof(inv_wr));
+		inv_wr.wr_id = ISER_FASTREG_LI_WRID;
+		inv_wr.opcode = IB_WR_LOCAL_INV;
+		inv_wr.ex.invalidate_rkey = fr_desc->data_mr->rkey;
+		wr = &inv_wr;
+		/* Bump the key */
+		key = (u8)(fr_desc->data_mr->rkey & 0x000000FF);
+		ib_update_fast_reg_key(fr_desc->data_mr, ++key);
+	}
+
+	/* Prepare FASTREG WR */
+	memset(&fr_wr, 0, sizeof(fr_wr));
+	fr_wr.wr_id = ISER_FASTREG_LI_WRID;
+	fr_wr.opcode = IB_WR_FAST_REG_MR;
+	fr_wr.wr.fast_reg.iova_start =
+		fr_desc->data_frpl->page_list[0] + page_off;
+	fr_wr.wr.fast_reg.page_list = fr_desc->data_frpl;
+	fr_wr.wr.fast_reg.page_list_len = pagelist_len;
+	fr_wr.wr.fast_reg.page_shift = PAGE_SHIFT;
+	fr_wr.wr.fast_reg.length = data_len;
+	fr_wr.wr.fast_reg.rkey = fr_desc->data_mr->rkey;
+	fr_wr.wr.fast_reg.access_flags = IB_ACCESS_LOCAL_WRITE;
+
+	if (!wr)
+		wr = &fr_wr;
+	else
+		wr->next = &fr_wr;
+
+	ret = ib_post_send(isert_conn->conn_qp, wr, &bad_wr);
+	if (ret) {
+		pr_err("fast registration failed, ret:%d\n", ret);
+		return ret;
+	}
+	fr_desc->valid = false;
+
+	ib_sge->lkey = fr_desc->data_mr->lkey;
+	ib_sge->addr = fr_desc->data_frpl->page_list[0] + page_off;
+	ib_sge->length = data_len;
+
+	pr_debug("RDMA ib_sge: addr: 0x%16llx  length: %u lkey: %08x\n",
+		 ib_sge->addr, ib_sge->length, ib_sge->lkey);
+
 	return ret;
 }
 
 static int
-isert_get_dataout(struct iscsi_conn *conn, struct iscsi_cmd *cmd, bool recovery)
+isert_reg_rdma(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+	       struct isert_rdma_wr *wr)
 {
 	struct se_cmd *se_cmd = &cmd->se_cmd;
-	struct isert_cmd *isert_cmd = container_of(cmd,
-					struct isert_cmd, iscsi_cmd);
-	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
-	struct ib_send_wr *wr_failed, *send_wr;
-	struct ib_sge *ib_sge;
 	struct ib_device *ib_dev = isert_conn->conn_cm_id->device;
+	struct ib_send_wr *send_wr;
+	struct ib_sge *ib_sge;
 	struct scatterlist *sg_start;
-	u32 sg_off, sg_nents, page_off, va_offset = 0;
+	struct fast_reg_descriptor *fr_desc;
+	u32 sg_off = 0, sg_nents;
 	u32 offset = 0, data_len, data_left, rdma_write_max;
-	int rc, ret = 0, count, i, ib_sge_cnt;
+	int ret = 0, count;
+	unsigned long flags;
 
-	pr_debug("RDMA_READ: data_length: %u write_data_done: %u\n",
-		 se_cmd->data_length, cmd->write_data_done);
+	if (wr->iser_ib_op == ISER_IB_RDMA_WRITE) {
+		data_left = se_cmd->data_length;
+	} else {
+		offset = cmd->write_data_done;
+		sg_off = offset / PAGE_SIZE;
+		data_left = se_cmd->data_length - cmd->write_data_done;
+		isert_cmd->tx_desc.isert_cmd = isert_cmd;
+	}
 
-	sg_off = cmd->write_data_done / PAGE_SIZE;
 	sg_start = &cmd->se_cmd.t_data_sg[sg_off];
-	page_off = cmd->write_data_done % PAGE_SIZE;
-
-	pr_debug("RDMA_READ: sg_off: %d, sg_start: %p page_off: %d\n",
-		 sg_off, sg_start, page_off);
-
-	data_left = se_cmd->data_length - cmd->write_data_done;
 	sg_nents = se_cmd->t_data_nents - sg_off;
 
-	pr_debug("RDMA_READ: data_left: %d, sg_nents: %d\n",
-		 data_left, sg_nents);
-
-	count = ib_dma_map_sg(ib_dev, sg_start, sg_nents, DMA_FROM_DEVICE);
+	count = ib_dma_map_sg(ib_dev, sg_start, sg_nents,
+			      (wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+			      DMA_TO_DEVICE : DMA_FROM_DEVICE);
 	if (unlikely(!count)) {
-		pr_err("Unable to map get_dataout SGs\n");
+		pr_err("Cmd: %p unrable to map SGs\n", isert_cmd);
 		return -EINVAL;
 	}
 	wr->sge = sg_start;
 	wr->num_sge = sg_nents;
-	pr_debug("Mapped IB count: %u sg_start: %p sg_nents: %u for RDMA_READ\n",
-		 count, sg_start, sg_nents);
+	pr_debug("Mapped cmd: %p count: %u sg: %p sg_nents: %u rdma_len %d\n",
+		 isert_cmd, count, sg_start, sg_nents, data_left);
 
-	ib_sge = kzalloc(sizeof(struct ib_sge) * sg_nents, GFP_KERNEL);
-	if (!ib_sge) {
-		pr_warn("Unable to allocate dataout ib_sge\n");
-		ret = -ENOMEM;
-		goto unmap_sg;
+	memset(&wr->s_ib_sge, 0, sizeof(*ib_sge));
+	ib_sge = &wr->s_ib_sge;
+	wr->ib_sge = ib_sge;
+
+	wr->send_wr_num = 1;
+	memset(&wr->s_send_wr, 0, sizeof(*send_wr));
+	wr->send_wr = &wr->s_send_wr;
+
+	wr->isert_cmd = isert_cmd;
+	rdma_write_max = ISCSI_ISER_SG_TABLESIZE * PAGE_SIZE;
+
+	send_wr = &isert_cmd->rdma_wr.s_send_wr;
+	send_wr->sg_list = ib_sge;
+	send_wr->num_sge = 1;
+	send_wr->wr_id = (unsigned long)&isert_cmd->tx_desc;
+	if (wr->iser_ib_op == ISER_IB_RDMA_WRITE) {
+		send_wr->opcode = IB_WR_RDMA_WRITE;
+		send_wr->wr.rdma.remote_addr = isert_cmd->read_va;
+		send_wr->wr.rdma.rkey = isert_cmd->read_stag;
+		send_wr->send_flags = 0;
+		send_wr->next = &isert_cmd->tx_desc.send_wr;
+	} else {
+		send_wr->opcode = IB_WR_RDMA_READ;
+		send_wr->wr.rdma.remote_addr = isert_cmd->write_va;
+		send_wr->wr.rdma.rkey = isert_cmd->write_stag;
+		send_wr->send_flags = IB_SEND_SIGNALED;
 	}
-	isert_cmd->ib_sge = ib_sge;
 
-	pr_debug("Using ib_sge: %p from sg_ents: %d for RDMA_READ\n",
-		 ib_sge, sg_nents);
+	data_len = min(data_left, rdma_write_max);
+	wr->cur_rdma_length = data_len;
 
-	wr->send_wr_num = DIV_ROUND_UP(sg_nents, isert_conn->max_sge);
-	wr->send_wr = kzalloc(sizeof(struct ib_send_wr) * wr->send_wr_num,
-				GFP_KERNEL);
-	if (!wr->send_wr) {
-		pr_debug("Unable to allocate wr->send_wr\n");
-		ret = -ENOMEM;
-		goto unmap_sg;
+	/* if there is a single dma entry, dma mr is sufficient */
+	if (count == 1) {
+		ib_sge->addr = ib_sg_dma_address(ib_dev, &sg_start[0]);
+		ib_sge->length = ib_sg_dma_len(ib_dev, &sg_start[0]);
+		ib_sge->lkey = isert_conn->conn_mr->lkey;
+		wr->fr_desc = NULL;
+	} else {
+		spin_lock_irqsave(&isert_conn->conn_lock, flags);
+		fr_desc = list_first_entry(&isert_conn->conn_fr_pool,
+					   struct fast_reg_descriptor, list);
+		list_del(&fr_desc->list);
+		spin_unlock_irqrestore(&isert_conn->conn_lock, flags);
+		wr->fr_desc = fr_desc;
+
+		ret = isert_fast_reg_mr(fr_desc, isert_conn, sg_start,
+					ib_sge, sg_nents, offset, data_len);
+		if (ret) {
+			list_add_tail(&fr_desc->list, &isert_conn->conn_fr_pool);
+			goto unmap_sg;
+		}
 	}
-	pr_debug("Allocated wr->send_wr: %p wr->send_wr_num: %u\n",
-		 wr->send_wr, wr->send_wr_num);
 
-	isert_cmd->tx_desc.isert_cmd = isert_cmd;
+	return 0;
 
-	wr->iser_ib_op = ISER_IB_RDMA_READ;
-	wr->isert_cmd = isert_cmd;
-	rdma_write_max = isert_conn->max_sge * PAGE_SIZE;
-	offset = cmd->write_data_done;
+unmap_sg:
+	ib_dma_unmap_sg(ib_dev, sg_start, sg_nents,
+			(wr->iser_ib_op == ISER_IB_RDMA_WRITE) ?
+			DMA_TO_DEVICE : DMA_FROM_DEVICE);
+	return ret;
+}
 
-	for (i = 0; i < wr->send_wr_num; i++) {
-		send_wr = &isert_cmd->rdma_wr.send_wr[i];
-		data_len = min(data_left, rdma_write_max);
+static int
+isert_put_datain(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
+{
+	struct se_cmd *se_cmd = &cmd->se_cmd;
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
+	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
+	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
+	struct isert_device *device = isert_conn->conn_device;
+	struct ib_send_wr *wr_failed;
+	int rc;
 
-		send_wr->opcode = IB_WR_RDMA_READ;
-		send_wr->wr.rdma.remote_addr = isert_cmd->write_va + va_offset;
-		send_wr->wr.rdma.rkey = isert_cmd->write_stag;
+	pr_debug("Cmd: %p RDMA_WRITE data_length: %u\n",
+		 isert_cmd, se_cmd->data_length);
+	wr->iser_ib_op = ISER_IB_RDMA_WRITE;
+	rc = device->reg_rdma_mem(conn, cmd, wr);
+	if (rc) {
+		pr_err("Cmd: %p failed to prepare RDMA res\n", isert_cmd);
+		return rc;
+	}
 
-		ib_sge_cnt = isert_build_rdma_wr(isert_conn, isert_cmd, ib_sge,
-					send_wr, data_len, offset);
-		ib_sge += ib_sge_cnt;
+	/*
+	 * Build isert_conn->tx_desc for iSCSI response PDU and attach
+	 */
+	isert_create_send_desc(isert_conn, isert_cmd, &isert_cmd->tx_desc);
+	iscsit_build_rsp_pdu(cmd, conn, true, (struct iscsi_scsi_rsp *)
+			     &isert_cmd->tx_desc.iscsi_header);
+	isert_init_tx_hdrs(isert_conn, &isert_cmd->tx_desc);
+	isert_init_send_wr(isert_conn, isert_cmd,
+			   &isert_cmd->tx_desc.send_wr, false);
 
-		if (i + 1 == wr->send_wr_num)
-			send_wr->send_flags = IB_SEND_SIGNALED;
-		else
-			send_wr->next = &wr->send_wr[i + 1];
+	atomic_add(wr->send_wr_num + 1, &isert_conn->post_send_buf_count);
 
-		offset += data_len;
-		va_offset += data_len;
-		data_left -= data_len;
+	rc = ib_post_send(isert_conn->conn_qp, wr->send_wr, &wr_failed);
+	if (rc) {
+		pr_warn("ib_post_send() failed for IB_WR_RDMA_WRITE\n");
+		atomic_sub(wr->send_wr_num + 1, &isert_conn->post_send_buf_count);
 	}
+	pr_debug("Cmd: %p posted RDMA_WRITE + Response for iSER Data READ\n",
+		 isert_cmd);
 
-	atomic_inc(&isert_conn->post_send_buf_count);
+	return 1;
+}
+
+static int
+isert_get_dataout(struct iscsi_conn *conn, struct iscsi_cmd *cmd, bool recovery)
+{
+	struct se_cmd *se_cmd = &cmd->se_cmd;
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
+	struct isert_rdma_wr *wr = &isert_cmd->rdma_wr;
+	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
+	struct isert_device *device = isert_conn->conn_device;
+	struct ib_send_wr *wr_failed;
+	int rc;
+
+	pr_debug("Cmd: %p RDMA_READ data_length: %u write_data_done: %u\n",
+		 isert_cmd, se_cmd->data_length, cmd->write_data_done);
+	wr->iser_ib_op = ISER_IB_RDMA_READ;
+	rc = device->reg_rdma_mem(conn, cmd, wr);
+	if (rc) {
+		pr_err("Cmd: %p failed to prepare RDMA res\n", isert_cmd);
+		return rc;
+	}
+
+	atomic_add(wr->send_wr_num, &isert_conn->post_send_buf_count);
 
 	rc = ib_post_send(isert_conn->conn_qp, wr->send_wr, &wr_failed);
 	if (rc) {
 		pr_warn("ib_post_send() failed for IB_WR_RDMA_READ\n");
-		atomic_dec(&isert_conn->post_send_buf_count);
+		atomic_sub(wr->send_wr_num, &isert_conn->post_send_buf_count);
 	}
-	pr_debug("Posted RDMA_READ memory for ISER Data WRITE\n");
-	return 0;
+	pr_debug("Cmd: %p posted RDMA_READ memory for ISER Data WRITE\n",
+		 isert_cmd);
 
-unmap_sg:
-	ib_dma_unmap_sg(ib_dev, sg_start, sg_nents, DMA_FROM_DEVICE);
-	return ret;
+	return 0;
 }
 
 static int
 isert_immediate_queue(struct iscsi_conn *conn, struct iscsi_cmd *cmd, int state)
 {
-	int ret;
+	struct isert_cmd *isert_cmd = iscsit_priv_cmd(cmd);
+	int ret = 0;
 
 	switch (state) {
+	case ISTATE_REMOVE:
+		spin_lock_bh(&conn->cmd_lock);
+		list_del_init(&cmd->i_conn_node);
+		spin_unlock_bh(&conn->cmd_lock);
+		isert_put_cmd(isert_cmd, true);
+		break;
 	case ISTATE_SEND_NOPIN_WANT_RESPONSE:
 		ret = isert_put_nopin(cmd, conn, false);
 		break;
@@ -1982,6 +2679,9 @@ isert_response_queue(struct iscsi_conn *conn, struct iscsi_cmd *cmd, int state)
 	case ISTATE_SEND_REJECT:
 		ret = isert_put_reject(cmd, conn);
 		break;
+	case ISTATE_SEND_TEXTRSP:
+		ret = isert_put_text_rsp(cmd, conn);
+		break;
 	case ISTATE_SEND_STATUS:
 		/*
 		 * Special case for sending non GOOD SCSI status from TX thread
@@ -1998,13 +2698,51 @@ isert_response_queue(struct iscsi_conn *conn, struct iscsi_cmd *cmd, int state)
 	return ret;
 }
 
+struct rdma_cm_id *
+isert_setup_id(struct isert_np *isert_np)
+{
+	struct iscsi_np *np = isert_np->np;
+	struct rdma_cm_id *id;
+	struct sockaddr *sa;
+	int ret;
+
+	sa = (struct sockaddr *)&np->np_sockaddr;
+	pr_debug("ksockaddr: %p, sa: %p\n", &np->np_sockaddr, sa);
+
+	id = rdma_create_id(isert_cma_handler, isert_np,
+			    RDMA_PS_TCP, IB_QPT_RC);
+	if (IS_ERR(id)) {
+		pr_err("rdma_create_id() failed: %ld\n", PTR_ERR(id));
+		ret = PTR_ERR(id);
+		goto out;
+	}
+	pr_debug("id %p context %p\n", id, id->context);
+
+	ret = rdma_bind_addr(id, sa);
+	if (ret) {
+		pr_err("rdma_bind_addr() failed: %d\n", ret);
+		goto out_id;
+	}
+
+	ret = rdma_listen(id, ISERT_RDMA_LISTEN_BACKLOG);
+	if (ret) {
+		pr_err("rdma_listen() failed: %d\n", ret);
+		goto out_id;
+	}
+
+	return id;
+out_id:
+	rdma_destroy_id(id);
+out:
+	return ERR_PTR(ret);
+}
+
 static int
 isert_setup_np(struct iscsi_np *np,
 	       struct __kernel_sockaddr_storage *ksockaddr)
 {
 	struct isert_np *isert_np;
 	struct rdma_cm_id *isert_lid;
-	struct sockaddr *sa;
 	int ret;
 
 	isert_np = kzalloc(sizeof(struct isert_np), GFP_KERNEL);
@@ -2012,13 +2750,12 @@ isert_setup_np(struct iscsi_np *np,
 		pr_err("Unable to allocate struct isert_np\n");
 		return -ENOMEM;
 	}
-	init_waitqueue_head(&isert_np->np_accept_wq);
+	sema_init(&isert_np->np_sem, 0);
 	mutex_init(&isert_np->np_accept_mutex);
 	INIT_LIST_HEAD(&isert_np->np_accept_list);
 	init_completion(&isert_np->np_login_comp);
+	isert_np->np = np;
 
-	sa = (struct sockaddr *)ksockaddr;
-	pr_debug("ksockaddr: %p, sa: %p\n", ksockaddr, sa);
 	/*
 	 * Setup the np->np_sockaddr from the passed sockaddr setup
 	 * in iscsi_target_configfs.c code..
@@ -2026,50 +2763,21 @@ isert_setup_np(struct iscsi_np *np,
 	memcpy(&np->np_sockaddr, ksockaddr,
 	       sizeof(struct __kernel_sockaddr_storage));
 
-	isert_lid = rdma_create_id(isert_cma_handler, np, RDMA_PS_TCP,
-				IB_QPT_RC);
+	isert_lid = isert_setup_id(isert_np);
 	if (IS_ERR(isert_lid)) {
-		pr_err("rdma_create_id() for isert_listen_handler failed: %ld\n",
-		       PTR_ERR(isert_lid));
 		ret = PTR_ERR(isert_lid);
 		goto out;
 	}
 
-	ret = rdma_bind_addr(isert_lid, sa);
-	if (ret) {
-		pr_err("rdma_bind_addr() for isert_lid failed: %d\n", ret);
-		goto out_lid;
-	}
-
-	ret = rdma_listen(isert_lid, ISERT_RDMA_LISTEN_BACKLOG);
-	if (ret) {
-		pr_err("rdma_listen() for isert_lid failed: %d\n", ret);
-		goto out_lid;
-	}
-
 	isert_np->np_cm_id = isert_lid;
 	np->np_context = isert_np;
-	pr_debug("Setup isert_lid->context: %p\n", isert_lid->context);
 
 	return 0;
 
-out_lid:
-	rdma_destroy_id(isert_lid);
 out:
 	kfree(isert_np);
-	return ret;
-}
-
-static int
-isert_check_accept_queue(struct isert_np *isert_np)
-{
-	int empty;
-
-	mutex_lock(&isert_np->np_accept_mutex);
-	empty = list_empty(&isert_np->np_accept_list);
-	mutex_unlock(&isert_np->np_accept_mutex);
 
-	return empty;
+	return ret;
 }
 
 static int
@@ -2104,13 +2812,33 @@ isert_get_login_rx(struct iscsi_conn *conn, struct iscsi_login *login)
 	struct isert_conn *isert_conn = (struct isert_conn *)conn->context;
 	int ret;
 
-	pr_debug("isert_get_login_rx before conn_login_comp conn: %p\n", conn);
+	pr_info("before login_req comp conn: %p\n", isert_conn);
+	ret = wait_for_completion_interruptible(&isert_conn->login_req_comp);
+	if (ret) {
+		pr_err("isert_conn %p interrupted before got login req\n",
+			  isert_conn);
+		return ret;
+	}
+	reinit_completion(&isert_conn->login_req_comp);
+
+	/*
+	 * For login requests after the first PDU, isert_rx_login_req() will
+	 * kick schedule_delayed_work(&conn->login_work) as the packet is
+	 * received, which turns this callback from iscsi_target_do_login_rx()
+	 * into a NOP.
+	 */
+	if (!login->first_request)
+		return 0;
 
+	isert_rx_login_req(isert_conn);
+
+	pr_info("before conn_login_comp conn: %p\n", conn);
 	ret = wait_for_completion_interruptible(&isert_conn->conn_login_comp);
 	if (ret)
 		return ret;
 
-	pr_debug("isert_get_login_rx processing login->req: %p\n", login->req);
+	pr_info("processing login->req: %p\n", login->req);
+
 	return 0;
 }
 
@@ -2156,16 +2884,19 @@ isert_accept_np(struct iscsi_np *np, struct iscsi_conn *conn)
 	int max_accept = 0, ret;
 
 accept_wait:
-	ret = wait_event_interruptible(isert_np->np_accept_wq,
-			!isert_check_accept_queue(isert_np) ||
-			np->np_thread_state == ISCSI_NP_THREAD_RESET);
+	ret = down_interruptible(&isert_np->np_sem);
 	if (max_accept > 5)
 		return -ENODEV;
 
 	spin_lock_bh(&np->np_thread_lock);
-	if (np->np_thread_state == ISCSI_NP_THREAD_RESET) {
+	if (np->np_thread_state >= ISCSI_NP_THREAD_RESET) {
 		spin_unlock_bh(&np->np_thread_lock);
-		pr_err("ISCSI_NP_THREAD_RESET for isert_accept_np\n");
+		pr_debug("np_thread_state %d for isert_accept_np\n",
+			 np->np_thread_state);
+		/**
+		 * No point in stalling here when np_thread
+		 * is in state RESET/SHUTDOWN/EXIT - bail
+		 **/
 		return -ENODEV;
 	}
 	spin_unlock_bh(&np->np_thread_lock);
@@ -2185,17 +2916,10 @@ accept_wait:
 	isert_conn->conn = conn;
 	max_accept = 0;
 
-	ret = isert_rdma_post_recvl(isert_conn);
-	if (ret)
-		return ret;
-
-	ret = isert_rdma_accept(isert_conn);
-	if (ret)
-		return ret;
-
 	isert_set_conn_info(np, conn, isert_conn);
 
-	pr_debug("Processing isert_accept_np: isert_conn: %p\n", isert_conn);
+	pr_debug("Processing isert_conn: %p\n", isert_conn);
+
 	return 0;
 }
 
@@ -2204,69 +2928,57 @@ isert_free_np(struct iscsi_np *np)
 {
 	struct isert_np *isert_np = (struct isert_np *)np->np_context;
 
-	rdma_destroy_id(isert_np->np_cm_id);
+	if (isert_np->np_cm_id)
+		rdma_destroy_id(isert_np->np_cm_id);
 
 	np->np_context = NULL;
 	kfree(isert_np);
 }
 
-static int isert_check_state(struct isert_conn *isert_conn, int state)
+static void isert_release_work(struct work_struct *work)
 {
-	int ret;
+	struct isert_conn *isert_conn = container_of(work,
+						     struct isert_conn,
+						     release_work);
+
+	pr_info("Starting release conn %p\n", isert_conn);
+
+	wait_for_completion(&isert_conn->conn_wait);
 
 	mutex_lock(&isert_conn->conn_mutex);
-	ret = (isert_conn->state == state);
+	isert_conn->state = ISER_CONN_DOWN;
 	mutex_unlock(&isert_conn->conn_mutex);
 
-	return ret;
+	pr_info("Destroying conn %p\n", isert_conn);
+	isert_put_conn(isert_conn);
 }
 
-static void isert_free_conn(struct iscsi_conn *conn)
+static void isert_wait_conn(struct iscsi_conn *conn)
 {
 	struct isert_conn *isert_conn = conn->context;
 
-	pr_debug("isert_free_conn: Starting \n");
-	/*
-	 * Decrement post_send_buf_count for special case when called
-	 * from isert_do_control_comp() -> iscsit_logout_post_handler()
-	 */
-	mutex_lock(&isert_conn->conn_mutex);
-	if (isert_conn->logout_posted)
-		atomic_dec(&isert_conn->post_send_buf_count);
+	pr_debug("isert_wait_conn: Starting \n");
 
-	if (isert_conn->conn_cm_id && isert_conn->state != ISER_CONN_DOWN) {
-		pr_debug("Calling rdma_disconnect from isert_free_conn\n");
-		rdma_disconnect(isert_conn->conn_cm_id);
-	}
+	mutex_lock(&isert_conn->conn_mutex);
 	/*
 	 * Only wait for conn_wait_comp_err if the isert_conn made it
 	 * into full feature phase..
 	 */
-	if (isert_conn->state == ISER_CONN_UP) {
-		pr_debug("isert_free_conn: Before wait_event comp_err %d\n",
-			 isert_conn->state);
-		mutex_unlock(&isert_conn->conn_mutex);
-
-		wait_event(isert_conn->conn_wait_comp_err,
-			  (isert_check_state(isert_conn, ISER_CONN_TERMINATING)));
-
-		wait_event(isert_conn->conn_wait,
-			  (isert_check_state(isert_conn, ISER_CONN_DOWN)));
-
-		isert_put_conn(isert_conn);
-		return;
-	}
 	if (isert_conn->state == ISER_CONN_INIT) {
 		mutex_unlock(&isert_conn->conn_mutex);
-		isert_put_conn(isert_conn);
 		return;
 	}
-	pr_debug("isert_free_conn: wait_event conn_wait %d\n",
-		 isert_conn->state);
+	isert_conn_terminate(isert_conn);
 	mutex_unlock(&isert_conn->conn_mutex);
 
-	wait_event(isert_conn->conn_wait,
-		  (isert_check_state(isert_conn, ISER_CONN_DOWN)));
+	wait_for_completion(&isert_conn->conn_wait_comp_err);
+
+	queue_work(isert_release_wq, &isert_conn->release_work);
+}
+
+static void isert_free_conn(struct iscsi_conn *conn)
+{
+	struct isert_conn *isert_conn = conn->context;
 
 	isert_put_conn(isert_conn);
 }
@@ -2274,12 +2986,13 @@ static void isert_free_conn(struct iscsi_conn *conn)
 static struct iscsit_transport iser_target_transport = {
 	.name			= "IB/iSER",
 	.transport_type		= ISCSI_INFINIBAND,
+	.priv_size		= sizeof(struct isert_cmd),
 	.owner			= THIS_MODULE,
 	.iscsit_setup_np	= isert_setup_np,
 	.iscsit_accept_np	= isert_accept_np,
 	.iscsit_free_np		= isert_free_np,
+	.iscsit_wait_conn	= isert_wait_conn,
 	.iscsit_free_conn	= isert_free_conn,
-	.iscsit_alloc_cmd	= isert_alloc_cmd,
 	.iscsit_get_login_rx	= isert_get_login_rx,
 	.iscsit_put_login_tx	= isert_put_login_tx,
 	.iscsit_immediate_queue	= isert_immediate_queue,
@@ -2306,20 +3019,20 @@ static int __init isert_init(void)
 		goto destroy_rx_wq;
 	}
 
-	isert_cmd_cache = kmem_cache_create("isert_cmd_cache",
-			sizeof(struct isert_cmd), __alignof__(struct isert_cmd),
-			0, NULL);
-	if (!isert_cmd_cache) {
-		pr_err("Unable to create isert_cmd_cache\n");
+	isert_release_wq = alloc_workqueue("isert_release_wq", WQ_UNBOUND,
+					WQ_UNBOUND_MAX_ACTIVE);
+	if (!isert_release_wq) {
+		pr_err("Unable to allocate isert_release_wq\n");
 		ret = -ENOMEM;
-		goto destroy_tx_cq;
+		goto destroy_comp_wq;
 	}
 
 	iscsit_register_transport(&iser_target_transport);
-	pr_debug("iSER_TARGET[0] - Loaded iser_target_transport\n");
+	pr_info("iSER_TARGET[0] - Loaded iser_target_transport\n");
+
 	return 0;
 
-destroy_tx_cq:
+destroy_comp_wq:
 	destroy_workqueue(isert_comp_wq);
 destroy_rx_wq:
 	destroy_workqueue(isert_rx_wq);
@@ -2328,7 +3041,8 @@ destroy_rx_wq:
 
 static void __exit isert_exit(void)
 {
-	kmem_cache_destroy(isert_cmd_cache);
+	flush_scheduled_work();
+	destroy_workqueue(isert_release_wq);
 	destroy_workqueue(isert_comp_wq);
 	destroy_workqueue(isert_rx_wq);
 	iscsit_unregister_transport(&iser_target_transport);
diff --git a/drivers/infiniband/ulp/isert/ib_isert.h b/drivers/infiniband/ulp/isert/ib_isert.h
index 5795c82..1178c5b 100644
--- a/drivers/infiniband/ulp/isert/ib_isert.h
+++ b/drivers/infiniband/ulp/isert/ib_isert.h
@@ -5,6 +5,8 @@
 #include <rdma/rdma_cm.h>
 
 #define ISERT_RDMA_LISTEN_BACKLOG	10
+#define ISCSI_ISER_SG_TABLESIZE		256
+#define ISER_FASTREG_LI_WRID		0xffffffffffffffffULL
 
 enum isert_desc_type {
 	ISCSI_TX_CONTROL,
@@ -21,6 +23,7 @@ enum iser_ib_op_code {
 enum iser_conn_state {
 	ISER_CONN_INIT,
 	ISER_CONN_UP,
+	ISER_CONN_FULL_FEATURE,
 	ISER_CONN_TERMINATING,
 	ISER_CONN_DOWN,
 };
@@ -42,18 +45,32 @@ struct iser_tx_desc {
 	struct ib_sge	tx_sg[2];
 	int		num_sge;
 	struct isert_cmd *isert_cmd;
+	struct llist_node *comp_llnode_batch;
+	struct llist_node comp_llnode;
+	bool		llnode_active;
 	struct ib_send_wr send_wr;
 } __packed;
 
+struct fast_reg_descriptor {
+	struct list_head	list;
+	struct ib_mr		*data_mr;
+	struct ib_fast_reg_page_list	*data_frpl;
+	bool			valid;
+};
+
 struct isert_rdma_wr {
 	struct list_head	wr_list;
 	struct isert_cmd	*isert_cmd;
 	enum iser_ib_op_code	iser_ib_op;
 	struct ib_sge		*ib_sge;
+	struct ib_sge		s_ib_sge;
 	int			num_sge;
 	struct scatterlist	*sge;
 	int			send_wr_num;
 	struct ib_send_wr	*send_wr;
+	struct ib_send_wr	s_send_wr;
+	u32			cur_rdma_length;
+	struct fast_reg_descriptor *fr_desc;
 };
 
 struct isert_cmd {
@@ -61,14 +78,13 @@ struct isert_cmd {
 	uint32_t		write_stag;
 	uint64_t		read_va;
 	uint64_t		write_va;
-	u64			sense_buf_dma;
-	u32			sense_buf_len;
+	u64			pdu_buf_dma;
+	u32			pdu_buf_len;
 	u32			read_va_off;
 	u32			write_va_off;
 	u32			rdma_wr_num;
 	struct isert_conn	*conn;
-	struct iscsi_cmd	iscsi_cmd;
-	struct ib_sge		*ib_sge;
+	struct iscsi_cmd	*iscsi_cmd;
 	struct iser_tx_desc	tx_desc;
 	struct isert_rdma_wr	rdma_wr;
 	struct work_struct	comp_work;
@@ -78,7 +94,6 @@ struct isert_device;
 
 struct isert_conn {
 	enum iser_conn_state	state;
-	bool			logout_posted;
 	int			post_recv_buf_count;
 	atomic_t		post_send_buf_count;
 	u32			responder_resources;
@@ -88,6 +103,7 @@ struct isert_conn {
 	char			*login_req_buf;
 	char			*login_rsp_buf;
 	u64			login_req_dma;
+	int			login_req_len;
 	u64			login_rsp_dma;
 	unsigned int		conn_rx_desc_head;
 	struct iser_rx_desc	*conn_rx_descs;
@@ -95,17 +111,25 @@ struct isert_conn {
 	struct iscsi_conn	*conn;
 	struct list_head	conn_accept_node;
 	struct completion	conn_login_comp;
+	struct completion	login_req_comp;
 	struct iser_tx_desc	conn_login_tx_desc;
 	struct rdma_cm_id	*conn_cm_id;
 	struct ib_pd		*conn_pd;
 	struct ib_mr		*conn_mr;
 	struct ib_qp		*conn_qp;
 	struct isert_device	*conn_device;
-	struct work_struct	conn_logout_work;
 	struct mutex		conn_mutex;
-	wait_queue_head_t	conn_wait;
-	wait_queue_head_t	conn_wait_comp_err;
+	struct completion	conn_wait;
+	struct completion	conn_wait_comp_err;
 	struct kref		conn_kref;
+	struct list_head	conn_fr_pool;
+	int			conn_fr_pool_size;
+	/* lock to protect fastreg pool */
+	spinlock_t		conn_lock;
+	struct work_struct	release_work;
+#define ISERT_COMP_BATCH_COUNT	8
+	int			conn_comp_batch;
+	struct llist_head	conn_comp_llist;
 };
 
 #define ISERT_MAX_CQ 64
@@ -118,20 +142,26 @@ struct isert_cq_desc {
 };
 
 struct isert_device {
+	int			use_fastreg;
 	int			cqs_used;
 	int			refcount;
 	int			cq_active_qps[ISERT_MAX_CQ];
 	struct ib_device	*ib_device;
-	struct ib_pd		*dev_pd;
-	struct ib_mr		*dev_mr;
 	struct ib_cq		*dev_rx_cq[ISERT_MAX_CQ];
 	struct ib_cq		*dev_tx_cq[ISERT_MAX_CQ];
 	struct isert_cq_desc	*cq_desc;
 	struct list_head	dev_node;
+	struct ib_device_attr	dev_attr;
+	int			(*reg_rdma_mem)(struct iscsi_conn *conn,
+						    struct iscsi_cmd *cmd,
+						    struct isert_rdma_wr *wr);
+	void			(*unreg_rdma_mem)(struct isert_cmd *isert_cmd,
+						  struct isert_conn *isert_conn);
 };
 
 struct isert_np {
-	wait_queue_head_t	np_accept_wq;
+	struct iscsi_np         *np;
+	struct semaphore	np_sem;
 	struct rdma_cm_id	*np_cm_id;
 	struct mutex		np_accept_mutex;
 	struct list_head	np_accept_list;
diff --git a/drivers/infiniband/ulp/srp/ib_srp.c b/drivers/infiniband/ulp/srp/ib_srp.c
index 7ccf328..35dd5ff 100644
--- a/drivers/infiniband/ulp/srp/ib_srp.c
+++ b/drivers/infiniband/ulp/srp/ib_srp.c
@@ -93,6 +93,7 @@ static void srp_send_completion(struct ib_cq *cq, void *target_ptr);
 static int srp_cm_handler(struct ib_cm_id *cm_id, struct ib_cm_event *event);
 
 static struct scsi_transport_template *ib_srp_transport_template;
+static struct workqueue_struct *srp_remove_wq;
 
 static struct ib_client srp_client = {
 	.name   = "srp",
@@ -456,7 +457,7 @@ static bool srp_queue_remove_work(struct srp_target_port *target)
 	spin_unlock_irq(&target->lock);
 
 	if (changed)
-		queue_work(system_long_wq, &target->remove_work);
+		queue_work(srp_remove_wq, &target->remove_work);
 
 	return changed;
 }
@@ -1300,14 +1301,13 @@ static void srp_handle_recv(struct srp_target_port *target, struct ib_wc *wc)
 			     PFX "Recv failed with error code %d\n", res);
 }
 
-static void srp_handle_qp_err(enum ib_wc_status wc_status,
-			      enum ib_wc_opcode wc_opcode,
+static void srp_handle_qp_err(enum ib_wc_status wc_status, bool send_err,
 			      struct srp_target_port *target)
 {
 	if (target->connected && !target->qp_in_error) {
 		shost_printk(KERN_ERR, target->scsi_host,
 			     PFX "failed %s status %d\n",
-			     wc_opcode & IB_WC_RECV ? "receive" : "send",
+			     send_err ? "send" : "receive",
 			     wc_status);
 	}
 	target->qp_in_error = true;
@@ -1323,7 +1323,7 @@ static void srp_recv_completion(struct ib_cq *cq, void *target_ptr)
 		if (likely(wc.status == IB_WC_SUCCESS)) {
 			srp_handle_recv(target, &wc);
 		} else {
-			srp_handle_qp_err(wc.status, wc.opcode, target);
+			srp_handle_qp_err(wc.status, false, target);
 		}
 	}
 }
@@ -1339,7 +1339,7 @@ static void srp_send_completion(struct ib_cq *cq, void *target_ptr)
 			iu = (struct srp_iu *) (uintptr_t) wc.wr_id;
 			list_add(&iu->list, &target->free_tx);
 		} else {
-			srp_handle_qp_err(wc.status, wc.opcode, target);
+			srp_handle_qp_err(wc.status, true, target);
 		}
 	}
 }
@@ -1410,6 +1410,12 @@ err_unmap:
 err_iu:
 	srp_put_tx_iu(target, iu, SRP_IU_CMD);
 
+	/*
+	 * Avoid that the loops that iterate over the request ring can
+	 * encounter a dangling SCSI command pointer.
+	 */
+	req->scmnd = NULL;
+
 	spin_lock_irqsave(&target->lock, flags);
 	list_add(&req->list, &target->free_reqs);
 
@@ -2525,9 +2531,10 @@ static void srp_remove_one(struct ib_device *device)
 		spin_unlock(&host->target_lock);
 
 		/*
-		 * Wait for target port removal tasks.
+		 * Wait for tl_err and target port removal tasks.
 		 */
 		flush_workqueue(system_long_wq);
+		flush_workqueue(srp_remove_wq);
 
 		kfree(host);
 	}
@@ -2572,16 +2579,22 @@ static int __init srp_init_module(void)
 		indirect_sg_entries = cmd_sg_entries;
 	}
 
+	srp_remove_wq = create_workqueue("srp_remove");
+	if (IS_ERR(srp_remove_wq)) {
+		ret = PTR_ERR(srp_remove_wq);
+		goto out;
+	}
+
+	ret = -ENOMEM;
 	ib_srp_transport_template =
 		srp_attach_transport(&ib_srp_transport_functions);
 	if (!ib_srp_transport_template)
-		return -ENOMEM;
+		goto destroy_wq;
 
 	ret = class_register(&srp_class);
 	if (ret) {
 		pr_err("couldn't register class infiniband_srp\n");
-		srp_release_transport(ib_srp_transport_template);
-		return ret;
+		goto release_tr;
 	}
 
 	ib_sa_register_client(&srp_sa_client);
@@ -2589,13 +2602,22 @@ static int __init srp_init_module(void)
 	ret = ib_register_client(&srp_client);
 	if (ret) {
 		pr_err("couldn't register IB client\n");
-		srp_release_transport(ib_srp_transport_template);
-		ib_sa_unregister_client(&srp_sa_client);
-		class_unregister(&srp_class);
-		return ret;
+		goto unreg_sa;
 	}
 
-	return 0;
+out:
+	return ret;
+
+unreg_sa:
+	ib_sa_unregister_client(&srp_sa_client);
+	class_unregister(&srp_class);
+
+release_tr:
+	srp_release_transport(ib_srp_transport_template);
+
+destroy_wq:
+	destroy_workqueue(srp_remove_wq);
+	goto out;
 }
 
 static void __exit srp_cleanup_module(void)
@@ -2604,6 +2626,7 @@ static void __exit srp_cleanup_module(void)
 	ib_sa_unregister_client(&srp_sa_client);
 	class_unregister(&srp_class);
 	srp_release_transport(ib_srp_transport_template);
+	destroy_workqueue(srp_remove_wq);
 }
 
 module_init(srp_init_module);
diff --git a/drivers/infiniband/ulp/srpt/ib_srpt.c b/drivers/infiniband/ulp/srpt/ib_srpt.c
index 6c66a72..0097b8d 100644
--- a/drivers/infiniband/ulp/srpt/ib_srpt.c
+++ b/drivers/infiniband/ulp/srpt/ib_srpt.c
@@ -1078,6 +1078,7 @@ static void srpt_unmap_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 static int srpt_map_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 				 struct srpt_send_ioctx *ioctx)
 {
+	struct ib_device *dev = ch->sport->sdev->device;
 	struct se_cmd *cmd;
 	struct scatterlist *sg, *sg_orig;
 	int sg_cnt;
@@ -1124,7 +1125,7 @@ static int srpt_map_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 
 	db = ioctx->rbufs;
 	tsize = cmd->data_length;
-	dma_len = sg_dma_len(&sg[0]);
+	dma_len = ib_sg_dma_len(dev, &sg[0]);
 	riu = ioctx->rdma_ius;
 
 	/*
@@ -1155,7 +1156,8 @@ static int srpt_map_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 					++j;
 					if (j < count) {
 						sg = sg_next(sg);
-						dma_len = sg_dma_len(sg);
+						dma_len = ib_sg_dma_len(
+								dev, sg);
 					}
 				}
 			} else {
@@ -1192,8 +1194,8 @@ static int srpt_map_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 	tsize = cmd->data_length;
 	riu = ioctx->rdma_ius;
 	sg = sg_orig;
-	dma_len = sg_dma_len(&sg[0]);
-	dma_addr = sg_dma_address(&sg[0]);
+	dma_len = ib_sg_dma_len(dev, &sg[0]);
+	dma_addr = ib_sg_dma_address(dev, &sg[0]);
 
 	/* this second loop is really mapped sg_addres to rdma_iu->ib_sge */
 	for (i = 0, j = 0;
@@ -1216,8 +1218,10 @@ static int srpt_map_sg_to_ib_sge(struct srpt_rdma_ch *ch,
 					++j;
 					if (j < count) {
 						sg = sg_next(sg);
-						dma_len = sg_dma_len(sg);
-						dma_addr = sg_dma_address(sg);
+						dma_len = ib_sg_dma_len(
+								dev, sg);
+						dma_addr = ib_sg_dma_address(
+								dev, sg);
 					}
 				}
 			} else {
@@ -1352,11 +1356,8 @@ static int srpt_abort_cmd(struct srpt_send_ioctx *ioctx)
 
 		/* XXX(hch): this is a horrible layering violation.. */
 		spin_lock_irqsave(&ioctx->cmd.t_state_lock, flags);
-		ioctx->cmd.transport_state |= CMD_T_LUN_STOP;
 		ioctx->cmd.transport_state &= ~CMD_T_ACTIVE;
 		spin_unlock_irqrestore(&ioctx->cmd.t_state_lock, flags);
-
-		complete(&ioctx->cmd.transport_lun_stop_comp);
 		break;
 	case SRPT_STATE_CMD_RSP_SENT:
 		/*
@@ -1364,9 +1365,6 @@ static int srpt_abort_cmd(struct srpt_send_ioctx *ioctx)
 		 * not been received in time.
 		 */
 		srpt_unmap_sg_to_ib_sge(ioctx->ch, ioctx);
-		spin_lock_irqsave(&ioctx->cmd.t_state_lock, flags);
-		ioctx->cmd.transport_state |= CMD_T_LUN_STOP;
-		spin_unlock_irqrestore(&ioctx->cmd.t_state_lock, flags);
 		target_put_sess_cmd(ioctx->ch->sess, &ioctx->cmd);
 		break;
 	case SRPT_STATE_MGMT_RSP_SENT:
@@ -1476,7 +1474,6 @@ static void srpt_handle_rdma_err_comp(struct srpt_rdma_ch *ch,
 {
 	struct se_cmd *cmd;
 	enum srpt_command_state state;
-	unsigned long flags;
 
 	cmd = &ioctx->cmd;
 	state = srpt_get_cmd_state(ioctx);
@@ -1496,9 +1493,6 @@ static void srpt_handle_rdma_err_comp(struct srpt_rdma_ch *ch,
 			       __func__, __LINE__, state);
 		break;
 	case SRPT_RDMA_WRITE_LAST:
-		spin_lock_irqsave(&ioctx->cmd.t_state_lock, flags);
-		ioctx->cmd.transport_state |= CMD_T_LUN_STOP;
-		spin_unlock_irqrestore(&ioctx->cmd.t_state_lock, flags);
 		break;
 	default:
 		printk(KERN_ERR "%s[%d]: opcode = %u\n", __func__,
@@ -2097,6 +2091,7 @@ static int srpt_create_ch_ib(struct srpt_rdma_ch *ch)
 	if (!qp_init)
 		goto out;
 
+retry:
 	ch->cq = ib_create_cq(sdev->device, srpt_completion, NULL, ch,
 			      ch->rq_size + srp_sq_size, 0);
 	if (IS_ERR(ch->cq)) {
@@ -2120,6 +2115,13 @@ static int srpt_create_ch_ib(struct srpt_rdma_ch *ch)
 	ch->qp = ib_create_qp(sdev->pd, qp_init);
 	if (IS_ERR(ch->qp)) {
 		ret = PTR_ERR(ch->qp);
+		if (ret == -ENOMEM) {
+			srp_sq_size /= 2;
+			if (srp_sq_size >= MIN_SRPT_SQ_SIZE) {
+				ib_destroy_cq(ch->cq);
+				goto retry;
+			}
+		}
 		printk(KERN_ERR "failed to create_qp ret= %d\n", ret);
 		goto err_destroy_cq;
 	}
@@ -3009,7 +3011,7 @@ static u8 tcm_to_srp_tsk_mgmt_status(const int tcm_mgmt_status)
  * Callback function called by the TCM core. Must not block since it can be
  * invoked on the context of the IB completion handler.
  */
-static int srpt_queue_response(struct se_cmd *cmd)
+static void srpt_queue_response(struct se_cmd *cmd)
 {
 	struct srpt_rdma_ch *ch;
 	struct srpt_send_ioctx *ioctx;
@@ -3020,8 +3022,6 @@ static int srpt_queue_response(struct se_cmd *cmd)
 	int resp_len;
 	u8 srp_tm_status;
 
-	ret = 0;
-
 	ioctx = container_of(cmd, struct srpt_send_ioctx, cmd);
 	ch = ioctx->ch;
 	BUG_ON(!ch);
@@ -3047,7 +3047,7 @@ static int srpt_queue_response(struct se_cmd *cmd)
 		     || WARN_ON_ONCE(state == SRPT_STATE_CMD_RSP_SENT))) {
 		atomic_inc(&ch->req_lim_delta);
 		srpt_abort_cmd(ioctx);
-		goto out;
+		return;
 	}
 
 	dir = ioctx->cmd.data_direction;
@@ -3059,7 +3059,7 @@ static int srpt_queue_response(struct se_cmd *cmd)
 		if (ret) {
 			printk(KERN_ERR "xfer_data failed for tag %llu\n",
 			       ioctx->tag);
-			goto out;
+			return;
 		}
 	}
 
@@ -3080,9 +3080,17 @@ static int srpt_queue_response(struct se_cmd *cmd)
 		srpt_set_cmd_state(ioctx, SRPT_STATE_DONE);
 		target_put_sess_cmd(ioctx->ch->sess, &ioctx->cmd);
 	}
+}
 
-out:
-	return ret;
+static int srpt_queue_data_in(struct se_cmd *cmd)
+{
+	srpt_queue_response(cmd);
+	return 0;
+}
+
+static void srpt_queue_tm_rsp(struct se_cmd *cmd)
+{
+	srpt_queue_response(cmd);
 }
 
 static int srpt_queue_status(struct se_cmd *cmd)
@@ -3095,7 +3103,8 @@ static int srpt_queue_status(struct se_cmd *cmd)
 	    (SCF_TRANSPORT_TASK_SENSE | SCF_EMULATED_TASK_SENSE))
 		WARN_ON(cmd->scsi_status != SAM_STAT_CHECK_CONDITION);
 	ioctx->queue_status_only = true;
-	return srpt_queue_response(cmd);
+	srpt_queue_response(cmd);
+	return 0;
 }
 
 static void srpt_refresh_port_work(struct work_struct *work)
@@ -3669,9 +3678,9 @@ static ssize_t srpt_tpg_attrib_store_srp_max_rdma_size(
 	unsigned long val;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &val);
+	ret = kstrtoul(page, 0, &val);
 	if (ret < 0) {
-		pr_err("strict_strtoul() failed with ret: %d\n", ret);
+		pr_err("kstrtoul() failed with ret: %d\n", ret);
 		return -EINVAL;
 	}
 	if (val > MAX_SRPT_RDMA_SIZE) {
@@ -3709,9 +3718,9 @@ static ssize_t srpt_tpg_attrib_store_srp_max_rsp_size(
 	unsigned long val;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &val);
+	ret = kstrtoul(page, 0, &val);
 	if (ret < 0) {
-		pr_err("strict_strtoul() failed with ret: %d\n", ret);
+		pr_err("kstrtoul() failed with ret: %d\n", ret);
 		return -EINVAL;
 	}
 	if (val > MAX_SRPT_RSP_SIZE) {
@@ -3749,9 +3758,9 @@ static ssize_t srpt_tpg_attrib_store_srp_sq_size(
 	unsigned long val;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &val);
+	ret = kstrtoul(page, 0, &val);
 	if (ret < 0) {
-		pr_err("strict_strtoul() failed with ret: %d\n", ret);
+		pr_err("kstrtoul() failed with ret: %d\n", ret);
 		return -EINVAL;
 	}
 	if (val > MAX_SRPT_SRQ_SIZE) {
@@ -3796,7 +3805,7 @@ static ssize_t srpt_tpg_store_enable(
 	unsigned long tmp;
         int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		printk(KERN_ERR "Unable to extract srpt_tpg_store_enable\n");
 		return -EINVAL;
@@ -3928,9 +3937,9 @@ static struct target_core_fabric_ops srpt_template = {
 	.set_default_node_attributes	= srpt_set_default_node_attrs,
 	.get_task_tag			= srpt_get_task_tag,
 	.get_cmd_state			= srpt_get_tcm_cmd_state,
-	.queue_data_in			= srpt_queue_response,
+	.queue_data_in			= srpt_queue_data_in,
 	.queue_status			= srpt_queue_status,
-	.queue_tm_rsp			= srpt_queue_response,
+	.queue_tm_rsp			= srpt_queue_tm_rsp,
 	/*
 	 * Setup function pointers for generic logic in
 	 * target_core_fabric_configfs.c
diff --git a/drivers/md/dm-raid.c b/drivers/md/dm-raid.c
index 2dea49c..2ef65d8 100644
--- a/drivers/md/dm-raid.c
+++ b/drivers/md/dm-raid.c
@@ -799,6 +799,7 @@ static int read_disk_sb(struct md_rdev *rdev, int size)
 	if (!sync_page_io(rdev, 0, size, rdev->sb_page, READ, 1)) {
 		DMERR("Failed to read superblock of device at position %d",
 		      rdev->raid_disk);
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(rdev->mddev, rdev);
 		return -EINVAL;
 	}
diff --git a/drivers/md/md.c b/drivers/md/md.c
index d78f1ff..fd25c0a 100644
--- a/drivers/md/md.c
+++ b/drivers/md/md.c
@@ -54,6 +54,10 @@
 #include "md.h"
 #include "bitmap.h"
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include <buffalo/kernevnt.h>
+#endif	/* CONFIG_BUFFALO_USE_KERNEVNT */
+
 #ifndef MODULE
 static void autostart_arrays(int part);
 #endif
@@ -97,7 +101,17 @@ static int remove_and_add_spares(struct mddev *mddev,
  */
 
 static int sysctl_speed_limit_min = 1000;
+#ifdef CONFIG_BUFFALO_PLATFORM
+static int sysctl_speed_limit_max = 50000;
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+static int sysctl_skip_resync = 0;
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+static int sysctl_use_kernevnt = 1;
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
+#else	/* CONFIG_BUFFALO_PLATFORM */
 static int sysctl_speed_limit_max = 200000;
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 static inline int speed_min(struct mddev *mddev)
 {
 	return mddev->sync_speed_min ?
@@ -120,6 +134,24 @@ static ctl_table raid_table[] = {
 		.mode		= S_IRUGO|S_IWUSR,
 		.proc_handler	= proc_dointvec,
 	},
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	{
+		.procname	= "skip_resync",
+		.data		= &sysctl_skip_resync,
+		.maxlen		= sizeof(int),
+		.mode		= S_IRUGO|S_IWUSR,
+		.proc_handler	= proc_dointvec,
+	},
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+	{
+		.procname	= "use_kernevnt",
+		.data		= &sysctl_use_kernevnt,
+		.maxlen		= sizeof(int),
+		.mode		= S_IRUGO|S_IWUSR,
+		.proc_handler	= proc_dointvec,
+	},
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
 	{
 		.procname	= "speed_limit_max",
 		.data		= &sysctl_speed_limit_max,
@@ -569,7 +601,7 @@ static struct mddev * mddev_find(dev_t unit)
 				kfree(new);
 				return NULL;
 			}
-				
+
 			is_free = 1;
 			list_for_each_entry(mddev, &all_mddevs, all_mddevs)
 				if (mddev->unit == dev) {
@@ -765,6 +797,7 @@ static void super_written(struct bio *bio, int error)
 		printk("md: super_written gets error=%d, uptodate=%d\n",
 		       error, test_bit(BIO_UPTODATE, &bio->bi_flags));
 		WARN_ON(test_bit(BIO_UPTODATE, &bio->bi_flags));
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, rdev);
 	}
 
@@ -1008,7 +1041,7 @@ int md_check_no_bitmap(struct mddev *mddev)
 EXPORT_SYMBOL(md_check_no_bitmap);
 
 /*
- * load_super for 0.90.0 
+ * load_super for 0.90.0
  */
 static int super_90_load(struct md_rdev *rdev, struct md_rdev *refdev, int minor_version)
 {
@@ -1087,7 +1120,7 @@ static int super_90_load(struct md_rdev *rdev, struct md_rdev *refdev, int minor
 		ev2 = md_event(refsb);
 		if (ev1 > ev2)
 			ret = 1;
-		else 
+		else
 			ret = 0;
 	}
 	rdev->sectors = rdev->sb_start;
@@ -1160,7 +1193,7 @@ static int super_90_validate(struct mddev *mddev, struct md_rdev *rdev)
 		if (sb->state & (1<<MD_SB_CLEAN))
 			mddev->recovery_cp = MaxSector;
 		else {
-			if (sb->events_hi == sb->cp_events_hi && 
+			if (sb->events_hi == sb->cp_events_hi &&
 				sb->events_lo == sb->cp_events_lo) {
 				mddev->recovery_cp = sb->recovery_cp;
 			} else
@@ -1188,7 +1221,7 @@ static int super_90_validate(struct mddev *mddev, struct md_rdev *rdev)
 		++ev1;
 		if (sb->disks[rdev->desc_nr].state & (
 			    (1<<MD_DISK_SYNC) | (1 << MD_DISK_ACTIVE)))
-			if (ev1 < mddev->events) 
+			if (ev1 < mddev->events)
 				return -EINVAL;
 	} else if (mddev->bitmap) {
 		/* if adding to array with a bitmap, then we can accept an
@@ -1798,8 +1831,11 @@ static void super_1_sync(struct mddev *mddev, struct md_rdev *rdev)
 	if (rdev->badblocks.count == 0)
 		/* Nothing to do for bad blocks*/ ;
 	else if (sb->bblog_offset == 0)
+	{
 		/* Cannot record bad blocks on this device */
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, rdev);
+	}
 	else {
 		struct badblocks *bb = &rdev->badblocks;
 		u64 *bbp = (u64 *)page_address(rdev->bb_page);
@@ -1846,7 +1882,7 @@ retry:
 
 	for (i=0; i<max_dev;i++)
 		sb->dev_roles[i] = cpu_to_le16(0xfffe);
-	
+
 	rdev_for_each(rdev2, mddev) {
 		i = rdev2->desc_nr;
 		if (test_bit(Faulty, &rdev2->flags))
@@ -2254,7 +2290,7 @@ static void print_sb_90(mdp_super_t *sb)
 {
 	int i;
 
-	printk(KERN_INFO 
+	printk(KERN_INFO
 		"md:  SB: (V:%d.%d.%d) ID:<%08x.%08x.%08x.%08x> CT:%08x\n",
 		sb->major_version, sb->minor_version, sb->patch_version,
 		sb->set_uuid0, sb->set_uuid1, sb->set_uuid2, sb->set_uuid3,
@@ -2419,7 +2455,7 @@ repeat:
 		    mddev->curr_resync_completed > rdev->recovery_offset)
 				rdev->recovery_offset = mddev->curr_resync_completed;
 
-	}	
+	}
 	if (!mddev->persistent) {
 		clear_bit(MD_CHANGE_CLEAN, &mddev->flags);
 		clear_bit(MD_CHANGE_DEVS, &mddev->flags);
@@ -2429,6 +2465,7 @@ repeat:
 				if (rdev->badblocks.changed) {
 					rdev->badblocks.changed = 0;
 					md_ack_all_badblocks(&rdev->badblocks);
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(mddev, rdev);
 				}
 				clear_bit(Blocked, &rdev->flags);
@@ -2654,6 +2691,7 @@ state_store(struct md_rdev *rdev, const char *buf, size_t len)
 	 */
 	int err = -EINVAL;
 	if (cmd_match(buf, "faulty") && rdev->mddev->pers) {
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(rdev->mddev, rdev);
 		if (test_bit(Faulty, &rdev->flags))
 			err = 0;
@@ -2685,6 +2723,7 @@ state_store(struct md_rdev *rdev, const char *buf, size_t len)
 			/* metadata handler doesn't understand badblocks,
 			 * so we need to fail the device
 			 */
+			pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 			md_error(rdev->mddev, rdev);
 		}
 		clear_bit(Blocked, &rdev->flags);
@@ -3265,7 +3304,7 @@ static struct md_rdev *md_import_device(dev_t newdev, int super_format, int supe
 
 	size = i_size_read(rdev->bdev->bd_inode) >> BLOCK_SIZE_BITS;
 	if (!size) {
-		printk(KERN_WARNING 
+		printk(KERN_WARNING
 			"md: %s has zero or unknown size, marking faulty!\n",
 			bdevname(rdev->bdev,b));
 		err = -EINVAL;
@@ -3284,7 +3323,7 @@ static struct md_rdev *md_import_device(dev_t newdev, int super_format, int supe
 			goto abort_free;
 		}
 		if (err < 0) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"md: could not read %s's sb, not importing!\n",
 				bdevname(rdev->bdev,b));
 			goto abort_free;
@@ -3324,7 +3363,7 @@ static void analyze_sbs(struct mddev * mddev)
 		default:
 			printk( KERN_ERR \
 				"md: fatal superblock inconsistency in %s"
-				" -- removing from array\n", 
+				" -- removing from array\n",
 				bdevname(rdev->bdev,b));
 			kick_rdev_from_array(rdev);
 		}
@@ -3368,7 +3407,7 @@ static void analyze_sbs(struct mddev * mddev)
 /* Read a fixed-point number.
  * Numbers in sysfs attributes should be in "standard" units where
  * possible, so time should be in seconds.
- * However we internally use a a much smaller unit such as 
+ * However we internally use a a much smaller unit such as
  * milliseconds or jiffies.
  * This function takes a decimal number with a possible fractional
  * component, and produces an integer which is the result of
@@ -3546,7 +3585,7 @@ level_store(struct mddev *mddev, const char *buf, size_t len)
 	/* Looks like we have a winner */
 	mddev_suspend(mddev);
 	mddev->pers->stop(mddev);
-	
+
 	if (mddev->pers->sync_request == NULL &&
 	    pers->sync_request != NULL) {
 		/* need to add the md_redundancy_group */
@@ -3555,7 +3594,7 @@ level_store(struct mddev *mddev, const char *buf, size_t len)
 			       "md: cannot register extra attributes for %s\n",
 			       mdname(mddev));
 		mddev->sysfs_action = sysfs_get_dirent(mddev->kobj.sd, NULL, "sync_action");
-	}		
+	}
 	if (mddev->pers->sync_request != NULL &&
 	    pers->sync_request == NULL) {
 		/* need to remove the md_redundancy_group */
@@ -3672,6 +3711,55 @@ static struct md_sysfs_entry md_layout =
 __ATTR(layout, S_IRUGO|S_IWUSR, layout_show, layout_store);
 
 
+#ifdef CONFIG_BUFFALO_ERRCNT
+static ssize_t
+maxerr_cnt_show(struct mddev *mddev, char *page)
+{
+	return sprintf(page, "%d\n", atomic_read(&mddev->maxerr_cnt));
+}
+
+static ssize_t
+maxerr_cnt_store(struct mddev *mddev, const char *buf, size_t len)
+{
+	char *e;
+	unsigned long n = simple_strtol(buf, &e, 10);
+
+	if (*buf &&
+	    (*e == 0 || *e == '\n') &&
+	    (n == -1 || (signed int)n >= 0)) {
+		atomic_set(&mddev->maxerr_cnt, n);
+		return len;
+	}
+	return -EINVAL;
+}
+static struct md_sysfs_entry md_maxerr_cnt =
+__ATTR(maxerr_cnt, S_IRUGO|S_IWUSR, maxerr_cnt_show, maxerr_cnt_store);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+static ssize_t
+skip_resync_show(struct mddev *mddev, char *page)
+{
+	return sprintf(page, "%d\n", atomic_read(&mddev->skip_resync));
+}
+static ssize_t
+skip_resync_store(struct mddev *mddev, const char *buf, size_t len)
+{
+	char *e;
+	unsigned long n = simple_strtol(buf, &e, 10);
+
+	if (*buf &&
+	    (*e == 0 || *e == '\n') &&
+	    (n == 1 || n == 0)) {
+		atomic_set(&mddev->skip_resync, n);
+		return len;
+	}
+	return -EINVAL;
+}
+static struct md_sysfs_entry md_skip_resync =
+__ATTR(skip_resync, S_IRUGO|S_IWUSR, skip_resync_show, skip_resync_store);
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+
 static ssize_t
 raid_disks_show(struct mddev *mddev, char *page)
 {
@@ -4498,7 +4586,7 @@ suspend_lo_store(struct mddev *mddev, const char *buf, size_t len)
 	unsigned long long new = simple_strtoull(buf, &e, 10);
 	unsigned long long old = mddev->suspend_lo;
 
-	if (mddev->pers == NULL || 
+	if (mddev->pers == NULL ||
 	    mddev->pers->quiesce == NULL)
 		return -EINVAL;
 	if (buf == e || (*e && *e != '\n'))
@@ -4669,6 +4757,12 @@ __ATTR(array_size, S_IRUGO|S_IWUSR, array_size_show,
 static struct attribute *md_default_attrs[] = {
 	&md_level.attr,
 	&md_layout.attr,
+#ifdef CONFIG_BUFFALO_ERRCNT
+	&md_maxerr_cnt.attr,
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	&md_skip_resync.attr,
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 	&md_raid_disks.attr,
 	&md_chunk_size.attr,
 	&md_size.attr,
@@ -5132,12 +5226,19 @@ int md_run(struct mddev *mddev)
 		if (rdev->raid_disk >= 0)
 			if (sysfs_link_rdev(mddev, rdev))
 				/* failure here is OK */;
-	
+
 	set_bit(MD_RECOVERY_NEEDED, &mddev->recovery);
-	
+
 	if (mddev->flags)
 		md_update_sb(mddev, 0);
 
+#ifdef CONFIG_BUFFALO_ERRCNT
+	atomic_set(&mddev->maxerr_cnt, MAXERR_CNT_DEFAULT);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	atomic_set(&mddev->skip_resync, 0);
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+
 	md_new_event(mddev);
 	sysfs_notify_dirent_safe(mddev->sysfs_state);
 	sysfs_notify_dirent_safe(mddev->sysfs_action);
@@ -5328,8 +5429,14 @@ static int md_set_readonly(struct mddev *mddev, struct block_device *bdev)
 		err = -EBUSY;
 		goto out;
 	}
-	if (bdev)
-		sync_blockdev(bdev);
+	if (bdev && !test_bit(MD_STILL_CLOSED, &mddev->flags)) {
+		/* Someone opened the device since we flushed it
+		 * so page cache could be dirty and it is too late
+		 * to flush.  So abort
+		 */
+		mutex_unlock(&mddev->open_mutex);
+		return -EBUSY;
+	}
 	if (mddev->pers) {
 		__md_stop_writes(mddev);
 
@@ -5340,7 +5447,7 @@ static int md_set_readonly(struct mddev *mddev, struct block_device *bdev)
 		set_disk_ro(mddev->gendisk, 1);
 		clear_bit(MD_RECOVERY_FROZEN, &mddev->recovery);
 		sysfs_notify_dirent_safe(mddev->sysfs_state);
-		err = 0;	
+		err = 0;
 	}
 out:
 	mutex_unlock(&mddev->open_mutex);
@@ -5364,14 +5471,14 @@ static int do_md_stop(struct mddev * mddev, int mode,
 		mutex_unlock(&mddev->open_mutex);
 		return -EBUSY;
 	}
-	if (bdev)
-		/* It is possible IO was issued on some other
-		 * open file which was closed before we took ->open_mutex.
-		 * As that was not the last close __blkdev_put will not
-		 * have called sync_blockdev, so we must.
+	if (bdev && !test_bit(MD_STILL_CLOSED, &mddev->flags)) {
+		/* Someone opened the device since we flushed it
+		 * so page cache could be dirty and it is too late
+		 * to flush.  So abort
 		 */
-		sync_blockdev(bdev);
-
+		mutex_unlock(&mddev->open_mutex);
+		return -EBUSY;
+	}
 	if (mddev->pers) {
 		if (mddev->ro)
 			set_disk_ro(disk, 0);
@@ -5511,12 +5618,12 @@ static void autorun_devices(int part)
 				"md: cannot allocate memory for md drive.\n");
 			break;
 		}
-		if (mddev_lock(mddev)) 
+		if (mddev_lock(mddev))
 			printk(KERN_WARNING "md: %s locked, cannot run\n",
 			       mdname(mddev));
 		else if (mddev->raid_disks || mddev->major_version
 			 || !list_empty(&mddev->disks)) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"md: %s already running, cannot run %s\n",
 				mdname(mddev), bdevname(rdev0->bdev,b));
 			mddev_unlock(mddev);
@@ -5573,7 +5680,7 @@ static int get_array_info(struct mddev * mddev, void __user * arg)
 		else {
 			working++;
 			if (test_bit(In_sync, &rdev->flags))
-				insync++;	
+				insync++;
 			else
 				spare++;
 		}
@@ -5704,7 +5811,7 @@ static int add_new_disk(struct mddev * mddev, mdu_disk_info_t *info)
 		/* expecting a device which has a superblock */
 		rdev = md_import_device(dev, mddev->major_version, mddev->minor_version);
 		if (IS_ERR(rdev)) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"md: md_import_device returned %ld\n",
 				PTR_ERR(rdev));
 			return PTR_ERR(rdev);
@@ -5716,9 +5823,9 @@ static int add_new_disk(struct mddev * mddev, mdu_disk_info_t *info)
 			err = super_types[mddev->major_version]
 				.load_super(rdev, rdev0, mddev->minor_version);
 			if (err < 0) {
-				printk(KERN_WARNING 
+				printk(KERN_WARNING
 					"md: %s has different UUID to %s\n",
-					bdevname(rdev->bdev,b), 
+					bdevname(rdev->bdev,b),
 					bdevname(rdev0->bdev,b2));
 				export_rdev(rdev);
 				return -EINVAL;
@@ -5738,7 +5845,7 @@ static int add_new_disk(struct mddev * mddev, mdu_disk_info_t *info)
 	if (mddev->pers) {
 		int err;
 		if (!mddev->pers->hot_add_disk) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"%s: personality does not support diskops!\n",
 			       mdname(mddev));
 			return -EINVAL;
@@ -5749,7 +5856,7 @@ static int add_new_disk(struct mddev * mddev, mdu_disk_info_t *info)
 		else
 			rdev = md_import_device(dev, -1, -1);
 		if (IS_ERR(rdev)) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"md: md_import_device returned %ld\n",
 				PTR_ERR(rdev));
 			return PTR_ERR(rdev);
@@ -5826,7 +5933,7 @@ static int add_new_disk(struct mddev * mddev, mdu_disk_info_t *info)
 		int err;
 		rdev = md_import_device(dev, -1, 0);
 		if (IS_ERR(rdev)) {
-			printk(KERN_WARNING 
+			printk(KERN_WARNING
 				"md: error, md_import_device() returned %ld\n",
 				PTR_ERR(rdev));
 			return PTR_ERR(rdev);
@@ -5903,7 +6010,7 @@ static int hot_add_disk(struct mddev * mddev, dev_t dev)
 		return -EINVAL;
 	}
 	if (!mddev->pers->hot_add_disk) {
-		printk(KERN_WARNING 
+		printk(KERN_WARNING
 			"%s: personality does not support diskops!\n",
 			mdname(mddev));
 		return -EINVAL;
@@ -5911,7 +6018,7 @@ static int hot_add_disk(struct mddev * mddev, dev_t dev)
 
 	rdev = md_import_device(dev, -1, 0);
 	if (IS_ERR(rdev)) {
-		printk(KERN_WARNING 
+		printk(KERN_WARNING
 			"md: error, md_import_device() returned %ld\n",
 			PTR_ERR(rdev));
 		return -EINVAL;
@@ -5925,7 +6032,7 @@ static int hot_add_disk(struct mddev * mddev, dev_t dev)
 	rdev->sectors = rdev->sb_start;
 
 	if (test_bit(Faulty, &rdev->flags)) {
-		printk(KERN_WARNING 
+		printk(KERN_WARNING
 			"md: can not hot-add faulty %s disk to %s!\n",
 			bdevname(rdev->bdev,b), mdname(mddev));
 		err = -EINVAL;
@@ -6043,7 +6150,7 @@ static int set_array_info(struct mddev * mddev, mdu_array_info_t *info)
 		    info->major_version >= ARRAY_SIZE(super_types) ||
 		    super_types[info->major_version].name == NULL) {
 			/* maybe try to auto-load a module? */
-			printk(KERN_INFO 
+			printk(KERN_INFO
 				"md: superblock version %d not known\n",
 				info->major_version);
 			return -EINVAL;
@@ -6304,6 +6411,7 @@ static int set_disk_faulty(struct mddev *mddev, dev_t dev)
 	if (!rdev)
 		err =  -ENODEV;
 	else {
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, rdev);
 		if (!test_bit(Faulty, &rdev->flags))
 			err = -EBUSY;
@@ -6405,9 +6513,23 @@ static int md_ioctl(struct block_device *bdev, fmode_t mode,
 		/* need to ensure md_delayed_delete() has completed */
 		flush_workqueue(md_misc_wq);
 
+	if (cmd == STOP_ARRAY || cmd == STOP_ARRAY_RO) {
+		/* Need to flush page cache, and ensure no-one else opens
+		 * and writes
+		 */
+		mutex_lock(&mddev->open_mutex);
+		if (atomic_read(&mddev->openers) > 1) {
+			mutex_unlock(&mddev->open_mutex);
+			err = -EBUSY;
+			goto abort;
+		}
+		set_bit(MD_STILL_CLOSED, &mddev->flags);
+		mutex_unlock(&mddev->open_mutex);
+		sync_blockdev(bdev);
+	}
 	err = mddev_lock(mddev);
 	if (err) {
-		printk(KERN_INFO 
+		printk(KERN_INFO
 			"md: ioctl lock interrupted, reason %d, cmd %d\n",
 			err, cmd);
 		goto abort;
@@ -6658,6 +6780,7 @@ static int md_open(struct block_device *bdev, fmode_t mode)
 
 	err = 0;
 	atomic_inc(&mddev->openers);
+	clear_bit(MD_STILL_CLOSED, &mddev->flags);
 	mutex_unlock(&mddev->open_mutex);
 
 	check_disk_change(bdev);
@@ -6804,6 +6927,13 @@ void md_error(struct mddev *mddev, struct md_rdev *rdev)
 	if (!rdev || test_bit(Faulty, &rdev->flags))
 		return;
 
+#ifdef CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT
+	if (sysctl_use_kernevnt)
+		kernevnt_RaidDegraded(mddev->md_minor,
+				      MAJOR(rdev->bdev->bd_dev),
+				      MINOR(rdev->bdev->bd_dev));
+#endif	/* CONFIG_BUFFALO_USE_MD_DEGRADE_KERNEVNT */
+
 	if (!mddev->pers || !mddev->pers->error_handler)
 		return;
 	mddev->pers->error_handler(mddev,rdev);
@@ -6962,7 +7092,7 @@ static void *md_seq_next(struct seq_file *seq, void *v, loff_t *pos)
 {
 	struct list_head *tmp;
 	struct mddev *next_mddev, *mddev = v;
-	
+
 	++*pos;
 	if (v == (void*)2)
 		return NULL;
@@ -6977,7 +7107,7 @@ static void *md_seq_next(struct seq_file *seq, void *v, loff_t *pos)
 	else {
 		next_mddev = (void*)2;
 		*pos = 0x10000;
-	}		
+	}
 	spin_unlock(&all_mddevs_lock);
 
 	if (v != (void*)1)
@@ -7091,7 +7221,7 @@ static int md_seq_show(struct seq_file *seq, void *v)
 		seq_printf(seq, "\n");
 	}
 	mddev_unlock(mddev);
-	
+
 	return 0;
 }
 
@@ -7325,6 +7455,13 @@ void md_do_sync(struct md_thread *thread)
 	struct md_rdev *rdev;
 	char *desc;
 	struct blk_plug plug;
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	int isRecovery, major=0, minor=0;
+#endif	/* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
+
+#ifdef CONFIG_BUFFALO_PLATFORM
+	set_user_nice(current, 4);
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	/* just incase thread restarts... */
 	if (test_bit(MD_RECOVERY_DONE, &mddev->recovery))
@@ -7339,6 +7476,12 @@ void md_do_sync(struct md_thread *thread)
 			desc = "requested-resync";
 		else
 			desc = "resync";
+#ifdef CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT
+		if (test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_CHECK, &mddev->recovery))
+			kernevnt_RaidScan(mddev->md_minor, 1);
+#endif	/* CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT */
 	} else if (test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))
 		desc = "reshape";
 	else
@@ -7438,6 +7581,31 @@ void md_do_sync(struct md_thread *thread)
 		rcu_read_unlock();
 	}
 
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	if (sysctl_use_kernevnt) {
+		if((test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery)) ||
+		   (!test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_RECOVER, &mddev->recovery))) {
+			struct md_rdev *rdev_tmp;
+			list_for_each_entry(rdev_tmp, &mddev->disks, same_set){
+				if (rdev_tmp->flags != In_sync) {
+					major = MAJOR(rdev_tmp->bdev->bd_dev);
+					minor = MINOR(rdev_tmp->bdev->bd_dev);
+					break;
+				}
+			}
+			isRecovery = !test_bit(MD_RECOVERY_SYNC,
+					       &mddev->recovery);
+			kernevnt_RaidRecovery(mddev->md_minor, 1,
+					      isRecovery, major, minor);
+		}
+		else if ((test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))) {
+			kernevnt_RaidReshape(mddev->md_minor, 1);
+		}
+	}
+#endif	/* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
+
 	printk(KERN_INFO "md: %s of RAID array %s\n", desc, mdname(mddev));
 	printk(KERN_INFO "md: minimum _guaranteed_  speed:"
 		" %d KB/sec/disk.\n", speed_min(mddev));
@@ -7467,7 +7635,7 @@ void md_do_sync(struct md_thread *thread)
 	last_check = 0;
 
 	if (j>2) {
-		printk(KERN_INFO 
+		printk(KERN_INFO
 		       "md: resuming %s of %s from checkpoint.\n",
 		       desc, mdname(mddev));
 		mddev->curr_resync = j;
@@ -7482,6 +7650,13 @@ void md_do_sync(struct md_thread *thread)
 	while (j < max_sectors) {
 		sector_t sectors;
 
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+		if (sysctl_skip_resync || atomic_read(&mddev->skip_resync)) {
+			mddev->curr_resync = max_sectors;
+			break;
+		}
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+
 		skipped = 0;
 
 		if (!test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery) &&
@@ -7593,6 +7768,21 @@ void md_do_sync(struct md_thread *thread)
 	blk_finish_plug(&plug);
 	wait_event(mddev->recovery_wait, !atomic_read(&mddev->recovery_active));
 
+#ifdef CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT
+	if (sysctl_use_kernevnt) {
+		if((test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    !test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery)) ||
+		   (!test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+		    test_bit(MD_RECOVERY_RECOVER, &mddev->recovery)))
+			kernevnt_RaidRecovery(mddev->md_minor, 0,
+					      isRecovery, major, minor);
+                else if((test_bit(MD_RECOVERY_RESHAPE, &mddev->recovery))) {
+			printk("RaidReshape(mddev->md_minor, 0)\n");
+			kernevnt_RaidReshape(mddev->md_minor, 0);
+		}
+	}
+#endif	/* CONFIG_BUFFALO_USE_MD_REBUILD_KERNEVNT */
+
 	/* tell personality that we are finished */
 	mddev->pers->sync_request(mddev, max_sectors, &skipped, 1);
 
@@ -7639,6 +7829,12 @@ void md_do_sync(struct md_thread *thread)
 	} else if (test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery))
 		mddev->resync_min = mddev->curr_resync_completed;
 	mddev->curr_resync = 0;
+#ifdef CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT
+	if (test_bit(MD_RECOVERY_SYNC, &mddev->recovery) &&
+	    test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery) &&
+	    !test_bit(MD_RECOVERY_CHECK, &mddev->recovery))
+		kernevnt_RaidScan(mddev->md_minor, 0);
+#endif	/* CONFIG_BUFFALO_USE_MD_SCAN_KERNEVNT */
 	wake_up(&resync_wait);
 	set_bit(MD_RECOVERY_DONE, &mddev->recovery);
 	md_wakeup_thread(mddev->thread);
@@ -7864,7 +8060,7 @@ void md_check_recovery(struct mddev *mddev)
 								"resync");
 			if (!mddev->sync_thread) {
 				printk(KERN_ERR "%s: could not start resync"
-					" thread...\n", 
+					" thread...\n",
 					mdname(mddev));
 				/* leave the spares where they are, it shouldn't hurt */
 				clear_bit(MD_RECOVERY_RUNNING, &mddev->recovery);
diff --git a/drivers/md/md.h b/drivers/md/md.h
index 653f992b6..58eab11 100644
--- a/drivers/md/md.h
+++ b/drivers/md/md.h
@@ -210,6 +210,9 @@ struct mddev {
 #define MD_CHANGE_CLEAN 1	/* transition to or from 'clean' */
 #define MD_CHANGE_PENDING 2	/* switch from 'clean' to 'active' in progress */
 #define MD_ARRAY_FIRST_USE 3    /* First use of array, needs initialization */
+#define MD_STILL_CLOSED	4	/* If set, then array has not been opened since
+				 * md_ioctl checked on it.
+				 */
 
 	int				suspended;
 	atomic_t			active_io;
@@ -422,6 +425,19 @@ struct mddev {
 	struct work_struct flush_work;
 	struct work_struct event_work;	/* used by dm to report failure event */
 	void (*sync_super)(struct mddev *mddev, struct md_rdev *rdev);
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+#define MAXERR_CNT_DEFAULT		1000
+	atomic_t			maxerr_cnt; /* If rdev->bdev->bd_disk->
+						     * nr_err reaches to
+						     * maxerr_cnt (excepting
+						     * maxerr_cnt is -1),
+						     * disk will be faulty.
+						     */
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	atomic_t			skip_resync;
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
 };
 
 
diff --git a/drivers/md/multipath.c b/drivers/md/multipath.c
index 1642eae..3b40050 100644
--- a/drivers/md/multipath.c
+++ b/drivers/md/multipath.c
@@ -37,7 +37,7 @@ static int multipath_map (struct mpconf *conf)
 	int i, disks = conf->raid_disks;
 
 	/*
-	 * Later we do read balancing on the read side 
+	 * Later we do read balancing on the read side
 	 * now we use the first available disk.
 	 */
 
@@ -97,9 +97,10 @@ static void multipath_end_request(struct bio *bio, int error)
 		 * oops, IO error:
 		 */
 		char b[BDEVNAME_SIZE];
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error (mp_bh->mddev, rdev);
-		printk(KERN_ERR "multipath: %s: rescheduling sector %llu\n", 
-		       bdevname(rdev->bdev,b), 
+		printk(KERN_ERR "multipath: %s: rescheduling sector %llu\n",
+		       bdevname(rdev->bdev,b),
 		       (unsigned long long)bio->bi_sector);
 		multipath_reschedule_retry(mp_bh);
 	} else
@@ -145,12 +146,12 @@ static void multipath_status (struct seq_file *seq, struct mddev *mddev)
 {
 	struct mpconf *conf = mddev->private;
 	int i;
-	
+
 	seq_printf (seq, " [%d/%d] [", conf->raid_disks,
 		    conf->raid_disks - mddev->degraded);
 	for (i = 0; i < conf->raid_disks; i++)
 		seq_printf (seq, "%s",
-			       conf->multipaths[i].rdev && 
+			       conf->multipaths[i].rdev &&
 			       test_bit(In_sync, &conf->multipaths[i].rdev->flags) ? "U" : "_");
 	seq_printf (seq, "]");
 }
@@ -195,7 +196,7 @@ static void multipath_error (struct mddev *mddev, struct md_rdev *rdev)
 		 * first check if this is a queued request for a device
 		 * which has just failed.
 		 */
-		printk(KERN_ALERT 
+		printk(KERN_ALERT
 		       "multipath: only one IO path left and IO error.\n");
 		/* leave it active... it's all we have */
 		return;
@@ -356,7 +357,7 @@ static void multipathd(struct md_thread *thread)
 
 		bio = &mp_bh->bio;
 		bio->bi_sector = mp_bh->master_bio->bi_sector;
-		
+
 		if ((mp_bh->path = multipath_map (conf))<0) {
 			printk(KERN_ALERT "multipath: %s: unrecoverable IO read"
 				" error for block %llu\n",
@@ -413,7 +414,7 @@ static int multipath_run (struct mddev *mddev)
 	conf = kzalloc(sizeof(struct mpconf), GFP_KERNEL);
 	mddev->private = conf;
 	if (!conf) {
-		printk(KERN_ERR 
+		printk(KERN_ERR
 			"multipath: couldn't allocate memory for %s\n",
 			mdname(mddev));
 		goto out;
@@ -422,7 +423,7 @@ static int multipath_run (struct mddev *mddev)
 	conf->multipaths = kzalloc(sizeof(struct multipath_info)*mddev->raid_disks,
 				   GFP_KERNEL);
 	if (!conf->multipaths) {
-		printk(KERN_ERR 
+		printk(KERN_ERR
 			"multipath: couldn't allocate memory for %s\n",
 			mdname(mddev));
 		goto out_free_conf;
@@ -468,7 +469,7 @@ static int multipath_run (struct mddev *mddev)
 	conf->pool = mempool_create_kmalloc_pool(NR_RESERVED_BUFS,
 						 sizeof(struct multipath_bh));
 	if (conf->pool == NULL) {
-		printk(KERN_ERR 
+		printk(KERN_ERR
 			"multipath: couldn't allocate memory for %s\n",
 			mdname(mddev));
 		goto out_free_conf;
@@ -484,7 +485,7 @@ static int multipath_run (struct mddev *mddev)
 		}
 	}
 
-	printk(KERN_INFO 
+	printk(KERN_INFO
 		"multipath: array %s active with %d out of %d IO paths\n",
 		mdname(mddev), conf->raid_disks - mddev->degraded,
 	       mddev->raid_disks);
diff --git a/drivers/md/raid1.c b/drivers/md/raid1.c
index afaa5d4..c7c4117 100644
--- a/drivers/md/raid1.c
+++ b/drivers/md/raid1.c
@@ -300,6 +300,9 @@ static void raid1_end_read_request(struct bio *bio, int error)
 	struct r1bio *r1_bio = bio->bi_private;
 	int mirror;
 	struct r1conf *conf = r1_bio->mddev->private;
+#ifdef CONFIG_BUFFALO_ERRCNT
+	struct md_rdev *rdev;
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 
 	mirror = r1_bio->read_disk;
 	/*
@@ -307,6 +310,22 @@ static void raid1_end_read_request(struct bio *bio, int error)
 	 */
 	update_head_pos(mirror, r1_bio);
 
+#ifdef CONFIG_BUFFALO_ERRCNT
+	rcu_read_lock();
+	rdev = rcu_dereference(conf->mirrors[r1_bio->read_disk].rdev);
+	if (rdev != NULL) {
+		int maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			if (conf->raid_disks - r1_bio->mddev->degraded != 1) {
+				rcu_read_unlock();
+				goto do_degrade;
+			}
+	}
+	rcu_read_unlock();
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+
 	if (uptodate)
 		set_bit(R1BIO_Uptodate, &r1_bio->state);
 	else {
@@ -331,6 +350,10 @@ static void raid1_end_read_request(struct bio *bio, int error)
 		 * oops, read error:
 		 */
 		char b[BDEVNAME_SIZE];
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+do_degrade:
+#endif /* CONFIG_BUFFALO_ERRCNT */
 		printk_ratelimited(
 			KERN_ERR "md/raid1:%s: %s: "
 			"rescheduling sector %llu\n",
@@ -914,7 +937,7 @@ static void unfreeze_array(struct r1conf *conf)
 }
 
 
-/* duplicate the data pages for behind I/O 
+/* duplicate the data pages for behind I/O
  */
 static void alloc_behind_pages(struct bio *bio, struct r1bio *r1_bio)
 {
@@ -1453,7 +1476,7 @@ static int raid1_spare_active(struct mddev *mddev)
 	unsigned long flags;
 
 	/*
-	 * Find all failed disks within the RAID1 configuration 
+	 * Find all failed disks within the RAID1 configuration
 	 * and mark them readable.
 	 * Called under mddev lock, so rcu protection not needed.
 	 */
@@ -1709,7 +1732,10 @@ static int r1_sync_page_io(struct md_rdev *rdev, sector_t sector,
 	}
 	/* need to record an error - either for the block or the device */
 	if (!rdev_set_badblocks(rdev, sector, sectors, 0))
+	{
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(rdev->mddev, rdev);
+	}
 	return 0;
 }
 
@@ -1939,6 +1965,28 @@ static void sync_request_write(struct mddev *mddev, struct r1bio *r1_bio)
 	if (test_bit(MD_RECOVERY_REQUESTED, &mddev->recovery))
 		if (process_checks(r1_bio) < 0)
 			return;
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+	rcu_read_lock();
+	for (i = 0; i < mddev->raid_disks; i++) {
+		struct md_rdev *rdev = rcu_dereference(conf->mirrors[i].rdev);
+		int maxerr_cnt = atomic_read(&mddev->maxerr_cnt);
+
+		if (r1_bio->bios[i]->bi_end_io != end_sync_read ||
+		    rdev == NULL)
+			continue;
+
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			if (!test_bit(Faulty, &conf->mirrors[i].rdev->flags))
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
+				md_error(mddev, conf->mirrors[i].rdev);
+			}
+	}
+	rcu_read_unlock();
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+
 	/*
 	 * schedule writes
 	 */
@@ -2024,7 +2072,10 @@ static void fix_read_error(struct r1conf *conf, int read_disk,
 			/* Cannot read from anywhere - mark it bad */
 			struct md_rdev *rdev = conf->mirrors[read_disk].rdev;
 			if (!rdev_set_badblocks(rdev, sect, s, 0))
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 				md_error(mddev, rdev);
+			}
 			break;
 		}
 		/* write it back and re-read */
@@ -2158,7 +2209,10 @@ static void handle_sync_write_finished(struct r1conf *conf, struct r1bio *r1_bio
 		if (!test_bit(BIO_UPTODATE, &bio->bi_flags) &&
 		    test_bit(R1BIO_WriteError, &r1_bio->state)) {
 			if (!rdev_set_badblocks(rdev, r1_bio->sector, s, 0))
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 				md_error(conf->mddev, rdev);
+			}
 		}
 	}
 	put_buf(r1_bio);
@@ -2181,6 +2235,7 @@ static void handle_write_finished(struct r1conf *conf, struct r1bio *r1_bio)
 			 * errors.
 			 */
 			if (!narrow_write_error(r1_bio, m)) {
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 				md_error(conf->mddev,
 					 conf->mirrors[m].rdev);
 				/* an I/O failed, we can't clear the bitmap */
@@ -2216,9 +2271,25 @@ static void handle_read_error(struct r1conf *conf, struct r1bio *r1_bio)
 		freeze_array(conf, 1);
 		fix_read_error(conf, r1_bio->read_disk,
 			       r1_bio->sector, r1_bio->sectors);
+#ifdef CONFIG_BUFFALO_ERRCNT
+		rdev = conf->mirrors[r1_bio->read_disk].rdev;
+		if (rdev != NULL) {
+			int maxerr_cnt =
+				atomic_read(&mddev->maxerr_cnt);
+			if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+			    maxerr_cnt != -1)
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
+				md_error(mddev, rdev);
+			}
+		}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		unfreeze_array(conf);
 	} else
+	{
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, conf->mirrors[r1_bio->read_disk].rdev);
+	}
 	rdev_dec_pending(conf->mirrors[r1_bio->read_disk].rdev, conf->mddev);
 
 	bio = r1_bio->bios[r1_bio->read_disk];
@@ -2823,9 +2894,9 @@ static int run(struct mddev *mddev)
 		printk(KERN_NOTICE "md/raid1:%s: not clean"
 		       " -- starting background reconstruction\n",
 		       mdname(mddev));
-	printk(KERN_INFO 
+	printk(KERN_INFO
 		"md/raid1:%s: active with %d out of %d mirrors\n",
-		mdname(mddev), mddev->raid_disks - mddev->degraded, 
+		mdname(mddev), mddev->raid_disks - mddev->degraded,
 		mddev->raid_disks);
 
 	/*
diff --git a/drivers/md/raid10.c b/drivers/md/raid10.c
index 0add868..173a146 100644
--- a/drivers/md/raid10.c
+++ b/drivers/md/raid10.c
@@ -465,10 +465,13 @@ static void raid10_end_write_request(struct bio *bio, int error)
 	 */
 	if (!uptodate) {
 		if (repl)
+		{
 			/* Never record new bad blocks to replacement,
 			 * just fail it.
 			 */
+			pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 			md_error(rdev->mddev, rdev);
+		}
 		else {
 			set_bit(WriteErrorSeen,	&rdev->flags);
 			if (!test_and_set_bit(WantReplacement, &rdev->flags))
@@ -2005,7 +2008,10 @@ static void end_sync_write(struct bio *bio, int error)
 
 	if (!uptodate) {
 		if (repl)
+		{
+			pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 			md_error(mddev, rdev);
+		}
 		else {
 			set_bit(WriteErrorSeen, &rdev->flags);
 			if (!test_and_set_bit(WantReplacement, &rdev->flags))
@@ -2346,7 +2352,10 @@ static int r10_sync_page_io(struct md_rdev *rdev, sector_t sector,
 	}
 	/* need to record an error - either for the block or the device */
 	if (!rdev_set_badblocks(rdev, sector, sectors, 0))
+	{
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(rdev->mddev, rdev);
+	}
 	return 0;
 }
 
@@ -2390,6 +2399,7 @@ static void fix_read_error(struct r10conf *conf, struct mddev *mddev, struct r10
 		printk(KERN_NOTICE
 		       "md/raid10:%s: %s: Failing raid device\n",
 		       mdname(mddev), b);
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, conf->mirrors[d].rdev);
 		r10_bio->devs[r10_bio->read_slot].bio = IO_BLOCKED;
 		return;
@@ -2447,6 +2457,7 @@ static void fix_read_error(struct r10conf *conf, struct mddev *mddev, struct r10
 				    r10_bio->devs[r10_bio->read_slot].addr
 				    + sect,
 				    s, 0)) {
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 				md_error(mddev, rdev);
 				r10_bio->devs[r10_bio->read_slot].bio
 					= IO_BLOCKED;
@@ -2736,7 +2747,10 @@ static void handle_write_completed(struct r10conf *conf, struct r10bio *r10_bio)
 					    rdev,
 					    r10_bio->devs[m].addr,
 					    r10_bio->sectors, 0))
+				{
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(conf->mddev, rdev);
+				}
 			}
 			rdev = conf->mirrors[dev].replacement;
 			if (r10_bio->devs[m].repl_bio == NULL)
@@ -2752,7 +2766,10 @@ static void handle_write_completed(struct r10conf *conf, struct r10bio *r10_bio)
 					    rdev,
 					    r10_bio->devs[m].addr,
 					    r10_bio->sectors, 0))
+				{
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(conf->mddev, rdev);
+				}
 			}
 		}
 		put_buf(r10_bio);
@@ -2770,6 +2787,7 @@ static void handle_write_completed(struct r10conf *conf, struct r10bio *r10_bio)
 			} else if (bio != NULL &&
 				   !test_bit(BIO_UPTODATE, &bio->bi_flags)) {
 				if (!narrow_write_error(r10_bio, m)) {
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(conf->mddev, rdev);
 					set_bit(R10BIO_Degraded,
 						&r10_bio->state);
@@ -4641,6 +4659,7 @@ static void end_reshape_write(struct bio *bio, int error)
 
 	if (!uptodate) {
 		/* FIXME should record badblock */
+		pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 		md_error(mddev, rdev);
 	}
 
diff --git a/drivers/md/raid5.c b/drivers/md/raid5.c
index 7e8ce61..b01647c 100644
--- a/drivers/md/raid5.c
+++ b/drivers/md/raid5.c
@@ -1785,6 +1785,18 @@ static void raid5_end_read_request(struct bio * bi, int error)
 		s = sh->sector + rdev->new_data_offset;
 	else
 		s = sh->sector + rdev->data_offset;
+
+#ifdef CONFIG_BUFFALO_ERRCNT
+	if (!(conf->mddev->degraded)) {
+		int maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+
+		rdev = conf->disks[i].rdev;
+		if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+		    maxerr_cnt != -1)
+			uptodate = 0;
+	}
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+
 	if (uptodate) {
 		set_bit(R5_UPTODATE, &sh->dev[i].flags);
 		if (test_bit(R5_ReadError, &sh->dev[i].flags)) {
@@ -1848,12 +1860,41 @@ static void raid5_end_read_request(struct bio * bi, int error)
 			       mdname(conf->mddev), bdn);
 		else
 			retry = 1;
+#ifdef CONFIG_BUFFALO_ERRCNT
+		if (retry) {
+			int maxerr_cnt;
+
+			if (test_bit(R5_ReadNoMerge, &sh->dev[i].flags)) {
+				set_bit(R5_ReadError, &sh->dev[i].flags);
+				clear_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+			} else
+				set_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+
+			printk("debug: Read Error dev[%d]: sector %llu(sh->sector=%llu)\n",
+			       i, (unsigned long long)sh->dev[i].sector,
+			       (unsigned long long)sh->sector);
+			/*
+			 * Don't forget the bracket {} put in the outside of
+			 * this macro, if you port this code to another
+			 * version of Linux.
+			 */
+			maxerr_cnt = atomic_read(&conf->mddev->maxerr_cnt);
+			rdev = conf->disks[i].rdev;
+			if (atomic_read(&rdev->bdev->bd_disk->nr_errs) > maxerr_cnt &&
+			    maxerr_cnt != -1)
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
+				md_error(conf->mddev, conf->disks[i].rdev);
+			}
+		}
+#else	/* CONFIG_BUFFALO_ERRCNT */
 		if (retry)
 			if (test_bit(R5_ReadNoMerge, &sh->dev[i].flags)) {
 				set_bit(R5_ReadError, &sh->dev[i].flags);
 				clear_bit(R5_ReadNoMerge, &sh->dev[i].flags);
 			} else
 				set_bit(R5_ReadNoMerge, &sh->dev[i].flags);
+#endif	/* CONFIG_BUFFALO_ERRCNT */
 		else {
 			clear_bit(R5_ReadError, &sh->dev[i].flags);
 			clear_bit(R5_ReWrite, &sh->dev[i].flags);
@@ -1861,7 +1902,10 @@ static void raid5_end_read_request(struct bio * bi, int error)
 			      && test_bit(In_sync, &rdev->flags)
 			      && rdev_set_badblocks(
 				      rdev, sh->sector, STRIPE_SECTORS, 0)))
+			{
+				pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 				md_error(conf->mddev, rdev);
+			}
 		}
 	}
 	rdev_dec_pending(rdev, conf->mddev);
@@ -1909,7 +1953,10 @@ static void raid5_end_write_request(struct bio *bi, int error)
 
 	if (replacement) {
 		if (!uptodate)
+		{
+			pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 			md_error(conf->mddev, rdev);
+		}
 		else if (is_badblock(rdev, sh->sector,
 				     STRIPE_SECTORS,
 				     &first_bad, &bad_sectors))
@@ -1942,7 +1989,7 @@ static void raid5_end_write_request(struct bio *bi, int error)
 }
 
 static sector_t compute_blocknr(struct stripe_head *sh, int i, int previous);
-	
+
 static void raid5_build_block(struct stripe_head *sh, int i, int previous)
 {
 	struct r5dev *dev = &sh->dev[i];
@@ -2522,7 +2569,10 @@ handle_failed_stripe(struct r5conf *conf, struct stripe_head *sh,
 					    rdev,
 					    sh->sector,
 					    STRIPE_SECTORS, 0))
+				{
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(conf->mddev, rdev);
+				}
 				rdev_dec_pending(rdev, conf->mddev);
 			}
 		}
@@ -3774,7 +3824,10 @@ finish:
 				rdev = conf->disks[i].rdev;
 				if (!rdev_set_badblocks(rdev, sh->sector,
 							STRIPE_SECTORS, 0))
+				{
+					pr_err("md_error() happened at %s (%d)",__FUNCTION__, __LINE__);
 					md_error(conf->mddev, rdev);
+				}
 				rdev_dec_pending(rdev, conf->mddev);
 			}
 			if (test_and_clear_bit(R5_MadeGood, &dev->flags)) {
@@ -4368,7 +4421,7 @@ static void make_request(struct mddev *mddev, struct bio * bi)
 						  previous,
 						  &dd_idx, NULL);
 		pr_debug("raid456: make_request, sector %llu logical %llu\n",
-			(unsigned long long)new_sector, 
+			(unsigned long long)new_sector,
 			(unsigned long long)logical_sector);
 
 		sh = get_active_stripe(conf, new_sector, previous,
@@ -5388,7 +5441,7 @@ static int only_parity(int raid_disk, int algo, int raid_disks, int max_degraded
 			return 1;
 		break;
 	case ALGORITHM_PARITY_0_6:
-		if (raid_disk == 0 || 
+		if (raid_disk == 0 ||
 		    raid_disk == raid_disks - 1)
 			return 1;
 		break;
diff --git a/drivers/mtd/nand/al/al_nand.c b/drivers/mtd/nand/al/al_nand.c
index da2cc83..198d9d5 100644
--- a/drivers/mtd/nand/al/al_nand.c
+++ b/drivers/mtd/nand/al/al_nand.c
@@ -505,8 +505,11 @@ int ecc_read_page(struct mtd_info *mtd, struct nand_chip *chip,
 			 * layer, don't update the statistics in this case */
 			chip->read_buf(mtd, nand->oob, mtd->oobsize);
 
-			if (is_empty_oob(nand->oob, mtd->oobsize))
+			if (is_empty_oob(nand->oob, mtd->oobsize)){
 				uncorr_err = false;
+				memset(buf, 0xff, mtd->writesize);
+				corr_err_count++;
+			}
 		}
 
 		if (uncorr_err) {
diff --git a/drivers/net/ethernet/al/al_eth.c b/drivers/net/ethernet/al/al_eth.c
index 7dfec65..4d92001 100644
--- a/drivers/net/ethernet/al/al_eth.c
+++ b/drivers/net/ethernet/al/al_eth.c
@@ -155,6 +155,12 @@ al_mdio_read(struct mii_bus *bp, int mii_id, int reg)
 			rc = al_eth_mdio_read(&adapter->hal_adapter, adapter->phy_addr,
 				((reg & AL_ETH_MDIO_C45_DEV_MASK) >> AL_ETH_MDIO_C45_DEV_SHIFT),
 				(reg & AL_ETH_MDIO_C45_REG_MASK), &value);
+		} else if ((adapter->phy_if == AL_ETH_BOARD_PHY_IF_XMDIO) && (mii_id & 0x8000)) {
+			/* There is only 16bit variable from user-space,
+			    so we used bit 32 of PHY ID to mark the C45 access */ 
+			al_dbg("%s [c45]: dev %x reg %x val %x\n", __func__, (mii_id & 0x1f), reg, value);
+			rc = al_eth_mdio_read(&adapter->hal_adapter, adapter->phy_addr,
+				(mii_id & 0x1f), reg, &value);
 		} else {
 			rc = al_eth_mdio_read(&adapter->hal_adapter, adapter->phy_addr,
 					      MDIO_DEVAD_NONE, reg, &value);
@@ -192,6 +198,12 @@ al_mdio_write(struct mii_bus *bp, int mii_id, int reg, u16 val)
 			rc = al_eth_mdio_write(&adapter->hal_adapter, adapter->phy_addr,
 				((reg & AL_ETH_MDIO_C45_DEV_MASK) >> AL_ETH_MDIO_C45_DEV_SHIFT),
 				(reg & AL_ETH_MDIO_C45_REG_MASK), val);
+		} else if ((adapter->phy_if == AL_ETH_BOARD_PHY_IF_XMDIO) && (mii_id & 0x8000)) {
+			/* There is only 16bit variable from user-space,
+			    so we used bit 32 of PHY ID to mark the C45 access */ 
+			al_dbg("%s [c45]: dev %x reg %x val %x\n", __func__, (mii_id & 0x1f), reg, val);
+			rc = al_eth_mdio_write(&adapter->hal_adapter, adapter->phy_addr,
+				(mii_id & 0x1f), reg, val);
 		} else {
 			rc = al_eth_mdio_write(&adapter->hal_adapter, adapter->phy_addr,
 				       MDIO_DEVAD_NONE, reg, val);
@@ -220,7 +232,7 @@ static int al_eth_ioctl(struct net_device *netdev, struct ifreq *ifr, int cmd)
 	struct mii_ioctl_data *mdio = if_mii(ifr);
 	struct phy_device *phydev;
 
-	netdev_info(adapter->netdev, "ioctl: phy id 0x%x, reg 0x%x, val_in 0x%x\n",
+	al_dbg("ioctl: phy id 0x%x, reg 0x%x, val_in 0x%x\n",
 			mdio->phy_id, mdio->reg_num, mdio->val_in);
 
 	if (adapter->mdio_bus) {
@@ -260,7 +272,7 @@ static void al_eth_adjust_link(struct net_device *dev)
 			case SPEED_10:
 				mac_mode_needed = (adapter->mac_mode == AL_ETH_MAC_MODE_RGMII) ?
 							AL_ETH_MAC_MODE_RGMII:
-							AL_ETH_MAC_MODE_SGMII;
+							AL_ETH_MAC_MODE_10GbE_Serial; //AL_ETH_MAC_MODE_SGMII;
 				break;
 			case SPEED_10000:
 			case SPEED_5000:
@@ -359,6 +371,9 @@ static int al_eth_phy_init(struct al_eth_adapter *adapter)
 
 	/* Mask with MAC supported features. */
 	phydev->supported &= (PHY_GBIT_FEATURES |
+#ifdef CONFIG_BUFFALO_PLATFORM
+				SUPPORTED_10000baseT_Full |
+#endif /* CONFIG_BUFFALO_PLATFORM */
 				SUPPORTED_Pause |
 				SUPPORTED_Asym_Pause);
 
@@ -401,6 +416,7 @@ static int al_eth_mdiobus_setup(struct al_eth_adapter *adapter)
 	adapter->mdio_bus->irq = kmalloc(sizeof(int) * PHY_MAX_ADDR, GFP_KERNEL);
 	if (!adapter->mdio_bus->irq) {
 		mdiobus_free(adapter->mdio_bus);
+		adapter->mdio_bus = NULL;
 		return -ENOMEM;
 	}
 
@@ -413,6 +429,7 @@ static int al_eth_mdiobus_setup(struct al_eth_adapter *adapter)
 		if (i) {
 			netdev_warn(adapter->netdev, "mdiobus_reg failed (0x%x)\n", i);
 			mdiobus_free(adapter->mdio_bus);
+			adapter->mdio_bus = NULL;
 			return i;
 		}
 
@@ -423,6 +440,7 @@ static int al_eth_mdiobus_setup(struct al_eth_adapter *adapter)
 		if (i) {
 			netdev_warn(adapter->netdev, "mdiobus_reg failed (0x%x)\n", i);
 			mdiobus_free(adapter->mdio_bus);
+			adapter->mdio_bus = NULL;
 			return i;
 		}
 
@@ -449,6 +467,7 @@ error:
 	mdiobus_unregister(adapter->mdio_bus);
 	kfree(adapter->mdio_bus->irq);
 	mdiobus_free(adapter->mdio_bus);
+	adapter->mdio_bus = NULL;
 	return -ENODEV;
 }
 
@@ -466,6 +485,8 @@ static void al_eth_mdiobus_teardown(struct al_eth_adapter *adapter)
 	kfree(adapter->mdio_bus->irq);
 	mdiobus_free(adapter->mdio_bus);
 	phy_device_free(adapter->phydev);
+	adapter->phydev = NULL;
+	adapter->mdio_bus = NULL;
 }
 
 static void al_eth_tx_timeout(struct net_device *dev)
@@ -3311,7 +3332,7 @@ static void al_eth_lm_config(struct al_eth_adapter *adapter)
 
 }
 
-#define AQUANTIA_AQR105_ID			0x3a1b4a2
+#define AQUANTIA_AQR105_ID			0x3a1b4a3
 
 static int al_eth_aq_phy_fixup(struct phy_device *phydev)
 {
diff --git a/drivers/net/ethernet/al/al_eth_sysfs.c b/drivers/net/ethernet/al/al_eth_sysfs.c
index 49ed217..5143e4d 100644
--- a/drivers/net/ethernet/al/al_eth_sysfs.c
+++ b/drivers/net/ethernet/al/al_eth_sysfs.c
@@ -201,6 +201,9 @@ static ssize_t al_eth_store_serdes_tx_param(struct device *dev,
 	unsigned long param;
 	int err;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!adapter->lm_context.serdes_obj) return -ENOSYS;
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	err = kstrtoul(buf, 16, &param);
 	if (err < 0)
 		return err;
@@ -228,6 +231,9 @@ static ssize_t al_eth_show_serdes_tx_param(struct device *dev,
 	struct al_serdes_adv_tx_params	tx_params;
 	uint8_t val;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!adapter->lm_context.serdes_obj) return -ENOSYS;
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	al_eth_lm_static_parameters_get(&adapter->lm_context,
 					&tx_params,
 					NULL);
@@ -248,6 +254,9 @@ static ssize_t al_eth_store_serdes_rx_param(struct device *dev,
 	unsigned long param;
 	int err;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!adapter->lm_context.serdes_obj) return -ENOSYS;
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	err = kstrtoul(buf, 16, &param);
 	if (err < 0)
 		return err;
@@ -275,6 +284,9 @@ static ssize_t al_eth_show_serdes_rx_param(struct device *dev,
 	struct al_serdes_adv_rx_params	rx_params;
 	uint8_t val;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (!adapter->lm_context.serdes_obj) return -ENOSYS;
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	al_eth_lm_static_parameters_get(&adapter->lm_context,
 					NULL,
 					&rx_params);
diff --git a/drivers/net/phy/aquantia.c b/drivers/net/phy/aquantia.c
index 14d2b64..d2aff83 100644
--- a/drivers/net/phy/aquantia.c
+++ b/drivers/net/phy/aquantia.c
@@ -6,14 +6,20 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation.
  */
-
 #include <linux/module.h>
 #include <linux/phy.h>
 #include <linux/delay.h>
 #include <linux/timer.h>
 #include <linux/of.h>
+#include <linux/netdevice.h>
+#include <linux/etherdevice.h>
 
-#define AQUANTIA_AQR105_ID			0x3a1b4a2
+#define AQUANTIA_AQR105_ID			0x3a1b4a3
+#define AQUANTIA_AQR106_ID			0x3a1b4d0
+#define AQUANTIA_AQR107_ID			0x3a1b4e2
+#define AQUANTIA_AQR111_ID			0x3a1b7e2
+#define AQUANTIA_AQR112_ID			0x3a1b792
+#define AQUANTIA_AQR113_ID			0x31c31c42
 
 #define AQ_PHY_ADDR(device, reg) (MII_ADDR_C45 | (device * 0x10000) | reg)
 
@@ -25,26 +31,232 @@
 #define AQ_STATUS_SPEED_5000			0xa
 #define AQ_STATUS_SPEED_2500			0x8
 #define AQ_STATUS_SPEED_1000			0x4
-#define AQ_STATUS_SPEED_100			0x3
+#define AQ_STATUS_SPEED_100			0x2
 
 #define AQ_CONNECTION_STATUS			AQ_PHY_ADDR(0x7, 0xc810)
 #define AQ_CONNECTION_STATUS_LINK_MASK		0x3e00
 #define AQ_CONNECTION_STATUS_LINK_UP		0x800
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+/* Supports LED provitioning via MDIO bus */
+#define AQ_GLOBAL_LED_PROVISIONING1		AQ_PHY_ADDR(0x1e, 0xc430)
+#define AQ_GLOBAL_LED_PROVISIONING2		AQ_PHY_ADDR(0x1e, 0xc431)
+#define AQ_GLOBAL_LED_PROVISIONING3		AQ_PHY_ADDR(0x1e, 0xc432)
+#define AQ_GLOBAL_LED_5G			(1 << 15)	/* 5Gbps */
+#define AQ_GLOBAL_LED_2_5G			(1 << 14)	/* 2.5Gbps */
+#define AQ_GLOBAL_LED_ON			(1 << 8)
+#define AQ_GLOBAL_LED_10G			(1 << 7)
+#define AQ_GLOBAL_LED_1G			(1 << 6)
+#define AQ_GLOBAL_LED_100M			(1 << 5)
+#define AQ_GLOBAL_LED_CONNECTING		(1 << 4)
+#define AQ_GLOBAL_LED_TOGGLE_RX			(1 << 3)
+#define AQ_GLOBAL_LED_TOGGLE_TX			(1 << 2)
+#define AQ_GLOBAL_LED_ACT_STRETCH_100ms		(3 << 0)
+#define AQ_GLOBAL_LED_ACT_STRETCH_60ms		(2 << 0)
+#define AQ_GLOBAL_LED_ACT_STRETCH_28ms		(1 << 0)
+#define AQ_GLOBAL_LED_ACT_STRETCH_none		(0 << 0)
+/* Buffalo TSx010 board specific settings: */
+#define AQ_GLOBAL_LED_OFF	(AQ_GLOBAL_LED_ON)  /*negate*/
+#define AQ_GLOBAL_LED1_ON	(AQ_GLOBAL_LED_10G | AQ_GLOBAL_LED_1G)
+#define AQ_GLOBAL_LED2_ON	(AQ_GLOBAL_LED_10G | AQ_GLOBAL_LED_100M)
+#define AQ_GLOBAL_LED3_ON	(AQ_GLOBAL_LED_1G  | AQ_GLOBAL_LED_100M)
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+
+//#define AQ11X_INTR_ENABLE			0x12
+//#define AQ11X_INTR_STATUS			0x13
+//#define AQ11X_WOL_ENABLE			0x01
+//#define AQ11X_LOC_MAC_ADDR_0_15_OFFSET		0xC339
+//#define AQ11X_LOC_MAC_ADDR_16_31_OFFSET		0xC33A
+//#define AQ11X_LOC_MAC_ADDR_32_47_OFFSET		0xC33B
+
+
+static int aq11x_set_wol(struct phy_device *phydev,
+			  struct ethtool_wolinfo *wol)
+{
+	struct net_device *ndev = phydev->attached_dev;
+	const u8 *mac;
+	int ret=0;
+	u32 value;
+
+	if (!ndev)
+		return -ENODEV;
+
+	if (wol->wolopts & WAKE_MAGIC) {
+		mac = (const u8 *) ndev->dev_addr;
+
+		if (!is_valid_ether_addr(mac))
+			return -EFAULT;
+		
+		phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xC339), mac[1]<<8 | mac[0]);
+		phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xC33A), mac[3]<<8 | mac[2]);
+		phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xC33B), mac[5]<<8 | mac[4]);
+		
+		phy_write(phydev, AQ_PHY_ADDR(0x7, 0xc400), 0x9040);
+		phy_write(phydev, AQ_PHY_ADDR(0x7, 0x20), 0x1);
+		phy_write(phydev, AQ_PHY_ADDR(0x7, 0xc410), 0x250);
+		phy_write(phydev, AQ_PHY_ADDR(0x1d, 0xc356), 0x1);
+		phy_write(phydev, AQ_PHY_ADDR(0x1e, 0x31b), 0x0b);
+		phy_write(phydev, AQ_PHY_ADDR(0x1e, 0x31c), 0x0b);
+		phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xc357), 0x8000);
+		phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xF420), 0x30);
+		//phy_write(phydev, AQ_PHY_ADDR(0x1D, 0xc357), 0x8000);
+		phy_write(phydev, AQ_PHY_ADDR(0x1E, 0xFF00), 0x1);
+		phy_write(phydev, AQ_PHY_ADDR(0x1e, 0xff01), 0x800);
+		phy_write(phydev, AQ_PHY_ADDR(0x7, 0x0), 0x3200);
+		while( (value = phy_read(phydev, AQ_PHY_ADDR(0x7,0xc812))) & 0x1);
+		value = phy_read(phydev, AQ_PHY_ADDR(0x1d,0xec20));
+	} else {
+		// BTS#271565#note-10
+		// don't operate when wol already disable.
+		value = phy_read(phydev, AQ_PHY_ADDR(0x7,0xc410));
+		if( value != 0){
+			phy_write(phydev, AQ_PHY_ADDR(0x7, 0xc410), 0);
+			phy_write(phydev, AQ_PHY_ADDR(0x7, 0x0), 0xb200);
+		}
+	}
+
+	return ret;
+}
+
+static void aq11x_get_wol(struct phy_device *phydev,
+			   struct ethtool_wolinfo *wol)
+{
+	u32 value;
+
+	wol->supported = WAKE_MAGIC;
+	wol->wolopts = 0;
+
+	value = phy_read(phydev, AQ_PHY_ADDR(0x7, 0xc410));
+	if (value & 0x40)
+		wol->wolopts |= WAKE_MAGIC;
+}
+
+
+
 static int aq_config_init(struct phy_device *phydev)
 {
-	phydev->supported = ADVERTISED_1000baseT_Full;
-	phydev->advertising = ADVERTISED_1000baseT_Full;
+	phydev->supported = ADVERTISED_10000baseT_Full | ADVERTISED_1000baseT_Full;
+	phydev->advertising = ADVERTISED_10000baseT_Full | ADVERTISED_1000baseT_Full;
+#ifdef CONFIG_BUFFALO_PLATFORM
+	phydev->supported |= ADVERTISED_100baseT_Full;
+	phydev->advertising |= ADVERTISED_100baseT_Full;
+#endif /* CONFIG_BUFFALO_PLATFORM */
 	phydev->state = PHY_NOLINK;
 	phydev->autoneg = AUTONEG_ENABLE;
 
 	return 0;
 }
 
+static int aq_config_init11x(struct phy_device *phydev)
+{
+	phy_write(phydev, AQ_PHY_ADDR(0x1e, 0xc006), 0x4000);
+
+	phydev->supported = ADVERTISED_10000baseT_Full | ADVERTISED_1000baseT_Full | ADVERTISED_100baseT_Full;
+	phydev->advertising = ADVERTISED_10000baseT_Full | ADVERTISED_1000baseT_Full | ADVERTISED_100baseT_Full;
+	phydev->state = PHY_NOLINK;
+	phydev->autoneg = AUTONEG_ENABLE;
+
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x0000);
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
+	
+	return 0;
+}
+
+#ifdef CONFIG_BUFFALO_PLATFORM
+static inline void aq_update_led(struct phy_device *phydev)
+{
+	const unsigned int s = AQ_GLOBAL_LED_ACT_STRETCH_100ms;
+
+	if (!phydev->link) {
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, AQ_GLOBAL_LED_OFF|s);
+	} else
+	switch (phydev->speed) {
+	case SPEED_10000:
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, AQ_GLOBAL_LED3_ON|s);
+	    break;
+	case SPEED_1000:
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, AQ_GLOBAL_LED2_ON|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, AQ_GLOBAL_LED_OFF|s);
+	    break;
+	case SPEED_5000:
+	case SPEED_2500:
+	default:
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, AQ_GLOBAL_LED1_ON|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, AQ_GLOBAL_LED_OFF|s);
+	    phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, AQ_GLOBAL_LED_OFF|s);
+	    break;
+	}
+}
+#endif /* CONFIG_BUFFALO_PLATFORM */
 static int aq_read_status(struct phy_device *phydev)
 {
 	int connection_status;
 	int an_vendor_status;
+#ifdef CONFIG_BUFFALO_PLATFORM
+	int link = phydev->link;
+	int speed = phydev->speed;
+#endif /* CONFIG_BUFFALO_PLATFORM */
+
+	connection_status = phy_read(phydev, AQ_CONNECTION_STATUS);
+	if ((connection_status & AQ_CONNECTION_STATUS_LINK_MASK) != AQ_CONNECTION_STATUS_LINK_UP)
+		goto no_link;
+
+	an_vendor_status = phy_read(phydev, AQ_AN_VENDOR_STATUS);
+
+	switch (an_vendor_status & AQ_AN_VENDOR_STATUS_SPEED_MASK) {
+	case AQ_STATUS_SPEED_10000:
+		phydev->speed = SPEED_10000;
+		break;
+	case AQ_STATUS_SPEED_5000:
+		phydev->speed = SPEED_5000;
+		break;
+	case AQ_STATUS_SPEED_2500:
+		phydev->speed = SPEED_2500;
+		break;
+	case AQ_STATUS_SPEED_1000:
+		phydev->speed = SPEED_1000;
+		break;
+	case AQ_STATUS_SPEED_100:
+		phydev->speed = SPEED_100;
+		break;
+	default:
+		phydev->speed = SPEED_10;
+	}
+
+	if ((an_vendor_status & AQ_AN_VENDOR_STATUS_DUPLEX_MASK) != 0) {
+		phydev->duplex = DUPLEX_FULL;
+	} else {
+		phydev->duplex = DUPLEX_HALF;
+	}
+
+	phydev->link = 1;
+#ifdef CONFIG_BUFFALO_PLATFORM
+	goto update_led;
+#else /*CONFIG_BUFFALO_PLATFORM*/
+	return 0;
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+
+no_link:
+	phydev->link = 0;
+#ifdef CONFIG_BUFFALO_PLATFORM
+update_led:
+	if (link != phydev->link || speed != phydev->speed) {
+		aq_update_led(phydev);
+	}
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	return 0;
+}
+
+static int aq_read_status11x(struct phy_device *phydev)
+{
+	int connection_status;
+	int an_vendor_status;
 
 	connection_status = phy_read(phydev, AQ_CONNECTION_STATUS);
 	if ((connection_status & AQ_CONNECTION_STATUS_LINK_MASK) != AQ_CONNECTION_STATUS_LINK_UP)
@@ -55,21 +267,39 @@ static int aq_read_status(struct phy_device *phydev)
 	switch (an_vendor_status & AQ_AN_VENDOR_STATUS_SPEED_MASK) {
 	case AQ_STATUS_SPEED_10000:
 		phydev->speed = SPEED_10000;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0xc08e);
 		break;
 	case AQ_STATUS_SPEED_5000:
 		phydev->speed = SPEED_5000;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x804e);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 		break;
 	case AQ_STATUS_SPEED_2500:
 		phydev->speed = SPEED_2500;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x404e);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 		break;
 	case AQ_STATUS_SPEED_1000:
 		phydev->speed = SPEED_1000;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x014e);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 		break;
 	case AQ_STATUS_SPEED_100:
 		phydev->speed = SPEED_100;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x012e);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 		break;
 	default:
 		phydev->speed = SPEED_10;
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+		phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 	}
 
 	if ((an_vendor_status & AQ_AN_VENDOR_STATUS_DUPLEX_MASK) != 0) {
@@ -78,33 +308,141 @@ static int aq_read_status(struct phy_device *phydev)
 		phydev->duplex = DUPLEX_HALF;
 	}
 
+	phydev->state = PHY_RUNNING;
 	phydev->link = 1;
+
 	return 0;
 
 no_link:
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING1, 0x0000);
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING2, 0x0000);
+	phy_write(phydev, AQ_GLOBAL_LED_PROVISIONING3, 0x0000);
 	phydev->link = 0;
 	return 0;
 }
 
-static int aq_match_phy_device(struct phy_device *phydev)
+static int aq_match_phy_device105(struct phy_device *phydev)
 {
 	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR105_ID)
 		return 1;
-
+	return 0;
+}
+static int aq_match_phy_device106(struct phy_device *phydev)
+{
+	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR106_ID)
+		return 1;
+	return 0;
+}
+static int aq_match_phy_device107(struct phy_device *phydev)
+{
+	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR107_ID)
+		return 1;
+	return 0;
+}
+static int aq_match_phy_device111(struct phy_device *phydev)
+{
+	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR111_ID)
+		return 1;
+	return 0;
+}
+static int aq_match_phy_device112(struct phy_device *phydev)
+{
+	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR112_ID)
+		return 1;
+	return 0;
+}
+static int aq_match_phy_device113(struct phy_device *phydev)
+{
+	if (phydev->c45_ids.device_ids[4] == AQUANTIA_AQR113_ID)
+		return 1;
 	return 0;
 }
 
 static struct phy_driver aq_driver[] = {
 {
-	.phy_id		= AQUANTIA_AQR105_ID,
+	.phy_id			= AQUANTIA_AQR105_ID,
+	.phy_id_mask	= 0xffffffff,
+	.name			= "Aquantia AQR105 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
+	.config_init	= aq_config_init,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	.read_status	= aq_read_status,
+	.match_phy_device = aq_match_phy_device105,
+	.driver			= { .owner = THIS_MODULE },
+},
+{
+	.phy_id			= AQUANTIA_AQR106_ID,
 	.phy_id_mask	= 0xffffffff,
-	.name		= "Aquantia AQR105 phy driver",
-	.flags		= PHY_HAS_INTERRUPT,
+	.name			= "Aquantia AQR106 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
 	.config_init	= aq_config_init,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
 	.read_status	= aq_read_status,
-	.match_phy_device = aq_match_phy_device,
-	.driver		= { .owner = THIS_MODULE },
-}};
+	.match_phy_device = aq_match_phy_device106,
+	.driver			= { .owner = THIS_MODULE },
+},
+{
+	.phy_id			= AQUANTIA_AQR107_ID,
+	.phy_id_mask	= 0xffffffff,
+	.name			= "Aquantia AQR107 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
+	.config_init	= aq_config_init,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	.read_status	= aq_read_status,
+	.match_phy_device = aq_match_phy_device107,
+	.driver			= { .owner = THIS_MODULE },
+},
+{
+	.phy_id			= AQUANTIA_AQR111_ID,
+	.phy_id_mask	= 0xffffffff,
+	.name			= "Aquantia AQR111 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
+	.config_init	= aq_config_init11x,
+	.set_wol		= aq11x_set_wol,
+	.get_wol		= aq11x_get_wol,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	.read_status	= aq_read_status11x,
+	.match_phy_device = aq_match_phy_device111,
+	.driver			= { .owner = THIS_MODULE },
+},
+{
+	.phy_id			= AQUANTIA_AQR112_ID,
+	.phy_id_mask	= 0xffffffff,
+	.name			= "Aquantia AQR112 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
+	.config_init	= aq_config_init11x,
+	.set_wol		= aq11x_set_wol,
+	.get_wol		= aq11x_get_wol,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	.read_status	= aq_read_status11x,
+	.match_phy_device = aq_match_phy_device112,
+	.driver			= { .owner = THIS_MODULE },
+},
+{
+	.phy_id			= AQUANTIA_AQR113_ID,
+	.phy_id_mask	= 0xffffffff,
+	.name			= "Aquantia AQR113 phy driver",
+	.flags			= PHY_HAS_INTERRUPT,
+	.config_init	= aq_config_init,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	.config_aneg	= genphy_config_aneg,
+#endif /*CONFIG_BUFFALO_PLATFORM*/
+	.read_status	= aq_read_status,
+	.match_phy_device = aq_match_phy_device113,
+	.driver			= { .owner = THIS_MODULE },
+
+}
+};
 
 static int __init aq_init(void)
 {
@@ -120,4 +458,4 @@ static void __exit aq_exit(void)
 }
 module_exit(aq_exit);
 
-MODULE_LICENSE("GPL");
+MODULE_LICENSE("GPL");
\ No newline at end of file
diff --git a/drivers/net/phy/at803x.c b/drivers/net/phy/at803x.c
index d03548e..7bdc610 100644
--- a/drivers/net/phy/at803x.c
+++ b/drivers/net/phy/at803x.c
@@ -150,13 +150,71 @@ static int at803x_config_init(struct phy_device *phydev)
 	return 0;
 }
 
+#ifdef CONFIG_BUFFALO_PLATFORM //for BTS#204035
+#define BMCR_PDOWN BIT(11)
+static int ar8035_phy_fixup(struct phy_device *dev)
+{
+	u16 val;
+printk("ar8035 found\n");
+	/* Ar803x phy SmartEEE feature cause link status generates glitch,
+	 * which cause ethernet link down/up issue, so disable SmartEEE
+	 */
+	phy_write(dev, 0xd, 0x3);
+	phy_write(dev, 0xe, 0x805d);
+	phy_write(dev, 0xd, 0x4003);
+
+	val = phy_read(dev, 0xe);
+	phy_write(dev, 0xe, val & ~(1 << 8));
+
+	/* To enable AR8031 output a 125MHz clk from CLK_25M */
+	phy_write(dev, 0xd, 0x7);
+	phy_write(dev, 0xe, 0x8016);
+	phy_write(dev, 0xd, 0x4007);
+
+	val = phy_read(dev, 0xe);
+	val &= 0xffe3;
+	val |= 0x18;
+	phy_write(dev, 0xe, val);
+
+	/* introduce tx clock delay */
+	phy_write(dev, 0x1d, 0x5);
+	val = phy_read(dev, 0x1e);
+	val |= 0x0100;
+	phy_write(dev, 0x1e, val);
+
+	/*check phy power*/
+	val = phy_read(dev, 0x0);
+	if (val & BMCR_PDOWN)
+		phy_write(dev, 0x0, val & ~BMCR_PDOWN);
+
+	return 0;
+}
+
+static int at8035_config_init(struct phy_device *phydev)
+{
+	int ret;
+
+	ret = at803x_config_init(phydev);
+	if (ret)
+		return ret;
+
+	ret = ar8035_phy_fixup(phydev);
+
+	return ret;
+}
+#endif
+
 static struct phy_driver at803x_driver[] = {
 {
 	/* ATHEROS 8035 */
 	.phy_id		= 0x004dd072,
 	.name		= "Atheros 8035 ethernet",
 	.phy_id_mask	= 0xffffffef,
+#ifdef CONFIG_BUFFALO_PLATFORM //for BTS#204035
+	.config_init	= at8035_config_init,
+#else
 	.config_init	= at803x_config_init,
+#endif
 	.set_wol	= at803x_set_wol,
 	.get_wol	= at803x_get_wol,
 	.features	= PHY_GBIT_FEATURES,
diff --git a/drivers/net/phy/phy.c b/drivers/net/phy/phy.c
index 38f0b31..cb79756 100644
--- a/drivers/net/phy/phy.c
+++ b/drivers/net/phy/phy.c
@@ -41,6 +41,9 @@
 #include <asm/io.h>
 #include <asm/irq.h>
 #include <asm/uaccess.h>
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+#include "buffalo/kernevnt.h"
+#endif
 
 /**
  * phy_print_status - Convenience function to print out the current phy status
@@ -734,6 +737,45 @@ void phy_start(struct phy_device *phydev)
 EXPORT_SYMBOL(phy_stop);
 EXPORT_SYMBOL(phy_start);
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+extern int phy_deferred_linkdown;
+/* phy_adjust_link() : wrapper of phydev->adjust_link() function to generate
+ * 'lanact' kernelevent by generic way.
+ */
+static void phy_adjust_link(struct phy_device *phydev)
+{
+	struct net_device *netdev = phydev->attached_dev;
+	int new_state = 0;
+	unsigned int max_linkdown = max(phy_deferred_linkdown, 1);
+
+	BUG_ON(!netdev);
+	phydev->adjust_link(netdev);
+	/* prepare for called just after initialization */
+	if (phydev->state_cache.downcnt == ~0U) {
+		phydev->state_cache.downcnt = max_linkdown;
+	}
+	if (phydev->link) {
+		/* issue event when link-down count was expired */
+		new_state += (phydev->link != phydev->state_cache.link);
+		new_state += (phydev->speed != phydev->state_cache.speed);
+		new_state += (phydev->duplex != phydev->state_cache.duplex);
+		phydev->state_cache.link = 1;
+		phydev->state_cache.downcnt = 0;
+		phydev->state_cache.speed = phydev->speed;
+		phydev->state_cache.duplex = phydev->duplex;
+	} else {
+		/* issue event only when link-down count was overflow */
+		phydev->state_cache.downcnt++;
+		if (phydev->state_cache.downcnt >= max_linkdown) {
+			new_state += (phydev->state_cache.link != 0);
+			phydev->state_cache.link = 0;
+		}
+	}
+	if (new_state) {
+		kernevnt_LanAct(phydev);
+	}
+}
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 /**
  * phy_state_machine - Handle the state machine
  * @work: work_struct that describes the work to be done
@@ -774,7 +816,11 @@ void phy_state_machine(struct work_struct *work)
 			if (!phydev->link) {
 				phydev->state = PHY_NOLINK;
 				netif_carrier_off(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				break;
 			}
 
@@ -788,7 +834,11 @@ void phy_state_machine(struct work_struct *work)
 			if (err > 0) {
 				phydev->state = PHY_RUNNING;
 				netif_carrier_on(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 			} else if (0 == phydev->link_timeout--) {
 				needs_aneg = 1;
@@ -807,8 +857,15 @@ void phy_state_machine(struct work_struct *work)
 			if (phydev->link) {
 				phydev->state = PHY_RUNNING;
 				netif_carrier_on(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				/* everytime call adjust_link */
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			}
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			break;
 		case PHY_FORCING:
 			err = genphy_update_link(phydev);
@@ -824,7 +881,11 @@ void phy_state_machine(struct work_struct *work)
 					needs_aneg = 1;
 			}
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			break;
 		case PHY_RUNNING:
 			/* Only register a CHANGE if we are
@@ -846,7 +907,11 @@ void phy_state_machine(struct work_struct *work)
 				netif_carrier_off(phydev->attached_dev);
 			}
 
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+			phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 			if (PHY_POLL != phydev->irq)
 				err = phy_config_interrupt(phydev,
@@ -856,7 +921,11 @@ void phy_state_machine(struct work_struct *work)
 			if (phydev->link) {
 				phydev->link = 0;
 				netif_carrier_off(phydev->attached_dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			}
 			break;
 		case PHY_RESUMING:
@@ -890,7 +959,11 @@ void phy_state_machine(struct work_struct *work)
 						netif_carrier_on(phydev->attached_dev);
 					} else
 						phydev->state = PHY_NOLINK;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+					phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 					phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				} else {
 					phydev->state = PHY_AN;
 					phydev->link_timeout = PHY_AN_TIMEOUT;
@@ -905,7 +978,11 @@ void phy_state_machine(struct work_struct *work)
 					netif_carrier_on(phydev->attached_dev);
 				} else
 					phydev->state = PHY_NOLINK;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+				phy_adjust_link(phydev);
+#else /*CONFIG_BUFFALO_USE_KERNEVNT*/
 				phydev->adjust_link(phydev->attached_dev);
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 			}
 			break;
 	}
diff --git a/drivers/net/phy/phy_device.c b/drivers/net/phy/phy_device.c
index a5f9ad4..4f23783 100644
--- a/drivers/net/phy/phy_device.c
+++ b/drivers/net/phy/phy_device.c
@@ -41,6 +41,11 @@
 MODULE_DESCRIPTION("PHY library");
 MODULE_AUTHOR("Andy Fleming");
 MODULE_LICENSE("GPL");
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+int phy_deferred_linkdown = 1;
+module_param_named(deferred_linkdown, phy_deferred_linkdown, int, 0600);
+MODULE_PARM_DESC(deferred_linkdown, "Max linkdown count for lanact event");
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 void phy_device_free(struct phy_device *phydev)
 {
@@ -186,6 +191,12 @@ struct phy_device *phy_device_create(struct mii_bus *bus, int addr, int phy_id,
 	dev->pause = dev->asym_pause = 0;
 	dev->link = 1;
 	dev->interface = PHY_INTERFACE_MODE_GMII;
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	dev->state_cache.speed = 0;
+	dev->state_cache.duplex = -1;
+	dev->state_cache.link = 1;
+	dev->state_cache.downcnt = ~0U;
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 
 	dev->autoneg = AUTONEG_ENABLE;
 
diff --git a/drivers/rtc/Kconfig b/drivers/rtc/Kconfig
index b983813..48eedba 100644
--- a/drivers/rtc/Kconfig
+++ b/drivers/rtc/Kconfig
@@ -470,6 +470,16 @@ config RTC_DRV_RX8025
 	  This driver can also be built as a module. If so, the module
 	  will be called rtc-rx8025.
 
+config RTC_DRV_RX8010
+	tristate "Epson RX-8010SJ"
+	help
+	  If you say yes here you get support for the Epson
+	  RX-8010SJ RTC chips.
+
+	  This driver can also be built as a module. If so, the module
+	  will be called rtc-rx8010.
+
+
 config RTC_DRV_EM3027
 	tristate "EM Microelectronic EM3027"
 	help
diff --git a/drivers/rtc/Makefile b/drivers/rtc/Makefile
index c33f86f..4e2d9ea 100644
--- a/drivers/rtc/Makefile
+++ b/drivers/rtc/Makefile
@@ -103,6 +103,7 @@ obj-$(CONFIG_RTC_DRV_RS5C372)	+= rtc-rs5c372.o
 obj-$(CONFIG_RTC_DRV_RV3029C2)	+= rtc-rv3029c2.o
 obj-$(CONFIG_RTC_DRV_RX4581)	+= rtc-rx4581.o
 obj-$(CONFIG_RTC_DRV_RX8025)	+= rtc-rx8025.o
+obj-$(CONFIG_RTC_DRV_RX8010)	+= rtc-rx8010.o
 obj-$(CONFIG_RTC_DRV_RX8581)	+= rtc-rx8581.o
 obj-$(CONFIG_RTC_DRV_S35390A)	+= rtc-s35390a.o
 obj-$(CONFIG_RTC_DRV_S3C)	+= rtc-s3c.o
diff --git a/drivers/rtc/rtc-rx8010.c b/drivers/rtc/rtc-rx8010.c
new file mode 100644
index 00000000..80f7506
--- /dev/null
+++ b/drivers/rtc/rtc-rx8010.c
@@ -0,0 +1,965 @@
+//======================================================================
+// Driver for the Epson RTC module RX-8010 SJ
+// 
+// Copyright(C) SEIKO EPSON CORPORATION 2013. All rights reserved.
+// 
+// Derived from RX-8025 driver: 
+// Copyright (C) 2009 Wolfgang Grandegger <wg@grandegger.com>
+// 
+// Copyright (C) 2005 by Digi International Inc.
+// All rights reserved.
+// 
+// Modified by fengjh at rising.com.cn
+// <http://lists.lm-sensors.org/mailman/listinfo/lm-sensors>
+// 2006.11
+// 
+// Code cleanup by Sergei Poselenov, <sposelenov@emcraft.com>
+// Converted to new style by Wolfgang Grandegger <wg@grandegger.com>
+// Alarm and periodic interrupt added by Dmitry Rakhchev <rda@emcraft.com>
+//
+// 
+// This driver software is distributed as is, without any warranty of any kind,
+// either express or implied as further specified in the GNU Public License. This
+// software may be used and distributed according to the terms of the GNU Public
+// License, version 2 as published by the Free Software Foundation.
+// See the file COPYING in the main directory of this archive for more details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program. If not, see <http://www.gnu.org/licenses/>.
+//======================================================================
+
+#if 0
+#define DEBUG
+#include <linux/device.h>
+#undef DEBUG
+#endif 
+
+#include <linux/kernel.h>
+#include <linux/module.h>
+#include <linux/slab.h>
+#include <linux/init.h>
+#include <linux/bcd.h>
+#include <linux/i2c.h>
+#include <linux/list.h>
+#include <linux/rtc.h>
+#include <linux/of_gpio.h>
+
+#include <linux/of.h>
+#include <linux/of_device.h>
+#include <linux/of_irq.h>
+#include <linux/interrupt.h>
+#include <linux/input.h>
+
+
+// RX-8010 Register definitions
+#define RX8010_REG_SEC		0x10
+#define RX8010_REG_MIN		0x11
+#define RX8010_REG_HOUR		0x12
+#define RX8010_REG_WDAY		0x13
+#define RX8010_REG_MDAY		0x14
+#define RX8010_REG_MONTH	0x15
+#define RX8010_REG_YEAR		0x16
+// 0x17 is reserved
+#define RX8010_REG_ALMIN	0x18
+#define RX8010_REG_ALHOUR	0x19
+#define RX8010_REG_ALWDAY	0x1A
+#define RX8010_REG_TCOUNT0	0x1B
+#define RX8010_REG_TCOUNT1	0x1C
+#define RX8010_REG_EXT		0x1D
+#define RX8010_REG_FLAG		0x1E
+#define RX8010_REG_CTRL		0x1F
+#define RX8010_REG_USER0	0x20
+#define RX8010_REG_USER1	0x21
+#define RX8010_REG_USER2	0x22
+#define RX8010_REG_USER3	0x23
+#define RX8010_REG_USER4	0x24
+#define RX8010_REG_USER5	0x25
+#define RX8010_REG_USER6	0x26
+#define RX8010_REG_USER7	0x27
+#define RX8010_REG_USER8	0x28
+#define RX8010_REG_USER9	0x29
+#define RX8010_REG_USERA	0x2A
+#define RX8010_REG_USERB	0x2B
+#define RX8010_REG_USERC	0x2C
+#define RX8010_REG_USERD	0x2D
+#define RX8010_REG_USERE	0x2E
+#define RX8010_REG_USERF	0x2F
+// 0x30 is reserved
+// 0x31 is reserved
+#define RX8010_REG_IRQ		0x32
+
+// Extension Register (1Dh) bit positions
+#define RX8010_BIT_EXT_TSEL		(7 << 0)
+#define RX8010_BIT_EXT_WADA		(1 << 3)
+#define RX8010_BIT_EXT_TE		(1 << 4)
+#define RX8010_BIT_EXT_USEL		(1 << 5)
+#define RX8010_BIT_EXT_FSEL		(3 << 6)
+
+// Flag Register (1Eh) bit positions
+#define RX8010_BIT_FLAG_VLF		(1 << 1)
+#define RX8010_BIT_FLAG_AF		(1 << 3)
+#define RX8010_BIT_FLAG_TF		(1 << 4)
+#define RX8010_BIT_FLAG_UF		(1 << 5)
+
+// Control Register (1Fh) bit positions
+#define RX8010_BIT_CTRL_TSTP	(1 << 2)
+#define RX8010_BIT_CTRL_AIE		(1 << 3)
+#define RX8010_BIT_CTRL_TIE		(1 << 4)
+#define RX8010_BIT_CTRL_UIE		(1 << 5)
+#define RX8010_BIT_CTRL_STOP	(1 << 6)
+#define RX8010_BIT_CTRL_TEST	(1 << 7)
+
+
+static const struct i2c_device_id rx8010_id[] = {
+	{ "rx8010", 0 },
+	{ }
+};
+MODULE_DEVICE_TABLE(i2c, rx8010_id);
+
+struct rx8010_data {
+	struct i2c_client *client;
+	struct rtc_device *rtc;
+	struct work_struct work_1;
+	struct work_struct work_2;
+	u8 ctrlreg;
+	int irq_1;
+	int irq_2;
+	unsigned exiting:1;
+};
+
+typedef struct {
+	u8 number;
+	u8 value;
+}reg_data;
+
+#define SE_RTC_REG_READ		_IOWR('p', 0x20, reg_data)		
+#define SE_RTC_REG_WRITE	_IOW('p',  0x21, reg_data)	
+
+//----------------------------------------------------------------------
+// rx8010_read_reg()
+// reads a rx8010 register (see Register defines)
+// See also rx8010_read_regs() to read multiple registers.
+//
+//----------------------------------------------------------------------
+static int rx8010_read_reg(struct i2c_client *client, int number, u8 *value)
+{
+	int ret = i2c_smbus_read_byte_data(client, number) ;
+
+	//check for error
+	if (ret < 0) {
+		dev_err(&client->dev, "Unable to read register #%d\n", number);
+		return ret;
+	}
+
+	*value = ret;
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_read_regs()
+// reads a specified number of rx8010 registers (see Register defines)
+// See also rx8010_read_reg() to read single register.
+//
+//----------------------------------------------------------------------
+static int rx8010_read_regs(struct i2c_client *client, int number, u8 length, u8 *values)
+{
+	int ret = i2c_smbus_read_i2c_block_data(client, number, length, values);
+
+	//check for length error
+	if (ret != length) {
+		dev_err(&client->dev, "Unable to read registers #%d..#%d\n", number, number + length - 1);
+		return ret < 0 ? ret : -EIO;
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_write_reg()
+// writes a rx8010 register (see Register defines)
+// See also rx8010_write_regs() to write multiple registers.
+//
+//----------------------------------------------------------------------
+static int rx8010_write_reg(struct i2c_client *client, int number, u8 value)
+{
+	int ret = i2c_smbus_write_byte_data(client, number, value);
+
+	//check for error
+	if (ret)
+		dev_err(&client->dev, "Unable to write register #%d\n", number);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_write_regs()
+// writes a specified number of rx8010 registers (see Register defines)
+// See also rx8010_write_reg() to write a single register.
+//
+//----------------------------------------------------------------------
+static int rx8010_write_regs(struct i2c_client *client, int number, u8 length, u8 *values)
+{
+	int ret = i2c_smbus_write_i2c_block_data(client, number, length, values);
+
+	//check for error
+	if (ret)
+		dev_err(&client->dev, "Unable to write registers #%d..#%d\n", number, number + length - 1);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_irq_1()
+// irq handler
+//
+//----------------------------------------------------------------------
+static irqreturn_t rx8010_irq_1(int irq, void *dev_id)
+{
+	struct i2c_client *client = dev_id;
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+
+	disable_irq_nosync(irq);
+	schedule_work(&rx8010->work_1);
+
+
+	return IRQ_HANDLED;
+}
+
+//----------------------------------------------------------------------
+// rx8010_work_1()
+//
+//----------------------------------------------------------------------
+static void rx8010_work_1(struct work_struct *work)
+{
+	struct rx8010_data *rx8010 = container_of(work, struct rx8010_data, work_1);
+	struct i2c_client *client = rx8010->client;
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+	u8 status;
+
+	mutex_lock(lock);
+	
+	if (rx8010_read_reg(client, RX8010_REG_FLAG, &status))
+		goto out;
+
+	// check VLF
+	if ((status & RX8010_BIT_FLAG_VLF))
+		dev_warn(&client->dev, "Frequency stop was detected, probably due to a supply voltage drop\n");
+			 
+	dev_dbg(&client->dev, "%s: RX8010_REG_FLAG: %xh\n", __func__, status);
+
+	// periodic "fixed-cycle" timer
+	if (status & RX8010_BIT_FLAG_TF) {
+		status &= ~RX8010_BIT_FLAG_TF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_PF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// alarm function
+	if (status & RX8010_BIT_FLAG_AF) {
+		status &= ~RX8010_BIT_FLAG_AF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_AF | RTC_IRQF);
+		local_irq_enable();
+	}
+	
+	// time update function
+	if (status & RX8010_BIT_FLAG_UF) {
+		status &= ~RX8010_BIT_FLAG_UF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_UF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// acknowledge IRQ (clear flags)
+	rx8010_write_reg(client, RX8010_REG_FLAG, status);		
+
+out:
+	if (!rx8010->exiting)
+	{
+		if (rx8010->irq_1 > 0)
+			enable_irq(rx8010->irq_1);
+		else
+			enable_irq(client->irq);
+	}	
+
+	mutex_unlock(lock);
+}
+
+//----------------------------------------------------------------------
+// rx8010_irq_2()
+// irq handler
+//
+//----------------------------------------------------------------------
+static irqreturn_t rx8010_irq_2(int irq, void *dev_id)
+{
+	struct i2c_client *client = dev_id;
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+
+	disable_irq_nosync(irq);
+	schedule_work(&rx8010->work_2);
+
+
+	return IRQ_HANDLED;
+}
+
+//----------------------------------------------------------------------
+// rx8010_work_2()
+//
+//----------------------------------------------------------------------
+static void rx8010_work_2(struct work_struct *work)
+{
+	struct rx8010_data *rx8010 = container_of(work, struct rx8010_data, work_2);
+	struct i2c_client *client = rx8010->client;
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+	u8 status;
+
+	mutex_lock(lock);
+	
+	if (rx8010_read_reg(client, RX8010_REG_FLAG, &status))
+		goto out;
+
+	// check VLF
+	if ((status & RX8010_BIT_FLAG_VLF))
+		dev_warn(&client->dev, "Frequency stop was detected, \
+								probably due to a supply voltage drop\n");
+			 
+	dev_dbg(&client->dev, "%s: RX8010_REG_FLAG: %xh\n", __func__, status);
+
+	// periodic "fixed-cycle" timer
+	if (status & RX8010_BIT_FLAG_TF) {
+		status &= ~RX8010_BIT_FLAG_TF;
+		local_irq_disable();
+		rtc_update_irq(rx8010->rtc, 1, RTC_PF | RTC_IRQF);
+		local_irq_enable();
+	}
+
+	// acknowledge IRQ (clear flags)
+	rx8010_write_reg(client, RX8010_REG_FLAG, status);		
+
+out:
+	if (!rx8010->exiting)
+	{
+		if (rx8010->irq_2 > 0)
+			enable_irq(rx8010->irq_2);
+		else
+			enable_irq(client->irq);
+	}	
+
+	mutex_unlock(lock);
+}
+
+//----------------------------------------------------------------------
+// rx8010_get_time()
+// gets the current time from the rx8010 registers
+//
+//----------------------------------------------------------------------
+static int rx8010_get_time(struct device *dev, struct rtc_time *dt)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 date[7];
+	int err;
+
+	err = rx8010_read_regs(rx8010->client, RX8010_REG_SEC, 7, date);
+	if (err)
+		return err;
+
+	dev_dbg(dev, "%s: read 0x%02x 0x%02x "
+		"0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n", __func__,
+		date[0], date[1], date[2], date[3], date[4], date[5], date[6]);
+
+	//Note: need to subtract 0x10 for index as register offset starts at 0x10
+	dt->tm_sec = bcd2bin(date[RX8010_REG_SEC-0x10] & 0x7f);
+	dt->tm_min = bcd2bin(date[RX8010_REG_MIN-0x10] & 0x7f);
+	dt->tm_hour = bcd2bin(date[RX8010_REG_HOUR-0x10] & 0x3f);	//only 24-hour clock
+	dt->tm_mday = bcd2bin(date[RX8010_REG_MDAY-0x10] & 0x3f);
+	dt->tm_mon = bcd2bin(date[RX8010_REG_MONTH-0x10] & 0x1f) - 1;
+	dt->tm_year = bcd2bin(date[RX8010_REG_YEAR-0x10]);
+	dt->tm_wday = bcd2bin(date[RX8010_REG_WDAY-0x10] & 0x7f);
+
+	if (dt->tm_year < 70)
+		dt->tm_year += 100;
+
+	dev_dbg(dev, "%s: date %ds %dm %dh %dmd %dm %dy\n", __func__,
+		dt->tm_sec, dt->tm_min, dt->tm_hour,
+		dt->tm_mday, dt->tm_mon, dt->tm_year);
+
+	return rtc_valid_tm(dt);
+}
+
+//----------------------------------------------------------------------
+// rx8010_set_time()
+// Sets the current time in the rx8010 registers
+//
+// BUG: The HW assumes every year that is a multiple of 4 to be a leap
+// year. Next time this is wrong is 2100, which will not be a leap year
+//
+// Note: If STOP is not set/cleared, the clock will start when the seconds
+//       register is written
+//
+//----------------------------------------------------------------------
+static int rx8010_set_time(struct device *dev, struct rtc_time *dt)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 date[7];
+	u8 ctrl;
+	int ret;
+
+	//set STOP bit before changing clock/calendar
+	rx8010_read_reg(rx8010->client, RX8010_REG_CTRL, &ctrl);
+	rx8010->ctrlreg = ctrl | RX8010_BIT_CTRL_STOP;
+	rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+	
+	//Note: need to subtract 0x10 for index as register offset starts at 0x10
+	date[RX8010_REG_SEC-0x10] = bin2bcd(dt->tm_sec);
+	date[RX8010_REG_MIN-0x10] = bin2bcd(dt->tm_min);
+	date[RX8010_REG_HOUR-0x10] = bin2bcd(dt->tm_hour);		//only 24hr time
+
+	date[RX8010_REG_MDAY-0x10] = bin2bcd(dt->tm_mday);
+	date[RX8010_REG_MONTH-0x10] = bin2bcd(dt->tm_mon + 1);
+	date[RX8010_REG_YEAR-0x10] = bin2bcd(dt->tm_year % 100);
+	date[RX8010_REG_WDAY-0x10] = bin2bcd(dt->tm_wday);
+
+	dev_dbg(dev, "%s: write 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x 0x%02x\n",
+		__func__, date[0], date[1], date[2], date[3], date[4], date[5], date[6]);
+
+	ret =  rx8010_write_regs(rx8010->client, RX8010_REG_SEC, 7, date);
+
+	//clear STOP bit after changing clock/calendar
+	rx8010_read_reg(rx8010->client, RX8010_REG_CTRL, &ctrl);
+	rx8010->ctrlreg = ctrl & ~RX8010_BIT_CTRL_STOP;
+	rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+
+	return ret;
+}
+
+//----------------------------------------------------------------------
+// rx8010_init_client()
+// initializes the rx8010
+//
+//----------------------------------------------------------------------
+static int rx8010_init_client(struct i2c_client *client, int *need_reset)
+{
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+	u8 ctrl[3];
+	int need_clear = 0;
+	int err;
+
+	//set reserved register 0x17 with specified value of 0xD8
+	err = rx8010_write_reg(client, 0x17, 0xD8);
+	if (err)
+		goto out;
+	
+	//set reserved register 0x30 with specified value of 0x00
+	err = rx8010_write_reg(client, 0x30, 0x00);
+	if (err)
+		goto out;
+
+	//set reserved register 0x31 with specified value of 0x08
+	err = rx8010_write_reg(client, 0x31, 0x08);
+	if (err)
+		goto out;
+		
+	//set reserved register 0x32 with default value
+	err = rx8010_write_reg(client, RX8010_REG_IRQ, 0x00);
+	if (err)
+		goto out;		
+		
+
+	//get current extension, flag, control register values
+	err = rx8010_read_regs(rx8010->client, RX8010_REG_EXT, 3, ctrl);
+	if (err)
+		goto out;
+	
+	//check for VLF Flag (set at power-on)
+	if ((ctrl[1] & RX8010_BIT_FLAG_VLF)) {
+		dev_warn(&client->dev, "Frequency stop was detected, probably due to a supply voltage drop\n");
+		*need_reset = 1;
+	}
+
+	//check for Alarm Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_AF) {
+		dev_warn(&client->dev, "Alarm was detected\n");
+		need_clear = 1;
+	}
+
+	//check for Periodic Timer Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_TF) {
+		dev_warn(&client->dev, "Periodic timer was detected\n");
+		need_clear = 1;
+	}
+	
+	//check for Update Timer Flag
+	if (ctrl[1] & RX8010_BIT_FLAG_UF) {
+		dev_warn(&client->dev, "Update timer was detected\n");
+		need_clear = 1;
+	}
+
+	//reset or clear needed?
+	if (*need_reset) {
+		//clear 1d, 1e, 1f registers
+		ctrl[0] = ctrl[1] = ctrl[2] = 0;
+		err = rx8010_write_regs(client, RX8010_REG_EXT, 3, ctrl);
+		if (err)
+			goto out;
+	}
+	else if(need_clear){
+		//clear flag register
+		err = rx8010_write_reg(client, RX8010_REG_FLAG, 0x00);
+		if (err)
+			goto out;
+	}
+	
+	//set "test bit" and reserved bits of control register zero
+	rx8010->ctrlreg = (ctrl[2] & ~RX8010_BIT_CTRL_TEST);		
+out:
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_read_alarm()
+// reads current Alarm 
+//
+// Notes: - currently filters the AE bits (bit 7)
+//        - assumes WADA setting is week (week/day) 
+//----------------------------------------------------------------------
+static int rx8010_read_alarm(struct device *dev, struct rtc_wkalrm *t)
+{
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	struct i2c_client *client = rx8010->client;
+	u8 alarmvals[3];		//minute, hour, week/day values
+	u8 ctrl[3];				//extension, flag, control values
+	int err;
+
+	if (client->irq <= 0)
+		return -EINVAL;
+
+	//get current minute, hour, week/day alarm values
+	err = rx8010_read_regs(client, RX8010_REG_ALMIN, 3, alarmvals);
+	if (err)
+		return err;
+	dev_dbg(dev, "%s: minutes:0x%02x hours:0x%02x week/day:0x%02x\n",
+		__func__, alarmvals[0], alarmvals[1], alarmvals[2]);
+
+	
+	//get current extension, flag, control register values
+	err = rx8010_read_regs(client, RX8010_REG_EXT, 3, ctrl);
+	if (err)
+		return err;
+	dev_dbg(dev, "%s: extension:0x%02x flag:0x%02x control:0x%02x \n",
+		__func__, ctrl[0], ctrl[1], ctrl[2]);
+
+	// Hardware alarm precision is 1 minute
+	t->time.tm_sec = 0;
+	t->time.tm_min = bcd2bin(alarmvals[0] & 0x7f);		//0x7f filters AE bit currently
+	t->time.tm_hour = bcd2bin(alarmvals[1] & 0x3f);		//0x3f filters AE bit currently, also 24hr only
+
+	t->time.tm_wday = -1;
+	t->time.tm_mday = -1;
+	t->time.tm_mon = -1;
+	t->time.tm_year = -1;
+
+	dev_dbg(dev, "%s: date: %ds %dm %dh %dmd %dm %dy\n",
+		__func__,
+		t->time.tm_sec, t->time.tm_min, t->time.tm_hour,
+		t->time.tm_mday, t->time.tm_mon, t->time.tm_year);
+		
+	t->enabled = !!(rx8010->ctrlreg & RX8010_BIT_CTRL_AIE);		//check if interrupt is enabled
+	t->pending = (ctrl[1] & RX8010_BIT_FLAG_AF) && t->enabled;	//check if flag is triggered
+
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_set_alarm()
+// sets Alarm 
+//
+// Notes: - currently filters the AE bits (bit 7)
+//        - assumes WADA setting is week (week/day) 
+//----------------------------------------------------------------------
+static int rx8010_set_alarm(struct device *dev, struct rtc_wkalrm *t)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 alarmvals[3];		//minute, hour, day
+	u8 extreg;				//extension register
+	u8 flagreg;				//flag register
+	int err;
+	 
+	if (client->irq <= 0)
+		return -EINVAL;
+		
+	//get current extension register
+	err = rx8010_read_reg(client, RX8010_REG_EXT, &extreg);
+	if (err <0)
+		return err;
+	
+	//get current flag register
+	err = rx8010_read_reg(client, RX8010_REG_FLAG, &flagreg);
+	if (err <0)
+		return err;
+
+	// Hardware alarm precision is 1 minute
+	alarmvals[0] = bin2bcd(t->time.tm_min);
+	alarmvals[1] = bin2bcd(t->time.tm_hour);
+	alarmvals[2] = bin2bcd(t->time.tm_mday);
+	dev_dbg(dev, "%s: write 0x%02x 0x%02x 0x%02x\n", __func__, alarmvals[0], alarmvals[1], alarmvals[2]);
+
+	//check interrupt enable and disable
+	if (rx8010->ctrlreg & RX8010_BIT_CTRL_AIE) {
+		rx8010->ctrlreg &= ~RX8010_BIT_CTRL_AIE;
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+	
+	//write the new minute and hour values
+	//Note:assume minute and hour values will be enabled. Bit 7 of each of the
+	//     minute, hour, week/day register can be set which will "disable" the
+	//     register from triggering an alarm. See the RX8010 spec for more information
+	err = rx8010_write_regs(rx8010->client, RX8010_REG_ALMIN, 2, alarmvals);
+	if (err)
+		return err;
+
+	//set Week/Day bit
+	// Week setting is typically not used, so we will assume "day" setting
+	extreg |= RX8010_BIT_EXT_WADA;		//set to "day of month"
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_EXT, extreg);
+	if (err)
+		return err;
+
+	//set Day of Month register
+	if (alarmvals[2] == 0) {
+		alarmvals[2] |= 0x80;	//turn on AE bit to ignore day of month (no zero day)
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_ALWDAY, alarmvals[2]);
+	}
+	else {
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_ALWDAY, alarmvals[2]);
+	}
+	if (err)
+		return err;
+
+	//clear Alarm Flag
+	flagreg &= ~RX8010_BIT_FLAG_AF;
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_FLAG, flagreg);
+	if (err)
+		return err;
+
+	//re-enable interrupt if required
+	if (t->enabled) {
+
+		if ( rx8010->rtc->uie_rtctimer.enabled )
+			rx8010->ctrlreg |= RX8010_BIT_CTRL_UIE;								//set update interrupt enable
+		if ( rx8010->rtc->aie_timer.enabled )
+			rx8010->ctrlreg |= (RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);		//set alarm interrupt enable
+			
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+
+	return 0;
+}
+
+//----------------------------------------------------------------------
+// rx8010_alarm_irq_enable()
+// sets enables Alarm IRQ
+//
+// Todo: - 
+//
+//----------------------------------------------------------------------
+static int rx8010_alarm_irq_enable(struct device *dev, unsigned int enabled)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	u8 flagreg;
+	u8 ctrl;
+	int err;
+	
+	//get the current ctrl settings
+	ctrl = rx8010->ctrlreg;
+
+	if (enabled)
+	{
+		if ( rx8010->rtc->uie_rtctimer.enabled )
+			ctrl |= RX8010_BIT_CTRL_UIE;								//set update interrupt enable
+		if ( rx8010->rtc->aie_timer.enabled )
+			ctrl |= (RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);		//set alarm interrupt enable		
+	}
+	else
+	{
+		if ( ! rx8010->rtc->uie_rtctimer.enabled )
+			ctrl &= ~RX8010_BIT_CTRL_UIE;								//clear update interrupt enable
+		if ( ! rx8010->rtc->aie_timer.enabled )
+		{
+			if ( rx8010->rtc->uie_rtctimer.enabled )
+				ctrl &= ~RX8010_BIT_CTRL_AIE;
+			else
+				ctrl &= ~(RX8010_BIT_CTRL_AIE | RX8010_BIT_CTRL_UIE);	//clear alarm interrupt enable
+		}		
+	}
+
+	//clear alarm flag
+	err = rx8010_read_reg(client, RX8010_REG_FLAG, &flagreg);
+	if (err <0)
+		return err;
+	flagreg &= ~RX8010_BIT_FLAG_AF;
+	err = rx8010_write_reg(rx8010->client, RX8010_REG_FLAG, flagreg);
+	if (err)
+		return err;
+	
+	//update the Control register if the setting changed
+	if (ctrl != rx8010->ctrlreg) {
+		rx8010->ctrlreg = ctrl;
+		err = rx8010_write_reg(rx8010->client, RX8010_REG_CTRL, rx8010->ctrlreg);
+		if (err)
+			return err;
+	}
+	
+	return 0;
+}
+
+//---------------------------------------------------------------------------
+// rx8010_ioctl()
+//
+//---------------------------------------------------------------------------
+static int rx8010_ioctl(struct device *dev, unsigned int cmd, unsigned long arg)
+{
+	struct i2c_client *client = to_i2c_client(dev);
+	//struct rx8010_data *rx8010 = dev_get_drvdata(dev);
+	//struct mutex *lock = &rx8010->rtc->ops_lock;
+	int ret = 0;
+	int tmp;
+	void __user *argp = (void __user *)arg;
+	reg_data reg;
+	
+	dev_dbg(dev, "%s: cmd=%x\n", __func__, cmd);
+
+	switch (cmd) {
+		case SE_RTC_REG_READ:
+			if (copy_from_user(&reg, argp, sizeof(reg)))
+				return -EFAULT;
+			if ( reg.number < RX8010_REG_SEC || reg.number > RX8010_REG_IRQ )
+				return -EFAULT;
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, reg.number, &reg.value);
+			//mutex_unlock(lock);
+			if (! ret )				
+				return copy_to_user(argp, &reg, sizeof(reg)) ? -EFAULT : 0;
+			break;
+			
+		case SE_RTC_REG_WRITE:
+			if (copy_from_user(&reg, argp, sizeof(reg)))
+				return -EFAULT;
+			if ( reg.number < RX8010_REG_SEC || reg.number > RX8010_REG_IRQ )
+				return -EFAULT;				
+			//mutex_lock(lock);
+			ret = rx8010_write_reg(client, reg.number, reg.value);
+			//mutex_unlock(lock);
+			break;
+	
+		case RTC_VL_READ:
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, RX8010_REG_FLAG, &reg.value);
+			//mutex_unlock(lock);
+			if (! ret)	
+			{
+				tmp = !!(reg.value & RX8010_BIT_FLAG_VLF);
+				return copy_to_user(argp, &tmp, sizeof(tmp)) ? -EFAULT : 0;
+			}			
+			break;			
+				
+		case RTC_VL_CLR:
+			//mutex_lock(lock);
+			ret = rx8010_read_reg(client, RX8010_REG_FLAG, &reg.value);
+			if (! ret)
+			{
+				reg.value &= ~RX8010_BIT_FLAG_VLF;
+				ret = rx8010_write_reg(client, RX8010_REG_FLAG, reg.value);
+			}
+			//mutex_unlock(lock);
+			break;
+			
+		default:
+			return -ENOIOCTLCMD;			
+	}
+	
+	return ret;
+}
+
+static struct rtc_class_ops rx8010_rtc_ops = {
+	.read_time = rx8010_get_time,
+	.set_time = rx8010_set_time,
+	.read_alarm = rx8010_read_alarm,
+	.set_alarm = rx8010_set_alarm,
+	.alarm_irq_enable = rx8010_alarm_irq_enable,
+	.ioctl = rx8010_ioctl,
+};
+
+//----------------------------------------------------------------------
+// rx8010_probe()
+// probe routine for the rx8010 driver
+//
+//----------------------------------------------------------------------
+static int rx8010_probe(struct i2c_client *client, const struct i2c_device_id *id)
+{
+	struct device_node *np = client->dev.of_node; 
+	struct i2c_adapter *adapter = to_i2c_adapter(client->dev.parent);
+	struct rx8010_data *rx8010;
+	int err, gpio, i, irqs_success = 0, need_reset = 0;
+	const char * irq_name[2] = {"rx8010-irq_1", "rx8010-irq_2"};
+
+	if (!i2c_check_functionality(adapter, I2C_FUNC_SMBUS_BYTE_DATA | I2C_FUNC_SMBUS_I2C_BLOCK)) {
+		dev_err(&adapter->dev, "doesn't support required functionality\n");
+		err = -EIO;
+		goto errout;
+	}
+
+	rx8010 = devm_kzalloc(&client->dev, sizeof(struct rx8010_data), GFP_KERNEL);
+	if (!rx8010) {
+		dev_err(&adapter->dev, "failed to alloc memory\n");
+		err = -ENOMEM;
+		goto errout;
+	}
+
+	rx8010->client = client;
+	i2c_set_clientdata(client, rx8010);
+
+	err = rx8010_init_client(client, &need_reset);
+	if (err)
+		goto errout;
+
+
+	if (need_reset) {
+		struct rtc_time tm;
+		rtc_time_to_tm(0, &tm);		// set to 1970/1/1
+		rx8010_set_time(&client->dev, &tm);
+		dev_warn(&client->dev, " - time reset to 1970/1/1\n");
+	}
+
+	rx8010->rtc = rtc_device_register(client->name, &client->dev, &rx8010_rtc_ops, THIS_MODULE);
+	
+	if (IS_ERR(rx8010->rtc)) {
+		err = PTR_ERR(rx8010->rtc);
+		dev_err(&client->dev, "unable to register the class device\n");
+		goto errout;
+	}
+
+	// get interrupts
+	rx8010->irq_1 = rx8010->irq_2 = -1;
+	for ( i=0; i < 2; i++ )
+	{
+		gpio = of_get_named_gpio(np, irq_name[i], 0);
+		if (gpio_is_valid(gpio)) {
+			int irq;
+			err = devm_gpio_request_one(&client->dev, gpio, GPIOF_DIR_IN, 
+															irq_name[i]);
+			if (err) {
+				dev_err(&client->dev, "cannot request %s\n", irq_name[i]);
+				goto errout_reg;
+			}
+			irq = gpio_to_irq(gpio);
+			dev_dbg(&client->dev, "%s %d\n", irq_name[i], irq);
+			if (irq <= 0) {
+				dev_warn(&client->dev, "Failed to "
+					"convert gpio #%d to %s\n",
+					gpio, irq_name[i]);
+				goto errout_reg;
+			}
+			err = devm_request_threaded_irq(&client->dev,irq, NULL, 
+											i==0 ? rx8010_irq_1 : rx8010_irq_2, 
+											IRQF_TRIGGER_LOW | IRQF_ONESHOT,
+											irq_name[i], 
+											client);	
+			if (err) {
+				dev_err(&client->dev, "unable to request %s\n", irq_name[i]);
+				goto errout_reg;
+			}
+			if (i == 0)
+			{
+				rx8010->irq_1 = irq;
+				INIT_WORK(&rx8010->work_1, rx8010_work_1);
+			}
+			else
+			{
+				rx8010->irq_2 = irq;
+				INIT_WORK(&rx8010->work_2, rx8010_work_2);
+			}
+			irqs_success++;		
+		} else {
+				dev_warn(&client->dev, "%s missing or invalid\n", 
+										irq_name[i]);
+		}
+	}
+	
+	// another irq request try if one failed above
+	if ( ! irqs_success && client->irq > 0 ){
+		dev_info(&client->dev, "IRQ %d supplied\n", client->irq);
+		err = devm_request_threaded_irq(&client->dev,client->irq, NULL, 
+										rx8010_irq_1, 
+										IRQF_TRIGGER_LOW | IRQF_ONESHOT,
+										"rx8010", client);
+		
+		if (err) {
+			dev_err(&client->dev, "unable to request IRQ\n");
+			goto errout_reg;
+		}
+		INIT_WORK(&rx8010->work_1, rx8010_work_1);	
+	}
+		
+
+	rx8010->rtc->irq_freq = 1;
+	rx8010->rtc->max_user_freq = 1;
+		
+	return 0;
+
+errout_reg:
+	rtc_device_unregister(rx8010->rtc);
+
+errout:
+	dev_err(&adapter->dev, "probing for rx8010 failed\n");
+	return err;
+}
+
+//----------------------------------------------------------------------
+// rx8010_remove()
+// remove routine for the rx8010 driver
+//
+//----------------------------------------------------------------------
+static int rx8010_remove(struct i2c_client *client)
+{
+	struct rx8010_data *rx8010 = i2c_get_clientdata(client);
+	struct mutex *lock = &rx8010->rtc->ops_lock;
+
+	if (client->irq > 0 || rx8010->irq_1 > 0 || rx8010->irq_2 > 0) {
+		mutex_lock(lock);
+		rx8010->exiting = 1;
+		mutex_unlock(lock);
+
+		//cancel_work
+		if (rx8010->irq_1 > 0 || client->irq > 0)
+			cancel_work_sync(&rx8010->work_1);
+		if (rx8010->irq_2 > 0)
+			cancel_work_sync(&rx8010->work_2);
+	}
+
+	rtc_device_unregister(rx8010->rtc);
+	
+	return 0;
+}
+
+static struct i2c_driver rx8010_driver = {
+	.driver = {
+		.name = "rtc-rx8010",
+		.owner = THIS_MODULE,
+	},
+	.probe		= rx8010_probe,
+	.remove		= rx8010_remove,
+	.id_table	= rx8010_id,
+};
+
+module_i2c_driver(rx8010_driver);
+
+MODULE_AUTHOR("Dennis Henderson <henderson.dennis@erd.epson.com>");
+MODULE_DESCRIPTION("RX-8010 SJ RTC driver");
+MODULE_LICENSE("GPL");
diff --git a/drivers/scsi/qla2xxx/tcm_qla2xxx.c b/drivers/scsi/qla2xxx/tcm_qla2xxx.c
index 66b0b26..aea4d6d 100644
--- a/drivers/scsi/qla2xxx/tcm_qla2xxx.c
+++ b/drivers/scsi/qla2xxx/tcm_qla2xxx.c
@@ -739,6 +739,20 @@ static int tcm_qla2xxx_queue_tm_rsp(struct se_cmd *se_cmd)
 	return 0;
 }
 
+static void tcm_qla2xxx_aborted_task(struct se_cmd *se_cmd)
+{
+	struct qla_tgt_cmd *cmd = container_of(se_cmd,
+				struct qla_tgt_cmd, se_cmd);
+	struct scsi_qla_host *vha = cmd->vha;
+	struct qla_hw_data *ha = vha->hw;
+
+	if (!cmd->sg_mapped)
+		return;
+
+	pci_unmap_sg(ha->pdev, cmd->sg, cmd->sg_cnt, cmd->dma_data_direction);
+	cmd->sg_mapped = 0;
+}
+
 /* Local pointer to allocated TCM configfs fabric module */
 struct target_fabric_configfs *tcm_qla2xxx_fabric_configfs;
 struct target_fabric_configfs *tcm_qla2xxx_npiv_fabric_configfs;
@@ -1759,6 +1773,7 @@ static struct target_core_fabric_ops tcm_qla2xxx_ops = {
 	.queue_data_in			= tcm_qla2xxx_queue_data_in,
 	.queue_status			= tcm_qla2xxx_queue_status,
 	.queue_tm_rsp			= tcm_qla2xxx_queue_tm_rsp,
+	.aborted_task			= tcm_qla2xxx_aborted_task,
 	/*
 	 * Setup function pointers for generic logic in
 	 * target_core_fabric_configfs.c
@@ -1806,6 +1821,7 @@ static struct target_core_fabric_ops tcm_qla2xxx_npiv_ops = {
 	.queue_data_in			= tcm_qla2xxx_queue_data_in,
 	.queue_status			= tcm_qla2xxx_queue_status,
 	.queue_tm_rsp			= tcm_qla2xxx_queue_tm_rsp,
+	.aborted_task			= tcm_qla2xxx_aborted_task,
 	/*
 	 * Setup function pointers for generic logic in
 	 * target_core_fabric_configfs.c
@@ -1845,16 +1861,16 @@ static int tcm_qla2xxx_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = tcm_qla2xxx_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = tcm_qla2xxx_tpg_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs =
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = tcm_qla2xxx_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = tcm_qla2xxx_tpg_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs =
 						tcm_qla2xxx_tpg_attrib_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 	/*
 	 * Register the fabric for use within TCM
 	 */
@@ -1885,15 +1901,15 @@ static int tcm_qla2xxx_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various npiv_fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(npiv_fabric)->tfc_wwn_cit.ct_attrs = tcm_qla2xxx_wwn_attrs;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(npiv_fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = tcm_qla2xxx_wwn_attrs;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	npiv_fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 	/*
 	 * Register the npiv_fabric for use within TCM
 	 */
diff --git a/drivers/scsi/scsi.c b/drivers/scsi/scsi.c
index eaa808e..098f687 100644
--- a/drivers/scsi/scsi.c
+++ b/drivers/scsi/scsi.c
@@ -108,8 +108,14 @@ static const char *const scsi_device_types[] = {
 	"WORM             ",
 	"CD-ROM           ",
 	"Scanner          ",
+#ifdef CONFIG_BUFFALO_PLATFORM
+	/* __LS_COMMENT__ BUFFALO change 2004.8.30 */
+	"Optical-Device   ",
+	"Medium-Changer   ",
+#else	/* CONFIG_BUFFALO_PLATFORM */
 	"Optical Device   ",
 	"Medium Changer   ",
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	"Communications   ",
 	"ASC IT8          ",
 	"ASC IT8          ",
@@ -700,8 +706,15 @@ int scsi_dispatch_cmd(struct scsi_cmnd *cmd)
 	 */
 	if (cmd->device->scsi_level <= SCSI_2 &&
 	    cmd->device->scsi_level != SCSI_UNKNOWN) {
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+		/* support for AVU2 */
+		if (!cmd->device->ignore_lun || !(cmd->cmnd[0] & 0xc0))
+			cmd->cmnd[1] = (cmd->cmnd[1] & 0x1f) |
+				       (cmd->device->lun << 5 & 0xe0);
+#else	/* CONFIG_BUFFALO_IGNORE_LUN */
 		cmd->cmnd[1] = (cmd->cmnd[1] & 0x1f) |
 			       (cmd->device->lun << 5 & 0xe0);
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	}
 
 	/*
diff --git a/drivers/scsi/scsi_scan.c b/drivers/scsi/scsi_scan.c
index 3e58b22..9409186 100644
--- a/drivers/scsi/scsi_scan.c
+++ b/drivers/scsi/scsi_scan.c
@@ -1319,6 +1319,10 @@ static int scsi_report_lun_scan(struct scsi_target *starget, int bflags,
 	struct Scsi_Host *shost = dev_to_shost(&starget->dev);
 	int ret = 0;
 
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	return 1;
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
+
 	/*
 	 * Only support SCSI-3 and up devices if BLIST_NOREPORTLUN is not set.
 	 * Also allow SCSI-2 if BLIST_REPORTLUN2 is set and host adapter does
diff --git a/drivers/scsi/scsi_sysfs.c b/drivers/scsi/scsi_sysfs.c
index 931a7d9..c029266 100644
--- a/drivers/scsi/scsi_sysfs.c
+++ b/drivers/scsi/scsi_sysfs.c
@@ -534,6 +534,9 @@ sdev_rd_attr (scsi_level, "%d\n");
 sdev_rd_attr (vendor, "%.8s\n");
 sdev_rd_attr (model, "%.16s\n");
 sdev_rd_attr (rev, "%.4s\n");
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+sdev_rw_attr (ignore_lun, "%d\n");
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 
 /*
  * TODO: can we make these symlinks to the block layer ones?
@@ -719,6 +722,9 @@ static struct attribute *scsi_sdev_attrs[] = {
 	&dev_attr_vendor.attr,
 	&dev_attr_model.attr,
 	&dev_attr_rev.attr,
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	&dev_attr_ignore_lun,
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	&dev_attr_rescan.attr,
 	&dev_attr_delete.attr,
 	&dev_attr_state.attr,
diff --git a/drivers/scsi/sd.c b/drivers/scsi/sd.c
index 734a29a..7af25c3 100644
--- a/drivers/scsi/sd.c
+++ b/drivers/scsi/sd.c
@@ -2818,6 +2818,10 @@ static void sd_probe_async(void *data, async_cookie_t cookie)
 	gd->fops = &sd_fops;
 	gd->private_data = &sdkp->driver;
 	gd->queue = sdkp->device->request_queue;
+#ifdef CONFIG_BUFFALO_IOERRS
+	gd->io_errors = 0;
+	gd->limit_io_errors = 1000;	/* default limit *//* XXX: should use MAXERR_CNT_DEFAULT in dirivers/md/md.h ? but it is not reasonable to include drivers/md/md.h ... */
+#endif	/* CONFIG_BUFFALO_IOERRS */
 
 	/* defaults, until the device tells us otherwise */
 	sdp->sector_size = 512;
diff --git a/drivers/scsi/sd.h b/drivers/scsi/sd.h
index 7a049de..1696d6f 100644
--- a/drivers/scsi/sd.h
+++ b/drivers/scsi/sd.h
@@ -11,7 +11,11 @@
 /*
  * Time out in seconds for disks and Magneto-opticals (which are slower).
  */
+#ifdef CONFIG_BUFFALO_PLATFORM
+#define SD_TIMEOUT		(120 * HZ)
+#else	/* CONFIG_BUFFALO_PLATFORM */
 #define SD_TIMEOUT		(30 * HZ)
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 #define SD_MOD_TIMEOUT		(75 * HZ)
 #define SD_FLUSH_TIMEOUT	(60 * HZ)
 #define SD_WRITE_SAME_TIMEOUT	(120 * HZ)
diff --git a/drivers/target/Kconfig b/drivers/target/Kconfig
index 1830368..dc2d84a 100644
--- a/drivers/target/Kconfig
+++ b/drivers/target/Kconfig
@@ -3,6 +3,7 @@ menuconfig TARGET_CORE
 	tristate "Generic Target Core Mod (TCM) and ConfigFS Infrastructure"
 	depends on SCSI && BLOCK
 	select CONFIGFS_FS
+	select CRC_T10DIF
 	default n
 	help
 	Say Y or M here to enable the TCM Storage Engine and ConfigFS enabled
@@ -13,6 +14,7 @@ if TARGET_CORE
 
 config TCM_IBLOCK
 	tristate "TCM/IBLOCK Subsystem Plugin for Linux/BLOCK"
+	select BLK_DEV_INTEGRITY
 	help
 	Say Y here to enable the TCM/IBLOCK subsystem plugin for non-buffered
 	access to Linux/Block devices using BIO
diff --git a/drivers/target/Makefile b/drivers/target/Makefile
index 9fdcb56..85b012d 100644
--- a/drivers/target/Makefile
+++ b/drivers/target/Makefile
@@ -13,7 +13,8 @@ target_core_mod-y		:= target_core_configfs.o \
 				   target_core_spc.o \
 				   target_core_ua.o \
 				   target_core_rd.o \
-				   target_core_stat.o
+				   target_core_stat.o \
+				   target_core_xcopy.o
 
 obj-$(CONFIG_TARGET_CORE)	+= target_core_mod.o
 
diff --git a/drivers/target/iscsi/Kconfig b/drivers/target/iscsi/Kconfig
index 8345fb4..014bbf5 100644
--- a/drivers/target/iscsi/Kconfig
+++ b/drivers/target/iscsi/Kconfig
@@ -7,3 +7,12 @@ config ISCSI_TARGET
 	help
 	Say M here to enable the ConfigFS enabled Linux-iSCSI.org iSCSI
 	Target Mode Stack.
+
+config ISCSI_CHAP_BASE64_SUPPORT
+	bool "Enable to apply iSCSI CHAP(Base64) support patch"
+	depends on ISCSI_TARGET
+	help
+	  Enable CHAP(Base64) authentication supports.
+	  Must be enabled to pass MicroSoft's iSCSI Target Mutual CHAP Test (LOGO)
+
+	  If unsure, say N.
\ No newline at end of file
diff --git a/drivers/target/iscsi/Makefile b/drivers/target/iscsi/Makefile
index 13a9240..272d156 100644
--- a/drivers/target/iscsi/Makefile
+++ b/drivers/target/iscsi/Makefile
@@ -19,3 +19,5 @@ iscsi_target_mod-y +=		iscsi_target_parameters.o \
 				iscsi_target_transport.o
 
 obj-$(CONFIG_ISCSI_TARGET)	+= iscsi_target_mod.o
+
+ccflags-$(CONFIG_ISCSI_CHAP_BASE64_SUPPORT) += -DISCSI_CHAP_BASE64_SUPPORT
diff --git a/drivers/target/iscsi/iscsi_target.c b/drivers/target/iscsi/iscsi_target.c
old mode 100644
new mode 100755
index 4c1b8db..39a4d6e
--- a/drivers/target/iscsi/iscsi_target.c
+++ b/drivers/target/iscsi/iscsi_target.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains main functions related to the iSCSI Target Core Driver.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -50,11 +48,20 @@
 #include "iscsi_target_stat.h"
 
 #include <target/iscsi/iscsi_transport.h>
+#ifdef MODULE
+/* To avoid link-error caused by 64-bit dividend in module. */
+#ifdef __arm__
+u_int64_t __aeabi_uldivmod(u_int64_t a, u_int64_t b)
+{
+	return div64_u64(a, b);
+}
+#endif /*__arm__*/
+#endif /*MODULE*/
 
 static LIST_HEAD(g_tiqn_list);
 static LIST_HEAD(g_np_list);
 static DEFINE_SPINLOCK(tiqn_lock);
-static DEFINE_SPINLOCK(np_lock);
+static DEFINE_MUTEX(np_lock);
 
 static struct idr tiqn_idr;
 struct idr sess_idr;
@@ -63,7 +70,6 @@ spinlock_t sess_idr_lock;
 
 struct iscsit_global *iscsit_global;
 
-struct kmem_cache *lio_cmd_cache;
 struct kmem_cache *lio_qr_cache;
 struct kmem_cache *lio_dr_cache;
 struct kmem_cache *lio_ooo_cache;
@@ -220,11 +226,6 @@ int iscsit_access_np(struct iscsi_np *np, struct iscsi_portal_group *tpg)
 		spin_unlock_bh(&np->np_thread_lock);
 		return -1;
 	}
-	if (np->np_login_tpg) {
-		pr_err("np->np_login_tpg() is not NULL!\n");
-		spin_unlock_bh(&np->np_thread_lock);
-		return -1;
-	}
 	spin_unlock_bh(&np->np_thread_lock);
 	/*
 	 * Determine if the portal group is accepting storage traffic.
@@ -239,26 +240,38 @@ int iscsit_access_np(struct iscsi_np *np, struct iscsi_portal_group *tpg)
 	/*
 	 * Here we serialize access across the TIQN+TPG Tuple.
 	 */
-	ret = mutex_lock_interruptible(&tpg->np_login_lock);
+	ret = down_interruptible(&tpg->np_login_sem);
 	if ((ret != 0) || signal_pending(current))
 		return -1;
 
-	spin_lock_bh(&np->np_thread_lock);
-	np->np_login_tpg = tpg;
-	spin_unlock_bh(&np->np_thread_lock);
+	spin_lock_bh(&tpg->tpg_state_lock);
+	if (tpg->tpg_state != TPG_STATE_ACTIVE) {
+		spin_unlock_bh(&tpg->tpg_state_lock);
+		up(&tpg->np_login_sem);
+		return -1;
+	}
+	spin_unlock_bh(&tpg->tpg_state_lock);
 
 	return 0;
 }
 
-int iscsit_deaccess_np(struct iscsi_np *np, struct iscsi_portal_group *tpg)
+void iscsit_login_kref_put(struct kref *kref)
+{
+	struct iscsi_tpg_np *tpg_np = container_of(kref,
+				struct iscsi_tpg_np, tpg_np_kref);
+
+	complete(&tpg_np->tpg_np_comp);
+}
+
+int iscsit_deaccess_np(struct iscsi_np *np, struct iscsi_portal_group *tpg,
+		       struct iscsi_tpg_np *tpg_np)
 {
 	struct iscsi_tiqn *tiqn = tpg->tpg_tiqn;
 
-	spin_lock_bh(&np->np_thread_lock);
-	np->np_login_tpg = NULL;
-	spin_unlock_bh(&np->np_thread_lock);
+	up(&tpg->np_login_sem);
 
-	mutex_unlock(&tpg->np_login_lock);
+	if (tpg_np)
+		kref_put(&tpg_np->tpg_np_kref, iscsit_login_kref_put);
 
 	if (tiqn)
 		iscsit_put_tiqn_for_login(tiqn);
@@ -303,6 +316,9 @@ bool iscsit_check_np_match(
 	return false;
 }
 
+/*
+ * Called with mutex np_lock held
+ */
 static struct iscsi_np *iscsit_get_np(
 	struct __kernel_sockaddr_storage *sockaddr,
 	int network_transport)
@@ -310,11 +326,10 @@ static struct iscsi_np *iscsit_get_np(
 	struct iscsi_np *np;
 	bool match;
 
-	spin_lock_bh(&np_lock);
 	list_for_each_entry(np, &g_np_list, np_list) {
-		spin_lock(&np->np_thread_lock);
+		spin_lock_bh(&np->np_thread_lock);
 		if (np->np_thread_state != ISCSI_NP_THREAD_ACTIVE) {
-			spin_unlock(&np->np_thread_lock);
+			spin_unlock_bh(&np->np_thread_lock);
 			continue;
 		}
 
@@ -326,13 +341,11 @@ static struct iscsi_np *iscsit_get_np(
 			 * while iscsi_tpg_add_network_portal() is called.
 			 */
 			np->np_exports++;
-			spin_unlock(&np->np_thread_lock);
-			spin_unlock_bh(&np_lock);
+			spin_unlock_bh(&np->np_thread_lock);
 			return np;
 		}
-		spin_unlock(&np->np_thread_lock);
+		spin_unlock_bh(&np->np_thread_lock);
 	}
-	spin_unlock_bh(&np_lock);
 
 	return NULL;
 }
@@ -346,16 +359,22 @@ struct iscsi_np *iscsit_add_np(
 	struct sockaddr_in6 *sock_in6;
 	struct iscsi_np *np;
 	int ret;
+
+	mutex_lock(&np_lock);
+
 	/*
 	 * Locate the existing struct iscsi_np if already active..
 	 */
 	np = iscsit_get_np(sockaddr, network_transport);
-	if (np)
+	if (np) {
+		mutex_unlock(&np_lock);
 		return np;
+	}
 
 	np = kzalloc(sizeof(struct iscsi_np), GFP_KERNEL);
 	if (!np) {
 		pr_err("Unable to allocate memory for struct iscsi_np\n");
+		mutex_unlock(&np_lock);
 		return ERR_PTR(-ENOMEM);
 	}
 
@@ -378,6 +397,7 @@ struct iscsi_np *iscsit_add_np(
 	ret = iscsi_target_setup_login_socket(np, sockaddr);
 	if (ret != 0) {
 		kfree(np);
+		mutex_unlock(&np_lock);
 		return ERR_PTR(ret);
 	}
 
@@ -386,6 +406,7 @@ struct iscsi_np *iscsit_add_np(
 		pr_err("Unable to create kthread: iscsi_np\n");
 		ret = PTR_ERR(np->np_thread);
 		kfree(np);
+		mutex_unlock(&np_lock);
 		return ERR_PTR(ret);
 	}
 	/*
@@ -396,10 +417,10 @@ struct iscsi_np *iscsit_add_np(
 	 * point because iscsi_np has not been added to g_np_list yet.
 	 */
 	np->np_exports = 1;
+	np->np_thread_state = ISCSI_NP_THREAD_ACTIVE;
 
-	spin_lock_bh(&np_lock);
 	list_add_tail(&np->np_list, &g_np_list);
-	spin_unlock_bh(&np_lock);
+	mutex_unlock(&np_lock);
 
 	pr_debug("CORE[0] - Added Network Portal: %s:%hu on %s\n",
 		np->np_ip, np->np_port, np->np_transport->name);
@@ -410,20 +431,10 @@ struct iscsi_np *iscsit_add_np(
 int iscsit_reset_np_thread(
 	struct iscsi_np *np,
 	struct iscsi_tpg_np *tpg_np,
-	struct iscsi_portal_group *tpg)
+	struct iscsi_portal_group *tpg,
+	bool shutdown)
 {
 	spin_lock_bh(&np->np_thread_lock);
-	if (tpg && tpg_np) {
-		/*
-		 * The reset operation need only be performed when the
-		 * passed struct iscsi_portal_group has a login in progress
-		 * to one of the network portals.
-		 */
-		if (tpg_np->tpg_np->np_login_tpg != tpg) {
-			spin_unlock_bh(&np->np_thread_lock);
-			return 0;
-		}
-	}
 	if (np->np_thread_state == ISCSI_NP_THREAD_INACTIVE) {
 		spin_unlock_bh(&np->np_thread_lock);
 		return 0;
@@ -438,6 +449,12 @@ int iscsit_reset_np_thread(
 	}
 	spin_unlock_bh(&np->np_thread_lock);
 
+	if (tpg_np && shutdown) {
+		kref_put(&tpg_np->tpg_np_kref, iscsit_login_kref_put);
+
+		wait_for_completion(&tpg_np->tpg_np_comp);
+	}
+
 	return 0;
 }
 
@@ -452,6 +469,7 @@ int iscsit_del_np(struct iscsi_np *np)
 	spin_lock_bh(&np->np_thread_lock);
 	np->np_exports--;
 	if (np->np_exports) {
+		np->enabled = true;
 		spin_unlock_bh(&np->np_thread_lock);
 		return 0;
 	}
@@ -465,13 +483,14 @@ int iscsit_del_np(struct iscsi_np *np)
 		 */
 		send_sig(SIGINT, np->np_thread, 1);
 		kthread_stop(np->np_thread);
+		np->np_thread = NULL;
 	}
 
 	np->np_transport->iscsit_free_np(np);
 
-	spin_lock_bh(&np_lock);
+	mutex_lock(&np_lock);
 	list_del(&np->np_list);
-	spin_unlock_bh(&np_lock);
+	mutex_unlock(&np_lock);
 
 	pr_debug("CORE[0] - Removed Network Portal: %s:%hu on %s\n",
 		np->np_ip, np->np_port, np->np_transport->name);
@@ -490,6 +509,24 @@ static int iscsit_queue_rsp(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
 	return 0;
 }
 
+static void iscsit_aborted_task(struct iscsi_conn *conn, struct iscsi_cmd *cmd)
+{
+	bool scsi_cmd = (cmd->iscsi_opcode == ISCSI_OP_SCSI_CMD);
+
+	spin_lock_bh(&conn->cmd_lock);
+	if (!list_empty(&cmd->i_conn_node) &&
+	    !(cmd->se_cmd.transport_state & CMD_T_FABRIC_STOP))
+		list_del_init(&cmd->i_conn_node);
+	spin_unlock_bh(&conn->cmd_lock);
+
+	__iscsit_free_cmd(cmd, scsi_cmd, true);
+}
+
+static enum target_prot_op iscsit_get_sup_prot_ops(struct iscsi_conn *conn)
+{
+	return TARGET_PROT_NORMAL;
+}
+
 static struct iscsit_transport iscsi_target_transport = {
 	.name			= "iSCSI/TCP",
 	.transport_type		= ISCSI_TCP,
@@ -497,7 +534,6 @@ static struct iscsit_transport iscsi_target_transport = {
 	.iscsit_setup_np	= iscsit_setup_np,
 	.iscsit_accept_np	= iscsit_accept_np,
 	.iscsit_free_np		= iscsit_free_np,
-	.iscsit_alloc_cmd	= iscsit_alloc_cmd,
 	.iscsit_get_login_rx	= iscsit_get_login_rx,
 	.iscsit_put_login_tx	= iscsit_put_login_tx,
 	.iscsit_get_dataout	= iscsit_build_r2ts_for_cmd,
@@ -505,11 +541,168 @@ static struct iscsit_transport iscsi_target_transport = {
 	.iscsit_response_queue	= iscsit_response_queue,
 	.iscsit_queue_data_in	= iscsit_queue_rsp,
 	.iscsit_queue_status	= iscsit_queue_rsp,
+	.iscsit_aborted_task	= iscsit_aborted_task,
+	.iscsit_get_sup_prot_ops = iscsit_get_sup_prot_ops,
+};
+
+static struct proc_dir_entry *proc_iscsi_target_dir_entry = NULL,
+                             *proc_status_dir_entry = NULL,
+                             *proc_session_dir_entry = NULL,
+                             *proc_conn_dir_entry = NULL;
+
+static int session_show(struct seq_file *seq, void *v)
+{
+        struct iscsi_tiqn *tiqn = NULL;
+        struct iscsi_portal_group *tpg = NULL;
+        struct se_session *se_sess = NULL;
+        struct iscsi_session *sess = NULL;
+        struct timespec ts;
+	int inst = 1;
+
+        seq_printf(seq, "inst node sid intr_name tgt_name creation_time\n");
+
+        spin_lock(iscsit_global->tiqn_lock);
+        list_for_each_entry(tiqn, iscsit_global->tiqn_list, tiqn_list) {
+                spin_lock(&tiqn->tiqn_tpg_lock);
+                list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
+                        spin_lock(&tpg->tpg_se_tpg.session_lock);
+                        list_for_each_entry(se_sess,
+                                            &tpg->tpg_se_tpg.tpg_sess_list,
+                                            sess_list) {
+                                sess = (struct iscsi_session *)
+                                       se_sess->fabric_sess_ptr;
+				getnstimeofday(&ts);
+                                seq_printf(seq,
+                                               "%d %d %d %s %s %llu\n",
+                                               inst++, tiqn->tiqn_index,
+                                               sess->sid,
+                                               sess->sess_ops->InitiatorName,
+                                               sess->sess_ops->TargetName,
+                                               (ts.tv_sec + ts.tv_nsec / 1000000000) -
+                                               ((get_jiffies_64() - INITIAL_JIFFIES) / HZ) +
+                                               ((sess->creation_time - INITIAL_JIFFIES) / HZ));
+                        }
+                        spin_unlock(&tpg->tpg_se_tpg.session_lock);
+                }
+                spin_unlock(&tiqn->tiqn_tpg_lock);
+        }
+        spin_unlock(iscsit_global->tiqn_lock);	
+
+	return 0;
+}
+
+static int session_seq_open(struct inode *inode, struct file *file)
+{
+	return single_open(file, session_show, NULL);
+}
+
+static struct file_operations session_proc_fops = {
+        .owner = THIS_MODULE,
+        .open = session_seq_open,
+        .read = seq_read,
+        .llseek = seq_lseek,
+        .release = single_release,
 };
 
+static int connection_show(struct seq_file *seq, void *v)
+{
+	struct iscsi_tiqn *tiqn = NULL;
+        struct iscsi_portal_group *tpg = NULL;
+        struct se_session *se_sess = NULL;
+        struct iscsi_session *sess = NULL;
+        struct iscsi_conn *conn = NULL;
+        int inst = 1;
+
+        seq_printf(seq, "inst node sid cid addr_type local_ip local_port rem_ip rem_port\n");
+
+        spin_lock(iscsit_global->tiqn_lock);
+        list_for_each_entry(tiqn, iscsit_global->tiqn_list, tiqn_list) {
+                spin_lock(&tiqn->tiqn_tpg_lock);
+                list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
+                        spin_lock(&tpg->tpg_se_tpg.session_lock);
+                        list_for_each_entry(se_sess,
+                                            &tpg->tpg_se_tpg.tpg_sess_list,
+                                            sess_list) {
+                                sess = (struct iscsi_session *)
+                                       se_sess->fabric_sess_ptr;
+                                list_for_each_entry(conn,
+                                                    &sess->sess_conn_list,
+                                                    conn_list) {
+                                        seq_printf(seq,
+                                               "%d %d %d %d %s %s %d %s %d\n",
+                                               inst++, tiqn->tiqn_index,
+                                               sess->sid, conn->cid,
+                                               conn->login_family == AF_INET6 ? "ipv6" : "ipv4",
+                                               conn->local_ip,
+                                               conn->local_port,
+                                               conn->login_ip,
+                                               conn->login_port);
+                                }
+                        }
+                        spin_unlock(&tpg->tpg_se_tpg.session_lock);
+                }
+                spin_unlock(&tiqn->tiqn_tpg_lock);
+        }
+        spin_unlock(iscsit_global->tiqn_lock);
+
+	return 0;
+}
+
+static int connection_seq_open(struct inode *inode, struct file *file)
+{
+        return single_open(file, connection_show, NULL);
+}
+
+static struct file_operations connection_proc_fops = {
+	.owner = THIS_MODULE,
+	.open = connection_seq_open,
+	.read = seq_read,
+	.llseek = seq_lseek,
+	.release = single_release,
+};
+
+static void create_proc_entries(void)
+{
+	proc_iscsi_target_dir_entry = proc_mkdir("iscsi_target", NULL);
+	if (proc_iscsi_target_dir_entry == NULL) {
+		pr_err("Failed to create proc 'iscsi_target' dir\n");
+	}
+	else {
+		proc_status_dir_entry =
+			proc_mkdir("status", proc_iscsi_target_dir_entry);
+		if (proc_status_dir_entry == NULL) {
+			pr_err("Failed to create proc 'iscsi_target/status' dir\n");
+		}
+		else {
+			proc_session_dir_entry =
+				proc_create("session", 0444,
+                                            proc_status_dir_entry, &session_proc_fops);
+			proc_conn_dir_entry =
+				proc_create("connection", 0444,
+                                            proc_status_dir_entry, &connection_proc_fops);
+		}
+	}
+}
+
+static void remove_proc_entries(void)
+{
+	if (proc_session_dir_entry != NULL) {
+		proc_remove(proc_session_dir_entry);
+	}
+	if (proc_conn_dir_entry != NULL) {
+		proc_remove(proc_conn_dir_entry);
+	}
+	if (proc_status_dir_entry != NULL) {
+		proc_remove(proc_status_dir_entry);
+	}
+	if (proc_iscsi_target_dir_entry != NULL) {
+		proc_remove(proc_iscsi_target_dir_entry);
+	}
+}
+
 static int __init iscsi_target_init_module(void)
 {
-	int ret = 0;
+	int ret = 0, size;
 
 	pr_debug("iSCSI-Target "ISCSIT_VERSION"\n");
 
@@ -518,6 +711,13 @@ static int __init iscsi_target_init_module(void)
 		pr_err("Unable to allocate memory for iscsit_global\n");
 		return -1;
 	}
+
+	iscsit_global->tiqn_list = &g_tiqn_list;
+	iscsit_global->np_list = &g_np_list;
+	iscsit_global->tiqn_lock = &tiqn_lock;
+	iscsit_global->np_lock = &np_lock;
+
+	spin_lock_init(&iscsit_global->ts_bitmap_lock);
 	mutex_init(&auth_id_lock);
 	spin_lock_init(&sess_idr_lock);
 	idr_init(&tiqn_idr);
@@ -527,24 +727,11 @@ static int __init iscsi_target_init_module(void)
 	if (ret < 0)
 		goto out;
 
-	ret = iscsi_thread_set_init();
-	if (ret < 0)
+	size = BITS_TO_LONGS(ISCSIT_BITMAP_BITS) * sizeof(long);
+	iscsit_global->ts_bitmap = vzalloc(size);
+	if (!iscsit_global->ts_bitmap) {
+		pr_err("Unable to allocate iscsit_global->ts_bitmap\n");
 		goto configfs_out;
-
-	if (iscsi_allocate_thread_sets(TARGET_THREAD_SET_COUNT) !=
-			TARGET_THREAD_SET_COUNT) {
-		pr_err("iscsi_allocate_thread_sets() returned"
-			" unexpected value!\n");
-		goto ts_out1;
-	}
-
-	lio_cmd_cache = kmem_cache_create("lio_cmd_cache",
-			sizeof(struct iscsi_cmd), __alignof__(struct iscsi_cmd),
-			0, NULL);
-	if (!lio_cmd_cache) {
-		pr_err("Unable to kmem_cache_create() for"
-				" lio_cmd_cache\n");
-		goto ts_out2;
 	}
 
 	lio_qr_cache = kmem_cache_create("lio_qr_cache",
@@ -553,7 +740,7 @@ static int __init iscsi_target_init_module(void)
 	if (!lio_qr_cache) {
 		pr_err("nable to kmem_cache_create() for"
 				" lio_qr_cache\n");
-		goto cmd_out;
+		goto bitmap_out;
 	}
 
 	lio_dr_cache = kmem_cache_create("lio_dr_cache",
@@ -588,6 +775,8 @@ static int __init iscsi_target_init_module(void)
 	if (iscsit_load_discovery_tpg() < 0)
 		goto r2t_out;
 
+	create_proc_entries();
+
 	return ret;
 r2t_out:
 	kmem_cache_destroy(lio_r2t_cache);
@@ -597,12 +786,8 @@ dr_out:
 	kmem_cache_destroy(lio_dr_cache);
 qr_out:
 	kmem_cache_destroy(lio_qr_cache);
-cmd_out:
-	kmem_cache_destroy(lio_cmd_cache);
-ts_out2:
-	iscsi_deallocate_thread_sets();
-ts_out1:
-	iscsi_thread_set_free();
+bitmap_out:
+	vfree(iscsit_global->ts_bitmap);
 configfs_out:
 	iscsi_target_deregister_configfs();
 out:
@@ -612,11 +797,10 @@ out:
 
 static void __exit iscsi_target_cleanup_module(void)
 {
-	iscsi_deallocate_thread_sets();
-	iscsi_thread_set_free();
+	remove_proc_entries();
+
 	iscsit_release_discovery_tpg();
 	iscsit_unregister_transport(&iscsi_target_transport);
-	kmem_cache_destroy(lio_cmd_cache);
 	kmem_cache_destroy(lio_qr_cache);
 	kmem_cache_destroy(lio_dr_cache);
 	kmem_cache_destroy(lio_ooo_cache);
@@ -624,6 +808,7 @@ static void __exit iscsi_target_cleanup_module(void)
 
 	iscsi_target_deregister_configfs();
 
+	vfree(iscsit_global->ts_bitmap);
 	kfree(iscsit_global);
 }
 
@@ -634,7 +819,7 @@ static int iscsit_add_reject(
 {
 	struct iscsi_cmd *cmd;
 
-	cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+	cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
 	if (!cmd)
 		return -1;
 
@@ -766,7 +951,8 @@ static void iscsit_unmap_iovec(struct iscsi_cmd *cmd)
 
 static void iscsit_ack_from_expstatsn(struct iscsi_conn *conn, u32 exp_statsn)
 {
-	struct iscsi_cmd *cmd;
+	LIST_HEAD(ack_list);
+	struct iscsi_cmd *cmd, *cmd_p;
 
 	conn->exp_statsn = exp_statsn;
 
@@ -774,19 +960,23 @@ static void iscsit_ack_from_expstatsn(struct iscsi_conn *conn, u32 exp_statsn)
 		return;
 
 	spin_lock_bh(&conn->cmd_lock);
-	list_for_each_entry(cmd, &conn->conn_cmd_list, i_conn_node) {
+	list_for_each_entry_safe(cmd, cmd_p, &conn->conn_cmd_list, i_conn_node) {
 		spin_lock(&cmd->istate_lock);
 		if ((cmd->i_state == ISTATE_SENT_STATUS) &&
 		    iscsi_sna_lt(cmd->stat_sn, exp_statsn)) {
 			cmd->i_state = ISTATE_REMOVE;
 			spin_unlock(&cmd->istate_lock);
-			iscsit_add_cmd_to_immediate_queue(cmd, conn,
-						cmd->i_state);
+			list_move_tail(&cmd->i_conn_node, &ack_list);
 			continue;
 		}
 		spin_unlock(&cmd->istate_lock);
 	}
 	spin_unlock_bh(&conn->cmd_lock);
+
+	list_for_each_entry_safe(cmd, cmd_p, &ack_list, i_conn_node) {
+		list_del_init(&cmd->i_conn_node);
+		iscsit_free_cmd(cmd, false);
+	}
 }
 
 static int iscsit_allocate_iovecs(struct iscsi_cmd *cmd)
@@ -813,14 +1003,7 @@ int iscsit_setup_scsi_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 	int iscsi_task_attr;
 	int sam_task_attr;
 
-	spin_lock_bh(&conn->sess->session_stats_lock);
-	conn->sess->cmd_pdus++;
-	if (conn->sess->se_sess->se_node_acl) {
-		spin_lock(&conn->sess->se_sess->se_node_acl->stats_lock);
-		conn->sess->se_sess->se_node_acl->num_cmds++;
-		spin_unlock(&conn->sess->se_sess->se_node_acl->stats_lock);
-	}
-	spin_unlock_bh(&conn->sess->session_stats_lock);
+	atomic_long_inc(&conn->sess->cmd_pdus);
 
 	hdr			= (struct iscsi_scsi_req *) buf;
 	payload_length		= ntoh24(hdr->dlength);
@@ -838,24 +1021,22 @@ int iscsit_setup_scsi_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 	if (((hdr->flags & ISCSI_FLAG_CMD_READ) ||
 	     (hdr->flags & ISCSI_FLAG_CMD_WRITE)) && !hdr->data_length) {
 		/*
-		 * Vmware ESX v3.0 uses a modified Cisco Initiator (v3.4.2)
-		 * that adds support for RESERVE/RELEASE.  There is a bug
-		 * add with this new functionality that sets R/W bits when
-		 * neither CDB carries any READ or WRITE datapayloads.
+		 * From RFC-3720 Section 10.3.1:
+		 *
+		 * "Either or both of R and W MAY be 1 when either the
+		 *  Expected Data Transfer Length and/or Bidirectional Read
+		 *  Expected Data Transfer Length are 0"
+		 *
+		 * For this case, go ahead and clear the unnecssary bits
+		 * to avoid any confusion with ->data_direction.
 		 */
-		if ((hdr->cdb[0] == 0x16) || (hdr->cdb[0] == 0x17)) {
-			hdr->flags &= ~ISCSI_FLAG_CMD_READ;
-			hdr->flags &= ~ISCSI_FLAG_CMD_WRITE;
-			goto done;
-		}
+		hdr->flags &= ~ISCSI_FLAG_CMD_READ;
+		hdr->flags &= ~ISCSI_FLAG_CMD_WRITE;
 
-		pr_err("ISCSI_FLAG_CMD_READ or ISCSI_FLAG_CMD_WRITE"
+		pr_warn("ISCSI_FLAG_CMD_READ or ISCSI_FLAG_CMD_WRITE"
 			" set when Expected Data Transfer Length is 0 for"
-			" CDB: 0x%02x. Bad iSCSI Initiator.\n", hdr->cdb[0]);
-		return iscsit_add_reject_cmd(cmd,
-					     ISCSI_REASON_BOOKMARK_INVALID, buf);
+			" CDB: 0x%02x, Fixing up flags\n", hdr->cdb[0]);
 	}
-done:
 
 	if (!(hdr->flags & ISCSI_FLAG_CMD_READ) &&
 	    !(hdr->flags & ISCSI_FLAG_CMD_WRITE) && (hdr->data_length != 0)) {
@@ -1172,7 +1353,7 @@ iscsit_handle_scsi_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 	 * traditional iSCSI block I/O.
 	 */
 	if (iscsit_allocate_iovecs(cmd) < 0) {
-		return iscsit_add_reject_cmd(cmd,
+		return iscsit_reject_cmd(cmd,
 				ISCSI_REASON_BOOKMARK_NO_RESOURCES, buf);
 	}
 	immed_data = cmd->immediate_data;
@@ -1258,25 +1439,16 @@ iscsit_check_dataout_hdr(struct iscsi_conn *conn, unsigned char *buf,
 	struct iscsi_data *hdr = (struct iscsi_data *)buf;
 	struct iscsi_cmd *cmd = NULL;
 	struct se_cmd *se_cmd;
-	unsigned long flags;
 	u32 payload_length = ntoh24(hdr->dlength);
 	int rc;
 
 	if (!payload_length) {
-		pr_err("DataOUT payload is ZERO, protocol error.\n");
-		return iscsit_add_reject(conn, ISCSI_REASON_PROTOCOL_ERROR,
-					 buf);
+		pr_warn("DataOUT payload is ZERO, ignoring.\n");
+		return 0;
 	}
 
 	/* iSCSI write */
-	spin_lock_bh(&conn->sess->session_stats_lock);
-	conn->sess->rx_data_octets += payload_length;
-	if (conn->sess->se_sess->se_node_acl) {
-		spin_lock(&conn->sess->se_sess->se_node_acl->stats_lock);
-		conn->sess->se_sess->se_node_acl->write_bytes += payload_length;
-		spin_unlock(&conn->sess->se_sess->se_node_acl->stats_lock);
-	}
-	spin_unlock_bh(&conn->sess->session_stats_lock);
+	atomic_long_add(payload_length, &conn->sess->rx_data_octets);
 
 	if (payload_length > conn->conn_ops->MaxXmitDataSegmentLength) {
 		pr_err("DataSegmentLength: %u is greater than"
@@ -1306,7 +1478,7 @@ iscsit_check_dataout_hdr(struct iscsi_conn *conn, unsigned char *buf,
 	if (cmd->data_direction != DMA_TO_DEVICE) {
 		pr_err("Command ITT: 0x%08x received DataOUT for a"
 			" NON-WRITE command.\n", cmd->init_task_tag);
-		return iscsit_reject_cmd(cmd, ISCSI_REASON_PROTOCOL_ERROR, buf);
+		return iscsit_dump_data_payload(conn, payload_length, 1);
 	}
 	se_cmd = &cmd->se_cmd;
 	iscsit_mod_dataout_timer(cmd);
@@ -1335,14 +1507,9 @@ iscsit_check_dataout_hdr(struct iscsi_conn *conn, unsigned char *buf,
 		 */
 
 		/* Something's amiss if we're not in WRITE_PENDING state... */
-		spin_lock_irqsave(&se_cmd->t_state_lock, flags);
 		WARN_ON(se_cmd->t_state != TRANSPORT_WRITE_PENDING);
-		spin_unlock_irqrestore(&se_cmd->t_state_lock, flags);
-
-		spin_lock_irqsave(&se_cmd->t_state_lock, flags);
 		if (!(se_cmd->se_cmd_flags & SCF_SUPPORTED_SAM_OPCODE))
 			dump_unsolicited_data = 1;
-		spin_unlock_irqrestore(&se_cmd->t_state_lock, flags);
 
 		if (dump_unsolicited_data) {
 			/*
@@ -1500,7 +1667,7 @@ EXPORT_SYMBOL(iscsit_check_dataout_payload);
 
 static int iscsit_handle_data_out(struct iscsi_conn *conn, unsigned char *buf)
 {
-	struct iscsi_cmd *cmd;
+	struct iscsi_cmd *cmd = NULL;
 	struct iscsi_data *hdr = (struct iscsi_data *)buf;
 	int rc;
 	bool data_crc_failed = false;
@@ -1520,18 +1687,20 @@ static int iscsit_handle_data_out(struct iscsi_conn *conn, unsigned char *buf)
 	return iscsit_check_dataout_payload(cmd, hdr, data_crc_failed);
 }
 
-int iscsit_handle_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
-			unsigned char *buf)
+int iscsit_setup_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+			 struct iscsi_nopout *hdr)
 {
-	unsigned char *ping_data = NULL;
-	int cmdsn_ret, niov = 0, ret = 0, rx_got, rx_size;
-	u32 checksum, data_crc, padding = 0, payload_length;
-	struct iscsi_cmd *cmd_p = NULL;
-	struct kvec *iov = NULL;
-	struct iscsi_nopout *hdr;
+	u32 payload_length = ntoh24(hdr->dlength);
 
-	hdr			= (struct iscsi_nopout *) buf;
-	payload_length		= ntoh24(hdr->dlength);
+	if (!(hdr->flags & ISCSI_FLAG_CMD_FINAL)) {
+		pr_err("NopOUT Flag's, Left Most Bit not set, protocol error.\n");
+		if (!cmd)
+			return iscsit_add_reject(conn, ISCSI_REASON_PROTOCOL_ERROR,
+						 (unsigned char *)hdr);
+		
+		return iscsit_reject_cmd(cmd, ISCSI_REASON_PROTOCOL_ERROR,
+					 (unsigned char *)hdr);
+	}
 
 	if (hdr->itt == RESERVED_ITT && !(hdr->opcode & ISCSI_OP_IMMEDIATE)) {
 		pr_err("NOPOUT ITT is reserved, but Immediate Bit is"
@@ -1570,11 +1739,6 @@ int iscsit_handle_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 	 * can contain ping data.
 	 */
 	if (hdr->ttt == cpu_to_be32(0xFFFFFFFF)) {
-		if (!cmd)
-			return iscsit_reject_cmd(cmd,
-					ISCSI_REASON_BOOKMARK_NO_RESOURCES,
-					(unsigned char *)hdr);
-
 		cmd->iscsi_opcode	= ISCSI_OP_NOOP_OUT;
 		cmd->i_state		= ISTATE_SEND_NOPIN;
 		cmd->immediate_cmd	= ((hdr->opcode & ISCSI_OP_IMMEDIATE) ?
@@ -1586,8 +1750,87 @@ int iscsit_handle_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 		cmd->data_direction	= DMA_NONE;
 	}
 
+	return 0;
+}
+EXPORT_SYMBOL(iscsit_setup_nop_out);
+
+int iscsit_process_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+			   struct iscsi_nopout *hdr)
+{
+	struct iscsi_cmd *cmd_p = NULL;
+	int cmdsn_ret = 0;
+	/*
+	 * Initiator is expecting a NopIN ping reply..
+	 */
+	if (hdr->itt != RESERVED_ITT) {
+		if (!cmd)
+			return iscsit_add_reject(conn, ISCSI_REASON_PROTOCOL_ERROR,
+						(unsigned char *)hdr);
+
+		spin_lock_bh(&conn->cmd_lock);
+		list_add_tail(&cmd->i_conn_node, &conn->conn_cmd_list);
+		spin_unlock_bh(&conn->cmd_lock);
+
+		iscsit_ack_from_expstatsn(conn, be32_to_cpu(hdr->exp_statsn));
+
+		if (hdr->opcode & ISCSI_OP_IMMEDIATE) {
+			iscsit_add_cmd_to_response_queue(cmd, conn,
+							 cmd->i_state);
+			return 0;
+		}
+
+		cmdsn_ret = iscsit_sequence_cmd(conn, cmd,
+				(unsigned char *)hdr, hdr->cmdsn);
+                if (cmdsn_ret == CMDSN_LOWER_THAN_EXP)
+			return 0;
+		if (cmdsn_ret == CMDSN_ERROR_CANNOT_RECOVER)
+			return -1;
+
+		return 0;
+	}
+	/*
+	 * This was a response to a unsolicited NOPIN ping.
+	 */
+	if (hdr->ttt != cpu_to_be32(0xFFFFFFFF)) {
+		cmd_p = iscsit_find_cmd_from_ttt(conn, be32_to_cpu(hdr->ttt));
+		if (!cmd_p)
+			return -EINVAL;
+
+		iscsit_stop_nopin_response_timer(conn);
+
+		cmd_p->i_state = ISTATE_REMOVE;
+		iscsit_add_cmd_to_immediate_queue(cmd_p, conn, cmd_p->i_state);
+
+		iscsit_start_nopin_timer(conn);
+		return 0;
+	}
+	/*
+	 * Otherwise, initiator is not expecting a NOPIN is response.
+	 * Just ignore for now.
+	 */
+        return 0;
+}
+EXPORT_SYMBOL(iscsit_process_nop_out);
+
+static int iscsit_handle_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+				 unsigned char *buf)
+{
+	unsigned char *ping_data = NULL;
+	struct iscsi_nopout *hdr = (struct iscsi_nopout *)buf;
+	struct kvec *iov = NULL;
+	u32 payload_length = ntoh24(hdr->dlength);
+	int ret;
+
+	ret = iscsit_setup_nop_out(conn, cmd, hdr);
+	if (ret < 0)
+		return 0;
+	/*
+	 * Handle NOP-OUT payload for traditional iSCSI sockets
+	 */
 	if (payload_length && hdr->ttt == cpu_to_be32(0xFFFFFFFF)) {
-		rx_size = payload_length;
+		u32 checksum, data_crc, padding = 0;
+		int niov = 0, rx_got, rx_size = payload_length;
+
 		ping_data = kzalloc(payload_length + 1, GFP_KERNEL);
 		if (!ping_data) {
 			pr_err("Unable to allocate memory for"
@@ -1666,75 +1909,14 @@ int iscsit_handle_nop_out(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 		pr_debug("Ping Data: \"%s\"\n", ping_data);
 	}
 
-	if (hdr->itt != RESERVED_ITT) {
-		if (!cmd) {
-			pr_err("Checking CmdSN for NOPOUT,"
-				" but cmd is NULL!\n");
-			return -1;
-		}
-		/*
-		 * Initiator is expecting a NopIN ping reply,
-		 */
-		spin_lock_bh(&conn->cmd_lock);
-		list_add_tail(&cmd->i_conn_node, &conn->conn_cmd_list);
-		spin_unlock_bh(&conn->cmd_lock);
-
-		iscsit_ack_from_expstatsn(conn, be32_to_cpu(hdr->exp_statsn));
-
-		if (hdr->opcode & ISCSI_OP_IMMEDIATE) {
-			iscsit_add_cmd_to_response_queue(cmd, conn,
-					cmd->i_state);
-			return 0;
-		}
-
-		cmdsn_ret = iscsit_sequence_cmd(conn, cmd,
-				(unsigned char *)hdr, hdr->cmdsn);
-		if (cmdsn_ret == CMDSN_LOWER_THAN_EXP) {
-			ret = 0;
-			goto ping_out;
-		}
-		if (cmdsn_ret == CMDSN_ERROR_CANNOT_RECOVER)
-			return -1;
-
-		return 0;
-	}
-
-	if (hdr->ttt != cpu_to_be32(0xFFFFFFFF)) {
-		/*
-		 * This was a response to a unsolicited NOPIN ping.
-		 */
-		cmd_p = iscsit_find_cmd_from_ttt(conn, be32_to_cpu(hdr->ttt));
-		if (!cmd_p)
-			return -1;
-
-		iscsit_stop_nopin_response_timer(conn);
-
-		cmd_p->i_state = ISTATE_REMOVE;
-		iscsit_add_cmd_to_immediate_queue(cmd_p, conn, cmd_p->i_state);
-		iscsit_start_nopin_timer(conn);
-	} else {
-		/*
-		 * Initiator is not expecting a NOPIN is response.
-		 * Just ignore for now.
-		 *
-		 * iSCSI v19-91 10.18
-		 * "A NOP-OUT may also be used to confirm a changed
-		 *  ExpStatSN if another PDU will not be available
-		 *  for a long time."
-		 */
-		ret = 0;
-		goto out;
-	}
-
-	return 0;
+	return iscsit_process_nop_out(conn, cmd, hdr);
 out:
 	if (cmd)
 		iscsit_free_cmd(cmd, false);
-ping_out:
+
 	kfree(ping_data);
 	return ret;
 }
-EXPORT_SYMBOL(iscsit_handle_nop_out);
 
 int
 iscsit_handle_task_mgt_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
@@ -1951,44 +2133,131 @@ attach:
 EXPORT_SYMBOL(iscsit_handle_task_mgt_cmd);
 
 /* #warning FIXME: Support Text Command parameters besides SendTargets */
-static int iscsit_handle_text_cmd(
-	struct iscsi_conn *conn,
-	unsigned char *buf)
+int
+iscsit_setup_text_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+		      struct iscsi_text *hdr)
 {
-	char *text_ptr, *text_in;
-	int cmdsn_ret, niov = 0, rx_got, rx_size;
-	u32 checksum = 0, data_crc = 0, payload_length;
-	u32 padding = 0, pad_bytes = 0, text_length = 0;
-	struct iscsi_cmd *cmd;
-	struct kvec iov[3];
-	struct iscsi_text *hdr;
-
-	hdr			= (struct iscsi_text *) buf;
-	payload_length		= ntoh24(hdr->dlength);
+	u32 payload_length = ntoh24(hdr->dlength);
 
 	if (payload_length > conn->conn_ops->MaxXmitDataSegmentLength) {
 		pr_err("Unable to accept text parameter length: %u"
 			"greater than MaxXmitDataSegmentLength %u.\n",
 		       payload_length, conn->conn_ops->MaxXmitDataSegmentLength);
-		return iscsit_add_reject(conn, ISCSI_REASON_PROTOCOL_ERROR, buf);
+		return iscsit_reject_cmd(cmd, ISCSI_REASON_PROTOCOL_ERROR,
+					 (unsigned char *)hdr);
+	}
+
+	if (!(hdr->flags & ISCSI_FLAG_CMD_FINAL) ||
+	     (hdr->flags & ISCSI_FLAG_TEXT_CONTINUE)) {
+		pr_err("Multi sequence text commands currently not supported\n");
+		return iscsit_reject_cmd(cmd, ISCSI_REASON_CMD_NOT_SUPPORTED,
+					(unsigned char *)hdr);
 	}
 
 	pr_debug("Got Text Request: ITT: 0x%08x, CmdSN: 0x%08x,"
 		" ExpStatSN: 0x%08x, Length: %u\n", hdr->itt, hdr->cmdsn,
 		hdr->exp_statsn, payload_length);
 
-	rx_size = text_length = payload_length;
-	if (text_length) {
-		text_in = kzalloc(text_length, GFP_KERNEL);
+	cmd->iscsi_opcode	= ISCSI_OP_TEXT;
+	cmd->i_state		= ISTATE_SEND_TEXTRSP;
+	cmd->immediate_cmd	= ((hdr->opcode & ISCSI_OP_IMMEDIATE) ? 1 : 0);
+	conn->sess->init_task_tag = cmd->init_task_tag  = hdr->itt;
+	cmd->targ_xfer_tag	= 0xFFFFFFFF;
+	cmd->cmd_sn		= be32_to_cpu(hdr->cmdsn);
+	cmd->exp_stat_sn	= be32_to_cpu(hdr->exp_statsn);
+	cmd->data_direction	= DMA_NONE;
+
+	return 0;
+}
+EXPORT_SYMBOL(iscsit_setup_text_cmd);
+
+int
+iscsit_process_text_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+			struct iscsi_text *hdr)
+{
+	unsigned char *text_in = cmd->text_in_ptr, *text_ptr;
+	int cmdsn_ret;
+
+	if (!text_in) {
+		pr_err("Unable to locate text_in buffer for sendtargets"
+		       " discovery\n");
+		goto reject;
+	}
+	if (strncmp("SendTargets", text_in, 11) != 0) {
+		pr_err("Received Text Data that is not"
+			" SendTargets, cannot continue.\n");
+		goto reject;
+	}
+	text_ptr = strchr(text_in, '=');
+	if (!text_ptr) {
+		pr_err("No \"=\" separator found in Text Data,"
+			"  cannot continue.\n");
+		goto reject;
+	}
+	if (!strncmp("=All", text_ptr, 4)) {
+		cmd->cmd_flags |= IFC_SENDTARGETS_ALL;
+	} else if (!strncmp("=iqn.", text_ptr, 5) ||
+		   !strncmp("=eui.", text_ptr, 5)) {
+		cmd->cmd_flags |= IFC_SENDTARGETS_SINGLE;
+	} else {
+		pr_err("Unable to locate valid SendTargets=%s value\n", text_ptr);
+		goto reject;
+	}
+
+	spin_lock_bh(&conn->cmd_lock);
+	list_add_tail(&cmd->i_conn_node, &conn->conn_cmd_list);
+	spin_unlock_bh(&conn->cmd_lock);
+
+	iscsit_ack_from_expstatsn(conn, be32_to_cpu(hdr->exp_statsn));
+
+	if (!(hdr->opcode & ISCSI_OP_IMMEDIATE)) {
+		cmdsn_ret = iscsit_sequence_cmd(conn, cmd,
+				(unsigned char *)hdr, hdr->cmdsn);
+		if (cmdsn_ret == CMDSN_ERROR_CANNOT_RECOVER)
+			return -1;
+
+		return 0;
+	}
+
+	return iscsit_execute_cmd(cmd, 0);
+
+reject:
+	return iscsit_reject_cmd(cmd, ISCSI_REASON_PROTOCOL_ERROR,
+				 (unsigned char *)hdr);
+}
+EXPORT_SYMBOL(iscsit_process_text_cmd);
+
+static int
+iscsit_handle_text_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
+		       unsigned char *buf)
+{
+	struct iscsi_text *hdr = (struct iscsi_text *)buf;
+	char *text_in = NULL;
+	u32 payload_length = ntoh24(hdr->dlength);
+	int rx_size, rc;
+
+	rc = iscsit_setup_text_cmd(conn, cmd, hdr);
+	if (rc < 0)
+		return 0;
+
+	rx_size = payload_length;
+	if (payload_length) {
+		u32 checksum = 0, data_crc = 0;
+		u32 padding = 0, pad_bytes = 0;
+		int niov = 0, rx_got;
+		struct kvec iov[3];
+
+		text_in = kzalloc(payload_length, GFP_KERNEL);
 		if (!text_in) {
 			pr_err("Unable to allocate memory for"
 				" incoming text parameters\n");
-			return -1;
+			goto reject;
 		}
+		cmd->text_in_ptr = text_in;
 
 		memset(iov, 0, 3 * sizeof(struct kvec));
 		iov[niov].iov_base	= text_in;
-		iov[niov++].iov_len	= text_length;
+		iov[niov++].iov_len	= payload_length;
 
 		padding = ((-payload_length) & 3);
 		if (padding != 0) {
@@ -2005,14 +2274,12 @@ static int iscsit_handle_text_cmd(
 		}
 
 		rx_got = rx_data(conn, &iov[0], niov, rx_size);
-		if (rx_got != rx_size) {
-			kfree(text_in);
-			return -1;
-		}
+		if (rx_got != rx_size)
+			goto reject;
 
 		if (conn->conn_ops->DataDigest) {
 			iscsit_do_crypto_hash_buf(&conn->conn_rx_hash,
-					text_in, text_length,
+					text_in, payload_length,
 					padding, (u8 *)&pad_bytes,
 					(u8 *)&data_crc);
 
@@ -2024,8 +2291,7 @@ static int iscsit_handle_text_cmd(
 					pr_err("Unable to recover from"
 					" Text Data digest failure while in"
 						" ERL=0.\n");
-					kfree(text_in);
-					return -1;
+					goto reject;
 				} else {
 					/*
 					 * Silently drop this PDU and let the
@@ -2040,67 +2306,22 @@ static int iscsit_handle_text_cmd(
 			} else {
 				pr_debug("Got CRC32C DataDigest"
 					" 0x%08x for %u bytes of text data.\n",
-						checksum, text_length);
+						checksum, payload_length);
 			}
 		}
-		text_in[text_length - 1] = '\0';
+		text_in[payload_length - 1] = '\0';
 		pr_debug("Successfully read %d bytes of text"
-				" data.\n", text_length);
-
-		if (strncmp("SendTargets", text_in, 11) != 0) {
-			pr_err("Received Text Data that is not"
-				" SendTargets, cannot continue.\n");
-			kfree(text_in);
-			return -1;
-		}
-		text_ptr = strchr(text_in, '=');
-		if (!text_ptr) {
-			pr_err("No \"=\" separator found in Text Data,"
-				"  cannot continue.\n");
-			kfree(text_in);
-			return -1;
-		}
-		if (strncmp("=All", text_ptr, 4) != 0) {
-			pr_err("Unable to locate All value for"
-				" SendTargets key,  cannot continue.\n");
-			kfree(text_in);
-			return -1;
-		}
-/*#warning Support SendTargets=(iSCSI Target Name/Nothing) values. */
-		kfree(text_in);
+				" data.\n", payload_length);
 	}
 
-	cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
-	if (!cmd)
-		return iscsit_add_reject(conn,
-					 ISCSI_REASON_BOOKMARK_NO_RESOURCES, buf);
-
-	cmd->iscsi_opcode	= ISCSI_OP_TEXT;
-	cmd->i_state		= ISTATE_SEND_TEXTRSP;
-	cmd->immediate_cmd	= ((hdr->opcode & ISCSI_OP_IMMEDIATE) ? 1 : 0);
-	conn->sess->init_task_tag = cmd->init_task_tag	= hdr->itt;
-	cmd->targ_xfer_tag	= 0xFFFFFFFF;
-	cmd->cmd_sn		= be32_to_cpu(hdr->cmdsn);
-	cmd->exp_stat_sn	= be32_to_cpu(hdr->exp_statsn);
-	cmd->data_direction	= DMA_NONE;
-
-	spin_lock_bh(&conn->cmd_lock);
-	list_add_tail(&cmd->i_conn_node, &conn->conn_cmd_list);
-	spin_unlock_bh(&conn->cmd_lock);
-
-	iscsit_ack_from_expstatsn(conn, be32_to_cpu(hdr->exp_statsn));
+	return iscsit_process_text_cmd(conn, cmd, hdr);
 
-	if (!(hdr->opcode & ISCSI_OP_IMMEDIATE)) {
-		cmdsn_ret = iscsit_sequence_cmd(conn, cmd,
-				(unsigned char *)hdr, hdr->cmdsn);
-		if (cmdsn_ret == CMDSN_ERROR_CANNOT_RECOVER)
-			return -1;
-
-		return 0;
-	}
-
-	return iscsit_execute_cmd(cmd, 0);
+reject:
+	kfree(cmd->text_in_ptr);
+	cmd->text_in_ptr = NULL;
+	return iscsit_reject_cmd(cmd, ISCSI_REASON_PROTOCOL_ERROR, buf);
 }
+EXPORT_SYMBOL(iscsit_handle_text_cmd);
 
 int iscsit_logout_closesession(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 {
@@ -2448,6 +2669,7 @@ static void iscsit_build_conn_drop_async_message(struct iscsi_conn *conn)
 {
 	struct iscsi_cmd *cmd;
 	struct iscsi_conn *conn_p;
+	bool found = false;
 
 	/*
 	 * Only send a Asynchronous Message on connections whos network
@@ -2456,14 +2678,15 @@ static void iscsit_build_conn_drop_async_message(struct iscsi_conn *conn)
 	list_for_each_entry(conn_p, &conn->sess->sess_conn_list, conn_list) {
 		if (conn_p->conn_state == TARG_CONN_STATE_LOGGED_IN) {
 			iscsit_inc_conn_usage_count(conn_p);
+			found = true;
 			break;
 		}
 	}
 
-	if (!conn_p)
+	if (!found)
 		return;
 
-	cmd = iscsit_allocate_cmd(conn_p, GFP_ATOMIC);
+	cmd = iscsit_allocate_cmd(conn_p, TASK_RUNNING);
 	if (!cmd) {
 		iscsit_dec_conn_usage_count(conn_p);
 		return;
@@ -2609,14 +2832,7 @@ static int iscsit_send_datain(struct iscsi_cmd *cmd, struct iscsi_conn *conn)
 		return -1;
 	}
 
-	spin_lock_bh(&conn->sess->session_stats_lock);
-	conn->sess->tx_data_octets += datain.length;
-	if (conn->sess->se_sess->se_node_acl) {
-		spin_lock(&conn->sess->se_sess->se_node_acl->stats_lock);
-		conn->sess->se_sess->se_node_acl->read_bytes += datain.length;
-		spin_unlock(&conn->sess->se_sess->se_node_acl->stats_lock);
-	}
-	spin_unlock_bh(&conn->sess->session_stats_lock);
+	atomic_long_add(datain.length, &conn->sess->tx_data_octets);
 	/*
 	 * Special case for successfully execution w/ both DATAIN
 	 * and Sense Data.
@@ -3141,9 +3357,7 @@ void iscsit_build_rsp_pdu(struct iscsi_cmd *cmd, struct iscsi_conn *conn,
 	if (inc_stat_sn)
 		cmd->stat_sn = conn->stat_sn++;
 
-	spin_lock_bh(&conn->sess->session_stats_lock);
-	conn->sess->rsp_pdus++;
-	spin_unlock_bh(&conn->sess->session_stats_lock);
+	atomic_long_inc(&conn->sess->rsp_pdus);
 
 	memset(hdr, 0, ISCSI_HDR_LEN);
 	hdr->opcode		= ISCSI_OP_SCSI_CMD_RSP;
@@ -3260,8 +3474,6 @@ static u8 iscsit_convert_tcm_tmr_rsp(struct se_tmr_req *se_tmr)
 		return ISCSI_TMF_RSP_NO_LUN;
 	case TMR_TASK_MGMT_FUNCTION_NOT_SUPPORTED:
 		return ISCSI_TMF_RSP_NOT_SUPPORTED;
-	case TMR_FUNCTION_AUTHORIZATION_FAILED:
-		return ISCSI_TMF_RSP_AUTH_FAILED;
 	case TMR_FUNCTION_REJECTED:
 	default:
 		return ISCSI_TMF_RSP_REJECTED;
@@ -3347,7 +3559,9 @@ static bool iscsit_check_inaddr_any(struct iscsi_np *np)
 
 #define SENDTARGETS_BUF_LIMIT 32768U
 
-static int iscsit_build_sendtargets_response(struct iscsi_cmd *cmd)
+static int
+iscsit_build_sendtargets_response(struct iscsi_cmd *cmd,
+				  enum iscsit_transport_type network_transport)
 {
 	char *payload = NULL;
 	struct iscsi_conn *conn = cmd->conn;
@@ -3355,7 +3569,9 @@ static int iscsit_build_sendtargets_response(struct iscsi_cmd *cmd)
 	struct iscsi_tiqn *tiqn;
 	struct iscsi_tpg_np *tpg_np;
 	int buffer_len, end_of_buf = 0, len = 0, payload_len = 0;
+	int target_name_printed;
 	unsigned char buf[ISCSI_IQN_LEN+12]; /* iqn + "TargetName=" + \0 */
+	unsigned char *text_in = cmd->text_in_ptr, *text_ptr = NULL;
 
 	buffer_len = max(conn->conn_ops->MaxRecvDataSegmentLength,
 			 SENDTARGETS_BUF_LIMIT);
@@ -3366,22 +3582,48 @@ static int iscsit_build_sendtargets_response(struct iscsi_cmd *cmd)
 				" response.\n");
 		return -ENOMEM;
 	}
+	/*
+	 * Locate pointer to iqn./eui. string for IFC_SENDTARGETS_SINGLE
+	 * explicit case..
+	 */
+	if (cmd->cmd_flags & IFC_SENDTARGETS_SINGLE) {
+		text_ptr = strchr(text_in, '=');
+		if (!text_ptr) {
+			pr_err("Unable to locate '=' string in text_in:"
+			       " %s\n", text_in);
+			kfree(payload);
+			return -EINVAL;
+		}
+		/*
+		 * Skip over '=' character..
+		 */
+		text_ptr += 1;
+	}
 
 	spin_lock(&tiqn_lock);
 	list_for_each_entry(tiqn, &g_tiqn_list, tiqn_list) {
-		len = sprintf(buf, "TargetName=%s", tiqn->tiqn);
-		len += 1;
-
-		if ((len + payload_len) > buffer_len) {
-			end_of_buf = 1;
-			goto eob;
+		if ((cmd->cmd_flags & IFC_SENDTARGETS_SINGLE) &&
+		     strcmp(tiqn->tiqn, text_ptr)) {
+			continue;
 		}
-		memcpy(payload + payload_len, buf, len);
-		payload_len += len;
+
+		target_name_printed = 0;
 
 		spin_lock(&tiqn->tiqn_tpg_lock);
 		list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
 
+			/* If demo_mode_discovery=0 and generate_node_acls=0
+			 * (demo mode dislabed) do not return
+			 * TargetName+TargetAddress unless a NodeACL exists.
+			 */
+
+			if ((tpg->tpg_attrib.generate_node_acls == 0) &&
+			    (tpg->tpg_attrib.demo_mode_discovery == 0) &&
+			    (!core_tpg_get_initiator_node_acl(&tpg->tpg_se_tpg,
+				cmd->conn->sess->sess_ops->InitiatorName))) {
+				continue;
+			}
+
 			spin_lock(&tpg->tpg_state_lock);
 			if ((tpg->tpg_state == TPG_STATE_FREE) ||
 			    (tpg->tpg_state == TPG_STATE_INACTIVE)) {
@@ -3396,13 +3638,30 @@ static int iscsit_build_sendtargets_response(struct iscsi_cmd *cmd)
 				struct iscsi_np *np = tpg_np->tpg_np;
 				bool inaddr_any = iscsit_check_inaddr_any(np);
 
+				if (np->np_network_transport != network_transport)
+					continue;
+
+				if (!target_name_printed) {
+					len = sprintf(buf, "TargetName=%s",
+						      tiqn->tiqn);
+					len += 1;
+
+					if ((len + payload_len) > buffer_len) {
+						spin_unlock(&tpg->tpg_np_lock);
+						spin_unlock(&tiqn->tiqn_tpg_lock);
+						end_of_buf = 1;
+						goto eob;
+					}
+					memcpy(payload + payload_len, buf, len);
+					payload_len += len;
+					target_name_printed = 1;
+				}
+
 				len = sprintf(buf, "TargetAddress="
-					"%s%s%s:%hu,%hu",
-					(np->np_sockaddr.ss_family == AF_INET6) ?
-					"[" : "", (inaddr_any == false) ?
+					"%s:%hu,%hu",
+					(inaddr_any == false) ?
 						np->np_ip : conn->local_ip,
-					(np->np_sockaddr.ss_family == AF_INET6) ?
-					"]" : "", (inaddr_any == false) ?
+					(inaddr_any == false) ?
 						np->np_port : conn->local_port,
 					tpg->tpgt);
 				len += 1;
@@ -3422,6 +3681,9 @@ static int iscsit_build_sendtargets_response(struct iscsi_cmd *cmd)
 eob:
 		if (end_of_buf)
 			break;
+
+		if (cmd->cmd_flags & IFC_SENDTARGETS_SINGLE)
+			break;
 	}
 	spin_unlock(&tiqn_lock);
 
@@ -3430,6 +3692,38 @@ eob:
 	return payload_len;
 }
 
+int
+iscsit_build_text_rsp(struct iscsi_cmd *cmd, struct iscsi_conn *conn,
+		      struct iscsi_text_rsp *hdr,
+		      enum iscsit_transport_type network_transport)
+{
+	int text_length, padding;
+
+	text_length = iscsit_build_sendtargets_response(cmd, network_transport);
+	if (text_length < 0)
+		return text_length;
+
+	hdr->opcode = ISCSI_OP_TEXT_RSP;
+	hdr->flags |= ISCSI_FLAG_CMD_FINAL;
+	padding = ((-text_length) & 3);
+	hton24(hdr->dlength, text_length);
+	hdr->itt = cmd->init_task_tag;
+	hdr->ttt = cpu_to_be32(cmd->targ_xfer_tag);
+	cmd->stat_sn = conn->stat_sn++;
+	hdr->statsn = cpu_to_be32(cmd->stat_sn);
+
+	iscsit_increment_maxcmdsn(cmd, conn->sess);
+	hdr->exp_cmdsn = cpu_to_be32(conn->sess->exp_cmd_sn);
+	hdr->max_cmdsn = cpu_to_be32(conn->sess->max_cmd_sn);
+
+	pr_debug("Built Text Response: ITT: 0x%08x, StatSN: 0x%08x,"
+		" Length: %u, CID: %hu\n", cmd->init_task_tag, cmd->stat_sn,
+		text_length, conn->cid);
+
+	return text_length + padding;
+}
+EXPORT_SYMBOL(iscsit_build_text_rsp);
+
 /*
  *	FIXME: Add support for F_BIT and C_BIT when the length is longer than
  *	MaxRecvDataSegmentLength.
@@ -3438,44 +3732,23 @@ static int iscsit_send_text_rsp(
 	struct iscsi_cmd *cmd,
 	struct iscsi_conn *conn)
 {
-	struct iscsi_text_rsp *hdr;
+	struct iscsi_text_rsp *hdr = (struct iscsi_text_rsp *)cmd->pdu;
 	struct kvec *iov;
-	u32 padding = 0, tx_size = 0;
-	int text_length, iov_count = 0;
-
-	text_length = iscsit_build_sendtargets_response(cmd);
-	if (text_length < 0)
-		return text_length;
-
-	padding = ((-text_length) & 3);
-	if (padding != 0) {
-		memset(cmd->buf_ptr + text_length, 0, padding);
-		pr_debug("Attaching %u additional bytes for"
-			" padding.\n", padding);
-	}
-
-	hdr			= (struct iscsi_text_rsp *) cmd->pdu;
-	memset(hdr, 0, ISCSI_HDR_LEN);
-	hdr->opcode		= ISCSI_OP_TEXT_RSP;
-	hdr->flags		|= ISCSI_FLAG_CMD_FINAL;
-	hton24(hdr->dlength, text_length);
-	hdr->itt		= cmd->init_task_tag;
-	hdr->ttt		= cpu_to_be32(cmd->targ_xfer_tag);
-	cmd->stat_sn		= conn->stat_sn++;
-	hdr->statsn		= cpu_to_be32(cmd->stat_sn);
+	u32 tx_size = 0;
+	int text_length, iov_count = 0, rc;
 
-	iscsit_increment_maxcmdsn(cmd, conn->sess);
-	hdr->exp_cmdsn		= cpu_to_be32(conn->sess->exp_cmd_sn);
-	hdr->max_cmdsn		= cpu_to_be32(conn->sess->max_cmd_sn);
+	rc = iscsit_build_text_rsp(cmd, conn, hdr, ISCSI_TCP);
+	if (rc < 0)
+		return rc;
 
+	text_length = rc;
 	iov = &cmd->iov_misc[0];
-
 	iov[iov_count].iov_base = cmd->pdu;
 	iov[iov_count++].iov_len = ISCSI_HDR_LEN;
 	iov[iov_count].iov_base	= cmd->buf_ptr;
-	iov[iov_count++].iov_len = text_length + padding;
+	iov[iov_count++].iov_len = text_length;
 
-	tx_size += (ISCSI_HDR_LEN + text_length + padding);
+	tx_size += (ISCSI_HDR_LEN + text_length);
 
 	if (conn->conn_ops->HeaderDigest) {
 		u32 *header_digest = (u32 *)&cmd->pdu[ISCSI_HDR_LEN];
@@ -3491,7 +3764,7 @@ static int iscsit_send_text_rsp(
 
 	if (conn->conn_ops->DataDigest) {
 		iscsit_do_crypto_hash_buf(&conn->conn_tx_hash,
-				cmd->buf_ptr, (text_length + padding),
+				cmd->buf_ptr, text_length,
 				0, NULL, (u8 *)&cmd->data_crc);
 
 		iov[iov_count].iov_base	= &cmd->data_crc;
@@ -3499,16 +3772,13 @@ static int iscsit_send_text_rsp(
 		tx_size	+= ISCSI_CRC_LEN;
 
 		pr_debug("Attaching DataDigest for %u bytes of text"
-			" data, CRC 0x%08x\n", (text_length + padding),
+			" data, CRC 0x%08x\n", text_length,
 			cmd->data_crc);
 	}
 
 	cmd->iov_misc_count = iov_count;
 	cmd->tx_size = tx_size;
 
-	pr_debug("Built Text Response: ITT: 0x%08x, StatSN: 0x%08x,"
-		" Length: %u, CID: %hu\n", cmd->init_task_tag, cmd->stat_sn,
-			text_length, conn->cid);
 	return 0;
 }
 
@@ -3581,17 +3851,16 @@ static int iscsit_send_reject(
 
 void iscsit_thread_get_cpumask(struct iscsi_conn *conn)
 {
-	struct iscsi_thread_set *ts = conn->thread_set;
 	int ord, cpu;
 	/*
-	 * thread_id is assigned from iscsit_global->ts_bitmap from
-	 * within iscsi_thread_set.c:iscsi_allocate_thread_sets()
+	 * bitmap_id is assigned from iscsit_global->ts_bitmap from
+	 * within iscsit_start_kthreads()
 	 *
-	 * Here we use thread_id to determine which CPU that this
-	 * iSCSI connection's iscsi_thread_set will be scheduled to
+	 * Here we use bitmap_id to determine which CPU that this
+	 * iSCSI connection's RX/TX threads will be scheduled to
 	 * execute upon.
 	 */
-	ord = ts->thread_id % cpumask_weight(cpu_online_mask);
+	ord = conn->bitmap_id % cpumask_weight(cpu_online_mask);
 	for_each_online_cpu(cpu) {
 		if (ord-- == 0) {
 			cpumask_set_cpu(cpu, conn->conn_cpumask);
@@ -3647,7 +3916,7 @@ iscsit_immediate_queue(struct iscsi_conn *conn, struct iscsi_cmd *cmd, int state
 		break;
 	case ISTATE_REMOVE:
 		spin_lock_bh(&conn->cmd_lock);
-		list_del(&cmd->i_conn_node);
+		list_del_init(&cmd->i_conn_node);
 		spin_unlock_bh(&conn->cmd_lock);
 
 		iscsit_free_cmd(cmd, false);
@@ -3783,7 +4052,7 @@ check_rsp_state:
 	switch (state) {
 	case ISTATE_SEND_LOGOUTRSP:
 		if (!iscsit_logout_post_handler(cmd, conn))
-			goto restart;
+			return -ECONNRESET;
 		/* fall through */
 	case ISTATE_SEND_STATUS:
 	case ISTATE_SEND_ASYNCMSG:
@@ -3811,8 +4080,6 @@ check_rsp_state:
 
 err:
 	return -1;
-restart:
-	return -EAGAIN;
 }
 
 static int iscsit_handle_response_queue(struct iscsi_conn *conn)
@@ -3839,21 +4106,13 @@ static int iscsit_handle_response_queue(struct iscsi_conn *conn)
 int iscsi_target_tx_thread(void *arg)
 {
 	int ret = 0;
-	struct iscsi_conn *conn;
-	struct iscsi_thread_set *ts = arg;
+	struct iscsi_conn *conn = arg;
 	/*
 	 * Allow ourselves to be interrupted by SIGINT so that a
 	 * connection recovery / failure event can be triggered externally.
 	 */
 	allow_signal(SIGINT);
 
-restart:
-	conn = iscsi_tx_thread_pre_handler(ts);
-	if (!conn)
-		goto out;
-
-	ret = 0;
-
 	while (!kthread_should_stop()) {
 		/*
 		 * Ensure that both TX and RX per connection kthreads
@@ -3862,11 +4121,9 @@ restart:
 		iscsit_thread_check_cpumask(conn, current, 1);
 
 		wait_event_interruptible(conn->queues_wq,
-					 !iscsit_conn_all_queues_empty(conn) ||
-					 ts->status == ISCSI_THREAD_SET_RESET);
+					 !iscsit_conn_all_queues_empty(conn));
 
-		if ((ts->status == ISCSI_THREAD_SET_RESET) ||
-		     signal_pending(current))
+		if (signal_pending(current))
 			goto transport_err;
 
 get_immediate:
@@ -3877,15 +4134,20 @@ get_immediate:
 		ret = iscsit_handle_response_queue(conn);
 		if (ret == 1)
 			goto get_immediate;
-		else if (ret == -EAGAIN)
-			goto restart;
+		else if (ret == -ECONNRESET)
+			goto out;
 		else if (ret < 0)
 			goto transport_err;
 	}
 
 transport_err:
-	iscsit_take_action_for_connection_exit(conn);
-	goto restart;
+	/*
+	 * Avoid the normal connection failure code-path if this connection
+	 * is still within LOGIN mode, and iscsi_np process context is
+	 * responsible for cleaning up the early connection failure.
+	 */
+	if (conn->conn_state != TARG_CONN_STATE_IN_LOGIN)
+		iscsit_take_action_for_connection_exit(conn);
 out:
 	return 0;
 }
@@ -3898,7 +4160,7 @@ static int iscsi_target_rx_opcode(struct iscsi_conn *conn, unsigned char *buf)
 
 	switch (hdr->opcode & ISCSI_OPCODE_MASK) {
 	case ISCSI_OP_SCSI_CMD:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
 		if (!cmd)
 			goto reject;
 
@@ -3910,24 +4172,28 @@ static int iscsi_target_rx_opcode(struct iscsi_conn *conn, unsigned char *buf)
 	case ISCSI_OP_NOOP_OUT:
 		cmd = NULL;
 		if (hdr->ttt == cpu_to_be32(0xFFFFFFFF)) {
-			cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+			cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
 			if (!cmd)
 				goto reject;
 		}
 		ret = iscsit_handle_nop_out(conn, cmd, buf);
 		break;
 	case ISCSI_OP_SCSI_TMFUNC:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
 		if (!cmd)
 			goto reject;
 
 		ret = iscsit_handle_task_mgt_cmd(conn, cmd, buf);
 		break;
 	case ISCSI_OP_TEXT:
-		ret = iscsit_handle_text_cmd(conn, buf);
+		cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
+		if (!cmd)
+			goto reject;
+
+		ret = iscsit_handle_text_cmd(conn, cmd, buf);
 		break;
 	case ISCSI_OP_LOGOUT:
-		cmd = iscsit_allocate_cmd(conn, GFP_KERNEL);
+		cmd = iscsit_allocate_cmd(conn, TASK_INTERRUPTIBLE);
 		if (!cmd)
 			goto reject;
 
@@ -3965,35 +4231,46 @@ reject:
 	return iscsit_add_reject(conn, ISCSI_REASON_BOOKMARK_NO_RESOURCES, buf);
 }
 
+static bool iscsi_target_check_conn_state(struct iscsi_conn *conn)
+{
+	bool ret;
+
+	spin_lock_bh(&conn->state_lock);
+	ret = (conn->conn_state != TARG_CONN_STATE_LOGGED_IN);
+	spin_unlock_bh(&conn->state_lock);
+
+	return ret;
+}
+
 int iscsi_target_rx_thread(void *arg)
 {
-	int ret;
+	int ret, rc;
 	u8 buffer[ISCSI_HDR_LEN], opcode;
 	u32 checksum = 0, digest = 0;
-	struct iscsi_conn *conn = NULL;
-	struct iscsi_thread_set *ts = arg;
+	struct iscsi_conn *conn = arg;
 	struct kvec iov;
 	/*
 	 * Allow ourselves to be interrupted by SIGINT so that a
 	 * connection recovery / failure event can be triggered externally.
 	 */
 	allow_signal(SIGINT);
-
-restart:
-	conn = iscsi_rx_thread_pre_handler(ts);
-	if (!conn)
-		goto out;
+	/*
+	 * Wait for iscsi_post_login_handler() to complete before allowing
+	 * incoming iscsi/tcp socket I/O, and/or failing the connection.
+	 */
+	rc = wait_for_completion_interruptible(&conn->rx_login_comp);
+	if (rc < 0 || iscsi_target_check_conn_state(conn))
+		return 0;
 
 	if (conn->conn_transport->transport_type == ISCSI_INFINIBAND) {
 		struct completion comp;
-		int rc;
 
 		init_completion(&comp);
 		rc = wait_for_completion_interruptible(&comp);
 		if (rc < 0)
 			goto transport_err;
 
-		goto out;
+		goto transport_err;
 	}
 
 	while (!kthread_should_stop()) {
@@ -4015,11 +4292,6 @@ restart:
 			goto transport_err;
 		}
 
-		/*
-		 * Set conn->bad_hdr for use with REJECT PDUs.
-		 */
-		memcpy(&conn->bad_hdr, &buffer, ISCSI_HDR_LEN);
-
 		if (conn->conn_ops->HeaderDigest) {
 			iov.iov_base	= &digest;
 			iov.iov_len	= ISCSI_CRC_LEN;
@@ -4043,9 +4315,7 @@ restart:
 				 * hit default in the switch below.
 				 */
 				memset(buffer, 0xff, ISCSI_HDR_LEN);
-				spin_lock_bh(&conn->sess->session_stats_lock);
-				conn->sess->conn_digest_errors++;
-				spin_unlock_bh(&conn->sess->session_stats_lock);
+				atomic_long_inc(&conn->sess->conn_digest_errors);
 			} else {
 				pr_debug("Got HeaderDigest CRC32C"
 						" 0x%08x\n", checksum);
@@ -4076,13 +4346,12 @@ transport_err:
 	if (!signal_pending(current))
 		atomic_set(&conn->transport_failed, 1);
 	iscsit_take_action_for_connection_exit(conn);
-	goto restart;
-out:
 	return 0;
 }
 
 static void iscsit_release_commands_from_conn(struct iscsi_conn *conn)
 {
+	LIST_HEAD(tmp_list);
 	struct iscsi_cmd *cmd = NULL, *cmd_tmp = NULL;
 	struct iscsi_session *sess = conn->sess;
 	/*
@@ -4091,18 +4360,26 @@ static void iscsit_release_commands_from_conn(struct iscsi_conn *conn)
 	 * has been reset -> returned sleeping pre-handler state.
 	 */
 	spin_lock_bh(&conn->cmd_lock);
-	list_for_each_entry_safe(cmd, cmd_tmp, &conn->conn_cmd_list, i_conn_node) {
+	list_splice_init(&conn->conn_cmd_list, &tmp_list);
 
-		list_del(&cmd->i_conn_node);
-		spin_unlock_bh(&conn->cmd_lock);
+	list_for_each_entry(cmd, &tmp_list, i_conn_node) {
+		struct se_cmd *se_cmd = &cmd->se_cmd;
 
-		iscsit_increment_maxcmdsn(cmd, sess);
+		if (se_cmd->se_tfo != NULL) {
+			spin_lock(&se_cmd->t_state_lock);
+			se_cmd->transport_state |= CMD_T_FABRIC_STOP;
+			spin_unlock(&se_cmd->t_state_lock);
+		}
+	}
+	spin_unlock_bh(&conn->cmd_lock);
 
+	list_for_each_entry_safe(cmd, cmd_tmp, &tmp_list, i_conn_node) {
+		list_del_init(&cmd->i_conn_node);
+
+		iscsit_increment_maxcmdsn(cmd, sess);
 		iscsit_free_cmd(cmd, true);
 
-		spin_lock_bh(&conn->cmd_lock);
 	}
-	spin_unlock_bh(&conn->cmd_lock);
 }
 
 static void iscsit_stop_timers_for_cmds(
@@ -4127,18 +4404,43 @@ int iscsit_close_connection(
 	pr_debug("Closing iSCSI connection CID %hu on SID:"
 		" %u\n", conn->cid, sess->sid);
 	/*
-	 * Always up conn_logout_comp just in case the RX Thread is sleeping
-	 * and the logout response never got sent because the connection
-	 * failed.
+	 * Always up conn_logout_comp for the traditional TCP case just in case
+	 * the RX Thread in iscsi_target_rx_opcode() is sleeping and the logout
+	 * response never got sent because the connection failed.
+	 *
+	 * However for iser-target, isert_wait4logout() is using conn_logout_comp
+	 * to signal logout response TX interrupt completion.  Go ahead and skip
+	 * this for iser since isert_rx_opcode() does not wait on logout failure,
+	 * and to avoid iscsi_conn pointer dereference in iser-target code.
 	 */
-	complete(&conn->conn_logout_comp);
+	if (conn->conn_transport->transport_type == ISCSI_TCP)
+		complete(&conn->conn_logout_comp);
+
+	if (!strcmp(current->comm, ISCSI_RX_THREAD_NAME)) {
+		if (conn->tx_thread &&
+		    cmpxchg(&conn->tx_thread_active, true, false)) {
+			send_sig(SIGINT, conn->tx_thread, 1);
+			kthread_stop(conn->tx_thread);
+		}
+	} else if (!strcmp(current->comm, ISCSI_TX_THREAD_NAME)) {
+		if (conn->rx_thread &&
+		    cmpxchg(&conn->rx_thread_active, true, false)) {
+			send_sig(SIGINT, conn->rx_thread, 1);
+			kthread_stop(conn->rx_thread);
+		}
+	}
 
-	iscsi_release_thread_set(conn);
+	spin_lock(&iscsit_global->ts_bitmap_lock);
+	bitmap_release_region(iscsit_global->ts_bitmap, conn->bitmap_id,
+			      get_order(1));
+	spin_unlock(&iscsit_global->ts_bitmap_lock);
 
 	iscsit_stop_timers_for_cmds(conn);
 	iscsit_stop_nopin_response_timer(conn);
 	iscsit_stop_nopin_timer(conn);
-	iscsit_free_queue_reqs_for_conn(conn);
+
+	if (conn->conn_transport->iscsit_wait_conn)
+		conn->conn_transport->iscsit_wait_conn(conn);
 
 	/*
 	 * During Connection recovery drop unacknowledged out of order
@@ -4156,6 +4458,7 @@ int iscsit_close_connection(
 		iscsit_clear_ooo_cmdsns_for_conn(conn);
 		iscsit_release_commands_from_conn(conn);
 	}
+	iscsit_free_queue_reqs_for_conn(conn);
 
 	/*
 	 * Handle decrementing session or connection usage count if
@@ -4332,7 +4635,7 @@ int iscsit_close_connection(
 
 int iscsit_close_session(struct iscsi_session *sess)
 {
-	struct iscsi_portal_group *tpg = ISCSI_TPG_S(sess);
+	struct iscsi_portal_group *tpg = sess->tpg;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 
 	if (atomic_read(&sess->nconn)) {
@@ -4409,15 +4712,24 @@ static void iscsit_logout_post_handler_closesession(
 	struct iscsi_conn *conn)
 {
 	struct iscsi_session *sess = conn->sess;
-
-	iscsi_set_thread_clear(conn, ISCSI_CLEAR_TX_THREAD);
-	iscsi_set_thread_set_signal(conn, ISCSI_SIGNAL_TX_THREAD);
+	int sleep = 1;
+	/*
+	 * Traditional iscsi/tcp will invoke this logic from TX thread
+	 * context during session logout, so clear tx_thread_active and
+	 * sleep if iscsit_close_connection() has not already occured.
+	 *
+	 * Since iser-target invokes this logic from it's own workqueue,
+	 * always sleep waiting for RX/TX thread shutdown to complete
+	 * within iscsit_close_connection().
+	 */
+	if (conn->conn_transport->transport_type == ISCSI_TCP)
+		sleep = cmpxchg(&conn->tx_thread_active, true, false);
 
 	atomic_set(&conn->conn_logout_remove, 0);
 	complete(&conn->conn_logout_comp);
 
 	iscsit_dec_conn_usage_count(conn);
-	iscsit_stop_session(sess, 1, 1);
+	iscsit_stop_session(sess, sleep, sleep);
 	iscsit_dec_session_usage_count(sess);
 	target_put_session(sess->se_sess);
 }
@@ -4425,13 +4737,15 @@ static void iscsit_logout_post_handler_closesession(
 static void iscsit_logout_post_handler_samecid(
 	struct iscsi_conn *conn)
 {
-	iscsi_set_thread_clear(conn, ISCSI_CLEAR_TX_THREAD);
-	iscsi_set_thread_set_signal(conn, ISCSI_SIGNAL_TX_THREAD);
+	int sleep = 1;
+
+	if (conn->conn_transport->transport_type == ISCSI_TCP)
+		sleep = cmpxchg(&conn->tx_thread_active, true, false);
 
 	atomic_set(&conn->conn_logout_remove, 0);
 	complete(&conn->conn_logout_comp);
 
-	iscsit_cause_connection_reinstatement(conn, 1);
+	iscsit_cause_connection_reinstatement(conn, sleep);
 	iscsit_dec_conn_usage_count(conn);
 }
 
@@ -4441,6 +4755,7 @@ static void iscsit_logout_post_handler_diffcid(
 {
 	struct iscsi_conn *l_conn;
 	struct iscsi_session *sess = conn->sess;
+	bool conn_found = false;
 
 	if (!sess)
 		return;
@@ -4449,12 +4764,13 @@ static void iscsit_logout_post_handler_diffcid(
 	list_for_each_entry(l_conn, &sess->sess_conn_list, conn_list) {
 		if (l_conn->cid == cid) {
 			iscsit_inc_conn_usage_count(l_conn);
+			conn_found = true;
 			break;
 		}
 	}
 	spin_unlock_bh(&sess->conn_lock);
 
-	if (!l_conn)
+	if (!conn_found)
 		return;
 
 	if (l_conn->sock)
@@ -4643,6 +4959,7 @@ int iscsit_release_sessions_for_tpg(struct iscsi_portal_group *tpg, int force)
 	struct iscsi_session *sess;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 	struct se_session *se_sess, *se_sess_tmp;
+	LIST_HEAD(free_list);
 	int session_count = 0;
 
 	spin_lock_bh(&se_tpg->session_lock);
@@ -4664,14 +4981,17 @@ int iscsit_release_sessions_for_tpg(struct iscsi_portal_group *tpg, int force)
 		}
 		atomic_set(&sess->session_reinstatement, 1);
 		spin_unlock(&sess->conn_lock);
-		spin_unlock_bh(&se_tpg->session_lock);
 
-		iscsit_free_session(sess);
-		spin_lock_bh(&se_tpg->session_lock);
+		list_move_tail(&se_sess->sess_list, &free_list);
+	}
+	spin_unlock_bh(&se_tpg->session_lock);
 
+	list_for_each_entry_safe(se_sess, se_sess_tmp, &free_list, sess_list) {
+		sess = (struct iscsi_session *)se_sess->fabric_sess_ptr;
+
+		iscsit_free_session(sess);
 		session_count++;
 	}
-	spin_unlock_bh(&se_tpg->session_lock);
 
 	pr_debug("Released %d iSCSI Session(s) from Target Portal"
 			" Group: %hu\n", session_count, tpg->tpgt);
diff --git a/drivers/target/iscsi/iscsi_target.h b/drivers/target/iscsi/iscsi_target.h
index 2c437cb..e936d56 100644
--- a/drivers/target/iscsi/iscsi_target.h
+++ b/drivers/target/iscsi/iscsi_target.h
@@ -7,13 +7,15 @@ extern void iscsit_put_tiqn_for_login(struct iscsi_tiqn *);
 extern struct iscsi_tiqn *iscsit_add_tiqn(unsigned char *);
 extern void iscsit_del_tiqn(struct iscsi_tiqn *);
 extern int iscsit_access_np(struct iscsi_np *, struct iscsi_portal_group *);
-extern int iscsit_deaccess_np(struct iscsi_np *, struct iscsi_portal_group *);
+extern void iscsit_login_kref_put(struct kref *);
+extern int iscsit_deaccess_np(struct iscsi_np *, struct iscsi_portal_group *,
+				struct iscsi_tpg_np *);
 extern bool iscsit_check_np_match(struct __kernel_sockaddr_storage *,
 				struct iscsi_np *, int);
 extern struct iscsi_np *iscsit_add_np(struct __kernel_sockaddr_storage *,
 				char *, int);
 extern int iscsit_reset_np_thread(struct iscsi_np *, struct iscsi_tpg_np *,
-				struct iscsi_portal_group *);
+				struct iscsi_portal_group *, bool);
 extern int iscsit_del_np(struct iscsi_np *);
 extern int iscsit_reject_cmd(struct iscsi_cmd *cmd, u8, unsigned char *);
 extern void iscsit_set_unsoliticed_dataout(struct iscsi_cmd *);
@@ -37,7 +39,6 @@ extern struct target_fabric_configfs *lio_target_fabric_configfs;
 
 extern struct kmem_cache *lio_dr_cache;
 extern struct kmem_cache *lio_ooo_cache;
-extern struct kmem_cache *lio_cmd_cache;
 extern struct kmem_cache *lio_qr_cache;
 extern struct kmem_cache *lio_r2t_cache;
 
diff --git a/drivers/target/iscsi/iscsi_target_auth.c b/drivers/target/iscsi/iscsi_target_auth.c
index cee1754..682a60b 100644
--- a/drivers/target/iscsi/iscsi_target_auth.c
+++ b/drivers/target/iscsi/iscsi_target_auth.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file houses the main functions for the iSCSI CHAP support
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -28,6 +26,131 @@
 #include "iscsi_target_nego.h"
 #include "iscsi_target_auth.h"
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+// Base64 decoding, taken from UNH-iSCSI "Base64codeToNumber()"
+static unsigned char decode_base64_digit(const char base64)
+{
+	switch (base64) {
+	case '=':
+		return 64;
+	case '/':
+		return 63;
+	case '+':
+		return 62;
+	default:
+		if ((base64 >= 'A') && (base64 <= 'Z')) {
+			return base64 - 'A';
+		} else if ((base64 >= 'a') && (base64 <= 'z')) {
+			return 26 + (base64 - 'a');
+		} else if ((base64 >= '0') && (base64 <= '9')) {
+			return 52 + (base64 - '0');
+		} else {
+			return -1;
+		}
+	}
+}
+
+// Base64 decoding, taken from UNH-iSCSI "Base64StringToInteger()"
+static void decode_base64_string(const char* string, unsigned char* int_num, const int int_len)
+{
+	int len = -1;
+	int count = 0;
+	int intptr = 0;
+	unsigned char num[4] = {0};
+	int octets = -1;
+
+	if (!string || !int_num) {
+		return;
+	}
+
+	if (0 == (len = strlen(string))) {
+		return;
+	}
+
+	if (0 != (len % 4)) {
+		return;
+	}
+
+	while (count < len - 4) {
+		num[0] = decode_base64_digit(string[count]);
+		num[1] = decode_base64_digit(string[count + 1]);
+		num[2] = decode_base64_digit(string[count + 2]);
+		num[3] = decode_base64_digit(string[count + 3]);
+		if ((65 == num[0]) || (65 == num[1]) || (65 == num[2]) || (65 == num[3])) {
+			return;
+		}
+		count += 4;
+		octets = (num[0] << 18) | (num[1] << 12) | (num[2] << 6) | num[3];
+		int_num[intptr] = (octets & 0xFF0000) >> 16;
+		int_num[intptr + 1] = (octets & 0x00FF00) >> 8;
+		int_num[intptr + 2] = octets & 0x0000FF;
+		intptr += 3;
+	}
+	num[0] = decode_base64_digit(string[count]);
+	num[1] = decode_base64_digit(string[count + 1]);
+	num[2] = decode_base64_digit(string[count + 2]);
+	num[3] = decode_base64_digit(string[count + 3]);
+	if ((64 == num[0]) || (64 == num[1])) {
+		return;
+	}
+	if (64 == num[2]) {
+		if (64 != num[3]) {
+			return;
+		}
+		int_num[intptr] = (num[0] << 2) | (num[1] >> 4);
+	} else if (num[3] == 64) {
+		int_num[intptr] = (num[0] << 2) | (num[1] >> 4);
+		int_num[intptr + 1] = (num[1] << 4) | (num[2] >> 2);
+	} else {
+		octets = (num[0] << 18) | (num[1] << 12) | (num[2] << 6) | num[3];
+		int_num[intptr] = (octets & 0xFF0000) >> 16;
+		int_num[intptr + 1] = (octets & 0x00FF00) >> 8;
+		int_num[intptr + 2] = octets & 0x0000FF;
+	}
+}
+
+// Base64 encoding, taken from UNH iSCSI "IntegerToBase64String()"
+static void encode_base64_string(char* string, const unsigned char* int_num, const long int_len)
+{
+	int count = 0, octets = 0, strptr = 0, delta = -1;
+	static const char base64code[] = {
+		'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M',
+		'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z',
+		'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm',
+		'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z',
+		'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', '+', '/', '='
+	};
+
+	if (!int_num || !string || !int_len) {
+		return;
+	}
+
+	while (2 < (delta = (int_len - count))) {
+		octets = (int_num[count] << 16) | (int_num[count + 1] << 8) | int_num[count + 2];
+		string[strptr] = base64code[(octets & 0xfc0000) >> 18];
+		string[strptr + 1] = base64code[(octets & 0x03f000) >> 12];
+		string[strptr + 2] = base64code[(octets & 0x000fc0) >> 6];
+		string[strptr + 3] = base64code[octets & 0x00003f];
+		count += 3;
+		strptr += 4;
+	}
+	if (delta == 1) {
+		string[strptr] = base64code[(int_num[count] & 0xfc) >> 2];
+		string[strptr + 1] = base64code[(int_num[count] & 0x03) << 4];
+		string[strptr + 2] = base64code[64];
+		string[strptr + 3] = base64code[64];
+		strptr += 4;
+	} else if (delta == 2) {
+		string[strptr] = base64code[(int_num[count] & 0xfc) >> 2];
+		string[strptr + 1] = base64code[((int_num[count] & 0x03) << 4) | ((int_num[count + 1] & 0xf0) >> 4)];
+		string[strptr + 2] = base64code[(int_num[count + 1] & 0x0f) << 2];
+		string[strptr + 3] = base64code[64];
+		strptr += 4;
+	}
+	string[strptr] = '\0';
+}
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
+
 static int chap_string_to_hex(unsigned char *dst, unsigned char *src, int len)
 {
 	int j = DIV_ROUND_UP(len, 2), rc;
@@ -113,7 +236,7 @@ static struct iscsi_chap *chap_server_open(
 	/*
 	 * Set Identifier.
 	 */
-	chap->id = ISCSI_TPG_C(conn)->tpg_chap_id++;
+	chap->id = conn->tpg->tpg_chap_id++;
 	*aic_len += sprintf(aic_str + *aic_len, "CHAP_I=%d", chap->id);
 	*aic_len += 1;
 	pr_debug("[server] Sending CHAP_I=%d\n", chap->id);
@@ -148,6 +271,7 @@ static int chap_server_compute_md5(
 	unsigned char client_digest[MD5_SIGNATURE_SIZE];
 	unsigned char server_digest[MD5_SIGNATURE_SIZE];
 	unsigned char chap_n[MAX_CHAP_N_SIZE], chap_r[MAX_RESPONSE_LENGTH];
+	size_t compare_len;
 	struct iscsi_chap *chap = conn->auth_protocol;
 	struct crypto_hash *tfm;
 	struct hash_desc desc;
@@ -186,7 +310,9 @@ static int chap_server_compute_md5(
 		goto out;
 	}
 
-	if (memcmp(chap_n, auth->userid, strlen(auth->userid)) != 0) {
+	/* Include the terminating NULL in the compare */
+	compare_len = strlen(auth->userid) + 1;
+	if (strncmp(chap_n, auth->userid, compare_len) != 0) {
 		pr_err("CHAP_N values do not match!\n");
 		goto out;
 	}
@@ -199,13 +325,25 @@ static int chap_server_compute_md5(
 		pr_err("Could not find CHAP_R.\n");
 		goto out;
 	}
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type != HEX && type != BASE64) {
+#else
 	if (type != HEX) {
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		pr_err("Could not find CHAP_R.\n");
 		goto out;
 	}
 
 	pr_debug("[server] Got CHAP_R=%s\n", chap_r);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		chap_string_to_hex(client_digest, chap_r, strlen(chap_r));
+	} else {
+		decode_base64_string(chap_r, client_digest, MD5_SIGNATURE_SIZE);
+	}
+#else
 	chap_string_to_hex(client_digest, chap_r, strlen(chap_r));
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 
 	tfm = crypto_alloc_hash("md5", 0, CRYPTO_ALG_ASYNC);
 	if (IS_ERR(tfm)) {
@@ -280,7 +418,11 @@ static int chap_server_compute_md5(
 		goto out;
 	}
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX || type == BASE64)
+#else
 	if (type == HEX)
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		id = simple_strtoul(&identifier[2], &endptr, 0);
 	else
 		id = simple_strtoul(identifier, &endptr, 0);
@@ -301,18 +443,57 @@ static int chap_server_compute_md5(
 		goto out;
 	}
 
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type != HEX && type != BASE64) {
+#else
 	if (type != HEX) {
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 		pr_err("Could not find CHAP_C.\n");
 		goto out;
 	}
 	pr_debug("[server] Got CHAP_C=%s\n", challenge);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		challenge_len = chap_string_to_hex(challenge_binhex, challenge, strlen(challenge));
+	} else {
+		int len = strlen(challenge);
+		if (len % 4) {
+			pr_err("invalid length: %zu\n", strlen(challenge));
+			goto out;
+		}
+
+		if (len < 2) {
+			pr_err("length is shorter than 2: %zu\n", strlen(challenge));
+			goto out;
+		}
+
+		challenge_len = strlen(challenge) / 4 * 3;
+		if (challenge[len - 1] == '=')
+			challenge_len--;
+		if (challenge[len - 2] == '=')
+			challenge_len--;
+
+		decode_base64_string(challenge, challenge_binhex, challenge_len);
+	}
+#else
 	challenge_len = chap_string_to_hex(challenge_binhex, challenge,
 				strlen(challenge));
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	if (!challenge_len) {
 		pr_err("Unable to convert incoming challenge\n");
 		goto out;
 	}
 	/*
+	 * During mutual authentication, the CHAP_C generated by the
+	 * initiator must not match the original CHAP_C generated by
+	 * the target.
+	 */
+	if (!memcmp(challenge_binhex, chap->challenge, CHAP_CHALLENGE_LENGTH)) {
+		pr_err("initiator CHAP_C matches target CHAP_C, failing"
+		       " login attempt\n");
+		goto out;
+	}
+	/*
 	 * Generate CHAP_N and CHAP_R for mutual authentication.
 	 */
 	tfm = crypto_alloc_hash("md5", 0, CRYPTO_ALG_ASYNC);
@@ -373,6 +554,25 @@ static int chap_server_compute_md5(
 	*nr_out_len = sprintf(nr_out_ptr, "CHAP_N=%s", auth->userid_mutual);
 	*nr_out_len += 1;
 	pr_debug("[server] Sending CHAP_N=%s\n", auth->userid_mutual);
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	if (type == HEX) {
+		/*
+		 * Convert response from binary hex to ascii hext.
+		 */
+
+		chap_binaryhex_to_asciihex(response, digest, MD5_SIGNATURE_SIZE);
+		*nr_out_len += sprintf(nr_out_ptr + *nr_out_len, "CHAP_R=0x%s",
+				response);
+		*nr_out_len += 1;
+		pr_debug("[server] Sending CHAP_R=0x%s\n", response);
+	} else {
+		encode_base64_string(response, digest, MD5_SIGNATURE_SIZE);
+		*nr_out_len += sprintf(nr_out_ptr + *nr_out_len, "CHAP_R=0b%s",
+			response);
+		*nr_out_len += 1;
+		pr_debug("[server] Sending CHAP_R=0b%s\n", response);
+	}
+#else
 	/*
 	 * Convert response from binary hex to ascii hext.
 	 */
@@ -381,6 +581,7 @@ static int chap_server_compute_md5(
 			response);
 	*nr_out_len += 1;
 	pr_debug("[server] Sending CHAP_R=0x%s\n", response);
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	auth_ret = 0;
 out:
 	kfree(challenge);
diff --git a/drivers/target/iscsi/iscsi_target_configfs.c b/drivers/target/iscsi/iscsi_target_configfs.c
index 421344d..4a28c5f 100644
--- a/drivers/target/iscsi/iscsi_target_configfs.c
+++ b/drivers/target/iscsi/iscsi_target_configfs.c
@@ -2,9 +2,7 @@
  * This file contains the configfs implementation for iSCSI Target mode
  * from the LIO-Target Project.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -20,6 +18,7 @@
  ****************************************************************************/
 
 #include <linux/configfs.h>
+#include <linux/ctype.h>
 #include <linux/export.h>
 #include <linux/inet.h>
 #include <target/target_core_base.h>
@@ -78,11 +77,12 @@ static ssize_t lio_target_np_store_sctp(
 	struct iscsi_tpg_np *tpg_np = container_of(se_tpg_np,
 				struct iscsi_tpg_np, se_tpg_np);
 	struct iscsi_tpg_np *tpg_np_sctp = NULL;
-	char *endptr;
 	u32 op;
 	int ret;
 
-	op = simple_strtoul(page, &endptr, 0);
+	ret = kstrtou32(page, 0, &op);
+	if (ret)
+		return ret;
 	if ((op != 1) && (op != 0)) {
 		pr_err("Illegal value for tpg_enable: %u\n", op);
 		return -EINVAL;
@@ -263,9 +263,9 @@ static struct se_tpg_np *lio_target_call_addnptotpg(
 		*port_str = '\0'; /* Terminate string for IP */
 		port_str++; /* Skip over ":" */
 
-		ret = strict_strtoul(port_str, 0, &port);
+		ret = kstrtoul(port_str, 0, &port);
 		if (ret < 0) {
-			pr_err("strict_strtoul() failed for port_str: %d\n", ret);
+			pr_err("kstrtoul() failed for port_str: %d\n", ret);
 			return ERR_PTR(ret);
 		}
 		sock_in6 = (struct sockaddr_in6 *)&sockaddr;
@@ -288,9 +288,9 @@ static struct se_tpg_np *lio_target_call_addnptotpg(
 		*port_str = '\0'; /* Terminate string for IP */
 		port_str++; /* Skip over ":" */
 
-		ret = strict_strtoul(port_str, 0, &port);
+		ret = kstrtoul(port_str, 0, &port);
 		if (ret < 0) {
-			pr_err("strict_strtoul() failed for port_str: %d\n", ret);
+			pr_err("kstrtoul() failed for port_str: %d\n", ret);
 			return ERR_PTR(ret);
 		}
 		sock_in = (struct sockaddr_in *)&sockaddr;
@@ -372,7 +372,7 @@ static ssize_t iscsi_nacl_attrib_show_##name(				\
 	struct iscsi_node_acl *nacl = container_of(se_nacl, struct iscsi_node_acl, \
 					se_node_acl);			\
 									\
-	return sprintf(page, "%u\n", ISCSI_NODE_ATTRIB(nacl)->name);	\
+	return sprintf(page, "%u\n", nacl->node_attrib.name);		\
 }									\
 									\
 static ssize_t iscsi_nacl_attrib_store_##name(				\
@@ -382,11 +382,12 @@ static ssize_t iscsi_nacl_attrib_store_##name(				\
 {									\
 	struct iscsi_node_acl *nacl = container_of(se_nacl, struct iscsi_node_acl, \
 					se_node_acl);			\
-	char *endptr;							\
 	u32 val;							\
 	int ret;							\
 									\
-	val = simple_strtoul(page, &endptr, 0);				\
+	ret = kstrtou32(page, 0, &val);					\
+	if (ret)							\
+		return ret;						\
 	ret = iscsit_na_##name(nacl, val);				\
 	if (ret < 0)							\
 		return ret;						\
@@ -473,7 +474,8 @@ static ssize_t __iscsi_##prefix##_store_##name(				\
 									\
 	if (!capable(CAP_SYS_ADMIN))					\
 		return -EPERM;						\
-									\
+	if (count >= sizeof(auth->name))				\
+		return -EINVAL;						\
 	snprintf(auth->name, sizeof(auth->name), "%s", page);		\
 	if (!strncmp("NULL", auth->name, 4))				\
 		auth->naf_flags &= ~flags;				\
@@ -789,11 +791,12 @@ static ssize_t lio_target_nacl_store_cmdsn_depth(
 	struct iscsi_portal_group *tpg = container_of(se_tpg,
 			struct iscsi_portal_group, tpg_se_tpg);
 	struct config_item *acl_ci, *tpg_ci, *wwn_ci;
-	char *endptr;
 	u32 cmdsn_depth = 0;
 	int ret;
 
-	cmdsn_depth = simple_strtoul(page, &endptr, 0);
+	ret = kstrtou32(page, 0, &cmdsn_depth);
+	if (ret)
+		return ret;
 	if (cmdsn_depth > TA_DEFAULT_CMDSN_DEPTH_MAX) {
 		pr_err("Passed cmdsn_depth: %u exceeds"
 			" TA_DEFAULT_CMDSN_DEPTH_MAX: %u\n", cmdsn_depth,
@@ -895,7 +898,7 @@ static struct se_node_acl *lio_target_make_nodeacl(
 	if (!se_nacl_new)
 		return ERR_PTR(-ENOMEM);
 
-	cmdsn_depth = ISCSI_TPG_ATTRIB(tpg)->default_cmdsn_depth;
+	cmdsn_depth = tpg->tpg_attrib.default_cmdsn_depth;
 	/*
 	 * se_nacl_new may be released by core_tpg_add_initiator_node_acl()
 	 * when converting a NdoeACL from demo mode -> explict
@@ -918,9 +921,9 @@ static struct se_node_acl *lio_target_make_nodeacl(
 		return ERR_PTR(-ENOMEM);
 	}
 
-	stats_cg->default_groups[0] = &NODE_STAT_GRPS(acl)->iscsi_sess_stats_group;
+	stats_cg->default_groups[0] = &acl->node_stat_grps.iscsi_sess_stats_group;
 	stats_cg->default_groups[1] = NULL;
-	config_group_init_type_name(&NODE_STAT_GRPS(acl)->iscsi_sess_stats_group,
+	config_group_init_type_name(&acl->node_stat_grps.iscsi_sess_stats_group,
 			"iscsi_sess_stats", &iscsi_stat_sess_cit);
 
 	return se_nacl;
@@ -965,7 +968,7 @@ static ssize_t iscsi_tpg_attrib_show_##name(				\
 	if (iscsit_get_tpg(tpg) < 0)					\
 		return -EINVAL;						\
 									\
-	rb = sprintf(page, "%u\n", ISCSI_TPG_ATTRIB(tpg)->name);	\
+	rb = sprintf(page, "%u\n", tpg->tpg_attrib.name);		\
 	iscsit_put_tpg(tpg);						\
 	return rb;							\
 }									\
@@ -977,14 +980,15 @@ static ssize_t iscsi_tpg_attrib_store_##name(				\
 {									\
 	struct iscsi_portal_group *tpg = container_of(se_tpg,		\
 			struct iscsi_portal_group, tpg_se_tpg);	\
-	char *endptr;							\
 	u32 val;							\
 	int ret;							\
 									\
 	if (iscsit_get_tpg(tpg) < 0)					\
 		return -EINVAL;						\
 									\
-	val = simple_strtoul(page, &endptr, 0);				\
+	ret = kstrtou32(page, 0, &val);					\
+	if (ret)							\
+		goto out;						\
 	ret = iscsit_ta_##name(tpg, val);				\
 	if (ret < 0)							\
 		goto out;						\
@@ -1038,6 +1042,16 @@ TPG_ATTR(demo_mode_write_protect, S_IRUGO | S_IWUSR);
  */
 DEF_TPG_ATTRIB(prod_mode_write_protect);
 TPG_ATTR(prod_mode_write_protect, S_IRUGO | S_IWUSR);
+/*
+ * Define iscsi_tpg_attrib_s_demo_mode_discovery,
+ */
+DEF_TPG_ATTRIB(demo_mode_discovery);
+TPG_ATTR(demo_mode_discovery, S_IRUGO | S_IWUSR);
+/*
+ * Define iscsi_tpg_attrib_s_default_erl
+ */
+DEF_TPG_ATTRIB(default_erl);
+TPG_ATTR(default_erl, S_IRUGO | S_IWUSR);
 
 static struct configfs_attribute *lio_target_tpg_attrib_attrs[] = {
 	&iscsi_tpg_attrib_authentication.attr,
@@ -1048,11 +1062,138 @@ static struct configfs_attribute *lio_target_tpg_attrib_attrs[] = {
 	&iscsi_tpg_attrib_cache_dynamic_acls.attr,
 	&iscsi_tpg_attrib_demo_mode_write_protect.attr,
 	&iscsi_tpg_attrib_prod_mode_write_protect.attr,
+	&iscsi_tpg_attrib_demo_mode_discovery.attr,
+	&iscsi_tpg_attrib_default_erl.attr,
 	NULL,
 };
 
 /* End items for lio_target_tpg_attrib_cit */
 
+/* Start items for lio_target_tpg_auth_cit */
+
+#define __DEF_TPG_AUTH_STR(prefix, name, flags)					\
+static ssize_t __iscsi_##prefix##_show_##name(					\
+	struct se_portal_group *se_tpg,						\
+	char *page)								\
+{										\
+	struct iscsi_portal_group *tpg = container_of(se_tpg,			\
+				struct iscsi_portal_group, tpg_se_tpg);		\
+	struct iscsi_node_auth *auth = &tpg->tpg_demo_auth;			\
+										\
+	if (!capable(CAP_SYS_ADMIN))						\
+		return -EPERM;							\
+										\
+	return snprintf(page, PAGE_SIZE, "%s\n", auth->name);			\
+}										\
+										\
+static ssize_t __iscsi_##prefix##_store_##name(					\
+	struct se_portal_group *se_tpg,						\
+	const char *page,							\
+	size_t count)								\
+{										\
+	struct iscsi_portal_group *tpg = container_of(se_tpg,			\
+				struct iscsi_portal_group, tpg_se_tpg);		\
+	struct iscsi_node_auth *auth = &tpg->tpg_demo_auth;			\
+										\
+	if (!capable(CAP_SYS_ADMIN))						\
+		return -EPERM;							\
+										\
+	snprintf(auth->name, sizeof(auth->name), "%s", page);			\
+	if (!(strncmp("NULL", auth->name, 4)))					\
+		auth->naf_flags &= ~flags;					\
+	else									\
+		auth->naf_flags |= flags;					\
+										\
+	if ((auth->naf_flags & NAF_USERID_IN_SET) &&				\
+	    (auth->naf_flags & NAF_PASSWORD_IN_SET))				\
+		auth->authenticate_target = 1;					\
+	else									\
+		auth->authenticate_target = 0;					\
+										\
+	return count;								\
+}
+
+#define __DEF_TPG_AUTH_INT(prefix, name)					\
+static ssize_t __iscsi_##prefix##_show_##name(					\
+	struct se_portal_group *se_tpg,						\
+	char *page)								\
+{										\
+	struct iscsi_portal_group *tpg = container_of(se_tpg,			\
+				struct iscsi_portal_group, tpg_se_tpg);		\
+	struct iscsi_node_auth *auth = &tpg->tpg_demo_auth;			\
+										\
+	if (!capable(CAP_SYS_ADMIN))						\
+		return -EPERM;							\
+										\
+	return snprintf(page, PAGE_SIZE, "%d\n", auth->name);			\
+}
+
+#define DEF_TPG_AUTH_STR(name, flags)						\
+	__DEF_TPG_AUTH_STR(tpg_auth, name, flags)				\
+static ssize_t iscsi_tpg_auth_show_##name(					\
+	struct se_portal_group *se_tpg,						\
+	char *page)								\
+{										\
+	return __iscsi_tpg_auth_show_##name(se_tpg, page);			\
+}										\
+										\
+static ssize_t iscsi_tpg_auth_store_##name(					\
+	struct se_portal_group *se_tpg,						\
+	const char *page,							\
+	size_t count)								\
+{										\
+	return __iscsi_tpg_auth_store_##name(se_tpg, page, count);		\
+}
+
+#define DEF_TPG_AUTH_INT(name)							\
+	__DEF_TPG_AUTH_INT(tpg_auth, name)					\
+static ssize_t iscsi_tpg_auth_show_##name(					\
+	struct se_portal_group *se_tpg,						\
+	char *page)								\
+{										\
+	return __iscsi_tpg_auth_show_##name(se_tpg, page);			\
+}
+
+#define TPG_AUTH_ATTR(_name, _mode) TF_TPG_AUTH_ATTR(iscsi, _name, _mode);
+#define TPG_AUTH_ATTR_RO(_name) TF_TPG_AUTH_ATTR_RO(iscsi, _name);
+
+/*
+ *  * One-way authentication userid
+ *   */
+DEF_TPG_AUTH_STR(userid, NAF_USERID_SET);
+TPG_AUTH_ATTR(userid, S_IRUGO | S_IWUSR);
+/*
+ *  * One-way authentication password
+ *   */
+DEF_TPG_AUTH_STR(password, NAF_PASSWORD_SET);
+TPG_AUTH_ATTR(password, S_IRUGO | S_IWUSR);
+/*
+ *  * Enforce mutual authentication
+ *   */
+DEF_TPG_AUTH_INT(authenticate_target);
+TPG_AUTH_ATTR_RO(authenticate_target);
+/*
+ *  * Mutual authentication userid
+ *   */
+DEF_TPG_AUTH_STR(userid_mutual, NAF_USERID_IN_SET);
+TPG_AUTH_ATTR(userid_mutual, S_IRUGO | S_IWUSR);
+/*
+ *  * Mutual authentication password
+ *   */
+DEF_TPG_AUTH_STR(password_mutual, NAF_PASSWORD_IN_SET);
+TPG_AUTH_ATTR(password_mutual, S_IRUGO | S_IWUSR);
+
+static struct configfs_attribute *lio_target_tpg_auth_attrs[] = {
+	&iscsi_tpg_auth_userid.attr,
+	&iscsi_tpg_auth_password.attr,
+	&iscsi_tpg_auth_authenticate_target.attr,
+	&iscsi_tpg_auth_userid_mutual.attr,
+	&iscsi_tpg_auth_password_mutual.attr,
+	NULL,
+};
+
+/* End items for lio_target_tpg_auth_cit */
+
 /* Start items for lio_target_tpg_param_cit */
 
 #define DEF_TPG_PARAM(name)						\
@@ -1087,13 +1228,14 @@ static ssize_t iscsi_tpg_param_store_##name(				\
 	struct iscsi_portal_group *tpg = container_of(se_tpg,		\
 			struct iscsi_portal_group, tpg_se_tpg);		\
 	char *buf;							\
-	int ret;							\
+	int ret, len;							\
 									\
 	buf = kzalloc(PAGE_SIZE, GFP_KERNEL);				\
 	if (!buf)							\
 		return -ENOMEM;						\
-	snprintf(buf, PAGE_SIZE, "%s=%s", __stringify(name), page);	\
-	buf[strlen(buf)-1] = '\0'; /* Kill newline */			\
+	len = snprintf(buf, PAGE_SIZE, "%s=%s", __stringify(name), page);	\
+	if (isspace(buf[len-1]))					\
+		buf[len-1] = '\0'; /* Kill newline */			\
 									\
 	if (iscsit_get_tpg(tpg) < 0) {					\
 		kfree(buf);						\
@@ -1230,11 +1372,12 @@ static ssize_t lio_target_tpg_store_enable(
 {
 	struct iscsi_portal_group *tpg = container_of(se_tpg,
 			struct iscsi_portal_group, tpg_se_tpg);
-	char *endptr;
 	u32 op;
-	int ret = 0;
+	int ret;
 
-	op = simple_strtoul(page, &endptr, 0);
+	ret = kstrtou32(page, 0, &op);
+	if (ret)
+		return ret;
 	if ((op != 1) && (op != 0)) {
 		pr_err("Illegal value for tpg_enable: %u\n", op);
 		return -EINVAL;
@@ -1282,15 +1425,15 @@ static struct se_portal_group *lio_target_tiqn_addtpg(
 {
 	struct iscsi_portal_group *tpg;
 	struct iscsi_tiqn *tiqn;
-	char *tpgt_str, *end_ptr;
-	int ret = 0;
-	unsigned short int tpgt;
+	char *tpgt_str;
+	int ret;
+	u16 tpgt;
 
 	tiqn = container_of(wwn, struct iscsi_tiqn, tiqn_wwn);
 	/*
 	 * Only tpgt_# directory groups can be created below
 	 * target/iscsi/iqn.superturodiskarry/
-	*/
+	 */
 	tpgt_str = strstr(name, "tpgt_");
 	if (!tpgt_str) {
 		pr_err("Unable to locate \"tpgt_#\" directory"
@@ -1298,7 +1441,9 @@ static struct se_portal_group *lio_target_tiqn_addtpg(
 		return NULL;
 	}
 	tpgt_str += 5; /* Skip ahead of "tpgt_" */
-	tpgt = (unsigned short int) simple_strtoul(tpgt_str, &end_ptr, 0);
+	ret = kstrtou16(tpgt_str, 0, &tpgt);
+	if (ret)
+		return NULL;
 
 	tpg = iscsit_alloc_portal_group(tiqn, tpgt);
 	if (!tpg)
@@ -1347,7 +1492,7 @@ static ssize_t lio_target_wwn_show_attr_lio_version(
 	struct target_fabric_configfs *tf,
 	char *page)
 {
-	return sprintf(page, "RisingTide Systems Linux-iSCSI Target "ISCSIT_VERSION"\n");
+	return sprintf(page, "Datera Inc. iSCSI Target "ISCSIT_VERSION"\n");
 }
 
 TF_WWN_ATTR_RO(lio_target, lio_version);
@@ -1382,21 +1527,21 @@ static struct se_wwn *lio_target_call_coreaddtiqn(
 		return ERR_PTR(-ENOMEM);
 	}
 
-	stats_cg->default_groups[0] = &WWN_STAT_GRPS(tiqn)->iscsi_instance_group;
-	stats_cg->default_groups[1] = &WWN_STAT_GRPS(tiqn)->iscsi_sess_err_group;
-	stats_cg->default_groups[2] = &WWN_STAT_GRPS(tiqn)->iscsi_tgt_attr_group;
-	stats_cg->default_groups[3] = &WWN_STAT_GRPS(tiqn)->iscsi_login_stats_group;
-	stats_cg->default_groups[4] = &WWN_STAT_GRPS(tiqn)->iscsi_logout_stats_group;
+	stats_cg->default_groups[0] = &tiqn->tiqn_stat_grps.iscsi_instance_group;
+	stats_cg->default_groups[1] = &tiqn->tiqn_stat_grps.iscsi_sess_err_group;
+	stats_cg->default_groups[2] = &tiqn->tiqn_stat_grps.iscsi_tgt_attr_group;
+	stats_cg->default_groups[3] = &tiqn->tiqn_stat_grps.iscsi_login_stats_group;
+	stats_cg->default_groups[4] = &tiqn->tiqn_stat_grps.iscsi_logout_stats_group;
 	stats_cg->default_groups[5] = NULL;
-	config_group_init_type_name(&WWN_STAT_GRPS(tiqn)->iscsi_instance_group,
+	config_group_init_type_name(&tiqn->tiqn_stat_grps.iscsi_instance_group,
 			"iscsi_instance", &iscsi_stat_instance_cit);
-	config_group_init_type_name(&WWN_STAT_GRPS(tiqn)->iscsi_sess_err_group,
+	config_group_init_type_name(&tiqn->tiqn_stat_grps.iscsi_sess_err_group,
 			"iscsi_sess_err", &iscsi_stat_sess_err_cit);
-	config_group_init_type_name(&WWN_STAT_GRPS(tiqn)->iscsi_tgt_attr_group,
+	config_group_init_type_name(&tiqn->tiqn_stat_grps.iscsi_tgt_attr_group,
 			"iscsi_tgt_attr", &iscsi_stat_tgt_attr_cit);
-	config_group_init_type_name(&WWN_STAT_GRPS(tiqn)->iscsi_login_stats_group,
+	config_group_init_type_name(&tiqn->tiqn_stat_grps.iscsi_login_stats_group,
 			"iscsi_login_stats", &iscsi_stat_login_cit);
-	config_group_init_type_name(&WWN_STAT_GRPS(tiqn)->iscsi_logout_stats_group,
+	config_group_init_type_name(&tiqn->tiqn_stat_grps.iscsi_logout_stats_group,
 			"iscsi_logout_stats", &iscsi_stat_logout_cit);
 
 	pr_debug("LIO_Target_ConfigFS: REGISTER -> %s\n", tiqn->tiqn);
@@ -1506,10 +1651,12 @@ static ssize_t iscsi_disc_store_enforce_discovery_auth(
 {
 	struct iscsi_param *param;
 	struct iscsi_portal_group *discovery_tpg = iscsit_global->discovery_tpg;
-	char *endptr;
 	u32 op;
+	int err;
 
-	op = simple_strtoul(page, &endptr, 0);
+	err = kstrtou32(page, 0, &op);
+	if (err)
+		return -EINVAL;
 	if ((op != 1) && (op != 0)) {
 		pr_err("Illegal value for enforce_discovery_auth:"
 				" %u\n", op);
@@ -1650,18 +1797,29 @@ static int lio_queue_status(struct se_cmd *se_cmd)
 	struct iscsi_cmd *cmd = container_of(se_cmd, struct iscsi_cmd, se_cmd);
 
 	cmd->i_state = ISTATE_SEND_STATUS;
+
+	if (cmd->se_cmd.scsi_status || cmd->sense_reason) {
+		iscsit_add_cmd_to_response_queue(cmd, cmd->conn, cmd->i_state);
+		return 0;
+	}
 	cmd->conn->conn_transport->iscsit_queue_status(cmd->conn, cmd);
 
 	return 0;
 }
 
-static int lio_queue_tm_rsp(struct se_cmd *se_cmd)
+static void lio_queue_tm_rsp(struct se_cmd *se_cmd)
 {
 	struct iscsi_cmd *cmd = container_of(se_cmd, struct iscsi_cmd, se_cmd);
 
 	cmd->i_state = ISTATE_SEND_TASKMGTRSP;
 	iscsit_add_cmd_to_response_queue(cmd, cmd->conn, cmd->i_state);
-	return 0;
+}
+
+static void lio_aborted_task(struct se_cmd *se_cmd)
+{
+	struct iscsi_cmd *cmd = container_of(se_cmd, struct iscsi_cmd, se_cmd);
+
+	cmd->conn->conn_transport->iscsit_aborted_task(cmd->conn, cmd);
 }
 
 static char *lio_tpg_get_endpoint_wwn(struct se_portal_group *se_tpg)
@@ -1682,21 +1840,21 @@ static u32 lio_tpg_get_default_depth(struct se_portal_group *se_tpg)
 {
 	struct iscsi_portal_group *tpg = se_tpg->se_tpg_fabric_ptr;
 
-	return ISCSI_TPG_ATTRIB(tpg)->default_cmdsn_depth;
+	return tpg->tpg_attrib.default_cmdsn_depth;
 }
 
 static int lio_tpg_check_demo_mode(struct se_portal_group *se_tpg)
 {
 	struct iscsi_portal_group *tpg = se_tpg->se_tpg_fabric_ptr;
 
-	return ISCSI_TPG_ATTRIB(tpg)->generate_node_acls;
+	return tpg->tpg_attrib.generate_node_acls;
 }
 
 static int lio_tpg_check_demo_mode_cache(struct se_portal_group *se_tpg)
 {
 	struct iscsi_portal_group *tpg = se_tpg->se_tpg_fabric_ptr;
 
-	return ISCSI_TPG_ATTRIB(tpg)->cache_dynamic_acls;
+	return tpg->tpg_attrib.cache_dynamic_acls;
 }
 
 static int lio_tpg_check_demo_mode_write_protect(
@@ -1704,7 +1862,7 @@ static int lio_tpg_check_demo_mode_write_protect(
 {
 	struct iscsi_portal_group *tpg = se_tpg->se_tpg_fabric_ptr;
 
-	return ISCSI_TPG_ATTRIB(tpg)->demo_mode_write_protect;
+	return tpg->tpg_attrib.demo_mode_write_protect;
 }
 
 static int lio_tpg_check_prod_mode_write_protect(
@@ -1712,7 +1870,7 @@ static int lio_tpg_check_prod_mode_write_protect(
 {
 	struct iscsi_portal_group *tpg = se_tpg->se_tpg_fabric_ptr;
 
-	return ISCSI_TPG_ATTRIB(tpg)->prod_mode_write_protect;
+	return tpg->tpg_attrib.prod_mode_write_protect;
 }
 
 static void lio_tpg_release_fabric_acl(
@@ -1725,7 +1883,8 @@ static void lio_tpg_release_fabric_acl(
 }
 
 /*
- * Called with spin_lock_bh(struct se_portal_group->session_lock) held..
+ * Called with spin_lock_irq(struct se_portal_group->session_lock) held
+ * or not held.
  *
  * Also, this function calls iscsit_inc_session_usage_count() on the
  * struct iscsi_session in question.
@@ -1733,19 +1892,32 @@ static void lio_tpg_release_fabric_acl(
 static int lio_tpg_shutdown_session(struct se_session *se_sess)
 {
 	struct iscsi_session *sess = se_sess->fabric_sess_ptr;
+	struct se_portal_group *se_tpg = se_sess->se_tpg;
+	bool local_lock = false;
+
+	if (!spin_is_locked(&se_tpg->session_lock)) {
+		spin_lock_irq(&se_tpg->session_lock);
+		local_lock = true;
+	}
 
 	spin_lock(&sess->conn_lock);
 	if (atomic_read(&sess->session_fall_back_to_erl0) ||
 	    atomic_read(&sess->session_logout) ||
 	    (sess->time2retain_timer_flags & ISCSI_TF_EXPIRED)) {
 		spin_unlock(&sess->conn_lock);
+		if (local_lock)
+			spin_unlock_irq(&sess->conn_lock);
 		return 0;
 	}
 	atomic_set(&sess->session_reinstatement, 1);
 	spin_unlock(&sess->conn_lock);
 
 	iscsit_stop_time2retain_timer(sess);
+	spin_unlock_irq(&se_tpg->session_lock);
+
 	iscsit_stop_session(sess, 1, 1);
+	if (!local_lock)
+		spin_lock_irq(&se_tpg->session_lock);
 
 	return 1;
 }
@@ -1775,9 +1947,12 @@ static void lio_set_default_node_attributes(struct se_node_acl *se_acl)
 {
 	struct iscsi_node_acl *acl = container_of(se_acl, struct iscsi_node_acl,
 				se_node_acl);
+	struct se_portal_group *se_tpg = se_acl->se_tpg;
+	struct iscsi_portal_group *tpg = container_of(se_tpg,
+				struct iscsi_portal_group, tpg_se_tpg);
 
-	ISCSI_NODE_ATTRIB(acl)->nacl = acl;
-	iscsit_set_default_node_attribues(acl);
+	acl->node_attrib.nacl = acl;
+	iscsit_set_default_node_attribues(acl, tpg);
 }
 
 static int lio_check_stop_free(struct se_cmd *se_cmd)
@@ -1790,7 +1965,7 @@ static void lio_release_cmd(struct se_cmd *se_cmd)
 	struct iscsi_cmd *cmd = container_of(se_cmd, struct iscsi_cmd, se_cmd);
 
 	pr_debug("Entering lio_release_cmd for se_cmd: %p\n", se_cmd);
-	cmd->release_cmd(cmd);
+	iscsit_release_cmd(cmd);
 }
 
 /* End functions for target_core_fabric_ops */
@@ -1845,6 +2020,7 @@ int iscsi_target_register_configfs(void)
 	fabric->tf_ops.queue_data_in = &lio_queue_data_in;
 	fabric->tf_ops.queue_status = &lio_queue_status;
 	fabric->tf_ops.queue_tm_rsp = &lio_queue_tm_rsp;
+	fabric->tf_ops.aborted_task = &lio_aborted_task;
 	/*
 	 * Setup function pointers for generic logic in target_core_fabric_configfs.c
 	 */
@@ -1862,16 +2038,17 @@ int iscsi_target_register_configfs(void)
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 * sturct config_item_type's
 	 */
-	TF_CIT_TMPL(fabric)->tfc_discovery_cit.ct_attrs = lio_target_discovery_auth_attrs;
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = lio_target_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = lio_target_tpg_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = lio_target_tpg_attrib_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = lio_target_tpg_param_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = lio_target_portal_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = lio_target_initiator_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = lio_target_nacl_attrib_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = lio_target_nacl_auth_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = lio_target_nacl_param_attrs;
+	fabric->tf_cit_tmpl.tfc_discovery_cit.ct_attrs = lio_target_discovery_auth_attrs;
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = lio_target_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = lio_target_tpg_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = lio_target_tpg_attrib_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_auth_cit.ct_attrs = lio_target_tpg_auth_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = lio_target_tpg_param_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = lio_target_portal_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = lio_target_initiator_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = lio_target_nacl_attrib_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = lio_target_nacl_auth_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = lio_target_nacl_param_attrs;
 
 	ret = target_fabric_configfs_register(fabric);
 	if (ret < 0) {
diff --git a/drivers/target/iscsi/iscsi_target_core.h b/drivers/target/iscsi/iscsi_target_core.h
index 8907dcd..49eac50 100644
--- a/drivers/target/iscsi/iscsi_target_core.h
+++ b/drivers/target/iscsi/iscsi_target_core.h
@@ -9,7 +9,7 @@
 #include <scsi/iscsi_proto.h>
 #include <target/target_core_base.h>
 
-#define ISCSIT_VERSION			"v4.1.0-rc2"
+#define ISCSIT_VERSION			"v4.1.0"
 #define ISCSI_MAX_DATASN_MISSING_COUNT	16
 #define ISCSI_TX_THREAD_TCP_TIMEOUT	2
 #define ISCSI_RX_THREAD_TCP_TIMEOUT	2
@@ -17,6 +17,9 @@
 #define SECONDS_FOR_ASYNC_TEXT		10
 #define SECONDS_FOR_LOGOUT_COMP		15
 #define WHITE_SPACE			" \t\v\f\n\r"
+#define ISCSIT_MIN_TAGS			16
+#define ISCSIT_EXTRA_TAGS		8
+#define ISCSIT_TCP_BACKLOG		256
 
 /* struct iscsi_node_attrib sanity values */
 #define NA_DATAOUT_TIMEOUT		3
@@ -34,9 +37,6 @@
 #define NA_RANDOM_DATAIN_PDU_OFFSETS	0
 #define NA_RANDOM_DATAIN_SEQ_OFFSETS	0
 #define NA_RANDOM_R2T_OFFSETS		0
-#define NA_DEFAULT_ERL			0
-#define NA_DEFAULT_ERL_MAX		2
-#define NA_DEFAULT_ERL_MIN		0
 
 /* struct iscsi_tpg_attrib sanity values */
 #define TA_AUTHENTICATION		1
@@ -47,7 +47,7 @@
 #define TA_NETIF_TIMEOUT_MAX		15
 #define TA_NETIF_TIMEOUT_MIN		2
 #define TA_GENERATE_NODE_ACLS		0
-#define TA_DEFAULT_CMDSN_DEPTH		16
+#define TA_DEFAULT_CMDSN_DEPTH		64
 #define TA_DEFAULT_CMDSN_DEPTH_MAX	512
 #define TA_DEFAULT_CMDSN_DEPTH_MIN	1
 #define TA_CACHE_DYNAMIC_ACLS		0
@@ -55,6 +55,8 @@
 #define TA_DEMO_MODE_WRITE_PROTECT	1
 /* Disabled by default in production mode w/ explict ACLs */
 #define TA_PROD_MODE_WRITE_PROTECT	0
+#define TA_DEMO_MODE_DISCOVERY		1
+#define TA_DEFAULT_ERL			0
 #define TA_CACHE_CORE_NPS		0
 
 
@@ -132,6 +134,8 @@ enum cmd_flags_table {
 	ICF_CONTIG_MEMORY			= 0x00000020,
 	ICF_ATTACHED_TO_RQUEUE			= 0x00000040,
 	ICF_OOO_CMDSN				= 0x00000080,
+	IFC_SENDTARGETS_ALL			= 0x00000100,
+	IFC_SENDTARGETS_SINGLE			= 0x00000200,
 };
 
 /* struct iscsi_cmd->i_state */
@@ -187,6 +191,7 @@ enum recover_cmdsn_ret_table {
 	CMDSN_NORMAL_OPERATION		= 0,
 	CMDSN_LOWER_THAN_EXP		= 1,
 	CMDSN_HIGHER_THAN_EXP		= 2,
+	CMDSN_MAXCMDSN_OVERRUN		= 3,
 };
 
 /* Used for iscsi_handle_immediate_data() return values */
@@ -428,6 +433,8 @@ struct iscsi_cmd {
 	u32			tx_size;
 	/* Buffer used for various purposes */
 	void			*buf_ptr;
+	/* Used by SendTargets=[iqn.,eui.] discovery */
+	void			*text_in_ptr;
 	/* See include/linux/dma-mapping.h */
 	enum dma_data_direction	data_direction;
 	/* iSCSI PDU Header + CRC */
@@ -485,7 +492,6 @@ struct iscsi_cmd {
 	u32			first_data_sg_off;
 	u32			kmapped_nents;
 	sense_reason_t		sense_reason;
-	void (*release_cmd)(struct iscsi_cmd *);
 }  ____cacheline_aligned;
 
 struct iscsi_tmr_req {
@@ -528,8 +534,6 @@ struct iscsi_conn {
 	u32			of_marker;
 	/* Used for calculating OFMarker offset to next PDU */
 	u32			of_marker_offset;
-	/* Complete Bad PDU for sending reject */
-	unsigned char		bad_hdr[ISCSI_HDR_LEN];
 #define IPV6_ADDRESS_SPACE				48
 	unsigned char		login_ip[IPV6_ADDRESS_SPACE];
 	unsigned char		local_ip[IPV6_ADDRESS_SPACE];
@@ -552,9 +556,19 @@ struct iscsi_conn {
 	struct completion	rx_half_close_comp;
 	/* socket used by this connection */
 	struct socket		*sock;
+	void			(*orig_data_ready)(struct sock *, int);
+	void			(*orig_state_change)(struct sock *);
+#define LOGIN_FLAGS_READ_ACTIVE		1
+#define LOGIN_FLAGS_CLOSED		2
+#define LOGIN_FLAGS_READY		4
+	unsigned long		login_flags;
+	struct delayed_work	login_work;
+	struct delayed_work	login_cleanup_work;
+	struct iscsi_login	*login;
 	struct timer_list	nopin_timer;
 	struct timer_list	nopin_response_timer;
 	struct timer_list	transport_timer;
+	struct task_struct	*login_kworker;
 	/* Spinlock used for add/deleting cmd's from conn_cmd_list */
 	spinlock_t		cmd_lock;
 	spinlock_t		conn_usage_lock;
@@ -582,10 +596,17 @@ struct iscsi_conn {
 	void			*context;
 	struct iscsi_login_thread_s *login_thread;
 	struct iscsi_portal_group *tpg;
+	struct iscsi_tpg_np	*tpg_np;
 	/* Pointer to parent session */
 	struct iscsi_session	*sess;
 	/* Pointer to thread_set in use for this conn's threads */
 	struct iscsi_thread_set	*thread_set;
+	int			bitmap_id;
+	int			rx_thread_active;
+	struct task_struct	*rx_thread;
+	struct completion	rx_login_comp;
+	int			tx_thread_active;
+	struct task_struct	*tx_thread;
 	/* list_head for session connection list */
 	struct list_head	conn_list;
 } ____cacheline_aligned;
@@ -635,14 +656,13 @@ struct iscsi_session {
 	/* Used for session reference counting */
 	int			session_usage_count;
 	int			session_waiting_on_uc;
-	u32			cmd_pdus;
-	u32			rsp_pdus;
-	u64			tx_data_octets;
-	u64			rx_data_octets;
-	u32			conn_digest_errors;
-	u32			conn_timeout_errors;
+	atomic_long_t		cmd_pdus;
+	atomic_long_t		rsp_pdus;
+	atomic_long_t		tx_data_octets;
+	atomic_long_t		rx_data_octets;
+	atomic_long_t		conn_digest_errors;
+	atomic_long_t		conn_timeout_errors;
 	u64			creation_time;
-	spinlock_t		session_stats_lock;
 	/* Number of active connections */
 	atomic_t		nconn;
 	atomic_t		session_continuation;
@@ -680,6 +700,7 @@ struct iscsi_login {
 	u8 version_max;
 	u8 login_complete;
 	u8 login_failed;
+	bool zero_tsih;
 	char isid[6];
 	u32 cmd_sn;
 	itt_t init_task_tag;
@@ -692,6 +713,7 @@ struct iscsi_login {
 	char *req_buf;
 	char *rsp_buf;
 	struct iscsi_conn *conn;
+	struct iscsi_np *np;
 } ____cacheline_aligned;
 
 struct iscsi_node_attrib {
@@ -738,11 +760,6 @@ struct iscsi_node_acl {
 	struct se_node_acl	se_node_acl;
 };
 
-#define NODE_STAT_GRPS(nacl)	(&(nacl)->node_stat_grps)
-
-#define ISCSI_NODE_ATTRIB(t)	(&(t)->node_attrib)
-#define ISCSI_NODE_AUTH(t)	(&(t)->node_auth)
-
 struct iscsi_tpg_attrib {
 	u32			authentication;
 	u32			login_timeout;
@@ -752,6 +769,8 @@ struct iscsi_tpg_attrib {
 	u32			default_cmdsn_depth;
 	u32			demo_mode_write_protect;
 	u32			prod_mode_write_protect;
+	u32			demo_mode_discovery;
+	u32			default_erl;
 	struct iscsi_portal_group *tpg;
 };
 
@@ -760,6 +779,7 @@ struct iscsi_np {
 	int			np_ip_proto;
 	int			np_sock_type;
 	enum np_thread_state_table np_thread_state;
+	bool                    enabled;
 	enum iscsi_timer_flags_table np_login_timer_flags;
 	u32			np_exports;
 	enum np_flags_table	np_flags;
@@ -771,7 +791,6 @@ struct iscsi_np {
 	struct __kernel_sockaddr_storage np_sockaddr;
 	struct task_struct	*np_thread;
 	struct timer_list	np_login_timer;
-	struct iscsi_portal_group *np_login_tpg;
 	void			*np_context;
 	struct iscsit_transport *np_transport;
 	struct list_head	np_list;
@@ -786,6 +805,8 @@ struct iscsi_tpg_np {
 	struct list_head	tpg_np_parent_list;
 	struct se_tpg_np	se_tpg_np;
 	spinlock_t		tpg_np_parent_lock;
+	struct completion	tpg_np_comp;
+	struct kref		tpg_np_kref;
 };
 
 struct iscsi_portal_group {
@@ -807,8 +828,9 @@ struct iscsi_portal_group {
 	spinlock_t		tpg_state_lock;
 	struct se_portal_group tpg_se_tpg;
 	struct mutex		tpg_access_lock;
-	struct mutex		np_login_lock;
+	struct semaphore	np_login_sem;
 	struct iscsi_tpg_attrib	tpg_attrib;
+	struct iscsi_node_auth	tpg_demo_auth;
 	/* Pointer to default list of iSCSI parameters for TPG */
 	struct iscsi_param_list	*param_list;
 	struct iscsi_tiqn	*tpg_tiqn;
@@ -816,12 +838,6 @@ struct iscsi_portal_group {
 	struct list_head	tpg_list;
 } ____cacheline_aligned;
 
-#define ISCSI_TPG_C(c)		((struct iscsi_portal_group *)(c)->tpg)
-#define ISCSI_TPG_LUN(c, l)  ((iscsi_tpg_list_t *)(c)->tpg->tpg_lun_list_t[l])
-#define ISCSI_TPG_S(s)		((struct iscsi_portal_group *)(s)->tpg)
-#define ISCSI_TPG_ATTRIB(t)	(&(t)->tpg_attrib)
-#define SE_TPG(tpg)		(&(tpg)->tpg_se_tpg)
-
 struct iscsi_wwn_stat_grps {
 	struct config_group	iscsi_stat_group;
 	struct config_group	iscsi_instance_group;
@@ -852,8 +868,6 @@ struct iscsi_tiqn {
 	struct iscsi_logout_stats    logout_stats;
 } ____cacheline_aligned;
 
-#define WWN_STAT_GRPS(tiqn)	(&(tiqn)->tiqn_stat_grps)
-
 struct iscsit_global {
 	/* In core shutdown */
 	u32			in_shutdown;
@@ -861,13 +875,20 @@ struct iscsit_global {
 	/* Unique identifier used for the authentication daemon */
 	u32			auth_id;
 	u32			inactive_ts;
+#define ISCSIT_BITMAP_BITS	262144
 	/* Thread Set bitmap count */
 	int			ts_bitmap_count;
 	/* Thread Set bitmap pointer */
 	unsigned long		*ts_bitmap;
+	spinlock_t		ts_bitmap_lock;
 	/* Used for iSCSI discovery session authentication */
 	struct iscsi_node_acl	discovery_acl;
 	struct iscsi_portal_group	*discovery_tpg;
+
+	struct list_head        *tiqn_list;
+	struct list_head	*np_list;
+	spinlock_t		*tiqn_lock;
+	spinlock_t		*np_lock;
 };
 
 #endif /* ISCSI_TARGET_CORE_H */
diff --git a/drivers/target/iscsi/iscsi_target_datain_values.c b/drivers/target/iscsi/iscsi_target_datain_values.c
index 848fee7..e93d5a7 100644
--- a/drivers/target/iscsi/iscsi_target_datain_values.c
+++ b/drivers/target/iscsi/iscsi_target_datain_values.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the iSCSI Target DataIN value generation functions.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
diff --git a/drivers/target/iscsi/iscsi_target_device.c b/drivers/target/iscsi/iscsi_target_device.c
index 1b74033..7087c73 100644
--- a/drivers/target/iscsi/iscsi_target_device.c
+++ b/drivers/target/iscsi/iscsi_target_device.c
@@ -2,9 +2,7 @@
  * This file contains the iSCSI Virtual Device and Disk Transport
  * agnostic related functions.
  *
- \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -60,11 +58,7 @@ void iscsit_increment_maxcmdsn(struct iscsi_cmd *cmd, struct iscsi_session *sess
 
 	cmd->maxcmdsn_inc = 1;
 
-	if (!mutex_trylock(&sess->cmdsn_mutex)) {
-		sess->max_cmd_sn += 1;
-		pr_debug("Updated MaxCmdSN to 0x%08x\n", sess->max_cmd_sn);
-		return;
-	}
+	mutex_lock(&sess->cmdsn_mutex);
 	sess->max_cmd_sn += 1;
 	pr_debug("Updated MaxCmdSN to 0x%08x\n", sess->max_cmd_sn);
 	mutex_unlock(&sess->cmdsn_mutex);
diff --git a/drivers/target/iscsi/iscsi_target_erl0.c b/drivers/target/iscsi/iscsi_target_erl0.c
old mode 100644
new mode 100755
index 08bd878..87f6872
--- a/drivers/target/iscsi/iscsi_target_erl0.c
+++ b/drivers/target/iscsi/iscsi_target_erl0.c
@@ -2,9 +2,7 @@
  * This file contains error recovery level zero functions used by
  * the iSCSI Target driver.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -347,7 +345,6 @@ static int iscsit_dataout_check_datasn(
 	struct iscsi_cmd *cmd,
 	unsigned char *buf)
 {
-	int dump = 0, recovery = 0;
 	u32 data_sn = 0;
 	struct iscsi_conn *conn = cmd->conn;
 	struct iscsi_data *hdr = (struct iscsi_data *) buf;
@@ -372,13 +369,11 @@ static int iscsit_dataout_check_datasn(
 		pr_err("Command ITT: 0x%08x, received DataSN: 0x%08x"
 			" higher than expected 0x%08x.\n", cmd->init_task_tag,
 				be32_to_cpu(hdr->datasn), data_sn);
-		recovery = 1;
 		goto recover;
 	} else if (be32_to_cpu(hdr->datasn) < data_sn) {
 		pr_err("Command ITT: 0x%08x, received DataSN: 0x%08x"
 			" lower than expected 0x%08x, discarding payload.\n",
 			cmd->init_task_tag, be32_to_cpu(hdr->datasn), data_sn);
-		dump = 1;
 		goto dump;
 	}
 
@@ -394,8 +389,7 @@ dump:
 	if (iscsit_dump_data_payload(conn, payload_length, 1) < 0)
 		return DATAOUT_CANNOT_RECOVER;
 
-	return (recovery || dump) ? DATAOUT_WITHIN_COMMAND_RECOVERY :
-				DATAOUT_NORMAL;
+	return DATAOUT_WITHIN_COMMAND_RECOVERY;
 }
 
 static int iscsit_dataout_pre_datapduinorder_yes(
@@ -759,7 +753,7 @@ int iscsit_check_post_dataout(
 static void iscsit_handle_time2retain_timeout(unsigned long data)
 {
 	struct iscsi_session *sess = (struct iscsi_session *) data;
-	struct iscsi_portal_group *tpg = ISCSI_TPG_S(sess);
+	struct iscsi_portal_group *tpg = sess->tpg;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 
 	spin_lock_bh(&se_tpg->session_lock);
@@ -787,7 +781,7 @@ static void iscsit_handle_time2retain_timeout(unsigned long data)
 		tiqn->sess_err_stats.last_sess_failure_type =
 				ISCSI_SESS_ERR_CXN_TIMEOUT;
 		tiqn->sess_err_stats.cxn_timeout_errors++;
-		sess->conn_timeout_errors++;
+		atomic_long_inc(&sess->conn_timeout_errors);
 		spin_unlock(&tiqn->sess_err_stats.lock);
 	}
 	}
@@ -803,9 +797,9 @@ void iscsit_start_time2retain_handler(struct iscsi_session *sess)
 	 * Only start Time2Retain timer when the associated TPG is still in
 	 * an ACTIVE (eg: not disabled or shutdown) state.
 	 */
-	spin_lock(&ISCSI_TPG_S(sess)->tpg_state_lock);
-	tpg_active = (ISCSI_TPG_S(sess)->tpg_state == TPG_STATE_ACTIVE);
-	spin_unlock(&ISCSI_TPG_S(sess)->tpg_state_lock);
+	spin_lock(&sess->tpg->tpg_state_lock);
+	tpg_active = (sess->tpg->tpg_state == TPG_STATE_ACTIVE);
+	spin_unlock(&sess->tpg->tpg_state_lock);
 
 	if (!tpg_active)
 		return;
@@ -831,7 +825,7 @@ void iscsit_start_time2retain_handler(struct iscsi_session *sess)
  */
 int iscsit_stop_time2retain_timer(struct iscsi_session *sess)
 {
-	struct iscsi_portal_group *tpg = ISCSI_TPG_S(sess);
+	struct iscsi_portal_group *tpg = sess->tpg;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 
 	if (sess->time2retain_timer_flags & ISCSI_TF_EXPIRED)
@@ -866,7 +860,10 @@ void iscsit_connection_reinstatement_rcfr(struct iscsi_conn *conn)
 	}
 	spin_unlock_bh(&conn->state_lock);
 
-	iscsi_thread_set_force_reinstatement(conn);
+	if (conn->tx_thread && conn->tx_thread_active)
+		send_sig(SIGINT, conn->tx_thread, 1);
+	if (conn->rx_thread && conn->rx_thread_active)
+		send_sig(SIGINT, conn->rx_thread, 1);
 
 sleep:
 	wait_for_completion(&conn->conn_wait_rcfr_comp);
@@ -891,10 +888,10 @@ void iscsit_cause_connection_reinstatement(struct iscsi_conn *conn, int sleep)
 		return;
 	}
 
-	if (iscsi_thread_set_force_reinstatement(conn) < 0) {
-		spin_unlock_bh(&conn->state_lock);
-		return;
-	}
+	if (conn->tx_thread && conn->tx_thread_active)
+		send_sig(SIGINT, conn->tx_thread, 1);
+	if (conn->rx_thread && conn->rx_thread_active)
+		send_sig(SIGINT, conn->rx_thread, 1);
 
 	atomic_set(&conn->connection_reinstatement, 1);
 	if (!sleep) {
diff --git a/drivers/target/iscsi/iscsi_target_erl1.c b/drivers/target/iscsi/iscsi_target_erl1.c
index 586c268..cda4d80 100644
--- a/drivers/target/iscsi/iscsi_target_erl1.c
+++ b/drivers/target/iscsi/iscsi_target_erl1.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains error recovery level one used by the iSCSI Target driver.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -509,7 +507,9 @@ int iscsit_handle_status_snack(
 	u32 last_statsn;
 	int found_cmd;
 
-	if (conn->exp_statsn > begrun) {
+	if (!begrun) {
+		begrun = conn->exp_statsn;
+	} else if (conn->exp_statsn > begrun) {
 		pr_err("Got Status SNACK Begrun: 0x%08x, RunLength:"
 			" 0x%08x but already got ExpStatSN: 0x%08x on CID:"
 			" %hu.\n", begrun, runlength, conn->exp_statsn,
diff --git a/drivers/target/iscsi/iscsi_target_erl2.c b/drivers/target/iscsi/iscsi_target_erl2.c
index 45a5afd..4ca8fd2 100644
--- a/drivers/target/iscsi/iscsi_target_erl2.c
+++ b/drivers/target/iscsi/iscsi_target_erl2.c
@@ -2,9 +2,7 @@
  * This file contains error recovery level two functions used by
  * the iSCSI Target driver.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -140,7 +138,7 @@ void iscsit_free_connection_recovery_entires(struct iscsi_session *sess)
 		list_for_each_entry_safe(cmd, cmd_tmp,
 				&cr->conn_recovery_cmd_list, i_conn_node) {
 
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 			cmd->conn = NULL;
 			spin_unlock(&cr->conn_recovery_cmd_lock);
 			iscsit_free_cmd(cmd, true);
@@ -162,7 +160,7 @@ void iscsit_free_connection_recovery_entires(struct iscsi_session *sess)
 		list_for_each_entry_safe(cmd, cmd_tmp,
 				&cr->conn_recovery_cmd_list, i_conn_node) {
 
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 			cmd->conn = NULL;
 			spin_unlock(&cr->conn_recovery_cmd_lock);
 			iscsit_free_cmd(cmd, true);
@@ -218,7 +216,7 @@ int iscsit_remove_cmd_from_connection_recovery(
 	}
 	cr = cmd->cr;
 
-	list_del(&cmd->i_conn_node);
+	list_del_init(&cmd->i_conn_node);
 	return --cr->cmd_count;
 }
 
@@ -299,7 +297,7 @@ int iscsit_discard_unacknowledged_ooo_cmdsns_for_conn(struct iscsi_conn *conn)
 		if (!(cmd->cmd_flags & ICF_OOO_CMDSN))
 			continue;
 
-		list_del(&cmd->i_conn_node);
+		list_del_init(&cmd->i_conn_node);
 
 		spin_unlock_bh(&conn->cmd_lock);
 		iscsit_free_cmd(cmd, true);
@@ -337,7 +335,7 @@ int iscsit_prepare_cmds_for_realligance(struct iscsi_conn *conn)
 	/*
 	 * Only perform connection recovery on ISCSI_OP_SCSI_CMD or
 	 * ISCSI_OP_NOOP_OUT opcodes.  For all other opcodes call
-	 * list_del(&cmd->i_conn_node); to release the command to the
+	 * list_del_init(&cmd->i_conn_node); to release the command to the
 	 * session pool and remove it from the connection's list.
 	 *
 	 * Also stop the DataOUT timer, which will be restarted after
@@ -353,7 +351,7 @@ int iscsit_prepare_cmds_for_realligance(struct iscsi_conn *conn)
 				" CID: %hu\n", cmd->iscsi_opcode,
 				cmd->init_task_tag, cmd->cmd_sn, conn->cid);
 
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 			spin_unlock_bh(&conn->cmd_lock);
 			iscsit_free_cmd(cmd, true);
 			spin_lock_bh(&conn->cmd_lock);
@@ -373,7 +371,7 @@ int iscsit_prepare_cmds_for_realligance(struct iscsi_conn *conn)
 		 */
 		if (!(cmd->cmd_flags & ICF_OOO_CMDSN) && !cmd->immediate_cmd &&
 		     iscsi_sna_gte(cmd->cmd_sn, conn->sess->exp_cmd_sn)) {
-			list_del(&cmd->i_conn_node);
+			list_del_init(&cmd->i_conn_node);
 			spin_unlock_bh(&conn->cmd_lock);
 			iscsit_free_cmd(cmd, true);
 			spin_lock_bh(&conn->cmd_lock);
@@ -395,7 +393,7 @@ int iscsit_prepare_cmds_for_realligance(struct iscsi_conn *conn)
 
 		cmd->sess = conn->sess;
 
-		list_del(&cmd->i_conn_node);
+		list_del_init(&cmd->i_conn_node);
 		spin_unlock_bh(&conn->cmd_lock);
 
 		iscsit_free_all_datain_reqs(cmd);
diff --git a/drivers/target/iscsi/iscsi_target_login.c b/drivers/target/iscsi/iscsi_target_login.c
index bc788c5..c7a843f 100644
--- a/drivers/target/iscsi/iscsi_target_login.c
+++ b/drivers/target/iscsi/iscsi_target_login.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the login functions used by the iSCSI Target driver.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -50,6 +48,7 @@ static struct iscsi_login *iscsi_login_init_conn(struct iscsi_conn *conn)
 		pr_err("Unable to allocate memory for struct iscsi_login.\n");
 		return NULL;
 	}
+	conn->login = login;
 	login->conn = conn;
 	login->first_request = 1;
 
@@ -84,6 +83,7 @@ static struct iscsi_login *iscsi_login_init_conn(struct iscsi_conn *conn)
 	init_completion(&conn->conn_logout_comp);
 	init_completion(&conn->rx_half_close_comp);
 	init_completion(&conn->tx_half_close_comp);
+	init_completion(&conn->rx_login_comp);
 	spin_lock_init(&conn->cmd_lock);
 	spin_lock_init(&conn->conn_usage_lock);
 	spin_lock_init(&conn->immed_queue_lock);
@@ -250,6 +250,28 @@ static void iscsi_login_set_conn_values(
 	mutex_unlock(&auth_id_lock);
 }
 
+static __printf(2, 3) int iscsi_change_param_sprintf(
+	struct iscsi_conn *conn,
+	const char *fmt, ...)
+{
+	va_list args;
+	unsigned char buf[64];
+
+	memset(buf, 0, sizeof buf);
+
+	va_start(args, fmt);
+	vsnprintf(buf, sizeof buf, fmt, args);
+	va_end(args);
+
+	if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
+		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
+				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+		return -1;
+	}
+
+	return 0;
+}
+
 /*
  *	This is the leading connection of a new session,
  *	or session reinstatement.
@@ -306,7 +328,6 @@ static int iscsi_login_zero_tsih_s1(
 	}
 
 	sess->creation_time = get_jiffies_64();
-	spin_lock_init(&sess->session_stats_lock);
 	/*
 	 * The FFP CmdSN window values will be allocated from the TPG's
 	 * Initiator Node's ACL once the login has been successfully completed.
@@ -339,7 +360,6 @@ static int iscsi_login_zero_tsih_s2(
 {
 	struct iscsi_node_attrib *na;
 	struct iscsi_session *sess = conn->sess;
-	unsigned char buf[32];
 	bool iser = false;
 
 	sess->tpg = conn->tpg;
@@ -348,15 +368,15 @@ static int iscsi_login_zero_tsih_s2(
 	 * Assign a new TPG Session Handle.  Note this is protected with
 	 * struct iscsi_portal_group->np_login_sem from iscsit_access_np().
 	 */
-	sess->tsih = ++ISCSI_TPG_S(sess)->ntsih;
+	sess->tsih = ++sess->tpg->ntsih;
 	if (!sess->tsih)
-		sess->tsih = ++ISCSI_TPG_S(sess)->ntsih;
+		sess->tsih = ++sess->tpg->ntsih;
 
 	/*
 	 * Create the default params from user defined values..
 	 */
 	if (iscsi_copy_param_list(&conn->param_list,
-				ISCSI_TPG_C(conn)->param_list, 1) < 0) {
+				conn->tpg->param_list, 1) < 0) {
 		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
 				ISCSI_LOGIN_STATUS_NO_RESOURCES);
 		return -1;
@@ -380,26 +400,16 @@ static int iscsi_login_zero_tsih_s2(
 	 *
 	 * In our case, we have already located the struct iscsi_tiqn at this point.
 	 */
-	memset(buf, 0, 32);
-	sprintf(buf, "TargetPortalGroupTag=%hu", ISCSI_TPG_S(sess)->tpgt);
-	if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
-		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
-				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+	if (iscsi_change_param_sprintf(conn, "TargetPortalGroupTag=%hu", sess->tpg->tpgt))
 		return -1;
-	}
 
 	/*
 	 * Workaround for Initiators that have broken connection recovery logic.
 	 *
 	 * "We would really like to get rid of this." Linux-iSCSI.org team
 	 */
-	memset(buf, 0, 32);
-	sprintf(buf, "ErrorRecoveryLevel=%d", na->default_erl);
-	if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
-		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
-				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+	if (iscsi_change_param_sprintf(conn, "ErrorRecoveryLevel=%d", na->default_erl))
 		return -1;
-	}
 
 	if (iscsi_login_disable_FIM_keys(conn->param_list, conn) < 0)
 		return -1;
@@ -411,12 +421,9 @@ static int iscsi_login_zero_tsih_s2(
 		unsigned long mrdsl, off;
 		int rc;
 
-		sprintf(buf, "RDMAExtensions=Yes");
-		if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
-			iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
-				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+		if (iscsi_change_param_sprintf(conn, "RDMAExtensions=Yes"))
 			return -1;
-		}
+
 		/*
 		 * Make MaxRecvDataSegmentLength PAGE_SIZE aligned for
 		 * Immediate Data + Unsolicitied Data-OUT if necessary..
@@ -428,7 +435,7 @@ static int iscsi_login_zero_tsih_s2(
 				ISCSI_LOGIN_STATUS_NO_RESOURCES);
 			return -1;
 		}
-		rc = strict_strtoul(param->value, 0, &mrdsl);
+		rc = kstrtoul(param->value, 0, &mrdsl);
 		if (rc < 0) {
 			iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
 				ISCSI_LOGIN_STATUS_NO_RESOURCES);
@@ -446,12 +453,8 @@ static int iscsi_login_zero_tsih_s2(
 		pr_warn("Aligning ISER MaxRecvDataSegmentLength: %lu down"
 			" to PAGE_SIZE\n", mrdsl);
 
-		sprintf(buf, "MaxRecvDataSegmentLength=%lu\n", mrdsl);
-		if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
-			iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
-				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+		if (iscsi_change_param_sprintf(conn, "MaxRecvDataSegmentLength=%lu\n", mrdsl))
 			return -1;
-		}
 	}
 
 	return 0;
@@ -525,13 +528,14 @@ static int iscsi_login_non_zero_tsih_s1(
  */
 static int iscsi_login_non_zero_tsih_s2(
 	struct iscsi_conn *conn,
-	unsigned char *buf)
+	unsigned char *p)
 {
 	struct iscsi_portal_group *tpg = conn->tpg;
 	struct iscsi_session *sess = NULL, *sess_p = NULL;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
 	struct se_session *se_sess, *se_sess_tmp;
-	struct iscsi_login_req *pdu = (struct iscsi_login_req *)buf;
+	struct iscsi_login_req *pdu = (struct iscsi_login_req *)p;
+	unsigned char buf[32];
 	bool iser = false;
 
 	spin_lock_bh(&se_tpg->session_lock);
@@ -576,7 +580,7 @@ static int iscsi_login_non_zero_tsih_s2(
 	iscsi_login_set_conn_values(sess, conn, pdu->cid);
 
 	if (iscsi_copy_param_list(&conn->param_list,
-			ISCSI_TPG_C(conn)->param_list, 0) < 0) {
+			conn->tpg->param_list, 0) < 0) {
 		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
 				ISCSI_LOGIN_STATUS_NO_RESOURCES);
 		return -1;
@@ -593,13 +597,8 @@ static int iscsi_login_non_zero_tsih_s2(
 	 *
 	 * In our case, we have already located the struct iscsi_tiqn at this point.
 	 */
-	memset(buf, 0, 32);
-	sprintf(buf, "TargetPortalGroupTag=%hu", ISCSI_TPG_S(sess)->tpgt);
-	if (iscsi_change_param_value(buf, conn->param_list, 0) < 0) {
-		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
-				ISCSI_LOGIN_STATUS_NO_RESOURCES);
+	if (iscsi_change_param_sprintf(conn, "TargetPortalGroupTag=%hu", sess->tpg->tpgt))
 		return -1;
-	}
 
 	return iscsi_login_disable_FIM_keys(conn->param_list, conn);
 }
@@ -684,7 +683,53 @@ static void iscsi_post_login_start_timers(struct iscsi_conn *conn)
 		iscsit_start_nopin_timer(conn);
 }
 
-static int iscsi_post_login_handler(
+int iscsit_start_kthreads(struct iscsi_conn *conn)
+{
+	int ret = 0;
+
+	spin_lock(&iscsit_global->ts_bitmap_lock);
+	conn->bitmap_id = bitmap_find_free_region(iscsit_global->ts_bitmap,
+					ISCSIT_BITMAP_BITS, get_order(1));
+	spin_unlock(&iscsit_global->ts_bitmap_lock);
+
+	if (conn->bitmap_id < 0) {
+		pr_err("bitmap_find_free_region() failed for"
+		       " iscsit_start_kthreads()\n");
+		return -ENOMEM;
+	}
+
+	conn->tx_thread = kthread_run(iscsi_target_tx_thread, conn,
+				      "%s", ISCSI_TX_THREAD_NAME);
+	if (IS_ERR(conn->tx_thread)) {
+		pr_err("Unable to start iscsi_target_tx_thread\n");
+		ret = PTR_ERR(conn->tx_thread);
+		goto out_bitmap;
+	}
+	conn->tx_thread_active = true;
+
+	conn->rx_thread = kthread_run(iscsi_target_rx_thread, conn,
+				      "%s", ISCSI_RX_THREAD_NAME);
+	if (IS_ERR(conn->rx_thread)) {
+		pr_err("Unable to start iscsi_target_rx_thread\n");
+		ret = PTR_ERR(conn->rx_thread);
+		goto out_tx;
+	}
+	conn->rx_thread_active = true;
+
+	return 0;
+out_tx:
+	send_sig(SIGINT, conn->tx_thread, 1);
+	kthread_stop(conn->tx_thread);
+	conn->tx_thread_active = false;
+out_bitmap:
+	spin_lock(&iscsit_global->ts_bitmap_lock);
+	bitmap_release_region(iscsit_global->ts_bitmap, conn->bitmap_id,
+			      get_order(1));
+	spin_unlock(&iscsit_global->ts_bitmap_lock);
+	return ret;
+}
+
+void iscsi_post_login_handler(
 	struct iscsi_np *np,
 	struct iscsi_conn *conn,
 	u8 zero_tsih)
@@ -692,9 +737,8 @@ static int iscsi_post_login_handler(
 	int stop_timer = 0;
 	struct iscsi_session *sess = conn->sess;
 	struct se_session *se_sess = sess->se_sess;
-	struct iscsi_portal_group *tpg = ISCSI_TPG_S(sess);
+	struct iscsi_portal_group *tpg = sess->tpg;
 	struct se_portal_group *se_tpg = &tpg->tpg_se_tpg;
-	struct iscsi_thread_set *ts;
 
 	iscsit_inc_conn_usage_count(conn);
 
@@ -709,7 +753,6 @@ static int iscsi_post_login_handler(
 	/*
 	 * SCSI Initiator -> SCSI Target Port Mapping
 	 */
-	ts = iscsi_get_thread_set();
 	if (!zero_tsih) {
 		iscsi_set_session_parameters(sess->sess_ops,
 				conn->param_list, 0);
@@ -737,8 +780,6 @@ static int iscsi_post_login_handler(
 		spin_unlock_bh(&sess->conn_lock);
 
 		iscsi_post_login_start_timers(conn);
-
-		iscsi_activate_thread_set(conn, ts);
 		/*
 		 * Determine CPU mask to ensure connection's RX and TX kthreads
 		 * are scheduled on the same CPU.
@@ -746,15 +787,20 @@ static int iscsi_post_login_handler(
 		iscsit_thread_get_cpumask(conn);
 		conn->conn_rx_reset_cpumask = 1;
 		conn->conn_tx_reset_cpumask = 1;
-
+		/*
+		 * Wakeup the sleeping iscsi_target_rx_thread() now that
+		 * iscsi_conn is in TARG_CONN_STATE_LOGGED_IN state.
+		 */
+		complete(&conn->rx_login_comp);
 		iscsit_dec_conn_usage_count(conn);
+
 		if (stop_timer) {
 			spin_lock_bh(&se_tpg->session_lock);
 			iscsit_stop_time2retain_timer(sess);
 			spin_unlock_bh(&se_tpg->session_lock);
 		}
 		iscsit_dec_session_usage_count(sess);
-		return 0;
+		return;
 	}
 
 	iscsi_set_session_parameters(sess->sess_ops, conn->param_list, 1);
@@ -796,7 +842,6 @@ static int iscsi_post_login_handler(
 	spin_unlock_bh(&se_tpg->session_lock);
 
 	iscsi_post_login_start_timers(conn);
-	iscsi_activate_thread_set(conn, ts);
 	/*
 	 * Determine CPU mask to ensure connection's RX and TX kthreads
 	 * are scheduled on the same CPU.
@@ -804,10 +849,12 @@ static int iscsi_post_login_handler(
 	iscsit_thread_get_cpumask(conn);
 	conn->conn_rx_reset_cpumask = 1;
 	conn->conn_tx_reset_cpumask = 1;
-
+	/*
+	 * Wakeup the sleeping iscsi_target_rx_thread() now that
+	 * iscsi_conn is in TARG_CONN_STATE_LOGGED_IN state.
+	 */
+	complete(&conn->rx_login_comp);
 	iscsit_dec_conn_usage_count(conn);
-
-	return 0;
 }
 
 static void iscsi_handle_login_thread_timeout(unsigned long data)
@@ -872,7 +919,7 @@ int iscsit_setup_np(
 	struct __kernel_sockaddr_storage *sockaddr)
 {
 	struct socket *sock = NULL;
-	int backlog = 5, ret, opt = 0, len;
+	int backlog = ISCSIT_TCP_BACKLOG, ret, opt = 0, len;
 
 	switch (np->np_network_transport) {
 	case ISCSI_TCP:
@@ -984,6 +1031,7 @@ int iscsi_target_setup_login_socket(
 	}
 
 	np->np_transport = t;
+	np->enabled = true;
 	return 0;
 }
 
@@ -1007,16 +1055,24 @@ int iscsit_accept_np(struct iscsi_np *np, struct iscsi_conn *conn)
 		rc = conn->sock->ops->getname(conn->sock,
 				(struct sockaddr *)&sock_in6, &err, 1);
 		if (!rc) {
-			snprintf(conn->login_ip, sizeof(conn->login_ip), "%pI6c",
-				&sock_in6.sin6_addr.in6_u);
+			if (!ipv6_addr_v4mapped(&sock_in6.sin6_addr))
+				snprintf(conn->login_ip, sizeof(conn->login_ip), "[%pI6c]",
+					&sock_in6.sin6_addr.in6_u);
+			else
+				snprintf(conn->login_ip, sizeof(conn->login_ip), "%pI4",
+					&sock_in6.sin6_addr.s6_addr32[3]);
 			conn->login_port = ntohs(sock_in6.sin6_port);
 		}
 
 		rc = conn->sock->ops->getname(conn->sock,
 				(struct sockaddr *)&sock_in6, &err, 0);
 		if (!rc) {
-			snprintf(conn->local_ip, sizeof(conn->local_ip), "%pI6c",
-				&sock_in6.sin6_addr.in6_u);
+			if (!ipv6_addr_v4mapped(&sock_in6.sin6_addr))
+				snprintf(conn->local_ip, sizeof(conn->local_ip), "[%pI6c]",
+					&sock_in6.sin6_addr.in6_u);
+			else
+				snprintf(conn->local_ip, sizeof(conn->local_ip), "%pI4",
+					&sock_in6.sin6_addr.s6_addr32[3]);
 			conn->local_port = ntohs(sock_in6.sin6_port);
 		}
 	} else {
@@ -1116,14 +1172,90 @@ iscsit_conn_set_transport(struct iscsi_conn *conn, struct iscsit_transport *t)
 	return 0;
 }
 
+void iscsi_target_login_sess_out(struct iscsi_conn *conn,
+		struct iscsi_np *np, bool zero_tsih, bool new_sess)
+{
+	if (new_sess == false)
+		goto old_sess_out;
+
+	pr_err("iSCSI Login negotiation failed.\n");
+	iscsit_collect_login_stats(conn, ISCSI_STATUS_CLS_INITIATOR_ERR,
+				   ISCSI_LOGIN_STATUS_INIT_ERR);
+	if (!zero_tsih || !conn->sess)
+		goto old_sess_out;
+	if (conn->sess->se_sess)
+		transport_free_session(conn->sess->se_sess);
+	if (conn->sess->session_index != 0) {
+		spin_lock_bh(&sess_idr_lock);
+		idr_remove(&sess_idr, conn->sess->session_index);
+		spin_unlock_bh(&sess_idr_lock);
+	}
+	kfree(conn->sess->sess_ops);
+	kfree(conn->sess);
+
+old_sess_out:
+	iscsi_stop_login_thread_timer(np);
+	/*
+	 * If login negotiation fails check if the Time2Retain timer
+	 * needs to be restarted.
+	 */
+	if (!zero_tsih && conn->sess) {
+		spin_lock_bh(&conn->sess->conn_lock);
+		if (conn->sess->session_state == TARG_SESS_STATE_FAILED) {
+			struct se_portal_group *se_tpg =
+					&conn->tpg->tpg_se_tpg;
+
+			atomic_set(&conn->sess->session_continuation, 0);
+			spin_unlock_bh(&conn->sess->conn_lock);
+			spin_lock_bh(&se_tpg->session_lock);
+			iscsit_start_time2retain_handler(conn->sess);
+			spin_unlock_bh(&se_tpg->session_lock);
+		} else
+			spin_unlock_bh(&conn->sess->conn_lock);
+		iscsit_dec_session_usage_count(conn->sess);
+	}
+
+	if (!IS_ERR(conn->conn_rx_hash.tfm))
+		crypto_free_hash(conn->conn_rx_hash.tfm);
+	if (!IS_ERR(conn->conn_tx_hash.tfm))
+		crypto_free_hash(conn->conn_tx_hash.tfm);
+
+	if (conn->conn_cpumask)
+		free_cpumask_var(conn->conn_cpumask);
+
+	kfree(conn->conn_ops);
+
+	if (conn->param_list) {
+		iscsi_release_param_list(conn->param_list);
+		conn->param_list = NULL;
+	}
+	iscsi_target_nego_release(conn);
+
+	if (conn->sock) {
+		sock_release(conn->sock);
+		conn->sock = NULL;
+	}
+
+	if (conn->conn_transport->iscsit_wait_conn)
+		conn->conn_transport->iscsit_wait_conn(conn);
+
+	if (conn->conn_transport->iscsit_free_conn)
+		conn->conn_transport->iscsit_free_conn(conn);
+
+	iscsit_put_transport(conn->conn_transport);
+	kfree(conn);
+}
+
 static int __iscsi_target_login_thread(struct iscsi_np *np)
 {
 	u8 *buffer, zero_tsih = 0;
-	int ret = 0, rc, stop;
+	int ret = 0, rc;
 	struct iscsi_conn *conn = NULL;
 	struct iscsi_login *login;
 	struct iscsi_portal_group *tpg = NULL;
 	struct iscsi_login_req *pdu;
+	struct iscsi_tpg_np *tpg_np;
+	bool new_sess = false;
 
 	flush_signals(current);
 
@@ -1131,6 +1263,9 @@ static int __iscsi_target_login_thread(struct iscsi_np *np)
 	if (np->np_thread_state == ISCSI_NP_THREAD_RESET) {
 		np->np_thread_state = ISCSI_NP_THREAD_ACTIVE;
 		complete(&np->np_restart_comp);
+	} else if (np->np_thread_state == ISCSI_NP_THREAD_SHUTDOWN) {
+		spin_unlock_bh(&np->np_thread_lock);
+		goto exit;
 	} else {
 		np->np_thread_state = ISCSI_NP_THREAD_ACTIVE;
 	}
@@ -1264,6 +1399,7 @@ static int __iscsi_target_login_thread(struct iscsi_np *np)
 		tpg = conn->tpg;
 		goto new_sess_out;
 	}
+	login->zero_tsih = zero_tsih;
 
 	tpg = conn->tpg;
 	if (!tpg) {
@@ -1279,114 +1415,44 @@ static int __iscsi_target_login_thread(struct iscsi_np *np)
 			goto old_sess_out;
 	}
 
-	if (iscsi_target_start_negotiation(login, conn) < 0)
-		goto new_sess_out;
-
-	if (!conn->sess) {
-		pr_err("struct iscsi_conn session pointer is NULL!\n");
+	ret = iscsi_target_start_negotiation(login, conn);
+	if (ret < 0)
 		goto new_sess_out;
-	}
 
 	iscsi_stop_login_thread_timer(np);
 
-	if (signal_pending(current))
-		goto new_sess_out;
+	if (ret == 1) {
+		tpg_np = conn->tpg_np;
 
-	ret = iscsi_post_login_handler(np, conn, zero_tsih);
-
-	if (ret < 0)
-		goto new_sess_out;
+		iscsi_post_login_handler(np, conn, zero_tsih);
+		iscsit_deaccess_np(np, tpg, tpg_np);
+	}
 
-	iscsit_deaccess_np(np, tpg);
 	tpg = NULL;
+	tpg_np = NULL;
 	/* Get another socket */
 	return 1;
 
 new_sess_out:
-	pr_err("iSCSI Login negotiation failed.\n");
-	iscsit_collect_login_stats(conn, ISCSI_STATUS_CLS_INITIATOR_ERR,
-				  ISCSI_LOGIN_STATUS_INIT_ERR);
-	if (!zero_tsih || !conn->sess)
-		goto old_sess_out;
-	if (conn->sess->se_sess)
-		transport_free_session(conn->sess->se_sess);
-	if (conn->sess->session_index != 0) {
-		spin_lock_bh(&sess_idr_lock);
-		idr_remove(&sess_idr, conn->sess->session_index);
-		spin_unlock_bh(&sess_idr_lock);
-	}
-	kfree(conn->sess->sess_ops);
-	kfree(conn->sess);
+	new_sess = true;
 old_sess_out:
-	iscsi_stop_login_thread_timer(np);
-	/*
-	 * If login negotiation fails check if the Time2Retain timer
-	 * needs to be restarted.
-	 */
-	if (!zero_tsih && conn->sess) {
-		spin_lock_bh(&conn->sess->conn_lock);
-		if (conn->sess->session_state == TARG_SESS_STATE_FAILED) {
-			struct se_portal_group *se_tpg =
-					&ISCSI_TPG_C(conn)->tpg_se_tpg;
-
-			atomic_set(&conn->sess->session_continuation, 0);
-			spin_unlock_bh(&conn->sess->conn_lock);
-			spin_lock_bh(&se_tpg->session_lock);
-			iscsit_start_time2retain_handler(conn->sess);
-			spin_unlock_bh(&se_tpg->session_lock);
-		} else
-			spin_unlock_bh(&conn->sess->conn_lock);
-		iscsit_dec_session_usage_count(conn->sess);
-	}
-
-	if (!IS_ERR(conn->conn_rx_hash.tfm))
-		crypto_free_hash(conn->conn_rx_hash.tfm);
-	if (!IS_ERR(conn->conn_tx_hash.tfm))
-		crypto_free_hash(conn->conn_tx_hash.tfm);
-
-	if (conn->conn_cpumask)
-		free_cpumask_var(conn->conn_cpumask);
-
-	kfree(conn->conn_ops);
-
-	if (conn->param_list) {
-		iscsi_release_param_list(conn->param_list);
-		conn->param_list = NULL;
-	}
-	iscsi_target_nego_release(conn);
-
-	if (conn->sock) {
-		sock_release(conn->sock);
-		conn->sock = NULL;
-	}
-
-	if (conn->conn_transport->iscsit_free_conn)
-		conn->conn_transport->iscsit_free_conn(conn);
-
-	iscsit_put_transport(conn->conn_transport);
-
-	kfree(conn);
+	tpg_np = conn->tpg_np;
+	iscsi_target_login_sess_out(conn, np, zero_tsih, new_sess);
+	new_sess = false;
 
 	if (tpg) {
-		iscsit_deaccess_np(np, tpg);
+		iscsit_deaccess_np(np, tpg, tpg_np);
 		tpg = NULL;
+		tpg_np = NULL;
 	}
 
 out:
-	stop = kthread_should_stop();
-	if (!stop && signal_pending(current)) {
-		spin_lock_bh(&np->np_thread_lock);
-		stop = (np->np_thread_state == ISCSI_NP_THREAD_SHUTDOWN);
-		spin_unlock_bh(&np->np_thread_lock);
-	}
-	/* Wait for another socket.. */
-	if (!stop)
-		return 1;
+	return 1;
+
 exit:
 	iscsi_stop_login_thread_timer(np);
 	spin_lock_bh(&np->np_thread_lock);
 	np->np_thread_state = ISCSI_NP_THREAD_EXIT;
-	np->np_thread = NULL;
 	spin_unlock_bh(&np->np_thread_lock);
 
 	return 0;
@@ -1399,7 +1465,7 @@ int iscsi_target_login_thread(void *arg)
 
 	allow_signal(SIGINT);
 
-	while (!kthread_should_stop()) {
+	while (1) {
 		ret = __iscsi_target_login_thread(np);
 		/*
 		 * We break and exit here unless another sock_accept() call
diff --git a/drivers/target/iscsi/iscsi_target_login.h b/drivers/target/iscsi/iscsi_target_login.h
index 63efd28..55cbf45 100644
--- a/drivers/target/iscsi/iscsi_target_login.h
+++ b/drivers/target/iscsi/iscsi_target_login.h
@@ -12,6 +12,10 @@ extern int iscsit_accept_np(struct iscsi_np *, struct iscsi_conn *);
 extern int iscsit_get_login_rx(struct iscsi_conn *, struct iscsi_login *);
 extern int iscsit_put_login_tx(struct iscsi_conn *, struct iscsi_login *, u32);
 extern void iscsit_free_conn(struct iscsi_np *, struct iscsi_conn *);
+extern int iscsit_start_kthreads(struct iscsi_conn *);
+extern void iscsi_post_login_handler(struct iscsi_np *, struct iscsi_conn *, u8);
+extern void iscsi_target_login_sess_out(struct iscsi_conn *, struct iscsi_np *,
+				bool, bool);
 extern int iscsi_target_login_thread(void *);
 extern int iscsi_login_disable_FIM_keys(struct iscsi_param_list *, struct iscsi_conn *);
 
diff --git a/drivers/target/iscsi/iscsi_target_nego.c b/drivers/target/iscsi/iscsi_target_nego.c
index cd5018f..9c536aa 100644
--- a/drivers/target/iscsi/iscsi_target_nego.c
+++ b/drivers/target/iscsi/iscsi_target_nego.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains main functions related to iSCSI Parameter negotiation.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -19,6 +17,7 @@
  ******************************************************************************/
 
 #include <linux/ctype.h>
+#include <linux/kthread.h>
 #include <scsi/iscsi_proto.h>
 #include <target/target_core_base.h>
 #include <target/target_core_fabric.h>
@@ -83,6 +82,11 @@ int extract_param(
 	if (*ptr == '0' && (*(ptr+1) == 'x' || *(ptr+1) == 'X')) {
 		ptr += 2; /* skip 0x */
 		*type = HEX;
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+	} else if (*ptr == '0' && (*(ptr+1) == 'b' || *(ptr+1) == 'B')) {
+		ptr += 2; /* skip 0b */
+		*type = BASE64;
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 	} else
 		*type = DECIMAL;
 
@@ -90,7 +94,7 @@ int extract_param(
 	if (len < 0)
 		return -1;
 
-	if (len > max_length) {
+	if (len >= max_length) {
 		pr_err("Length of input: %d exceeds max_length:"
 			" %d\n", len, max_length);
 		return -1;
@@ -112,6 +116,7 @@ static u32 iscsi_handle_authentication(
 	struct iscsi_session *sess = conn->sess;
 	struct iscsi_node_auth *auth;
 	struct iscsi_node_acl *iscsi_nacl;
+	struct iscsi_portal_group *iscsi_tpg;
 	struct se_node_acl *se_nacl;
 
 	if (!sess->sess_ops->SessionType) {
@@ -132,7 +137,17 @@ static u32 iscsi_handle_authentication(
 			return -1;
 		}
 
-		auth = ISCSI_NODE_AUTH(iscsi_nacl);
+		if (se_nacl->dynamic_node_acl) {
+			iscsi_tpg = container_of(se_nacl->se_tpg,
+					struct iscsi_portal_group, tpg_se_tpg);
+
+			auth = &iscsi_tpg->tpg_demo_auth;
+		} else {
+			iscsi_nacl = container_of(se_nacl, struct iscsi_node_acl,
+						  se_node_acl);
+
+			auth = &iscsi_nacl->node_auth;
+		}
 	} else {
 		/*
 		 * For SessionType=Discovery
@@ -352,10 +367,24 @@ static int iscsi_target_do_tx_login_io(struct iscsi_conn *conn, struct iscsi_log
 		ntohl(login_rsp->statsn), login->rsp_length);
 
 	padding = ((-login->rsp_length) & 3);
+	/*
+	 * Before sending the last login response containing the transition
+	 * bit for full-feature-phase, go ahead and start up TX/RX threads
+	 * now to avoid potential resource allocation failures after the
+	 * final login response has been sent.
+	 */
+	if (login->login_complete) {
+		int rc = iscsit_start_kthreads(conn);
+		if (rc) {
+			iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
+					    ISCSI_LOGIN_STATUS_NO_RESOURCES);
+			return -1;
+		}
+	}
 
 	if (conn->conn_transport->iscsit_put_login_tx(conn, login,
 					login->rsp_length + padding) < 0)
-		return -1;
+		goto err;
 
 	login->rsp_length		= 0;
 	mutex_lock(&sess->cmdsn_mutex);
@@ -364,17 +393,304 @@ static int iscsi_target_do_tx_login_io(struct iscsi_conn *conn, struct iscsi_log
 	mutex_unlock(&sess->cmdsn_mutex);
 
 	return 0;
+
+err:
+	if (login->login_complete) {
+		if (conn->rx_thread && conn->rx_thread_active) {
+			send_sig(SIGINT, conn->rx_thread, 1);
+			complete(&conn->rx_login_comp);
+			kthread_stop(conn->rx_thread);
+		}
+		if (conn->tx_thread && conn->tx_thread_active) {
+			send_sig(SIGINT, conn->tx_thread, 1);
+			kthread_stop(conn->tx_thread);
+		}
+		spin_lock(&iscsit_global->ts_bitmap_lock);
+		bitmap_release_region(iscsit_global->ts_bitmap, conn->bitmap_id,
+				      get_order(1));
+		spin_unlock(&iscsit_global->ts_bitmap_lock);
+	}
+	return -1;
 }
 
-static int iscsi_target_do_login_io(struct iscsi_conn *conn, struct iscsi_login *login)
+static void iscsi_target_sk_data_ready(struct sock *sk, int count)
 {
-	if (iscsi_target_do_tx_login_io(conn, login) < 0)
-		return -1;
+	struct iscsi_conn *conn = sk->sk_user_data;
+	bool rc;
 
-	if (conn->conn_transport->iscsit_get_login_rx(conn, login) < 0)
-		return -1;
+	pr_debug("Entering iscsi_target_sk_data_ready: conn: %p\n", conn);
 
-	return 0;
+	write_lock_bh(&sk->sk_callback_lock);
+	if (!sk->sk_user_data) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		return;
+	}
+	if (!test_bit(LOGIN_FLAGS_READY, &conn->login_flags)) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		pr_debug("Got LOGIN_FLAGS_READY=0, conn: %p >>>>\n", conn);
+		return;
+	}
+	if (test_bit(LOGIN_FLAGS_CLOSED, &conn->login_flags)) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		pr_debug("Got LOGIN_FLAGS_CLOSED=1, conn: %p >>>>\n", conn);
+		return;
+	}
+	if (test_and_set_bit(LOGIN_FLAGS_READ_ACTIVE, &conn->login_flags)) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		pr_debug("Got LOGIN_FLAGS_READ_ACTIVE=1, conn: %p >>>>\n", conn);
+		return;
+	}
+
+	rc = schedule_delayed_work(&conn->login_work, 0);
+	if (rc == false) {
+		pr_debug("iscsi_target_sk_data_ready, schedule_delayed_work"
+			 " got false\n");
+	}
+	write_unlock_bh(&sk->sk_callback_lock);
+}
+
+static void iscsi_target_sk_state_change(struct sock *);
+
+static void iscsi_target_set_sock_callbacks(struct iscsi_conn *conn)
+{
+	struct sock *sk;
+
+	if (!conn->sock)
+		return;
+
+	sk = conn->sock->sk;
+	pr_debug("Entering iscsi_target_set_sock_callbacks: conn: %p\n", conn);
+
+	write_lock_bh(&sk->sk_callback_lock);
+	sk->sk_user_data = conn;
+	conn->orig_data_ready = sk->sk_data_ready;
+	conn->orig_state_change = sk->sk_state_change;
+	sk->sk_data_ready = iscsi_target_sk_data_ready;
+	sk->sk_state_change = iscsi_target_sk_state_change;
+	write_unlock_bh(&sk->sk_callback_lock);
+
+	sk->sk_sndtimeo = TA_LOGIN_TIMEOUT * HZ;
+	sk->sk_rcvtimeo = TA_LOGIN_TIMEOUT * HZ;
+}
+
+static void iscsi_target_restore_sock_callbacks(struct iscsi_conn *conn)
+{
+	struct sock *sk;
+
+	if (!conn->sock)
+		return;
+
+	sk = conn->sock->sk;
+	pr_debug("Entering iscsi_target_restore_sock_callbacks: conn: %p\n", conn);
+
+	write_lock_bh(&sk->sk_callback_lock);
+	if (!sk->sk_user_data) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		return;
+	}
+	sk->sk_user_data = NULL;
+	sk->sk_data_ready = conn->orig_data_ready;
+	sk->sk_state_change = conn->orig_state_change;
+	write_unlock_bh(&sk->sk_callback_lock);
+
+	sk->sk_sndtimeo = MAX_SCHEDULE_TIMEOUT;
+	sk->sk_rcvtimeo = MAX_SCHEDULE_TIMEOUT;
+}
+
+static int iscsi_target_do_login(struct iscsi_conn *, struct iscsi_login *);
+
+static bool iscsi_target_sk_state_check(struct sock *sk)
+{
+	if (sk->sk_state == TCP_CLOSE_WAIT || sk->sk_state == TCP_CLOSE) {
+		pr_debug("iscsi_target_sk_state_check: TCP_CLOSE_WAIT|TCP_CLOSE,"
+			"returning FALSE\n");
+		return false;
+	}
+	return true;
+}
+
+static void iscsi_target_login_drop(struct iscsi_conn *conn, struct iscsi_login *login)
+{
+	struct iscsi_np *np = login->np;
+	bool zero_tsih = login->zero_tsih;
+
+	iscsi_remove_failed_auth_entry(conn);
+	iscsi_target_nego_release(conn);
+	iscsi_target_login_sess_out(conn, np, zero_tsih, true);
+}
+
+static void iscsi_target_login_timeout(unsigned long data)
+{
+	struct iscsi_conn *conn = (struct iscsi_conn *)data;
+
+	pr_debug("Entering iscsi_target_login_timeout >>>>>>>>>>>>>>>>>>>\n");
+
+	if (conn->login_kworker) {
+		pr_debug("Sending SIGINT to conn->login_kworker %s/%d\n",
+			 conn->login_kworker->comm, conn->login_kworker->pid);
+		send_sig(SIGINT, conn->login_kworker, 1);
+	}
+}
+
+static void iscsi_target_do_login_rx(struct work_struct *work)
+{
+	struct iscsi_conn *conn = container_of(work,
+				struct iscsi_conn, login_work.work);
+	struct iscsi_login *login = conn->login;
+	struct iscsi_np *np = login->np;
+	struct iscsi_portal_group *tpg = conn->tpg;
+	struct iscsi_tpg_np *tpg_np = conn->tpg_np;
+	struct timer_list login_timer;
+	int rc, zero_tsih = login->zero_tsih;
+	bool state;
+
+	pr_debug("entering iscsi_target_do_login_rx, conn: %p, %s:%d\n",
+			conn, current->comm, current->pid);
+
+	spin_lock(&tpg->tpg_state_lock);
+	state = (tpg->tpg_state == TPG_STATE_ACTIVE);
+	spin_unlock(&tpg->tpg_state_lock);
+
+	if (state == false) {
+		pr_debug("iscsi_target_do_login_rx: tpg_state != TPG_STATE_ACTIVE\n");
+		iscsi_target_restore_sock_callbacks(conn);
+		iscsi_target_login_drop(conn, login);
+		iscsit_deaccess_np(np, tpg, tpg_np);
+		return;
+	}
+
+	if (conn->sock) {
+		struct sock *sk = conn->sock->sk;
+
+		read_lock_bh(&sk->sk_callback_lock);
+		state = iscsi_target_sk_state_check(sk);
+		read_unlock_bh(&sk->sk_callback_lock);
+
+		if (state == false) {
+			pr_debug("iscsi_target_do_login_rx, TCP state CLOSE\n");
+			iscsi_target_restore_sock_callbacks(conn);
+			iscsi_target_login_drop(conn, login);
+			iscsit_deaccess_np(np, tpg, tpg_np);
+			return;
+		}
+	}
+
+	conn->login_kworker = current;
+	allow_signal(SIGINT);
+
+	init_timer(&login_timer);
+	login_timer.expires = (get_jiffies_64() + TA_LOGIN_TIMEOUT * HZ);
+	login_timer.data = (unsigned long)conn;
+	login_timer.function = iscsi_target_login_timeout;
+	add_timer(&login_timer);
+	pr_debug("Starting login_timer for %s/%d\n", current->comm, current->pid);
+
+	rc = conn->conn_transport->iscsit_get_login_rx(conn, login);
+	del_timer_sync(&login_timer);
+	flush_signals(current);
+	conn->login_kworker = NULL;
+
+	if (rc < 0) {
+		iscsi_target_restore_sock_callbacks(conn);
+		iscsi_target_login_drop(conn, login);
+		iscsit_deaccess_np(np, tpg, tpg_np);
+		return;
+	}
+
+	pr_debug("iscsi_target_do_login_rx after rx_login_io, %p, %s:%d\n",
+			conn, current->comm, current->pid);
+
+	rc = iscsi_target_do_login(conn, login);
+	if (rc < 0) {
+		iscsi_target_restore_sock_callbacks(conn);
+		iscsi_target_login_drop(conn, login);
+		iscsit_deaccess_np(np, tpg, tpg_np);
+	} else if (!rc) {
+		if (conn->sock) {
+			struct sock *sk = conn->sock->sk;
+
+			write_lock_bh(&sk->sk_callback_lock);
+			clear_bit(LOGIN_FLAGS_READ_ACTIVE, &conn->login_flags);
+			write_unlock_bh(&sk->sk_callback_lock);
+		}
+	} else if (rc == 1) {
+		iscsi_target_nego_release(conn);
+		iscsi_post_login_handler(np, conn, zero_tsih);
+		iscsit_deaccess_np(np, tpg, tpg_np);
+	}
+}
+
+static void iscsi_target_do_cleanup(struct work_struct *work)
+{
+	struct iscsi_conn *conn = container_of(work,
+				struct iscsi_conn, login_cleanup_work.work);
+	struct sock *sk = conn->sock->sk;
+	struct iscsi_login *login = conn->login;
+	struct iscsi_np *np = login->np;
+	struct iscsi_portal_group *tpg = conn->tpg;
+	struct iscsi_tpg_np *tpg_np = conn->tpg_np;
+
+	pr_debug("Entering iscsi_target_do_cleanup\n");
+
+	cancel_delayed_work_sync(&conn->login_work);
+	conn->orig_state_change(sk);
+
+	iscsi_target_restore_sock_callbacks(conn);
+	iscsi_target_login_drop(conn, login);
+	iscsit_deaccess_np(np, tpg, tpg_np);
+
+	pr_debug("iscsi_target_do_cleanup done()\n");
+}
+
+static void iscsi_target_sk_state_change(struct sock *sk)
+{
+	struct iscsi_conn *conn;
+	void (*orig_state_change)(struct sock *);
+	bool state;
+
+	pr_debug("Entering iscsi_target_sk_state_change\n");
+
+	write_lock_bh(&sk->sk_callback_lock);
+	conn = sk->sk_user_data;
+	if (!conn) {
+		write_unlock_bh(&sk->sk_callback_lock);
+		return;
+	}
+	orig_state_change = conn->orig_state_change;
+
+	if (!test_bit(LOGIN_FLAGS_READY, &conn->login_flags)) {
+		pr_debug("Got LOGIN_FLAGS_READY=0 sk_state_change conn: %p\n",
+			 conn);
+		write_unlock_bh(&sk->sk_callback_lock);
+		orig_state_change(sk);
+		return;
+	}
+	if (test_bit(LOGIN_FLAGS_READ_ACTIVE, &conn->login_flags)) {
+		pr_debug("Got LOGIN_FLAGS_READ_ACTIVE=1 sk_state_change"
+			 " conn: %p\n", conn);
+		write_unlock_bh(&sk->sk_callback_lock);
+		orig_state_change(sk);
+		return;
+	}
+	if (test_and_set_bit(LOGIN_FLAGS_CLOSED, &conn->login_flags)) {
+		pr_debug("Got LOGIN_FLAGS_CLOSED=1 sk_state_change conn: %p\n",
+			 conn);
+		write_unlock_bh(&sk->sk_callback_lock);
+		orig_state_change(sk);
+		return;
+	}
+
+	state = iscsi_target_sk_state_check(sk);
+	write_unlock_bh(&sk->sk_callback_lock);
+
+	pr_debug("iscsi_target_sk_state_change: state: %d\n", state);
+
+	if (!state) {
+		pr_debug("iscsi_target_sk_state_change got failed state\n");
+		schedule_delayed_work(&conn->login_cleanup_work, 0);
+		return;
+	}
+	orig_state_change(sk);
 }
 
 /*
@@ -511,7 +827,7 @@ static int iscsi_target_handle_csg_zero(
 		return -1;
 
 	if (!iscsi_check_negotiated_keys(conn->param_list)) {
-		if (ISCSI_TPG_ATTRIB(ISCSI_TPG_C(conn))->authentication &&
+		if (conn->tpg->tpg_attrib.authentication &&
 		    !strncmp(param->value, NONE, 4)) {
 			pr_err("Initiator sent AuthMethod=None but"
 				" Target is enforcing iSCSI Authentication,"
@@ -521,7 +837,7 @@ static int iscsi_target_handle_csg_zero(
 			return -1;
 		}
 
-		if (ISCSI_TPG_ATTRIB(ISCSI_TPG_C(conn))->authentication &&
+		if (conn->tpg->tpg_attrib.authentication &&
 		    !login->auth_complete)
 			return 0;
 
@@ -584,7 +900,7 @@ static int iscsi_target_handle_csg_one(struct iscsi_conn *conn, struct iscsi_log
 	}
 
 	if (!login->auth_complete &&
-	     ISCSI_TPG_ATTRIB(ISCSI_TPG_C(conn))->authentication) {
+	     conn->tpg->tpg_attrib.authentication) {
 		pr_err("Initiator is requesting CSG: 1, has not been"
 			 " successfully authenticated, and the Target is"
 			" enforcing iSCSI Authentication, login failed.\n");
@@ -632,10 +948,11 @@ static int iscsi_target_do_login(struct iscsi_conn *conn, struct iscsi_login *lo
 			if (login_rsp->flags & ISCSI_FLAG_LOGIN_TRANSIT) {
 				login->tsih = conn->sess->tsih;
 				login->login_complete = 1;
+				iscsi_target_restore_sock_callbacks(conn);
 				if (iscsi_target_do_tx_login_io(conn,
 						login) < 0)
 					return -1;
-				return 0;
+				return 1;
 			}
 			break;
 		default:
@@ -645,13 +962,29 @@ static int iscsi_target_do_login(struct iscsi_conn *conn, struct iscsi_login *lo
 			break;
 		}
 
-		if (iscsi_target_do_login_io(conn, login) < 0)
+		if (iscsi_target_do_tx_login_io(conn, login) < 0)
 			return -1;
 
 		if (login_rsp->flags & ISCSI_FLAG_LOGIN_TRANSIT) {
 			login_rsp->flags &= ~ISCSI_FLAG_LOGIN_TRANSIT;
 			login_rsp->flags &= ~ISCSI_FLAG_LOGIN_NEXT_STAGE_MASK;
 		}
+		break;
+	}
+
+	if (conn->sock) {
+		struct sock *sk = conn->sock->sk;
+		bool state;
+
+		read_lock_bh(&sk->sk_callback_lock);
+		state = iscsi_target_sk_state_check(sk);
+		read_unlock_bh(&sk->sk_callback_lock);
+
+		if (!state) {
+			pr_debug("iscsi_target_do_login() failed state for"
+				 " conn: %p\n", conn);
+			return -1;
+		}
 	}
 
 	return 0;
@@ -684,9 +1017,17 @@ int iscsi_target_locate_portal(
 	char *tmpbuf, *start = NULL, *end = NULL, *key, *value;
 	struct iscsi_session *sess = conn->sess;
 	struct iscsi_tiqn *tiqn;
+	struct iscsi_tpg_np *tpg_np = NULL;
 	struct iscsi_login_req *login_req;
-	u32 payload_length;
-	int sessiontype = 0, ret = 0;
+	struct se_node_acl *se_nacl;
+	u32 payload_length, queue_depth = 0;
+	int sessiontype = 0, ret = 0, tag_num, tag_size;
+
+	INIT_DELAYED_WORK(&conn->login_work, iscsi_target_do_login_rx);
+	INIT_DELAYED_WORK(&conn->login_cleanup_work, iscsi_target_do_cleanup);
+	iscsi_target_set_sock_callbacks(conn);
+
+	login->np = np;
 
 	login_req = (struct iscsi_login_req *) login->req;
 	payload_length = ntoh24(login_req->dlength);
@@ -780,7 +1121,7 @@ int iscsi_target_locate_portal(
 			goto out;
 		}
 		ret = 0;
-		goto out;
+		goto alloc_tags;
 	}
 
 get_target:
@@ -811,7 +1152,7 @@ get_target:
 	/*
 	 * Locate Target Portal Group from Storage Node.
 	 */
-	conn->tpg = iscsit_get_tpg_from_np(tiqn, np);
+	conn->tpg = iscsit_get_tpg_from_np(tiqn, np, &tpg_np);
 	if (!conn->tpg) {
 		pr_err("Unable to locate Target Portal Group"
 				" on %s\n", tiqn->tiqn);
@@ -821,12 +1162,16 @@ get_target:
 		ret = -1;
 		goto out;
 	}
+	conn->tpg_np = tpg_np;
 	pr_debug("Located Portal Group Object: %hu\n", conn->tpg->tpgt);
 	/*
 	 * Setup crc32c modules from libcrypto
 	 */
 	if (iscsi_login_setup_crypto(conn) < 0) {
 		pr_err("iscsi_login_setup_crypto() failed\n");
+		kref_put(&tpg_np->tpg_np_kref, iscsit_login_kref_put);
+		iscsit_put_tiqn_for_login(tiqn);
+		conn->tpg = NULL;
 		ret = -1;
 		goto out;
 	}
@@ -835,11 +1180,12 @@ get_target:
 	 * process login attempt.
 	 */
 	if (iscsit_access_np(np, conn->tpg) < 0) {
+		kref_put(&tpg_np->tpg_np_kref, iscsit_login_kref_put);
 		iscsit_put_tiqn_for_login(tiqn);
 		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
 				ISCSI_LOGIN_STATUS_SVC_UNAVAILABLE);
-		ret = -1;
 		conn->tpg = NULL;
+		ret = -1;
 		goto out;
 	}
 
@@ -872,8 +1218,27 @@ get_target:
 		ret = -1;
 		goto out;
 	}
+	se_nacl = sess->se_sess->se_node_acl;
+	queue_depth = se_nacl->queue_depth;
+	/*
+	 * Setup pre-allocated tags based upon allowed per NodeACL CmdSN
+	 * depth for non immediate commands, plus extra tags for immediate
+	 * commands.
+	 *
+	 * Also enforce a ISCSIT_MIN_TAGS to prevent unnecessary contention
+	 * in per-cpu-ida tag allocation logic + small queue_depth.
+	 */
+alloc_tags:
+	tag_num = max_t(u32, ISCSIT_MIN_TAGS, queue_depth);
+	tag_num = (tag_num * 2) + ISCSIT_EXTRA_TAGS;
+	tag_size = sizeof(struct iscsi_cmd) + conn->conn_transport->priv_size;
 
-	ret = 0;
+	ret = transport_alloc_session_tags(sess->se_sess, tag_num, tag_size);
+	if (ret < 0) {
+		iscsit_tx_login_rsp(conn, ISCSI_STATUS_CLS_TARGET_ERR,
+				    ISCSI_LOGIN_STATUS_NO_RESOURCES);
+		ret = -1;
+	}
 out:
 	kfree(tmpbuf);
 	return ret;
@@ -886,10 +1251,23 @@ int iscsi_target_start_negotiation(
 	int ret;
 
 	ret = iscsi_target_do_login(conn, login);
-	if (ret != 0)
+	if (!ret) {
+		if (conn->sock) {
+			struct sock *sk = conn->sock->sk;
+
+			write_lock_bh(&sk->sk_callback_lock);
+			set_bit(LOGIN_FLAGS_READY, &conn->login_flags);
+			write_unlock_bh(&sk->sk_callback_lock);
+		}
+	} else if (ret < 0) {
+		cancel_delayed_work_sync(&conn->login_work);
+		cancel_delayed_work_sync(&conn->login_cleanup_work);
+		iscsi_target_restore_sock_callbacks(conn);
 		iscsi_remove_failed_auth_entry(conn);
+	}
+	if (ret != 0)
+		iscsi_target_nego_release(conn);
 
-	iscsi_target_nego_release(conn);
 	return ret;
 }
 
diff --git a/drivers/target/iscsi/iscsi_target_nego.h b/drivers/target/iscsi/iscsi_target_nego.h
index f021cbd..54d5cd5 100644
--- a/drivers/target/iscsi/iscsi_target_nego.h
+++ b/drivers/target/iscsi/iscsi_target_nego.h
@@ -3,6 +3,9 @@
 
 #define DECIMAL         0
 #define HEX             1
+#ifdef ISCSI_CHAP_BASE64_SUPPORT
+#define BASE64          2
+#endif /* ISCSI_CHAP_BASE64_SUPPORT */
 
 extern void convert_null_to_semi(char *, int);
 extern int extract_param(const char *, const char *, unsigned int, char *,
diff --git a/drivers/target/iscsi/iscsi_target_nodeattrib.c b/drivers/target/iscsi/iscsi_target_nodeattrib.c
index 11dc293..16454a9 100644
--- a/drivers/target/iscsi/iscsi_target_nodeattrib.c
+++ b/drivers/target/iscsi/iscsi_target_nodeattrib.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the main functions related to Initiator Node Attributes.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -35,7 +33,8 @@ static inline char *iscsit_na_get_initiatorname(
 }
 
 void iscsit_set_default_node_attribues(
-	struct iscsi_node_acl *acl)
+	struct iscsi_node_acl *acl,
+	struct iscsi_portal_group *tpg)
 {
 	struct iscsi_node_attrib *a = &acl->node_attrib;
 
@@ -46,7 +45,7 @@ void iscsit_set_default_node_attribues(
 	a->random_datain_pdu_offsets = NA_RANDOM_DATAIN_PDU_OFFSETS;
 	a->random_datain_seq_offsets = NA_RANDOM_DATAIN_SEQ_OFFSETS;
 	a->random_r2t_offsets = NA_RANDOM_R2T_OFFSETS;
-	a->default_erl = NA_DEFAULT_ERL;
+	a->default_erl = tpg->tpg_attrib.default_erl;
 }
 
 int iscsit_na_dataout_timeout(
diff --git a/drivers/target/iscsi/iscsi_target_nodeattrib.h b/drivers/target/iscsi/iscsi_target_nodeattrib.h
index c970b326..0c69a46 100644
--- a/drivers/target/iscsi/iscsi_target_nodeattrib.h
+++ b/drivers/target/iscsi/iscsi_target_nodeattrib.h
@@ -1,7 +1,8 @@
 #ifndef ISCSI_TARGET_NODEATTRIB_H
 #define ISCSI_TARGET_NODEATTRIB_H
 
-extern void iscsit_set_default_node_attribues(struct iscsi_node_acl *);
+extern void iscsit_set_default_node_attribues(struct iscsi_node_acl *,
+					      struct iscsi_portal_group *);
 extern int iscsit_na_dataout_timeout(struct iscsi_node_acl *, u32);
 extern int iscsit_na_dataout_timeout_retries(struct iscsi_node_acl *, u32);
 extern int iscsit_na_nopin_timeout(struct iscsi_node_acl *, u32);
diff --git a/drivers/target/iscsi/iscsi_target_parameters.c b/drivers/target/iscsi/iscsi_target_parameters.c
index e382221..43b7e6a 100644
--- a/drivers/target/iscsi/iscsi_target_parameters.c
+++ b/drivers/target/iscsi/iscsi_target_parameters.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains main functions related to iSCSI Parameter negotiation.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -603,7 +601,7 @@ int iscsi_copy_param_list(
 	param_list = kzalloc(sizeof(struct iscsi_param_list), GFP_KERNEL);
 	if (!param_list) {
 		pr_err("Unable to allocate memory for struct iscsi_param_list.\n");
-		goto err_out;
+		return -1;
 	}
 	INIT_LIST_HEAD(&param_list->param_list);
 	INIT_LIST_HEAD(&param_list->extra_response_list);
@@ -1182,7 +1180,7 @@ static int iscsi_check_acceptor_state(struct iscsi_param *param, char *value,
 			unsigned long long tmp;
 			int rc;
 
-			rc = strict_strtoull(param->value, 0, &tmp);
+			rc = kstrtoull(param->value, 0, &tmp);
 			if (rc < 0)
 				return -1;
 
@@ -1799,9 +1797,6 @@ void iscsi_set_connection_parameters(
 		 * this key is not sent over the wire.
 		 */
 		if (!strcmp(param->name, MAXXMITDATASEGMENTLENGTH)) {
-			if (param_list->iser == true)
-				continue;
-
 			ops->MaxXmitDataSegmentLength =
 				simple_strtoul(param->value, &tmpptr, 0);
 			pr_debug("MaxXmitDataSegmentLength:     %s\n",
diff --git a/drivers/target/iscsi/iscsi_target_seq_pdu_list.c b/drivers/target/iscsi/iscsi_target_seq_pdu_list.c
index edb592a..ca41b58 100644
--- a/drivers/target/iscsi/iscsi_target_seq_pdu_list.c
+++ b/drivers/target/iscsi/iscsi_target_seq_pdu_list.c
@@ -2,9 +2,7 @@
  * This file contains main functions related to iSCSI DataSequenceInOrder=No
  * and DataPDUInOrder=No.
  *
- \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
diff --git a/drivers/target/iscsi/iscsi_target_stat.c b/drivers/target/iscsi/iscsi_target_stat.c
index 464b420..1033955 100644
--- a/drivers/target/iscsi/iscsi_target_stat.c
+++ b/drivers/target/iscsi/iscsi_target_stat.c
@@ -2,9 +2,7 @@
  * Modern ConfigFS group context specific iSCSI statistics based on original
  * iscsi_target_mib.c code
  *
- * Copyright (c) 2011 Rising Tide Systems
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * Copyright (c) 2011-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -177,7 +175,7 @@ ISCSI_STAT_INSTANCE_ATTR_RO(description);
 static ssize_t iscsi_stat_instance_show_attr_vendor(
 	struct iscsi_wwn_stat_grps *igrps, char *page)
 {
-	return snprintf(page, PAGE_SIZE, "RisingTide Systems iSCSI-Target\n");
+	return snprintf(page, PAGE_SIZE, "Datera, Inc. iSCSI-Target\n");
 }
 ISCSI_STAT_INSTANCE_ATTR_RO(vendor);
 
@@ -432,13 +430,7 @@ static ssize_t iscsi_stat_tgt_attr_show_attr_fail_intr_addr(
 	int ret;
 
 	spin_lock(&lstat->lock);
-	if (lstat->last_intr_fail_ip_family == AF_INET6) {
-		ret = snprintf(page, PAGE_SIZE, "[%s]\n",
-			       lstat->last_intr_fail_ip_addr);
-	} else {
-		ret = snprintf(page, PAGE_SIZE, "%s\n",
-			       lstat->last_intr_fail_ip_addr);
-	}
+	ret = snprintf(page, PAGE_SIZE, "%s\n", lstat->last_intr_fail_ip_addr);
 	spin_unlock(&lstat->lock);
 
 	return ret;
@@ -800,7 +792,8 @@ static ssize_t iscsi_stat_sess_show_attr_cmd_pdus(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%u\n", sess->cmd_pdus);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->cmd_pdus));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
@@ -823,7 +816,8 @@ static ssize_t iscsi_stat_sess_show_attr_rsp_pdus(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%u\n", sess->rsp_pdus);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->rsp_pdus));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
@@ -846,8 +840,8 @@ static ssize_t iscsi_stat_sess_show_attr_txdata_octs(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%llu\n",
-				(unsigned long long)sess->tx_data_octets);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->tx_data_octets));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
@@ -870,8 +864,8 @@ static ssize_t iscsi_stat_sess_show_attr_rxdata_octs(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%llu\n",
-				(unsigned long long)sess->rx_data_octets);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->rx_data_octets));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
@@ -894,8 +888,8 @@ static ssize_t iscsi_stat_sess_show_attr_conn_digest_errors(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%u\n",
-					sess->conn_digest_errors);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->conn_digest_errors));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
@@ -918,8 +912,8 @@ static ssize_t iscsi_stat_sess_show_attr_conn_timeout_errors(
 	if (se_sess) {
 		sess = se_sess->fabric_sess_ptr;
 		if (sess)
-			ret = snprintf(page, PAGE_SIZE, "%u\n",
-					sess->conn_timeout_errors);
+			ret = snprintf(page, PAGE_SIZE, "%lu\n",
+				       atomic_long_read(&sess->conn_timeout_errors));
 	}
 	spin_unlock_bh(&se_nacl->nacl_sess_lock);
 
diff --git a/drivers/target/iscsi/iscsi_target_tmr.c b/drivers/target/iscsi/iscsi_target_tmr.c
index b997e5d..78404b1 100644
--- a/drivers/target/iscsi/iscsi_target_tmr.c
+++ b/drivers/target/iscsi/iscsi_target_tmr.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the iSCSI Target specific Task Management functions.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
diff --git a/drivers/target/iscsi/iscsi_target_tpg.c b/drivers/target/iscsi/iscsi_target_tpg.c
index 439260b..d875f79 100644
--- a/drivers/target/iscsi/iscsi_target_tpg.c
+++ b/drivers/target/iscsi/iscsi_target_tpg.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains iSCSI Target Portal Group related functions.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -49,7 +47,7 @@ struct iscsi_portal_group *iscsit_alloc_portal_group(struct iscsi_tiqn *tiqn, u1
 	INIT_LIST_HEAD(&tpg->tpg_gnp_list);
 	INIT_LIST_HEAD(&tpg->tpg_list);
 	mutex_init(&tpg->tpg_access_lock);
-	mutex_init(&tpg->np_login_lock);
+	sema_init(&tpg->np_login_sem, 1);
 	spin_lock_init(&tpg->tpg_state_lock);
 	spin_lock_init(&tpg->tpg_np_lock);
 
@@ -129,7 +127,8 @@ void iscsit_release_discovery_tpg(void)
 
 struct iscsi_portal_group *iscsit_get_tpg_from_np(
 	struct iscsi_tiqn *tiqn,
-	struct iscsi_np *np)
+	struct iscsi_np *np,
+	struct iscsi_tpg_np **tpg_np_out)
 {
 	struct iscsi_portal_group *tpg = NULL;
 	struct iscsi_tpg_np *tpg_np;
@@ -138,7 +137,7 @@ struct iscsi_portal_group *iscsit_get_tpg_from_np(
 	list_for_each_entry(tpg, &tiqn->tiqn_tpg_list, tpg_list) {
 
 		spin_lock(&tpg->tpg_state_lock);
-		if (tpg->tpg_state == TPG_STATE_FREE) {
+		if (tpg->tpg_state != TPG_STATE_ACTIVE) {
 			spin_unlock(&tpg->tpg_state_lock);
 			continue;
 		}
@@ -147,6 +146,8 @@ struct iscsi_portal_group *iscsit_get_tpg_from_np(
 		spin_lock(&tpg->tpg_np_lock);
 		list_for_each_entry(tpg_np, &tpg->tpg_gnp_list, tpg_np_list) {
 			if (tpg_np->tpg_np == np) {
+				*tpg_np_out = tpg_np;
+				kref_get(&tpg_np->tpg_np_kref);
 				spin_unlock(&tpg->tpg_np_lock);
 				spin_unlock(&tiqn->tiqn_tpg_lock);
 				return tpg;
@@ -175,18 +176,22 @@ void iscsit_put_tpg(struct iscsi_portal_group *tpg)
 
 static void iscsit_clear_tpg_np_login_thread(
 	struct iscsi_tpg_np *tpg_np,
-	struct iscsi_portal_group *tpg)
+	struct iscsi_portal_group *tpg,
+	bool shutdown)
 {
 	if (!tpg_np->tpg_np) {
 		pr_err("struct iscsi_tpg_np->tpg_np is NULL!\n");
 		return;
 	}
 
-	iscsit_reset_np_thread(tpg_np->tpg_np, tpg_np, tpg);
+	if (shutdown)
+		tpg_np->tpg_np->enabled = false;
+	iscsit_reset_np_thread(tpg_np->tpg_np, tpg_np, tpg, shutdown);
 }
 
 void iscsit_clear_tpg_np_login_threads(
-	struct iscsi_portal_group *tpg)
+	struct iscsi_portal_group *tpg,
+	bool shutdown)
 {
 	struct iscsi_tpg_np *tpg_np;
 
@@ -197,7 +202,7 @@ void iscsit_clear_tpg_np_login_threads(
 			continue;
 		}
 		spin_unlock(&tpg->tpg_np_lock);
-		iscsit_clear_tpg_np_login_thread(tpg_np, tpg);
+		iscsit_clear_tpg_np_login_thread(tpg_np, tpg, shutdown);
 		spin_lock(&tpg->tpg_np_lock);
 	}
 	spin_unlock(&tpg->tpg_np_lock);
@@ -220,6 +225,8 @@ static void iscsit_set_default_tpg_attribs(struct iscsi_portal_group *tpg)
 	a->cache_dynamic_acls = TA_CACHE_DYNAMIC_ACLS;
 	a->demo_mode_write_protect = TA_DEMO_MODE_WRITE_PROTECT;
 	a->prod_mode_write_protect = TA_PROD_MODE_WRITE_PROTECT;
+	a->demo_mode_discovery = TA_DEMO_MODE_DISCOVERY;
+	a->default_erl = TA_DEFAULT_ERL;
 }
 
 int iscsit_tpg_add_portal_group(struct iscsi_tiqn *tiqn, struct iscsi_portal_group *tpg)
@@ -234,7 +241,7 @@ int iscsit_tpg_add_portal_group(struct iscsi_tiqn *tiqn, struct iscsi_portal_gro
 	if (iscsi_create_default_params(&tpg->param_list) < 0)
 		goto err_out;
 
-	ISCSI_TPG_ATTRIB(tpg)->tpg = tpg;
+	tpg->tpg_attrib.tpg = tpg;
 
 	spin_lock(&tpg->tpg_state_lock);
 	tpg->tpg_state	= TPG_STATE_INACTIVE;
@@ -268,6 +275,8 @@ int iscsit_tpg_del_portal_group(
 	tpg->tpg_state = TPG_STATE_INACTIVE;
 	spin_unlock(&tpg->tpg_state_lock);
 
+	iscsit_clear_tpg_np_login_threads(tpg, true);
+
 	if (iscsit_release_sessions_for_tpg(tpg, force) < 0) {
 		pr_err("Unable to delete iSCSI Target Portal Group:"
 			" %hu while active sessions exist, and force=0\n",
@@ -325,7 +334,7 @@ int iscsit_tpg_enable_portal_group(struct iscsi_portal_group *tpg)
 		return -EINVAL;
 	}
 
-	if (ISCSI_TPG_ATTRIB(tpg)->authentication) {
+	if (tpg->tpg_attrib.authentication) {
 		if (!strcmp(param->value, NONE)) {
 			ret = iscsi_update_param_value(param, CHAP);
 			if (ret)
@@ -368,7 +377,7 @@ int iscsit_tpg_disable_portal_group(struct iscsi_portal_group *tpg, int force)
 	tpg->tpg_state = TPG_STATE_INACTIVE;
 	spin_unlock(&tpg->tpg_state_lock);
 
-	iscsit_clear_tpg_np_login_threads(tpg);
+	iscsit_clear_tpg_np_login_threads(tpg, false);
 
 	if (iscsit_release_sessions_for_tpg(tpg, force) < 0) {
 		spin_lock(&tpg->tpg_state_lock);
@@ -490,6 +499,8 @@ struct iscsi_tpg_np *iscsit_tpg_add_network_portal(
 	INIT_LIST_HEAD(&tpg_np->tpg_np_child_list);
 	INIT_LIST_HEAD(&tpg_np->tpg_np_parent_list);
 	spin_lock_init(&tpg_np->tpg_np_parent_lock);
+	init_completion(&tpg_np->tpg_np_comp);
+	kref_init(&tpg_np->tpg_np_kref);
 	tpg_np->tpg_np		= np;
 	tpg_np->tpg		= tpg;
 
@@ -520,7 +531,7 @@ static int iscsit_tpg_release_np(
 	struct iscsi_portal_group *tpg,
 	struct iscsi_np *np)
 {
-	iscsit_clear_tpg_np_login_thread(tpg_np, tpg);
+	iscsit_clear_tpg_np_login_thread(tpg_np, tpg, true);
 
 	pr_debug("CORE[%s] - Removed Network Portal: %s:%hu,%hu on %s\n",
 		tpg->tpg_tiqn->tiqn, np->np_ip, np->np_port, tpg->tpgt,
@@ -813,3 +824,39 @@ int iscsit_ta_prod_mode_write_protect(
 
 	return 0;
 }
+
+int iscsit_ta_demo_mode_discovery(
+	struct iscsi_portal_group *tpg,
+	u32 flag)
+{
+	struct iscsi_tpg_attrib *a = &tpg->tpg_attrib;
+
+	if ((flag != 0) && (flag != 1)) {
+		pr_err("Illegal value %d\n", flag);
+		return -EINVAL;
+	}
+
+	a->demo_mode_discovery = flag;
+	pr_debug("iSCSI_TPG[%hu] - Demo Mode Discovery bit:"
+		" %s\n", tpg->tpgt, (a->demo_mode_discovery) ?
+		"ON" : "OFF");
+
+	return 0;
+}
+
+int iscsit_ta_default_erl(
+	struct iscsi_portal_group *tpg,
+	u32 default_erl)
+{
+	struct iscsi_tpg_attrib *a = &tpg->tpg_attrib;
+
+	if ((default_erl != 0) && (default_erl != 1) && (default_erl != 2)) {
+		pr_err("Illegal value for default_erl: %u\n", default_erl);
+		return -EINVAL;
+	}
+
+	a->default_erl = default_erl;
+	pr_debug("iSCSI_TPG[%hu] - DefaultERL: %u\n", tpg->tpgt, a->default_erl);
+
+	return 0;
+}
diff --git a/drivers/target/iscsi/iscsi_target_tpg.h b/drivers/target/iscsi/iscsi_target_tpg.h
index dda48c1..213c0fc 100644
--- a/drivers/target/iscsi/iscsi_target_tpg.h
+++ b/drivers/target/iscsi/iscsi_target_tpg.h
@@ -5,10 +5,10 @@ extern struct iscsi_portal_group *iscsit_alloc_portal_group(struct iscsi_tiqn *,
 extern int iscsit_load_discovery_tpg(void);
 extern void iscsit_release_discovery_tpg(void);
 extern struct iscsi_portal_group *iscsit_get_tpg_from_np(struct iscsi_tiqn *,
-			struct iscsi_np *);
+			struct iscsi_np *, struct iscsi_tpg_np **);
 extern int iscsit_get_tpg(struct iscsi_portal_group *);
 extern void iscsit_put_tpg(struct iscsi_portal_group *);
-extern void iscsit_clear_tpg_np_login_threads(struct iscsi_portal_group *);
+extern void iscsit_clear_tpg_np_login_threads(struct iscsi_portal_group *, bool);
 extern void iscsit_tpg_dump_params(struct iscsi_portal_group *);
 extern int iscsit_tpg_add_portal_group(struct iscsi_tiqn *, struct iscsi_portal_group *);
 extern int iscsit_tpg_del_portal_group(struct iscsi_tiqn *, struct iscsi_portal_group *,
@@ -37,5 +37,7 @@ extern int iscsit_ta_default_cmdsn_depth(struct iscsi_portal_group *, u32);
 extern int iscsit_ta_cache_dynamic_acls(struct iscsi_portal_group *, u32);
 extern int iscsit_ta_demo_mode_write_protect(struct iscsi_portal_group *, u32);
 extern int iscsit_ta_prod_mode_write_protect(struct iscsi_portal_group *, u32);
+extern int iscsit_ta_demo_mode_discovery(struct iscsi_portal_group *, u32);
+extern int iscsit_ta_default_erl(struct iscsi_portal_group *, u32);
 
 #endif /* ISCSI_TARGET_TPG_H */
diff --git a/drivers/target/iscsi/iscsi_target_tq.c b/drivers/target/iscsi/iscsi_target_tq.c
index 8128952..bb2890e 100644
--- a/drivers/target/iscsi/iscsi_target_tq.c
+++ b/drivers/target/iscsi/iscsi_target_tq.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the iSCSI Login Thread and Thread Queue functions.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -26,36 +24,22 @@
 #include "iscsi_target_tq.h"
 #include "iscsi_target.h"
 
-static LIST_HEAD(active_ts_list);
 static LIST_HEAD(inactive_ts_list);
-static DEFINE_SPINLOCK(active_ts_lock);
 static DEFINE_SPINLOCK(inactive_ts_lock);
 static DEFINE_SPINLOCK(ts_bitmap_lock);
 
-static void iscsi_add_ts_to_active_list(struct iscsi_thread_set *ts)
-{
-	spin_lock(&active_ts_lock);
-	list_add_tail(&ts->ts_list, &active_ts_list);
-	iscsit_global->active_ts++;
-	spin_unlock(&active_ts_lock);
-}
-
 static void iscsi_add_ts_to_inactive_list(struct iscsi_thread_set *ts)
 {
+	if (!list_empty(&ts->ts_list)) {
+		WARN_ON(1);
+		return;
+	}
 	spin_lock(&inactive_ts_lock);
 	list_add_tail(&ts->ts_list, &inactive_ts_list);
 	iscsit_global->inactive_ts++;
 	spin_unlock(&inactive_ts_lock);
 }
 
-static void iscsi_del_ts_from_active_list(struct iscsi_thread_set *ts)
-{
-	spin_lock(&active_ts_lock);
-	list_del(&ts->ts_list);
-	iscsit_global->active_ts--;
-	spin_unlock(&active_ts_lock);
-}
-
 static struct iscsi_thread_set *iscsi_get_ts_from_inactive_list(void)
 {
 	struct iscsi_thread_set *ts;
@@ -68,7 +52,7 @@ static struct iscsi_thread_set *iscsi_get_ts_from_inactive_list(void)
 
 	ts = list_first_entry(&inactive_ts_list, struct iscsi_thread_set, ts_list);
 
-	list_del(&ts->ts_list);
+	list_del_init(&ts->ts_list);
 	iscsit_global->inactive_ts--;
 	spin_unlock(&inactive_ts_lock);
 
@@ -105,12 +89,11 @@ int iscsi_allocate_thread_sets(u32 thread_pair_count)
 		ts->status = ISCSI_THREAD_SET_FREE;
 		INIT_LIST_HEAD(&ts->ts_list);
 		spin_lock_init(&ts->ts_state_lock);
-		init_completion(&ts->rx_post_start_comp);
-		init_completion(&ts->tx_post_start_comp);
 		init_completion(&ts->rx_restart_comp);
 		init_completion(&ts->tx_restart_comp);
 		init_completion(&ts->rx_start_comp);
 		init_completion(&ts->tx_start_comp);
+		sema_init(&ts->ts_activate_sem, 0);
 
 		ts->create_threads = 1;
 		ts->tx_thread = kthread_run(iscsi_target_tx_thread, ts, "%s",
@@ -139,35 +122,44 @@ int iscsi_allocate_thread_sets(u32 thread_pair_count)
 	return allocated_thread_pair_count;
 }
 
-void iscsi_deallocate_thread_sets(void)
+static void iscsi_deallocate_thread_one(struct iscsi_thread_set *ts)
 {
-	u32 released_count = 0;
-	struct iscsi_thread_set *ts = NULL;
-
-	while ((ts = iscsi_get_ts_from_inactive_list())) {
+	spin_lock_bh(&ts->ts_state_lock);
+	ts->status = ISCSI_THREAD_SET_DIE;
 
+	if (ts->rx_thread) {
+		complete(&ts->rx_start_comp);
+		spin_unlock_bh(&ts->ts_state_lock);
+		kthread_stop(ts->rx_thread);
 		spin_lock_bh(&ts->ts_state_lock);
-		ts->status = ISCSI_THREAD_SET_DIE;
+	}
+	if (ts->tx_thread) {
+		complete(&ts->tx_start_comp);
 		spin_unlock_bh(&ts->ts_state_lock);
+		kthread_stop(ts->tx_thread);
+		spin_lock_bh(&ts->ts_state_lock);
+	}
+	spin_unlock_bh(&ts->ts_state_lock);
+	/*
+	 * Release this thread_id in the thread_set_bitmap
+	 */
+	spin_lock(&ts_bitmap_lock);
+	bitmap_release_region(iscsit_global->ts_bitmap,
+			ts->thread_id, get_order(1));
+	spin_unlock(&ts_bitmap_lock);
 
-		if (ts->rx_thread) {
-			send_sig(SIGINT, ts->rx_thread, 1);
-			kthread_stop(ts->rx_thread);
-		}
-		if (ts->tx_thread) {
-			send_sig(SIGINT, ts->tx_thread, 1);
-			kthread_stop(ts->tx_thread);
-		}
-		/*
-		 * Release this thread_id in the thread_set_bitmap
-		 */
-		spin_lock(&ts_bitmap_lock);
-		bitmap_release_region(iscsit_global->ts_bitmap,
-				ts->thread_id, get_order(1));
-		spin_unlock(&ts_bitmap_lock);
+	kfree(ts);
+}
+
+void iscsi_deallocate_thread_sets(void)
+{
+	struct iscsi_thread_set *ts = NULL;
+	u32 released_count = 0;
+
+	while ((ts = iscsi_get_ts_from_inactive_list())) {
 
+		iscsi_deallocate_thread_one(ts);
 		released_count++;
-		kfree(ts);
 	}
 
 	if (released_count)
@@ -187,74 +179,37 @@ static void iscsi_deallocate_extra_thread_sets(void)
 		if (!ts)
 			break;
 
-		spin_lock_bh(&ts->ts_state_lock);
-		ts->status = ISCSI_THREAD_SET_DIE;
-		spin_unlock_bh(&ts->ts_state_lock);
-
-		if (ts->rx_thread) {
-			send_sig(SIGINT, ts->rx_thread, 1);
-			kthread_stop(ts->rx_thread);
-		}
-		if (ts->tx_thread) {
-			send_sig(SIGINT, ts->tx_thread, 1);
-			kthread_stop(ts->tx_thread);
-		}
-		/*
-		 * Release this thread_id in the thread_set_bitmap
-		 */
-		spin_lock(&ts_bitmap_lock);
-		bitmap_release_region(iscsit_global->ts_bitmap,
-				ts->thread_id, get_order(1));
-		spin_unlock(&ts_bitmap_lock);
-
+		iscsi_deallocate_thread_one(ts);
 		released_count++;
-		kfree(ts);
 	}
 
-	if (released_count) {
+	if (released_count)
 		pr_debug("Stopped %d thread set(s) (%d total threads)."
 			"\n", released_count, released_count * 2);
-	}
 }
 
 void iscsi_activate_thread_set(struct iscsi_conn *conn, struct iscsi_thread_set *ts)
 {
-	iscsi_add_ts_to_active_list(ts);
-
 	spin_lock_bh(&ts->ts_state_lock);
 	conn->thread_set = ts;
 	ts->conn = conn;
+	ts->status = ISCSI_THREAD_SET_ACTIVE;
 	spin_unlock_bh(&ts->ts_state_lock);
-	/*
-	 * Start up the RX thread and wait on rx_post_start_comp.  The RX
-	 * Thread will then do the same for the TX Thread in
-	 * iscsi_rx_thread_pre_handler().
-	 */
+
 	complete(&ts->rx_start_comp);
-	wait_for_completion(&ts->rx_post_start_comp);
+	complete(&ts->tx_start_comp);
+
+	down(&ts->ts_activate_sem);
 }
 
 struct iscsi_thread_set *iscsi_get_thread_set(void)
 {
-	int allocate_ts = 0;
-	struct completion comp;
-	struct iscsi_thread_set *ts = NULL;
-	/*
-	 * If no inactive thread set is available on the first call to
-	 * iscsi_get_ts_from_inactive_list(), sleep for a second and
-	 * try again.  If still none are available after two attempts,
-	 * allocate a set ourselves.
-	 */
+	struct iscsi_thread_set *ts;
+
 get_set:
 	ts = iscsi_get_ts_from_inactive_list();
 	if (!ts) {
-		if (allocate_ts == 2)
-			iscsi_allocate_thread_sets(1);
-
-		init_completion(&comp);
-		wait_for_completion_timeout(&comp, 1 * HZ);
-
-		allocate_ts++;
+		iscsi_allocate_thread_sets(1);
 		goto get_set;
 	}
 
@@ -263,6 +218,7 @@ get_set:
 	ts->thread_count = 2;
 	init_completion(&ts->rx_restart_comp);
 	init_completion(&ts->tx_restart_comp);
+	sema_init(&ts->ts_activate_sem, 0);
 
 	return ts;
 }
@@ -400,7 +356,8 @@ static void iscsi_check_to_add_additional_sets(void)
 static int iscsi_signal_thread_pre_handler(struct iscsi_thread_set *ts)
 {
 	spin_lock_bh(&ts->ts_state_lock);
-	if ((ts->status == ISCSI_THREAD_SET_DIE) || signal_pending(current)) {
+	if (ts->status == ISCSI_THREAD_SET_DIE || kthread_should_stop() ||
+	    signal_pending(current)) {
 		spin_unlock_bh(&ts->ts_state_lock);
 		return -1;
 	}
@@ -419,11 +376,11 @@ struct iscsi_conn *iscsi_rx_thread_pre_handler(struct iscsi_thread_set *ts)
 		goto sleep;
 	}
 
-	flush_signals(current);
+	if (ts->status != ISCSI_THREAD_SET_DIE)
+		flush_signals(current);
 
 	if (ts->delay_inactive && (--ts->thread_count == 0)) {
 		spin_unlock_bh(&ts->ts_state_lock);
-		iscsi_del_ts_from_active_list(ts);
 
 		if (!iscsit_global->in_shutdown)
 			iscsi_deallocate_extra_thread_sets();
@@ -446,18 +403,19 @@ sleep:
 	if (iscsi_signal_thread_pre_handler(ts) < 0)
 		return NULL;
 
+	iscsi_check_to_add_additional_sets();
+
+	spin_lock_bh(&ts->ts_state_lock);
 	if (!ts->conn) {
 		pr_err("struct iscsi_thread_set->conn is NULL for"
-			" thread_id: %d, going back to sleep\n", ts->thread_id);
-		goto sleep;
+			" RX thread_id: %s/%d\n", current->comm, current->pid);
+		spin_unlock_bh(&ts->ts_state_lock);
+		return NULL;
 	}
-	iscsi_check_to_add_additional_sets();
-	/*
-	 * The RX Thread starts up the TX Thread and sleeps.
-	 */
 	ts->thread_clear |= ISCSI_CLEAR_RX_THREAD;
-	complete(&ts->tx_start_comp);
-	wait_for_completion(&ts->tx_post_start_comp);
+	spin_unlock_bh(&ts->ts_state_lock);
+
+	up(&ts->ts_activate_sem);
 
 	return ts->conn;
 }
@@ -472,11 +430,11 @@ struct iscsi_conn *iscsi_tx_thread_pre_handler(struct iscsi_thread_set *ts)
 		goto sleep;
 	}
 
-	flush_signals(current);
+	if (ts->status != ISCSI_THREAD_SET_DIE)
+		flush_signals(current);
 
 	if (ts->delay_inactive && (--ts->thread_count == 0)) {
 		spin_unlock_bh(&ts->ts_state_lock);
-		iscsi_del_ts_from_active_list(ts);
 
 		if (!iscsit_global->in_shutdown)
 			iscsi_deallocate_extra_thread_sets();
@@ -498,27 +456,20 @@ sleep:
 	if (iscsi_signal_thread_pre_handler(ts) < 0)
 		return NULL;
 
-	if (!ts->conn) {
-		pr_err("struct iscsi_thread_set->conn is NULL for "
-			" thread_id: %d, going back to sleep\n",
-			ts->thread_id);
-		goto sleep;
-	}
-
 	iscsi_check_to_add_additional_sets();
-	/*
-	 * From the TX thread, up the tx_post_start_comp that the RX Thread is
-	 * sleeping on in iscsi_rx_thread_pre_handler(), then up the
-	 * rx_post_start_comp that iscsi_activate_thread_set() is sleeping on.
-	 */
-	ts->thread_clear |= ISCSI_CLEAR_TX_THREAD;
-	complete(&ts->tx_post_start_comp);
-	complete(&ts->rx_post_start_comp);
 
 	spin_lock_bh(&ts->ts_state_lock);
-	ts->status = ISCSI_THREAD_SET_ACTIVE;
+	if (!ts->conn) {
+		pr_err("struct iscsi_thread_set->conn is NULL for"
+			" TX thread_id: %s/%d\n", current->comm, current->pid);
+		spin_unlock_bh(&ts->ts_state_lock);
+		return NULL;
+	}
+	ts->thread_clear |= ISCSI_CLEAR_TX_THREAD;
 	spin_unlock_bh(&ts->ts_state_lock);
 
+	up(&ts->ts_activate_sem);
+
 	return ts->conn;
 }
 
diff --git a/drivers/target/iscsi/iscsi_target_tq.h b/drivers/target/iscsi/iscsi_target_tq.h
index 547d118..cc1eede 100644
--- a/drivers/target/iscsi/iscsi_target_tq.h
+++ b/drivers/target/iscsi/iscsi_target_tq.h
@@ -64,10 +64,6 @@ struct iscsi_thread_set {
 	struct iscsi_conn	*conn;
 	/* used for controlling ts state accesses */
 	spinlock_t	ts_state_lock;
-	/* Used for rx side post startup */
-	struct completion	rx_post_start_comp;
-	/* Used for tx side post startup */
-	struct completion	tx_post_start_comp;
 	/* used for restarting thread queue */
 	struct completion	rx_restart_comp;
 	/* used for restarting thread queue */
@@ -82,6 +78,7 @@ struct iscsi_thread_set {
 	struct task_struct	*tx_thread;
 	/* struct iscsi_thread_set in list list head*/
 	struct list_head	ts_list;
+	struct semaphore	ts_activate_sem;
 };
 
 #endif   /*** ISCSI_THREAD_QUEUE_H ***/
diff --git a/drivers/target/iscsi/iscsi_target_util.c b/drivers/target/iscsi/iscsi_target_util.c
old mode 100644
new mode 100755
index 77dad24..c34bc84
--- a/drivers/target/iscsi/iscsi_target_util.c
+++ b/drivers/target/iscsi/iscsi_target_util.c
@@ -1,9 +1,7 @@
 /*******************************************************************************
  * This file contains the iSCSI Target specific utility functions.
  *
- * \u00a9 Copyright 2007-2011 RisingTide Systems LLC.
- *
- * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
+ * (c) Copyright 2007-2013 Datera, Inc.
  *
  * Author: Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -19,6 +17,7 @@
  ******************************************************************************/
 
 #include <linux/list.h>
+#include <linux/percpu_ida.h>
 #include <scsi/scsi_tcq.h>
 #include <scsi/iscsi_proto.h>
 #include <target/target_core_base.h>
@@ -149,31 +148,25 @@ void iscsit_free_r2ts_from_list(struct iscsi_cmd *cmd)
 	spin_unlock_bh(&cmd->r2t_lock);
 }
 
-struct iscsi_cmd *iscsit_alloc_cmd(struct iscsi_conn *conn, gfp_t gfp_mask)
-{
-	struct iscsi_cmd *cmd;
-
-	cmd = kmem_cache_zalloc(lio_cmd_cache, gfp_mask);
-	if (!cmd)
-		return NULL;
-
-	cmd->release_cmd = &iscsit_release_cmd;
-	return cmd;
-}
-
 /*
  * May be called from software interrupt (timer) context for allocating
  * iSCSI NopINs.
  */
-struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *conn, gfp_t gfp_mask)
+struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *conn, int state)
 {
 	struct iscsi_cmd *cmd;
+	struct se_session *se_sess = conn->sess->se_sess;
+	int size, tag;
 
-	cmd = conn->conn_transport->iscsit_alloc_cmd(conn, gfp_mask);
-	if (!cmd) {
-		pr_err("Unable to allocate memory for struct iscsi_cmd.\n");
+	tag = percpu_ida_alloc(&se_sess->sess_tag_pool, state);
+	if (tag < 0)
 		return NULL;
-	}
+
+	size = sizeof(struct iscsi_cmd) + conn->conn_transport->priv_size;
+	cmd = (struct iscsi_cmd *)(se_sess->sess_cmd_map + (tag * size));
+	memset(cmd, 0, size);
+
+	cmd->se_cmd.map_tag = tag;
 	cmd->conn = conn;
 	INIT_LIST_HEAD(&cmd->i_conn_node);
 	INIT_LIST_HEAD(&cmd->datain_list);
@@ -252,9 +245,9 @@ static inline int iscsit_check_received_cmdsn(struct iscsi_session *sess, u32 cm
 	 */
 	if (iscsi_sna_gt(cmdsn, sess->max_cmd_sn)) {
 		pr_err("Received CmdSN: 0x%08x is greater than"
-		       " MaxCmdSN: 0x%08x, protocol error.\n", cmdsn,
+		       " MaxCmdSN: 0x%08x, ignoring.\n", cmdsn,
 		       sess->max_cmd_sn);
-		ret = CMDSN_ERROR_CANNOT_RECOVER;
+		ret = CMDSN_MAXCMDSN_OVERRUN;
 
 	} else if (cmdsn == sess->exp_cmd_sn) {
 		sess->exp_cmd_sn++;
@@ -313,14 +306,16 @@ int iscsit_sequence_cmd(struct iscsi_conn *conn, struct iscsi_cmd *cmd,
 		ret = CMDSN_HIGHER_THAN_EXP;
 		break;
 	case CMDSN_LOWER_THAN_EXP:
+	case CMDSN_MAXCMDSN_OVERRUN:
+	default:
 		cmd->i_state = ISTATE_REMOVE;
 		iscsit_add_cmd_to_immediate_queue(cmd, conn, cmd->i_state);
-		ret = cmdsn_ret;
-		break;
-	default:
-		reason = ISCSI_REASON_PROTOCOL_ERROR;
-		reject = true;
-		ret = cmdsn_ret;
+		/*
+		 * Existing callers for iscsit_sequence_cmd() will silently
+		 * ignore commands with CMDSN_LOWER_THAN_EXP, so force this
+		 * return for CMDSN_MAXCMDSN_OVERRUN as well..
+		 */
+		ret = CMDSN_LOWER_THAN_EXP;
 		break;
 	}
 	mutex_unlock(&conn->sess->cmdsn_mutex);
@@ -405,6 +400,8 @@ struct iscsi_cmd *iscsit_find_cmd_from_itt_or_dump(
 
 	spin_lock_bh(&conn->cmd_lock);
 	list_for_each_entry(cmd, &conn->conn_cmd_list, i_conn_node) {
+		if (cmd->cmd_flags & ICF_GOT_LAST_DATAOUT)
+			continue;
 		if (cmd->init_task_tag == init_task_tag) {
 			spin_unlock_bh(&conn->cmd_lock);
 			return cmd;
@@ -689,17 +686,29 @@ void iscsit_free_queue_reqs_for_conn(struct iscsi_conn *conn)
 
 void iscsit_release_cmd(struct iscsi_cmd *cmd)
 {
+	struct iscsi_session *sess;
+	struct se_cmd *se_cmd = &cmd->se_cmd;
+
+	if (cmd->conn)
+		sess = cmd->conn->sess;
+	else
+		sess = cmd->sess;
+
+	BUG_ON(!sess || !sess->se_sess);
+
 	kfree(cmd->buf_ptr);
 	kfree(cmd->pdu_list);
 	kfree(cmd->seq_list);
 	kfree(cmd->tmr_req);
 	kfree(cmd->iov_data);
+	kfree(cmd->text_in_ptr);
 
-	kmem_cache_free(lio_cmd_cache, cmd);
+	percpu_ida_free(&sess->se_sess->sess_tag_pool, se_cmd->map_tag);
 }
+EXPORT_SYMBOL(iscsit_release_cmd);
 
-static void __iscsit_free_cmd(struct iscsi_cmd *cmd, bool scsi_cmd,
-			      bool check_queues)
+void __iscsit_free_cmd(struct iscsi_cmd *cmd, bool scsi_cmd,
+		       bool check_queues)
 {
 	struct iscsi_conn *conn = cmd->conn;
 
@@ -760,7 +769,7 @@ void iscsit_free_cmd(struct iscsi_cmd *cmd, bool shutdown)
 		/* Fall-through */
 	default:
 		__iscsit_free_cmd(cmd, false, shutdown);
-		cmd->release_cmd(cmd);
+		iscsit_release_cmd(cmd);
 		break;
 	}
 }
@@ -922,7 +931,7 @@ static int iscsit_add_nopin(struct iscsi_conn *conn, int want_response)
 	u8 state;
 	struct iscsi_cmd *cmd;
 
-	cmd = iscsit_allocate_cmd(conn, GFP_ATOMIC);
+	cmd = iscsit_allocate_cmd(conn, TASK_RUNNING);
 	if (!cmd)
 		return -1;
 
@@ -978,7 +987,7 @@ static void iscsit_handle_nopin_response_timeout(unsigned long data)
 		tiqn->sess_err_stats.last_sess_failure_type =
 				ISCSI_SESS_ERR_CXN_TIMEOUT;
 		tiqn->sess_err_stats.cxn_timeout_errors++;
-		conn->sess->conn_timeout_errors++;
+		atomic_long_inc(&conn->sess->conn_timeout_errors);
 		spin_unlock_bh(&tiqn->sess_err_stats.lock);
 	}
 	}
@@ -1288,6 +1297,8 @@ int iscsit_tx_login_rsp(struct iscsi_conn *conn, u8 status_class, u8 status_deta
 	login->login_failed = 1;
 	iscsit_collect_login_stats(conn, status_class, status_detail);
 
+	memset(&login->rsp[0], 0, ISCSI_HDR_LEN);
+
 	hdr	= (struct iscsi_login_rsp *)&login->rsp[0];
 	hdr->opcode		= ISCSI_OP_LOGIN_RSP;
 	hdr->status_class	= status_class;
@@ -1347,15 +1358,15 @@ static int iscsit_do_tx_data(
 	struct iscsi_conn *conn,
 	struct iscsi_data_count *count)
 {
-	int data = count->data_length, total_tx = 0, tx_loop = 0, iov_len;
+	int ret, iov_len;
 	struct kvec *iov_p;
 	struct msghdr msg;
 
 	if (!conn || !conn->sock || !conn->conn_ops)
 		return -1;
 
-	if (data <= 0) {
-		pr_err("Data length is: %d\n", data);
+	if (count->data_length <= 0) {
+		pr_err("Data length is: %d\n", count->data_length);
 		return -1;
 	}
 
@@ -1364,20 +1375,16 @@ static int iscsit_do_tx_data(
 	iov_p = count->iov;
 	iov_len = count->iov_count;
 
-	while (total_tx < data) {
-		tx_loop = kernel_sendmsg(conn->sock, &msg, iov_p, iov_len,
-					(data - total_tx));
-		if (tx_loop <= 0) {
-			pr_debug("tx_loop: %d total_tx %d\n",
-				tx_loop, total_tx);
-			return tx_loop;
-		}
-		total_tx += tx_loop;
-		pr_debug("tx_loop: %d, total_tx: %d, data: %d\n",
-					tx_loop, total_tx, data);
+	ret = kernel_sendmsg(conn->sock, &msg, iov_p, iov_len,
+			     count->data_length);
+	if (ret != count->data_length) {
+		pr_err("Unexpected ret: %d send data %d\n",
+		       ret, count->data_length);
+		return -EPIPE;
 	}
+	pr_debug("ret: %d, sent data: %d\n", ret, count->data_length);
 
-	return total_tx;
+	return ret;
 }
 
 int rx_data(
diff --git a/drivers/target/iscsi/iscsi_target_util.h b/drivers/target/iscsi/iscsi_target_util.h
index e4fc34a..a68508c 100644
--- a/drivers/target/iscsi/iscsi_target_util.h
+++ b/drivers/target/iscsi/iscsi_target_util.h
@@ -9,7 +9,7 @@ extern struct iscsi_r2t *iscsit_get_r2t_from_list(struct iscsi_cmd *);
 extern void iscsit_free_r2t(struct iscsi_r2t *, struct iscsi_cmd *);
 extern void iscsit_free_r2ts_from_list(struct iscsi_cmd *);
 extern struct iscsi_cmd *iscsit_alloc_cmd(struct iscsi_conn *, gfp_t);
-extern struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *, gfp_t);
+extern struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *, int);
 extern struct iscsi_seq *iscsit_get_seq_holder_for_datain(struct iscsi_cmd *, u32);
 extern struct iscsi_seq *iscsit_get_seq_holder_for_r2t(struct iscsi_cmd *);
 extern struct iscsi_r2t *iscsit_get_holder_for_r2tsn(struct iscsi_cmd *, u32);
@@ -30,6 +30,7 @@ extern void iscsit_remove_cmd_from_tx_queues(struct iscsi_cmd *, struct iscsi_co
 extern bool iscsit_conn_all_queues_empty(struct iscsi_conn *);
 extern void iscsit_free_queue_reqs_for_conn(struct iscsi_conn *);
 extern void iscsit_release_cmd(struct iscsi_cmd *);
+extern void __iscsit_free_cmd(struct iscsi_cmd *, bool, bool);
 extern void iscsit_free_cmd(struct iscsi_cmd *, bool);
 extern int iscsit_check_session_usage_count(struct iscsi_session *);
 extern void iscsit_dec_session_usage_count(struct iscsi_session *);
diff --git a/drivers/target/loopback/tcm_loop.c b/drivers/target/loopback/tcm_loop.c
index 7c90814..fd974d6 100644
--- a/drivers/target/loopback/tcm_loop.c
+++ b/drivers/target/loopback/tcm_loop.c
@@ -3,7 +3,7 @@
  * This file contains the Linux/SCSI LLD virtual SCSI initiator driver
  * for emulated SAS initiator ports
  *
- * © Copyright 2011 RisingTide Systems LLC.
+ * © Copyright 2011-2013 Datera, Inc.
  *
  * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
  *
@@ -135,21 +135,29 @@ static int tcm_loop_change_queue_depth(
 	return sdev->queue_depth;
 }
 
+static int tcm_loop_change_queue_type(struct scsi_device *sdev, int tag)
+{
+	if (sdev->tagged_supported) {
+		scsi_set_tag_type(sdev, tag);
+
+		if (tag)
+			scsi_activate_tcq(sdev, sdev->queue_depth);
+		else
+			scsi_deactivate_tcq(sdev, sdev->queue_depth);
+	} else
+		tag = 0;
+
+	return tag;
+}
+
 /*
  * Locate the SAM Task Attr from struct scsi_cmnd *
  */
-static int tcm_loop_sam_attr(struct scsi_cmnd *sc)
-{
-	if (sc->device->tagged_supported) {
-		switch (sc->tag) {
-		case HEAD_OF_QUEUE_TAG:
-			return MSG_HEAD_TAG;
-		case ORDERED_QUEUE_TAG:
-			return MSG_ORDERED_TAG;
-		default:
-			break;
-		}
-	}
+static int tcm_loop_sam_attr(struct scsi_cmnd *sc, int tag)
+{
+	if (sc->device->tagged_supported &&
+	    sc->device->ordered_tags && tag >= 0)
+		return MSG_ORDERED_TAG;
 
 	return MSG_SIMPLE_TAG;
 }
@@ -178,8 +186,11 @@ static void tcm_loop_submission_work(struct work_struct *work)
 		set_host_byte(sc, DID_NO_CONNECT);
 		goto out_done;
 	}
-
-	tl_nexus = tl_hba->tl_nexus;
+	if (tl_tpg->tl_transport_status == TCM_TRANSPORT_OFFLINE) {
+		set_host_byte(sc, DID_TRANSPORT_DISRUPTED);
+		goto out_done;
+	}
+	tl_nexus = tl_tpg->tl_nexus;
 	if (!tl_nexus) {
 		scmd_printk(KERN_ERR, sc, "TCM_Loop I_T Nexus"
 				" does not exist\n");
@@ -196,10 +207,11 @@ static void tcm_loop_submission_work(struct work_struct *work)
 	}
 	rc = target_submit_cmd_map_sgls(se_cmd, tl_nexus->se_sess, sc->cmnd,
 			&tl_cmd->tl_sense_buf[0], tl_cmd->sc->device->lun,
-			scsi_bufflen(sc), tcm_loop_sam_attr(sc),
+			scsi_bufflen(sc), tcm_loop_sam_attr(sc, tl_cmd->sc_cmd_tag),
 			sc->sc_data_direction, 0,
 			scsi_sglist(sc), scsi_sg_count(sc),
-			sgl_bidi, sgl_bidi_count);
+			sgl_bidi, sgl_bidi_count,
+			scsi_prot_sglist(sc), scsi_prot_sg_count(sc));
 	if (rc < 0) {
 		set_host_byte(sc, DID_NO_CONNECT);
 		goto out_done;
@@ -233,6 +245,7 @@ static int tcm_loop_queuecommand(struct Scsi_Host *sh, struct scsi_cmnd *sc)
 	}
 
 	tl_cmd->sc = sc;
+	tl_cmd->sc_cmd_tag = sc->request->tag;
 	INIT_WORK(&tl_cmd->work, tcm_loop_submission_work);
 	queue_work(tcm_loop_workqueue, &tl_cmd->work);
 	return 0;
@@ -242,41 +255,31 @@ static int tcm_loop_queuecommand(struct Scsi_Host *sh, struct scsi_cmnd *sc)
  * Called from SCSI EH process context to issue a LUN_RESET TMR
  * to struct scsi_device
  */
-static int tcm_loop_device_reset(struct scsi_cmnd *sc)
+static int tcm_loop_issue_tmr(struct tcm_loop_tpg *tl_tpg,
+			      int lun, int task, enum tcm_tmreq_table tmr)
 {
 	struct se_cmd *se_cmd = NULL;
-	struct se_portal_group *se_tpg;
 	struct se_session *se_sess;
-	struct tcm_loop_cmd *tl_cmd = NULL;
-	struct tcm_loop_hba *tl_hba;
+	struct se_portal_group *se_tpg;
 	struct tcm_loop_nexus *tl_nexus;
+	struct tcm_loop_cmd *tl_cmd = NULL;
 	struct tcm_loop_tmr *tl_tmr = NULL;
-	struct tcm_loop_tpg *tl_tpg;
-	int ret = FAILED, rc;
-	/*
-	 * Locate the tcm_loop_hba_t pointer
-	 */
-	tl_hba = *(struct tcm_loop_hba **)shost_priv(sc->device->host);
+	int ret = TMR_FUNCTION_FAILED, rc;
+
 	/*
 	 * Locate the tl_nexus and se_sess pointers
 	 */
-	tl_nexus = tl_hba->tl_nexus;
+	tl_nexus = tl_tpg->tl_nexus;
 	if (!tl_nexus) {
 		pr_err("Unable to perform device reset without"
 				" active I_T Nexus\n");
-		return FAILED;
+		return ret;
 	}
-	se_sess = tl_nexus->se_sess;
-	/*
-	 * Locate the tl_tpg and se_tpg pointers from TargetID in sc->device->id
-	 */
-	tl_tpg = &tl_hba->tl_hba_tpgs[sc->device->id];
-	se_tpg = &tl_tpg->tl_se_tpg;
 
 	tl_cmd = kmem_cache_zalloc(tcm_loop_cmd_cache, GFP_KERNEL);
 	if (!tl_cmd) {
 		pr_err("Unable to allocate memory for tl_cmd\n");
-		return FAILED;
+		return ret;
 	}
 
 	tl_tmr = kzalloc(sizeof(struct tcm_loop_tmr), GFP_KERNEL);
@@ -287,6 +290,8 @@ static int tcm_loop_device_reset(struct scsi_cmnd *sc)
 	init_waitqueue_head(&tl_tmr->tl_tmr_wait);
 
 	se_cmd = &tl_cmd->tl_se_cmd;
+	se_tpg = &tl_tpg->tl_se_tpg;
+	se_sess = tl_tpg->tl_nexus->se_sess;
 	/*
 	 * Initialize struct se_cmd descriptor from target_core_mod infrastructure
 	 */
@@ -294,17 +299,23 @@ static int tcm_loop_device_reset(struct scsi_cmnd *sc)
 				DMA_NONE, MSG_SIMPLE_TAG,
 				&tl_cmd->tl_sense_buf[0]);
 
-	rc = core_tmr_alloc_req(se_cmd, tl_tmr, TMR_LUN_RESET, GFP_KERNEL);
+	rc = core_tmr_alloc_req(se_cmd, tl_tmr, tmr, GFP_KERNEL);
 	if (rc < 0)
 		goto release;
+
+	if (tmr == TMR_ABORT_TASK)
+		se_cmd->se_tmr_req->ref_task_tag = task;
+
 	/*
-	 * Locate the underlying TCM struct se_lun from sc->device->lun
+	 * Locate the underlying TCM struct se_lun
 	 */
-	if (transport_lookup_tmr_lun(se_cmd, sc->device->lun) < 0)
+	if (transport_lookup_tmr_lun(se_cmd, lun) < 0) {
+		ret = TMR_LUN_DOES_NOT_EXIST;
 		goto release;
+	}
 	/*
-	 * Queue the TMR to TCM Core and sleep waiting for tcm_loop_queue_tm_rsp()
-	 * to wake us up.
+	 * Queue the TMR to TCM Core and sleep waiting for
+	 * tcm_loop_queue_tm_rsp() to wake us up.
 	 */
 	transport_generic_handle_tmr(se_cmd);
 	wait_event(tl_tmr->tl_tmr_wait, atomic_read(&tl_tmr->tmr_complete));
@@ -312,8 +323,7 @@ static int tcm_loop_device_reset(struct scsi_cmnd *sc)
 	 * The TMR LUN_RESET has completed, check the response status and
 	 * then release allocations.
 	 */
-	ret = (se_cmd->se_tmr_req->response == TMR_FUNCTION_COMPLETE) ?
-		SUCCESS : FAILED;
+	ret = se_cmd->se_tmr_req->response;
 release:
 	if (se_cmd)
 		transport_generic_free_cmd(se_cmd, 1);
@@ -323,6 +333,68 @@ release:
 	return ret;
 }
 
+static int tcm_loop_abort_task(struct scsi_cmnd *sc)
+{
+	struct tcm_loop_hba *tl_hba;
+	struct tcm_loop_tpg *tl_tpg;
+	int ret = FAILED;
+
+	/*
+	 * Locate the tcm_loop_hba_t pointer
+	 */
+	tl_hba = *(struct tcm_loop_hba **)shost_priv(sc->device->host);
+	tl_tpg = &tl_hba->tl_hba_tpgs[sc->device->id];
+	ret = tcm_loop_issue_tmr(tl_tpg, sc->device->lun,
+				 sc->request->tag, TMR_ABORT_TASK);
+	return (ret == TMR_FUNCTION_COMPLETE) ? SUCCESS : FAILED;
+}
+
+/*
+ * Called from SCSI EH process context to issue a LUN_RESET TMR
+ * to struct scsi_device
+ */
+static int tcm_loop_device_reset(struct scsi_cmnd *sc)
+{
+	struct tcm_loop_hba *tl_hba;
+	struct tcm_loop_tpg *tl_tpg;
+	int ret = FAILED;
+
+	/*
+	 * Locate the tcm_loop_hba_t pointer
+	 */
+	tl_hba = *(struct tcm_loop_hba **)shost_priv(sc->device->host);
+	tl_tpg = &tl_hba->tl_hba_tpgs[sc->device->id];
+
+	ret = tcm_loop_issue_tmr(tl_tpg, sc->device->lun,
+				 0, TMR_LUN_RESET);
+	return (ret == TMR_FUNCTION_COMPLETE) ? SUCCESS : FAILED;
+}
+
+static int tcm_loop_target_reset(struct scsi_cmnd *sc)
+{
+	struct tcm_loop_hba *tl_hba;
+	struct tcm_loop_tpg *tl_tpg;
+
+	/*
+	 * Locate the tcm_loop_hba_t pointer
+	 */
+	tl_hba = *(struct tcm_loop_hba **)shost_priv(sc->device->host);
+	if (!tl_hba) {
+		pr_err("Unable to perform device reset without"
+				" active I_T Nexus\n");
+		return FAILED;
+	}
+	/*
+	 * Locate the tl_tpg pointer from TargetID in sc->device->id
+	 */
+	tl_tpg = &tl_hba->tl_hba_tpgs[sc->device->id];
+	if (tl_tpg) {
+		tl_tpg->tl_transport_status = TCM_TRANSPORT_ONLINE;
+		return SUCCESS;
+	}
+	return FAILED;
+}
+
 static int tcm_loop_slave_alloc(struct scsi_device *sd)
 {
 	set_bit(QUEUE_FLAG_BIDI, &sd->request_queue->queue_flags);
@@ -331,6 +403,15 @@ static int tcm_loop_slave_alloc(struct scsi_device *sd)
 
 static int tcm_loop_slave_configure(struct scsi_device *sd)
 {
+	if (sd->tagged_supported) {
+		scsi_activate_tcq(sd, sd->queue_depth);
+		scsi_adjust_queue_depth(sd, MSG_SIMPLE_TAG,
+					sd->host->cmd_per_lun);
+	} else {
+		scsi_adjust_queue_depth(sd, 0,
+					sd->host->cmd_per_lun);
+	}
+
 	return 0;
 }
 
@@ -340,7 +421,10 @@ static struct scsi_host_template tcm_loop_driver_template = {
 	.name			= "TCM_Loopback",
 	.queuecommand		= tcm_loop_queuecommand,
 	.change_queue_depth	= tcm_loop_change_queue_depth,
+	.change_queue_type	= tcm_loop_change_queue_type,
+	.eh_abort_handler = tcm_loop_abort_task,
 	.eh_device_reset_handler = tcm_loop_device_reset,
+	.eh_target_reset_handler = tcm_loop_target_reset,
 	.can_queue		= 1024,
 	.this_id		= -1,
 	.sg_tablesize		= 256,
@@ -356,7 +440,7 @@ static int tcm_loop_driver_probe(struct device *dev)
 {
 	struct tcm_loop_hba *tl_hba;
 	struct Scsi_Host *sh;
-	int error;
+	int error, host_prot;
 
 	tl_hba = to_tcm_loop_hba(dev);
 
@@ -380,6 +464,13 @@ static int tcm_loop_driver_probe(struct device *dev)
 	sh->max_channel = 0;
 	sh->max_cmd_len = TL_SCSI_MAX_CMD_LEN;
 
+	host_prot = SHOST_DIF_TYPE1_PROTECTION | SHOST_DIF_TYPE2_PROTECTION |
+		    SHOST_DIF_TYPE3_PROTECTION | SHOST_DIX_TYPE1_PROTECTION |
+		    SHOST_DIX_TYPE2_PROTECTION | SHOST_DIX_TYPE3_PROTECTION;
+
+	scsi_host_set_prot(sh, host_prot);
+	scsi_host_set_guard(sh, SHOST_DIX_GUARD_CRC);
+
 	error = scsi_add_host(sh, &tl_hba->dev);
 	if (error) {
 		pr_err("%s: scsi_add_host failed\n", __func__);
@@ -699,7 +790,10 @@ static void tcm_loop_set_default_node_attributes(struct se_node_acl *se_acl)
 
 static u32 tcm_loop_get_task_tag(struct se_cmd *se_cmd)
 {
-	return 1;
+	struct tcm_loop_cmd *tl_cmd = container_of(se_cmd,
+			struct tcm_loop_cmd, tl_se_cmd);
+
+	return tl_cmd->sc_cmd_tag;
 }
 
 static int tcm_loop_get_cmd_state(struct se_cmd *se_cmd)
@@ -786,7 +880,7 @@ static int tcm_loop_queue_status(struct se_cmd *se_cmd)
 	return 0;
 }
 
-static int tcm_loop_queue_tm_rsp(struct se_cmd *se_cmd)
+static void tcm_loop_queue_tm_rsp(struct se_cmd *se_cmd)
 {
 	struct se_tmr_req *se_tmr = se_cmd->se_tmr_req;
 	struct tcm_loop_tmr *tl_tmr = se_tmr->fabric_tmr_ptr;
@@ -796,7 +890,11 @@ static int tcm_loop_queue_tm_rsp(struct se_cmd *se_cmd)
 	 */
 	atomic_set(&tl_tmr->tmr_complete, 1);
 	wake_up(&tl_tmr->tl_tmr_wait);
-	return 0;
+}
+
+static void tcm_loop_aborted_task(struct se_cmd *se_cmd)
+{
+	return;
 }
 
 static char *tcm_loop_dump_proto_id(struct tcm_loop_hba *tl_hba)
@@ -879,8 +977,8 @@ static int tcm_loop_make_nexus(
 	struct tcm_loop_nexus *tl_nexus;
 	int ret = -ENOMEM;
 
-	if (tl_tpg->tl_hba->tl_nexus) {
-		pr_debug("tl_tpg->tl_hba->tl_nexus already exists\n");
+	if (tl_tpg->tl_nexus) {
+		pr_debug("tl_tpg->tl_nexus already exists\n");
 		return -EEXIST;
 	}
 	se_tpg = &tl_tpg->tl_se_tpg;
@@ -915,7 +1013,7 @@ static int tcm_loop_make_nexus(
 	 */
 	__transport_register_session(se_tpg, tl_nexus->se_sess->se_node_acl,
 			tl_nexus->se_sess, tl_nexus);
-	tl_tpg->tl_hba->tl_nexus = tl_nexus;
+	tl_tpg->tl_nexus = tl_nexus;
 	pr_debug("TCM_Loop_ConfigFS: Established I_T Nexus to emulated"
 		" %s Initiator Port: %s\n", tcm_loop_dump_proto_id(tl_hba),
 		name);
@@ -931,9 +1029,8 @@ static int tcm_loop_drop_nexus(
 {
 	struct se_session *se_sess;
 	struct tcm_loop_nexus *tl_nexus;
-	struct tcm_loop_hba *tl_hba = tpg->tl_hba;
 
-	tl_nexus = tpg->tl_hba->tl_nexus;
+	tl_nexus = tpg->tl_nexus;
 	if (!tl_nexus)
 		return -ENODEV;
 
@@ -949,13 +1046,13 @@ static int tcm_loop_drop_nexus(
 	}
 
 	pr_debug("TCM_Loop_ConfigFS: Removing I_T Nexus to emulated"
-		" %s Initiator Port: %s\n", tcm_loop_dump_proto_id(tl_hba),
+		" %s Initiator Port: %s\n", tcm_loop_dump_proto_id(tpg->tl_hba),
 		tl_nexus->se_sess->se_node_acl->initiatorname);
 	/*
 	 * Release the SCSI I_T Nexus to the emulated SAS Target Port
 	 */
 	transport_deregister_session(tl_nexus->se_sess);
-	tpg->tl_hba->tl_nexus = NULL;
+	tpg->tl_nexus = NULL;
 	kfree(tl_nexus);
 	return 0;
 }
@@ -971,7 +1068,7 @@ static ssize_t tcm_loop_tpg_show_nexus(
 	struct tcm_loop_nexus *tl_nexus;
 	ssize_t ret;
 
-	tl_nexus = tl_tpg->tl_hba->tl_nexus;
+	tl_nexus = tl_tpg->tl_nexus;
 	if (!tl_nexus)
 		return -ENODEV;
 
@@ -1062,14 +1159,62 @@ check_newline:
 
 TF_TPG_BASE_ATTR(tcm_loop, nexus, S_IRUGO | S_IWUSR);
 
+static ssize_t tcm_loop_tpg_show_transport_status(
+	struct se_portal_group *se_tpg,
+	char *page)
+{
+	struct tcm_loop_tpg *tl_tpg = container_of(se_tpg,
+			struct tcm_loop_tpg, tl_se_tpg);
+	const char *status = NULL;
+	ssize_t ret = -EINVAL;
+
+	switch (tl_tpg->tl_transport_status) {
+	case TCM_TRANSPORT_ONLINE:
+		status = "online";
+		break;
+	case TCM_TRANSPORT_OFFLINE:
+		status = "offline";
+		break;
+	default:
+		break;
+	}
+
+	if (status)
+		ret = snprintf(page, PAGE_SIZE, "%s\n", status);
+
+	return ret;
+}
+
+static ssize_t tcm_loop_tpg_store_transport_status(
+	struct se_portal_group *se_tpg,
+	const char *page,
+	size_t count)
+{
+	struct tcm_loop_tpg *tl_tpg = container_of(se_tpg,
+			struct tcm_loop_tpg, tl_se_tpg);
+
+	if (!strncmp(page, "online", 6)) {
+		tl_tpg->tl_transport_status = TCM_TRANSPORT_ONLINE;
+		return count;
+	}
+	if (!strncmp(page, "offline", 7)) {
+		tl_tpg->tl_transport_status = TCM_TRANSPORT_OFFLINE;
+		return count;
+	}
+	return -EINVAL;
+}
+
+TF_TPG_BASE_ATTR(tcm_loop, transport_status, S_IRUGO | S_IWUSR);
+
 static struct configfs_attribute *tcm_loop_tpg_attrs[] = {
 	&tcm_loop_tpg_nexus.attr,
+	&tcm_loop_tpg_transport_status.attr,
 	NULL,
 };
 
 /* Start items for tcm_loop_naa_cit */
 
-struct se_portal_group *tcm_loop_make_naa_tpg(
+static struct se_portal_group *tcm_loop_make_naa_tpg(
 	struct se_wwn *wwn,
 	struct config_group *group,
 	const char *name)
@@ -1114,7 +1259,7 @@ struct se_portal_group *tcm_loop_make_naa_tpg(
 	return &tl_tpg->tl_se_tpg;
 }
 
-void tcm_loop_drop_naa_tpg(
+static void tcm_loop_drop_naa_tpg(
 	struct se_portal_group *se_tpg)
 {
 	struct se_wwn *wwn = se_tpg->se_tpg_wwn;
@@ -1146,7 +1291,7 @@ void tcm_loop_drop_naa_tpg(
 
 /* Start items for tcm_loop_cit */
 
-struct se_wwn *tcm_loop_make_scsi_hba(
+static struct se_wwn *tcm_loop_make_scsi_hba(
 	struct target_fabric_configfs *tf,
 	struct config_group *group,
 	const char *name)
@@ -1216,7 +1361,7 @@ out:
 	return ERR_PTR(ret);
 }
 
-void tcm_loop_drop_scsi_hba(
+static void tcm_loop_drop_scsi_hba(
 	struct se_wwn *wwn)
 {
 	struct tcm_loop_hba *tl_hba = container_of(wwn,
@@ -1316,6 +1461,7 @@ static int tcm_loop_register_configfs(void)
 	fabric->tf_ops.queue_data_in = &tcm_loop_queue_data_in;
 	fabric->tf_ops.queue_status = &tcm_loop_queue_status;
 	fabric->tf_ops.queue_tm_rsp = &tcm_loop_queue_tm_rsp;
+	fabric->tf_ops.aborted_task = &tcm_loop_aborted_task;
 
 	/*
 	 * Setup function pointers for generic logic in target_core_fabric_configfs.c
@@ -1335,11 +1481,11 @@ static int tcm_loop_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = tcm_loop_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = tcm_loop_tpg_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = tcm_loop_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = tcm_loop_tpg_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
 	/*
 	 * Once fabric->tf_ops has been setup, now register the fabric for
 	 * use within TCM
diff --git a/drivers/target/loopback/tcm_loop.h b/drivers/target/loopback/tcm_loop.h
index dd7a84e..6ae49f2 100644
--- a/drivers/target/loopback/tcm_loop.h
+++ b/drivers/target/loopback/tcm_loop.h
@@ -10,6 +10,8 @@
 struct tcm_loop_cmd {
 	/* State of Linux/SCSI CDB+Data descriptor */
 	u32 sc_cmd_state;
+	/* Tagged command queueing */
+	u32 sc_cmd_tag;
 	/* Pointer to the CDB+Data descriptor from Linux/SCSI subsystem */
 	struct scsi_cmnd *sc;
 	/* The TCM I/O descriptor that is accessed via container_of() */
@@ -25,11 +27,6 @@ struct tcm_loop_tmr {
 };
 
 struct tcm_loop_nexus {
-	int it_nexus_active;
-	/*
-	 * Pointer to Linux/SCSI HBA from linux/include/scsi_host.h
-	 */
-	struct scsi_host *sh;
 	/*
 	 * Pointer to TCM session for I_T Nexus
 	 */
@@ -40,11 +37,16 @@ struct tcm_loop_nacl {
 	struct se_node_acl se_node_acl;
 };
 
+#define TCM_TRANSPORT_ONLINE 0
+#define TCM_TRANSPORT_OFFLINE 1
+
 struct tcm_loop_tpg {
 	unsigned short tl_tpgt;
+	unsigned short tl_transport_status;
 	atomic_t tl_tpg_port_count;
 	struct se_portal_group tl_se_tpg;
 	struct tcm_loop_hba *tl_hba;
+	struct tcm_loop_nexus *tl_nexus;
 };
 
 struct tcm_loop_hba {
@@ -53,7 +55,6 @@ struct tcm_loop_hba {
 	struct se_hba_s *se_hba;
 	struct se_lun *tl_hba_lun;
 	struct se_port *tl_hba_lun_sep;
-	struct tcm_loop_nexus *tl_nexus;
 	struct device dev;
 	struct Scsi_Host *sh;
 	struct tcm_loop_tpg tl_hba_tpgs[TL_TPGS_PER_HBA];
diff --git a/drivers/target/sbp/sbp_target.c b/drivers/target/sbp/sbp_target.c
index d3536f5..ad04ea9 100644
--- a/drivers/target/sbp/sbp_target.c
+++ b/drivers/target/sbp/sbp_target.c
@@ -1842,9 +1842,13 @@ static int sbp_queue_status(struct se_cmd *se_cmd)
 	return sbp_send_sense(req);
 }
 
-static int sbp_queue_tm_rsp(struct se_cmd *se_cmd)
+static void sbp_queue_tm_rsp(struct se_cmd *se_cmd)
 {
-	return 0;
+}
+
+static void sbp_aborted_task(struct se_cmd *se_cmd)
+{
+	return;
 }
 
 static int sbp_check_stop_free(struct se_cmd *se_cmd)
@@ -2527,6 +2531,7 @@ static struct target_core_fabric_ops sbp_ops = {
 	.queue_data_in			= sbp_queue_data_in,
 	.queue_status			= sbp_queue_status,
 	.queue_tm_rsp			= sbp_queue_tm_rsp,
+	.aborted_task			= sbp_aborted_task,
 	.check_stop_free		= sbp_check_stop_free,
 
 	.fabric_make_wwn		= sbp_make_tport,
@@ -2557,15 +2562,15 @@ static int sbp_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = sbp_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = sbp_tpg_base_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = sbp_tpg_attrib_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = sbp_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = sbp_tpg_base_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = sbp_tpg_attrib_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 
 	ret = target_fabric_configfs_register(fabric);
 	if (ret < 0) {
diff --git a/drivers/target/target_core_alua.c b/drivers/target/target_core_alua.c
old mode 100644
new mode 100755
index f608fbc..63512cc
--- a/drivers/target/target_core_alua.c
+++ b/drivers/target/target_core_alua.c
@@ -3,7 +3,7 @@
  *
  * This file contains SPC-3 compliant asymmetric logical unit assigntment (ALUA)
  *
- * (c) Copyright 2009-2012 RisingTide Systems LLC.
+ * (c) Copyright 2009-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -41,10 +41,13 @@
 #include "target_core_alua.h"
 #include "target_core_ua.h"
 
-static sense_reason_t core_alua_check_transition(int state, int *primary);
+static sense_reason_t core_alua_check_transition(int state, int valid,
+						 int *primary);
 static int core_alua_set_tg_pt_secondary_state(
 		struct t10_alua_tg_pt_gp_member *tg_pt_gp_mem,
-		struct se_port *port, int explict, int offline);
+		struct se_port *port, int explicit, int offline);
+
+static char *core_alua_dump_state(int state);
 
 static u16 alua_lu_gps_counter;
 static u32 alua_lu_gps_count;
@@ -55,6 +58,86 @@ static LIST_HEAD(lu_gps_list);
 struct t10_alua_lu_gp *default_lu_gp;
 
 /*
+ * REPORT REFERRALS
+ *
+ * See sbc3r35 section 5.23
+ */
+sense_reason_t
+target_emulate_report_referrals(struct se_cmd *cmd)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct t10_alua_lba_map *map;
+	struct t10_alua_lba_map_member *map_mem;
+	unsigned char *buf;
+	u32 rd_len = 0, off;
+
+	if (cmd->data_length < 4) {
+		pr_warn("REPORT REFERRALS allocation length %u too"
+			" small\n", cmd->data_length);
+		return TCM_INVALID_CDB_FIELD;
+	}
+
+	buf = transport_kmap_data_sg(cmd);
+	if (!buf)
+		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+
+	off = 4;
+	spin_lock(&dev->t10_alua.lba_map_lock);
+	if (list_empty(&dev->t10_alua.lba_map_list)) {
+		spin_unlock(&dev->t10_alua.lba_map_lock);
+		transport_kunmap_data_sg(cmd);
+
+		return TCM_UNSUPPORTED_SCSI_OPCODE;
+	}
+
+	list_for_each_entry(map, &dev->t10_alua.lba_map_list,
+			    lba_map_list) {
+		int desc_num = off + 3;
+		int pg_num;
+
+		off += 4;
+		if (cmd->data_length > off)
+			put_unaligned_be64(map->lba_map_first_lba, &buf[off]);
+		off += 8;
+		if (cmd->data_length > off)
+			put_unaligned_be64(map->lba_map_last_lba, &buf[off]);
+		off += 8;
+		rd_len += 20;
+		pg_num = 0;
+		list_for_each_entry(map_mem, &map->lba_map_mem_list,
+				    lba_map_mem_list) {
+			int alua_state = map_mem->lba_map_mem_alua_state;
+			int alua_pg_id = map_mem->lba_map_mem_alua_pg_id;
+
+			if (cmd->data_length > off)
+				buf[off] = alua_state & 0x0f;
+			off += 2;
+			if (cmd->data_length > off)
+				buf[off] = (alua_pg_id >> 8) & 0xff;
+			off++;
+			if (cmd->data_length > off)
+				buf[off] = (alua_pg_id & 0xff);
+			off++;
+			rd_len += 4;
+			pg_num++;
+		}
+		if (cmd->data_length > desc_num)
+			buf[desc_num] = pg_num;
+	}
+	spin_unlock(&dev->t10_alua.lba_map_lock);
+
+	/*
+	 * Set the RETURN DATA LENGTH set in the header of the DataIN Payload
+	 */
+	put_unaligned_be16(rd_len, &buf[2]);
+
+	transport_kunmap_data_sg(cmd);
+
+	target_complete_cmd(cmd, GOOD);
+	return 0;
+}
+
+/*
  * REPORT_TARGET_PORT_GROUPS
  *
  * See spc4r17 section 6.27
@@ -117,12 +200,7 @@ target_emulate_report_target_port_groups(struct se_cmd *cmd)
 		/*
 		 * Set supported ASYMMETRIC ACCESS State bits
 		 */
-		buf[off] = 0x80; /* T_SUP */
-		buf[off] |= 0x40; /* O_SUP */
-		buf[off] |= 0x8; /* U_SUP */
-		buf[off] |= 0x4; /* S_SUP */
-		buf[off] |= 0x2; /* AN_SUP */
-		buf[off++] |= 0x1; /* AO_SUP */
+		buf[off++] |= tg_pt_gp->tg_pt_gp_alua_supported_states;
 		/*
 		 * TARGET PORT GROUP
 		 */
@@ -175,7 +253,7 @@ target_emulate_report_target_port_groups(struct se_cmd *cmd)
 	if (ext_hdr != 0) {
 		buf[4] = 0x10;
 		/*
-		 * Set the implict transition time (in seconds) for the application
+		 * Set the implicit transition time (in seconds) for the application
 		 * client to use as a base for it's transition timeout value.
 		 *
 		 * Use the current tg_pt_gp_mem -> tg_pt_gp membership from the LUN
@@ -188,7 +266,7 @@ target_emulate_report_target_port_groups(struct se_cmd *cmd)
 			spin_lock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
 			tg_pt_gp = tg_pt_gp_mem->tg_pt_gp;
 			if (tg_pt_gp)
-				buf[5] = tg_pt_gp->tg_pt_gp_implict_trans_secs;
+				buf[5] = tg_pt_gp->tg_pt_gp_implicit_trans_secs;
 			spin_unlock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
 		}
 	}
@@ -199,7 +277,7 @@ target_emulate_report_target_port_groups(struct se_cmd *cmd)
 }
 
 /*
- * SET_TARGET_PORT_GROUPS for explict ALUA operation.
+ * SET_TARGET_PORT_GROUPS for explicit ALUA operation.
  *
  * See spc4r17 section 6.35
  */
@@ -215,7 +293,7 @@ target_emulate_set_target_port_groups(struct se_cmd *cmd)
 	unsigned char *ptr;
 	sense_reason_t rc = TCM_NO_SENSE;
 	u32 len = 4; /* Skip over RESERVED area in header */
-	int alua_access_state, primary = 0;
+	int alua_access_state, primary = 0, valid_states;
 	u16 tg_pt_id, rtpi;
 
 	if (!l_port)
@@ -232,7 +310,7 @@ target_emulate_set_target_port_groups(struct se_cmd *cmd)
 		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
 
 	/*
-	 * Determine if explict ALUA via SET_TARGET_PORT_GROUPS is allowed
+	 * Determine if explicit ALUA via SET_TARGET_PORT_GROUPS is allowed
 	 * for the local tg_pt_gp.
 	 */
 	l_tg_pt_gp_mem = l_port->sep_alua_tg_pt_gp_mem;
@@ -251,12 +329,13 @@ target_emulate_set_target_port_groups(struct se_cmd *cmd)
 	}
 	spin_unlock(&l_tg_pt_gp_mem->tg_pt_gp_mem_lock);
 
-	if (!(l_tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICT_ALUA)) {
+	if (!(l_tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICIT_ALUA)) {
 		pr_debug("Unable to process SET_TARGET_PORT_GROUPS"
-				" while TPGS_EXPLICT_ALUA is disabled\n");
+				" while TPGS_EXPLICIT_ALUA is disabled\n");
 		rc = TCM_UNSUPPORTED_SCSI_OPCODE;
 		goto out;
 	}
+	valid_states = l_tg_pt_gp->tg_pt_gp_alua_supported_states;
 
 	ptr = &buf[4]; /* Skip over RESERVED area in header */
 
@@ -268,7 +347,8 @@ target_emulate_set_target_port_groups(struct se_cmd *cmd)
 		 * the state is a primary or secondary target port asymmetric
 		 * access state.
 		 */
-		rc = core_alua_check_transition(alua_access_state, &primary);
+		rc = core_alua_check_transition(alua_access_state,
+						valid_states, &primary);
 		if (rc) {
 			/*
 			 * If the SET TARGET PORT GROUPS attempts to establish
@@ -330,7 +410,7 @@ target_emulate_set_target_port_groups(struct se_cmd *cmd)
 			spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
 		} else {
 			/*
-			 * Extact the RELATIVE TARGET PORT IDENTIFIER to identify
+			 * Extract the RELATIVE TARGET PORT IDENTIFIER to identify
 			 * the Target Port in question for the the incoming
 			 * SET_TARGET_PORT_GROUPS op.
 			 */
@@ -375,11 +455,26 @@ out:
 	return rc;
 }
 
-static inline int core_alua_state_nonoptimized(
+static inline void set_ascq(struct se_cmd *cmd, u8 alua_ascq)
+{
+	/*
+	 * Set SCSI additional sense code (ASC) to 'LUN Not Accessible';
+	 * The ALUA additional sense code qualifier (ASCQ) is determined
+	 * by the ALUA primary or secondary access state..
+	 */
+	pr_debug("[%s]: ALUA TG Port not available, "
+		"SenseKey: NOT_READY, ASC/ASCQ: "
+		"0x04/0x%02x\n",
+		cmd->se_tfo->get_fabric_name(), alua_ascq);
+
+	cmd->scsi_asc = 0x04;
+	cmd->scsi_ascq = alua_ascq;
+}
+
+static inline void core_alua_state_nonoptimized(
 	struct se_cmd *cmd,
 	unsigned char *cdb,
-	int nonop_delay_msecs,
-	u8 *alua_ascq)
+	int nonop_delay_msecs)
 {
 	/*
 	 * Set SCF_ALUA_NON_OPTIMIZED here, this value will be checked
@@ -388,13 +483,85 @@ static inline int core_alua_state_nonoptimized(
 	 */
 	cmd->se_cmd_flags |= SCF_ALUA_NON_OPTIMIZED;
 	cmd->alua_nonop_delay = nonop_delay_msecs;
+}
+
+static inline int core_alua_state_lba_dependent(
+	struct se_cmd *cmd,
+	struct t10_alua_tg_pt_gp *tg_pt_gp)
+{
+	struct se_device *dev = cmd->se_dev;
+	u64 segment_size, segment_mult, sectors, lba;
+
+	/* Only need to check for cdb actually containing LBAs */
+	if (!(cmd->se_cmd_flags & SCF_SCSI_DATA_CDB))
+		return 0;
+
+	spin_lock(&dev->t10_alua.lba_map_lock);
+	segment_size = dev->t10_alua.lba_map_segment_size;
+	segment_mult = dev->t10_alua.lba_map_segment_multiplier;
+	sectors = cmd->data_length / dev->dev_attrib.block_size;
+
+	lba = cmd->t_task_lba;
+	while (lba < cmd->t_task_lba + sectors) {
+		struct t10_alua_lba_map *cur_map = NULL, *map;
+		struct t10_alua_lba_map_member *map_mem;
+
+		list_for_each_entry(map, &dev->t10_alua.lba_map_list,
+				    lba_map_list) {
+			u64 start_lba, last_lba;
+			u64 first_lba = map->lba_map_first_lba;
+
+			if (segment_mult) {
+				u64 tmp = lba;
+				start_lba = do_div(tmp, segment_size * segment_mult);
+
+				last_lba = first_lba + segment_size - 1;
+				if (start_lba >= first_lba &&
+				    start_lba <= last_lba) {
+					lba += segment_size;
+					cur_map = map;
+					break;
+				}
+			} else {
+				last_lba = map->lba_map_last_lba;
+				if (lba >= first_lba && lba <= last_lba) {
+					lba = last_lba + 1;
+					cur_map = map;
+					break;
+				}
+			}
+		}
+		if (!cur_map) {
+			spin_unlock(&dev->t10_alua.lba_map_lock);
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_UNAVAILABLE);
+			return 1;
+		}
+		list_for_each_entry(map_mem, &cur_map->lba_map_mem_list,
+				    lba_map_mem_list) {
+			if (map_mem->lba_map_mem_alua_pg_id !=
+			    tg_pt_gp->tg_pt_gp_id)
+				continue;
+			switch(map_mem->lba_map_mem_alua_state) {
+			case ALUA_ACCESS_STATE_STANDBY:
+				spin_unlock(&dev->t10_alua.lba_map_lock);
+				set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_STANDBY);
+				return 1;
+			case ALUA_ACCESS_STATE_UNAVAILABLE:
+				spin_unlock(&dev->t10_alua.lba_map_lock);
+				set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_UNAVAILABLE);
+				return 1;
+			default:
+				break;
+			}
+		}
+	}
+	spin_unlock(&dev->t10_alua.lba_map_lock);
 	return 0;
 }
 
 static inline int core_alua_state_standby(
 	struct se_cmd *cmd,
-	unsigned char *cdb,
-	u8 *alua_ascq)
+	unsigned char *cdb)
 {
 	/*
 	 * Allowed CDBs for ALUA_ACCESS_STATE_STANDBY as defined by
@@ -409,13 +576,22 @@ static inline int core_alua_state_standby(
 	case REPORT_LUNS:
 	case RECEIVE_DIAGNOSTIC:
 	case SEND_DIAGNOSTIC:
+	case READ_CAPACITY:
 		return 0;
+	case SERVICE_ACTION_IN:
+		switch (cdb[1] & 0x1f) {
+		case SAI_READ_CAPACITY_16:
+			return 0;
+		default:
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_STANDBY);
+			return 1;
+		}
 	case MAINTENANCE_IN:
 		switch (cdb[1] & 0x1f) {
 		case MI_REPORT_TARGET_PGS:
 			return 0;
 		default:
-			*alua_ascq = ASCQ_04H_ALUA_TG_PT_STANDBY;
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_STANDBY);
 			return 1;
 		}
 	case MAINTENANCE_OUT:
@@ -423,7 +599,7 @@ static inline int core_alua_state_standby(
 		case MO_SET_TARGET_PGS:
 			return 0;
 		default:
-			*alua_ascq = ASCQ_04H_ALUA_TG_PT_STANDBY;
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_STANDBY);
 			return 1;
 		}
 	case REQUEST_SENSE:
@@ -433,7 +609,7 @@ static inline int core_alua_state_standby(
 	case WRITE_BUFFER:
 		return 0;
 	default:
-		*alua_ascq = ASCQ_04H_ALUA_TG_PT_STANDBY;
+		set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_STANDBY);
 		return 1;
 	}
 
@@ -442,8 +618,7 @@ static inline int core_alua_state_standby(
 
 static inline int core_alua_state_unavailable(
 	struct se_cmd *cmd,
-	unsigned char *cdb,
-	u8 *alua_ascq)
+	unsigned char *cdb)
 {
 	/*
 	 * Allowed CDBs for ALUA_ACCESS_STATE_UNAVAILABLE as defined by
@@ -458,7 +633,7 @@ static inline int core_alua_state_unavailable(
 		case MI_REPORT_TARGET_PGS:
 			return 0;
 		default:
-			*alua_ascq = ASCQ_04H_ALUA_TG_PT_UNAVAILABLE;
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_UNAVAILABLE);
 			return 1;
 		}
 	case MAINTENANCE_OUT:
@@ -466,7 +641,7 @@ static inline int core_alua_state_unavailable(
 		case MO_SET_TARGET_PGS:
 			return 0;
 		default:
-			*alua_ascq = ASCQ_04H_ALUA_TG_PT_UNAVAILABLE;
+			set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_UNAVAILABLE);
 			return 1;
 		}
 	case REQUEST_SENSE:
@@ -474,7 +649,7 @@ static inline int core_alua_state_unavailable(
 	case WRITE_BUFFER:
 		return 0;
 	default:
-		*alua_ascq = ASCQ_04H_ALUA_TG_PT_UNAVAILABLE;
+		set_ascq(cmd, ASCQ_04H_ALUA_TG_PT_UNAVAILABLE);
 		return 1;
 	}
 
@@ -483,11 +658,10 @@ static inline int core_alua_state_unavailable(
 
 static inline int core_alua_state_transition(
 	struct se_cmd *cmd,
-	unsigned char *cdb,
-	u8 *alua_ascq)
+	unsigned char *cdb)
 {
 	/*
-	 * Allowed CDBs for ALUA_ACCESS_STATE_TRANSITIO as defined by
+	 * Allowed CDBs for ALUA_ACCESS_STATE_TRANSITION as defined by
 	 * spc4r17 section 5.9.2.5
 	 */
 	switch (cdb[0]) {
@@ -499,7 +673,7 @@ static inline int core_alua_state_transition(
 		case MI_REPORT_TARGET_PGS:
 			return 0;
 		default:
-			*alua_ascq = ASCQ_04H_ALUA_STATE_TRANSITION;
+			set_ascq(cmd, ASCQ_04H_ALUA_STATE_TRANSITION);
 			return 1;
 		}
 	case REQUEST_SENSE:
@@ -507,7 +681,7 @@ static inline int core_alua_state_transition(
 	case WRITE_BUFFER:
 		return 0;
 	default:
-		*alua_ascq = ASCQ_04H_ALUA_STATE_TRANSITION;
+		set_ascq(cmd, ASCQ_04H_ALUA_STATE_TRANSITION);
 		return 1;
 	}
 
@@ -515,9 +689,9 @@ static inline int core_alua_state_transition(
 }
 
 /*
- * return 1: Is used to signal LUN not accecsable, and check condition/not ready
+ * return 1: Is used to signal LUN not accessible, and check condition/not ready
  * return 0: Used to signal success
- * reutrn -1: Used to signal failure, and invalid cdb field
+ * return -1: Used to signal failure, and invalid cdb field
  */
 sense_reason_t
 target_alua_state_check(struct se_cmd *cmd)
@@ -529,8 +703,6 @@ target_alua_state_check(struct se_cmd *cmd)
 	struct t10_alua_tg_pt_gp *tg_pt_gp;
 	struct t10_alua_tg_pt_gp_member *tg_pt_gp_mem;
 	int out_alua_state, nonop_delay_msecs;
-	u8 alua_ascq;
-	int ret;
 
 	if (dev->se_hba->hba_flags & HBA_FLAGS_INTERNAL_USE)
 		return 0;
@@ -546,9 +718,8 @@ target_alua_state_check(struct se_cmd *cmd)
 	if (atomic_read(&port->sep_tg_pt_secondary_offline)) {
 		pr_debug("ALUA: Got secondary offline status for local"
 				" target port\n");
-		alua_ascq = ASCQ_04H_ALUA_OFFLINE;
-		ret = 1;
-		goto out;
+		set_ascq(cmd, ASCQ_04H_ALUA_OFFLINE);
+		return TCM_CHECK_CONDITION_NOT_READY;
 	}
 	 /*
 	 * Second, obtain the struct t10_alua_tg_pt_gp_member pointer to the
@@ -557,33 +728,42 @@ target_alua_state_check(struct se_cmd *cmd)
 	 * a ALUA logical unit group.
 	 */
 	tg_pt_gp_mem = port->sep_alua_tg_pt_gp_mem;
+	if (!tg_pt_gp_mem)
+		return 0;
+
 	spin_lock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
 	tg_pt_gp = tg_pt_gp_mem->tg_pt_gp;
 	out_alua_state = atomic_read(&tg_pt_gp->tg_pt_gp_alua_access_state);
 	nonop_delay_msecs = tg_pt_gp->tg_pt_gp_nonop_delay_msecs;
 	spin_unlock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
 	/*
-	 * Process ALUA_ACCESS_STATE_ACTIVE_OPTMIZED in a separate conditional
+	 * Process ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED in a separate conditional
 	 * statement so the compiler knows explicitly to check this case first.
 	 * For the Optimized ALUA access state case, we want to process the
 	 * incoming fabric cmd ASAP..
 	 */
-	if (out_alua_state == ALUA_ACCESS_STATE_ACTIVE_OPTMIZED)
+	if (out_alua_state == ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED)
 		return 0;
 
 	switch (out_alua_state) {
 	case ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED:
-		ret = core_alua_state_nonoptimized(cmd, cdb,
-					nonop_delay_msecs, &alua_ascq);
+		core_alua_state_nonoptimized(cmd, cdb, nonop_delay_msecs);
 		break;
 	case ALUA_ACCESS_STATE_STANDBY:
-		ret = core_alua_state_standby(cmd, cdb, &alua_ascq);
+		if (core_alua_state_standby(cmd, cdb))
+			return TCM_CHECK_CONDITION_NOT_READY;
 		break;
 	case ALUA_ACCESS_STATE_UNAVAILABLE:
-		ret = core_alua_state_unavailable(cmd, cdb, &alua_ascq);
+		if (core_alua_state_unavailable(cmd, cdb))
+			return TCM_CHECK_CONDITION_NOT_READY;
 		break;
 	case ALUA_ACCESS_STATE_TRANSITION:
-		ret = core_alua_state_transition(cmd, cdb, &alua_ascq);
+		if (core_alua_state_transition(cmd, cdb))
+			return TCM_CHECK_CONDITION_NOT_READY;
+		break;
+	case ALUA_ACCESS_STATE_LBA_DEPENDENT:
+		if (core_alua_state_lba_dependent(cmd, tg_pt_gp))
+			return TCM_CHECK_CONDITION_NOT_READY;
 		break;
 	/*
 	 * OFFLINE is a secondary ALUA target port group access state, that is
@@ -596,41 +776,43 @@ target_alua_state_check(struct se_cmd *cmd)
 		return TCM_INVALID_CDB_FIELD;
 	}
 
-out:
-	if (ret > 0) {
-		/*
-		 * Set SCSI additional sense code (ASC) to 'LUN Not Accessible';
-		 * The ALUA additional sense code qualifier (ASCQ) is determined
-		 * by the ALUA primary or secondary access state..
-		 */
-		pr_debug("[%s]: ALUA TG Port not available, "
-			"SenseKey: NOT_READY, ASC/ASCQ: "
-			"0x04/0x%02x\n",
-			cmd->se_tfo->get_fabric_name(), alua_ascq);
-
-		cmd->scsi_asc = 0x04;
-		cmd->scsi_ascq = alua_ascq;
-		return TCM_CHECK_CONDITION_NOT_READY;
-	}
-
 	return 0;
 }
 
 /*
- * Check implict and explict ALUA state change request.
+ * Check implicit and explicit ALUA state change request.
  */
 static sense_reason_t
-core_alua_check_transition(int state, int *primary)
+core_alua_check_transition(int state, int valid, int *primary)
 {
+	/*
+	 * OPTIMIZED, NON-OPTIMIZED, STANDBY and UNAVAILABLE are
+	 * defined as primary target port asymmetric access states.
+	 */
 	switch (state) {
-	case ALUA_ACCESS_STATE_ACTIVE_OPTMIZED:
+	case ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED:
+		if (!(valid & ALUA_AO_SUP))
+			goto not_supported;
+		*primary = 1;
+		break;
 	case ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED:
+		if (!(valid & ALUA_AN_SUP))
+			goto not_supported;
+		*primary = 1;
+		break;
 	case ALUA_ACCESS_STATE_STANDBY:
+		if (!(valid & ALUA_S_SUP))
+			goto not_supported;
+		*primary = 1;
+		break;
 	case ALUA_ACCESS_STATE_UNAVAILABLE:
-		/*
-		 * OPTIMIZED, NON-OPTIMIZED, STANDBY and UNAVAILABLE are
-		 * defined as primary target port asymmetric access states.
-		 */
+		if (!(valid & ALUA_U_SUP))
+			goto not_supported;
+		*primary = 1;
+		break;
+	case ALUA_ACCESS_STATE_LBA_DEPENDENT:
+		if (!(valid & ALUA_LBD_SUP))
+			goto not_supported;
 		*primary = 1;
 		break;
 	case ALUA_ACCESS_STATE_OFFLINE:
@@ -638,29 +820,46 @@ core_alua_check_transition(int state, int *primary)
 		 * OFFLINE state is defined as a secondary target port
 		 * asymmetric access state.
 		 */
+		if (!(valid & ALUA_O_SUP))
+			goto not_supported;
 		*primary = 0;
 		break;
+	case ALUA_ACCESS_STATE_TRANSITION:
+		/*
+		 * Transitioning is set internally, and
+		 * cannot be selected manually.
+		 */
+		goto not_supported;
 	default:
 		pr_err("Unknown ALUA access state: 0x%02x\n", state);
 		return TCM_INVALID_PARAMETER_LIST;
 	}
 
 	return 0;
+
+not_supported:
+	pr_err("ALUA access state %s not supported",
+	       core_alua_dump_state(state));
+	return TCM_INVALID_PARAMETER_LIST;
 }
 
 static char *core_alua_dump_state(int state)
 {
 	switch (state) {
-	case ALUA_ACCESS_STATE_ACTIVE_OPTMIZED:
+	case ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED:
 		return "Active/Optimized";
 	case ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED:
 		return "Active/NonOptimized";
+	case ALUA_ACCESS_STATE_LBA_DEPENDENT:
+		return "LBA Dependent";
 	case ALUA_ACCESS_STATE_STANDBY:
 		return "Standby";
 	case ALUA_ACCESS_STATE_UNAVAILABLE:
 		return "Unavailable";
 	case ALUA_ACCESS_STATE_OFFLINE:
 		return "Offline";
+	case ALUA_ACCESS_STATE_TRANSITION:
+		return "Transitioning";
 	default:
 		return "Unknown";
 	}
@@ -673,10 +872,10 @@ char *core_alua_dump_status(int status)
 	switch (status) {
 	case ALUA_STATUS_NONE:
 		return "None";
-	case ALUA_STATUS_ALTERED_BY_EXPLICT_STPG:
-		return "Altered by Explict STPG";
-	case ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA:
-		return "Altered by Implict ALUA";
+	case ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG:
+		return "Altered by Explicit STPG";
+	case ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA:
+		return "Altered by Implicit ALUA";
 	default:
 		return "Unknown";
 	}
@@ -737,58 +936,49 @@ static int core_alua_write_tpg_metadata(
  * Called with tg_pt_gp->tg_pt_gp_md_mutex held
  */
 static int core_alua_update_tpg_primary_metadata(
-	struct t10_alua_tg_pt_gp *tg_pt_gp,
-	int primary_state,
-	unsigned char *md_buf)
+	struct t10_alua_tg_pt_gp *tg_pt_gp)
 {
+	unsigned char *md_buf;
 	struct t10_wwn *wwn = &tg_pt_gp->tg_pt_gp_dev->t10_wwn;
 	char path[ALUA_METADATA_PATH_LEN];
-	int len;
+	int len, rc;
+
+	md_buf = kzalloc(ALUA_MD_BUF_LEN, GFP_KERNEL);
+	if (!md_buf) {
+		pr_err("Unable to allocate buf for ALUA metadata\n");
+		return -ENOMEM;
+	}
 
 	memset(path, 0, ALUA_METADATA_PATH_LEN);
 
-	len = snprintf(md_buf, tg_pt_gp->tg_pt_gp_md_buf_len,
+	len = snprintf(md_buf, ALUA_MD_BUF_LEN,
 			"tg_pt_gp_id=%hu\n"
 			"alua_access_state=0x%02x\n"
 			"alua_access_status=0x%02x\n",
-			tg_pt_gp->tg_pt_gp_id, primary_state,
+			tg_pt_gp->tg_pt_gp_id,
+			tg_pt_gp->tg_pt_gp_alua_pending_state,
 			tg_pt_gp->tg_pt_gp_alua_access_status);
 
 	snprintf(path, ALUA_METADATA_PATH_LEN,
 		"/var/target/alua/tpgs_%s/%s", &wwn->unit_serial[0],
 		config_item_name(&tg_pt_gp->tg_pt_gp_group.cg_item));
 
-	return core_alua_write_tpg_metadata(path, md_buf, len);
+	rc = core_alua_write_tpg_metadata(path, md_buf, len);
+	kfree(md_buf);
+	return rc;
 }
 
-static int core_alua_do_transition_tg_pt(
-	struct t10_alua_tg_pt_gp *tg_pt_gp,
-	struct se_port *l_port,
-	struct se_node_acl *nacl,
-	unsigned char *md_buf,
-	int new_state,
-	int explict)
+static void core_alua_do_transition_tg_pt_work(struct work_struct *work)
 {
+	struct t10_alua_tg_pt_gp *tg_pt_gp = container_of(work,
+		struct t10_alua_tg_pt_gp, tg_pt_gp_transition_work.work);
+	struct se_device *dev = tg_pt_gp->tg_pt_gp_dev;
 	struct se_dev_entry *se_deve;
 	struct se_lun_acl *lacl;
 	struct se_port *port;
 	struct t10_alua_tg_pt_gp_member *mem;
-	int old_state = 0;
-	/*
-	 * Save the old primary ALUA access state, and set the current state
-	 * to ALUA_ACCESS_STATE_TRANSITION.
-	 */
-	old_state = atomic_read(&tg_pt_gp->tg_pt_gp_alua_access_state);
-	atomic_set(&tg_pt_gp->tg_pt_gp_alua_access_state,
-			ALUA_ACCESS_STATE_TRANSITION);
-	tg_pt_gp->tg_pt_gp_alua_access_status = (explict) ?
-				ALUA_STATUS_ALTERED_BY_EXPLICT_STPG :
-				ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA;
-	/*
-	 * Check for the optional ALUA primary state transition delay
-	 */
-	if (tg_pt_gp->tg_pt_gp_trans_delay_msecs != 0)
-		msleep_interruptible(tg_pt_gp->tg_pt_gp_trans_delay_msecs);
+	bool explicit = (tg_pt_gp->tg_pt_gp_alua_access_status ==
+			 ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG);
 
 	spin_lock(&tg_pt_gp->tg_pt_gp_lock);
 	list_for_each_entry(mem, &tg_pt_gp->tg_pt_gp_mem_list,
@@ -799,7 +989,7 @@ static int core_alua_do_transition_tg_pt(
 		 * change, a device server shall establish a unit attention
 		 * condition for the initiator port associated with every I_T
 		 * nexus with the additional sense code set to ASYMMETRIC
-		 * ACCESS STATE CHAGED.
+		 * ACCESS STATE CHANGED.
 		 *
 		 * After an explicit target port asymmetric access state
 		 * change, a device server shall establish a unit attention
@@ -818,14 +1008,17 @@ static int core_alua_do_transition_tg_pt(
 			lacl = se_deve->se_lun_acl;
 			/*
 			 * se_deve->se_lun_acl pointer may be NULL for a
-			 * entry created without explict Node+MappedLUN ACLs
+			 * entry created without explicit Node+MappedLUN ACLs
 			 */
 			if (!lacl)
 				continue;
 
-			if (explict &&
-			   (nacl != NULL) && (nacl == lacl->se_lun_nacl) &&
-			   (l_port != NULL) && (l_port == port))
+			if ((tg_pt_gp->tg_pt_gp_alua_access_status ==
+			     ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG) &&
+			   (tg_pt_gp->tg_pt_gp_alua_nacl != NULL) &&
+			    (tg_pt_gp->tg_pt_gp_alua_nacl == lacl->se_lun_nacl) &&
+			   (tg_pt_gp->tg_pt_gp_alua_port != NULL) &&
+			    (tg_pt_gp->tg_pt_gp_alua_port == port))
 				continue;
 
 			core_scsi3_ua_allocate(lacl->se_lun_nacl,
@@ -853,20 +1046,102 @@ static int core_alua_do_transition_tg_pt(
 	 */
 	if (tg_pt_gp->tg_pt_gp_write_metadata) {
 		mutex_lock(&tg_pt_gp->tg_pt_gp_md_mutex);
-		core_alua_update_tpg_primary_metadata(tg_pt_gp,
-					new_state, md_buf);
+		core_alua_update_tpg_primary_metadata(tg_pt_gp);
 		mutex_unlock(&tg_pt_gp->tg_pt_gp_md_mutex);
 	}
 	/*
 	 * Set the current primary ALUA access state to the requested new state
 	 */
-	atomic_set(&tg_pt_gp->tg_pt_gp_alua_access_state, new_state);
+	atomic_set(&tg_pt_gp->tg_pt_gp_alua_access_state,
+		   tg_pt_gp->tg_pt_gp_alua_pending_state);
 
 	pr_debug("Successful %s ALUA transition TG PT Group: %s ID: %hu"
-		" from primary access state %s to %s\n", (explict) ? "explict" :
-		"implict", config_item_name(&tg_pt_gp->tg_pt_gp_group.cg_item),
-		tg_pt_gp->tg_pt_gp_id, core_alua_dump_state(old_state),
-		core_alua_dump_state(new_state));
+		" from primary access state %s to %s\n", (explicit) ? "explicit" :
+		"implicit", config_item_name(&tg_pt_gp->tg_pt_gp_group.cg_item),
+		tg_pt_gp->tg_pt_gp_id,
+		core_alua_dump_state(tg_pt_gp->tg_pt_gp_alua_previous_state),
+		core_alua_dump_state(tg_pt_gp->tg_pt_gp_alua_pending_state));
+	spin_lock(&dev->t10_alua.tg_pt_gps_lock);
+	atomic_dec(&tg_pt_gp->tg_pt_gp_ref_cnt);
+	smp_mb__after_atomic_dec();
+	spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
+
+	if (tg_pt_gp->tg_pt_gp_transition_complete)
+		complete(tg_pt_gp->tg_pt_gp_transition_complete);
+}
+
+static int core_alua_do_transition_tg_pt(
+	struct t10_alua_tg_pt_gp *tg_pt_gp,
+	int new_state,
+	int explicit)
+{
+	struct se_device *dev = tg_pt_gp->tg_pt_gp_dev;
+	DECLARE_COMPLETION_ONSTACK(wait);
+
+	/* Nothing to be done here */
+	if (atomic_read(&tg_pt_gp->tg_pt_gp_alua_access_state) == new_state)
+		return 0;
+
+	if (new_state == ALUA_ACCESS_STATE_TRANSITION)
+		return -EAGAIN;
+
+	/*
+	 * Flush any pending transitions
+	 */
+	if (!explicit && tg_pt_gp->tg_pt_gp_implicit_trans_secs &&
+	    atomic_read(&tg_pt_gp->tg_pt_gp_alua_access_state) ==
+	    ALUA_ACCESS_STATE_TRANSITION) {
+		/* Just in case */
+		tg_pt_gp->tg_pt_gp_alua_pending_state = new_state;
+		tg_pt_gp->tg_pt_gp_transition_complete = &wait;
+		flush_delayed_work(&tg_pt_gp->tg_pt_gp_transition_work);
+		wait_for_completion(&wait);
+		tg_pt_gp->tg_pt_gp_transition_complete = NULL;
+		return 0;
+	}
+
+	/*
+	 * Save the old primary ALUA access state, and set the current state
+	 * to ALUA_ACCESS_STATE_TRANSITION.
+	 */
+	tg_pt_gp->tg_pt_gp_alua_previous_state =
+		atomic_read(&tg_pt_gp->tg_pt_gp_alua_access_state);
+	tg_pt_gp->tg_pt_gp_alua_pending_state = new_state;
+
+	atomic_set(&tg_pt_gp->tg_pt_gp_alua_access_state,
+			ALUA_ACCESS_STATE_TRANSITION);
+	tg_pt_gp->tg_pt_gp_alua_access_status = (explicit) ?
+				ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG :
+				ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA;
+
+	/*
+	 * Check for the optional ALUA primary state transition delay
+	 */
+	if (tg_pt_gp->tg_pt_gp_trans_delay_msecs != 0)
+		msleep_interruptible(tg_pt_gp->tg_pt_gp_trans_delay_msecs);
+
+	/*
+	 * Take a reference for workqueue item
+	 */
+	spin_lock(&dev->t10_alua.tg_pt_gps_lock);
+	atomic_inc(&tg_pt_gp->tg_pt_gp_ref_cnt);
+	smp_mb__after_atomic_inc();
+	spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
+
+	if (!explicit && tg_pt_gp->tg_pt_gp_implicit_trans_secs) {
+		unsigned long transition_tmo;
+
+		transition_tmo = tg_pt_gp->tg_pt_gp_implicit_trans_secs * HZ;
+		queue_delayed_work(tg_pt_gp->tg_pt_gp_dev->tmr_wq,
+				   &tg_pt_gp->tg_pt_gp_transition_work,
+				   transition_tmo);
+	} else {
+		tg_pt_gp->tg_pt_gp_transition_complete = &wait;
+		queue_delayed_work(tg_pt_gp->tg_pt_gp_dev->tmr_wq,
+				   &tg_pt_gp->tg_pt_gp_transition_work, 0);
+		wait_for_completion(&wait);
+		tg_pt_gp->tg_pt_gp_transition_complete = NULL;
+	}
 
 	return 0;
 }
@@ -877,26 +1152,18 @@ int core_alua_do_port_transition(
 	struct se_port *l_port,
 	struct se_node_acl *l_nacl,
 	int new_state,
-	int explict)
+	int explicit)
 {
 	struct se_device *dev;
-	struct se_port *port;
-	struct se_node_acl *nacl;
 	struct t10_alua_lu_gp *lu_gp;
 	struct t10_alua_lu_gp_member *lu_gp_mem, *local_lu_gp_mem;
 	struct t10_alua_tg_pt_gp *tg_pt_gp;
-	unsigned char *md_buf;
-	int primary;
+	int primary, valid_states, rc = 0;
 
-	if (core_alua_check_transition(new_state, &primary) != 0)
+	valid_states = l_tg_pt_gp->tg_pt_gp_alua_supported_states;
+	if (core_alua_check_transition(new_state, valid_states, &primary) != 0)
 		return -EINVAL;
 
-	md_buf = kzalloc(l_tg_pt_gp->tg_pt_gp_md_buf_len, GFP_KERNEL);
-	if (!md_buf) {
-		pr_err("Unable to allocate buf for ALUA metadata\n");
-		return -ENOMEM;
-	}
-
 	local_lu_gp_mem = l_dev->dev_alua_lu_gp_mem;
 	spin_lock(&local_lu_gp_mem->lu_gp_mem_lock);
 	lu_gp = local_lu_gp_mem->lu_gp;
@@ -913,12 +1180,13 @@ int core_alua_do_port_transition(
 		 * core_alua_do_transition_tg_pt() will always return
 		 * success.
 		 */
-		core_alua_do_transition_tg_pt(l_tg_pt_gp, l_port, l_nacl,
-					md_buf, new_state, explict);
+		l_tg_pt_gp->tg_pt_gp_alua_port = l_port;
+		l_tg_pt_gp->tg_pt_gp_alua_nacl = l_nacl;
+		rc = core_alua_do_transition_tg_pt(l_tg_pt_gp,
+						   new_state, explicit);
 		atomic_dec(&lu_gp->lu_gp_ref_cnt);
 		smp_mb__after_atomic_dec();
-		kfree(md_buf);
-		return 0;
+		return rc;
 	}
 	/*
 	 * For all other LU groups aside from 'default_lu_gp', walk all of
@@ -943,7 +1211,7 @@ int core_alua_do_port_transition(
 				continue;
 			/*
 			 * If the target behavior port asymmetric access state
-			 * is changed for any target port group accessiable via
+			 * is changed for any target port group accessible via
 			 * a logical unit within a LU group, the target port
 			 * behavior group asymmetric access states for the same
 			 * target port group accessible via other logical units
@@ -953,11 +1221,11 @@ int core_alua_do_port_transition(
 				continue;
 
 			if (l_tg_pt_gp == tg_pt_gp) {
-				port = l_port;
-				nacl = l_nacl;
+				tg_pt_gp->tg_pt_gp_alua_port = l_port;
+				tg_pt_gp->tg_pt_gp_alua_nacl = l_nacl;
 			} else {
-				port = NULL;
-				nacl = NULL;
+				tg_pt_gp->tg_pt_gp_alua_port = NULL;
+				tg_pt_gp->tg_pt_gp_alua_nacl = NULL;
 			}
 			atomic_inc(&tg_pt_gp->tg_pt_gp_ref_cnt);
 			smp_mb__after_atomic_inc();
@@ -966,12 +1234,14 @@ int core_alua_do_port_transition(
 			 * core_alua_do_transition_tg_pt() will always return
 			 * success.
 			 */
-			core_alua_do_transition_tg_pt(tg_pt_gp, port,
-					nacl, md_buf, new_state, explict);
+			rc = core_alua_do_transition_tg_pt(tg_pt_gp,
+					new_state, explicit);
 
 			spin_lock(&dev->t10_alua.tg_pt_gps_lock);
 			atomic_dec(&tg_pt_gp->tg_pt_gp_ref_cnt);
 			smp_mb__after_atomic_dec();
+			if (rc)
+				break;
 		}
 		spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
 
@@ -981,16 +1251,18 @@ int core_alua_do_port_transition(
 	}
 	spin_unlock(&lu_gp->lu_gp_lock);
 
-	pr_debug("Successfully processed LU Group: %s all ALUA TG PT"
-		" Group IDs: %hu %s transition to primary state: %s\n",
-		config_item_name(&lu_gp->lu_gp_group.cg_item),
-		l_tg_pt_gp->tg_pt_gp_id, (explict) ? "explict" : "implict",
-		core_alua_dump_state(new_state));
+	if (!rc) {
+		pr_debug("Successfully processed LU Group: %s all ALUA TG PT"
+			 " Group IDs: %hu %s transition to primary state: %s\n",
+			 config_item_name(&lu_gp->lu_gp_group.cg_item),
+			 l_tg_pt_gp->tg_pt_gp_id,
+			 (explicit) ? "explicit" : "implicit",
+			 core_alua_dump_state(new_state));
+	}
 
 	atomic_dec(&lu_gp->lu_gp_ref_cnt);
 	smp_mb__after_atomic_dec();
-	kfree(md_buf);
-	return 0;
+	return rc;
 }
 
 /*
@@ -998,13 +1270,18 @@ int core_alua_do_port_transition(
  */
 static int core_alua_update_tpg_secondary_metadata(
 	struct t10_alua_tg_pt_gp_member *tg_pt_gp_mem,
-	struct se_port *port,
-	unsigned char *md_buf,
-	u32 md_buf_len)
+	struct se_port *port)
 {
+	unsigned char *md_buf;
 	struct se_portal_group *se_tpg = port->sep_tpg;
 	char path[ALUA_METADATA_PATH_LEN], wwn[ALUA_SECONDARY_METADATA_WWN_LEN];
-	int len;
+	int len, rc;
+
+	md_buf = kzalloc(ALUA_MD_BUF_LEN, GFP_KERNEL);
+	if (!md_buf) {
+		pr_err("Unable to allocate buf for ALUA metadata\n");
+		return -ENOMEM;
+	}
 
 	memset(path, 0, ALUA_METADATA_PATH_LEN);
 	memset(wwn, 0, ALUA_SECONDARY_METADATA_WWN_LEN);
@@ -1016,7 +1293,7 @@ static int core_alua_update_tpg_secondary_metadata(
 		snprintf(wwn+len, ALUA_SECONDARY_METADATA_WWN_LEN-len, "+%hu",
 				se_tpg->se_tpg_tfo->tpg_get_tag(se_tpg));
 
-	len = snprintf(md_buf, md_buf_len, "alua_tg_pt_offline=%d\n"
+	len = snprintf(md_buf, ALUA_MD_BUF_LEN, "alua_tg_pt_offline=%d\n"
 			"alua_tg_pt_status=0x%02x\n",
 			atomic_read(&port->sep_tg_pt_secondary_offline),
 			port->sep_tg_pt_secondary_stat);
@@ -1025,18 +1302,19 @@ static int core_alua_update_tpg_secondary_metadata(
 			se_tpg->se_tpg_tfo->get_fabric_name(), wwn,
 			port->sep_lun->unpacked_lun);
 
-	return core_alua_write_tpg_metadata(path, md_buf, len);
+	rc = core_alua_write_tpg_metadata(path, md_buf, len);
+	kfree(md_buf);
+
+	return rc;
 }
 
 static int core_alua_set_tg_pt_secondary_state(
 	struct t10_alua_tg_pt_gp_member *tg_pt_gp_mem,
 	struct se_port *port,
-	int explict,
+	int explicit,
 	int offline)
 {
 	struct t10_alua_tg_pt_gp *tg_pt_gp;
-	unsigned char *md_buf;
-	u32 md_buf_len;
 	int trans_delay_msecs;
 
 	spin_lock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
@@ -1057,14 +1335,13 @@ static int core_alua_set_tg_pt_secondary_state(
 	else
 		atomic_set(&port->sep_tg_pt_secondary_offline, 0);
 
-	md_buf_len = tg_pt_gp->tg_pt_gp_md_buf_len;
-	port->sep_tg_pt_secondary_stat = (explict) ?
-			ALUA_STATUS_ALTERED_BY_EXPLICT_STPG :
-			ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA;
+	port->sep_tg_pt_secondary_stat = (explicit) ?
+			ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG :
+			ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA;
 
 	pr_debug("Successful %s ALUA transition TG PT Group: %s ID: %hu"
-		" to secondary access state: %s\n", (explict) ? "explict" :
-		"implict", config_item_name(&tg_pt_gp->tg_pt_gp_group.cg_item),
+		" to secondary access state: %s\n", (explicit) ? "explicit" :
+		"implicit", config_item_name(&tg_pt_gp->tg_pt_gp_group.cg_item),
 		tg_pt_gp->tg_pt_gp_id, (offline) ? "OFFLINE" : "ONLINE");
 
 	spin_unlock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
@@ -1079,23 +1356,115 @@ static int core_alua_set_tg_pt_secondary_state(
 	 * secondary state and status
 	 */
 	if (port->sep_tg_pt_secondary_write_md) {
-		md_buf = kzalloc(md_buf_len, GFP_KERNEL);
-		if (!md_buf) {
-			pr_err("Unable to allocate md_buf for"
-				" secondary ALUA access metadata\n");
-			return -ENOMEM;
-		}
 		mutex_lock(&port->sep_tg_pt_md_mutex);
-		core_alua_update_tpg_secondary_metadata(tg_pt_gp_mem, port,
-				md_buf, md_buf_len);
+		core_alua_update_tpg_secondary_metadata(tg_pt_gp_mem, port);
 		mutex_unlock(&port->sep_tg_pt_md_mutex);
+	}
+
+	return 0;
+}
+
+struct t10_alua_lba_map *
+core_alua_allocate_lba_map(struct list_head *list,
+			   u64 first_lba, u64 last_lba)
+{
+	struct t10_alua_lba_map *lba_map;
+
+	lba_map = kmem_cache_zalloc(t10_alua_lba_map_cache, GFP_KERNEL);
+	if (!lba_map) {
+		pr_err("Unable to allocate struct t10_alua_lba_map\n");
+		return ERR_PTR(-ENOMEM);
+	}
+	INIT_LIST_HEAD(&lba_map->lba_map_mem_list);
+	lba_map->lba_map_first_lba = first_lba;
+	lba_map->lba_map_last_lba = last_lba;
+
+	list_add_tail(&lba_map->lba_map_list, list);
+	return lba_map;
+}
+
+int
+core_alua_allocate_lba_map_mem(struct t10_alua_lba_map *lba_map,
+			       int pg_id, int state)
+{
+	struct t10_alua_lba_map_member *lba_map_mem;
+
+	list_for_each_entry(lba_map_mem, &lba_map->lba_map_mem_list,
+			    lba_map_mem_list) {
+		if (lba_map_mem->lba_map_mem_alua_pg_id == pg_id) {
+			pr_err("Duplicate pg_id %d in lba_map\n", pg_id);
+			return -EINVAL;
+		}
+	}
 
-		kfree(md_buf);
+	lba_map_mem = kmem_cache_zalloc(t10_alua_lba_map_mem_cache, GFP_KERNEL);
+	if (!lba_map_mem) {
+		pr_err("Unable to allocate struct t10_alua_lba_map_mem\n");
+		return -ENOMEM;
 	}
+	lba_map_mem->lba_map_mem_alua_state = state;
+	lba_map_mem->lba_map_mem_alua_pg_id = pg_id;
 
+	list_add_tail(&lba_map_mem->lba_map_mem_list,
+		      &lba_map->lba_map_mem_list);
 	return 0;
 }
 
+void
+core_alua_free_lba_map(struct list_head *lba_list)
+{
+	struct t10_alua_lba_map *lba_map, *lba_map_tmp;
+	struct t10_alua_lba_map_member *lba_map_mem, *lba_map_mem_tmp;
+
+	list_for_each_entry_safe(lba_map, lba_map_tmp, lba_list,
+				 lba_map_list) {
+		list_for_each_entry_safe(lba_map_mem, lba_map_mem_tmp,
+					 &lba_map->lba_map_mem_list,
+					 lba_map_mem_list) {
+			list_del(&lba_map_mem->lba_map_mem_list);
+			kmem_cache_free(t10_alua_lba_map_mem_cache,
+					lba_map_mem);
+		}
+		list_del(&lba_map->lba_map_list);
+		kmem_cache_free(t10_alua_lba_map_cache, lba_map);
+	}
+}
+
+void
+core_alua_set_lba_map(struct se_device *dev, struct list_head *lba_map_list,
+		      int segment_size, int segment_mult)
+{
+	struct list_head old_lba_map_list;
+	struct t10_alua_tg_pt_gp *tg_pt_gp;
+	int activate = 0, supported;
+
+	INIT_LIST_HEAD(&old_lba_map_list);
+	spin_lock(&dev->t10_alua.lba_map_lock);
+	dev->t10_alua.lba_map_segment_size = segment_size;
+	dev->t10_alua.lba_map_segment_multiplier = segment_mult;
+	list_splice_init(&dev->t10_alua.lba_map_list, &old_lba_map_list);
+	if (lba_map_list) {
+		list_splice_init(lba_map_list, &dev->t10_alua.lba_map_list);
+		activate = 1;
+	}
+	spin_unlock(&dev->t10_alua.lba_map_lock);
+	spin_lock(&dev->t10_alua.tg_pt_gps_lock);
+	list_for_each_entry(tg_pt_gp, &dev->t10_alua.tg_pt_gps_list,
+			    tg_pt_gp_list) {
+
+		if (!tg_pt_gp->tg_pt_gp_valid_id)
+			continue;
+		supported = tg_pt_gp->tg_pt_gp_alua_supported_states;
+		if (activate)
+			supported |= ALUA_LBD_SUP;
+		else
+			supported &= ~ALUA_LBD_SUP;
+		tg_pt_gp->tg_pt_gp_alua_supported_states = supported;
+	}
+	spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
+	core_alua_free_lba_map(&old_lba_map_list);
+}
+
 struct t10_alua_lu_gp *
 core_alua_allocate_lu_gp(const char *name, int def_group)
 {
@@ -1229,7 +1598,7 @@ void core_alua_free_lu_gp(struct t10_alua_lu_gp *lu_gp)
 		 * struct se_device is released via core_alua_free_lu_gp_mem().
 		 *
 		 * If the passed lu_gp does NOT match the default_lu_gp, assume
-		 * we want to re-assocate a given lu_gp_mem with default_lu_gp.
+		 * we want to re-associate a given lu_gp_mem with default_lu_gp.
 		 */
 		spin_lock(&lu_gp_mem->lu_gp_mem_lock);
 		if (lu_gp != default_lu_gp)
@@ -1348,21 +1717,29 @@ struct t10_alua_tg_pt_gp *core_alua_allocate_tg_pt_gp(struct se_device *dev,
 	mutex_init(&tg_pt_gp->tg_pt_gp_md_mutex);
 	spin_lock_init(&tg_pt_gp->tg_pt_gp_lock);
 	atomic_set(&tg_pt_gp->tg_pt_gp_ref_cnt, 0);
+	INIT_DELAYED_WORK(&tg_pt_gp->tg_pt_gp_transition_work,
+			  core_alua_do_transition_tg_pt_work);
 	tg_pt_gp->tg_pt_gp_dev = dev;
-	tg_pt_gp->tg_pt_gp_md_buf_len = ALUA_MD_BUF_LEN;
 	atomic_set(&tg_pt_gp->tg_pt_gp_alua_access_state,
-		ALUA_ACCESS_STATE_ACTIVE_OPTMIZED);
+		ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED);
 	/*
-	 * Enable both explict and implict ALUA support by default
+	 * Enable both explicit and implicit ALUA support by default
 	 */
 	tg_pt_gp->tg_pt_gp_alua_access_type =
-			TPGS_EXPLICT_ALUA | TPGS_IMPLICT_ALUA;
+			TPGS_EXPLICIT_ALUA | TPGS_IMPLICIT_ALUA;
 	/*
 	 * Set the default Active/NonOptimized Delay in milliseconds
 	 */
 	tg_pt_gp->tg_pt_gp_nonop_delay_msecs = ALUA_DEFAULT_NONOP_DELAY_MSECS;
 	tg_pt_gp->tg_pt_gp_trans_delay_msecs = ALUA_DEFAULT_TRANS_DELAY_MSECS;
-	tg_pt_gp->tg_pt_gp_implict_trans_secs = ALUA_DEFAULT_IMPLICT_TRANS_SECS;
+	tg_pt_gp->tg_pt_gp_implicit_trans_secs = ALUA_DEFAULT_IMPLICIT_TRANS_SECS;
+
+	/*
+	 * Enable all supported states
+	 */
+	tg_pt_gp->tg_pt_gp_alua_supported_states =
+	    ALUA_T_SUP | ALUA_O_SUP |
+	    ALUA_U_SUP | ALUA_S_SUP | ALUA_AN_SUP | ALUA_AO_SUP;
 
 	if (def_group) {
 		spin_lock(&dev->t10_alua.tg_pt_gps_lock);
@@ -1462,7 +1839,7 @@ void core_alua_free_tg_pt_gp(
 	 * been called from target_core_alua_drop_tg_pt_gp().
 	 *
 	 * Here we remove *tg_pt_gp from the global list so that
-	 * no assications *OR* explict ALUA via SET_TARGET_PORT_GROUPS
+	 * no associations *OR* explicit ALUA via SET_TARGET_PORT_GROUPS
 	 * can be made while we are releasing struct t10_alua_tg_pt_gp.
 	 */
 	spin_lock(&dev->t10_alua.tg_pt_gps_lock);
@@ -1470,6 +1847,8 @@ void core_alua_free_tg_pt_gp(
 	dev->t10_alua.alua_tg_pt_gps_counter--;
 	spin_unlock(&dev->t10_alua.tg_pt_gps_lock);
 
+	flush_delayed_work(&tg_pt_gp->tg_pt_gp_transition_work);
+
 	/*
 	 * Allow a struct t10_alua_tg_pt_gp_member * referenced by
 	 * core_alua_get_tg_pt_gp_by_name() in
@@ -1498,7 +1877,7 @@ void core_alua_free_tg_pt_gp(
 		 * core_alua_free_tg_pt_gp_mem().
 		 *
 		 * If the passed tg_pt_gp does NOT match the default_tg_pt_gp,
-		 * assume we want to re-assocate a given tg_pt_gp_mem with
+		 * assume we want to re-associate a given tg_pt_gp_mem with
 		 * default_tg_pt_gp.
 		 */
 		spin_lock(&tg_pt_gp_mem->tg_pt_gp_mem_lock);
@@ -1737,13 +2116,13 @@ ssize_t core_alua_show_access_type(
 	struct t10_alua_tg_pt_gp *tg_pt_gp,
 	char *page)
 {
-	if ((tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICT_ALUA) &&
-	    (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICT_ALUA))
-		return sprintf(page, "Implict and Explict\n");
-	else if (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICT_ALUA)
-		return sprintf(page, "Implict\n");
-	else if (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICT_ALUA)
-		return sprintf(page, "Explict\n");
+	if ((tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICIT_ALUA) &&
+	    (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICIT_ALUA))
+		return sprintf(page, "Implicit and Explicit\n");
+	else if (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICIT_ALUA)
+		return sprintf(page, "Implicit\n");
+	else if (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICIT_ALUA)
+		return sprintf(page, "Explicit\n");
 	else
 		return sprintf(page, "None\n");
 }
@@ -1756,10 +2135,10 @@ ssize_t core_alua_store_access_type(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract alua_access_type\n");
-		return -EINVAL;
+		return ret;
 	}
 	if ((tmp != 0) && (tmp != 1) && (tmp != 2) && (tmp != 3)) {
 		pr_err("Illegal value for alua_access_type:"
@@ -1768,11 +2147,11 @@ ssize_t core_alua_store_access_type(
 	}
 	if (tmp == 3)
 		tg_pt_gp->tg_pt_gp_alua_access_type =
-			TPGS_IMPLICT_ALUA | TPGS_EXPLICT_ALUA;
+			TPGS_IMPLICIT_ALUA | TPGS_EXPLICIT_ALUA;
 	else if (tmp == 2)
-		tg_pt_gp->tg_pt_gp_alua_access_type = TPGS_EXPLICT_ALUA;
+		tg_pt_gp->tg_pt_gp_alua_access_type = TPGS_EXPLICIT_ALUA;
 	else if (tmp == 1)
-		tg_pt_gp->tg_pt_gp_alua_access_type = TPGS_IMPLICT_ALUA;
+		tg_pt_gp->tg_pt_gp_alua_access_type = TPGS_IMPLICIT_ALUA;
 	else
 		tg_pt_gp->tg_pt_gp_alua_access_type = 0;
 
@@ -1794,10 +2173,10 @@ ssize_t core_alua_store_nonop_delay_msecs(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract nonop_delay_msecs\n");
-		return -EINVAL;
+		return ret;
 	}
 	if (tmp > ALUA_MAX_NONOP_DELAY_MSECS) {
 		pr_err("Passed nonop_delay_msecs: %lu, exceeds"
@@ -1825,10 +2204,10 @@ ssize_t core_alua_store_trans_delay_msecs(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract trans_delay_msecs\n");
-		return -EINVAL;
+		return ret;
 	}
 	if (tmp > ALUA_MAX_TRANS_DELAY_MSECS) {
 		pr_err("Passed trans_delay_msecs: %lu, exceeds"
@@ -1841,14 +2220,14 @@ ssize_t core_alua_store_trans_delay_msecs(
 	return count;
 }
 
-ssize_t core_alua_show_implict_trans_secs(
+ssize_t core_alua_show_implicit_trans_secs(
 	struct t10_alua_tg_pt_gp *tg_pt_gp,
 	char *page)
 {
-	return sprintf(page, "%d\n", tg_pt_gp->tg_pt_gp_implict_trans_secs);
+	return sprintf(page, "%d\n", tg_pt_gp->tg_pt_gp_implicit_trans_secs);
 }
 
-ssize_t core_alua_store_implict_trans_secs(
+ssize_t core_alua_store_implicit_trans_secs(
 	struct t10_alua_tg_pt_gp *tg_pt_gp,
 	const char *page,
 	size_t count)
@@ -1856,18 +2235,18 @@ ssize_t core_alua_store_implict_trans_secs(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
-		pr_err("Unable to extract implict_trans_secs\n");
-		return -EINVAL;
+		pr_err("Unable to extract implicit_trans_secs\n");
+		return ret;
 	}
-	if (tmp > ALUA_MAX_IMPLICT_TRANS_SECS) {
-		pr_err("Passed implict_trans_secs: %lu, exceeds"
-			" ALUA_MAX_IMPLICT_TRANS_SECS: %d\n", tmp,
-			ALUA_MAX_IMPLICT_TRANS_SECS);
+	if (tmp > ALUA_MAX_IMPLICIT_TRANS_SECS) {
+		pr_err("Passed implicit_trans_secs: %lu, exceeds"
+			" ALUA_MAX_IMPLICIT_TRANS_SECS: %d\n", tmp,
+			ALUA_MAX_IMPLICIT_TRANS_SECS);
 		return  -EINVAL;
 	}
-	tg_pt_gp->tg_pt_gp_implict_trans_secs = (int)tmp;
+	tg_pt_gp->tg_pt_gp_implicit_trans_secs = (int)tmp;
 
 	return count;
 }
@@ -1887,10 +2266,10 @@ ssize_t core_alua_store_preferred_bit(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract preferred ALUA value\n");
-		return -EINVAL;
+		return ret;
 	}
 	if ((tmp != 0) && (tmp != 1)) {
 		pr_err("Illegal value for preferred ALUA: %lu\n", tmp);
@@ -1922,10 +2301,10 @@ ssize_t core_alua_store_offline_bit(
 	if (!lun->lun_sep)
 		return -ENODEV;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract alua_tg_pt_offline value\n");
-		return -EINVAL;
+		return ret;
 	}
 	if ((tmp != 0) && (tmp != 1)) {
 		pr_err("Illegal value for alua_tg_pt_offline: %lu\n",
@@ -1961,14 +2340,14 @@ ssize_t core_alua_store_secondary_status(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract alua_tg_pt_status\n");
-		return -EINVAL;
+		return ret;
 	}
 	if ((tmp != ALUA_STATUS_NONE) &&
-	    (tmp != ALUA_STATUS_ALTERED_BY_EXPLICT_STPG) &&
-	    (tmp != ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA)) {
+	    (tmp != ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG) &&
+	    (tmp != ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA)) {
 		pr_err("Illegal value for alua_tg_pt_status: %lu\n",
 				tmp);
 		return -EINVAL;
@@ -1994,10 +2373,10 @@ ssize_t core_alua_store_secondary_write_metadata(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract alua_tg_pt_write_md\n");
-		return -EINVAL;
+		return ret;
 	}
 	if ((tmp != 0) && (tmp != 1)) {
 		pr_err("Illegal value for alua_tg_pt_write_md:"
diff --git a/drivers/target/target_core_alua.h b/drivers/target/target_core_alua.h
index e539c3e..0a7d65e 100644
--- a/drivers/target/target_core_alua.h
+++ b/drivers/target/target_core_alua.h
@@ -7,29 +7,41 @@
  * from spc4r17 section 6.4.2 Table 135
  */
 #define TPGS_NO_ALUA				0x00
-#define TPGS_IMPLICT_ALUA			0x10
-#define TPGS_EXPLICT_ALUA			0x20
+#define TPGS_IMPLICIT_ALUA			0x10
+#define TPGS_EXPLICIT_ALUA			0x20
 
 /*
  * ASYMMETRIC ACCESS STATE field
  *
- * from spc4r17 section 6.27 Table 245
+ * from spc4r36j section 6.37 Table 307
  */
-#define ALUA_ACCESS_STATE_ACTIVE_OPTMIZED	0x0
+#define ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED	0x0
 #define ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED	0x1
 #define ALUA_ACCESS_STATE_STANDBY		0x2
 #define ALUA_ACCESS_STATE_UNAVAILABLE		0x3
+#define ALUA_ACCESS_STATE_LBA_DEPENDENT		0x4
 #define ALUA_ACCESS_STATE_OFFLINE		0xe
 #define ALUA_ACCESS_STATE_TRANSITION		0xf
 
 /*
+ * from spc4r36j section 6.37 Table 306
+ */
+#define ALUA_T_SUP		0x80
+#define ALUA_O_SUP		0x40
+#define ALUA_LBD_SUP		0x10
+#define ALUA_U_SUP		0x08
+#define ALUA_S_SUP		0x04
+#define ALUA_AN_SUP		0x02
+#define ALUA_AO_SUP		0x01
+
+/*
  * REPORT_TARGET_PORT_GROUP STATUS CODE
  *
  * from spc4r17 section 6.27 Table 246
  */
 #define ALUA_STATUS_NONE				0x00
-#define ALUA_STATUS_ALTERED_BY_EXPLICT_STPG		0x01
-#define ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA		0x02
+#define ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG		0x01
+#define ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA		0x02
 
 /*
  * From spc4r17, Table D.1: ASC and ASCQ Assignement
@@ -46,17 +58,17 @@
 #define ALUA_DEFAULT_NONOP_DELAY_MSECS			100
 #define ALUA_MAX_NONOP_DELAY_MSECS			10000 /* 10 seconds */
 /*
- * Used for implict and explict ALUA transitional delay, that is disabled
+ * Used for implicit and explicit ALUA transitional delay, that is disabled
  * by default, and is intended to be used for debugging client side ALUA code.
  */
 #define ALUA_DEFAULT_TRANS_DELAY_MSECS			0
 #define ALUA_MAX_TRANS_DELAY_MSECS			30000 /* 30 seconds */
 /*
- * Used for the recommended application client implict transition timeout
+ * Used for the recommended application client implicit transition timeout
  * in seconds, returned by the REPORT_TARGET_PORT_GROUPS w/ extended header.
  */
-#define ALUA_DEFAULT_IMPLICT_TRANS_SECS			0
-#define ALUA_MAX_IMPLICT_TRANS_SECS			255
+#define ALUA_DEFAULT_IMPLICIT_TRANS_SECS			0
+#define ALUA_MAX_IMPLICIT_TRANS_SECS			255
 /*
  * Used by core_alua_update_tpg_primary_metadata() and
  * core_alua_update_tpg_secondary_metadata()
@@ -67,18 +79,30 @@
  */
 #define ALUA_SECONDARY_METADATA_WWN_LEN			256
 
+/* Used by core_alua_update_tpg_(primary,secondary)_metadata */
+#define ALUA_MD_BUF_LEN					1024
+
 extern struct kmem_cache *t10_alua_lu_gp_cache;
 extern struct kmem_cache *t10_alua_lu_gp_mem_cache;
 extern struct kmem_cache *t10_alua_tg_pt_gp_cache;
 extern struct kmem_cache *t10_alua_tg_pt_gp_mem_cache;
+extern struct kmem_cache *t10_alua_lba_map_cache;
+extern struct kmem_cache *t10_alua_lba_map_mem_cache;
 
 extern sense_reason_t target_emulate_report_target_port_groups(struct se_cmd *);
 extern sense_reason_t target_emulate_set_target_port_groups(struct se_cmd *);
+extern sense_reason_t target_emulate_report_referrals(struct se_cmd *);
 extern int core_alua_check_nonop_delay(struct se_cmd *);
 extern int core_alua_do_port_transition(struct t10_alua_tg_pt_gp *,
 				struct se_device *, struct se_port *,
 				struct se_node_acl *, int, int);
 extern char *core_alua_dump_status(int);
+extern struct t10_alua_lba_map *core_alua_allocate_lba_map(
+				struct list_head *, u64, u64);
+extern int core_alua_allocate_lba_map_mem(struct t10_alua_lba_map *, int, int);
+extern void core_alua_free_lba_map(struct list_head *);
+extern void core_alua_set_lba_map(struct se_device *, struct list_head *,
+				int, int);
 extern struct t10_alua_lu_gp *core_alua_allocate_lu_gp(const char *, int);
 extern int core_alua_set_lu_gp_id(struct t10_alua_lu_gp *, u16);
 extern void core_alua_free_lu_gp(struct t10_alua_lu_gp *);
@@ -113,9 +137,9 @@ extern ssize_t core_alua_show_trans_delay_msecs(struct t10_alua_tg_pt_gp *,
 					char *);
 extern ssize_t core_alua_store_trans_delay_msecs(struct t10_alua_tg_pt_gp *,
 					const char *, size_t);
-extern ssize_t core_alua_show_implict_trans_secs(struct t10_alua_tg_pt_gp *,
+extern ssize_t core_alua_show_implicit_trans_secs(struct t10_alua_tg_pt_gp *,
 					char *);
-extern ssize_t core_alua_store_implict_trans_secs(struct t10_alua_tg_pt_gp *,
+extern ssize_t core_alua_store_implicit_trans_secs(struct t10_alua_tg_pt_gp *,
 					const char *, size_t);
 extern ssize_t core_alua_show_preferred_bit(struct t10_alua_tg_pt_gp *,
 					char *);
diff --git a/drivers/target/target_core_configfs.c b/drivers/target/target_core_configfs.c
index 4a8bd36..756def3 100644
--- a/drivers/target/target_core_configfs.c
+++ b/drivers/target/target_core_configfs.c
@@ -3,7 +3,7 @@
  *
  * This file contains ConfigFS logic for the Generic Target Engine project.
  *
- * (c) Copyright 2008-2012 RisingTide Systems LLC.
+ * (c) Copyright 2008-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -48,6 +48,7 @@
 #include "target_core_alua.h"
 #include "target_core_pr.h"
 #include "target_core_rd.h"
+#include "target_core_xcopy.h"
 
 extern struct t10_alua_lu_gp *default_lu_gp;
 
@@ -176,16 +177,16 @@ static struct config_group *target_core_register_fabric(
 	 * struct target_fabric_configfs *tf will contain a usage reference.
 	 */
 	pr_debug("Target_Core_ConfigFS: REGISTER tfc_wwn_cit -> %p\n",
-			&TF_CIT_TMPL(tf)->tfc_wwn_cit);
+			&tf->tf_cit_tmpl.tfc_wwn_cit);
 
 	tf->tf_group.default_groups = tf->tf_default_groups;
 	tf->tf_group.default_groups[0] = &tf->tf_disc_group;
 	tf->tf_group.default_groups[1] = NULL;
 
 	config_group_init_type_name(&tf->tf_group, name,
-			&TF_CIT_TMPL(tf)->tfc_wwn_cit);
+			&tf->tf_cit_tmpl.tfc_wwn_cit);
 	config_group_init_type_name(&tf->tf_disc_group, "discovery_auth",
-			&TF_CIT_TMPL(tf)->tfc_discovery_cit);
+			&tf->tf_cit_tmpl.tfc_discovery_cit);
 
 	pr_debug("Target_Core_ConfigFS: REGISTER -> Allocated Fabric:"
 			" %s\n", tf->tf_group.cg_item.ci_name);
@@ -268,7 +269,7 @@ static struct configfs_subsystem target_core_fabrics = {
 	},
 };
 
-static struct configfs_subsystem *target_core_subsystem[] = {
+struct configfs_subsystem *target_core_subsystem[] = {
 	&target_core_fabrics,
 	NULL,
 };
@@ -456,6 +457,10 @@ static int target_fabric_tf_ops_check(
 		pr_err("Missing tfo->queue_tm_rsp()\n");
 		return -EINVAL;
 	}
+	if (!tfo->aborted_task) {
+		pr_err("Missing tfo->aborted_task()\n");
+		return -EINVAL;
+	}
 	/*
 	 * We at least require tfo->fabric_make_wwn(), tfo->fabric_drop_wwn()
 	 * tfo->fabric_make_tpg() and tfo->fabric_drop_tpg() in
@@ -577,9 +582,9 @@ static ssize_t target_core_dev_store_attr_##_name(			\
 	unsigned long val;						\
 	int ret;							\
 									\
-	ret = strict_strtoul(page, 0, &val);				\
+	ret = kstrtoul(page, 0, &val);				\
 	if (ret < 0) {							\
-		pr_err("strict_strtoul() failed with"		\
+		pr_err("kstrtoul() failed with"		\
 			" ret: %d\n", ret);				\
 		return -EINVAL;						\
 	}								\
@@ -636,6 +641,21 @@ SE_DEV_ATTR(emulate_tpu, S_IRUGO | S_IWUSR);
 DEF_DEV_ATTRIB(emulate_tpws);
 SE_DEV_ATTR(emulate_tpws, S_IRUGO | S_IWUSR);
 
+DEF_DEV_ATTRIB(emulate_caw);
+SE_DEV_ATTR(emulate_caw, S_IRUGO | S_IWUSR);
+
+DEF_DEV_ATTRIB(emulate_3pc);
+SE_DEV_ATTR(emulate_3pc, S_IRUGO | S_IWUSR);
+
+DEF_DEV_ATTRIB(pi_prot_type);
+SE_DEV_ATTR(pi_prot_type, S_IRUGO | S_IWUSR);
+
+DEF_DEV_ATTRIB_RO(hw_pi_prot_type);
+SE_DEV_ATTR_RO(hw_pi_prot_type);
+
+DEF_DEV_ATTRIB(pi_prot_format);
+SE_DEV_ATTR(pi_prot_format, S_IRUGO | S_IWUSR);
+
 DEF_DEV_ATTRIB(enforce_pr_isids);
 SE_DEV_ATTR(enforce_pr_isids, S_IRUGO | S_IWUSR);
 
@@ -693,6 +713,11 @@ static struct configfs_attribute *target_core_dev_attrib_attrs[] = {
 	&target_core_dev_attrib_emulate_tas.attr,
 	&target_core_dev_attrib_emulate_tpu.attr,
 	&target_core_dev_attrib_emulate_tpws.attr,
+	&target_core_dev_attrib_emulate_caw.attr,
+	&target_core_dev_attrib_emulate_3pc.attr,
+	&target_core_dev_attrib_pi_prot_type.attr,
+	&target_core_dev_attrib_hw_pi_prot_type.attr,
+	&target_core_dev_attrib_pi_prot_format.attr,
 	&target_core_dev_attrib_enforce_pr_isids.attr,
 	&target_core_dev_attrib_is_nonrot.attr,
 	&target_core_dev_attrib_emulate_rest_reord.attr,
@@ -983,7 +1008,6 @@ static ssize_t target_core_dev_pr_show_spc3_res(struct se_device *dev,
 	struct se_node_acl *se_nacl;
 	struct t10_pr_registration *pr_reg;
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
 
@@ -992,12 +1016,11 @@ static ssize_t target_core_dev_pr_show_spc3_res(struct se_device *dev,
 		return sprintf(page, "No SPC-3 Reservation holder\n");
 
 	se_nacl = pr_reg->pr_reg_nacl;
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 	return sprintf(page, "SPC-3 Reservation: %s Initiator: %s%s\n",
 		se_nacl->se_tpg->se_tpg_tfo->get_fabric_name(),
-		se_nacl->initiatorname, (prf_isid) ? &i_buf[0] : "");
+		se_nacl->initiatorname, i_buf);
 }
 
 static ssize_t target_core_dev_pr_show_spc2_res(struct se_device *dev,
@@ -1116,7 +1139,7 @@ static ssize_t target_core_dev_pr_show_attr_res_pr_registered_i_pts(
 	unsigned char buf[384];
 	char i_buf[PR_REG_ISID_ID_LEN];
 	ssize_t len = 0;
-	int reg_count = 0, prf_isid;
+	int reg_count = 0;
 
 	len += sprintf(page+len, "SPC-3 PR Registrations:\n");
 
@@ -1127,12 +1150,11 @@ static ssize_t target_core_dev_pr_show_attr_res_pr_registered_i_pts(
 		memset(buf, 0, 384);
 		memset(i_buf, 0, PR_REG_ISID_ID_LEN);
 		tfo = pr_reg->pr_reg_nacl->se_tpg->se_tpg_tfo;
-		prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
+		core_pr_dump_initiator_port(pr_reg, i_buf,
 					PR_REG_ISID_ID_LEN);
 		sprintf(buf, "%s Node: %s%s Key: 0x%016Lx PRgen: 0x%08x\n",
 			tfo->get_fabric_name(),
-			pr_reg->pr_reg_nacl->initiatorname, (prf_isid) ?
-			&i_buf[0] : "", pr_reg->pr_res_key,
+			pr_reg->pr_reg_nacl->initiatorname, i_buf, pr_reg->pr_res_key,
 			pr_reg->pr_res_generation);
 
 		if (len + strlen(buf) >= PAGE_SIZE)
@@ -1313,9 +1335,9 @@ static ssize_t target_core_dev_pr_store_attr_res_aptpl_metadata(
 				ret = -ENOMEM;
 				goto out;
 			}
-			ret = strict_strtoull(arg_p, 0, &tmp_ll);
+			ret = kstrtoull(arg_p, 0, &tmp_ll);
 			if (ret < 0) {
-				pr_err("strict_strtoull() failed for"
+				pr_err("kstrtoull() failed for"
 					" sa_res_key=\n");
 				goto out;
 			}
@@ -1735,6 +1757,176 @@ static struct target_core_configfs_attribute target_core_attr_dev_alua_lu_gp = {
 	.store	= target_core_store_alua_lu_gp,
 };
 
+static ssize_t target_core_show_dev_lba_map(void *p, char *page)
+{
+	struct se_device *dev = p;
+	struct t10_alua_lba_map *map;
+	struct t10_alua_lba_map_member *mem;
+	char *b = page;
+	int bl = 0;
+	char state;
+
+	spin_lock(&dev->t10_alua.lba_map_lock);
+	if (!list_empty(&dev->t10_alua.lba_map_list))
+	    bl += sprintf(b + bl, "%u %u\n",
+			  dev->t10_alua.lba_map_segment_size,
+			  dev->t10_alua.lba_map_segment_multiplier);
+	list_for_each_entry(map, &dev->t10_alua.lba_map_list, lba_map_list) {
+		bl += sprintf(b + bl, "%llu %llu",
+			      map->lba_map_first_lba, map->lba_map_last_lba);
+		list_for_each_entry(mem, &map->lba_map_mem_list,
+				    lba_map_mem_list) {
+			switch (mem->lba_map_mem_alua_state) {
+			case ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED:
+				state = 'O';
+				break;
+			case ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED:
+				state = 'A';
+				break;
+			case ALUA_ACCESS_STATE_STANDBY:
+				state = 'S';
+				break;
+			case ALUA_ACCESS_STATE_UNAVAILABLE:
+				state = 'U';
+				break;
+			default:
+				state = '.';
+				break;
+			}
+			bl += sprintf(b + bl, " %d:%c",
+				      mem->lba_map_mem_alua_pg_id, state);
+		}
+		bl += sprintf(b + bl, "\n");
+	}
+	spin_unlock(&dev->t10_alua.lba_map_lock);
+	return bl;
+}
+
+static ssize_t target_core_store_dev_lba_map(
+	void *p,
+	const char *page,
+	size_t count)
+{
+	struct se_device *dev = p;
+	struct t10_alua_lba_map *lba_map = NULL;
+	struct list_head lba_list;
+	char *map_entries, *ptr;
+	char state;
+	int pg_num = -1, pg;
+	int ret = 0, num = 0, pg_id, alua_state;
+	unsigned long start_lba = -1, end_lba = -1;
+	unsigned long segment_size = -1, segment_mult = -1;
+
+	map_entries = kstrdup(page, GFP_KERNEL);
+	if (!map_entries)
+		return -ENOMEM;
+
+	INIT_LIST_HEAD(&lba_list);
+	while ((ptr = strsep(&map_entries, "\n")) != NULL) {
+		if (!*ptr)
+			continue;
+
+		if (num == 0) {
+			if (sscanf(ptr, "%lu %lu\n",
+				   &segment_size, &segment_mult) != 2) {
+				pr_err("Invalid line %d\n", num);
+				ret = -EINVAL;
+				break;
+			}
+			num++;
+			continue;
+		}
+		if (sscanf(ptr, "%lu %lu", &start_lba, &end_lba) != 2) {
+			pr_err("Invalid line %d\n", num);
+			ret = -EINVAL;
+			break;
+		}
+		ptr = strchr(ptr, ' ');
+		if (!ptr) {
+			pr_err("Invalid line %d, missing end lba\n", num);
+			ret = -EINVAL;
+			break;
+		}
+		ptr++;
+		ptr = strchr(ptr, ' ');
+		if (!ptr) {
+			pr_err("Invalid line %d, missing state definitions\n",
+			       num);
+			ret = -EINVAL;
+			break;
+		}
+		ptr++;
+		lba_map = core_alua_allocate_lba_map(&lba_list,
+						     start_lba, end_lba);
+		if (IS_ERR(lba_map)) {
+			ret = PTR_ERR(lba_map);
+			break;
+		}
+		pg = 0;
+		while (sscanf(ptr, "%d:%c", &pg_id, &state) == 2) {
+			switch (state) {
+			case 'O':
+				alua_state = ALUA_ACCESS_STATE_ACTIVE_OPTIMIZED;
+				break;
+			case 'A':
+				alua_state = ALUA_ACCESS_STATE_ACTIVE_NON_OPTIMIZED;
+				break;
+			case 'S':
+				alua_state = ALUA_ACCESS_STATE_STANDBY;
+				break;
+			case 'U':
+				alua_state = ALUA_ACCESS_STATE_UNAVAILABLE;
+				break;
+			default:
+				pr_err("Invalid ALUA state '%c'\n", state);
+				ret = -EINVAL;
+				goto out;
+			}
+
+			ret = core_alua_allocate_lba_map_mem(lba_map,
+							     pg_id, alua_state);
+			if (ret) {
+				pr_err("Invalid target descriptor %d:%c "
+				       "at line %d\n",
+				       pg_id, state, num);
+				break;
+			}
+			pg++;
+			ptr = strchr(ptr, ' ');
+			if (ptr)
+				ptr++;
+			else
+				break;
+		}
+		if (pg_num == -1)
+		    pg_num = pg;
+		else if (pg != pg_num) {
+			pr_err("Only %d from %d port groups definitions "
+			       "at line %d\n", pg, pg_num, num);
+			ret = -EINVAL;
+			break;
+		}
+		num++;
+	}
+out:
+	if (ret) {
+		core_alua_free_lba_map(&lba_list);
+		count = ret;
+	} else
+		core_alua_set_lba_map(dev, &lba_list,
+				      segment_size, segment_mult);
+	kfree(map_entries);
+	return count;
+}
+
+static struct target_core_configfs_attribute target_core_attr_dev_lba_map = {
+	.attr	= { .ca_owner = THIS_MODULE,
+		    .ca_name = "lba_map",
+		    .ca_mode = S_IRUGO | S_IWUSR },
+	.show	= target_core_show_dev_lba_map,
+	.store	= target_core_store_dev_lba_map,
+};
+
 static struct configfs_attribute *lio_core_dev_attrs[] = {
 	&target_core_attr_dev_info.attr,
 	&target_core_attr_dev_control.attr,
@@ -1742,6 +1934,7 @@ static struct configfs_attribute *lio_core_dev_attrs[] = {
 	&target_core_attr_dev_udev_path.attr,
 	&target_core_attr_dev_enable.attr,
 	&target_core_attr_dev_alua_lu_gp.attr,
+	&target_core_attr_dev_lba_map.attr,
 	NULL,
 };
 
@@ -1839,11 +2032,11 @@ static ssize_t target_core_alua_lu_gp_store_attr_lu_gp_id(
 	unsigned long lu_gp_id;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &lu_gp_id);
+	ret = kstrtoul(page, 0, &lu_gp_id);
 	if (ret < 0) {
-		pr_err("strict_strtoul() returned %d for"
+		pr_err("kstrtoul() returned %d for"
 			" lu_gp_id\n", ret);
-		return -EINVAL;
+		return ret;
 	}
 	if (lu_gp_id > 0x0000ffff) {
 		pr_err("ALUA lu_gp_id: %lu exceeds maximum:"
@@ -2030,22 +2223,34 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_alua_access_state(
 	int new_state, ret;
 
 	if (!tg_pt_gp->tg_pt_gp_valid_id) {
-		pr_err("Unable to do implict ALUA on non valid"
+		pr_err("Unable to do implicit ALUA on non valid"
 			" tg_pt_gp ID: %hu\n", tg_pt_gp->tg_pt_gp_valid_id);
 		return -EINVAL;
 	}
+	if (!(dev->dev_flags & DF_CONFIGURED)) {
+		pr_err("Unable to set alua_access_state while device is"
+		       " not configured\n");
+		return -ENODEV;
+	}
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract new ALUA access state from"
 				" %s\n", page);
-		return -EINVAL;
+		return ret;
 	}
 	new_state = (int)tmp;
 
-	if (!(tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICT_ALUA)) {
-		pr_err("Unable to process implict configfs ALUA"
-			" transition while TPGS_IMPLICT_ALUA is disabled\n");
+	if (!(tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_IMPLICIT_ALUA)) {
+		pr_err("Unable to process implicit configfs ALUA"
+			" transition while TPGS_IMPLICIT_ALUA is disabled\n");
+		return -EINVAL;
+	}
+	if (tg_pt_gp->tg_pt_gp_alua_access_type & TPGS_EXPLICIT_ALUA &&
+	    new_state == ALUA_ACCESS_STATE_LBA_DEPENDENT) {
+		/* LBA DEPENDENT is only allowed with implicit ALUA */
+		pr_err("Unable to process implicit configfs ALUA transition"
+		       " while explicit ALUA management is enabled\n");
 		return -EINVAL;
 	}
 
@@ -2082,17 +2287,17 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_alua_access_status(
 		return -EINVAL;
 	}
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract new ALUA access status"
 				" from %s\n", page);
-		return -EINVAL;
+		return ret;
 	}
 	new_status = (int)tmp;
 
 	if ((new_status != ALUA_STATUS_NONE) &&
-	    (new_status != ALUA_STATUS_ALTERED_BY_EXPLICT_STPG) &&
-	    (new_status != ALUA_STATUS_ALTERED_BY_IMPLICT_ALUA)) {
+	    (new_status != ALUA_STATUS_ALTERED_BY_EXPLICIT_STPG) &&
+	    (new_status != ALUA_STATUS_ALTERED_BY_IMPLICIT_ALUA)) {
 		pr_err("Illegal ALUA access status: 0x%02x\n",
 				new_status);
 		return -EINVAL;
@@ -2125,6 +2330,90 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_alua_access_type(
 SE_DEV_ALUA_TG_PT_ATTR(alua_access_type, S_IRUGO | S_IWUSR);
 
 /*
+ * alua_supported_states
+ */
+
+#define SE_DEV_ALUA_SUPPORT_STATE_SHOW(_name, _var, _bit)		\
+static ssize_t target_core_alua_tg_pt_gp_show_attr_alua_support_##_name( \
+	struct t10_alua_tg_pt_gp *t, char *p)				\
+{									\
+	return sprintf(p, "%d\n", !!(t->_var & _bit));			\
+}
+
+#define SE_DEV_ALUA_SUPPORT_STATE_STORE(_name, _var, _bit)		\
+static ssize_t target_core_alua_tg_pt_gp_store_attr_alua_support_##_name(\
+	struct t10_alua_tg_pt_gp *t, const char *p, size_t c)		\
+{									\
+	unsigned long tmp;						\
+	int ret;							\
+									\
+	if (!t->tg_pt_gp_valid_id) {					\
+		pr_err("Unable to do set ##_name ALUA state on non"	\
+		       " valid tg_pt_gp ID: %hu\n",			\
+		       t->tg_pt_gp_valid_id);				\
+		return -EINVAL;						\
+	}								\
+									\
+	ret = kstrtoul(p, 0, &tmp);					\
+	if (ret < 0) {							\
+		pr_err("Invalid value '%s', must be '0' or '1'\n", p);	\
+		return -EINVAL;						\
+	}								\
+	if (tmp > 1) {							\
+		pr_err("Invalid value '%ld', must be '0' or '1'\n", tmp); \
+		return -EINVAL;						\
+	}								\
+	if (tmp)							\
+		t->_var |= _bit;					\
+	else								\
+		t->_var &= ~_bit;					\
+									\
+	return c;							\
+}
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(transitioning,
+			       tg_pt_gp_alua_supported_states, ALUA_T_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(transitioning,
+				tg_pt_gp_alua_supported_states, ALUA_T_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_transitioning, S_IRUGO | S_IWUSR);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(offline,
+			       tg_pt_gp_alua_supported_states, ALUA_O_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(offline,
+				tg_pt_gp_alua_supported_states, ALUA_O_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_offline, S_IRUGO | S_IWUSR);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(lba_dependent,
+			       tg_pt_gp_alua_supported_states, ALUA_LBD_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(lba_dependent,
+				tg_pt_gp_alua_supported_states, ALUA_LBD_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_lba_dependent, S_IRUGO);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(unavailable,
+			       tg_pt_gp_alua_supported_states, ALUA_U_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(unavailable,
+				tg_pt_gp_alua_supported_states, ALUA_U_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_unavailable, S_IRUGO | S_IWUSR);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(standby,
+			       tg_pt_gp_alua_supported_states, ALUA_S_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(standby,
+				tg_pt_gp_alua_supported_states, ALUA_S_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_standby, S_IRUGO | S_IWUSR);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(active_optimized,
+			       tg_pt_gp_alua_supported_states, ALUA_AO_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(active_optimized,
+				tg_pt_gp_alua_supported_states, ALUA_AO_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_active_optimized, S_IRUGO | S_IWUSR);
+
+SE_DEV_ALUA_SUPPORT_STATE_SHOW(active_nonoptimized,
+			       tg_pt_gp_alua_supported_states, ALUA_AN_SUP);
+SE_DEV_ALUA_SUPPORT_STATE_STORE(active_nonoptimized,
+				tg_pt_gp_alua_supported_states, ALUA_AN_SUP);
+SE_DEV_ALUA_TG_PT_ATTR(alua_support_active_nonoptimized, S_IRUGO | S_IWUSR);
+
+/*
  * alua_write_metadata
  */
 static ssize_t target_core_alua_tg_pt_gp_show_attr_alua_write_metadata(
@@ -2142,10 +2431,10 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_alua_write_metadata(
 	unsigned long tmp;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tmp);
+	ret = kstrtoul(page, 0, &tmp);
 	if (ret < 0) {
 		pr_err("Unable to extract alua_write_metadata\n");
-		return -EINVAL;
+		return ret;
 	}
 
 	if ((tmp != 0) && (tmp != 1)) {
@@ -2204,24 +2493,24 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_trans_delay_msecs(
 SE_DEV_ALUA_TG_PT_ATTR(trans_delay_msecs, S_IRUGO | S_IWUSR);
 
 /*
- * implict_trans_secs
+ * implicit_trans_secs
  */
-static ssize_t target_core_alua_tg_pt_gp_show_attr_implict_trans_secs(
+static ssize_t target_core_alua_tg_pt_gp_show_attr_implicit_trans_secs(
 	struct t10_alua_tg_pt_gp *tg_pt_gp,
 	char *page)
 {
-	return core_alua_show_implict_trans_secs(tg_pt_gp, page);
+	return core_alua_show_implicit_trans_secs(tg_pt_gp, page);
 }
 
-static ssize_t target_core_alua_tg_pt_gp_store_attr_implict_trans_secs(
+static ssize_t target_core_alua_tg_pt_gp_store_attr_implicit_trans_secs(
 	struct t10_alua_tg_pt_gp *tg_pt_gp,
 	const char *page,
 	size_t count)
 {
-	return core_alua_store_implict_trans_secs(tg_pt_gp, page, count);
+	return core_alua_store_implicit_trans_secs(tg_pt_gp, page, count);
 }
 
-SE_DEV_ALUA_TG_PT_ATTR(implict_trans_secs, S_IRUGO | S_IWUSR);
+SE_DEV_ALUA_TG_PT_ATTR(implicit_trans_secs, S_IRUGO | S_IWUSR);
 
 /*
  * preferred
@@ -2266,11 +2555,11 @@ static ssize_t target_core_alua_tg_pt_gp_store_attr_tg_pt_gp_id(
 	unsigned long tg_pt_gp_id;
 	int ret;
 
-	ret = strict_strtoul(page, 0, &tg_pt_gp_id);
+	ret = kstrtoul(page, 0, &tg_pt_gp_id);
 	if (ret < 0) {
-		pr_err("strict_strtoul() returned %d for"
+		pr_err("kstrtoul() returned %d for"
 			" tg_pt_gp_id\n", ret);
-		return -EINVAL;
+		return ret;
 	}
 	if (tg_pt_gp_id > 0x0000ffff) {
 		pr_err("ALUA tg_pt_gp_id: %lu exceeds maximum:"
@@ -2344,10 +2633,17 @@ static struct configfs_attribute *target_core_alua_tg_pt_gp_attrs[] = {
 	&target_core_alua_tg_pt_gp_alua_access_state.attr,
 	&target_core_alua_tg_pt_gp_alua_access_status.attr,
 	&target_core_alua_tg_pt_gp_alua_access_type.attr,
+	&target_core_alua_tg_pt_gp_alua_support_transitioning.attr,
+	&target_core_alua_tg_pt_gp_alua_support_offline.attr,
+	&target_core_alua_tg_pt_gp_alua_support_lba_dependent.attr,
+	&target_core_alua_tg_pt_gp_alua_support_unavailable.attr,
+	&target_core_alua_tg_pt_gp_alua_support_standby.attr,
+	&target_core_alua_tg_pt_gp_alua_support_active_nonoptimized.attr,
+	&target_core_alua_tg_pt_gp_alua_support_active_optimized.attr,
 	&target_core_alua_tg_pt_gp_alua_write_metadata.attr,
 	&target_core_alua_tg_pt_gp_nonop_delay_msecs.attr,
 	&target_core_alua_tg_pt_gp_trans_delay_msecs.attr,
-	&target_core_alua_tg_pt_gp_implict_trans_secs.attr,
+	&target_core_alua_tg_pt_gp_implicit_trans_secs.attr,
 	&target_core_alua_tg_pt_gp_preferred.attr,
 	&target_core_alua_tg_pt_gp_tg_pt_gp_id.attr,
 	&target_core_alua_tg_pt_gp_members.attr,
@@ -2679,10 +2975,10 @@ static ssize_t target_core_hba_store_attr_hba_mode(struct se_hba *hba,
 	if (transport->pmode_enable_hba == NULL)
 		return -EINVAL;
 
-	ret = strict_strtoul(page, 0, &mode_flag);
+	ret = kstrtoul(page, 0, &mode_flag);
 	if (ret < 0) {
 		pr_err("Unable to extract hba mode flag: %d\n", ret);
-		return -EINVAL;
+		return ret;
 	}
 
 	if (hba->dev_count) {
@@ -2770,11 +3066,11 @@ static struct config_group *target_core_call_addhbatotarget(
 		str++; /* Skip to start of plugin dependent ID */
 	}
 
-	ret = strict_strtoul(str, 0, &plugin_dep_id);
+	ret = kstrtoul(str, 0, &plugin_dep_id);
 	if (ret < 0) {
-		pr_err("strict_strtoul() returned %d for"
+		pr_err("kstrtoul() returned %d for"
 				" plugin_dep_id\n", ret);
-		return ERR_PTR(-EINVAL);
+		return ERR_PTR(ret);
 	}
 	/*
 	 * Load up TCM subsystem plugins if they have not already been loaded.
@@ -2840,7 +3136,7 @@ static int __init target_core_init_configfs(void)
 	 * and ALUA Logical Unit Group and Target Port Group infrastructure.
 	 */
 	target_cg = &subsys->su_group;
-	target_cg->default_groups = kmalloc(sizeof(struct config_group) * 2,
+	target_cg->default_groups = kmalloc(sizeof(struct config_group *) * 2,
 				GFP_KERNEL);
 	if (!target_cg->default_groups) {
 		pr_err("Unable to allocate target_cg->default_groups\n");
@@ -2930,6 +3226,10 @@ static int __init target_core_init_configfs(void)
 	if (ret < 0)
 		goto out;
 
+	ret = target_xcopy_setup_pt();
+	if (ret < 0)
+		goto out;
+
 	return 0;
 
 out:
@@ -3002,6 +3302,7 @@ static void __exit target_core_exit_configfs(void)
 
 	core_dev_release_virtual_lun0();
 	rd_module_exit();
+	target_xcopy_release_pt();
 	release_se_kmem_caches();
 }
 
diff --git a/drivers/target/target_core_device.c b/drivers/target/target_core_device.c
old mode 100644
new mode 100755
index 4630481..7c3ba7d
--- a/drivers/target/target_core_device.c
+++ b/drivers/target/target_core_device.c
@@ -4,7 +4,7 @@
  * This file contains the TCM Virtual Device and Disk Transport
  * agnostic related functions.
  *
- * (c) Copyright 2003-2012 RisingTide Systems LLC.
+ * (c) Copyright 2003-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -47,6 +47,9 @@
 #include "target_core_pr.h"
 #include "target_core_ua.h"
 
+DEFINE_MUTEX(g_device_mutex);
+LIST_HEAD(g_device_list);
+
 static struct se_hba *lun0_hba;
 /* not static, needed by tpg.c */
 struct se_device *g_lun0_dev;
@@ -89,6 +92,9 @@ transport_lookup_cmd_lun(struct se_cmd *se_cmd, u32 unpacked_lun)
 		se_cmd->pr_res_key = deve->pr_res_key;
 		se_cmd->orig_fe_lun = unpacked_lun;
 		se_cmd->se_cmd_flags |= SCF_SE_LUN_CMD;
+
+		percpu_ref_get(&se_lun->lun_ref);
+		se_cmd->lun_ref_active = true;
 	}
 	spin_unlock_irqrestore(&se_sess->se_node_acl->device_list_lock, flags);
 
@@ -116,24 +122,20 @@ transport_lookup_cmd_lun(struct se_cmd *se_cmd, u32 unpacked_lun)
 		se_cmd->se_lun = &se_sess->se_tpg->tpg_virt_lun0;
 		se_cmd->orig_fe_lun = 0;
 		se_cmd->se_cmd_flags |= SCF_SE_LUN_CMD;
+
+		percpu_ref_get(&se_lun->lun_ref);
+		se_cmd->lun_ref_active = true;
 	}
 
 	/* Directly associate cmd with se_dev */
 	se_cmd->se_dev = se_lun->lun_se_dev;
 
-	/* TODO: get rid of this and use atomics for stats */
 	dev = se_lun->lun_se_dev;
-	spin_lock_irqsave(&dev->stats_lock, flags);
-	dev->num_cmds++;
+	atomic_long_inc(&dev->num_cmds);
 	if (se_cmd->data_direction == DMA_TO_DEVICE)
-		dev->write_bytes += se_cmd->data_length;
+		atomic_long_add(se_cmd->data_length, &dev->write_bytes);
 	else if (se_cmd->data_direction == DMA_FROM_DEVICE)
-		dev->read_bytes += se_cmd->data_length;
-	spin_unlock_irqrestore(&dev->stats_lock, flags);
-
-	spin_lock_irqsave(&se_lun->lun_cmd_lock, flags);
-	list_add_tail(&se_cmd->se_lun_node, &se_lun->lun_cmd_list);
-	spin_unlock_irqrestore(&se_lun->lun_cmd_lock, flags);
+		atomic_long_add(se_cmd->data_length, &dev->read_bytes);
 
 	return 0;
 }
@@ -311,14 +313,14 @@ int core_enable_device_list_for_node(
 	deve = nacl->device_list[mapped_lun];
 
 	/*
-	 * Check if the call is handling demo mode -> explict LUN ACL
+	 * Check if the call is handling demo mode -> explicit LUN ACL
 	 * transition.  This transition must be for the same struct se_lun
 	 * + mapped_lun that was setup in demo mode..
 	 */
 	if (deve->lun_flags & TRANSPORT_LUNFLAGS_INITIATOR_ACCESS) {
 		if (deve->se_lun_acl != NULL) {
 			pr_err("struct se_dev_entry->se_lun_acl"
-			       " already set for demo mode -> explict"
+			       " already set for demo mode -> explicit"
 			       " LUN ACL transition\n");
 			spin_unlock_irq(&nacl->device_list_lock);
 			return -EINVAL;
@@ -326,7 +328,7 @@ int core_enable_device_list_for_node(
 		if (deve->se_lun != lun) {
 			pr_err("struct se_dev_entry->se_lun does"
 			       " match passed struct se_lun for demo mode"
-			       " -> explict LUN ACL transition\n");
+			       " -> explicit LUN ACL transition\n");
 			spin_unlock_irq(&nacl->device_list_lock);
 			return -EINVAL;
 		}
@@ -614,6 +616,7 @@ void core_dev_unexport(
 	dev->export_count--;
 	spin_unlock(&hba->device_lock);
 
+	lun->lun_sep = NULL;
 	lun->lun_se_dev = NULL;
 }
 
@@ -796,10 +799,10 @@ int se_dev_set_emulate_write_cache(struct se_device *dev, int flag)
 		pr_err("emulate_write_cache not supported for pSCSI\n");
 		return -EINVAL;
 	}
-	if (dev->transport->get_write_cache) {
-		pr_warn("emulate_write_cache cannot be changed when underlying"
-			" HW reports WriteCacheEnabled, ignoring request\n");
-		return 0;
+	if (flag &&
+	    dev->transport->get_write_cache) {
+		pr_err("emulate_write_cache not supported for this device\n");
+		return -EINVAL;
 	}
 
 	dev->dev_attrib.emulate_write_cache = flag;
@@ -890,6 +893,120 @@ int se_dev_set_emulate_tpws(struct se_device *dev, int flag)
 	return 0;
 }
 
+int se_dev_set_emulate_caw(struct se_device *dev, int flag)
+{
+	if (flag != 0 && flag != 1) {
+		pr_err("Illegal value %d\n", flag);
+		return -EINVAL;
+	}
+	dev->dev_attrib.emulate_caw = flag;
+	pr_debug("dev[%p]: SE Device CompareAndWrite (AtomicTestandSet): %d\n",
+		 dev, flag);
+
+	return 0;
+}
+
+int se_dev_set_emulate_3pc(struct se_device *dev, int flag)
+{
+	if (flag != 0 && flag != 1) {
+		pr_err("Illegal value %d\n", flag);
+		return -EINVAL;
+	}
+	dev->dev_attrib.emulate_3pc = flag;
+	pr_debug("dev[%p]: SE Device 3rd Party Copy (EXTENDED_COPY): %d\n",
+		dev, flag);
+
+	return 0;
+}
+
+int se_dev_set_pi_prot_type(struct se_device *dev, int flag)
+{
+	int rc, old_prot = dev->dev_attrib.pi_prot_type;
+
+	if (flag != 0 && flag != 1 && flag != 2 && flag != 3) {
+		pr_err("Illegal value %d for pi_prot_type\n", flag);
+		return -EINVAL;
+	}
+	if (flag == 2) {
+		pr_err("DIF TYPE2 protection currently not supported\n");
+		return -ENOSYS;
+	}
+	if (dev->dev_attrib.hw_pi_prot_type) {
+		pr_warn("DIF protection enabled on underlying hardware,"
+			" ignoring\n");
+		return 0;
+	}
+	if (!dev->transport->init_prot || !dev->transport->free_prot) {
+		/* 0 is only allowed value for non-supporting backends */
+		if (flag == 0)
+			return 0;
+
+		pr_err("DIF protection not supported by backend: %s\n",
+		       dev->transport->name);
+		return -ENOSYS;
+	}
+	if (!(dev->dev_flags & DF_CONFIGURED)) {
+		pr_err("DIF protection requires device to be configured\n");
+		return -ENODEV;
+	}
+	if (dev->export_count) {
+		pr_err("dev[%p]: Unable to change SE Device PROT type while"
+		       " export_count is %d\n", dev, dev->export_count);
+		return -EINVAL;
+	}
+
+	dev->dev_attrib.pi_prot_type = flag;
+
+	if (flag && !old_prot) {
+		rc = dev->transport->init_prot(dev);
+		if (rc) {
+			dev->dev_attrib.pi_prot_type = old_prot;
+			return rc;
+		}
+
+	} else if (!flag && old_prot) {
+		dev->transport->free_prot(dev);
+	}
+	pr_debug("dev[%p]: SE Device Protection Type: %d\n", dev, flag);
+
+	return 0;
+}
+
+int se_dev_set_pi_prot_format(struct se_device *dev, int flag)
+{
+	int rc;
+
+	if (!flag)
+		return 0;
+
+	if (flag != 1) {
+		pr_err("Illegal value %d for pi_prot_format\n", flag);
+		return -EINVAL;
+	}
+	if (!dev->transport->format_prot) {
+		pr_err("DIF protection format not supported by backend %s\n",
+		       dev->transport->name);
+		return -ENOSYS;
+	}
+	if (!(dev->dev_flags & DF_CONFIGURED)) {
+		pr_err("DIF protection format requires device to be configured\n");
+		return -ENODEV;
+	}
+	if (dev->export_count) {
+		pr_err("dev[%p]: Unable to format SE Device PROT type while"
+		       " export_count is %d\n", dev, dev->export_count);
+		return -EINVAL;
+	}
+
+	rc = dev->transport->format_prot(dev);
+	if (rc)
+		return rc;
+
+	pr_debug("dev[%p]: SE Device Protection Format complete\n", dev);
+
+	return 0;
+}
+
 int se_dev_set_enforce_pr_isids(struct se_device *dev, int flag)
 {
 	if ((flag != 0) && (flag != 1)) {
@@ -1036,10 +1153,10 @@ int se_dev_set_optimal_sectors(struct se_device *dev, u32 optimal_sectors)
 				" changed for TCM/pSCSI\n", dev);
 		return -EINVAL;
 	}
-	if (optimal_sectors > dev->dev_attrib.fabric_max_sectors) {
+	if (optimal_sectors > dev->dev_attrib.hw_max_sectors) {
 		pr_err("dev[%p]: Passed optimal_sectors %u cannot be"
-			" greater than fabric_max_sectors: %u\n", dev,
-			optimal_sectors, dev->dev_attrib.fabric_max_sectors);
+			" greater than hw_max_sectors: %u\n", dev,
+			optimal_sectors, dev->dev_attrib.hw_max_sectors);
 		return -EINVAL;
 	}
 
@@ -1078,29 +1195,34 @@ int se_dev_set_block_size(struct se_device *dev, u32 block_size)
 	dev->dev_attrib.block_size = block_size;
 	pr_debug("dev[%p]: SE Device block_size changed to %u\n",
 			dev, block_size);
+
+	if (dev->dev_attrib.max_bytes_per_io)
+		dev->dev_attrib.hw_max_sectors =
+			dev->dev_attrib.max_bytes_per_io / block_size;
+
 	return 0;
 }
 
 struct se_lun *core_dev_add_lun(
 	struct se_portal_group *tpg,
 	struct se_device *dev,
-	u32 lun)
+	u32 unpacked_lun)
 {
-	struct se_lun *lun_p;
+	struct se_lun *lun;
 	int rc;
 
-	lun_p = core_tpg_pre_addlun(tpg, lun);
-	if (IS_ERR(lun_p))
-		return lun_p;
+	lun = core_tpg_alloc_lun(tpg, unpacked_lun);
+	if (IS_ERR(lun))
+		return lun;
 
-	rc = core_tpg_post_addlun(tpg, lun_p,
+	rc = core_tpg_add_lun(tpg, lun,
 				TRANSPORT_LUNFLAGS_READ_WRITE, dev);
 	if (rc < 0)
 		return ERR_PTR(rc);
 
 	pr_debug("%s_TPG[%u]_LUN[%u] - Activated %s Logical Unit from"
 		" CORE HBA: %u\n", tpg->se_tpg_tfo->get_fabric_name(),
-		tpg->se_tpg_tfo->tpg_get_tag(tpg), lun_p->unpacked_lun,
+		tpg->se_tpg_tfo->tpg_get_tag(tpg), lun->unpacked_lun,
 		tpg->se_tpg_tfo->get_fabric_name(), dev->se_hba->hba_id);
 	/*
 	 * Update LUN maps for dynamically added initiators when
@@ -1121,7 +1243,7 @@ struct se_lun *core_dev_add_lun(
 		spin_unlock_irq(&tpg->acl_node_lock);
 	}
 
-	return lun_p;
+	return lun;
 }
 
 /*      core_dev_del_lun():
@@ -1287,7 +1409,8 @@ int core_dev_add_initiator_node_lun_acl(
 	 * Check to see if there are any existing persistent reservation APTPL
 	 * pre-registrations that need to be enabled for this LUN ACL..
 	 */
-	core_scsi3_check_aptpl_registration(lun->lun_se_dev, tpg, lun, lacl);
+	core_scsi3_check_aptpl_registration(lun->lun_se_dev, tpg, lun, nacl,
+					    lacl->mapped_lun);
 	return 0;
 }
 
@@ -1378,6 +1501,7 @@ static void scsi_dump_inquiry(struct se_device *dev)
 struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 {
 	struct se_device *dev;
+	struct se_lun *xcopy_lun;
 
 	dev = hba->transport->alloc_device(hba, name);
 	if (!dev)
@@ -1386,6 +1510,7 @@ struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 	dev->dev_link_magic = SE_DEV_LINK_MAGIC;
 	dev->se_hba = hba;
 	dev->transport = hba->transport;
+	dev->prot_length = sizeof(struct se_dif_v1_tuple);
 
 	INIT_LIST_HEAD(&dev->dev_list);
 	INIT_LIST_HEAD(&dev->dev_sep_list);
@@ -1393,13 +1518,14 @@ struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 	INIT_LIST_HEAD(&dev->delayed_cmd_list);
 	INIT_LIST_HEAD(&dev->state_list);
 	INIT_LIST_HEAD(&dev->qf_cmd_list);
-	spin_lock_init(&dev->stats_lock);
+	INIT_LIST_HEAD(&dev->g_dev_node);
 	spin_lock_init(&dev->execute_task_lock);
 	spin_lock_init(&dev->delayed_cmd_lock);
 	spin_lock_init(&dev->dev_reservation_lock);
 	spin_lock_init(&dev->se_port_lock);
 	spin_lock_init(&dev->se_tmr_lock);
 	spin_lock_init(&dev->qf_cmd_lock);
+	sema_init(&dev->caw_sem, 1);
 	atomic_set(&dev->dev_ordered_id, 0);
 	INIT_LIST_HEAD(&dev->t10_wwn.t10_vpd_list);
 	spin_lock_init(&dev->t10_wwn.t10_vpd_lock);
@@ -1409,8 +1535,9 @@ struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 	spin_lock_init(&dev->t10_pr.aptpl_reg_lock);
 	INIT_LIST_HEAD(&dev->t10_alua.tg_pt_gps_list);
 	spin_lock_init(&dev->t10_alua.tg_pt_gps_lock);
+	INIT_LIST_HEAD(&dev->t10_alua.lba_map_list);
+	spin_lock_init(&dev->t10_alua.lba_map_lock);
 
-	dev->t10_pr.pr_aptpl_buf_len = PR_APTPL_BUF_LEN;
 	dev->t10_wwn.t10_dev = dev;
 	dev->t10_alua.t10_dev = dev;
 
@@ -1424,6 +1551,9 @@ struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 	dev->dev_attrib.emulate_tas = DA_EMULATE_TAS;
 	dev->dev_attrib.emulate_tpu = DA_EMULATE_TPU;
 	dev->dev_attrib.emulate_tpws = DA_EMULATE_TPWS;
+	dev->dev_attrib.emulate_caw = DA_EMULATE_CAW;
+	dev->dev_attrib.emulate_3pc = DA_EMULATE_3PC;
+	dev->dev_attrib.pi_prot_type = TARGET_DIF_TYPE0_PROT;
 	dev->dev_attrib.enforce_pr_isids = DA_ENFORCE_PR_ISIDS;
 	dev->dev_attrib.is_nonrot = DA_IS_NONROT;
 	dev->dev_attrib.emulate_rest_reord = DA_EMULATE_REST_REORD;
@@ -1435,11 +1565,63 @@ struct se_device *target_alloc_device(struct se_hba *hba, const char *name)
 				DA_UNMAP_GRANULARITY_ALIGNMENT_DEFAULT;
 	dev->dev_attrib.max_write_same_len = DA_MAX_WRITE_SAME_LEN;
 	dev->dev_attrib.fabric_max_sectors = DA_FABRIC_MAX_SECTORS;
-	dev->dev_attrib.optimal_sectors = DA_FABRIC_MAX_SECTORS;
+
+	xcopy_lun = &dev->xcopy_lun;
+	xcopy_lun->lun_se_dev = dev;
+	init_completion(&xcopy_lun->lun_shutdown_comp);
+	INIT_LIST_HEAD(&xcopy_lun->lun_acl_list);
+	spin_lock_init(&xcopy_lun->lun_acl_lock);
+	spin_lock_init(&xcopy_lun->lun_sep_lock);
+	init_completion(&xcopy_lun->lun_ref_comp);
 
 	return dev;
 }
 
+/*
+ * Check if the underlying struct block_device request_queue supports
+ * the QUEUE_FLAG_DISCARD bit for UNMAP/WRITE_SAME in SCSI + TRIM
+ * in ATA and we need to set TPE=1
+ */
+bool target_configure_unmap_from_queue(struct se_dev_attrib *attrib,
+				       struct request_queue *q)
+{
+	int block_size = queue_logical_block_size(q);
+
+	if (!blk_queue_discard(q))
+		return false;
+
+	attrib->max_unmap_lba_count =
+		q->limits.max_discard_sectors >> (ilog2(block_size) - 9);
+	/*
+	 * Currently hardcoded to 1 in Linux/SCSI code..
+	 */
+	attrib->max_unmap_block_desc_count = 1;
+	attrib->unmap_granularity = q->limits.discard_granularity / block_size;
+	attrib->unmap_granularity_alignment = q->limits.discard_alignment /
+								block_size;
+	return true;
+}
+EXPORT_SYMBOL(target_configure_unmap_from_queue);
+
+/*
+ * Convert from blocksize advertised to the initiator to the 512 byte
+ * units unconditionally used by the Linux block layer.
+ */
+sector_t target_to_linux_sector(struct se_device *dev, sector_t lb)
+{
+	switch (dev->dev_attrib.block_size) {
+	case 4096:
+		return lb << 3;
+	case 2048:
+		return lb << 2;
+	case 1024:
+		return lb << 1;
+	default:
+		return lb;
+	}
+}
+EXPORT_SYMBOL(target_to_linux_sector);
+
 int target_configure_device(struct se_device *dev)
 {
 	struct se_hba *hba = dev->se_hba;
@@ -1454,8 +1636,6 @@ int target_configure_device(struct se_device *dev)
 	ret = dev->transport->configure_device(dev);
 	if (ret)
 		goto out;
-	dev->dev_flags |= DF_CONFIGURED;
-
 	/*
 	 * XXX: there is not much point to have two different values here..
 	 */
@@ -1468,6 +1648,7 @@ int target_configure_device(struct se_device *dev)
 	dev->dev_attrib.hw_max_sectors =
 		se_dev_align_max_sectors(dev->dev_attrib.hw_max_sectors,
 					 dev->dev_attrib.hw_block_size);
+	dev->dev_attrib.optimal_sectors = dev->dev_attrib.hw_max_sectors;
 
 	dev->dev_index = scsi_get_new_index(SCSI_DEVICE_INDEX);
 	dev->creation_time = get_jiffies_64();
@@ -1511,6 +1692,13 @@ int target_configure_device(struct se_device *dev)
 	spin_lock(&hba->device_lock);
 	hba->dev_count++;
 	spin_unlock(&hba->device_lock);
+
+	mutex_lock(&g_device_mutex);
+	list_add_tail(&dev->g_dev_node, &g_device_list);
+	mutex_unlock(&g_device_mutex);
+
+	dev->dev_flags |= DF_CONFIGURED;
+
 	return 0;
 
 out_free_alua:
@@ -1529,15 +1717,23 @@ void target_free_device(struct se_device *dev)
 	if (dev->dev_flags & DF_CONFIGURED) {
 		destroy_workqueue(dev->tmr_wq);
 
+		mutex_lock(&g_device_mutex);
+		list_del(&dev->g_dev_node);
+		mutex_unlock(&g_device_mutex);
+
 		spin_lock(&hba->device_lock);
 		hba->dev_count--;
 		spin_unlock(&hba->device_lock);
 	}
 
 	core_alua_free_lu_gp_mem(dev);
+	core_alua_set_lba_map(dev, NULL, 0, 0);
 	core_scsi3_free_all_registrations(dev);
 	se_release_vpd_for_dev(dev);
 
+	if (dev->transport->free_prot)
+		dev->transport->free_prot(dev);
+
 	dev->transport->free_device(dev);
 }
 
@@ -1545,7 +1741,7 @@ int core_dev_setup_virtual_lun0(void)
 {
 	struct se_hba *hba;
 	struct se_device *dev;
-	char buf[16];
+	char buf[] = "rd_pages=8,rd_nullio=1";
 	int ret;
 
 	hba = core_alloc_hba("rd_mcp", 0, HBA_FLAGS_INTERNAL_USE);
@@ -1558,8 +1754,6 @@ int core_dev_setup_virtual_lun0(void)
 		goto out_free_hba;
 	}
 
-	memset(buf, 0, 16);
-	sprintf(buf, "rd_pages=8");
 	hba->transport->set_configfs_dev_params(dev, buf, sizeof(buf));
 
 	ret = target_configure_device(dev);
diff --git a/drivers/target/target_core_fabric_configfs.c b/drivers/target/target_core_fabric_configfs.c
index 04c775c..7de9f04 100644
--- a/drivers/target/target_core_fabric_configfs.c
+++ b/drivers/target/target_core_fabric_configfs.c
@@ -4,7 +4,7 @@
  * This file contains generic fabric module configfs infrastructure for
  * TCM v4.x code
  *
- * (c) Copyright 2010-2012 RisingTide Systems LLC.
+ * (c) Copyright 2010-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@linux-iscsi.org>
 *
@@ -189,9 +189,11 @@ static ssize_t target_fabric_mappedlun_store_write_protect(
 	struct se_node_acl *se_nacl = lacl->se_lun_nacl;
 	struct se_portal_group *se_tpg = se_nacl->se_tpg;
 	unsigned long op;
+	int ret;
 
-	if (strict_strtoul(page, 0, &op))
-		return -EINVAL;
+	ret = kstrtoul(page, 0, &op);
+	if (ret)
+		return ret;
 
 	if ((op != 1) && (op != 0))
 		return -EINVAL;
@@ -350,7 +352,10 @@ static struct config_group *target_fabric_make_mappedlun(
 	 * Determine the Mapped LUN value.  This is what the SCSI Initiator
 	 * Port will actually see.
 	 */
-	if (strict_strtoul(buf + 4, 0, &mapped_lun) || mapped_lun > UINT_MAX) {
+	ret = kstrtoul(buf + 4, 0, &mapped_lun);
+	if (ret)
+		goto out;
+	if (mapped_lun > UINT_MAX) {
 		ret = -EINVAL;
 		goto out;
 	}
@@ -380,9 +385,9 @@ static struct config_group *target_fabric_make_mappedlun(
 	}
 
 	config_group_init_type_name(&lacl->se_lun_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_mappedlun_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_mappedlun_cit);
 	config_group_init_type_name(&lacl->ml_stat_grps.stat_group,
-			"statistics", &TF_CIT_TMPL(tf)->tfc_tpg_mappedlun_stat_cit);
+			"statistics", &tf->tf_cit_tmpl.tfc_tpg_mappedlun_stat_cit);
 	lacl_cg->default_groups[0] = &lacl->ml_stat_grps.stat_group;
 	lacl_cg->default_groups[1] = NULL;
 
@@ -499,16 +504,16 @@ static struct config_group *target_fabric_make_nodeacl(
 	nacl_cg->default_groups[4] = NULL;
 
 	config_group_init_type_name(&se_nacl->acl_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_base_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_base_cit);
 	config_group_init_type_name(&se_nacl->acl_attrib_group, "attrib",
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_attrib_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit);
 	config_group_init_type_name(&se_nacl->acl_auth_group, "auth",
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_auth_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_auth_cit);
 	config_group_init_type_name(&se_nacl->acl_param_group, "param",
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_param_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_param_cit);
 	config_group_init_type_name(&se_nacl->acl_fabric_stat_group,
 			"fabric_statistics",
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_stat_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_stat_cit);
 
 	return &se_nacl->acl_group;
 }
@@ -590,7 +595,7 @@ static struct config_group *target_fabric_make_np(
 
 	se_tpg_np->tpg_np_parent = se_tpg;
 	config_group_init_type_name(&se_tpg_np->tpg_np_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_np_base_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_np_base_cit);
 
 	return &se_tpg_np->tpg_np_group;
 }
@@ -875,7 +880,10 @@ static struct config_group *target_fabric_make_lun(
 				" \"lun_$LUN_NUMBER\"\n");
 		return ERR_PTR(-EINVAL);
 	}
-	if (strict_strtoul(name + 4, 0, &unpacked_lun) || unpacked_lun > UINT_MAX)
+	errno = kstrtoul(name + 4, 0, &unpacked_lun);
+	if (errno)
+		return ERR_PTR(errno);
+	if (unpacked_lun > UINT_MAX)
 		return ERR_PTR(-EINVAL);
 
 	lun = core_get_lun_from_tpg(se_tpg, unpacked_lun);
@@ -891,14 +899,14 @@ static struct config_group *target_fabric_make_lun(
 	}
 
 	config_group_init_type_name(&lun->lun_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_port_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_port_cit);
 	config_group_init_type_name(&lun->port_stat_grps.stat_group,
-			"statistics", &TF_CIT_TMPL(tf)->tfc_tpg_port_stat_cit);
+			"statistics", &tf->tf_cit_tmpl.tfc_tpg_port_stat_cit);
 	lun_cg->default_groups[0] = &lun->port_stat_grps.stat_group;
 	lun_cg->default_groups[1] = NULL;
 
 	port_stat_grp = &lun->port_stat_grps.stat_group;
-	port_stat_grp->default_groups =  kzalloc(sizeof(struct config_group) * 3,
+	port_stat_grp->default_groups =  kzalloc(sizeof(struct config_group *) * 4,
 				GFP_KERNEL);
 	if (!port_stat_grp->default_groups) {
 		pr_err("Unable to allocate port_stat_grp->default_groups\n");
@@ -965,6 +973,19 @@ TF_CIT_SETUP(tpg_attrib, &target_fabric_tpg_attrib_item_ops, NULL, NULL);
 
 /* End of tfc_tpg_attrib_cit */
 
+/* Start of tfc_tpg_auth_cit */
+
+CONFIGFS_EATTR_OPS(target_fabric_tpg_auth, se_portal_group, tpg_auth_group);
+
+static struct configfs_item_operations target_fabric_tpg_auth_item_ops = {
+	.show_attribute		= target_fabric_tpg_auth_attr_show,
+	.store_attribute	= target_fabric_tpg_auth_attr_store,
+};
+
+TF_CIT_SETUP(tpg_auth, &target_fabric_tpg_auth_item_ops, NULL, NULL);
+
+/* End of tfc_tpg_attrib_cit */
+
 /* Start of tfc_tpg_param_cit */
 
 CONFIGFS_EATTR_OPS(target_fabric_tpg_param, se_portal_group, tpg_param_group);
@@ -1030,21 +1051,24 @@ static struct config_group *target_fabric_make_tpg(
 	se_tpg->tpg_group.default_groups[1] = &se_tpg->tpg_np_group;
 	se_tpg->tpg_group.default_groups[2] = &se_tpg->tpg_acl_group;
 	se_tpg->tpg_group.default_groups[3] = &se_tpg->tpg_attrib_group;
-	se_tpg->tpg_group.default_groups[4] = &se_tpg->tpg_param_group;
-	se_tpg->tpg_group.default_groups[5] = NULL;
+	se_tpg->tpg_group.default_groups[4] = &se_tpg->tpg_auth_group;
+	se_tpg->tpg_group.default_groups[5] = &se_tpg->tpg_param_group;
+	se_tpg->tpg_group.default_groups[6] = NULL;
 
 	config_group_init_type_name(&se_tpg->tpg_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_base_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_base_cit);
 	config_group_init_type_name(&se_tpg->tpg_lun_group, "lun",
-			&TF_CIT_TMPL(tf)->tfc_tpg_lun_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_lun_cit);
 	config_group_init_type_name(&se_tpg->tpg_np_group, "np",
-			&TF_CIT_TMPL(tf)->tfc_tpg_np_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_np_cit);
 	config_group_init_type_name(&se_tpg->tpg_acl_group, "acls",
-			&TF_CIT_TMPL(tf)->tfc_tpg_nacl_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_nacl_cit);
 	config_group_init_type_name(&se_tpg->tpg_attrib_group, "attrib",
-			&TF_CIT_TMPL(tf)->tfc_tpg_attrib_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_attrib_cit);
+	config_group_init_type_name(&se_tpg->tpg_auth_group, "auth",
+			&tf->tf_cit_tmpl.tfc_tpg_auth_cit);
 	config_group_init_type_name(&se_tpg->tpg_param_group, "param",
-			&TF_CIT_TMPL(tf)->tfc_tpg_param_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_param_cit);
 
 	return &se_tpg->tpg_group;
 }
@@ -1131,9 +1155,9 @@ static struct config_group *target_fabric_make_wwn(
 	wwn->wwn_group.default_groups[1] = NULL;
 
 	config_group_init_type_name(&wwn->wwn_group, name,
-			&TF_CIT_TMPL(tf)->tfc_tpg_cit);
+			&tf->tf_cit_tmpl.tfc_tpg_cit);
 	config_group_init_type_name(&wwn->fabric_stat_group, "fabric_statistics",
-			&TF_CIT_TMPL(tf)->tfc_wwn_fabric_stats_cit);
+			&tf->tf_cit_tmpl.tfc_wwn_fabric_stats_cit);
 
 	return &wwn->wwn_group;
 }
@@ -1202,6 +1226,7 @@ int target_fabric_setup_cits(struct target_fabric_configfs *tf)
 	target_fabric_setup_tpg_np_cit(tf);
 	target_fabric_setup_tpg_np_base_cit(tf);
 	target_fabric_setup_tpg_attrib_cit(tf);
+	target_fabric_setup_tpg_auth_cit(tf);
 	target_fabric_setup_tpg_param_cit(tf);
 	target_fabric_setup_tpg_nacl_cit(tf);
 	target_fabric_setup_tpg_nacl_base_cit(tf);
diff --git a/drivers/target/target_core_fabric_lib.c b/drivers/target/target_core_fabric_lib.c
index 687b0b0..0d1cf8b 100644
--- a/drivers/target/target_core_fabric_lib.c
+++ b/drivers/target/target_core_fabric_lib.c
@@ -4,7 +4,7 @@
  * This file contains generic high level protocol identifier and PR
  * handlers for TCM fabric modules
  *
- * (c) Copyright 2010-2012 RisingTide Systems LLC.
+ * (c) Copyright 2010-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
diff --git a/drivers/target/target_core_file.c b/drivers/target/target_core_file.c
old mode 100644
new mode 100755
index b11890d..110c2ad
--- a/drivers/target/target_core_file.c
+++ b/drivers/target/target_core_file.c
@@ -3,7 +3,7 @@
  *
  * This file contains the Storage Engine <-> FILEIO transport specific functions
  *
- * (c) Copyright 2005-2012 RisingTide Systems LLC.
+ * (c) Copyright 2005-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -66,9 +66,8 @@ static int fd_attach_hba(struct se_hba *hba, u32 host_id)
 	pr_debug("CORE_HBA[%d] - TCM FILEIO HBA Driver %s on Generic"
 		" Target Core Stack %s\n", hba->hba_id, FD_VERSION,
 		TARGET_CORE_MOD_VERSION);
-	pr_debug("CORE_HBA[%d] - Attached FILEIO HBA: %u to Generic"
-		" MaxSectors: %u\n",
-		hba->hba_id, fd_host->fd_host_id, FD_MAX_SECTORS);
+	pr_debug("CORE_HBA[%d] - Attached FILEIO HBA: %u to Generic\n",
+		hba->hba_id, fd_host->fd_host_id);
 
 	return 0;
 }
@@ -165,25 +164,10 @@ static int fd_configure_device(struct se_device *dev)
 			" block_device blocks: %llu logical_block_size: %d\n",
 			dev_size, div_u64(dev_size, fd_dev->fd_block_size),
 			fd_dev->fd_block_size);
-		/*
-		 * Check if the underlying struct block_device request_queue supports
-		 * the QUEUE_FLAG_DISCARD bit for UNMAP/WRITE_SAME in SCSI + TRIM
-		 * in ATA and we need to set TPE=1
-		 */
-		if (blk_queue_discard(q)) {
-			dev->dev_attrib.max_unmap_lba_count =
-				q->limits.max_discard_sectors;
-			/*
-			 * Currently hardcoded to 1 in Linux/SCSI code..
-			 */
-			dev->dev_attrib.max_unmap_block_desc_count = 1;
-			dev->dev_attrib.unmap_granularity =
-				q->limits.discard_granularity >> 9;
-			dev->dev_attrib.unmap_granularity_alignment =
-				q->limits.discard_alignment;
+
+		if (target_configure_unmap_from_queue(&dev->dev_attrib, q))
 			pr_debug("IFILE: BLOCK Discard support available,"
-					" disabled by default\n");
-		}
+				 " disabled by default\n");
 		/*
 		 * Enable write same emulation for IBLOCK and use 0xFFFF as
 		 * the smaller WRITE_SAME(10) only has a two-byte block count.
@@ -220,7 +204,8 @@ static int fd_configure_device(struct se_device *dev)
 	}
 
 	dev->dev_attrib.hw_block_size = fd_dev->fd_block_size;
-	dev->dev_attrib.hw_max_sectors = FD_MAX_SECTORS;
+	dev->dev_attrib.max_bytes_per_io = FD_MAX_BYTES;
+	dev->dev_attrib.hw_max_sectors = FD_MAX_BYTES / fd_dev->fd_block_size;
 	dev->dev_attrib.hw_queue_depth = FD_MAX_DEVICE_QUEUE_DEPTH;
 
 	if (fd_dev->fbd_flags & FDBD_HAS_BUFFERED_IO_WCE) {
@@ -257,6 +242,64 @@ static void fd_free_device(struct se_device *dev)
 	kfree(fd_dev);
 }
 
+static int fd_do_prot_rw(struct se_cmd *cmd, struct fd_prot *fd_prot,
+			 int is_write)
+{
+	struct se_device *se_dev = cmd->se_dev;
+	struct fd_dev *dev = FD_DEV(se_dev);
+	struct file *prot_fd = dev->fd_prot_file;
+	loff_t pos = (cmd->t_task_lba * se_dev->prot_length);
+	unsigned char *buf;
+	u32 prot_size;
+	int rc, ret = 1;
+
+	prot_size = (cmd->data_length / se_dev->dev_attrib.block_size) *
+		     se_dev->prot_length;
+
+	if (!is_write) {
+		fd_prot->prot_buf = kzalloc(prot_size, GFP_KERNEL);
+		if (!fd_prot->prot_buf) {
+			pr_err("Unable to allocate fd_prot->prot_buf\n");
+			return -ENOMEM;
+		}
+		buf = fd_prot->prot_buf;
+
+		fd_prot->prot_sg_nents = 1;
+		fd_prot->prot_sg = kzalloc(sizeof(struct scatterlist),
+					   GFP_KERNEL);
+		if (!fd_prot->prot_sg) {
+			pr_err("Unable to allocate fd_prot->prot_sg\n");
+			kfree(fd_prot->prot_buf);
+			return -ENOMEM;
+		}
+		sg_init_table(fd_prot->prot_sg, fd_prot->prot_sg_nents);
+		sg_set_buf(fd_prot->prot_sg, buf, prot_size);
+	}
+
+	if (is_write) {
+		rc = kernel_write(prot_fd, fd_prot->prot_buf, prot_size, pos);
+		if (rc < 0 || prot_size != rc) {
+			pr_err("kernel_write() for fd_do_prot_rw failed:"
+			       " %d\n", rc);
+			ret = -EINVAL;
+		}
+	} else {
+		rc = kernel_read(prot_fd, pos, fd_prot->prot_buf, prot_size);
+		if (rc < 0) {
+			pr_err("kernel_read() for fd_do_prot_rw failed:"
+			       " %d\n", rc);
+			ret = -EINVAL;
+		}
+	}
+
+	if (is_write || ret < 0) {
+		kfree(fd_prot->prot_sg);
+		kfree(fd_prot->prot_buf);
+	}
+
+	return ret;
+}
+
 static int fd_do_rw(struct se_cmd *cmd, struct scatterlist *sgl,
 		u32 sgl_nents, int is_write)
 {
@@ -349,7 +392,7 @@ fd_execute_sync_cache(struct se_cmd *cmd)
 	} else {
 		start = cmd->t_task_lba * dev->dev_attrib.block_size;
 		if (cmd->data_length)
-			end = start + cmd->data_length;
+			end = start + cmd->data_length - 1;
 		else
 			end = LLONG_MAX;
 	}
@@ -477,6 +520,56 @@ fd_execute_write_same(struct se_cmd *cmd)
 	return 0;
 }
 
+static int
+fd_do_prot_fill(struct se_device *se_dev, sector_t lba, sector_t nolb,
+		void *buf, size_t bufsize)
+{
+	struct fd_dev *fd_dev = FD_DEV(se_dev);
+	struct file *prot_fd = fd_dev->fd_prot_file;
+	sector_t prot_length, prot;
+	loff_t pos = lba * se_dev->prot_length;
+
+	if (!prot_fd) {
+		pr_err("Unable to locate fd_dev->fd_prot_file\n");
+		return -ENODEV;
+	}
+
+	prot_length = nolb * se_dev->prot_length;
+
+	for (prot = 0; prot < prot_length;) {
+		sector_t len = min_t(sector_t, bufsize, prot_length - prot);
+		ssize_t ret = kernel_write(prot_fd, buf, len, pos + prot);
+
+		if (ret != len) {
+			pr_err("vfs_write to prot file failed: %zd\n", ret);
+			return ret < 0 ? ret : -ENODEV;
+		}
+		prot += ret;
+	}
+
+	return 0;
+}
+
+static int
+fd_do_prot_unmap(struct se_cmd *cmd, sector_t lba, sector_t nolb)
+{
+	void *buf;
+	int rc;
+
+	buf = (void *)__get_free_page(GFP_KERNEL);
+	if (!buf) {
+		pr_err("Unable to allocate FILEIO prot buf\n");
+		return -ENOMEM;
+	}
+	memset(buf, 0xff, PAGE_SIZE);
+
+	rc = fd_do_prot_fill(cmd->se_dev, lba, nolb, buf, PAGE_SIZE);
+
+	free_page((unsigned long)buf);
+
+	return rc;
+}
+
 static sense_reason_t
 fd_do_unmap(struct se_cmd *cmd, void *priv, sector_t lba, sector_t nolb)
 {
@@ -484,6 +577,12 @@ fd_do_unmap(struct se_cmd *cmd, void *priv, sector_t lba, sector_t nolb)
 	struct inode *inode = file->f_mapping->host;
 	int ret;
 
+	if (cmd->se_dev->dev_attrib.pi_prot_type) {
+		ret = fd_do_prot_unmap(cmd, lba, nolb);
+		if (ret)
+			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
+
 	if (S_ISBLK(inode->i_mode)) {
 		/* The backend is block device, use discard */
 		struct block_device *bdev = inode->i_bdev;
@@ -547,24 +646,73 @@ fd_execute_unmap(struct se_cmd *cmd)
 }
 
 static sense_reason_t
-fd_execute_rw(struct se_cmd *cmd)
+fd_execute_rw(struct se_cmd *cmd, struct scatterlist *sgl, u32 sgl_nents,
+	      enum dma_data_direction data_direction)
 {
-	struct scatterlist *sgl = cmd->t_data_sg;
-	u32 sgl_nents = cmd->t_data_nents;
-	enum dma_data_direction data_direction = cmd->data_direction;
 	struct se_device *dev = cmd->se_dev;
+	struct fd_prot fd_prot;
+	sense_reason_t rc;
 	int ret = 0;
-
+	/*
+	 * We are currently limited by the number of iovecs (2048) per
+	 * single vfs_[writev,readv] call.
+	 */
+	if (cmd->data_length > FD_MAX_BYTES) {
+		pr_err("FILEIO: Not able to process I/O of %u bytes due to"
+		       "FD_MAX_BYTES: %u iovec count limitiation\n",
+			cmd->data_length, FD_MAX_BYTES);
+		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
 	/*
 	 * Call vectorized fileio functions to map struct scatterlist
 	 * physical memory addresses to struct iovec virtual memory.
 	 */
 	if (data_direction == DMA_FROM_DEVICE) {
+		memset(&fd_prot, 0, sizeof(struct fd_prot));
+
+		if (cmd->prot_type) {
+			ret = fd_do_prot_rw(cmd, &fd_prot, false);
+			if (ret < 0)
+				return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+		}
+
 		ret = fd_do_rw(cmd, sgl, sgl_nents, 0);
+
+		if (ret > 0 && cmd->prot_type) {
+			u32 sectors = cmd->data_length / dev->dev_attrib.block_size;
+
+			rc = sbc_dif_verify_read(cmd, cmd->t_task_lba, sectors,
+						 0, fd_prot.prot_sg, 0);
+			if (rc) {
+				kfree(fd_prot.prot_sg);
+				kfree(fd_prot.prot_buf);
+				return rc;
+			}
+			kfree(fd_prot.prot_sg);
+			kfree(fd_prot.prot_buf);
+		}
 	} else {
+		memset(&fd_prot, 0, sizeof(struct fd_prot));
+
+		if (cmd->prot_type) {
+			u32 sectors = cmd->data_length / dev->dev_attrib.block_size;
+
+			ret = fd_do_prot_rw(cmd, &fd_prot, false);
+			if (ret < 0)
+				return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+
+			rc = sbc_dif_verify_write(cmd, cmd->t_task_lba, sectors,
+						  0, fd_prot.prot_sg, 0);
+			if (rc) {
+				kfree(fd_prot.prot_sg);
+				kfree(fd_prot.prot_buf);
+				return rc;
+			}
+		}
+
 		ret = fd_do_rw(cmd, sgl, sgl_nents, 1);
 		/*
-		 * Perform implict vfs_fsync_range() for fd_do_writev() ops
+		 * Perform implicit vfs_fsync_range() for fd_do_writev() ops
 		 * for SCSI WRITEs with Forced Unit Access (FUA) set.
 		 * Allow this to happen independent of WCE=0 setting.
 		 */
@@ -574,14 +722,28 @@ fd_execute_rw(struct se_cmd *cmd)
 			struct fd_dev *fd_dev = FD_DEV(dev);
 			loff_t start = cmd->t_task_lba *
 				dev->dev_attrib.block_size;
-			loff_t end = start + cmd->data_length;
+			loff_t end;
+
+			if (cmd->data_length)
+				end = start + cmd->data_length - 1;
+			else
+				end = LLONG_MAX;
 
 			vfs_fsync_range(fd_dev->fd_file, start, end, 1);
 		}
+
+		if (ret > 0 && cmd->prot_type) {
+			ret = fd_do_prot_rw(cmd, &fd_prot, true);
+			if (ret < 0)
+				return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+		}
 	}
 
-	if (ret < 0)
+	if (ret < 0) {
+		kfree(fd_prot.prot_sg);
+		kfree(fd_prot.prot_buf);
 		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
 
 	if (ret)
 		target_complete_cmd(cmd, SAM_STAT_GOOD);
@@ -635,10 +797,10 @@ static ssize_t fd_set_configfs_dev_params(struct se_device *dev,
 				ret = -ENOMEM;
 				break;
 			}
-			ret = strict_strtoull(arg_p, 0, &fd_dev->fd_dev_size);
+			ret = kstrtoull(arg_p, 0, &fd_dev->fd_dev_size);
 			kfree(arg_p);
 			if (ret < 0) {
-				pr_err("strict_strtoull() failed for"
+				pr_err("kstrtoull() failed for"
 						" fd_dev_size=\n");
 				goto out;
 			}
@@ -647,7 +809,9 @@ static ssize_t fd_set_configfs_dev_params(struct se_device *dev,
 			fd_dev->fbd_flags |= FBDF_HAS_SIZE;
 			break;
 		case Opt_fd_buffered_io:
-			match_int(args, &arg);
+			ret = match_int(args, &arg);
+			if (ret)
+				goto out;
 			if (arg != 1) {
 				pr_err("bogus fd_buffered_io=%d value\n", arg);
 				ret = -EINVAL;
@@ -702,6 +866,82 @@ static sector_t fd_get_blocks(struct se_device *dev)
 		       dev->dev_attrib.block_size);
 }
 
+static int fd_init_prot(struct se_device *dev)
+{
+	struct fd_dev *fd_dev = FD_DEV(dev);
+	struct file *prot_file, *file = fd_dev->fd_file;
+	struct inode *inode;
+	int ret, flags = O_RDWR | O_CREAT | O_LARGEFILE | O_DSYNC;
+	char buf[FD_MAX_DEV_PROT_NAME];
+
+	if (!file) {
+		pr_err("Unable to locate fd_dev->fd_file\n");
+		return -ENODEV;
+	}
+
+	inode = file->f_mapping->host;
+	if (S_ISBLK(inode->i_mode)) {
+		pr_err("FILEIO Protection emulation only supported on"
+		       " !S_ISBLK\n");
+		return -ENOSYS;
+	}
+
+	if (fd_dev->fbd_flags & FDBD_HAS_BUFFERED_IO_WCE)
+		flags &= ~O_DSYNC;
+
+	snprintf(buf, FD_MAX_DEV_PROT_NAME, "%s.protection",
+		 fd_dev->fd_dev_name);
+
+	prot_file = filp_open(buf, flags, 0600);
+	if (IS_ERR(prot_file)) {
+		pr_err("filp_open(%s) failed\n", buf);
+		ret = PTR_ERR(prot_file);
+		return ret;
+	}
+	fd_dev->fd_prot_file = prot_file;
+
+	return 0;
+}
+
+static int fd_format_prot(struct se_device *dev)
+{
+	unsigned char *buf;
+	int unit_size = FDBD_FORMAT_UNIT_SIZE * dev->dev_attrib.block_size;
+	int ret;
+
+	if (!dev->dev_attrib.pi_prot_type) {
+		pr_err("Unable to format_prot while pi_prot_type == 0\n");
+		return -ENODEV;
+	}
+
+	buf = vzalloc(unit_size);
+	if (!buf) {
+		pr_err("Unable to allocate FILEIO prot buf\n");
+		return -ENOMEM;
+	}
+
+	pr_debug("Using FILEIO prot_length: %llu\n",
+		 (unsigned long long)(dev->transport->get_blocks(dev) + 1) *
+					dev->prot_length);
+
+	memset(buf, 0xff, unit_size);
+	ret = fd_do_prot_fill(dev, 0, dev->transport->get_blocks(dev) + 1,
+			      buf, unit_size);
+	vfree(buf);
+	return ret;
+}
+
+static void fd_free_prot(struct se_device *dev)
+{
+	struct fd_dev *fd_dev = FD_DEV(dev);
+
+	if (!fd_dev->fd_prot_file)
+		return;
+
+	filp_close(fd_dev->fd_prot_file, NULL);
+	fd_dev->fd_prot_file = NULL;
+}
+
 static struct sbc_ops fd_sbc_ops = {
 	.execute_rw		= fd_execute_rw,
 	.execute_sync_cache	= fd_execute_sync_cache,
@@ -732,6 +972,9 @@ static struct se_subsystem_api fileio_template = {
 	.show_configfs_dev_params = fd_show_configfs_dev_params,
 	.get_device_type	= sbc_get_device_type,
 	.get_blocks		= fd_get_blocks,
+	.init_prot		= fd_init_prot,
+	.format_prot		= fd_format_prot,
+	.free_prot		= fd_free_prot,
 };
 
 static int __init fileio_module_init(void)
diff --git a/drivers/target/target_core_file.h b/drivers/target/target_core_file.h
index 37ffc5b..182cbb2 100644
--- a/drivers/target/target_core_file.h
+++ b/drivers/target/target_core_file.h
@@ -4,10 +4,14 @@
 #define FD_VERSION		"4.0"
 
 #define FD_MAX_DEV_NAME		256
+#define FD_MAX_DEV_PROT_NAME	FD_MAX_DEV_NAME + 16
 #define FD_DEVICE_QUEUE_DEPTH	32
 #define FD_MAX_DEVICE_QUEUE_DEPTH 128
 #define FD_BLOCKSIZE		512
-#define FD_MAX_SECTORS		2048
+/*
+ * Limited by the number of iovecs (2048) per vfs_[writev,readv] call
+ */
+#define FD_MAX_BYTES		8388608
 
 #define RRF_EMULATE_CDB		0x01
 #define RRF_GOT_LBA		0x02
@@ -15,6 +19,13 @@
 #define FBDF_HAS_PATH		0x01
 #define FBDF_HAS_SIZE		0x02
 #define FDBD_HAS_BUFFERED_IO_WCE 0x04
+#define FDBD_FORMAT_UNIT_SIZE	2048
+
+struct fd_prot {
+	unsigned char	*prot_buf;
+	struct scatterlist *prot_sg;
+	u32 prot_sg_nents;
+};
 
 struct fd_dev {
 	struct se_device dev;
@@ -29,6 +40,7 @@ struct fd_dev {
 	u32		fd_block_size;
 	unsigned long long fd_dev_size;
 	struct file	*fd_file;
+	struct file	*fd_prot_file;
 	/* FILEIO HBA device is connected to */
 	struct fd_host *fd_host;
 } ____cacheline_aligned;
diff --git a/drivers/target/target_core_hba.c b/drivers/target/target_core_hba.c
index d2616cd..a25051a 100644
--- a/drivers/target/target_core_hba.c
+++ b/drivers/target/target_core_hba.c
@@ -3,7 +3,7 @@
  *
  * This file contains the TCM HBA Transport related functions.
  *
- * (c) Copyright 2003-2012 RisingTide Systems LLC.
+ * (c) Copyright 2003-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
diff --git a/drivers/target/target_core_iblock.c b/drivers/target/target_core_iblock.c
old mode 100644
new mode 100755
index aa1620a..261dc3f
--- a/drivers/target/target_core_iblock.c
+++ b/drivers/target/target_core_iblock.c
@@ -4,7 +4,7 @@
  * This file contains the Storage Engine  <-> Linux BlockIO transport
  * specific functions.
  *
- * (c) Copyright 2003-2012 RisingTide Systems LLC.
+ * (c) Copyright 2003-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -91,6 +91,7 @@ static int iblock_configure_device(struct se_device *dev)
 	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
 	struct request_queue *q;
 	struct block_device *bd = NULL;
+	struct blk_integrity *bi;
 	fmode_t mode;
 	int ret = -ENOMEM;
 
@@ -122,30 +123,13 @@ static int iblock_configure_device(struct se_device *dev)
 	q = bdev_get_queue(bd);
 
 	dev->dev_attrib.hw_block_size = bdev_logical_block_size(bd);
-	dev->dev_attrib.hw_max_sectors = UINT_MAX;
+	dev->dev_attrib.hw_max_sectors = queue_max_hw_sectors(q);
 	dev->dev_attrib.hw_queue_depth = q->nr_requests;
 
-	/*
-	 * Check if the underlying struct block_device request_queue supports
-	 * the QUEUE_FLAG_DISCARD bit for UNMAP/WRITE_SAME in SCSI + TRIM
-	 * in ATA and we need to set TPE=1
-	 */
-	if (blk_queue_discard(q)) {
-		dev->dev_attrib.max_unmap_lba_count =
-				q->limits.max_discard_sectors;
-
-		/*
-		 * Currently hardcoded to 1 in Linux/SCSI code..
-		 */
-		dev->dev_attrib.max_unmap_block_desc_count = 1;
-		dev->dev_attrib.unmap_granularity =
-				q->limits.discard_granularity >> 9;
-		dev->dev_attrib.unmap_granularity_alignment =
-				q->limits.discard_alignment;
-
+	if (target_configure_unmap_from_queue(&dev->dev_attrib, q))
 		pr_debug("IBLOCK: BLOCK Discard support available,"
-				" disabled by default\n");
-	}
+			 " disabled by default\n");
+
 	/*
 	 * Enable write same emulation for IBLOCK and use 0xFFFF as
 	 * the smaller WRITE_SAME(10) only has a two-byte block count.
@@ -155,8 +139,40 @@ static int iblock_configure_device(struct se_device *dev)
 	if (blk_queue_nonrot(q))
 		dev->dev_attrib.is_nonrot = 1;
 
+	bi = bdev_get_integrity(bd);
+	if (bi) {
+		struct bio_set *bs = ib_dev->ibd_bio_set;
+
+		if (!strcmp(bi->name, "T10-DIF-TYPE3-IP") ||
+		    !strcmp(bi->name, "T10-DIF-TYPE1-IP")) {
+			pr_err("IBLOCK export of blk_integrity: %s not"
+			       " supported\n", bi->name);
+			ret = -ENOSYS;
+			goto out_blkdev_put;
+		}
+
+		if (!strcmp(bi->name, "T10-DIF-TYPE3-CRC")) {
+			dev->dev_attrib.pi_prot_type = TARGET_DIF_TYPE3_PROT;
+		} else if (!strcmp(bi->name, "T10-DIF-TYPE1-CRC")) {
+			dev->dev_attrib.pi_prot_type = TARGET_DIF_TYPE1_PROT;
+		}
+
+		if (dev->dev_attrib.pi_prot_type) {
+			if (bioset_integrity_create(bs, IBLOCK_BIO_POOL_SIZE) < 0) {
+				pr_err("Unable to allocate bioset for PI\n");
+				ret = -ENOMEM;
+				goto out_blkdev_put;
+			}
+			pr_debug("IBLOCK setup BIP bs->bio_integrity_pool: %p\n",
+				 bs->bio_integrity_pool);
+		}
+		dev->dev_attrib.hw_pi_prot_type = dev->dev_attrib.pi_prot_type;
+	}
+
 	return 0;
 
+out_blkdev_put:
+	blkdev_put(ib_dev->ibd_bd, FMODE_WRITE|FMODE_READ|FMODE_EXCL);
 out_free_bioset:
 	bioset_free(ib_dev->ibd_bio_set);
 	ib_dev->ibd_bio_set = NULL;
@@ -172,6 +188,7 @@ static void iblock_free_device(struct se_device *dev)
 		blkdev_put(ib_dev->ibd_bd, FMODE_WRITE|FMODE_READ|FMODE_EXCL);
 	if (ib_dev->ibd_bio_set != NULL)
 		bioset_free(ib_dev->ibd_bio_set);
+
 	kfree(ib_dev);
 }
 
@@ -384,9 +401,13 @@ iblock_do_unmap(struct se_cmd *cmd, void *priv,
 		sector_t lba, sector_t nolb)
 {
 	struct block_device *bdev = priv;
+	struct se_device *dev = cmd->se_dev;
 	int ret;
 
-	ret = blkdev_issue_discard(bdev, lba, nolb, GFP_KERNEL, 0);
+	ret = blkdev_issue_discard(bdev,
+				   target_to_linux_sector(dev, lba),
+				   target_to_linux_sector(dev,  nolb),
+				   GFP_KERNEL, 0);
 	if (ret < 0) {
 		pr_err("blkdev_issue_discard() failed: %d\n", ret);
 		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
@@ -426,8 +447,10 @@ iblock_execute_write_same(struct se_cmd *cmd)
 	struct scatterlist *sg;
 	struct bio *bio;
 	struct bio_list list;
-	sector_t block_lba = cmd->t_task_lba;
-	sector_t sectors = sbc_get_write_same_sectors(cmd);
+	struct se_device *dev = cmd->se_dev;
+	sector_t block_lba = target_to_linux_sector(dev, cmd->t_task_lba);
+	sector_t sectors = target_to_linux_sector(dev,
+					sbc_get_write_same_sectors(cmd));
 
 	sg = &cmd->t_data_sg[0];
 
@@ -536,10 +559,10 @@ static ssize_t iblock_set_configfs_dev_params(struct se_device *dev,
 				ret = -ENOMEM;
 				break;
 			}
-			ret = strict_strtoul(arg_p, 0, &tmp_readonly);
+			ret = kstrtoul(arg_p, 0, &tmp_readonly);
 			kfree(arg_p);
 			if (ret < 0) {
-				pr_err("strict_strtoul() failed for"
+				pr_err("kstrtoul() failed for"
 						" readonly=\n");
 				goto out;
 			}
@@ -586,19 +609,62 @@ static ssize_t iblock_show_configfs_dev_params(struct se_device *dev, char *b)
 	return bl;
 }
 
+static int
+iblock_alloc_bip(struct se_cmd *cmd, struct bio *bio)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct blk_integrity *bi;
+	struct bio_integrity_payload *bip;
+	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
+	struct scatterlist *sg;
+	int i, rc;
+
+	bi = bdev_get_integrity(ib_dev->ibd_bd);
+	if (!bi) {
+		pr_err("Unable to locate bio_integrity\n");
+		return -ENODEV;
+	}
+
+	bip = bio_integrity_alloc(bio, GFP_NOIO, cmd->t_prot_nents);
+	if (!bip) {
+		pr_err("Unable to allocate bio_integrity_payload\n");
+		return -ENOMEM;
+	}
+
+	bip->bip_size = (cmd->data_length / dev->dev_attrib.block_size) *
+			 dev->prot_length;
+	bip->bip_sector = bio->bi_sector;
+
+	pr_debug("IBLOCK BIP Size: %u Sector: %llu\n", bip->bip_size,
+		 (unsigned long long)bip->bip_sector);
+
+	for_each_sg(cmd->t_prot_sg, sg, cmd->t_prot_nents, i) {
+
+		rc = bio_integrity_add_page(bio, sg_page(sg), sg->length,
+					    sg->offset);
+		if (rc != sg->length) {
+			pr_err("bio_integrity_add_page() failed; %d\n", rc);
+			return -ENOMEM;
+		}
+
+		pr_debug("Added bio integrity page: %p length: %d offset; %d\n",
+			 sg_page(sg), sg->length, sg->offset);
+	}
+
+	return 0;
+}
+
 static sense_reason_t
-iblock_execute_rw(struct se_cmd *cmd)
+iblock_execute_rw(struct se_cmd *cmd, struct scatterlist *sgl, u32 sgl_nents,
+		  enum dma_data_direction data_direction)
 {
-	struct scatterlist *sgl = cmd->t_data_sg;
-	u32 sgl_nents = cmd->t_data_nents;
-	enum dma_data_direction data_direction = cmd->data_direction;
 	struct se_device *dev = cmd->se_dev;
+	sector_t block_lba = target_to_linux_sector(dev, cmd->t_task_lba);
 	struct iblock_req *ibr;
-	struct bio *bio;
+	struct bio *bio, *bio_start;
 	struct bio_list list;
 	struct scatterlist *sg;
 	u32 sg_num = sgl_nents;
-	sector_t block_lba;
 	unsigned bio_cnt;
 	int rw = 0;
 	int i;
@@ -624,24 +690,6 @@ iblock_execute_rw(struct se_cmd *cmd)
 		rw = READ;
 	}
 
-	/*
-	 * Convert the blocksize advertised to the initiator to the 512 byte
-	 * units unconditionally used by the Linux block layer.
-	 */
-	if (dev->dev_attrib.block_size == 4096)
-		block_lba = (cmd->t_task_lba << 3);
-	else if (dev->dev_attrib.block_size == 2048)
-		block_lba = (cmd->t_task_lba << 2);
-	else if (dev->dev_attrib.block_size == 1024)
-		block_lba = (cmd->t_task_lba << 1);
-	else if (dev->dev_attrib.block_size == 512)
-		block_lba = cmd->t_task_lba;
-	else {
-		pr_err("Unsupported SCSI -> BLOCK LBA conversion:"
-				" %u\n", dev->dev_attrib.block_size);
-		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
-	}
-
 	ibr = kzalloc(sizeof(struct iblock_req), GFP_KERNEL);
 	if (!ibr)
 		goto fail;
@@ -657,6 +705,7 @@ iblock_execute_rw(struct se_cmd *cmd)
 	if (!bio)
 		goto fail_free_ibr;
 
+	bio_start = bio;
 	bio_list_init(&list);
 	bio_list_add(&list, bio);
 
@@ -690,6 +739,12 @@ iblock_execute_rw(struct se_cmd *cmd)
 		sg_num--;
 	}
 
+	if (cmd->prot_type) {
+		int rc = iblock_alloc_bip(cmd, bio_start);
+		if (rc)
+			goto fail_put_bios;
+	}
+
 	iblock_submit_bios(&list, rw);
 	iblock_complete_cmd(cmd);
 	return 0;
@@ -712,6 +767,45 @@ static sector_t iblock_get_blocks(struct se_device *dev)
 	return iblock_emulate_read_cap_with_block_size(dev, bd, q);
 }
 
+static sector_t iblock_get_alignment_offset_lbas(struct se_device *dev)
+{
+	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
+	struct block_device *bd = ib_dev->ibd_bd;
+	int ret;
+
+	ret = bdev_alignment_offset(bd);
+	if (ret == -1)
+		return 0;
+
+	/* convert offset-bytes to offset-lbas */
+	return ret / bdev_logical_block_size(bd);
+}
+
+static unsigned int iblock_get_lbppbe(struct se_device *dev)
+{
+	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
+	struct block_device *bd = ib_dev->ibd_bd;
+	int logs_per_phys = bdev_physical_block_size(bd) / bdev_logical_block_size(bd);
+
+	return ilog2(logs_per_phys);
+}
+
+static unsigned int iblock_get_io_min(struct se_device *dev)
+{
+	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
+	struct block_device *bd = ib_dev->ibd_bd;
+
+	return bdev_io_min(bd);
+}
+
+static unsigned int iblock_get_io_opt(struct se_device *dev)
+{
+	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
+	struct block_device *bd = ib_dev->ibd_bd;
+
+	return bdev_io_opt(bd);
+}
+
 static struct sbc_ops iblock_sbc_ops = {
 	.execute_rw		= iblock_execute_rw,
 	.execute_sync_cache	= iblock_execute_sync_cache,
@@ -726,7 +820,7 @@ iblock_parse_cdb(struct se_cmd *cmd)
 	return sbc_parse_cdb(cmd, &iblock_sbc_ops);
 }
 
-bool iblock_get_write_cache(struct se_device *dev)
+static bool iblock_get_write_cache(struct se_device *dev)
 {
 	struct iblock_dev *ib_dev = IBLOCK_DEV(dev);
 	struct block_device *bd = ib_dev->ibd_bd;
@@ -751,6 +845,10 @@ static struct se_subsystem_api iblock_template = {
 	.show_configfs_dev_params = iblock_show_configfs_dev_params,
 	.get_device_type	= sbc_get_device_type,
 	.get_blocks		= iblock_get_blocks,
+	.get_alignment_offset_lbas = iblock_get_alignment_offset_lbas,
+	.get_lbppbe		= iblock_get_lbppbe,
+	.get_io_min		= iblock_get_io_min,
+	.get_io_opt		= iblock_get_io_opt,
 	.get_write_cache	= iblock_get_write_cache,
 };
 
diff --git a/drivers/target/target_core_internal.h b/drivers/target/target_core_internal.h
index 18d49df..de9cab7 100644
--- a/drivers/target/target_core_internal.h
+++ b/drivers/target/target_core_internal.h
@@ -33,6 +33,10 @@ int	se_dev_set_emulate_ua_intlck_ctrl(struct se_device *, int);
 int	se_dev_set_emulate_tas(struct se_device *, int);
 int	se_dev_set_emulate_tpu(struct se_device *, int);
 int	se_dev_set_emulate_tpws(struct se_device *, int);
+int	se_dev_set_emulate_caw(struct se_device *, int);
+int	se_dev_set_emulate_3pc(struct se_device *, int);
+int	se_dev_set_pi_prot_type(struct se_device *, int);
+int	se_dev_set_pi_prot_format(struct se_device *, int);
 int	se_dev_set_enforce_pr_isids(struct se_device *, int);
 int	se_dev_set_is_nonrot(struct se_device *, int);
 int	se_dev_set_emulate_rest_reord(struct se_device *dev, int);
@@ -73,13 +77,11 @@ extern struct se_device *g_lun0_dev;
 
 struct se_node_acl *__core_tpg_get_initiator_node_acl(struct se_portal_group *tpg,
 		const char *);
-struct se_node_acl *core_tpg_get_initiator_node_acl(struct se_portal_group *tpg,
-		unsigned char *);
 void	core_tpg_add_node_to_devs(struct se_node_acl *, struct se_portal_group *);
 void	core_tpg_wait_for_nacl_pr_ref(struct se_node_acl *);
-struct se_lun *core_tpg_pre_addlun(struct se_portal_group *, u32);
-int	core_tpg_post_addlun(struct se_portal_group *, struct se_lun *,
-		u32, void *);
+struct se_lun *core_tpg_alloc_lun(struct se_portal_group *, u32);
+int	core_tpg_add_lun(struct se_portal_group *, struct se_lun *,
+		u32, struct se_device *);
 struct se_lun *core_tpg_pre_dellun(struct se_portal_group *, u32 unpacked_lun);
 int	core_tpg_post_dellun(struct se_portal_group *, struct se_lun *);
 
@@ -100,7 +102,7 @@ int	transport_dump_vpd_assoc(struct t10_vpd *, unsigned char *, int);
 int	transport_dump_vpd_ident_type(struct t10_vpd *, unsigned char *, int);
 int	transport_dump_vpd_ident(struct t10_vpd *, unsigned char *, int);
 bool	target_stop_cmd(struct se_cmd *cmd, unsigned long *flags);
-int	transport_clear_lun_from_sessions(struct se_lun *);
+int	transport_clear_lun_ref(struct se_lun *);
 void	transport_send_task_abort(struct se_cmd *);
 sense_reason_t	target_cmd_size_check(struct se_cmd *cmd, unsigned int size);
 void	target_qf_do_work(struct work_struct *work);
diff --git a/drivers/target/target_core_pr.c b/drivers/target/target_core_pr.c
index 04a7493..70cb375 100644
--- a/drivers/target/target_core_pr.c
+++ b/drivers/target/target_core_pr.c
@@ -4,7 +4,7 @@
  * This file contains SPC-3 compliant persistent reservations and
  * legacy SPC-2 reservations with compatible reservation handling (CRH=1)
  *
- * (c) Copyright 2009-2012 RisingTide Systems LLC.
+ * (c) Copyright 2009-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -53,20 +53,30 @@ struct pr_transport_id_holder {
 	struct list_head dest_list;
 };
 
-int core_pr_dump_initiator_port(
+void core_pr_dump_initiator_port(
 	struct t10_pr_registration *pr_reg,
 	char *buf,
 	u32 size)
 {
 	if (!pr_reg->isid_present_at_reg)
-		return 0;
+		buf[0] = '\0';
 
-	snprintf(buf, size, ",i,0x%s", &pr_reg->pr_reg_isid[0]);
-	return 1;
+	snprintf(buf, size, ",i,0x%s", pr_reg->pr_reg_isid);
 }
 
+enum register_type {
+	REGISTER,
+	REGISTER_AND_IGNORE_EXISTING_KEY,
+	REGISTER_AND_MOVE,
+};
+
+enum preempt_type {
+	PREEMPT,
+	PREEMPT_AND_ABORT,
+};
+
 static void __core_scsi3_complete_pro_release(struct se_device *, struct se_node_acl *,
-			struct t10_pr_registration *, int);
+					      struct t10_pr_registration *, int, int);
 
 static sense_reason_t
 target_scsi2_reservation_check(struct se_cmd *cmd)
@@ -464,7 +474,7 @@ static int core_scsi3_pr_seq_non_holder(
 	 * statement.
 	 */
 	if (!ret && !other_cdb) {
-		pr_debug("Allowing explict CDB: 0x%02x for %s"
+		pr_debug("Allowing explicit CDB: 0x%02x for %s"
 			" reservation holder\n", cdb[0],
 			core_scsi3_pr_dump_type(pr_reg_type));
 
@@ -497,7 +507,7 @@ static int core_scsi3_pr_seq_non_holder(
 			 */
 
 			if (!registered_nexus) {
-				pr_debug("Allowing implict CDB: 0x%02x"
+				pr_debug("Allowing implicit CDB: 0x%02x"
 					" for %s reservation on unregistered"
 					" nexus\n", cdb[0],
 					core_scsi3_pr_dump_type(pr_reg_type));
@@ -512,12 +522,24 @@ static int core_scsi3_pr_seq_non_holder(
 			 * allow commands from registered nexuses.
 			 */
 
-			pr_debug("Allowing implict CDB: 0x%02x for %s"
+			pr_debug("Allowing implicit CDB: 0x%02x for %s"
 				" reservation\n", cdb[0],
 				core_scsi3_pr_dump_type(pr_reg_type));
 
 			return 0;
 		}
+       } else if (we && registered_nexus) {
+               /*
+                * Reads are allowed for Write Exclusive locks
+                * from all registrants.
+                */
+               if (cmd->data_direction == DMA_FROM_DEVICE) {
+                       pr_debug("Allowing READ CDB: 0x%02x for %s"
+                               " reservation\n", cdb[0],
+                               core_scsi3_pr_dump_type(pr_reg_type));
+
+                       return 0;
+               }
 	}
 	pr_debug("%s Conflict for %sregistered nexus %s CDB: 0x%2x"
 		" for %s reservation\n", transport_dump_cmd_direction(cmd),
@@ -596,14 +618,6 @@ static struct t10_pr_registration *__core_scsi3_do_alloc_registration(
 		return NULL;
 	}
 
-	pr_reg->pr_aptpl_buf = kzalloc(dev->t10_pr.pr_aptpl_buf_len,
-					GFP_ATOMIC);
-	if (!pr_reg->pr_aptpl_buf) {
-		pr_err("Unable to allocate pr_reg->pr_aptpl_buf\n");
-		kmem_cache_free(t10_pr_reg_cache, pr_reg);
-		return NULL;
-	}
-
 	INIT_LIST_HEAD(&pr_reg->pr_reg_list);
 	INIT_LIST_HEAD(&pr_reg->pr_reg_abort_list);
 	INIT_LIST_HEAD(&pr_reg->pr_reg_aptpl_list);
@@ -681,7 +695,7 @@ static struct t10_pr_registration *__core_scsi3_alloc_registration(
 					alua_port_list) {
 			/*
 			 * This pointer will be NULL for demo mode MappedLUNs
-			 * that have not been make explict via a ConfigFS
+			 * that have not been make explicit via a ConfigFS
 			 * MappedLUN group for the SCSI Initiator Node ACL.
 			 */
 			if (!deve_tmp->se_lun_acl)
@@ -794,7 +808,6 @@ int core_scsi3_alloc_aptpl_registration(
 		pr_err("Unable to allocate struct t10_pr_registration\n");
 		return -ENOMEM;
 	}
-	pr_reg->pr_aptpl_buf = kzalloc(pr_tmpl->pr_aptpl_buf_len, GFP_KERNEL);
 
 	INIT_LIST_HEAD(&pr_reg->pr_reg_list);
 	INIT_LIST_HEAD(&pr_reg->pr_reg_abort_list);
@@ -848,11 +861,9 @@ static void core_scsi3_aptpl_reserve(
 	struct t10_pr_registration *pr_reg)
 {
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 	spin_lock(&dev->dev_reservation_lock);
 	dev->dev_pr_res_holder = pr_reg;
@@ -865,11 +876,11 @@ static void core_scsi3_aptpl_reserve(
 		(pr_reg->pr_reg_all_tg_pt) ? 1 : 0);
 	pr_debug("SPC-3 PR [%s] RESERVE Node: %s%s\n",
 		tpg->se_tpg_tfo->get_fabric_name(), node_acl->initiatorname,
-		(prf_isid) ? &i_buf[0] : "");
+		i_buf);
 }
 
 static void __core_scsi3_add_registration(struct se_device *, struct se_node_acl *,
-				struct t10_pr_registration *, int, int);
+				struct t10_pr_registration *, enum register_type, int);
 
 static int __core_scsi3_check_aptpl_registration(
 	struct se_device *dev,
@@ -945,10 +956,10 @@ int core_scsi3_check_aptpl_registration(
 	struct se_device *dev,
 	struct se_portal_group *tpg,
 	struct se_lun *lun,
-	struct se_lun_acl *lun_acl)
+	struct se_node_acl *nacl,
+	u32 mapped_lun)
 {
-	struct se_node_acl *nacl = lun_acl->se_lun_nacl;
-	struct se_dev_entry *deve = nacl->device_list[lun_acl->mapped_lun];
+	struct se_dev_entry *deve = nacl->device_list[mapped_lun];
 
 	if (dev->dev_reservation_flags & DRF_SPC2_RESERVATIONS)
 		return 0;
@@ -962,21 +973,19 @@ static void __core_scsi3_dump_registration(
 	struct se_device *dev,
 	struct se_node_acl *nacl,
 	struct t10_pr_registration *pr_reg,
-	int register_type)
+	enum register_type register_type)
 {
 	struct se_portal_group *se_tpg = nacl->se_tpg;
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
 
 	memset(&i_buf[0], 0, PR_REG_ISID_ID_LEN);
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 	pr_debug("SPC-3 PR [%s] Service Action: REGISTER%s Initiator"
-		" Node: %s%s\n", tfo->get_fabric_name(), (register_type == 2) ?
-		"_AND_MOVE" : (register_type == 1) ?
+		" Node: %s%s\n", tfo->get_fabric_name(), (register_type == REGISTER_AND_MOVE) ?
+		"_AND_MOVE" : (register_type == REGISTER_AND_IGNORE_EXISTING_KEY) ?
 		"_AND_IGNORE_EXISTING_KEY" : "", nacl->initiatorname,
-		(prf_isid) ? i_buf : "");
+		i_buf);
 	pr_debug("SPC-3 PR [%s] registration on Target Port: %s,0x%04x\n",
 		 tfo->get_fabric_name(), tfo->tpg_get_wwn(se_tpg),
 		tfo->tpg_get_tag(se_tpg));
@@ -998,7 +1007,7 @@ static void __core_scsi3_add_registration(
 	struct se_device *dev,
 	struct se_node_acl *nacl,
 	struct t10_pr_registration *pr_reg,
-	int register_type,
+	enum register_type register_type,
 	int register_move)
 {
 	struct target_core_fabric_ops *tfo = nacl->se_tpg->se_tpg_tfo;
@@ -1064,7 +1073,7 @@ static int core_scsi3_alloc_registration(
 	u64 sa_res_key,
 	int all_tg_pt,
 	int aptpl,
-	int register_type,
+	enum register_type register_type,
 	int register_move)
 {
 	struct t10_pr_registration *pr_reg;
@@ -1161,7 +1170,7 @@ static void core_scsi3_put_pr_reg(struct t10_pr_registration *pr_reg)
 	smp_mb__after_atomic_dec();
 }
 
-static int core_scsi3_check_implict_release(
+static int core_scsi3_check_implicit_release(
 	struct se_device *dev,
 	struct t10_pr_registration *pr_reg)
 {
@@ -1177,7 +1186,7 @@ static int core_scsi3_check_implict_release(
 	}
 	if (pr_res_holder == pr_reg) {
 		/*
-		 * Perform an implict RELEASE if the registration that
+		 * Perform an implicit RELEASE if the registration that
 		 * is being released is holding the reservation.
 		 *
 		 * From spc4r17, section 5.7.11.1:
@@ -1189,13 +1198,13 @@ static int core_scsi3_check_implict_release(
 		 *    service action with the SERVICE ACTION RESERVATION KEY
 		 *    field set to zero (see 5.7.11.3).
 		 */
-		__core_scsi3_complete_pro_release(dev, nacl, pr_reg, 0);
+		__core_scsi3_complete_pro_release(dev, nacl, pr_reg, 0, 1);
 		ret = 1;
 		/*
 		 * For 'All Registrants' reservation types, all existing
 		 * registrations are still processed as reservation holders
 		 * in core_scsi3_pr_seq_non_holder() after the initial
-		 * reservation holder is implictly released here.
+		 * reservation holder is implicitly released here.
 		 */
 	} else if (pr_reg->pr_reg_all_tg_pt &&
 		  (!strcmp(pr_res_holder->pr_reg_nacl->initiatorname,
@@ -1225,15 +1234,14 @@ static void __core_scsi3_free_registration(
 			pr_reg->pr_reg_nacl->se_tpg->se_tpg_tfo;
 	struct t10_reservation *pr_tmpl = &dev->t10_pr;
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 	pr_reg->pr_reg_deve->def_pr_registered = 0;
 	pr_reg->pr_reg_deve->pr_res_key = 0;
-	list_del(&pr_reg->pr_reg_list);
+	if (!list_empty(&pr_reg->pr_reg_list))
+		list_del(&pr_reg->pr_reg_list);
 	/*
 	 * Caller accessing *pr_reg using core_scsi3_locate_pr_reg(),
 	 * so call core_scsi3_put_pr_reg() to decrement our reference.
@@ -1257,7 +1265,7 @@ static void __core_scsi3_free_registration(
 	pr_debug("SPC-3 PR [%s] Service Action: UNREGISTER Initiator"
 		" Node: %s%s\n", tfo->get_fabric_name(),
 		pr_reg->pr_reg_nacl->initiatorname,
-		(prf_isid) ? &i_buf[0] : "");
+		i_buf);
 	pr_debug("SPC-3 PR [%s] for %s TCM Subsystem %s Object Target"
 		" Port(s)\n", tfo->get_fabric_name(),
 		(pr_reg->pr_reg_all_tg_pt) ? "ALL" : "SINGLE",
@@ -1269,7 +1277,6 @@ static void __core_scsi3_free_registration(
 	if (!preempt_and_abort_list) {
 		pr_reg->pr_reg_deve = NULL;
 		pr_reg->pr_reg_nacl = NULL;
-		kfree(pr_reg->pr_aptpl_buf);
 		kmem_cache_free(t10_pr_reg_cache, pr_reg);
 		return;
 	}
@@ -1286,6 +1293,7 @@ void core_scsi3_free_pr_reg_from_nacl(
 {
 	struct t10_reservation *pr_tmpl = &dev->t10_pr;
 	struct t10_pr_registration *pr_reg, *pr_reg_tmp, *pr_res_holder;
+	bool free_reg = false;
 	/*
 	 * If the passed se_node_acl matches the reservation holder,
 	 * release the reservation.
@@ -1293,13 +1301,18 @@ void core_scsi3_free_pr_reg_from_nacl(
 	spin_lock(&dev->dev_reservation_lock);
 	pr_res_holder = dev->dev_pr_res_holder;
 	if ((pr_res_holder != NULL) &&
-	    (pr_res_holder->pr_reg_nacl == nacl))
-		__core_scsi3_complete_pro_release(dev, nacl, pr_res_holder, 0);
+	    (pr_res_holder->pr_reg_nacl == nacl)) {
+		__core_scsi3_complete_pro_release(dev, nacl, pr_res_holder, 0, 1);
+		free_reg = true;
+	}
 	spin_unlock(&dev->dev_reservation_lock);
 	/*
 	 * Release any registration associated with the struct se_node_acl.
 	 */
 	spin_lock(&pr_tmpl->registration_lock);
+	if (pr_res_holder && free_reg)
+		__core_scsi3_free_registration(dev, pr_res_holder, NULL, 0);
+
 	list_for_each_entry_safe(pr_reg, pr_reg_tmp,
 			&pr_tmpl->registration_list, pr_reg_list) {
 
@@ -1322,7 +1335,7 @@ void core_scsi3_free_all_registrations(
 	if (pr_res_holder != NULL) {
 		struct se_node_acl *pr_res_nacl = pr_res_holder->pr_reg_nacl;
 		__core_scsi3_complete_pro_release(dev, pr_res_nacl,
-				pr_res_holder, 0);
+						  pr_res_holder, 0, 0);
 	}
 	spin_unlock(&dev->dev_reservation_lock);
 
@@ -1338,7 +1351,6 @@ void core_scsi3_free_all_registrations(
 	list_for_each_entry_safe(pr_reg, pr_reg_tmp, &pr_tmpl->aptpl_reg_list,
 				pr_reg_aptpl_list) {
 		list_del(&pr_reg->pr_reg_aptpl_list);
-		kfree(pr_reg->pr_aptpl_buf);
 		kmem_cache_free(t10_pr_reg_cache, pr_reg);
 	}
 	spin_unlock(&pr_tmpl->aptpl_reg_lock);
@@ -1453,7 +1465,7 @@ core_scsi3_decode_spec_i_port(
 	char *iport_ptr = NULL, dest_iport[64], i_buf[PR_REG_ISID_ID_LEN];
 	sense_reason_t ret;
 	u32 tpdl, tid_len = 0;
-	int dest_local_nexus, prf_isid;
+	int dest_local_nexus;
 	u32 dest_rtpi = 0;
 
 	memset(dest_iport, 0, 64);
@@ -1764,8 +1776,7 @@ core_scsi3_decode_spec_i_port(
 		kfree(tidh);
 
 		memset(i_buf, 0, PR_REG_ISID_ID_LEN);
-		prf_isid = core_pr_dump_initiator_port(dest_pr_reg, &i_buf[0],
-						PR_REG_ISID_ID_LEN);
+		core_pr_dump_initiator_port(dest_pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 		__core_scsi3_add_registration(cmd->se_dev, dest_node_acl,
 					dest_pr_reg, 0, 0);
@@ -1773,8 +1784,7 @@ core_scsi3_decode_spec_i_port(
 		pr_debug("SPC-3 PR [%s] SPEC_I_PT: Successfully"
 			" registered Transport ID for Node: %s%s Mapped LUN:"
 			" %u\n", dest_tpg->se_tpg_tfo->get_fabric_name(),
-			dest_node_acl->initiatorname, (prf_isid) ?
-			&i_buf[0] : "", dest_se_deve->mapped_lun);
+			dest_node_acl->initiatorname, i_buf, dest_se_deve->mapped_lun);
 
 		if (dest_local_nexus)
 			continue;
@@ -1813,7 +1823,6 @@ out:
 			kmem_cache_free(t10_pr_reg_cache, pr_reg_tmp);
 		}
 
-		kfree(dest_pr_reg->pr_aptpl_buf);
 		kmem_cache_free(t10_pr_reg_cache, dest_pr_reg);
 
 		if (dest_local_nexus)
@@ -1826,14 +1835,10 @@ out:
 	return ret;
 }
 
-/*
- * Called with struct se_device->dev_reservation_lock held
- */
-static int __core_scsi3_update_aptpl_buf(
+static int core_scsi3_update_aptpl_buf(
 	struct se_device *dev,
 	unsigned char *buf,
-	u32 pr_aptpl_buf_len,
-	int clear_aptpl_metadata)
+	u32 pr_aptpl_buf_len)
 {
 	struct se_lun *lun;
 	struct se_portal_group *tpg;
@@ -1841,20 +1846,13 @@ static int __core_scsi3_update_aptpl_buf(
 	unsigned char tmp[512], isid_buf[32];
 	ssize_t len = 0;
 	int reg_count = 0;
+	int ret = 0;
 
-	memset(buf, 0, pr_aptpl_buf_len);
-	/*
-	 * Called to clear metadata once APTPL has been deactivated.
-	 */
-	if (clear_aptpl_metadata) {
-		snprintf(buf, pr_aptpl_buf_len,
-				"No Registrations or Reservations\n");
-		return 0;
-	}
+	spin_lock(&dev->dev_reservation_lock);
+	spin_lock(&dev->t10_pr.registration_lock);
 	/*
 	 * Walk the registration list..
 	 */
-	spin_lock(&dev->t10_pr.registration_lock);
 	list_for_each_entry(pr_reg, &dev->t10_pr.registration_list,
 			pr_reg_list) {
 
@@ -1898,10 +1896,10 @@ static int __core_scsi3_update_aptpl_buf(
 		}
 
 		if ((len + strlen(tmp) >= pr_aptpl_buf_len)) {
-			pr_err("Unable to update renaming"
-				" APTPL metadata\n");
-			spin_unlock(&dev->t10_pr.registration_lock);
-			return -EMSGSIZE;
+			pr_err("Unable to update renaming APTPL metadata,"
+			       " reallocating larger buffer\n");
+			ret = -EMSGSIZE;
+			goto out;
 		}
 		len += sprintf(buf+len, "%s", tmp);
 
@@ -1916,50 +1914,34 @@ static int __core_scsi3_update_aptpl_buf(
 			lun->lun_sep->sep_rtpi, lun->unpacked_lun, reg_count);
 
 		if ((len + strlen(tmp) >= pr_aptpl_buf_len)) {
-			pr_err("Unable to update renaming"
-				" APTPL metadata\n");
-			spin_unlock(&dev->t10_pr.registration_lock);
-			return -EMSGSIZE;
+			pr_err("Unable to update renaming APTPL metadata,"
+			       " reallocating larger buffer\n");
+			ret = -EMSGSIZE;
+			goto out;
 		}
 		len += sprintf(buf+len, "%s", tmp);
 		reg_count++;
 	}
-	spin_unlock(&dev->t10_pr.registration_lock);
 
 	if (!reg_count)
 		len += sprintf(buf+len, "No Registrations or Reservations");
 
-	return 0;
-}
-
-static int core_scsi3_update_aptpl_buf(
-	struct se_device *dev,
-	unsigned char *buf,
-	u32 pr_aptpl_buf_len,
-	int clear_aptpl_metadata)
-{
-	int ret;
-
-	spin_lock(&dev->dev_reservation_lock);
-	ret = __core_scsi3_update_aptpl_buf(dev, buf, pr_aptpl_buf_len,
-				clear_aptpl_metadata);
+out:
+	spin_unlock(&dev->t10_pr.registration_lock);
 	spin_unlock(&dev->dev_reservation_lock);
 
 	return ret;
 }
 
-/*
- * Called with struct se_device->aptpl_file_mutex held
- */
 static int __core_scsi3_write_aptpl_to_file(
 	struct se_device *dev,
-	unsigned char *buf,
-	u32 pr_aptpl_buf_len)
+	unsigned char *buf)
 {
 	struct t10_wwn *wwn = &dev->t10_wwn;
 	struct file *file;
 	int flags = O_RDWR | O_CREAT | O_TRUNC;
 	char path[512];
+	u32 pr_aptpl_buf_len;
 	int ret;
 
 	memset(path, 0, 512);
@@ -1978,8 +1960,7 @@ static int __core_scsi3_write_aptpl_to_file(
 		return PTR_ERR(file);
 	}
 
-	if (!pr_aptpl_buf_len)
-		pr_aptpl_buf_len = (strlen(&buf[0]) + 1); /* Add extra for NULL */
+	pr_aptpl_buf_len = (strlen(buf) + 1); /* Add extra for NULL */
 
 	ret = kernel_write(file, buf, pr_aptpl_buf_len, 0);
 
@@ -1990,57 +1971,62 @@ static int __core_scsi3_write_aptpl_to_file(
 	return (ret < 0) ? -EIO : 0;
 }
 
-static int
-core_scsi3_update_and_write_aptpl(struct se_device *dev, unsigned char *in_buf,
-		u32 in_pr_aptpl_buf_len)
+/*
+ * Clear the APTPL metadata if APTPL has been disabled, otherwise
+ * write out the updated metadata to struct file for this SCSI device.
+ */
+static sense_reason_t core_scsi3_update_and_write_aptpl(struct se_device *dev, bool aptpl)
 {
-	unsigned char null_buf[64], *buf;
-	u32 pr_aptpl_buf_len;
-	int clear_aptpl_metadata = 0;
-	int ret;
+	unsigned char *buf;
+	int rc, len = PR_APTPL_BUF_LEN;
 
-	/*
-	 * Can be called with a NULL pointer from PROUT service action CLEAR
-	 */
-	if (!in_buf) {
-		memset(null_buf, 0, 64);
-		buf = &null_buf[0];
-		/*
-		 * This will clear the APTPL metadata to:
-		 * "No Registrations or Reservations" status
-		 */
-		pr_aptpl_buf_len = 64;
-		clear_aptpl_metadata = 1;
-	} else {
-		buf = in_buf;
-		pr_aptpl_buf_len = in_pr_aptpl_buf_len;
+	if (!aptpl) {
+		char *null_buf = "No Registrations or Reservations\n";
+
+		rc = __core_scsi3_write_aptpl_to_file(dev, null_buf);
+		dev->t10_pr.pr_aptpl_active = 0;
+		pr_debug("SPC-3 PR: Set APTPL Bit Deactivated\n");
+
+		if (rc)
+			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+
+		return 0;
 	}
+retry:
+	buf = vzalloc(len);
+	if (!buf)
+		return TCM_OUT_OF_RESOURCES;
 
-	ret = core_scsi3_update_aptpl_buf(dev, buf, pr_aptpl_buf_len,
-				clear_aptpl_metadata);
-	if (ret != 0)
-		return ret;
+	rc = core_scsi3_update_aptpl_buf(dev, buf, len);
+	if (rc < 0) {
+		vfree(buf);
+		len *= 2;
+		goto retry;
+	}
 
-	/*
-	 * __core_scsi3_write_aptpl_to_file() will call strlen()
-	 * on the passed buf to determine pr_aptpl_buf_len.
-	 */
-	return __core_scsi3_write_aptpl_to_file(dev, buf, 0);
+	rc = __core_scsi3_write_aptpl_to_file(dev, buf);
+	if (rc != 0) {
+		pr_err("SPC-3 PR: Could not update APTPL\n");
+		vfree(buf);
+		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
+	dev->t10_pr.pr_aptpl_active = 1;
+	vfree(buf);
+	pr_debug("SPC-3 PR: Set APTPL Bit Activated\n");
+	return 0;
 }
 
 static sense_reason_t
 core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
-		int aptpl, int all_tg_pt, int spec_i_pt, int ignore_key)
+		bool aptpl, bool all_tg_pt, bool spec_i_pt, enum register_type register_type)
 {
 	struct se_session *se_sess = cmd->se_sess;
 	struct se_device *dev = cmd->se_dev;
 	struct se_dev_entry *se_deve;
 	struct se_lun *se_lun = cmd->se_lun;
 	struct se_portal_group *se_tpg;
-	struct t10_pr_registration *pr_reg, *pr_reg_p, *pr_reg_tmp, *pr_reg_e;
+	struct t10_pr_registration *pr_reg, *pr_reg_p, *pr_reg_tmp;
 	struct t10_reservation *pr_tmpl = &dev->t10_pr;
-	/* Used for APTPL metadata w/ UNREGISTER */
-	unsigned char *pr_aptpl_buf = NULL;
 	unsigned char isid_buf[PR_REG_ISID_LEN], *isid_ptr = NULL;
 	sense_reason_t ret = TCM_NO_SENSE;
 	int pr_holder = 0, type;
@@ -2061,8 +2047,8 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 	/*
 	 * Follow logic from spc4r17 Section 5.7.7, Register Behaviors Table 47
 	 */
-	pr_reg_e = core_scsi3_locate_pr_reg(dev, se_sess->se_node_acl, se_sess);
-	if (!pr_reg_e) {
+	pr_reg = core_scsi3_locate_pr_reg(dev, se_sess->se_node_acl, se_sess);
+	if (!pr_reg) {
 		if (res_key) {
 			pr_warn("SPC-3 PR: Reservation Key non-zero"
 				" for SA REGISTER, returning CONFLICT\n");
@@ -2083,7 +2069,7 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 			if (core_scsi3_alloc_registration(cmd->se_dev,
 					se_sess->se_node_acl, se_deve, isid_ptr,
 					sa_res_key, all_tg_pt, aptpl,
-					ignore_key, 0)) {
+					register_type, 0)) {
 				pr_err("Unable to allocate"
 					" struct t10_pr_registration\n");
 				return TCM_INVALID_PARAMETER_LIST;
@@ -2102,97 +2088,69 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 			if (ret != 0)
 				return ret;
 		}
-		/*
-		 * Nothing left to do for the APTPL=0 case.
-		 */
-		if (!aptpl) {
-			pr_tmpl->pr_aptpl_active = 0;
-			core_scsi3_update_and_write_aptpl(cmd->se_dev, NULL, 0);
-			pr_debug("SPC-3 PR: Set APTPL Bit Deactivated for"
-					" REGISTER\n");
-			return 0;
-		}
-		/*
-		 * Locate the newly allocated local I_T Nexus *pr_reg, and
-		 * update the APTPL metadata information using its
-		 * preallocated *pr_reg->pr_aptpl_buf.
-		 */
-		pr_reg = core_scsi3_locate_pr_reg(cmd->se_dev,
-				se_sess->se_node_acl, se_sess);
 
-		if (core_scsi3_update_and_write_aptpl(cmd->se_dev,
-				&pr_reg->pr_aptpl_buf[0],
-				pr_tmpl->pr_aptpl_buf_len)) {
-			pr_tmpl->pr_aptpl_active = 1;
-			pr_debug("SPC-3 PR: Set APTPL Bit Activated for REGISTER\n");
-		}
-
-		goto out_put_pr_reg;
+		return core_scsi3_update_and_write_aptpl(dev, aptpl);
 	}
 
-	/*
-	 * Locate the existing *pr_reg via struct se_node_acl pointers
-	 */
-	pr_reg = pr_reg_e;
-	type = pr_reg->pr_res_type;
-
-	if (!ignore_key) {
-		if (res_key != pr_reg->pr_res_key) {
-			pr_err("SPC-3 PR REGISTER: Received"
-				" res_key: 0x%016Lx does not match"
-				" existing SA REGISTER res_key:"
-				" 0x%016Lx\n", res_key,
-				pr_reg->pr_res_key);
-			ret = TCM_RESERVATION_CONFLICT;
-			goto out_put_pr_reg;
-		}
+	/* ok, existing registration */
+
+	if ((register_type == REGISTER) && (res_key != pr_reg->pr_res_key)) {
+		pr_err("SPC-3 PR REGISTER: Received"
+		       " res_key: 0x%016Lx does not match"
+		       " existing SA REGISTER res_key:"
+		       " 0x%016Lx\n", res_key,
+		       pr_reg->pr_res_key);
+		ret = TCM_RESERVATION_CONFLICT;
+		goto out;
 	}
 
 	if (spec_i_pt) {
-		pr_err("SPC-3 PR UNREGISTER: SPEC_I_PT"
-			" set while sa_res_key=0\n");
+		pr_err("SPC-3 PR REGISTER: SPEC_I_PT"
+			" set on a registered nexus\n");
 		ret = TCM_INVALID_PARAMETER_LIST;
-		goto out_put_pr_reg;
+		goto out;
 	}
 
 	/*
 	 * An existing ALL_TG_PT=1 registration being released
 	 * must also set ALL_TG_PT=1 in the incoming PROUT.
 	 */
-	if (pr_reg->pr_reg_all_tg_pt && !(all_tg_pt)) {
-		pr_err("SPC-3 PR UNREGISTER: ALL_TG_PT=1"
+	if (pr_reg->pr_reg_all_tg_pt && !all_tg_pt) {
+		pr_err("SPC-3 PR REGISTER: ALL_TG_PT=1"
 			" registration exists, but ALL_TG_PT=1 bit not"
 			" present in received PROUT\n");
 		ret = TCM_INVALID_CDB_FIELD;
-		goto out_put_pr_reg;
+		goto out;
 	}
 
 	/*
-	 * Allocate APTPL metadata buffer used for UNREGISTER ops
+	 * sa_res_key=1 Change Reservation Key for registered I_T Nexus.
 	 */
-	if (aptpl) {
-		pr_aptpl_buf = kzalloc(pr_tmpl->pr_aptpl_buf_len,
-					GFP_KERNEL);
-		if (!pr_aptpl_buf) {
-			pr_err("Unable to allocate"
-				" pr_aptpl_buf\n");
-			ret = TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
-			goto out_put_pr_reg;
-		}
-	}
+	if (sa_res_key) {
+		/*
+		 * Increment PRgeneration counter for struct se_device"
+		 * upon a successful REGISTER, see spc4r17 section 6.3.2
+		 * READ_KEYS service action.
+		 */
+		pr_reg->pr_res_generation = core_scsi3_pr_generation(cmd->se_dev);
+		pr_reg->pr_res_key = sa_res_key;
+		pr_debug("SPC-3 PR [%s] REGISTER%s: Changed Reservation"
+			 " Key for %s to: 0x%016Lx PRgeneration:"
+			 " 0x%08x\n", cmd->se_tfo->get_fabric_name(),
+			 (register_type == REGISTER_AND_IGNORE_EXISTING_KEY) ? "_AND_IGNORE_EXISTING_KEY" : "",
+			 pr_reg->pr_reg_nacl->initiatorname,
+			 pr_reg->pr_res_key, pr_reg->pr_res_generation);
 
-	/*
-	 * sa_res_key=0 Unregister Reservation Key for registered I_T
-	 * Nexus sa_res_key=1 Change Reservation Key for registered I_T
-	 * Nexus.
-	 */
-	if (!sa_res_key) {
-		pr_holder = core_scsi3_check_implict_release(
-				cmd->se_dev, pr_reg);
+	} else {
+		/*
+		 * sa_res_key=0 Unregister Reservation Key for registered I_T Nexus.
+		 */
+		type = pr_reg->pr_res_type;
+		pr_holder = core_scsi3_check_implicit_release(cmd->se_dev,
+							      pr_reg);
 		if (pr_holder < 0) {
-			kfree(pr_aptpl_buf);
 			ret = TCM_RESERVATION_CONFLICT;
-			goto out_put_pr_reg;
+			goto out;
 		}
 
 		spin_lock(&pr_tmpl->registration_lock);
@@ -2224,6 +2182,7 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 		 * Release the calling I_T Nexus registration now..
 		 */
 		__core_scsi3_free_registration(cmd->se_dev, pr_reg, NULL, 1);
+		pr_reg = NULL;
 
 		/*
 		 * From spc4r17, section 5.7.11.3 Unregistering
@@ -2237,8 +2196,8 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 		 * RESERVATIONS RELEASED.
 		 */
 		if (pr_holder &&
-		   (type == PR_TYPE_WRITE_EXCLUSIVE_REGONLY ||
-		    type == PR_TYPE_EXCLUSIVE_ACCESS_REGONLY)) {
+		    (type == PR_TYPE_WRITE_EXCLUSIVE_REGONLY ||
+		     type == PR_TYPE_EXCLUSIVE_ACCESS_REGONLY)) {
 			list_for_each_entry(pr_reg_p,
 					&pr_tmpl->registration_list,
 					pr_reg_list) {
@@ -2250,61 +2209,15 @@ core_scsi3_emulate_pro_register(struct se_cmd *cmd, u64 res_key, u64 sa_res_key,
 					ASCQ_2AH_RESERVATIONS_RELEASED);
 			}
 		}
-		spin_unlock(&pr_tmpl->registration_lock);
-
-		if (!aptpl) {
-			pr_tmpl->pr_aptpl_active = 0;
-			core_scsi3_update_and_write_aptpl(dev, NULL, 0);
-			pr_debug("SPC-3 PR: Set APTPL Bit Deactivated"
-					" for UNREGISTER\n");
-			return 0;
-		}
 
-		if (!core_scsi3_update_and_write_aptpl(dev, &pr_aptpl_buf[0],
-				pr_tmpl->pr_aptpl_buf_len)) {
-			pr_tmpl->pr_aptpl_active = 1;
-			pr_debug("SPC-3 PR: Set APTPL Bit Activated"
-					" for UNREGISTER\n");
-		}
-
-		goto out_free_aptpl_buf;
-	}
-
-	/*
-	 * Increment PRgeneration counter for struct se_device"
-	 * upon a successful REGISTER, see spc4r17 section 6.3.2
-	 * READ_KEYS service action.
-	 */
-	pr_reg->pr_res_generation = core_scsi3_pr_generation(cmd->se_dev);
-	pr_reg->pr_res_key = sa_res_key;
-	pr_debug("SPC-3 PR [%s] REGISTER%s: Changed Reservation"
-		" Key for %s to: 0x%016Lx PRgeneration:"
-		" 0x%08x\n", cmd->se_tfo->get_fabric_name(),
-		(ignore_key) ? "_AND_IGNORE_EXISTING_KEY" : "",
-		pr_reg->pr_reg_nacl->initiatorname,
-		pr_reg->pr_res_key, pr_reg->pr_res_generation);
-
-	if (!aptpl) {
-		pr_tmpl->pr_aptpl_active = 0;
-		core_scsi3_update_and_write_aptpl(dev, NULL, 0);
-		pr_debug("SPC-3 PR: Set APTPL Bit Deactivated"
-				" for REGISTER\n");
-		ret = 0;
-		goto out_put_pr_reg;
+		spin_unlock(&pr_tmpl->registration_lock);
 	}
 
-	if (!core_scsi3_update_and_write_aptpl(dev, &pr_aptpl_buf[0],
-						pr_tmpl->pr_aptpl_buf_len)) {
-		pr_tmpl->pr_aptpl_active = 1;
-		pr_debug("SPC-3 PR: Set APTPL Bit Activated"
-			" for REGISTER\n");
-	}
+	ret = core_scsi3_update_and_write_aptpl(dev, aptpl);
 
-out_free_aptpl_buf:
-	kfree(pr_aptpl_buf);
-	ret = 0;
-out_put_pr_reg:
-	core_scsi3_put_pr_reg(pr_reg);
+out:
+	if (pr_reg)
+		core_scsi3_put_pr_reg(pr_reg);
 	return ret;
 }
 
@@ -2340,7 +2253,6 @@ core_scsi3_pro_reserve(struct se_cmd *cmd, int type, int scope, u64 res_key)
 	struct t10_reservation *pr_tmpl = &dev->t10_pr;
 	char i_buf[PR_REG_ISID_ID_LEN];
 	sense_reason_t ret;
-	int prf_isid;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
 
@@ -2397,6 +2309,7 @@ core_scsi3_pro_reserve(struct se_cmd *cmd, int type, int scope, u64 res_key)
 	spin_lock(&dev->dev_reservation_lock);
 	pr_res_holder = dev->dev_pr_res_holder;
 	if (pr_res_holder) {
+		int pr_res_type = pr_res_holder->pr_res_type;
 		/*
 		 * From spc4r17 Section 5.7.9: Reserving:
 		 *
@@ -2407,7 +2320,9 @@ core_scsi3_pro_reserve(struct se_cmd *cmd, int type, int scope, u64 res_key)
 		 * the logical unit, then the command shall be completed with
 		 * RESERVATION CONFLICT status.
 		 */
-		if (pr_res_holder != pr_reg) {
+		if ((pr_res_holder != pr_reg) &&
+		    (pr_res_type != PR_TYPE_WRITE_EXCLUSIVE_ALLREG) &&
+		    (pr_res_type != PR_TYPE_EXCLUSIVE_ACCESS_ALLREG)) {
 			struct se_node_acl *pr_res_nacl = pr_res_holder->pr_reg_nacl;
 			pr_err("SPC-3 PR: Attempted RESERVE from"
 				" [%s]: %s while reservation already held by"
@@ -2466,8 +2381,7 @@ core_scsi3_pro_reserve(struct se_cmd *cmd, int type, int scope, u64 res_key)
 	pr_reg->pr_res_type = type;
 	pr_reg->pr_res_holder = 1;
 	dev->dev_pr_res_holder = pr_reg;
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 
 	pr_debug("SPC-3 PR [%s] Service Action: RESERVE created new"
 		" reservation holder TYPE: %s ALL_TG_PT: %d\n",
@@ -2476,17 +2390,11 @@ core_scsi3_pro_reserve(struct se_cmd *cmd, int type, int scope, u64 res_key)
 	pr_debug("SPC-3 PR [%s] RESERVE Node: %s%s\n",
 			cmd->se_tfo->get_fabric_name(),
 			se_sess->se_node_acl->initiatorname,
-			(prf_isid) ? &i_buf[0] : "");
+			i_buf);
 	spin_unlock(&dev->dev_reservation_lock);
 
-	if (pr_tmpl->pr_aptpl_active) {
-		if (!core_scsi3_update_and_write_aptpl(cmd->se_dev,
-				&pr_reg->pr_aptpl_buf[0],
-				pr_tmpl->pr_aptpl_buf_len)) {
-			pr_debug("SPC-3 PR: Updated APTPL metadata"
-					" for RESERVE\n");
-		}
-	}
+	if (pr_tmpl->pr_aptpl_active)
+		core_scsi3_update_and_write_aptpl(cmd->se_dev, true);
 
 	ret = 0;
 out_put_pr_reg:
@@ -2520,28 +2428,62 @@ static void __core_scsi3_complete_pro_release(
 	struct se_device *dev,
 	struct se_node_acl *se_nacl,
 	struct t10_pr_registration *pr_reg,
-	int explict)
+	int explicit,
+	int unreg)
 {
 	struct target_core_fabric_ops *tfo = se_nacl->se_tpg->se_tpg_tfo;
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
+	int pr_res_type = 0, pr_res_scope = 0;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 	/*
 	 * Go ahead and release the current PR reservation holder.
+	 * If an All Registrants reservation is currently active and
+	 * a unregister operation is requested, replace the current
+	 * dev_pr_res_holder with another active registration.
 	 */
-	dev->dev_pr_res_holder = NULL;
+	if (dev->dev_pr_res_holder) {
+		pr_res_type = dev->dev_pr_res_holder->pr_res_type;
+		pr_res_scope = dev->dev_pr_res_holder->pr_res_scope;
+		dev->dev_pr_res_holder->pr_res_type = 0;
+		dev->dev_pr_res_holder->pr_res_scope = 0;
+		dev->dev_pr_res_holder->pr_res_holder = 0;
+		dev->dev_pr_res_holder = NULL;
+	}
+	if (!unreg)
+		goto out;
 
-	pr_debug("SPC-3 PR [%s] Service Action: %s RELEASE cleared"
-		" reservation holder TYPE: %s ALL_TG_PT: %d\n",
-		tfo->get_fabric_name(), (explict) ? "explict" : "implict",
-		core_scsi3_pr_dump_type(pr_reg->pr_res_type),
-		(pr_reg->pr_reg_all_tg_pt) ? 1 : 0);
+	spin_lock(&dev->t10_pr.registration_lock);
+	list_del_init(&pr_reg->pr_reg_list);
+	/*
+	 * If the I_T nexus is a reservation holder, the persistent reservation
+	 * is of an all registrants type, and the I_T nexus is the last remaining
+	 * registered I_T nexus, then the device server shall also release the
+	 * persistent reservation.
+	 */
+	if (!list_empty(&dev->t10_pr.registration_list) &&
+	    ((pr_res_type == PR_TYPE_WRITE_EXCLUSIVE_ALLREG) ||
+	     (pr_res_type == PR_TYPE_EXCLUSIVE_ACCESS_ALLREG))) {
+		dev->dev_pr_res_holder =
+			list_entry(dev->t10_pr.registration_list.next,
+				   struct t10_pr_registration, pr_reg_list);
+		dev->dev_pr_res_holder->pr_res_type = pr_res_type;
+		dev->dev_pr_res_holder->pr_res_scope = pr_res_scope;
+		dev->dev_pr_res_holder->pr_res_holder = 1;
+	}
+	spin_unlock(&dev->t10_pr.registration_lock);
+out:
+	if (!dev->dev_pr_res_holder) {
+		pr_debug("SPC-3 PR [%s] Service Action: %s RELEASE cleared"
+			" reservation holder TYPE: %s ALL_TG_PT: %d\n",
+			tfo->get_fabric_name(), (explicit) ? "explicit" :
+			"implicit", core_scsi3_pr_dump_type(pr_res_type),
+			(pr_reg->pr_reg_all_tg_pt) ? 1 : 0);
+	}
 	pr_debug("SPC-3 PR [%s] RELEASE Node: %s%s\n",
 		tfo->get_fabric_name(), se_nacl->initiatorname,
-		(prf_isid) ? &i_buf[0] : "");
+		i_buf);
 	/*
 	 * Clear TYPE and SCOPE for the next PROUT Service Action: RESERVE
 	 */
@@ -2669,7 +2611,7 @@ core_scsi3_emulate_pro_release(struct se_cmd *cmd, int type, int scope,
 	 *    server shall not establish a unit attention condition.
 	 */
 	__core_scsi3_complete_pro_release(dev, se_sess->se_node_acl,
-			pr_reg, 1);
+					  pr_reg, 1, 0);
 
 	spin_unlock(&dev->dev_reservation_lock);
 
@@ -2702,12 +2644,9 @@ core_scsi3_emulate_pro_release(struct se_cmd *cmd, int type, int scope,
 	spin_unlock(&pr_tmpl->registration_lock);
 
 write_aptpl:
-	if (pr_tmpl->pr_aptpl_active) {
-		if (!core_scsi3_update_and_write_aptpl(cmd->se_dev,
-			&pr_reg->pr_aptpl_buf[0], pr_tmpl->pr_aptpl_buf_len)) {
-			pr_debug("SPC-3 PR: Updated APTPL metadata for RELEASE\n");
-		}
-	}
+	if (pr_tmpl->pr_aptpl_active)
+		core_scsi3_update_and_write_aptpl(cmd->se_dev, true);
+
 out_put_pr_reg:
 	core_scsi3_put_pr_reg(pr_reg);
 	return ret;
@@ -2760,7 +2699,7 @@ core_scsi3_emulate_pro_clear(struct se_cmd *cmd, u64 res_key)
 	if (pr_res_holder) {
 		struct se_node_acl *pr_res_nacl = pr_res_holder->pr_reg_nacl;
 		__core_scsi3_complete_pro_release(dev, pr_res_nacl,
-			pr_res_holder, 0);
+						  pr_res_holder, 0, 0);
 	}
 	spin_unlock(&dev->dev_reservation_lock);
 	/*
@@ -2791,11 +2730,7 @@ core_scsi3_emulate_pro_clear(struct se_cmd *cmd, u64 res_key)
 	pr_debug("SPC-3 PR [%s] Service Action: CLEAR complete\n",
 		cmd->se_tfo->get_fabric_name());
 
-	if (pr_tmpl->pr_aptpl_active) {
-		core_scsi3_update_and_write_aptpl(cmd->se_dev, NULL, 0);
-		pr_debug("SPC-3 PR: Updated APTPL metadata"
-				" for CLEAR\n");
-	}
+	core_scsi3_update_and_write_aptpl(cmd->se_dev, false);
 
 	core_scsi3_pr_generation(dev);
 	return 0;
@@ -2810,22 +2745,20 @@ static void __core_scsi3_complete_pro_preempt(
 	struct list_head *preempt_and_abort_list,
 	int type,
 	int scope,
-	int abort)
+	enum preempt_type preempt_type)
 {
 	struct se_node_acl *nacl = pr_reg->pr_reg_nacl;
 	struct target_core_fabric_ops *tfo = nacl->se_tpg->se_tpg_tfo;
 	char i_buf[PR_REG_ISID_ID_LEN];
-	int prf_isid;
 
 	memset(i_buf, 0, PR_REG_ISID_ID_LEN);
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 	/*
-	 * Do an implict RELEASE of the existing reservation.
+	 * Do an implicit RELEASE of the existing reservation.
 	 */
 	if (dev->dev_pr_res_holder)
 		__core_scsi3_complete_pro_release(dev, nacl,
-				dev->dev_pr_res_holder, 0);
+						  dev->dev_pr_res_holder, 0, 0);
 
 	dev->dev_pr_res_holder = pr_reg;
 	pr_reg->pr_res_holder = 1;
@@ -2834,12 +2767,12 @@ static void __core_scsi3_complete_pro_preempt(
 
 	pr_debug("SPC-3 PR [%s] Service Action: PREEMPT%s created new"
 		" reservation holder TYPE: %s ALL_TG_PT: %d\n",
-		tfo->get_fabric_name(), (abort) ? "_AND_ABORT" : "",
+		tfo->get_fabric_name(), (preempt_type == PREEMPT_AND_ABORT) ? "_AND_ABORT" : "",
 		core_scsi3_pr_dump_type(type),
 		(pr_reg->pr_reg_all_tg_pt) ? 1 : 0);
 	pr_debug("SPC-3 PR [%s] PREEMPT%s from Node: %s%s\n",
-		tfo->get_fabric_name(), (abort) ? "_AND_ABORT" : "",
-		nacl->initiatorname, (prf_isid) ? &i_buf[0] : "");
+		tfo->get_fabric_name(), (preempt_type == PREEMPT_AND_ABORT) ? "_AND_ABORT" : "",
+		nacl->initiatorname, i_buf);
 	/*
 	 * For PREEMPT_AND_ABORT, add the preempting reservation's
 	 * struct t10_pr_registration to the list that will be compared
@@ -2869,14 +2802,13 @@ static void core_scsi3_release_preempt_and_abort(
 
 		pr_reg->pr_reg_deve = NULL;
 		pr_reg->pr_reg_nacl = NULL;
-		kfree(pr_reg->pr_aptpl_buf);
 		kmem_cache_free(t10_pr_reg_cache, pr_reg);
 	}
 }
 
 static sense_reason_t
 core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
-		u64 sa_res_key, int abort)
+		u64 sa_res_key, enum preempt_type preempt_type)
 {
 	struct se_device *dev = cmd->se_dev;
 	struct se_node_acl *pr_reg_nacl;
@@ -2896,7 +2828,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 	if (!pr_reg_n) {
 		pr_err("SPC-3 PR: Unable to locate"
 			" PR_REGISTERED *pr_reg for PREEMPT%s\n",
-			(abort) ? "_AND_ABORT" : "");
+			(preempt_type == PREEMPT_AND_ABORT) ? "_AND_ABORT" : "");
 		return TCM_RESERVATION_CONFLICT;
 	}
 	if (pr_reg_n->pr_res_key != res_key) {
@@ -2965,7 +2897,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 				pr_reg_nacl = pr_reg->pr_reg_nacl;
 				pr_res_mapped_lun = pr_reg->pr_res_mapped_lun;
 				__core_scsi3_free_registration(dev, pr_reg,
-					(abort) ? &preempt_and_abort_list :
+					(preempt_type == PREEMPT_AND_ABORT) ? &preempt_and_abort_list :
 						NULL, calling_it_nexus);
 				released_regs++;
 			} else {
@@ -2975,7 +2907,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 				 * 5.7.11.4 Preempting, Table 52 and Figure 7.
 				 *
 				 * For a ZERO SA Reservation key, release
-				 * all other registrations and do an implict
+				 * all other registrations and do an implicit
 				 * release of active persistent reservation.
 				 *
 				 * For a non-ZERO SA Reservation key, only
@@ -2993,7 +2925,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 				pr_reg_nacl = pr_reg->pr_reg_nacl;
 				pr_res_mapped_lun = pr_reg->pr_res_mapped_lun;
 				__core_scsi3_free_registration(dev, pr_reg,
-					(abort) ? &preempt_and_abort_list :
+					(preempt_type == PREEMPT_AND_ABORT) ? &preempt_and_abort_list :
 						NULL, 0);
 				released_regs++;
 			}
@@ -3022,24 +2954,17 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 		 */
 		if (pr_res_holder && all_reg && !(sa_res_key)) {
 			__core_scsi3_complete_pro_preempt(dev, pr_reg_n,
-				(abort) ? &preempt_and_abort_list : NULL,
-				type, scope, abort);
+				(preempt_type == PREEMPT_AND_ABORT) ? &preempt_and_abort_list : NULL,
+				type, scope, preempt_type);
 
-			if (abort)
+			if (preempt_type == PREEMPT_AND_ABORT)
 				core_scsi3_release_preempt_and_abort(
 					&preempt_and_abort_list, pr_reg_n);
 		}
 		spin_unlock(&dev->dev_reservation_lock);
 
-		if (pr_tmpl->pr_aptpl_active) {
-			if (!core_scsi3_update_and_write_aptpl(cmd->se_dev,
-					&pr_reg_n->pr_aptpl_buf[0],
-					pr_tmpl->pr_aptpl_buf_len)) {
-				pr_debug("SPC-3 PR: Updated APTPL"
-					" metadata for  PREEMPT%s\n", (abort) ?
-					"_AND_ABORT" : "");
-			}
-		}
+		if (pr_tmpl->pr_aptpl_active)
+			core_scsi3_update_and_write_aptpl(cmd->se_dev, true);
 
 		core_scsi3_put_pr_reg(pr_reg_n);
 		core_scsi3_pr_generation(cmd->se_dev);
@@ -3077,8 +3002,8 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 	 */
 	if (pr_reg_n != pr_res_holder)
 		__core_scsi3_complete_pro_release(dev,
-				pr_res_holder->pr_reg_nacl,
-				dev->dev_pr_res_holder, 0);
+						  pr_res_holder->pr_reg_nacl,
+						  dev->dev_pr_res_holder, 0, 0);
 	/*
 	 * b) Remove the registrations for all I_T nexuses identified
 	 *    by the SERVICE ACTION RESERVATION KEY field, except the
@@ -3103,7 +3028,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 		pr_reg_nacl = pr_reg->pr_reg_nacl;
 		pr_res_mapped_lun = pr_reg->pr_res_mapped_lun;
 		__core_scsi3_free_registration(dev, pr_reg,
-				(abort) ? &preempt_and_abort_list : NULL,
+				(preempt_type == PREEMPT_AND_ABORT) ? &preempt_and_abort_list : NULL,
 				calling_it_nexus);
 		/*
 		 * e) Establish a unit attention condition for the initiator
@@ -3120,8 +3045,8 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 	 *    I_T nexus using the contents of the SCOPE and TYPE fields;
 	 */
 	__core_scsi3_complete_pro_preempt(dev, pr_reg_n,
-			(abort) ? &preempt_and_abort_list : NULL,
-			type, scope, abort);
+			(preempt_type == PREEMPT_AND_ABORT) ? &preempt_and_abort_list : NULL,
+			type, scope, preempt_type);
 	/*
 	 * d) Process tasks as defined in 5.7.1;
 	 * e) See above..
@@ -3161,20 +3086,14 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 	 * been removed from the primary pr_reg list), except the
 	 * new persistent reservation holder, the calling Initiator Port.
 	 */
-	if (abort) {
+	if (preempt_type == PREEMPT_AND_ABORT) {
 		core_tmr_lun_reset(dev, NULL, &preempt_and_abort_list, cmd);
 		core_scsi3_release_preempt_and_abort(&preempt_and_abort_list,
 						pr_reg_n);
 	}
 
-	if (pr_tmpl->pr_aptpl_active) {
-		if (!core_scsi3_update_and_write_aptpl(cmd->se_dev,
-				&pr_reg_n->pr_aptpl_buf[0],
-				pr_tmpl->pr_aptpl_buf_len)) {
-			pr_debug("SPC-3 PR: Updated APTPL metadata for PREEMPT"
-				"%s\n", abort ? "_AND_ABORT" : "");
-		}
-	}
+	if (pr_tmpl->pr_aptpl_active)
+		core_scsi3_update_and_write_aptpl(cmd->se_dev, true);
 
 	core_scsi3_put_pr_reg(pr_reg_n);
 	core_scsi3_pr_generation(cmd->se_dev);
@@ -3183,7 +3102,7 @@ core_scsi3_pro_preempt(struct se_cmd *cmd, int type, int scope, u64 res_key,
 
 static sense_reason_t
 core_scsi3_emulate_pro_preempt(struct se_cmd *cmd, int type, int scope,
-		u64 res_key, u64 sa_res_key, int abort)
+		u64 res_key, u64 sa_res_key, enum preempt_type preempt_type)
 {
 	switch (type) {
 	case PR_TYPE_WRITE_EXCLUSIVE:
@@ -3193,10 +3112,10 @@ core_scsi3_emulate_pro_preempt(struct se_cmd *cmd, int type, int scope,
 	case PR_TYPE_WRITE_EXCLUSIVE_ALLREG:
 	case PR_TYPE_EXCLUSIVE_ACCESS_ALLREG:
 		return core_scsi3_pro_preempt(cmd, type, scope, res_key,
-					      sa_res_key, abort);
+					      sa_res_key, preempt_type);
 	default:
 		pr_err("SPC-3 PR: Unknown Service Action PREEMPT%s"
-			" Type: 0x%02x\n", (abort) ? "_AND_ABORT" : "", type);
+			" Type: 0x%02x\n", (preempt_type == PREEMPT_AND_ABORT) ? "_AND_ABORT" : "", type);
 		return TCM_INVALID_CDB_FIELD;
 	}
 }
@@ -3220,7 +3139,7 @@ core_scsi3_emulate_pro_register_and_move(struct se_cmd *cmd, u64 res_key,
 	unsigned char *initiator_str;
 	char *iport_ptr = NULL, dest_iport[64], i_buf[PR_REG_ISID_ID_LEN];
 	u32 tid_len, tmp_tid_len;
-	int new_reg = 0, type, scope, matching_iname, prf_isid;
+	int new_reg = 0, type, scope, matching_iname;
 	sense_reason_t ret;
 	unsigned short rtpi;
 	unsigned char proto_ident;
@@ -3554,7 +3473,7 @@ after_iport_check:
 	 *    holder (i.e., the I_T nexus on which the
 	 */
 	__core_scsi3_complete_pro_release(dev, pr_res_nacl,
-			dev->dev_pr_res_holder, 0);
+					  dev->dev_pr_res_holder, 0, 0);
 	/*
 	 * g) Move the persistent reservation to the specified I_T nexus using
 	 *    the same scope and type as the persistent reservation released in
@@ -3564,8 +3483,7 @@ after_iport_check:
 	dest_pr_reg->pr_res_holder = 1;
 	dest_pr_reg->pr_res_type = type;
 	pr_reg->pr_res_scope = scope;
-	prf_isid = core_pr_dump_initiator_port(pr_reg, &i_buf[0],
-				PR_REG_ISID_ID_LEN);
+	core_pr_dump_initiator_port(pr_reg, i_buf, PR_REG_ISID_ID_LEN);
 	/*
 	 * Increment PRGeneration for existing registrations..
 	 */
@@ -3581,7 +3499,7 @@ after_iport_check:
 	pr_debug("SPC-3 PR Successfully moved reservation from"
 		" %s Fabric Node: %s%s -> %s Fabric Node: %s %s\n",
 		tf_ops->get_fabric_name(), pr_reg_nacl->initiatorname,
-		(prf_isid) ? &i_buf[0] : "", dest_tf_ops->get_fabric_name(),
+		i_buf, dest_tf_ops->get_fabric_name(),
 		dest_node_acl->initiatorname, (iport_ptr != NULL) ?
 		iport_ptr : "");
 	/*
@@ -3602,24 +3520,7 @@ after_iport_check:
 	} else
 		core_scsi3_put_pr_reg(pr_reg);
 
-	/*
-	 * Clear the APTPL metadata if APTPL has been disabled, otherwise
-	 * write out the updated metadata to struct file for this SCSI device.
-	 */
-	if (!aptpl) {
-		pr_tmpl->pr_aptpl_active = 0;
-		core_scsi3_update_and_write_aptpl(cmd->se_dev, NULL, 0);
-		pr_debug("SPC-3 PR: Set APTPL Bit Deactivated for"
-				" REGISTER_AND_MOVE\n");
-	} else {
-		pr_tmpl->pr_aptpl_active = 1;
-		if (!core_scsi3_update_and_write_aptpl(cmd->se_dev,
-				&dest_pr_reg->pr_aptpl_buf[0],
-				pr_tmpl->pr_aptpl_buf_len)) {
-			pr_debug("SPC-3 PR: Set APTPL Bit Activated for"
-					" REGISTER_AND_MOVE\n");
-		}
-	}
+	core_scsi3_update_and_write_aptpl(cmd->se_dev, aptpl);
 
 	transport_kunmap_data_sg(cmd);
 
@@ -3752,7 +3653,7 @@ target_scsi3_emulate_pr_out(struct se_cmd *cmd)
 	switch (sa) {
 	case PRO_REGISTER:
 		ret = core_scsi3_emulate_pro_register(cmd,
-			res_key, sa_res_key, aptpl, all_tg_pt, spec_i_pt, 0);
+			res_key, sa_res_key, aptpl, all_tg_pt, spec_i_pt, REGISTER);
 		break;
 	case PRO_RESERVE:
 		ret = core_scsi3_emulate_pro_reserve(cmd, type, scope, res_key);
@@ -3765,15 +3666,15 @@ target_scsi3_emulate_pr_out(struct se_cmd *cmd)
 		break;
 	case PRO_PREEMPT:
 		ret = core_scsi3_emulate_pro_preempt(cmd, type, scope,
-					res_key, sa_res_key, 0);
+					res_key, sa_res_key, PREEMPT);
 		break;
 	case PRO_PREEMPT_AND_ABORT:
 		ret = core_scsi3_emulate_pro_preempt(cmd, type, scope,
-					res_key, sa_res_key, 1);
+					res_key, sa_res_key, PREEMPT_AND_ABORT);
 		break;
 	case PRO_REGISTER_AND_IGNORE_EXISTING_KEY:
 		ret = core_scsi3_emulate_pro_register(cmd,
-			0, sa_res_key, aptpl, all_tg_pt, spec_i_pt, 1);
+			0, sa_res_key, aptpl, all_tg_pt, spec_i_pt, REGISTER_AND_IGNORE_EXISTING_KEY);
 		break;
 	case PRO_REGISTER_AND_MOVE:
 		ret = core_scsi3_emulate_pro_register_and_move(cmd, res_key,
@@ -4012,7 +3913,8 @@ core_scsi3_pri_read_full_status(struct se_cmd *cmd)
 	unsigned char *buf;
 	u32 add_desc_len = 0, add_len = 0, desc_len, exp_desc_len;
 	u32 off = 8; /* off into first Full Status descriptor */
-	int format_code = 0;
+	int format_code = 0, pr_res_type = 0, pr_res_scope = 0;
+	bool all_reg = false;
 
 	if (cmd->data_length < 8) {
 		pr_err("PRIN SA READ_FULL_STATUS SCSI Data Length: %u"
@@ -4029,6 +3931,19 @@ core_scsi3_pri_read_full_status(struct se_cmd *cmd)
 	buf[2] = ((dev->t10_pr.pr_generation >> 8) & 0xff);
 	buf[3] = (dev->t10_pr.pr_generation & 0xff);
 
+	spin_lock(&dev->dev_reservation_lock);
+	if (dev->dev_pr_res_holder) {
+		struct t10_pr_registration *pr_holder = dev->dev_pr_res_holder;
+
+		if (pr_holder->pr_res_type == PR_TYPE_WRITE_EXCLUSIVE_ALLREG ||
+		    pr_holder->pr_res_type == PR_TYPE_EXCLUSIVE_ACCESS_ALLREG) {
+			all_reg = true;
+			pr_res_type = pr_holder->pr_res_type;
+			pr_res_scope = pr_holder->pr_res_scope;
+		}
+	}
+	spin_unlock(&dev->dev_reservation_lock);
+
 	spin_lock(&pr_tmpl->registration_lock);
 	list_for_each_entry_safe(pr_reg, pr_reg_tmp,
 			&pr_tmpl->registration_list, pr_reg_list) {
@@ -4078,14 +3993,20 @@ core_scsi3_pri_read_full_status(struct se_cmd *cmd)
 		 * reservation holder for PR_HOLDER bit.
 		 *
 		 * Also, if this registration is the reservation
-		 * holder, fill in SCOPE and TYPE in the next byte.
+		 * holder or there is an All Registrants reservation
+		 * active, fill in SCOPE and TYPE in the next byte.
 		 */
 		if (pr_reg->pr_res_holder) {
 			buf[off++] |= 0x01;
 			buf[off++] = (pr_reg->pr_res_scope & 0xf0) |
 				     (pr_reg->pr_res_type & 0x0f);
-		} else
+		} else if (all_reg) {
+			buf[off++] |= 0x01;
+			buf[off++] = (pr_res_scope & 0xf0) |
+				     (pr_res_type & 0x0f);
+		} else {
 			off += 2;
+		}
 
 		off += 4; /* Skip over reserved area */
 		/*
diff --git a/drivers/target/target_core_pr.h b/drivers/target/target_core_pr.h
index b4a0042..749fd7b 100644
--- a/drivers/target/target_core_pr.h
+++ b/drivers/target/target_core_pr.h
@@ -43,9 +43,14 @@
 #define PR_APTPL_MAX_IPORT_LEN			256
 #define PR_APTPL_MAX_TPORT_LEN			256
 
+/*
+ *  Function defined in target_core_spc.c
+ */
+void spc_parse_naa_6h_vendor_specific(struct se_device *, unsigned char *);
+
 extern struct kmem_cache *t10_pr_reg_cache;
 
-extern int core_pr_dump_initiator_port(struct t10_pr_registration *,
+extern void core_pr_dump_initiator_port(struct t10_pr_registration *,
 			char *, u32);
 extern sense_reason_t target_scsi2_reservation_release(struct se_cmd *);
 extern sense_reason_t target_scsi2_reservation_reserve(struct se_cmd *);
@@ -55,7 +60,7 @@ extern int core_scsi3_alloc_aptpl_registration(
 			unsigned char *, u16, u32, int, int, u8);
 extern int core_scsi3_check_aptpl_registration(struct se_device *,
 			struct se_portal_group *, struct se_lun *,
-			struct se_lun_acl *);
+			struct se_node_acl *, u32);
 extern void core_scsi3_free_pr_reg_from_nacl(struct se_device *,
 					     struct se_node_acl *);
 extern void core_scsi3_free_all_registrations(struct se_device *);
diff --git a/drivers/target/target_core_pscsi.c b/drivers/target/target_core_pscsi.c
index 3250ba2..9b90cfa 100644
--- a/drivers/target/target_core_pscsi.c
+++ b/drivers/target/target_core_pscsi.c
@@ -3,7 +3,7 @@
  *
  * This file contains the generic target mode <-> Linux SCSI subsystem plugin.
  *
- * (c) Copyright 2003-2012 RisingTide Systems LLC.
+ * (c) Copyright 2003-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -520,6 +520,7 @@ static int pscsi_configure_device(struct se_device *dev)
 					" pdv_host_id: %d\n", pdv->pdv_host_id);
 				return -EINVAL;
 			}
+			pdv->pdv_lld_host = sh;
 		}
 	} else {
 		if (phv->phv_mode == PHV_VIRTUAL_HOST_ID) {
@@ -602,6 +603,8 @@ static void pscsi_free_device(struct se_device *dev)
 		if ((phv->phv_mode == PHV_LLD_SCSI_HOST_NO) &&
 		    (phv->phv_lld_host != NULL))
 			scsi_host_put(phv->phv_lld_host);
+		else if (pdv->pdv_lld_host)
+			scsi_host_put(pdv->pdv_lld_host);
 
 		if ((sd->type == TYPE_DISK) || (sd->type == TYPE_ROM))
 			scsi_device_put(sd);
@@ -1050,9 +1053,8 @@ pscsi_execute_cmd(struct se_cmd *cmd)
 		req = blk_get_request(pdv->pdv_sd->request_queue,
 				(data_direction == DMA_TO_DEVICE),
 				GFP_KERNEL);
-		if (!req || IS_ERR(req)) {
-			pr_err("PSCSI: blk_get_request() failed: %ld\n",
-					req ? IS_ERR(req) : -ENOMEM);
+		if (!req) {
+			pr_err("PSCSI: blk_get_request() failed\n");
 			ret = TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
 			goto fail;
 		}
@@ -1112,7 +1114,7 @@ static u32 pscsi_get_device_type(struct se_device *dev)
 	struct pscsi_dev_virt *pdv = PSCSI_DEV(dev);
 	struct scsi_device *sd = pdv->pdv_sd;
 
-	return sd->type;
+	return (sd) ? sd->type : TYPE_NO_LUN;
 }
 
 static sector_t pscsi_get_blocks(struct se_device *dev)
diff --git a/drivers/target/target_core_pscsi.h b/drivers/target/target_core_pscsi.h
index 1bd757d..820d305 100644
--- a/drivers/target/target_core_pscsi.h
+++ b/drivers/target/target_core_pscsi.h
@@ -45,6 +45,7 @@ struct pscsi_dev_virt {
 	int	pdv_lun_id;
 	struct block_device *pdv_bd;
 	struct scsi_device *pdv_sd;
+	struct Scsi_Host *pdv_lld_host;
 } ____cacheline_aligned;
 
 typedef enum phv_modes {
diff --git a/drivers/target/target_core_rd.c b/drivers/target/target_core_rd.c
index 0921a64..7b331b9 100644
--- a/drivers/target/target_core_rd.c
+++ b/drivers/target/target_core_rd.c
@@ -4,7 +4,7 @@
  * This file contains the Storage Engine <-> Ramdisk transport
  * specific functions.
  *
- * (c) Copyright 2003-2012 RisingTide Systems LLC.
+ * (c) Copyright 2003-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -27,7 +27,6 @@
 #include <linux/string.h>
 #include <linux/parser.h>
 #include <linux/timer.h>
-#include <linux/blkdev.h>
 #include <linux/slab.h>
 #include <linux/spinlock.h>
 #include <scsi/scsi.h>
@@ -79,23 +78,14 @@ static void rd_detach_hba(struct se_hba *hba)
 	hba->hba_ptr = NULL;
 }
 
-/*	rd_release_device_space():
- *
- *
- */
-static void rd_release_device_space(struct rd_dev *rd_dev)
+static u32 rd_release_sgl_table(struct rd_dev *rd_dev, struct rd_dev_sg_table *sg_table,
+				 u32 sg_table_count)
 {
-	u32 i, j, page_count = 0, sg_per_table;
-	struct rd_dev_sg_table *sg_table;
 	struct page *pg;
 	struct scatterlist *sg;
+	u32 i, j, page_count = 0, sg_per_table;
 
-	if (!rd_dev->sg_table_array || !rd_dev->sg_table_count)
-		return;
-
-	sg_table = rd_dev->sg_table_array;
-
-	for (i = 0; i < rd_dev->sg_table_count; i++) {
+	for (i = 0; i < sg_table_count; i++) {
 		sg = sg_table[i].sg_table;
 		sg_per_table = sg_table[i].rd_sg_count;
 
@@ -106,16 +96,28 @@ static void rd_release_device_space(struct rd_dev *rd_dev)
 				page_count++;
 			}
 		}
-
 		kfree(sg);
 	}
 
+	kfree(sg_table);
+	return page_count;
+}
+
+static void rd_release_device_space(struct rd_dev *rd_dev)
+{
+	u32 page_count;
+
+	if (!rd_dev->sg_table_array || !rd_dev->sg_table_count)
+		return;
+
+	page_count = rd_release_sgl_table(rd_dev, rd_dev->sg_table_array,
+					  rd_dev->sg_table_count);
+
 	pr_debug("CORE_RD[%u] - Released device space for Ramdisk"
 		" Device ID: %u, pages %u in %u tables total bytes %lu\n",
 		rd_dev->rd_host->rd_host_id, rd_dev->rd_dev_id, page_count,
 		rd_dev->sg_table_count, (unsigned long)page_count * PAGE_SIZE);
 
-	kfree(sg_table);
 	rd_dev->sg_table_array = NULL;
 	rd_dev->sg_table_count = 0;
 }
@@ -125,33 +127,15 @@ static void rd_release_device_space(struct rd_dev *rd_dev)
  *
  *
  */
-static int rd_build_device_space(struct rd_dev *rd_dev)
+static int rd_allocate_sgl_table(struct rd_dev *rd_dev, struct rd_dev_sg_table *sg_table,
+				 u32 total_sg_needed, unsigned char init_payload)
 {
-	u32 i = 0, j, page_offset = 0, sg_per_table, sg_tables, total_sg_needed;
+	u32 i = 0, j, page_offset = 0, sg_per_table;
 	u32 max_sg_per_table = (RD_MAX_ALLOCATION_SIZE /
 				sizeof(struct scatterlist));
-	struct rd_dev_sg_table *sg_table;
 	struct page *pg;
 	struct scatterlist *sg;
-
-	if (rd_dev->rd_page_count <= 0) {
-		pr_err("Illegal page count: %u for Ramdisk device\n",
-			rd_dev->rd_page_count);
-		return -EINVAL;
-	}
-	total_sg_needed = rd_dev->rd_page_count;
-
-	sg_tables = (total_sg_needed / max_sg_per_table) + 1;
-
-	sg_table = kzalloc(sg_tables * sizeof(struct rd_dev_sg_table), GFP_KERNEL);
-	if (!sg_table) {
-		pr_err("Unable to allocate memory for Ramdisk"
-			" scatterlist tables\n");
-		return -ENOMEM;
-	}
-
-	rd_dev->sg_table_array = sg_table;
-	rd_dev->sg_table_count = sg_tables;
+	unsigned char *p;
 
 	while (total_sg_needed) {
 		sg_per_table = (total_sg_needed > max_sg_per_table) ?
@@ -174,7 +158,7 @@ static int rd_build_device_space(struct rd_dev *rd_dev)
 						- 1;
 
 		for (j = 0; j < sg_per_table; j++) {
-			pg = alloc_pages(GFP_KERNEL, 0);
+			pg = alloc_pages(GFP_KERNEL | __GFP_ZERO, 0);
 			if (!pg) {
 				pr_err("Unable to allocate scatterlist"
 					" pages for struct rd_dev_sg_table\n");
@@ -182,16 +166,119 @@ static int rd_build_device_space(struct rd_dev *rd_dev)
 			}
 			sg_assign_page(&sg[j], pg);
 			sg[j].length = PAGE_SIZE;
+
+			p = kmap(pg);
+			memset(p, init_payload, PAGE_SIZE);
+			kunmap(pg);
 		}
 
 		page_offset += sg_per_table;
 		total_sg_needed -= sg_per_table;
 	}
 
+	return 0;
+}
+
+static int rd_build_device_space(struct rd_dev *rd_dev)
+{
+	struct rd_dev_sg_table *sg_table;
+	u32 sg_tables, total_sg_needed;
+	u32 max_sg_per_table = (RD_MAX_ALLOCATION_SIZE /
+				sizeof(struct scatterlist));
+	int rc;
+
+	if (rd_dev->rd_page_count <= 0) {
+		pr_err("Illegal page count: %u for Ramdisk device\n",
+		       rd_dev->rd_page_count);
+		return -EINVAL;
+	}
+
+	/* Don't need backing pages for NULLIO */
+	if (rd_dev->rd_flags & RDF_NULLIO)
+		return 0;
+
+	total_sg_needed = rd_dev->rd_page_count;
+
+	sg_tables = (total_sg_needed / max_sg_per_table) + 1;
+
+	sg_table = kzalloc(sg_tables * sizeof(struct rd_dev_sg_table), GFP_KERNEL);
+	if (!sg_table) {
+		pr_err("Unable to allocate memory for Ramdisk"
+		       " scatterlist tables\n");
+		return -ENOMEM;
+	}
+
+	rd_dev->sg_table_array = sg_table;
+	rd_dev->sg_table_count = sg_tables;
+
+	rc = rd_allocate_sgl_table(rd_dev, sg_table, total_sg_needed, 0x00);
+	if (rc)
+		return rc;
+
 	pr_debug("CORE_RD[%u] - Built Ramdisk Device ID: %u space of"
-		" %u pages in %u tables\n", rd_dev->rd_host->rd_host_id,
-		rd_dev->rd_dev_id, rd_dev->rd_page_count,
-		rd_dev->sg_table_count);
+		 " %u pages in %u tables\n", rd_dev->rd_host->rd_host_id,
+		 rd_dev->rd_dev_id, rd_dev->rd_page_count,
+		 rd_dev->sg_table_count);
+
+	return 0;
+}
+
+static void rd_release_prot_space(struct rd_dev *rd_dev)
+{
+	u32 page_count;
+
+	if (!rd_dev->sg_prot_array || !rd_dev->sg_prot_count)
+		return;
+
+	page_count = rd_release_sgl_table(rd_dev, rd_dev->sg_prot_array,
+					  rd_dev->sg_prot_count);
+
+	pr_debug("CORE_RD[%u] - Released protection space for Ramdisk"
+		 " Device ID: %u, pages %u in %u tables total bytes %lu\n",
+		 rd_dev->rd_host->rd_host_id, rd_dev->rd_dev_id, page_count,
+		 rd_dev->sg_table_count, (unsigned long)page_count * PAGE_SIZE);
+
+	rd_dev->sg_prot_array = NULL;
+	rd_dev->sg_prot_count = 0;
+}
+
+static int rd_build_prot_space(struct rd_dev *rd_dev, int prot_length, int block_size)
+{
+	struct rd_dev_sg_table *sg_table;
+	u32 total_sg_needed, sg_tables;
+	u32 max_sg_per_table = (RD_MAX_ALLOCATION_SIZE /
+				sizeof(struct scatterlist));
+	int rc;
+
+	if (rd_dev->rd_flags & RDF_NULLIO)
+		return 0;
+	/*
+	 * prot_length=8byte dif data
+	 * tot sg needed = rd_page_count * (PGSZ/block_size) *
+	 * 		   (prot_length/block_size) + pad
+	 * PGSZ canceled each other.
+	 */
+	total_sg_needed = (rd_dev->rd_page_count * prot_length / block_size) + 1;
+
+	sg_tables = (total_sg_needed / max_sg_per_table) + 1;
+
+	sg_table = kzalloc(sg_tables * sizeof(struct rd_dev_sg_table), GFP_KERNEL);
+	if (!sg_table) {
+		pr_err("Unable to allocate memory for Ramdisk protection"
+		       " scatterlist tables\n");
+		return -ENOMEM;
+	}
+
+	rd_dev->sg_prot_array = sg_table;
+	rd_dev->sg_prot_count = sg_tables;
+
+	rc = rd_allocate_sgl_table(rd_dev, sg_table, total_sg_needed, 0xff);
+	if (rc)
+		return rc;
+
+	pr_debug("CORE_RD[%u] - Built Ramdisk Device ID: %u prot space of"
+		 " %u pages in %u tables\n", rd_dev->rd_host->rd_host_id,
+		 rd_dev->rd_dev_id, total_sg_needed, rd_dev->sg_prot_count);
 
 	return 0;
 }
@@ -274,12 +361,30 @@ static struct rd_dev_sg_table *rd_get_sg_table(struct rd_dev *rd_dev, u32 page)
 	return NULL;
 }
 
+static struct rd_dev_sg_table *rd_get_prot_table(struct rd_dev *rd_dev, u32 page)
+{
+	struct rd_dev_sg_table *sg_table;
+	u32 i, sg_per_table = (RD_MAX_ALLOCATION_SIZE /
+				sizeof(struct scatterlist));
+
+	i = page / sg_per_table;
+	if (i < rd_dev->sg_prot_count) {
+		sg_table = &rd_dev->sg_prot_array[i];
+		if ((sg_table->page_start_offset <= page) &&
+		     (sg_table->page_end_offset >= page))
+			return sg_table;
+	}
+
+	pr_err("Unable to locate struct prot rd_dev_sg_table for page: %u\n",
+			page);
+
+	return NULL;
+}
+
 static sense_reason_t
-rd_execute_rw(struct se_cmd *cmd)
+rd_execute_rw(struct se_cmd *cmd, struct scatterlist *sgl, u32 sgl_nents,
+	      enum dma_data_direction data_direction)
 {
-	struct scatterlist *sgl = cmd->t_data_sg;
-	u32 sgl_nents = cmd->t_data_nents;
-	enum dma_data_direction data_direction = cmd->data_direction;
 	struct se_device *se_dev = cmd->se_dev;
 	struct rd_dev *dev = RD_DEV(se_dev);
 	struct rd_dev_sg_table *table;
@@ -290,6 +395,7 @@ rd_execute_rw(struct se_cmd *cmd)
 	u32 rd_page;
 	u32 src_len;
 	u64 tmp;
+	sense_reason_t rc;
 
 	if (dev->rd_flags & RDF_NULLIO) {
 		target_complete_cmd(cmd, SAM_STAT_GOOD);
@@ -312,6 +418,28 @@ rd_execute_rw(struct se_cmd *cmd)
 			data_direction == DMA_FROM_DEVICE ? "Read" : "Write",
 			cmd->t_task_lba, rd_size, rd_page, rd_offset);
 
+	if (cmd->prot_type && data_direction == DMA_TO_DEVICE) {
+		struct rd_dev_sg_table *prot_table;
+		struct scatterlist *prot_sg;
+		u32 sectors = cmd->data_length / se_dev->dev_attrib.block_size;
+		u32 prot_offset, prot_page;
+
+		tmp = cmd->t_task_lba * se_dev->prot_length;
+		prot_offset = do_div(tmp, PAGE_SIZE);
+		prot_page = tmp;
+
+		prot_table = rd_get_prot_table(dev, prot_page);
+		if (!prot_table)
+			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+
+		prot_sg = &prot_table->sg_table[prot_page - prot_table->page_start_offset];
+
+		rc = sbc_dif_verify_write(cmd, cmd->t_task_lba, sectors, 0,
+					  prot_sg, prot_offset);
+		if (rc)
+			return rc;
+	}
+
 	src_len = PAGE_SIZE - rd_offset;
 	sg_miter_start(&m, sgl, sgl_nents,
 			data_direction == DMA_FROM_DEVICE ?
@@ -373,6 +501,28 @@ rd_execute_rw(struct se_cmd *cmd)
 	}
 	sg_miter_stop(&m);
 
+	if (cmd->prot_type && data_direction == DMA_FROM_DEVICE) {
+		struct rd_dev_sg_table *prot_table;
+		struct scatterlist *prot_sg;
+		u32 sectors = cmd->data_length / se_dev->dev_attrib.block_size;
+		u32 prot_offset, prot_page;
+
+		tmp = cmd->t_task_lba * se_dev->prot_length;
+		prot_offset = do_div(tmp, PAGE_SIZE);
+		prot_page = tmp;
+
+		prot_table = rd_get_prot_table(dev, prot_page);
+		if (!prot_table)
+			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+
+		prot_sg = &prot_table->sg_table[prot_page - prot_table->page_start_offset];
+
+		rc = sbc_dif_verify_read(cmd, cmd->t_task_lba, sectors, 0,
+					 prot_sg, prot_offset);
+		if (rc)
+			return rc;
+	}
+
 	target_complete_cmd(cmd, SAM_STAT_GOOD);
 	return 0;
 }
@@ -454,6 +604,24 @@ static sector_t rd_get_blocks(struct se_device *dev)
 	return blocks_long;
 }
 
+static int rd_init_prot(struct se_device *dev)
+{
+	struct rd_dev *rd_dev = RD_DEV(dev);
+
+        if (!dev->dev_attrib.pi_prot_type)
+		return 0;
+
+	return rd_build_prot_space(rd_dev, dev->prot_length,
+				   dev->dev_attrib.block_size);
+}
+
+static void rd_free_prot(struct se_device *dev)
+{
+	struct rd_dev *rd_dev = RD_DEV(dev);
+
+	rd_release_prot_space(rd_dev);
+}
+
 static struct sbc_ops rd_sbc_ops = {
 	.execute_rw		= rd_execute_rw,
 };
@@ -479,6 +647,8 @@ static struct se_subsystem_api rd_mcp_template = {
 	.show_configfs_dev_params = rd_show_configfs_dev_params,
 	.get_device_type	= sbc_get_device_type,
 	.get_blocks		= rd_get_blocks,
+	.init_prot		= rd_init_prot,
+	.free_prot		= rd_free_prot,
 };
 
 int __init rd_module_init(void)
diff --git a/drivers/target/target_core_rd.h b/drivers/target/target_core_rd.h
index 1789d1e..cc46a6a 100644
--- a/drivers/target/target_core_rd.h
+++ b/drivers/target/target_core_rd.h
@@ -33,8 +33,12 @@ struct rd_dev {
 	u32		rd_page_count;
 	/* Number of SG tables in sg_table_array */
 	u32		sg_table_count;
+	/* Number of SG tables in sg_prot_array */
+	u32		sg_prot_count;
 	/* Array of rd_dev_sg_table_t containing scatterlists */
 	struct rd_dev_sg_table *sg_table_array;
+	/* Array of rd_dev_sg_table containing protection scatterlists */
+	struct rd_dev_sg_table *sg_prot_array;
 	/* Ramdisk HBA device is connected to */
 	struct rd_host *rd_host;
 } ____cacheline_aligned;
diff --git a/drivers/target/target_core_sbc.c b/drivers/target/target_core_sbc.c
old mode 100644
new mode 100755
index bbc5b0e..e5da7a0
--- a/drivers/target/target_core_sbc.c
+++ b/drivers/target/target_core_sbc.c
@@ -1,7 +1,7 @@
 /*
  * SCSI Block Commands (SBC) parsing and emulation.
  *
- * (c) Copyright 2002-2012 RisingTide Systems LLC.
+ * (c) Copyright 2002-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -23,8 +23,10 @@
 #include <linux/kernel.h>
 #include <linux/module.h>
 #include <linux/ratelimit.h>
+#include <linux/crc-t10dif.h>
 #include <asm/unaligned.h>
 #include <scsi/scsi.h>
+#include <scsi/scsi_tcq.h>
 
 #include <target/target_core_base.h>
 #include <target/target_core_backend.h>
@@ -32,17 +34,33 @@
 
 #include "target_core_internal.h"
 #include "target_core_ua.h"
-
+#include "target_core_alua.h"
 
 static sense_reason_t
 sbc_emulate_readcapacity(struct se_cmd *cmd)
 {
 	struct se_device *dev = cmd->se_dev;
+	unsigned char *cdb = cmd->t_task_cdb;
 	unsigned long long blocks_long = dev->transport->get_blocks(dev);
 	unsigned char *rbuf;
 	unsigned char buf[8];
 	u32 blocks;
 
+	/*
+	 * SBC-2 says:
+	 *   If the PMI bit is set to zero and the LOGICAL BLOCK
+	 *   ADDRESS field is not set to zero, the device server shall
+	 *   terminate the command with CHECK CONDITION status with
+	 *   the sense key set to ILLEGAL REQUEST and the additional
+	 *   sense code set to INVALID FIELD IN CDB.
+	 *
+	 * In SBC-3, these fields are obsolete, but some SCSI
+	 * compliance tests actually check this, so we might as well
+	 * follow SBC-2.
+	 */
+	if (!(cdb[8] & 1) && !!(cdb[2] | cdb[3] | cdb[4] | cdb[5]))
+		return TCM_INVALID_CDB_FIELD;
+
 	if (blocks_long >= 0x00000000ffffffff)
 		blocks = 0xffffffff;
 	else
@@ -63,7 +81,7 @@ sbc_emulate_readcapacity(struct se_cmd *cmd)
 		transport_kunmap_data_sg(cmd);
 	}
 
-	target_complete_cmd(cmd, GOOD);
+	target_complete_cmd_with_length(cmd, GOOD, 8);
 	return 0;
 }
 
@@ -71,6 +89,7 @@ static sense_reason_t
 sbc_emulate_readcapacity_16(struct se_cmd *cmd)
 {
 	struct se_device *dev = cmd->se_dev;
+	struct se_session *sess = cmd->se_sess;
 	unsigned char *rbuf;
 	unsigned char buf[32];
 	unsigned long long blocks = dev->transport->get_blocks(dev);
@@ -89,11 +108,28 @@ sbc_emulate_readcapacity_16(struct se_cmd *cmd)
 	buf[10] = (dev->dev_attrib.block_size >> 8) & 0xff;
 	buf[11] = dev->dev_attrib.block_size & 0xff;
 	/*
+	 * Set P_TYPE and PROT_EN bits for DIF support
+	 */
+	if (sess->sup_prot_ops & (TARGET_PROT_DIN_PASS | TARGET_PROT_DOUT_PASS)) {
+		if (dev->dev_attrib.pi_prot_type)
+			buf[12] = (dev->dev_attrib.pi_prot_type - 1) << 1 | 0x1;
+	}
+
+	if (dev->transport->get_lbppbe)
+		buf[13] = dev->transport->get_lbppbe(dev) & 0x0f;
+
+	if (dev->transport->get_alignment_offset_lbas) {
+		u16 lalba = dev->transport->get_alignment_offset_lbas(dev);
+		buf[14] = (lalba >> 8) & 0x3f;
+		buf[15] = lalba & 0xff;
+	}
+
+	/*
 	 * Set Thin Provisioning Enable bit following sbc3r22 in section
 	 * READ CAPACITY (16) byte 14 if emulate_tpu or emulate_tpws is enabled.
 	 */
 	if (dev->dev_attrib.emulate_tpu || dev->dev_attrib.emulate_tpws)
-		buf[14] = 0x80;
+		buf[14] |= 0x80;
 
 	rbuf = transport_kmap_data_sg(cmd);
 	if (rbuf) {
@@ -101,7 +137,7 @@ sbc_emulate_readcapacity_16(struct se_cmd *cmd)
 		transport_kunmap_data_sg(cmd);
 	}
 
-	target_complete_cmd(cmd, GOOD);
+	target_complete_cmd_with_length(cmd, GOOD, 32);
 	return 0;
 }
 
@@ -233,6 +269,8 @@ static inline unsigned long long transport_lba_64_ext(unsigned char *cdb)
 static sense_reason_t
 sbc_setup_write_same(struct se_cmd *cmd, unsigned char *flags, struct sbc_ops *ops)
 {
+	struct se_device *dev = cmd->se_dev;
+	sector_t end_lba = dev->transport->get_blocks(dev) + 1;
 	unsigned int sectors = sbc_get_write_same_sectors(cmd);
 
 	if ((flags[0] & 0x04) || (flags[0] & 0x02)) {
@@ -247,6 +285,21 @@ sbc_setup_write_same(struct se_cmd *cmd, unsigned char *flags, struct sbc_ops *o
 		return TCM_INVALID_CDB_FIELD;
 	}
 	/*
+	 * Sanity check for LBA wrap and request past end of device.
+	 */
+	if (((cmd->t_task_lba + sectors) < cmd->t_task_lba) ||
+	    ((cmd->t_task_lba + sectors) > end_lba)) {
+		pr_err("WRITE_SAME exceeds last lba %llu (lba %llu, sectors %u)\n",
+		       (unsigned long long)end_lba, cmd->t_task_lba, sectors);
+		return TCM_ADDRESS_OUT_OF_RANGE;
+	}
+
+	/* We always have ANC_SUP == 0 so setting ANCHOR is always an error */
+	if (flags[0] & 0x10) {
+		pr_warn("WRITE SAME with ANCHOR not supported\n");
+		return TCM_INVALID_CDB_FIELD;
+	}
+	/*
 	 * Special case for WRITE_SAME w/ UNMAP=1 that ends up getting
 	 * translated into block discard requests within backend code.
 	 */
@@ -264,13 +317,14 @@ sbc_setup_write_same(struct se_cmd *cmd, unsigned char *flags, struct sbc_ops *o
 	return 0;
 }
 
-static void xdreadwrite_callback(struct se_cmd *cmd)
+static sense_reason_t xdreadwrite_callback(struct se_cmd *cmd, bool success,
+					   int *post_ret)
 {
 	unsigned char *buf, *addr;
 	struct scatterlist *sg;
 	unsigned int offset;
-	int i;
-	int count;
+	sense_reason_t ret = TCM_NO_SENSE;
+	int i, count;
 	/*
 	 * From sbc3r22.pdf section 5.48 XDWRITEREAD (10) command
 	 *
@@ -285,7 +339,7 @@ static void xdreadwrite_callback(struct se_cmd *cmd)
 	buf = kmalloc(cmd->data_length, GFP_KERNEL);
 	if (!buf) {
 		pr_err("Unable to allocate xor_callback buf\n");
-		return;
+		return TCM_OUT_OF_RESOURCES;
 	}
 	/*
 	 * Copy the scatterlist WRITE buffer located at cmd->t_data_sg
@@ -304,8 +358,10 @@ static void xdreadwrite_callback(struct se_cmd *cmd)
 	offset = 0;
 	for_each_sg(cmd->t_bidi_data_sg, sg, cmd->t_bidi_data_nents, count) {
 		addr = kmap_atomic(sg_page(sg));
-		if (!addr)
+		if (!addr) {
+			ret = TCM_OUT_OF_RESOURCES;
 			goto out;
+		}
 
 		for (i = 0; i < sg->length; i++)
 			*(addr + sg->offset + i) ^= *(buf + offset + i);
@@ -316,6 +372,324 @@ static void xdreadwrite_callback(struct se_cmd *cmd)
 
 out:
 	kfree(buf);
+	return ret;
+}
+
+static sense_reason_t
+sbc_execute_rw(struct se_cmd *cmd)
+{
+	return cmd->execute_rw(cmd, cmd->t_data_sg, cmd->t_data_nents,
+			       cmd->data_direction);
+}
+
+static sense_reason_t compare_and_write_post(struct se_cmd *cmd, bool success,
+					     int *post_ret)
+{
+	struct se_device *dev = cmd->se_dev;
+
+	/*
+	 * Only set SCF_COMPARE_AND_WRITE_POST to force a response fall-through
+	 * within target_complete_ok_work() if the command was successfully
+	 * sent to the backend driver.
+	 */
+	spin_lock_irq(&cmd->t_state_lock);
+	if ((cmd->transport_state & CMD_T_SENT) && !cmd->scsi_status) {
+		cmd->se_cmd_flags |= SCF_COMPARE_AND_WRITE_POST;
+		*post_ret = 1;
+	}
+	spin_unlock_irq(&cmd->t_state_lock);
+
+	/*
+	 * Unlock ->caw_sem originally obtained during sbc_compare_and_write()
+	 * before the original READ I/O submission.
+	 */
+	up(&dev->caw_sem);
+
+	return TCM_NO_SENSE;
+}
+
+static sense_reason_t compare_and_write_callback(struct se_cmd *cmd, bool success,
+						 int *post_ret)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct scatterlist *write_sg = NULL, *sg;
+	unsigned char *buf = NULL, *addr;
+	struct sg_mapping_iter m;
+	unsigned int offset = 0, len;
+	unsigned int nlbas = cmd->t_task_nolb;
+	unsigned int block_size = dev->dev_attrib.block_size;
+	unsigned int compare_len = (nlbas * block_size);
+	sense_reason_t ret = TCM_NO_SENSE;
+	int rc, i;
+
+	/*
+	 * Handle early failure in transport_generic_request_failure(),
+	 * which will not have taken ->caw_sem yet..
+	 */
+	if (!success && (!cmd->t_data_sg || !cmd->t_bidi_data_sg))
+		return TCM_NO_SENSE;
+	/*
+	 * Handle special case for zero-length COMPARE_AND_WRITE
+	 */
+	if (!cmd->data_length)
+		goto out;
+	/*
+	 * Immediately exit + release dev->caw_sem if command has already
+	 * been failed with a non-zero SCSI status.
+	 */
+	if (cmd->scsi_status) {
+		pr_err("compare_and_write_callback: non zero scsi_status:"
+			" 0x%02x\n", cmd->scsi_status);
+		goto out;
+	}
+
+	buf = kzalloc(cmd->data_length, GFP_KERNEL);
+	if (!buf) {
+		pr_err("Unable to allocate compare_and_write buf\n");
+		ret = TCM_OUT_OF_RESOURCES;
+		goto out;
+	}
+
+	write_sg = kmalloc(sizeof(struct scatterlist) * cmd->t_data_nents,
+			   GFP_KERNEL);
+	if (!write_sg) {
+		pr_err("Unable to allocate compare_and_write sg\n");
+		ret = TCM_OUT_OF_RESOURCES;
+		goto out;
+	}
+	sg_init_table(write_sg, cmd->t_data_nents);
+	/*
+	 * Setup verify and write data payloads from total NumberLBAs.
+	 */
+	rc = sg_copy_to_buffer(cmd->t_data_sg, cmd->t_data_nents, buf,
+			       cmd->data_length);
+	if (!rc) {
+		pr_err("sg_copy_to_buffer() failed for compare_and_write\n");
+		ret = TCM_OUT_OF_RESOURCES;
+		goto out;
+	}
+	/*
+	 * Compare against SCSI READ payload against verify payload
+	 */
+	for_each_sg(cmd->t_bidi_data_sg, sg, cmd->t_bidi_data_nents, i) {
+		addr = (unsigned char *)kmap_atomic(sg_page(sg));
+		if (!addr) {
+			ret = TCM_OUT_OF_RESOURCES;
+			goto out;
+		}
+
+		len = min(sg->length, compare_len);
+
+		if (memcmp(addr, buf + offset, len)) {
+			pr_warn("Detected MISCOMPARE for addr: %p buf: %p\n",
+				addr, buf + offset);
+			kunmap_atomic(addr);
+			goto miscompare;
+		}
+		kunmap_atomic(addr);
+
+		offset += len;
+		compare_len -= len;
+		if (!compare_len)
+			break;
+	}
+
+	i = 0;
+	len = cmd->t_task_nolb * block_size;
+	sg_miter_start(&m, cmd->t_data_sg, cmd->t_data_nents, SG_MITER_TO_SG);
+	/*
+	 * Currently assumes NoLB=1 and SGLs are PAGE_SIZE..
+	 */
+	while (len) {
+		sg_miter_next(&m);
+
+		if (block_size < PAGE_SIZE) {
+			sg_set_page(&write_sg[i], m.page, block_size,
+				    m.piter.sg->offset + block_size);
+		} else {
+			sg_miter_next(&m);
+			sg_set_page(&write_sg[i], m.page, block_size,
+				    m.piter.sg->offset);
+		}
+		len -= block_size;
+		i++;
+	}
+	sg_miter_stop(&m);
+	/*
+	 * Save the original SGL + nents values before updating to new
+	 * assignments, to be released in transport_free_pages() ->
+	 * transport_reset_sgl_orig()
+	 */
+	cmd->t_data_sg_orig = cmd->t_data_sg;
+	cmd->t_data_sg = write_sg;
+	cmd->t_data_nents_orig = cmd->t_data_nents;
+	cmd->t_data_nents = 1;
+
+	cmd->sam_task_attr = MSG_HEAD_TAG;
+	cmd->transport_complete_callback = compare_and_write_post;
+	/*
+	 * Now reset ->execute_cmd() to the normal sbc_execute_rw() handler
+	 * for submitting the adjusted SGL to write instance user-data.
+	 */
+	cmd->execute_cmd = sbc_execute_rw;
+
+	spin_lock_irq(&cmd->t_state_lock);
+	cmd->t_state = TRANSPORT_PROCESSING;
+	cmd->transport_state |= CMD_T_ACTIVE|CMD_T_BUSY|CMD_T_SENT;
+	spin_unlock_irq(&cmd->t_state_lock);
+
+	__target_execute_cmd(cmd);
+
+	kfree(buf);
+	return ret;
+
+miscompare:
+	pr_warn("Target/%s: Send MISCOMPARE check condition and sense\n",
+		dev->transport->name);
+	ret = TCM_MISCOMPARE_VERIFY;
+out:
+	/*
+	 * In the MISCOMPARE or failure case, unlock ->caw_sem obtained in
+	 * sbc_compare_and_write() before the original READ I/O submission.
+	 */
+	up(&dev->caw_sem);
+	kfree(write_sg);
+	kfree(buf);
+	return ret;
+}
+
+static sense_reason_t
+sbc_compare_and_write(struct se_cmd *cmd)
+{
+	struct se_device *dev = cmd->se_dev;
+	sense_reason_t ret;
+	int rc;
+	/*
+	 * Submit the READ first for COMPARE_AND_WRITE to perform the
+	 * comparision using SGLs at cmd->t_bidi_data_sg..
+	 */
+	rc = down_interruptible(&dev->caw_sem);
+	if ((rc != 0) || signal_pending(current)) {
+		cmd->transport_complete_callback = NULL;
+		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
+	/*
+	 * Reset cmd->data_length to individual block_size in order to not
+	 * confuse backend drivers that depend on this value matching the
+	 * size of the I/O being submitted.
+	 */
+	cmd->data_length = cmd->t_task_nolb * dev->dev_attrib.block_size;
+
+	ret = cmd->execute_rw(cmd, cmd->t_bidi_data_sg, cmd->t_bidi_data_nents,
+			      DMA_FROM_DEVICE);
+	if (ret) {
+		cmd->transport_complete_callback = NULL;
+		up(&dev->caw_sem);
+		return ret;
+	}
+	/*
+	 * Unlock of dev->caw_sem to occur in compare_and_write_callback()
+	 * upon MISCOMPARE, or in compare_and_write_done() upon completion
+	 * of WRITE instance user-data.
+	 */
+	return TCM_NO_SENSE;
+}
+
+static int
+sbc_set_prot_op_checks(u8 protect, enum target_prot_type prot_type,
+		       bool is_write, struct se_cmd *cmd)
+{
+	if (is_write) {
+		cmd->prot_op = protect ? TARGET_PROT_DOUT_PASS :
+					 TARGET_PROT_DOUT_INSERT;
+		switch (protect) {
+		case 0x0:
+		case 0x3:
+			cmd->prot_checks = 0;
+			break;
+		case 0x1:
+		case 0x5:
+			cmd->prot_checks = TARGET_DIF_CHECK_GUARD;
+			if (prot_type == TARGET_DIF_TYPE1_PROT)
+				cmd->prot_checks |= TARGET_DIF_CHECK_REFTAG;
+			break;
+		case 0x2:
+			if (prot_type == TARGET_DIF_TYPE1_PROT)
+				cmd->prot_checks = TARGET_DIF_CHECK_REFTAG;
+			break;
+		case 0x4:
+			cmd->prot_checks = TARGET_DIF_CHECK_GUARD;
+			break;
+		default:
+			pr_err("Unsupported protect field %d\n", protect);
+			return -EINVAL;
+		}
+	} else {
+		cmd->prot_op = protect ? TARGET_PROT_DIN_PASS :
+					 TARGET_PROT_DIN_STRIP;
+		switch (protect) {
+		case 0x0:
+		case 0x1:
+		case 0x5:
+			cmd->prot_checks = TARGET_DIF_CHECK_GUARD;
+			if (prot_type == TARGET_DIF_TYPE1_PROT)
+				cmd->prot_checks |= TARGET_DIF_CHECK_REFTAG;
+			break;
+		case 0x2:
+			if (prot_type == TARGET_DIF_TYPE1_PROT)
+				cmd->prot_checks = TARGET_DIF_CHECK_REFTAG;
+			break;
+		case 0x3:
+			cmd->prot_checks = 0;
+			break;
+		case 0x4:
+			cmd->prot_checks = TARGET_DIF_CHECK_GUARD;
+			break;
+		default:
+			pr_err("Unsupported protect field %d\n", protect);
+			return -EINVAL;
+		}
+	}
+
+	return 0;
+}
+
+static bool
+sbc_check_prot(struct se_device *dev, struct se_cmd *cmd, unsigned char *cdb,
+	       u32 sectors)
+{
+	if (!cmd->t_prot_sg || !cmd->t_prot_nents)
+		return true;
+
+	switch (dev->dev_attrib.pi_prot_type) {
+	case TARGET_DIF_TYPE3_PROT:
+		if (!(cdb[1] & 0xe0))
+			return true;
+
+		cmd->reftag_seed = 0xffffffff;
+		break;
+	case TARGET_DIF_TYPE2_PROT:
+		if (cdb[1] & 0xe0)
+			return false;
+
+		cmd->reftag_seed = cmd->t_task_lba;
+		break;
+	case TARGET_DIF_TYPE1_PROT:
+		if (!(cdb[1] & 0xe0))
+			return true;
+
+		cmd->reftag_seed = cmd->t_task_lba;
+		break;
+	case TARGET_DIF_TYPE0_PROT:
+	default:
+		return true;
+	}
+
+	cmd->prot_type = dev->dev_attrib.pi_prot_type;
+	cmd->prot_length = dev->prot_length * sectors;
+	cmd->prot_handover = PROT_SEPERATED;
+
+	return true;
 }
 
 sense_reason_t
@@ -332,56 +706,88 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 		sectors = transport_get_sectors_6(cdb);
 		cmd->t_task_lba = transport_lba_21(cdb);
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case READ_10:
 		sectors = transport_get_sectors_10(cdb);
 		cmd->t_task_lba = transport_lba_32(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case READ_12:
 		sectors = transport_get_sectors_12(cdb);
 		cmd->t_task_lba = transport_lba_32(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case READ_16:
 		sectors = transport_get_sectors_16(cdb);
 		cmd->t_task_lba = transport_lba_64(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case WRITE_6:
 		sectors = transport_get_sectors_6(cdb);
 		cmd->t_task_lba = transport_lba_21(cdb);
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case WRITE_10:
 	case WRITE_VERIFY:
 		sectors = transport_get_sectors_10(cdb);
 		cmd->t_task_lba = transport_lba_32(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		if (cdb[1] & 0x8)
 			cmd->se_cmd_flags |= SCF_FUA;
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case WRITE_12:
 		sectors = transport_get_sectors_12(cdb);
 		cmd->t_task_lba = transport_lba_32(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		if (cdb[1] & 0x8)
 			cmd->se_cmd_flags |= SCF_FUA;
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case WRITE_16:
 		sectors = transport_get_sectors_16(cdb);
 		cmd->t_task_lba = transport_lba_64(cdb);
+
+		if (!sbc_check_prot(dev, cmd, cdb, sectors))
+			return TCM_UNSUPPORTED_SCSI_OPCODE;
+
 		if (cdb[1] & 0x8)
 			cmd->se_cmd_flags |= SCF_FUA;
 		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB;
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		break;
 	case XDWRITEREAD_10:
 		if (cmd->data_direction != DMA_TO_DEVICE ||
@@ -395,7 +801,8 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 		/*
 		 * Setup BIDI XOR callback to be run after I/O completion.
 		 */
-		cmd->execute_cmd = ops->execute_rw;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_execute_rw;
 		cmd->transport_complete_callback = &xdreadwrite_callback;
 		if (cdb[1] & 0x8)
 			cmd->se_cmd_flags |= SCF_FUA;
@@ -418,7 +825,8 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 			 * Setup BIDI XOR callback to be run during after I/O
 			 * completion.
 			 */
-			cmd->execute_cmd = ops->execute_rw;
+			cmd->execute_rw = ops->execute_rw;
+			cmd->execute_cmd = sbc_execute_rw;
 			cmd->transport_complete_callback = &xdreadwrite_callback;
 			if (cdb[1] & 0x8)
 				cmd->se_cmd_flags |= SCF_FUA;
@@ -445,6 +853,28 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 		}
 		break;
 	}
+	case COMPARE_AND_WRITE:
+		sectors = cdb[13];
+		/*
+		 * Currently enforce COMPARE_AND_WRITE for a single sector
+		 */
+		if (sectors > 1) {
+			pr_err("COMPARE_AND_WRITE contains NoLB: %u greater"
+			       " than 1\n", sectors);
+			return TCM_INVALID_CDB_FIELD;
+		}
+		/*
+		 * Double size because we have two buffers, note that
+		 * zero is not an error..
+		 */
+		size = 2 * sbc_get_size(cmd, sectors);
+		cmd->t_task_lba = get_unaligned_be64(&cdb[2]);
+		cmd->t_task_nolb = sectors;
+		cmd->se_cmd_flags |= SCF_SCSI_DATA_CDB | SCF_COMPARE_AND_WRITE;
+		cmd->execute_rw = ops->execute_rw;
+		cmd->execute_cmd = sbc_compare_and_write;
+		cmd->transport_complete_callback = compare_and_write_callback;
+		break;
 	case READ_CAPACITY:
 		size = READ_CAP_LEN;
 		cmd->execute_cmd = sbc_emulate_readcapacity;
@@ -454,6 +884,9 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 		case SAI_READ_CAPACITY_16:
 			cmd->execute_cmd = sbc_emulate_readcapacity_16;
 			break;
+		case SAI_REPORT_REFERRALS:
+			cmd->execute_cmd = target_emulate_report_referrals;
+			break;
 		default:
 			pr_err("Unsupported SA: 0x%02x\n",
 				cmd->t_task_cdb[1] & 0x1f);
@@ -561,30 +994,17 @@ sbc_parse_cdb(struct se_cmd *cmd, struct sbc_ops *ops)
 	if (cmd->se_cmd_flags & SCF_SCSI_DATA_CDB) {
 		unsigned long long end_lba;
 
-		if (sectors > dev->dev_attrib.fabric_max_sectors) {
-			printk_ratelimited(KERN_ERR "SCSI OP %02xh with too"
-				" big sectors %u exceeds fabric_max_sectors:"
-				" %u\n", cdb[0], sectors,
-				dev->dev_attrib.fabric_max_sectors);
-			return TCM_INVALID_CDB_FIELD;
-		}
-		if (sectors > dev->dev_attrib.hw_max_sectors) {
-			printk_ratelimited(KERN_ERR "SCSI OP %02xh with too"
-				" big sectors %u exceeds backend hw_max_sectors:"
-				" %u\n", cdb[0], sectors,
-				dev->dev_attrib.hw_max_sectors);
-			return TCM_INVALID_CDB_FIELD;
-		}
-
 		end_lba = dev->transport->get_blocks(dev) + 1;
-		if (cmd->t_task_lba + sectors > end_lba) {
+		if (((cmd->t_task_lba + sectors) < cmd->t_task_lba) ||
+		    ((cmd->t_task_lba + sectors) > end_lba)) {
 			pr_err("cmd exceeds last lba %llu "
 				"(lba %llu, sectors %u)\n",
 				end_lba, cmd->t_task_lba, sectors);
-			return TCM_INVALID_CDB_FIELD;
+			return TCM_ADDRESS_OUT_OF_RANGE;
 		}
 
-		size = sbc_get_size(cmd, sectors);
+		if (!(cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE))
+			size = sbc_get_size(cmd, sectors);
 	}
 
 	return target_cmd_size_check(cmd, size);
@@ -681,3 +1101,263 @@ err:
 	return ret;
 }
 EXPORT_SYMBOL(sbc_execute_unmap);
+
+void
+sbc_dif_generate(struct se_cmd *cmd)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct se_dif_v1_tuple *sdt;
+	struct scatterlist *dsg, *psg = cmd->t_prot_sg;
+	sector_t sector = cmd->t_task_lba;
+	void *daddr, *paddr;
+	int i, j, offset = 0;
+
+	for_each_sg(cmd->t_data_sg, dsg, cmd->t_data_nents, i) {
+		daddr = kmap_atomic(sg_page(dsg)) + dsg->offset;
+		paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+
+		for (j = 0; j < dsg->length; j += dev->dev_attrib.block_size) {
+
+			if (offset >= psg->length) {
+				kunmap_atomic(paddr);
+				psg = sg_next(psg);
+				paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+				offset = 0;
+			}
+
+			sdt = paddr + offset;
+			sdt->guard_tag = cpu_to_be16(crc_t10dif(daddr + j,
+						dev->dev_attrib.block_size));
+			if (dev->dev_attrib.pi_prot_type == TARGET_DIF_TYPE1_PROT)
+				sdt->ref_tag = cpu_to_be32(sector & 0xffffffff);
+			sdt->app_tag = 0;
+
+			pr_debug("DIF WRITE INSERT sector: %llu guard_tag: 0x%04x"
+				 " app_tag: 0x%04x ref_tag: %u\n",
+				 (unsigned long long)sector, sdt->guard_tag,
+				 sdt->app_tag, be32_to_cpu(sdt->ref_tag));
+
+			sector++;
+			offset += sizeof(struct se_dif_v1_tuple);
+		}
+
+		kunmap_atomic(paddr);
+		kunmap_atomic(daddr);
+	}
+}
+
+static sense_reason_t
+sbc_dif_v1_verify(struct se_device *dev, struct se_dif_v1_tuple *sdt,
+		  const void *p, sector_t sector, unsigned int ei_lba)
+{
+	int block_size = dev->dev_attrib.block_size;
+	__be16 csum;
+
+	csum = cpu_to_be16(crc_t10dif(p, block_size));
+
+	if (sdt->guard_tag != csum) {
+		pr_err("DIFv1 checksum failed on sector %llu guard tag 0x%04x"
+			" csum 0x%04x\n", (unsigned long long)sector,
+			be16_to_cpu(sdt->guard_tag), be16_to_cpu(csum));
+		return TCM_LOGICAL_BLOCK_GUARD_CHECK_FAILED;
+	}
+
+	if (dev->dev_attrib.pi_prot_type == TARGET_DIF_TYPE1_PROT &&
+	    be32_to_cpu(sdt->ref_tag) != (sector & 0xffffffff)) {
+		pr_err("DIFv1 Type 1 reference failed on sector: %llu tag: 0x%08x"
+		       " sector MSB: 0x%08x\n", (unsigned long long)sector,
+		       be32_to_cpu(sdt->ref_tag), (u32)(sector & 0xffffffff));
+		return TCM_LOGICAL_BLOCK_REF_TAG_CHECK_FAILED;
+	}
+
+	if (dev->dev_attrib.pi_prot_type == TARGET_DIF_TYPE2_PROT &&
+	    be32_to_cpu(sdt->ref_tag) != ei_lba) {
+		pr_err("DIFv1 Type 2 reference failed on sector: %llu tag: 0x%08x"
+		       " ei_lba: 0x%08x\n", (unsigned long long)sector,
+			be32_to_cpu(sdt->ref_tag), ei_lba);
+		return TCM_LOGICAL_BLOCK_REF_TAG_CHECK_FAILED;
+	}
+
+	return 0;
+}
+
+static void
+sbc_dif_copy_prot(struct se_cmd *cmd, unsigned int sectors, bool read,
+		  struct scatterlist *sg, int sg_off)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct scatterlist *psg;
+	void *paddr, *addr;
+	unsigned int i, len, left;
+	unsigned int offset = sg_off;
+
+	left = sectors * dev->prot_length;
+
+	for_each_sg(cmd->t_prot_sg, psg, cmd->t_prot_nents, i) {
+		unsigned int psg_len, copied = 0;
+
+		paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+		psg_len = min(left, psg->length);
+		while (psg_len) {
+			len = min(psg_len, sg->length - offset);
+			addr = kmap_atomic(sg_page(sg)) + sg->offset + offset;
+
+			if (read)
+				memcpy(paddr + copied, addr, len);
+			else
+				memcpy(addr, paddr + copied, len);
+
+			left -= len;
+			offset += len;
+			copied += len;
+			psg_len -= len;
+
+			if (offset >= sg->length) {
+				sg = sg_next(sg);
+				offset = 0;
+			}
+			kunmap_atomic(addr);
+		}
+		kunmap_atomic(paddr);
+	}
+}
+
+sense_reason_t
+sbc_dif_verify_write(struct se_cmd *cmd, sector_t start, unsigned int sectors,
+		     unsigned int ei_lba, struct scatterlist *sg, int sg_off)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct se_dif_v1_tuple *sdt;
+	struct scatterlist *dsg, *psg = cmd->t_prot_sg;
+	sector_t sector = start;
+	void *daddr, *paddr;
+	int i, j, offset = 0;
+	sense_reason_t rc;
+
+	for_each_sg(cmd->t_data_sg, dsg, cmd->t_data_nents, i) {
+		daddr = kmap_atomic(sg_page(dsg)) + dsg->offset;
+		paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+
+		for (j = 0; j < dsg->length; j += dev->dev_attrib.block_size) {
+
+			if (offset >= psg->length) {
+				kunmap_atomic(paddr);
+				psg = sg_next(psg);
+				paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+				offset = 0;
+			}
+
+			sdt = paddr + offset;
+
+			pr_debug("DIF WRITE sector: %llu guard_tag: 0x%04x"
+				 " app_tag: 0x%04x ref_tag: %u\n",
+				 (unsigned long long)sector, sdt->guard_tag,
+				 sdt->app_tag, be32_to_cpu(sdt->ref_tag));
+
+			rc = sbc_dif_v1_verify(dev, sdt, daddr + j, sector,
+					       ei_lba);
+			if (rc) {
+				kunmap_atomic(paddr);
+				kunmap_atomic(daddr);
+				cmd->bad_sector = sector;
+				return rc;
+			}
+
+			sector++;
+			ei_lba++;
+			offset += sizeof(struct se_dif_v1_tuple);
+		}
+
+		kunmap_atomic(paddr);
+		kunmap_atomic(daddr);
+	}
+	sbc_dif_copy_prot(cmd, sectors, false, sg, sg_off);
+
+	return 0;
+}
+EXPORT_SYMBOL(sbc_dif_verify_write);
+
+static sense_reason_t
+__sbc_dif_verify_read(struct se_cmd *cmd, sector_t start, unsigned int sectors,
+		      unsigned int ei_lba, struct scatterlist *sg, int sg_off)
+{
+	struct se_device *dev = cmd->se_dev;
+	struct se_dif_v1_tuple *sdt;
+	struct scatterlist *dsg, *psg = sg;
+	sector_t sector = start;
+	void *daddr, *paddr;
+	int i, j, offset = sg_off;
+	sense_reason_t rc;
+
+	for_each_sg(cmd->t_data_sg, dsg, cmd->t_data_nents, i) {
+		daddr = kmap_atomic(sg_page(dsg)) + dsg->offset;
+		paddr = kmap_atomic(sg_page(psg)) + sg->offset;
+
+		for (j = 0; j < dsg->length; j += dev->dev_attrib.block_size) {
+
+			if (offset >= psg->length) {
+				kunmap_atomic(paddr);
+				psg = sg_next(psg);
+				paddr = kmap_atomic(sg_page(psg)) + psg->offset;
+				offset = 0;
+			}
+
+			sdt = paddr + offset;
+
+			pr_debug("DIF READ sector: %llu guard_tag: 0x%04x"
+				 " app_tag: 0x%04x ref_tag: %u\n",
+				 (unsigned long long)sector, sdt->guard_tag,
+				 sdt->app_tag, be32_to_cpu(sdt->ref_tag));
+
+			if (sdt->app_tag == cpu_to_be16(0xffff)) {
+				sector++;
+				offset += sizeof(struct se_dif_v1_tuple);
+				continue;
+			}
+
+			rc = sbc_dif_v1_verify(dev, sdt, daddr + j, sector,
+					       ei_lba);
+			if (rc) {
+				kunmap_atomic(paddr);
+				kunmap_atomic(daddr);
+				cmd->bad_sector = sector;
+				return rc;
+			}
+
+			sector++;
+			ei_lba++;
+			offset += sizeof(struct se_dif_v1_tuple);
+		}
+
+		kunmap_atomic(paddr);
+		kunmap_atomic(daddr);
+	}
+
+	return 0;
+}
+
+sense_reason_t
+sbc_dif_read_strip(struct se_cmd *cmd)
+{
+	struct se_device *dev = cmd->se_dev;
+	u32 sectors = cmd->prot_length / dev->prot_length;
+
+	return __sbc_dif_verify_read(cmd, cmd->t_task_lba, sectors, 0,
+				     cmd->t_prot_sg, 0);
+}
+
+sense_reason_t
+sbc_dif_verify_read(struct se_cmd *cmd, sector_t start, unsigned int sectors,
+		    unsigned int ei_lba, struct scatterlist *sg, int sg_off)
+{
+	sense_reason_t rc;
+
+	rc = __sbc_dif_verify_read(cmd, start, sectors, ei_lba, sg, sg_off);
+	if (rc)
+		return rc;
+
+	sbc_dif_copy_prot(cmd, sectors, true, sg, sg_off);
+
+	return 0;
+}
+EXPORT_SYMBOL(sbc_dif_verify_read);
diff --git a/drivers/target/target_core_spc.c b/drivers/target/target_core_spc.c
index 9fabbf7..12a74f6 100644
--- a/drivers/target/target_core_spc.c
+++ b/drivers/target/target_core_spc.c
@@ -1,7 +1,7 @@
 /*
  * SCSI Primary Commands (SPC) parsing and emulation.
  *
- * (c) Copyright 2002-2012 RisingTide Systems LLC.
+ * (c) Copyright 2002-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -35,7 +35,7 @@
 #include "target_core_alua.h"
 #include "target_core_pr.h"
 #include "target_core_ua.h"
-
+#include "target_core_xcopy.h"
 
 static void spc_fill_alua_data(struct se_port *port, unsigned char *buf)
 {
@@ -48,7 +48,7 @@ static void spc_fill_alua_data(struct se_port *port, unsigned char *buf)
 	buf[5]	= 0x80;
 
 	/*
-	 * Set TPGS field for explict and/or implict ALUA access type
+	 * Set TPGS field for explicit and/or implicit ALUA access type
 	 * and opteration.
 	 *
 	 * See spc4r17 section 6.4.2 Table 135
@@ -95,6 +95,17 @@ spc_emulate_inquiry_std(struct se_cmd *cmd, unsigned char *buf)
 	 */
 	spc_fill_alua_data(lun->lun_sep, buf);
 
+	/*
+	 * Set Third-Party Copy (3PC) bit to indicate support for EXTENDED_COPY
+	 */
+	if (dev->dev_attrib.emulate_3pc)
+		buf[5] |= 0x8;
+	/*
+	 * Set Protection (PROTECT) bit when DIF has been enabled.
+	 */
+	if (dev->dev_attrib.pi_prot_type)
+		buf[5] |= 0x1;
+
 	buf[7] = 0x2; /* CmdQue=1 */
 
 	memcpy(&buf[8], "LIO-ORG ", 8);
@@ -129,8 +140,8 @@ spc_emulate_evpd_80(struct se_cmd *cmd, unsigned char *buf)
 	return 0;
 }
 
-static void spc_parse_naa_6h_vendor_specific(struct se_device *dev,
-		unsigned char *buf)
+void spc_parse_naa_6h_vendor_specific(struct se_device *dev,
+				      unsigned char *buf)
 {
 	unsigned char *p = &dev->t10_wwn.unit_serial[0];
 	int cnt;
@@ -261,7 +272,7 @@ check_t10_vend_desc:
 	port = lun->lun_sep;
 	if (port) {
 		struct t10_alua_lu_gp *lu_gp;
-		u32 padding, scsi_name_len;
+		u32 padding, scsi_name_len, scsi_target_len;
 		u16 lu_gp_id = 0;
 		u16 tg_pt_gp_id = 0;
 		u16 tpgt;
@@ -359,16 +370,6 @@ check_lu_gp:
 		 * section 7.5.1 Table 362
 		 */
 check_scsi_name:
-		scsi_name_len = strlen(tpg->se_tpg_tfo->tpg_get_wwn(tpg));
-		/* UTF-8 ",t,0x<16-bit TPGT>" + NULL Terminator */
-		scsi_name_len += 10;
-		/* Check for 4-byte padding */
-		padding = ((-scsi_name_len) & 3);
-		if (padding != 0)
-			scsi_name_len += padding;
-		/* Header size + Designation descriptor */
-		scsi_name_len += 4;
-
 		buf[off] =
 			(tpg->se_tpg_tfo->get_fabric_proto_ident(tpg) << 4);
 		buf[off++] |= 0x3; /* CODE SET == UTF-8 */
@@ -396,13 +397,57 @@ check_scsi_name:
 		 * shall be no larger than 256 and shall be a multiple
 		 * of four.
 		 */
+		padding = ((-scsi_name_len) & 3);
 		if (padding)
 			scsi_name_len += padding;
+		if (scsi_name_len > 256)
+			scsi_name_len = 256;
 
 		buf[off-1] = scsi_name_len;
 		off += scsi_name_len;
 		/* Header size + Designation descriptor */
 		len += (scsi_name_len + 4);
+
+		/*
+		 * Target device designator
+		 */
+		buf[off] =
+			(tpg->se_tpg_tfo->get_fabric_proto_ident(tpg) << 4);
+		buf[off++] |= 0x3; /* CODE SET == UTF-8 */
+		buf[off] = 0x80; /* Set PIV=1 */
+		/* Set ASSOCIATION == target device: 10b */
+		buf[off] |= 0x20;
+		/* DESIGNATOR TYPE == SCSI name string */
+		buf[off++] |= 0x8;
+		off += 2; /* Skip over Reserved and length */
+		/*
+		 * SCSI name string identifer containing, $FABRIC_MOD
+		 * dependent information.  For LIO-Target and iSCSI
+		 * Target Port, this means "<iSCSI name>" in
+		 * UTF-8 encoding.
+		 */
+		scsi_target_len = sprintf(&buf[off], "%s",
+					  tpg->se_tpg_tfo->tpg_get_wwn(tpg));
+		scsi_target_len += 1 /* Include  NULL terminator */;
+		/*
+		 * The null-terminated, null-padded (see 4.4.2) SCSI
+		 * NAME STRING field contains a UTF-8 format string.
+		 * The number of bytes in the SCSI NAME STRING field
+		 * (i.e., the value in the DESIGNATOR LENGTH field)
+		 * shall be no larger than 256 and shall be a multiple
+		 * of four.
+		 */
+		padding = ((-scsi_target_len) & 3);
+		if (padding)
+			scsi_target_len += padding;
+		if (scsi_target_len > 256)
+			scsi_target_len = 256;
+
+		buf[off-1] = scsi_target_len;
+		off += scsi_target_len;
+
+		/* Header size + Designation descriptor */
+		len += (scsi_target_len + 4);
 	}
 	buf[2] = ((len >> 8) & 0xff);
 	buf[3] = (len & 0xff); /* Page Length for VPD 0x83 */
@@ -430,12 +475,26 @@ spc_emulate_evpd_86(struct se_cmd *cmd, unsigned char *buf)
 	struct se_device *dev = cmd->se_dev;
 
 	buf[3] = 0x3c;
+	/*
+	 * Set GRD_CHK + REF_CHK for TYPE1 protection, or GRD_CHK
+	 * only for TYPE3 protection.
+	 */
+	if (dev->dev_attrib.pi_prot_type == TARGET_DIF_TYPE1_PROT)
+		buf[4] = 0x5;
+	else if (dev->dev_attrib.pi_prot_type == TARGET_DIF_TYPE3_PROT)
+		buf[4] = 0x4;
+
 	/* Set HEADSUP, ORDSUP, SIMPSUP */
 	buf[5] = 0x07;
 
 	/* If WriteCache emulation is enabled, set V_SUP */
 	if (spc_check_dev_wce(dev))
 		buf[6] = 0x01;
+	/* If an LBA map is present set R_SUP */
+	spin_lock(&cmd->se_dev->t10_alua.lba_map_lock);
+	if (!list_empty(&dev->t10_alua.lba_map_list))
+		buf[8] = 0x10;
+	spin_unlock(&cmd->se_dev->t10_alua.lba_map_lock);
 	return 0;
 }
 
@@ -444,8 +503,8 @@ static sense_reason_t
 spc_emulate_evpd_b0(struct se_cmd *cmd, unsigned char *buf)
 {
 	struct se_device *dev = cmd->se_dev;
-	u32 max_sectors;
 	int have_tp = 0;
+	int opt, min;
 
 	/*
 	 * Following spc3r22 section 6.5.3 Block Limits VPD page, when
@@ -460,23 +519,32 @@ spc_emulate_evpd_b0(struct se_cmd *cmd, unsigned char *buf)
 
 	/* Set WSNZ to 1 */
 	buf[4] = 0x01;
+	/*
+	 * Set MAXIMUM COMPARE AND WRITE LENGTH
+	 */
+	if (dev->dev_attrib.emulate_caw)
+		buf[5] = 0x01;
 
 	/*
 	 * Set OPTIMAL TRANSFER LENGTH GRANULARITY
 	 */
-	put_unaligned_be16(1, &buf[6]);
+	if (dev->transport->get_io_min && (min = dev->transport->get_io_min(dev)))
+		put_unaligned_be16(min / dev->dev_attrib.block_size, &buf[6]);
+	else
+		put_unaligned_be16(1, &buf[6]);
 
 	/*
 	 * Set MAXIMUM TRANSFER LENGTH
 	 */
-	max_sectors = min(dev->dev_attrib.fabric_max_sectors,
-			  dev->dev_attrib.hw_max_sectors);
-	put_unaligned_be32(max_sectors, &buf[8]);
+	put_unaligned_be32(dev->dev_attrib.hw_max_sectors, &buf[8]);
 
 	/*
 	 * Set OPTIMAL TRANSFER LENGTH
 	 */
-	put_unaligned_be32(dev->dev_attrib.optimal_sectors, &buf[12]);
+	if (dev->transport->get_io_opt && (opt = dev->transport->get_io_opt(dev)))
+		put_unaligned_be32(opt / dev->dev_attrib.block_size, &buf[12]);
+	else
+		put_unaligned_be32(dev->dev_attrib.optimal_sectors, &buf[12]);
 
 	/*
 	 * Exit now if we don't support TP.
@@ -582,6 +650,20 @@ spc_emulate_evpd_b2(struct se_cmd *cmd, unsigned char *buf)
 	return 0;
 }
 
+/* Referrals VPD page */
+static sense_reason_t
+spc_emulate_evpd_b3(struct se_cmd *cmd, unsigned char *buf)
+{
+	struct se_device *dev = cmd->se_dev;
+
+	buf[0] = dev->transport->get_device_type(dev);
+	buf[3] = 0x0c;
+	put_unaligned_be32(dev->t10_alua.lba_map_segment_size, &buf[8]);
+	put_unaligned_be32(dev->t10_alua.lba_map_segment_size, &buf[12]);
+
+	return 0;
+}
+
 static sense_reason_t
 spc_emulate_evpd_00(struct se_cmd *cmd, unsigned char *buf);
 
@@ -596,6 +678,7 @@ static struct {
 	{ .page = 0xb0, .emulate = spc_emulate_evpd_b0 },
 	{ .page = 0xb1, .emulate = spc_emulate_evpd_b1 },
 	{ .page = 0xb2, .emulate = spc_emulate_evpd_b2 },
+	{ .page = 0xb3, .emulate = spc_emulate_evpd_b3 },
 };
 
 /* supported vital product data pages */
@@ -625,11 +708,16 @@ spc_emulate_inquiry(struct se_cmd *cmd)
 	struct se_portal_group *tpg = cmd->se_lun->lun_sep->sep_tpg;
 	unsigned char *rbuf;
 	unsigned char *cdb = cmd->t_task_cdb;
-	unsigned char buf[SE_INQUIRY_BUF];
+	unsigned char *buf;
 	sense_reason_t ret;
 	int p;
+	int len = 0;
 
-	memset(buf, 0, SE_INQUIRY_BUF);
+	buf = kzalloc(SE_INQUIRY_BUF, GFP_KERNEL);
+	if (!buf) {
+		pr_err("Unable to allocate response buffer for INQUIRY\n");
+		return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
 
 	if (dev == tpg->tpg_virt_lun0.lun_se_dev)
 		buf[0] = 0x3f; /* Not connected */
@@ -645,6 +733,7 @@ spc_emulate_inquiry(struct se_cmd *cmd)
 		}
 
 		ret = spc_emulate_inquiry_std(cmd, buf);
+		len = buf[4] + 5;
 		goto out;
 	}
 
@@ -652,6 +741,7 @@ spc_emulate_inquiry(struct se_cmd *cmd)
 		if (cdb[2] == evpd_handlers[p].page) {
 			buf[1] = cdb[2];
 			ret = evpd_handlers[p].emulate(cmd, buf);
+			len = get_unaligned_be16(&buf[2]) + 4;
 			goto out;
 		}
 	}
@@ -662,12 +752,13 @@ spc_emulate_inquiry(struct se_cmd *cmd)
 out:
 	rbuf = transport_kmap_data_sg(cmd);
 	if (rbuf) {
-		memcpy(rbuf, buf, min_t(u32, sizeof(buf), cmd->data_length));
+		memcpy(rbuf, buf, min_t(u32, SE_INQUIRY_BUF, cmd->data_length));
 		transport_kunmap_data_sg(cmd);
 	}
+	kfree(buf);
 
 	if (!ret)
-		target_complete_cmd(cmd, GOOD);
+		target_complete_cmd_with_length(cmd, GOOD, len);
 	return ret;
 }
 
@@ -767,6 +858,19 @@ static int spc_modesense_control(struct se_device *dev, u8 pc, u8 *p)
 	 * status (see SAM-4).
 	 */
 	p[5] = (dev->dev_attrib.emulate_tas) ? 0x40 : 0x00;
+	/*
+	 * From spc4r30, section 7.5.7 Control mode page
+	 *
+	 * Application Tag Owner (ATO) bit set to one.
+	 *
+	 * If the ATO bit is set to one the device server shall not modify the
+	 * LOGICAL BLOCK APPLICATION TAG field and, depending on the protection
+	 * type, shall not modify the contents of the LOGICAL BLOCK REFERENCE
+	 * TAG field.
+	 */
+	if (dev->dev_attrib.pi_prot_type)
+		p[5] |= 0x80;
+
 	p[8] = 0xff;
 	p[9] = 0xff;
 	p[11] = 30;
@@ -985,7 +1089,7 @@ set_length:
 		transport_kunmap_data_sg(cmd);
 	}
 
-	target_complete_cmd(cmd, GOOD);
+	target_complete_cmd_with_length(cmd, GOOD, length);
 	return 0;
 }
 
@@ -1162,7 +1266,7 @@ done:
 	buf[3] = (lun_count & 0xff);
 	transport_kunmap_data_sg(cmd);
 
-	target_complete_cmd(cmd, GOOD);
+	target_complete_cmd_with_length(cmd, GOOD, 8 + lun_count * 8);
 	return 0;
 }
 EXPORT_SYMBOL(spc_emulate_report_luns);
@@ -1239,7 +1343,7 @@ spc_parse_cdb(struct se_cmd *cmd, unsigned int *size)
 		*size = (cdb[3] << 8) + cdb[4];
 
 		/*
-		 * Do implict HEAD_OF_QUEUE processing for INQUIRY.
+		 * Do implicit HEAD_OF_QUEUE processing for INQUIRY.
 		 * See spc4r17 section 5.3
 		 */
 		cmd->sam_task_attr = MSG_HEAD_TAG;
@@ -1250,8 +1354,14 @@ spc_parse_cdb(struct se_cmd *cmd, unsigned int *size)
 		*size = (cdb[6] << 24) | (cdb[7] << 16) | (cdb[8] << 8) | cdb[9];
 		break;
 	case EXTENDED_COPY:
-	case READ_ATTRIBUTE:
+		*size = get_unaligned_be32(&cdb[10]);
+		cmd->execute_cmd = target_do_xcopy;
+		break;
 	case RECEIVE_COPY_RESULTS:
+		*size = get_unaligned_be32(&cdb[10]);
+		cmd->execute_cmd = target_do_receive_copy_results;
+		break;
+	case READ_ATTRIBUTE:
 	case WRITE_ATTRIBUTE:
 		*size = (cdb[10] << 24) | (cdb[11] << 16) |
 		       (cdb[12] << 8) | cdb[13];
@@ -1267,7 +1377,7 @@ spc_parse_cdb(struct se_cmd *cmd, unsigned int *size)
 		cmd->execute_cmd = spc_emulate_report_luns;
 		*size = (cdb[6] << 24) | (cdb[7] << 16) | (cdb[8] << 8) | cdb[9];
 		/*
-		 * Do implict HEAD_OF_QUEUE processing for REPORT_LUNS
+		 * Do implicit HEAD_OF_QUEUE processing for REPORT_LUNS
 		 * See spc4r17 section 5.3
 		 */
 		cmd->sam_task_attr = MSG_HEAD_TAG;
diff --git a/drivers/target/target_core_stat.c b/drivers/target/target_core_stat.c
index d154ce7..0353899 100644
--- a/drivers/target/target_core_stat.c
+++ b/drivers/target/target_core_stat.c
@@ -4,7 +4,7 @@
  * Modern ConfigFS group context specific statistics based on original
  * target_core_mib.c code
  *
- * (c) Copyright 2006-2012 RisingTide Systems LLC.
+ * (c) Copyright 2006-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@linux-iscsi.org>
  *
@@ -32,7 +32,6 @@
 #include <linux/utsname.h>
 #include <linux/proc_fs.h>
 #include <linux/seq_file.h>
-#include <linux/blkdev.h>
 #include <linux/configfs.h>
 #include <scsi/scsi.h>
 #include <scsi/scsi_device.h>
@@ -214,7 +213,8 @@ static ssize_t target_stat_scsi_tgt_dev_show_attr_resets(
 	struct se_device *dev =
 		container_of(sgrps, struct se_device, dev_stat_grps);
 
-	return snprintf(page, PAGE_SIZE, "%u\n", dev->num_resets);
+	return snprintf(page, PAGE_SIZE, "%lu\n",
+			atomic_long_read(&dev->num_resets));
 }
 DEV_STAT_SCSI_TGT_DEV_ATTR_RO(resets);
 
@@ -397,8 +397,8 @@ static ssize_t target_stat_scsi_lu_show_attr_num_cmds(
 		container_of(sgrps, struct se_device, dev_stat_grps);
 
 	/* scsiLuNumCommands */
-	return snprintf(page, PAGE_SIZE, "%llu\n",
-			(unsigned long long)dev->num_cmds);
+	return snprintf(page, PAGE_SIZE, "%lu\n",
+			atomic_long_read(&dev->num_cmds));
 }
 DEV_STAT_SCSI_LU_ATTR_RO(num_cmds);
 
@@ -409,7 +409,8 @@ static ssize_t target_stat_scsi_lu_show_attr_read_mbytes(
 		container_of(sgrps, struct se_device, dev_stat_grps);
 
 	/* scsiLuReadMegaBytes */
-	return snprintf(page, PAGE_SIZE, "%u\n", (u32)(dev->read_bytes >> 20));
+	return snprintf(page, PAGE_SIZE, "%lu\n",
+			atomic_long_read(&dev->read_bytes) >> 20);
 }
 DEV_STAT_SCSI_LU_ATTR_RO(read_mbytes);
 
@@ -420,7 +421,8 @@ static ssize_t target_stat_scsi_lu_show_attr_write_mbytes(
 		container_of(sgrps, struct se_device, dev_stat_grps);
 
 	/* scsiLuWrittenMegaBytes */
-	return snprintf(page, PAGE_SIZE, "%u\n", (u32)(dev->write_bytes >> 20));
+	return snprintf(page, PAGE_SIZE, "%lu\n",
+			atomic_long_read(&dev->write_bytes) >> 20);
 }
 DEV_STAT_SCSI_LU_ATTR_RO(write_mbytes);
 
@@ -431,7 +433,7 @@ static ssize_t target_stat_scsi_lu_show_attr_resets(
 		container_of(sgrps, struct se_device, dev_stat_grps);
 
 	/* scsiLuInResets */
-	return snprintf(page, PAGE_SIZE, "%u\n", dev->num_resets);
+	return snprintf(page, PAGE_SIZE, "%lu\n", atomic_long_read(&dev->num_resets));
 }
 DEV_STAT_SCSI_LU_ATTR_RO(resets);
 
diff --git a/drivers/target/target_core_tmr.c b/drivers/target/target_core_tmr.c
old mode 100644
new mode 100755
index d0b4dd9..033a59c
--- a/drivers/target/target_core_tmr.c
+++ b/drivers/target/target_core_tmr.c
@@ -3,7 +3,7 @@
  *
  * This file contains SPC-3 task management infrastructure
  *
- * (c) Copyright 2009-2012 RisingTide Systems LLC.
+ * (c) Copyright 2009-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -76,30 +76,29 @@ void core_tmr_release_req(
 	}
 
 	spin_lock_irqsave(&dev->se_tmr_lock, flags);
-	list_del(&tmr->tmr_list);
+	list_del_init(&tmr->tmr_list);
 	spin_unlock_irqrestore(&dev->se_tmr_lock, flags);
 
 	kfree(tmr);
 }
 
-static void core_tmr_handle_tas_abort(
-	struct se_node_acl *tmr_nacl,
-	struct se_cmd *cmd,
-	int tas,
-	int fe_count)
+static void core_tmr_handle_tas_abort(struct se_cmd *cmd, int tas)
 {
-	if (!fe_count) {
-		transport_cmd_finish_abort(cmd, 1);
-		return;
-	}
+	unsigned long flags;
+	bool remove = true, send_tas;
 	/*
 	 * TASK ABORTED status (TAS) bit support
-	*/
-	if ((tmr_nacl &&
-	     (tmr_nacl == cmd->se_sess->se_node_acl)) || tas)
+	 */
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	send_tas = (cmd->transport_state & CMD_T_TAS);
+	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+
+	if (send_tas) {
+		remove = false;
 		transport_send_task_abort(cmd);
+	}
 
-	transport_cmd_finish_abort(cmd, 0);
+	transport_cmd_finish_abort(cmd, remove);
 }
 
 static int target_check_cdb_and_preempt(struct list_head *list,
@@ -117,6 +116,47 @@ static int target_check_cdb_and_preempt(struct list_head *list,
 	return 1;
 }
 
+static bool __target_check_io_state(struct se_cmd *se_cmd,
+				    struct se_session *tmr_sess, int tas)
+{
+	struct se_session *sess = se_cmd->se_sess;
+
+	assert_spin_locked(&sess->sess_cmd_lock);
+	WARN_ON_ONCE(!irqs_disabled());
+	/*
+	 * If command already reached CMD_T_COMPLETE state within
+	 * target_complete_cmd() or CMD_T_FABRIC_STOP due to shutdown,
+	 * this se_cmd has been passed to fabric driver and will
+	 * not be aborted.
+	 *
+	 * Otherwise, obtain a local se_cmd->cmd_kref now for TMR
+	 * ABORT_TASK + LUN_RESET for CMD_T_ABORTED processing as
+	 * long as se_cmd->cmd_kref is still active unless zero.
+	 */
+	spin_lock(&se_cmd->t_state_lock);
+	if (se_cmd->transport_state & (CMD_T_COMPLETE | CMD_T_FABRIC_STOP)) {
+		pr_debug("Attempted to abort io tag: %u already complete or"
+			" fabric stop, skipping\n",
+			se_cmd->se_tfo->get_task_tag(se_cmd));
+		spin_unlock(&se_cmd->t_state_lock);
+		return false;
+	}
+	if (sess->sess_tearing_down || se_cmd->cmd_wait_set) {
+		pr_debug("Attempted to abort io tag: %u already shutdown,"
+			" skipping\n", se_cmd->se_tfo->get_task_tag(se_cmd));
+		spin_unlock(&se_cmd->t_state_lock);
+		return false;
+	}
+	se_cmd->transport_state |= CMD_T_ABORTED;
+
+	if ((tmr_sess != se_cmd->se_sess) && tas)
+		se_cmd->transport_state |= CMD_T_TAS;
+
+	spin_unlock(&se_cmd->t_state_lock);
+
+	return kref_get_unless_zero(&se_cmd->cmd_kref);
+}
+
 void core_tmr_abort_task(
 	struct se_device *dev,
 	struct se_tmr_req *tmr,
@@ -132,6 +172,11 @@ void core_tmr_abort_task(
 
 		if (dev != se_cmd->se_dev)
 			continue;
+
+		/* skip se_cmd associated with tmr */
+		if (tmr->task_cmd == se_cmd)
+			continue;
+
 		ref_tag = se_cmd->se_tfo->get_task_tag(se_cmd);
 		if (tmr->ref_task_tag != ref_tag)
 			continue;
@@ -139,33 +184,18 @@ void core_tmr_abort_task(
 		printk("ABORT_TASK: Found referenced %s task_tag: %u\n",
 			se_cmd->se_tfo->get_fabric_name(), ref_tag);
 
-		spin_lock(&se_cmd->t_state_lock);
-		if (se_cmd->transport_state & CMD_T_COMPLETE) {
-			printk("ABORT_TASK: ref_tag: %u already complete, skipping\n", ref_tag);
-			spin_unlock(&se_cmd->t_state_lock);
+		if (!__target_check_io_state(se_cmd, se_sess, 0)) {
 			spin_unlock_irqrestore(&se_sess->sess_cmd_lock, flags);
 			goto out;
 		}
-		se_cmd->transport_state |= CMD_T_ABORTED;
-		spin_unlock(&se_cmd->t_state_lock);
 
 		list_del_init(&se_cmd->se_cmd_list);
-		kref_get(&se_cmd->cmd_kref);
 		spin_unlock_irqrestore(&se_sess->sess_cmd_lock, flags);
 
 		cancel_work_sync(&se_cmd->work);
 		transport_wait_for_tasks(se_cmd);
-		/*
-		 * Now send SAM_STAT_TASK_ABORTED status for the referenced
-		 * se_cmd descriptor..
-		 */
-		transport_send_task_abort(se_cmd);
-		/*
-		 * Also deal with possible extra acknowledge reference..
-		 */
-		if (se_cmd->se_cmd_flags & SCF_ACK_KREF)
-			target_put_sess_cmd(se_sess, se_cmd);
 
+		transport_cmd_finish_abort(se_cmd, true);
 		target_put_sess_cmd(se_sess, se_cmd);
 
 		printk("ABORT_TASK: Sending TMR_FUNCTION_COMPLETE for"
@@ -187,9 +217,11 @@ static void core_tmr_drain_tmr_list(
 	struct list_head *preempt_and_abort_list)
 {
 	LIST_HEAD(drain_tmr_list);
+	struct se_session *sess;
 	struct se_tmr_req *tmr_p, *tmr_pp;
 	struct se_cmd *cmd;
 	unsigned long flags;
+	bool rc;
 	/*
 	 * Release all pending and outgoing TMRs aside from the received
 	 * LUN_RESET tmr..
@@ -215,17 +247,39 @@ static void core_tmr_drain_tmr_list(
 		if (target_check_cdb_and_preempt(preempt_and_abort_list, cmd))
 			continue;
 
+		sess = cmd->se_sess;
+		if (WARN_ON_ONCE(!sess))
+			continue;
+
+		spin_lock(&sess->sess_cmd_lock);
 		spin_lock(&cmd->t_state_lock);
-		if (!(cmd->transport_state & CMD_T_ACTIVE)) {
+		if (!(cmd->transport_state & CMD_T_ACTIVE) ||
+		     (cmd->transport_state & CMD_T_FABRIC_STOP)) {
 			spin_unlock(&cmd->t_state_lock);
+			spin_unlock(&sess->sess_cmd_lock);
 			continue;
 		}
 		if (cmd->t_state == TRANSPORT_ISTATE_PROCESSING) {
 			spin_unlock(&cmd->t_state_lock);
+			spin_unlock(&sess->sess_cmd_lock);
+			continue;
+		}
+		if (sess->sess_tearing_down || cmd->cmd_wait_set) {
+			spin_unlock(&cmd->t_state_lock);
+			spin_unlock(&sess->sess_cmd_lock);
 			continue;
 		}
+		cmd->transport_state |= CMD_T_ABORTED;
 		spin_unlock(&cmd->t_state_lock);
 
+		rc = kref_get_unless_zero(&cmd->cmd_kref);
+		if (!rc) {
+			printk("LUN_RESET TMR: non-zero kref_get_unless_zero\n");
+			spin_unlock(&sess->sess_cmd_lock);
+			continue;
+		}
+		spin_unlock(&sess->sess_cmd_lock);
+
 		list_move_tail(&tmr_p->tmr_list, &drain_tmr_list);
 	}
 	spin_unlock_irqrestore(&dev->se_tmr_lock, flags);
@@ -239,21 +293,26 @@ static void core_tmr_drain_tmr_list(
 			(preempt_and_abort_list) ? "Preempt" : "", tmr_p,
 			tmr_p->function, tmr_p->response, cmd->t_state);
 
+		cancel_work_sync(&cmd->work);
+		transport_wait_for_tasks(cmd);
+
 		transport_cmd_finish_abort(cmd, 1);
+		target_put_sess_cmd(cmd->se_sess, cmd);
 	}
 }
 
 static void core_tmr_drain_state_list(
 	struct se_device *dev,
 	struct se_cmd *prout_cmd,
-	struct se_node_acl *tmr_nacl,
+	struct se_session *tmr_sess,
 	int tas,
 	struct list_head *preempt_and_abort_list)
 {
 	LIST_HEAD(drain_task_list);
+	struct se_session *sess;
 	struct se_cmd *cmd, *next;
 	unsigned long flags;
-	int fe_count;
+	int rc;
 
 	/*
 	 * Complete outstanding commands with TASK_ABORTED SAM status.
@@ -292,6 +351,16 @@ static void core_tmr_drain_state_list(
 		if (prout_cmd == cmd)
 			continue;
 
+		sess = cmd->se_sess;
+		if (WARN_ON_ONCE(!sess))
+			continue;
+
+		spin_lock(&sess->sess_cmd_lock);
+		rc = __target_check_io_state(cmd, tmr_sess, tas);
+		spin_unlock(&sess->sess_cmd_lock);
+		if (!rc)
+			continue;
+
 		list_move_tail(&cmd->state_list, &drain_task_list);
 		cmd->state_active = false;
 	}
@@ -299,7 +368,7 @@ static void core_tmr_drain_state_list(
 
 	while (!list_empty(&drain_task_list)) {
 		cmd = list_entry(drain_task_list.next, struct se_cmd, state_list);
-		list_del(&cmd->state_list);
+		list_del_init(&cmd->state_list);
 
 		pr_debug("LUN_RESET: %s cmd: %p"
 			" ITT/CmdSN: 0x%08x/0x%08x, i_state: %d, t_state: %d"
@@ -323,18 +392,11 @@ static void core_tmr_drain_state_list(
 		 * loop above, but we do it down here given that
 		 * cancel_work_sync may block.
 		 */
-		if (cmd->t_state == TRANSPORT_COMPLETE)
-			cancel_work_sync(&cmd->work);
-
-		spin_lock_irqsave(&cmd->t_state_lock, flags);
-		target_stop_cmd(cmd, &flags);
-
-		fe_count = atomic_read(&cmd->t_fe_count);
-
-		cmd->transport_state |= CMD_T_ABORTED;
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+		cancel_work_sync(&cmd->work);
+		transport_wait_for_tasks(cmd);
 
-		core_tmr_handle_tas_abort(tmr_nacl, cmd, tas, fe_count);
+		core_tmr_handle_tas_abort(cmd, tas);
+		target_put_sess_cmd(cmd->se_sess, cmd);
 	}
 }
 
@@ -346,6 +408,7 @@ int core_tmr_lun_reset(
 {
 	struct se_node_acl *tmr_nacl = NULL;
 	struct se_portal_group *tmr_tpg = NULL;
+	struct se_session *tmr_sess = NULL;
 	int tas;
         /*
 	 * TASK_ABORTED status bit, this is configurable via ConfigFS
@@ -364,8 +427,9 @@ int core_tmr_lun_reset(
 	 * or struct se_device passthrough..
 	 */
 	if (tmr && tmr->task_cmd && tmr->task_cmd->se_sess) {
-		tmr_nacl = tmr->task_cmd->se_sess->se_node_acl;
-		tmr_tpg = tmr->task_cmd->se_sess->se_tpg;
+		tmr_sess = tmr->task_cmd->se_sess;
+		tmr_nacl = tmr_sess->se_node_acl;
+		tmr_tpg = tmr_sess->se_tpg;
 		if (tmr_nacl && tmr_tpg) {
 			pr_debug("LUN_RESET: TMR caller fabric: %s"
 				" initiator port %s\n",
@@ -378,7 +442,7 @@ int core_tmr_lun_reset(
 		dev->transport->name, tas);
 
 	core_tmr_drain_tmr_list(dev, tmr, preempt_and_abort_list);
-	core_tmr_drain_state_list(dev, prout_cmd, tmr_nacl, tas,
+	core_tmr_drain_state_list(dev, prout_cmd, tmr_sess, tas,
 				preempt_and_abort_list);
 
 	/*
@@ -394,9 +458,7 @@ int core_tmr_lun_reset(
 		pr_debug("LUN_RESET: SCSI-2 Released reservation\n");
 	}
 
-	spin_lock_irq(&dev->stats_lock);
-	dev->num_resets++;
-	spin_unlock_irq(&dev->stats_lock);
+	atomic_long_inc(&dev->num_resets);
 
 	pr_debug("LUN_RESET: %s for [%s] Complete\n",
 			(preempt_and_abort_list) ? "Preempt" : "TMR",
diff --git a/drivers/target/target_core_tpg.c b/drivers/target/target_core_tpg.c
index aac9d27..fb8a1a1 100644
--- a/drivers/target/target_core_tpg.c
+++ b/drivers/target/target_core_tpg.c
@@ -3,7 +3,7 @@
  *
  * This file contains generic Target Portal Group related functions.
  *
- * (c) Copyright 2002-2012 RisingTide Systems LLC.
+ * (c) Copyright 2002-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -40,6 +40,7 @@
 #include <target/target_core_fabric.h>
 
 #include "target_core_internal.h"
+#include "target_core_pr.h"
 
 extern struct se_device *g_lun0_dev;
 
@@ -116,6 +117,7 @@ struct se_node_acl *core_tpg_get_initiator_node_acl(
 
 	return acl;
 }
+EXPORT_SYMBOL(core_tpg_get_initiator_node_acl);
 
 /*	core_tpg_add_node_to_devs():
  *
@@ -165,6 +167,13 @@ void core_tpg_add_node_to_devs(
 
 		core_enable_device_list_for_node(lun, NULL, lun->unpacked_lun,
 				lun_access, acl, tpg);
+		/*
+		 * Check to see if there are any existing persistent reservation
+		 * APTPL pre-registrations that need to be enabled for this dynamic
+		 * LUN ACL now..
+		 */
+		core_scsi3_check_aptpl_registration(dev, tpg, lun, acl,
+						    lun->unpacked_lun);
 		spin_lock(&tpg->tpg_lun_lock);
 	}
 	spin_unlock(&tpg->tpg_lun_lock);
@@ -277,7 +286,6 @@ struct se_node_acl *core_tpg_check_initiator_node_acl(
 	snprintf(acl->initiatorname, TRANSPORT_IQN_LEN, "%s", initiatorname);
 	acl->se_tpg = tpg;
 	acl->acl_index = scsi_get_new_index(SCSI_AUTH_INTR_INDEX);
-	spin_lock_init(&acl->stats_lock);
 	acl->dynamic_node_acl = 1;
 
 	tpg->se_tpg_tfo->set_default_node_attributes(acl);
@@ -405,7 +413,6 @@ struct se_node_acl *core_tpg_add_initiator_node_acl(
 	snprintf(acl->initiatorname, TRANSPORT_IQN_LEN, "%s", initiatorname);
 	acl->se_tpg = tpg;
 	acl->acl_index = scsi_get_new_index(SCSI_AUTH_INTR_INDEX);
-	spin_lock_init(&acl->stats_lock);
 
 	tpg->se_tpg_tfo->set_default_node_attributes(acl);
 
@@ -633,6 +640,13 @@ int core_tpg_set_initiator_node_tag(
 }
 EXPORT_SYMBOL(core_tpg_set_initiator_node_tag);
 
+static void core_tpg_lun_ref_release(struct percpu_ref *ref)
+{
+	struct se_lun *lun = container_of(ref, struct se_lun, lun_ref);
+
+	complete(&lun->lun_ref_comp);
+}
+
 static int core_tpg_setup_virtual_lun0(struct se_portal_group *se_tpg)
 {
 	/* Set in core_dev_setup_virtual_lun0() */
@@ -646,12 +660,11 @@ static int core_tpg_setup_virtual_lun0(struct se_portal_group *se_tpg)
 	atomic_set(&lun->lun_acl_count, 0);
 	init_completion(&lun->lun_shutdown_comp);
 	INIT_LIST_HEAD(&lun->lun_acl_list);
-	INIT_LIST_HEAD(&lun->lun_cmd_list);
 	spin_lock_init(&lun->lun_acl_lock);
-	spin_lock_init(&lun->lun_cmd_lock);
 	spin_lock_init(&lun->lun_sep_lock);
+	init_completion(&lun->lun_ref_comp);
 
-	ret = core_tpg_post_addlun(se_tpg, lun, lun_access, dev);
+	ret = core_tpg_add_lun(se_tpg, lun, lun_access, dev);
 	if (ret < 0)
 		return ret;
 
@@ -691,10 +704,9 @@ int core_tpg_register(
 		atomic_set(&lun->lun_acl_count, 0);
 		init_completion(&lun->lun_shutdown_comp);
 		INIT_LIST_HEAD(&lun->lun_acl_list);
-		INIT_LIST_HEAD(&lun->lun_cmd_list);
 		spin_lock_init(&lun->lun_acl_lock);
-		spin_lock_init(&lun->lun_cmd_lock);
 		spin_lock_init(&lun->lun_sep_lock);
+		init_completion(&lun->lun_ref_comp);
 	}
 
 	se_tpg->se_tpg_type = se_tpg_type;
@@ -777,7 +789,7 @@ int core_tpg_deregister(struct se_portal_group *se_tpg)
 }
 EXPORT_SYMBOL(core_tpg_deregister);
 
-struct se_lun *core_tpg_pre_addlun(
+struct se_lun *core_tpg_alloc_lun(
 	struct se_portal_group *tpg,
 	u32 unpacked_lun)
 {
@@ -807,18 +819,24 @@ struct se_lun *core_tpg_pre_addlun(
 	return lun;
 }
 
-int core_tpg_post_addlun(
+int core_tpg_add_lun(
 	struct se_portal_group *tpg,
 	struct se_lun *lun,
 	u32 lun_access,
-	void *lun_ptr)
+	struct se_device *dev)
 {
 	int ret;
 
-	ret = core_dev_export(lun_ptr, tpg, lun);
+	ret = percpu_ref_init(&lun->lun_ref, core_tpg_lun_ref_release);
 	if (ret < 0)
 		return ret;
 
+	ret = core_dev_export(dev, tpg, lun);
+	if (ret < 0) {
+		percpu_ref_cancel_init(&lun->lun_ref);
+		return ret;
+	}
+
 	spin_lock(&tpg->tpg_lun_lock);
 	lun->lun_access = lun_access;
 	lun->lun_status = TRANSPORT_LUN_STATUS_ACTIVE;
@@ -827,14 +845,6 @@ int core_tpg_post_addlun(
 	return 0;
 }
 
-static void core_tpg_shutdown_lun(
-	struct se_portal_group *tpg,
-	struct se_lun *lun)
-{
-	core_clear_lun_from_tpg(lun, tpg);
-	transport_clear_lun_from_sessions(lun);
-}
-
 struct se_lun *core_tpg_pre_dellun(
 	struct se_portal_group *tpg,
 	u32 unpacked_lun)
@@ -869,7 +879,8 @@ int core_tpg_post_dellun(
 	struct se_portal_group *tpg,
 	struct se_lun *lun)
 {
-	core_tpg_shutdown_lun(tpg, lun);
+	core_clear_lun_from_tpg(lun, tpg);
+	transport_clear_lun_ref(lun);
 
 	core_dev_unexport(lun->lun_se_dev, tpg, lun);
 
diff --git a/drivers/target/target_core_transport.c b/drivers/target/target_core_transport.c
old mode 100644
new mode 100755
index 21e3158..aa5046b
--- a/drivers/target/target_core_transport.c
+++ b/drivers/target/target_core_transport.c
@@ -3,7 +3,7 @@
  *
  * This file contains the Generic Target Engine Core.
  *
- * (c) Copyright 2002-2012 RisingTide Systems LLC.
+ * (c) Copyright 2002-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -28,7 +28,6 @@
 #include <linux/string.h>
 #include <linux/timer.h>
 #include <linux/slab.h>
-#include <linux/blkdev.h>
 #include <linux/spinlock.h>
 #include <linux/kthread.h>
 #include <linux/in.h>
@@ -52,6 +51,9 @@
 #include "target_core_pr.h"
 #include "target_core_ua.h"
 
+#define CREATE_TRACE_POINTS
+#include <trace/events/target.h>
+
 static struct workqueue_struct *target_completion_wq;
 static struct kmem_cache *se_sess_cache;
 struct kmem_cache *se_ua_cache;
@@ -60,11 +62,12 @@ struct kmem_cache *t10_alua_lu_gp_cache;
 struct kmem_cache *t10_alua_lu_gp_mem_cache;
 struct kmem_cache *t10_alua_tg_pt_gp_cache;
 struct kmem_cache *t10_alua_tg_pt_gp_mem_cache;
+struct kmem_cache *t10_alua_lba_map_cache;
+struct kmem_cache *t10_alua_lba_map_mem_cache;
 
 static void transport_complete_task_attr(struct se_cmd *cmd);
 static void transport_handle_queue_full(struct se_cmd *cmd,
 		struct se_device *dev);
-static int transport_generic_get_mem(struct se_cmd *cmd);
 static int transport_put_cmd(struct se_cmd *cmd);
 static void target_complete_ok_work(struct work_struct *work);
 
@@ -127,14 +130,36 @@ int init_se_kmem_caches(void)
 				"mem_t failed\n");
 		goto out_free_tg_pt_gp_cache;
 	}
+	t10_alua_lba_map_cache = kmem_cache_create(
+			"t10_alua_lba_map_cache",
+			sizeof(struct t10_alua_lba_map),
+			__alignof__(struct t10_alua_lba_map), 0, NULL);
+	if (!t10_alua_lba_map_cache) {
+		pr_err("kmem_cache_create() for t10_alua_lba_map_"
+				"cache failed\n");
+		goto out_free_tg_pt_gp_mem_cache;
+	}
+	t10_alua_lba_map_mem_cache = kmem_cache_create(
+			"t10_alua_lba_map_mem_cache",
+			sizeof(struct t10_alua_lba_map_member),
+			__alignof__(struct t10_alua_lba_map_member), 0, NULL);
+	if (!t10_alua_lba_map_mem_cache) {
+		pr_err("kmem_cache_create() for t10_alua_lba_map_mem_"
+				"cache failed\n");
+		goto out_free_lba_map_cache;
+	}
 
 	target_completion_wq = alloc_workqueue("target_completion",
 					       WQ_MEM_RECLAIM, 0);
 	if (!target_completion_wq)
-		goto out_free_tg_pt_gp_mem_cache;
+		goto out_free_lba_map_mem_cache;
 
 	return 0;
 
+out_free_lba_map_mem_cache:
+	kmem_cache_destroy(t10_alua_lba_map_mem_cache);
+out_free_lba_map_cache:
+	kmem_cache_destroy(t10_alua_lba_map_cache);
 out_free_tg_pt_gp_mem_cache:
 	kmem_cache_destroy(t10_alua_tg_pt_gp_mem_cache);
 out_free_tg_pt_gp_cache:
@@ -163,6 +188,8 @@ void release_se_kmem_caches(void)
 	kmem_cache_destroy(t10_alua_lu_gp_mem_cache);
 	kmem_cache_destroy(t10_alua_tg_pt_gp_cache);
 	kmem_cache_destroy(t10_alua_tg_pt_gp_mem_cache);
+	kmem_cache_destroy(t10_alua_lba_map_cache);
+	kmem_cache_destroy(t10_alua_lba_map_mem_cache);
 }
 
 /* This code ensures unique mib indexes are handed out. */
@@ -229,6 +256,57 @@ struct se_session *transport_init_session(void)
 }
 EXPORT_SYMBOL(transport_init_session);
 
+int transport_alloc_session_tags(struct se_session *se_sess,
+			         unsigned int tag_num, unsigned int tag_size)
+{
+	int rc;
+
+	se_sess->sess_cmd_map = kzalloc(tag_num * tag_size,
+					GFP_KERNEL | __GFP_NOWARN | __GFP_REPEAT);
+	if (!se_sess->sess_cmd_map) {
+		se_sess->sess_cmd_map = vzalloc(tag_num * tag_size);
+		if (!se_sess->sess_cmd_map) {
+			pr_err("Unable to allocate se_sess->sess_cmd_map\n");
+			return -ENOMEM;
+		}
+	}
+
+	rc = percpu_ida_init(&se_sess->sess_tag_pool, tag_num);
+	if (rc < 0) {
+		pr_err("Unable to init se_sess->sess_tag_pool,"
+			" tag_num: %u\n", tag_num);
+		if (is_vmalloc_addr(se_sess->sess_cmd_map))
+			vfree(se_sess->sess_cmd_map);
+		else
+			kfree(se_sess->sess_cmd_map);
+		se_sess->sess_cmd_map = NULL;
+		return -ENOMEM;
+	}
+
+	return 0;
+}
+EXPORT_SYMBOL(transport_alloc_session_tags);
+
+struct se_session *transport_init_session_tags(unsigned int tag_num,
+					       unsigned int tag_size)
+{
+	struct se_session *se_sess;
+	int rc;
+
+	se_sess = transport_init_session();
+	if (IS_ERR(se_sess))
+		return se_sess;
+
+	rc = transport_alloc_session_tags(se_sess, tag_num, tag_size);
+	if (rc < 0) {
+		transport_free_session(se_sess);
+		return ERR_PTR(-ENOMEM);
+	}
+
+	return se_sess;
+}
+EXPORT_SYMBOL(transport_init_session_tags);
+
 /*
  * Called with spin_lock_irqsave(&struct se_portal_group->session_lock called.
  */
@@ -364,6 +442,13 @@ EXPORT_SYMBOL(transport_deregister_session_configfs);
 
 void transport_free_session(struct se_session *se_sess)
 {
+	if (se_sess->sess_cmd_map) {
+		percpu_ida_destroy(&se_sess->sess_tag_pool);
+		if (is_vmalloc_addr(se_sess->sess_cmd_map))
+			vfree(se_sess->sess_cmd_map);
+		else
+			kfree(se_sess->sess_cmd_map);
+	}
 	kmem_cache_free(se_sess_cache, se_sess);
 }
 EXPORT_SYMBOL(transport_free_session);
@@ -413,7 +498,7 @@ void transport_deregister_session(struct se_session *se_sess)
 	pr_debug("TARGET_CORE[%s]: Deregistered fabric_sess\n",
 		se_tpg->se_tpg_tfo->get_fabric_name());
 	/*
-	 * If last kref is dropping now for an explict NodeACL, awake sleeping
+	 * If last kref is dropping now for an explicit NodeACL, awake sleeping
 	 * ->acl_free_comp caller to wakeup configfs se_node_acl->acl_group
 	 * removal context.
 	 */
@@ -424,9 +509,6 @@ void transport_deregister_session(struct se_session *se_sess)
 }
 EXPORT_SYMBOL(transport_deregister_session);
 
-/*
- * Called with cmd->t_state_lock held.
- */
 static void target_remove_from_state_list(struct se_cmd *cmd)
 {
 	struct se_device *dev = cmd->se_dev;
@@ -446,28 +528,11 @@ static void target_remove_from_state_list(struct se_cmd *cmd)
 	spin_unlock_irqrestore(&dev->execute_task_lock, flags);
 }
 
-static int transport_cmd_check_stop(struct se_cmd *cmd, bool remove_from_lists)
+static int transport_cmd_check_stop(struct se_cmd *cmd, bool remove_from_lists,
+				    bool write_pending)
 {
 	unsigned long flags;
 
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	/*
-	 * Determine if IOCTL context caller in requesting the stopping of this
-	 * command for LUN shutdown purposes.
-	 */
-	if (cmd->transport_state & CMD_T_LUN_STOP) {
-		pr_debug("%s:%d CMD_T_LUN_STOP for ITT: 0x%08x\n",
-			__func__, __LINE__, cmd->se_tfo->get_task_tag(cmd));
-
-		cmd->transport_state &= ~CMD_T_ACTIVE;
-		if (remove_from_lists)
-			target_remove_from_state_list(cmd);
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-
-		complete(&cmd->transport_lun_stop_comp);
-		return 1;
-	}
-
 	if (remove_from_lists) {
 		target_remove_from_state_list(cmd);
 
@@ -477,6 +542,10 @@ static int transport_cmd_check_stop(struct se_cmd *cmd, bool remove_from_lists)
 		cmd->se_lun = NULL;
 	}
 
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	if (write_pending)
+		cmd->t_state = TRANSPORT_WRITE_PENDING;
+
 	/*
 	 * Determine if frontend context caller is requesting the stopping of
 	 * this command for frontend exceptions.
@@ -488,7 +557,7 @@ static int transport_cmd_check_stop(struct se_cmd *cmd, bool remove_from_lists)
 
 		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
 
-		complete(&cmd->t_transport_stop_comp);
+		complete_all(&cmd->t_transport_stop_comp);
 		return 1;
 	}
 
@@ -515,35 +584,36 @@ static int transport_cmd_check_stop(struct se_cmd *cmd, bool remove_from_lists)
 
 static int transport_cmd_check_stop_to_fabric(struct se_cmd *cmd)
 {
-	return transport_cmd_check_stop(cmd, true);
+	return transport_cmd_check_stop(cmd, true, false);
 }
 
 static void transport_lun_remove_cmd(struct se_cmd *cmd)
 {
 	struct se_lun *lun = cmd->se_lun;
-	unsigned long flags;
 
 	if (!lun)
 		return;
 
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	if (cmd->transport_state & CMD_T_DEV_ACTIVE) {
-		cmd->transport_state &= ~CMD_T_DEV_ACTIVE;
-		target_remove_from_state_list(cmd);
-	}
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-
-	spin_lock_irqsave(&lun->lun_cmd_lock, flags);
-	if (!list_empty(&cmd->se_lun_node))
-		list_del_init(&cmd->se_lun_node);
-	spin_unlock_irqrestore(&lun->lun_cmd_lock, flags);
+	if (cmpxchg(&cmd->lun_ref_active, true, false))
+		percpu_ref_put(&lun->lun_ref);
 }
 
 void transport_cmd_finish_abort(struct se_cmd *cmd, int remove)
 {
+	bool ack_kref = (cmd->se_cmd_flags & SCF_ACK_KREF);
+
+	if (cmd->se_cmd_flags & SCF_SE_LUN_CMD)
+		transport_lun_remove_cmd(cmd);
+	/*
+	 * Allow the fabric driver to unmap any resources before
+	 * releasing the descriptor via TFO->release_cmd()
+	 */
+	if (remove)
+		cmd->se_tfo->aborted_task(cmd);
+
 	if (transport_cmd_check_stop_to_fabric(cmd))
 		return;
-	if (remove)
+	if (remove && ack_kref)
 		transport_put_cmd(cmd);
 }
 
@@ -607,19 +677,16 @@ void target_complete_cmd(struct se_cmd *cmd, u8 scsi_status)
 		return;
 	}
 
-	if (!success)
-		cmd->transport_state |= CMD_T_FAILED;
-
 	/*
-	 * Check for case where an explict ABORT_TASK has been received
+	 * Check for case where an explicit ABORT_TASK has been received
 	 * and transport_wait_for_tasks() will be waiting for completion..
 	 */
-	if (cmd->transport_state & CMD_T_ABORTED &&
+	if (cmd->transport_state & CMD_T_ABORTED ||
 	    cmd->transport_state & CMD_T_STOP) {
 		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-		complete(&cmd->t_transport_stop_comp);
+		complete_all(&cmd->t_transport_stop_comp);
 		return;
-	} else if (cmd->transport_state & CMD_T_FAILED) {
+	} else if (!success) {
 		INIT_WORK(&cmd->work, target_complete_failure_work);
 	} else {
 		INIT_WORK(&cmd->work, target_complete_ok_work);
@@ -633,6 +700,23 @@ void target_complete_cmd(struct se_cmd *cmd, u8 scsi_status)
 }
 EXPORT_SYMBOL(target_complete_cmd);
 
+void target_complete_cmd_with_length(struct se_cmd *cmd, u8 scsi_status, int length)
+{
+	if (scsi_status == SAM_STAT_GOOD && length < cmd->data_length) {
+		if (cmd->se_cmd_flags & SCF_UNDERFLOW_BIT) {
+			cmd->residual_count += cmd->data_length - length;
+		} else {
+			cmd->se_cmd_flags |= SCF_UNDERFLOW_BIT;
+			cmd->residual_count = cmd->data_length - length;
+		}
+
+		cmd->data_length = length;
+	}
+
+	target_complete_cmd(cmd, scsi_status);
+}
+EXPORT_SYMBOL(target_complete_cmd_with_length);
+
 static void target_add_to_state_list(struct se_cmd *cmd)
 {
 	struct se_device *dev = cmd->se_dev;
@@ -1035,17 +1119,15 @@ void transport_init_se_cmd(
 	int task_attr,
 	unsigned char *sense_buffer)
 {
-	INIT_LIST_HEAD(&cmd->se_lun_node);
 	INIT_LIST_HEAD(&cmd->se_delayed_node);
 	INIT_LIST_HEAD(&cmd->se_qf_node);
 	INIT_LIST_HEAD(&cmd->se_cmd_list);
 	INIT_LIST_HEAD(&cmd->state_list);
-	init_completion(&cmd->transport_lun_fe_stop_comp);
-	init_completion(&cmd->transport_lun_stop_comp);
 	init_completion(&cmd->t_transport_stop_comp);
 	init_completion(&cmd->cmd_wait_comp);
 	init_completion(&cmd->task_stop_comp);
 	spin_lock_init(&cmd->t_state_lock);
+	kref_init(&cmd->cmd_kref);
 	cmd->transport_state = CMD_T_DEV_ACTIVE;
 
 	cmd->se_tfo = tfo;
@@ -1092,7 +1174,6 @@ sense_reason_t
 target_setup_cmd_from_cdb(struct se_cmd *cmd, unsigned char *cdb)
 {
 	struct se_device *dev = cmd->se_dev;
-	unsigned long flags;
 	sense_reason_t ret;
 
 	/*
@@ -1127,6 +1208,8 @@ target_setup_cmd_from_cdb(struct se_cmd *cmd, unsigned char *cdb)
 	 */
 	memcpy(cmd->t_task_cdb, cdb, scsi_command_size(cdb));
 
+	trace_target_sequencer_start(cmd);
+
 	/*
 	 * Check for an existing UNIT ATTENTION condition
 	 */
@@ -1152,9 +1235,7 @@ target_setup_cmd_from_cdb(struct se_cmd *cmd, unsigned char *cdb)
 	if (ret)
 		return ret;
 
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
 	cmd->se_cmd_flags |= SCF_SUPPORTED_SAM_OPCODE;
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
 
 	spin_lock(&cmd->se_lun->lun_sep_lock);
 	if (cmd->se_lun->lun_sep)
@@ -1207,7 +1288,7 @@ int transport_handle_cdb_direct(
 }
 EXPORT_SYMBOL(transport_handle_cdb_direct);
 
-static sense_reason_t
+sense_reason_t
 transport_generic_map_mem_to_cmd(struct se_cmd *cmd, struct scatterlist *sgl,
 		u32 sgl_count, struct scatterlist *sgl_bidi, u32 sgl_bidi_count)
 {
@@ -1253,6 +1334,8 @@ transport_generic_map_mem_to_cmd(struct se_cmd *cmd, struct scatterlist *sgl,
  * @sgl_count: scatterlist count for unidirectional mapping
  * @sgl_bidi: struct scatterlist memory for bidirectional READ mapping
  * @sgl_bidi_count: scatterlist count for bidirectional READ mapping
+ * @sgl_prot: struct scatterlist memory protection information
+ * @sgl_prot_count: scatterlist count for protection information
  *
  * Returns non zero to signal active I/O shutdown failure.  All other
  * setup exceptions will be returned as a SCSI CHECK_CONDITION response,
@@ -1265,7 +1348,8 @@ int target_submit_cmd_map_sgls(struct se_cmd *se_cmd, struct se_session *se_sess
 		unsigned char *cdb, unsigned char *sense, u32 unpacked_lun,
 		u32 data_length, int task_attr, int data_dir, int flags,
 		struct scatterlist *sgl, u32 sgl_count,
-		struct scatterlist *sgl_bidi, u32 sgl_bidi_count)
+		struct scatterlist *sgl_bidi, u32 sgl_bidi_count,
+		struct scatterlist *sgl_prot, u32 sgl_prot_count)
 {
 	struct se_portal_group *se_tpg;
 	sense_reason_t rc;
@@ -1313,6 +1397,16 @@ int target_submit_cmd_map_sgls(struct se_cmd *se_cmd, struct se_session *se_sess
 		transport_generic_request_failure(se_cmd, rc);
 		return 0;
 	}
+
+	/*
+	 * Save pointers for SGLs containing protection information,
+	 * if present.
+	 */
+	if (sgl_prot_count) {
+		se_cmd->t_prot_sg = sgl_prot;
+		se_cmd->t_prot_nents = sgl_prot_count;
+	}
+
 	/*
 	 * When a non zero sgl_count has been passed perform SGL passthrough
 	 * mapping for pre-allocated fabric memory instead of having target
@@ -1349,6 +1443,7 @@ int target_submit_cmd_map_sgls(struct se_cmd *se_cmd, struct se_session *se_sess
 			return 0;
 		}
 	}
+
 	/*
 	 * Check if we need to delay processing because of ALUA
 	 * Active/NonOptimized primary access state..
@@ -1388,7 +1483,7 @@ int target_submit_cmd(struct se_cmd *se_cmd, struct se_session *se_sess,
 {
 	return target_submit_cmd_map_sgls(se_cmd, se_sess, cdb, sense,
 			unpacked_lun, data_length, task_attr, data_dir,
-			flags, NULL, 0, NULL, 0);
+			flags, NULL, 0, NULL, 0, NULL, 0);
 }
 EXPORT_SYMBOL(target_submit_cmd);
 
@@ -1496,7 +1591,7 @@ bool target_stop_cmd(struct se_cmd *cmd, unsigned long *flags)
 void transport_generic_request_failure(struct se_cmd *cmd,
 		sense_reason_t sense_reason)
 {
-	int ret = 0;
+	int ret = 0, post_ret = 0;
 
 	pr_debug("-----[ Storage Engine Exception for cmd: %p ITT: 0x%08x"
 		" CDB: 0x%02x\n", cmd, cmd->se_tfo->get_task_tag(cmd),
@@ -1513,6 +1608,13 @@ void transport_generic_request_failure(struct se_cmd *cmd,
 	 * For SAM Task Attribute emulation for failed struct se_cmd
 	 */
 	transport_complete_task_attr(cmd);
+	/*
+	 * Handle special case for COMPARE_AND_WRITE failure, where the
+	 * callback is expected to drop the per device ->caw_sem.
+	 */
+	if ((cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE) &&
+	     cmd->transport_complete_callback)
+		cmd->transport_complete_callback(cmd, false, &post_ret);
 
 	switch (sense_reason) {
 	case TCM_NON_EXISTENT_LUN:
@@ -1527,6 +1629,9 @@ void transport_generic_request_failure(struct se_cmd *cmd,
 	case TCM_CHECK_CONDITION_ABORT_CMD:
 	case TCM_CHECK_CONDITION_UNIT_ATTENTION:
 	case TCM_CHECK_CONDITION_NOT_READY:
+	case TCM_LOGICAL_BLOCK_GUARD_CHECK_FAILED:
+	case TCM_LOGICAL_BLOCK_APP_TAG_CHECK_FAILED:
+	case TCM_LOGICAL_BLOCK_REF_TAG_CHECK_FAILED:
 		break;
 	case TCM_OUT_OF_RESOURCES:
 		sense_reason = TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
@@ -1552,7 +1657,8 @@ void transport_generic_request_failure(struct se_cmd *cmd,
 				cmd->orig_fe_lun, 0x2C,
 				ASCQ_2CH_PREVIOUS_RESERVATION_CONFLICT_STATUS);
 
-		ret = cmd->se_tfo->queue_status(cmd);
+		trace_target_cmd_complete(cmd);
+		ret = cmd->se_tfo-> queue_status(cmd);
 		if (ret == -EAGAIN || ret == -ENOMEM)
 			goto queue_full;
 		goto check_stop;
@@ -1579,14 +1685,10 @@ queue_full:
 }
 EXPORT_SYMBOL(transport_generic_request_failure);
 
-static void __target_execute_cmd(struct se_cmd *cmd)
+void __target_execute_cmd(struct se_cmd *cmd)
 {
 	sense_reason_t ret;
 
-	spin_lock_irq(&cmd->t_state_lock);
-	cmd->transport_state |= (CMD_T_BUSY|CMD_T_SENT);
-	spin_unlock_irq(&cmd->t_state_lock);
-
 	if (cmd->execute_cmd) {
 		ret = cmd->execute_cmd(cmd);
 		if (ret) {
@@ -1654,50 +1756,52 @@ static bool target_handle_task_attr(struct se_cmd *cmd)
 	return true;
 }
 
+static int __transport_check_aborted_status(struct se_cmd *, int);
+
 void target_execute_cmd(struct se_cmd *cmd)
 {
 	/*
+	 * Determine if frontend context caller is requesting the stopping of
+	 * this command for frontend exceptions.
+	 *
 	 * If the received CDB has aleady been aborted stop processing it here.
 	 */
-	if (transport_check_aborted_status(cmd, 1)) {
-		complete(&cmd->transport_lun_stop_comp);
-		return;
-	}
-
-	/*
-	 * Determine if IOCTL context caller in requesting the stopping of this
-	 * command for LUN shutdown purposes.
-	 */
 	spin_lock_irq(&cmd->t_state_lock);
-	if (cmd->transport_state & CMD_T_LUN_STOP) {
-		pr_debug("%s:%d CMD_T_LUN_STOP for ITT: 0x%08x\n",
-			__func__, __LINE__, cmd->se_tfo->get_task_tag(cmd));
-
-		cmd->transport_state &= ~CMD_T_ACTIVE;
+	if (__transport_check_aborted_status(cmd, 1)) {
 		spin_unlock_irq(&cmd->t_state_lock);
-		complete(&cmd->transport_lun_stop_comp);
 		return;
 	}
-	/*
-	 * Determine if frontend context caller is requesting the stopping of
-	 * this command for frontend exceptions.
-	 */
 	if (cmd->transport_state & CMD_T_STOP) {
 		pr_debug("%s:%d CMD_T_STOP for ITT: 0x%08x\n",
 			__func__, __LINE__,
 			cmd->se_tfo->get_task_tag(cmd));
 
 		spin_unlock_irq(&cmd->t_state_lock);
-		complete(&cmd->t_transport_stop_comp);
+		complete_all(&cmd->t_transport_stop_comp);
 		return;
 	}
 
 	cmd->t_state = TRANSPORT_PROCESSING;
-	cmd->transport_state |= CMD_T_ACTIVE;
+	cmd->transport_state |= CMD_T_ACTIVE|CMD_T_BUSY|CMD_T_SENT;
 	spin_unlock_irq(&cmd->t_state_lock);
+	/*
+	 * Perform WRITE_INSERT of PI using software emulation when backend
+	 * device has PI enabled, if the transport has not already generated
+	 * PI using hardware WRITE_INSERT offload.
+	 */
+	if (cmd->prot_op == TARGET_PROT_DOUT_INSERT) {
+		if (!(cmd->se_sess->sup_prot_ops & TARGET_PROT_DOUT_INSERT))
+			sbc_dif_generate(cmd);
+	}
 
-	if (!target_handle_task_attr(cmd))
-		__target_execute_cmd(cmd);
+	if (target_handle_task_attr(cmd)) {
+		spin_lock_irq(&cmd->t_state_lock);
+		cmd->transport_state &= ~CMD_T_BUSY|CMD_T_SENT;
+		spin_unlock_irq(&cmd->t_state_lock);
+		return;
+	}
+
+	__target_execute_cmd(cmd);
 }
 EXPORT_SYMBOL(target_execute_cmd);
 
@@ -1770,23 +1874,25 @@ static void transport_complete_qf(struct se_cmd *cmd)
 	transport_complete_task_attr(cmd);
 
 	if (cmd->se_cmd_flags & SCF_TRANSPORT_TASK_SENSE) {
+		trace_target_cmd_complete(cmd);
 		ret = cmd->se_tfo->queue_status(cmd);
-		if (ret)
-			goto out;
+		goto out;
 	}
 
 	switch (cmd->data_direction) {
 	case DMA_FROM_DEVICE:
+		trace_target_cmd_complete(cmd);
 		ret = cmd->se_tfo->queue_data_in(cmd);
 		break;
 	case DMA_TO_DEVICE:
-		if (cmd->t_bidi_data_sg) {
+		if (cmd->se_cmd_flags & SCF_BIDI) {
 			ret = cmd->se_tfo->queue_data_in(cmd);
 			if (ret < 0)
 				break;
 		}
 		/* Fall through for DMA_TO_DEVICE */
 	case DMA_NONE:
+		trace_target_cmd_complete(cmd);
 		ret = cmd->se_tfo->queue_status(cmd);
 		break;
 	default:
@@ -1815,6 +1921,21 @@ static void transport_handle_queue_full(
 	schedule_work(&cmd->se_dev->qf_work_queue);
 }
 
+static bool target_check_read_strip(struct se_cmd *cmd)
+{
+	sense_reason_t rc;
+
+	if (!(cmd->se_sess->sup_prot_ops & TARGET_PROT_DIN_STRIP)) {
+		rc = sbc_dif_read_strip(cmd);
+		if (rc) {
+			cmd->pi_err = rc;
+			return true;
+		}
+	}
+
+	return false;
+}
+
 static void target_complete_ok_work(struct work_struct *work)
 {
 	struct se_cmd *cmd = container_of(work, struct se_cmd, work);
@@ -1851,11 +1972,33 @@ static void target_complete_ok_work(struct work_struct *work)
 	}
 	/*
 	 * Check for a callback, used by amongst other things
-	 * XDWRITE_READ_10 emulation.
+	 * XDWRITE_READ_10 and COMPARE_AND_WRITE emulation.
 	 */
-	if (cmd->transport_complete_callback)
-		cmd->transport_complete_callback(cmd);
+	if (cmd->transport_complete_callback) {
+		sense_reason_t rc;
+		bool caw = (cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE);
+		bool zero_dl = !(cmd->data_length);
+		int post_ret = 0;
+
+		rc = cmd->transport_complete_callback(cmd, true, &post_ret);
+		if (!rc && !post_ret) {
+			if (caw && zero_dl)
+				goto queue_rsp;
+
+			return;
+		} else if (rc) {
+			ret = transport_send_check_condition_and_sense(cmd,
+						rc, 0);
+			if (ret == -EAGAIN || ret == -ENOMEM)
+				goto queue_full;
+
+			transport_lun_remove_cmd(cmd);
+			transport_cmd_check_stop_to_fabric(cmd);
+			return;
+		}
+	}
 
+queue_rsp:
 	switch (cmd->data_direction) {
 	case DMA_FROM_DEVICE:
 		spin_lock(&cmd->se_lun->lun_sep_lock);
@@ -1864,7 +2007,24 @@ static void target_complete_ok_work(struct work_struct *work)
 					cmd->data_length;
 		}
 		spin_unlock(&cmd->se_lun->lun_sep_lock);
+		/*
+		 * Perform READ_STRIP of PI using software emulation when
+		 * backend had PI enabled, if the transport will not be
+		 * performing hardware READ_STRIP offload.
+		 */
+		if (cmd->prot_op == TARGET_PROT_DIN_STRIP &&
+		    target_check_read_strip(cmd)) {
+			ret = transport_send_check_condition_and_sense(cmd,
+						cmd->pi_err, 0);
+			if (ret == -EAGAIN || ret == -ENOMEM)
+				goto queue_full;
+
+			transport_lun_remove_cmd(cmd);
+			transport_cmd_check_stop_to_fabric(cmd);
+			return;
+		}
 
+		trace_target_cmd_complete(cmd);
 		ret = cmd->se_tfo->queue_data_in(cmd);
 		if (ret == -EAGAIN || ret == -ENOMEM)
 			goto queue_full;
@@ -1879,7 +2039,7 @@ static void target_complete_ok_work(struct work_struct *work)
 		/*
 		 * Check if we need to send READ payload for BIDI-COMMAND
 		 */
-		if (cmd->t_bidi_data_sg) {
+		if (cmd->se_cmd_flags & SCF_BIDI) {
 			spin_lock(&cmd->se_lun->lun_sep_lock);
 			if (cmd->se_lun->lun_sep) {
 				cmd->se_lun->lun_sep->sep_stats.tx_data_octets +=
@@ -1893,6 +2053,7 @@ static void target_complete_ok_work(struct work_struct *work)
 		}
 		/* Fall through for DMA_TO_DEVICE */
 	case DMA_NONE:
+		trace_target_cmd_complete(cmd);
 		ret = cmd->se_tfo->queue_status(cmd);
 		if (ret == -EAGAIN || ret == -ENOMEM)
 			goto queue_full;
@@ -1923,10 +2084,39 @@ static inline void transport_free_sgl(struct scatterlist *sgl, int nents)
 	kfree(sgl);
 }
 
+static inline void transport_reset_sgl_orig(struct se_cmd *cmd)
+{
+	/*
+	 * Check for saved t_data_sg that may be used for COMPARE_AND_WRITE
+	 * emulation, and free + reset pointers if necessary..
+	 */
+	if (!cmd->t_data_sg_orig)
+		return;
+
+	kfree(cmd->t_data_sg);
+	cmd->t_data_sg = cmd->t_data_sg_orig;
+	cmd->t_data_sg_orig = NULL;
+	cmd->t_data_nents = cmd->t_data_nents_orig;
+	cmd->t_data_nents_orig = 0;
+}
+
 static inline void transport_free_pages(struct se_cmd *cmd)
 {
-	if (cmd->se_cmd_flags & SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC)
+	if (cmd->se_cmd_flags & SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC) {
+		/*
+		 * Release special case READ buffer payload required for
+		 * SG_TO_MEM_NOALLOC to function with COMPARE_AND_WRITE
+		 */
+		if (cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE) {
+			transport_free_sgl(cmd->t_bidi_data_sg,
+					   cmd->t_bidi_data_nents);
+			cmd->t_bidi_data_sg = NULL;
+			cmd->t_bidi_data_nents = 0;
+		}
+		transport_reset_sgl_orig(cmd);
 		return;
+	}
+	transport_reset_sgl_orig(cmd);
 
 	transport_free_sgl(cmd->t_data_sg, cmd->t_data_nents);
 	cmd->t_data_sg = NULL;
@@ -1935,32 +2125,10 @@ static inline void transport_free_pages(struct se_cmd *cmd)
 	transport_free_sgl(cmd->t_bidi_data_sg, cmd->t_bidi_data_nents);
 	cmd->t_bidi_data_sg = NULL;
 	cmd->t_bidi_data_nents = 0;
-}
-
-/**
- * transport_release_cmd - free a command
- * @cmd:       command to free
- *
- * This routine unconditionally frees a command, and reference counting
- * or list removal must be done in the caller.
- */
-static int transport_release_cmd(struct se_cmd *cmd)
-{
-	BUG_ON(!cmd->se_tfo);
-
-	if (cmd->se_cmd_flags & SCF_SCSI_TMR_CDB)
-		core_tmr_release_req(cmd->se_tmr_req);
-	if (cmd->t_task_cdb != cmd->__t_task_cdb)
-		kfree(cmd->t_task_cdb);
-	/*
-	 * If this cmd has been setup with target_get_sess_cmd(), drop
-	 * the kref and call ->release_cmd() in kref callback.
-	 */
-	 if (cmd->check_release != 0)
-		return target_put_sess_cmd(cmd->se_sess, cmd);
 
-	cmd->se_tfo->release_cmd(cmd);
-	return 1;
+	transport_free_sgl(cmd->t_prot_sg, cmd->t_prot_nents);
+	cmd->t_prot_sg = NULL;
+	cmd->t_prot_nents = 0;
 }
 
 /**
@@ -1971,23 +2139,12 @@ static int transport_release_cmd(struct se_cmd *cmd)
  */
 static int transport_put_cmd(struct se_cmd *cmd)
 {
-	unsigned long flags;
-
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	if (atomic_read(&cmd->t_fe_count) &&
-	    !atomic_dec_and_test(&cmd->t_fe_count)) {
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-		return 0;
-	}
-
-	if (cmd->transport_state & CMD_T_DEV_ACTIVE) {
-		cmd->transport_state &= ~CMD_T_DEV_ACTIVE;
-		target_remove_from_state_list(cmd);
-	}
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-
-	transport_free_pages(cmd);
-	return transport_release_cmd(cmd);
+	BUG_ON(!cmd->se_tfo);
+	/*
+	 * If this cmd has been setup with target_get_sess_cmd(), drop
+	 * the kref and call ->release_cmd() in kref callback.
+	 */
+	return target_put_sess_cmd(cmd->se_sess, cmd);
 }
 
 void *transport_kmap_data_sg(struct se_cmd *cmd)
@@ -2041,24 +2198,22 @@ void transport_kunmap_data_sg(struct se_cmd *cmd)
 }
 EXPORT_SYMBOL(transport_kunmap_data_sg);
 
-static int
-transport_generic_get_mem(struct se_cmd *cmd)
+int
+target_alloc_sgl(struct scatterlist **sgl, unsigned int *nents, u32 length,
+		 bool zero_page)
 {
-	u32 length = cmd->data_length;
-	unsigned int nents;
+	struct scatterlist *sg;
 	struct page *page;
-	gfp_t zero_flag;
+	gfp_t zero_flag = (zero_page) ? __GFP_ZERO : 0;
+	unsigned int nent;
 	int i = 0;
 
-	nents = DIV_ROUND_UP(length, PAGE_SIZE);
-	cmd->t_data_sg = kmalloc(sizeof(struct scatterlist) * nents, GFP_KERNEL);
-	if (!cmd->t_data_sg)
+	nent = DIV_ROUND_UP(length, PAGE_SIZE);
+	sg = kmalloc(sizeof(struct scatterlist) * nent, GFP_KERNEL);
+	if (!sg)
 		return -ENOMEM;
 
-	cmd->t_data_nents = nents;
-	sg_init_table(cmd->t_data_sg, nents);
-
-	zero_flag = cmd->se_cmd_flags & SCF_SCSI_DATA_CDB ? 0 : __GFP_ZERO;
+	sg_init_table(sg, nent);
 
 	while (length) {
 		u32 page_len = min_t(u32, length, PAGE_SIZE);
@@ -2066,19 +2221,20 @@ transport_generic_get_mem(struct se_cmd *cmd)
 		if (!page)
 			goto out;
 
-		sg_set_page(&cmd->t_data_sg[i], page, page_len, 0);
+		sg_set_page(&sg[i], page, page_len, 0);
 		length -= page_len;
 		i++;
 	}
+	*sgl = sg;
+	*nents = nent;
 	return 0;
 
 out:
 	while (i > 0) {
 		i--;
-		__free_page(sg_page(&cmd->t_data_sg[i]));
+		__free_page(sg_page(&sg[i]));
 	}
-	kfree(cmd->t_data_sg);
-	cmd->t_data_sg = NULL;
+	kfree(sg);
 	return -ENOMEM;
 }
 
@@ -2091,6 +2247,7 @@ sense_reason_t
 transport_generic_new_cmd(struct se_cmd *cmd)
 {
 	int ret = 0;
+	bool zero_flag = !(cmd->se_cmd_flags & SCF_SCSI_DATA_CDB);
 
 	/*
 	 * Determine is the TCM fabric module has already allocated physical
@@ -2099,29 +2256,62 @@ transport_generic_new_cmd(struct se_cmd *cmd)
 	 */
 	if (!(cmd->se_cmd_flags & SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC) &&
 	    cmd->data_length) {
-		ret = transport_generic_get_mem(cmd);
+
+		if ((cmd->se_cmd_flags & SCF_BIDI) ||
+		    (cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE)) {
+			u32 bidi_length;
+
+			if (cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE)
+				bidi_length = cmd->t_task_nolb *
+					      cmd->se_dev->dev_attrib.block_size;
+			else
+				bidi_length = cmd->data_length;
+
+			ret = target_alloc_sgl(&cmd->t_bidi_data_sg,
+					       &cmd->t_bidi_data_nents,
+					       bidi_length, zero_flag);
+			if (ret < 0)
+				return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+		}
+
+		if (cmd->prot_op != TARGET_PROT_NORMAL) {
+			ret = target_alloc_sgl(&cmd->t_prot_sg,
+					       &cmd->t_prot_nents,
+					       cmd->prot_length, true);
+			if (ret < 0)
+				return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+		}
+
+		ret = target_alloc_sgl(&cmd->t_data_sg, &cmd->t_data_nents,
+				       cmd->data_length, zero_flag);
 		if (ret < 0)
 			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
-	}
-
-	atomic_inc(&cmd->t_fe_count);
+	} else if ((cmd->se_cmd_flags & SCF_COMPARE_AND_WRITE) &&
+		    cmd->data_length) {
+		/*
+		 * Special case for COMPARE_AND_WRITE with fabrics
+		 * using SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC.
+		 */
+		u32 caw_length = cmd->t_task_nolb *
+				 cmd->se_dev->dev_attrib.block_size;
 
+		ret = target_alloc_sgl(&cmd->t_bidi_data_sg,
+				       &cmd->t_bidi_data_nents,
+				       caw_length, zero_flag);
+		if (ret < 0)
+			return TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+	}
 	/*
 	 * If this command is not a write we can execute it right here,
 	 * for write buffers we need to notify the fabric driver first
 	 * and let it call back once the write buffers are ready.
 	 */
 	target_add_to_state_list(cmd);
-	if (cmd->data_direction != DMA_TO_DEVICE) {
+	if (cmd->data_direction != DMA_TO_DEVICE || cmd->data_length == 0) {
 		target_execute_cmd(cmd);
 		return 0;
 	}
-
-	spin_lock_irq(&cmd->t_state_lock);
-	cmd->t_state = TRANSPORT_WRITE_PENDING;
-	spin_unlock_irq(&cmd->t_state_lock);
-
-	transport_cmd_check_stop(cmd, false);
+	transport_cmd_check_stop(cmd, false, true);
 
 	ret = cmd->se_tfo->write_pending(cmd);
 	if (ret == -EAGAIN || ret == -ENOMEM)
@@ -2152,23 +2342,59 @@ static void transport_write_pending_qf(struct se_cmd *cmd)
 	}
 }
 
+static bool
+__transport_wait_for_tasks(struct se_cmd *, bool, bool *, bool *,
+			   unsigned long *flags);
+
+static void target_wait_free_cmd(struct se_cmd *cmd, bool *aborted, bool *tas)
+{
+	unsigned long flags;
+
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	__transport_wait_for_tasks(cmd, true, aborted, tas, &flags);
+	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+}
+
 int transport_generic_free_cmd(struct se_cmd *cmd, int wait_for_tasks)
 {
 	int ret = 0;
+	bool aborted = false, tas = false;
 
 	if (!(cmd->se_cmd_flags & SCF_SE_LUN_CMD)) {
 		if (wait_for_tasks && (cmd->se_cmd_flags & SCF_SCSI_TMR_CDB))
-			 transport_wait_for_tasks(cmd);
+			target_wait_free_cmd(cmd, &aborted, &tas);
 
-		ret = transport_release_cmd(cmd);
+		if (!aborted || tas)
+			ret = transport_put_cmd(cmd);
 	} else {
 		if (wait_for_tasks)
-			transport_wait_for_tasks(cmd);
+			target_wait_free_cmd(cmd, &aborted, &tas);
+		/*
+		 * Handle WRITE failure case where transport_generic_new_cmd()
+		 * has already added se_cmd to state_list, but fabric has
+		 * failed command before I/O submission.
+		 */
+		if (cmd->state_active)
+			target_remove_from_state_list(cmd);
 
 		if (cmd->se_lun)
 			transport_lun_remove_cmd(cmd);
 
-		ret = transport_put_cmd(cmd);
+		if (!aborted || tas)
+			ret = transport_put_cmd(cmd);
+	}
+	/*
+	 * If the task has been internally aborted due to TMR ABORT_TASK
+	 * or LUN_RESET, target_core_tmr.c is responsible for performing
+	 * the remaining calls to target_put_sess_cmd(), and not the
+	 * callers of this function.
+	 */
+	if (aborted) {
+		pr_debug("Detected CMD_T_ABORTED for ITT: %u\n",
+			cmd->se_tfo->get_task_tag(cmd));
+		wait_for_completion(&cmd->cmd_wait_comp);
+		cmd->se_tfo->release_cmd(cmd);
+		ret = 1;
 	}
 	return ret;
 }
@@ -2185,7 +2411,6 @@ int target_get_sess_cmd(struct se_session *se_sess, struct se_cmd *se_cmd,
 	unsigned long flags;
 	int ret = 0;
 
-	kref_init(&se_cmd->cmd_kref);
 	/*
 	 * Add a second kref if the fabric caller is expecting to handle
 	 * fabric acknowledgement that requires two target_put_sess_cmd()
@@ -2202,32 +2427,54 @@ int target_get_sess_cmd(struct se_session *se_sess, struct se_cmd *se_cmd,
 		goto out;
 	}
 	list_add_tail(&se_cmd->se_cmd_list, &se_sess->sess_cmd_list);
-	se_cmd->check_release = 1;
-
 out:
 	spin_unlock_irqrestore(&se_sess->sess_cmd_lock, flags);
+
+	if (ret && ack_kref)
+		target_put_sess_cmd(se_sess, se_cmd);
+
 	return ret;
 }
 EXPORT_SYMBOL(target_get_sess_cmd);
 
+static void target_free_cmd_mem(struct se_cmd *cmd)
+{
+	transport_free_pages(cmd);
+
+	if (cmd->se_cmd_flags & SCF_SCSI_TMR_CDB)
+		core_tmr_release_req(cmd->se_tmr_req);
+	if (cmd->t_task_cdb != cmd->__t_task_cdb)
+		kfree(cmd->t_task_cdb);
+}
+
 static void target_release_cmd_kref(struct kref *kref)
 {
 	struct se_cmd *se_cmd = container_of(kref, struct se_cmd, cmd_kref);
 	struct se_session *se_sess = se_cmd->se_sess;
+	bool fabric_stop;
 
 	if (list_empty(&se_cmd->se_cmd_list)) {
 		spin_unlock(&se_sess->sess_cmd_lock);
+		target_free_cmd_mem(se_cmd);
 		se_cmd->se_tfo->release_cmd(se_cmd);
 		return;
 	}
-	if (se_sess->sess_tearing_down && se_cmd->cmd_wait_set) {
+
+	spin_lock(&se_cmd->t_state_lock);
+	fabric_stop = (se_cmd->transport_state & CMD_T_FABRIC_STOP);
+	spin_unlock(&se_cmd->t_state_lock);
+
+	if (se_cmd->cmd_wait_set || fabric_stop) {
+		list_del_init(&se_cmd->se_cmd_list);
 		spin_unlock(&se_sess->sess_cmd_lock);
+		target_free_cmd_mem(se_cmd);
 		complete(&se_cmd->cmd_wait_comp);
 		return;
 	}
-	list_del(&se_cmd->se_cmd_list);
+	list_del_init(&se_cmd->se_cmd_list);
 	spin_unlock(&se_sess->sess_cmd_lock);
 
+	target_free_cmd_mem(se_cmd);
 	se_cmd->se_tfo->release_cmd(se_cmd);
 }
 
@@ -2237,6 +2484,11 @@ static void target_release_cmd_kref(struct kref *kref)
  */
 int target_put_sess_cmd(struct se_session *se_sess, struct se_cmd *se_cmd)
 {
+	if (!se_sess) {
+		target_free_cmd_mem(se_cmd);
+		se_cmd->se_tfo->release_cmd(se_cmd);
+		return 1;
+	}
 	return kref_put_spinlock_irqsave(&se_cmd->cmd_kref, target_release_cmd_kref,
 			&se_sess->sess_cmd_lock);
 }
@@ -2251,6 +2503,7 @@ void target_sess_cmd_list_set_waiting(struct se_session *se_sess)
 {
 	struct se_cmd *se_cmd;
 	unsigned long flags;
+	int rc;
 
 	spin_lock_irqsave(&se_sess->sess_cmd_lock, flags);
 	if (se_sess->sess_tearing_down) {
@@ -2260,8 +2513,15 @@ void target_sess_cmd_list_set_waiting(struct se_session *se_sess)
 	se_sess->sess_tearing_down = 1;
 	list_splice_init(&se_sess->sess_cmd_list, &se_sess->sess_wait_list);
 
-	list_for_each_entry(se_cmd, &se_sess->sess_wait_list, se_cmd_list)
-		se_cmd->cmd_wait_set = 1;
+	list_for_each_entry(se_cmd, &se_sess->sess_wait_list, se_cmd_list) {
+		rc = kref_get_unless_zero(&se_cmd->cmd_kref);
+		if (rc) {
+			se_cmd->cmd_wait_set = 1;
+			spin_lock(&se_cmd->t_state_lock);
+			se_cmd->transport_state |= CMD_T_FABRIC_STOP;
+			spin_unlock(&se_cmd->t_state_lock);
+		}
+	}
 
 	spin_unlock_irqrestore(&se_sess->sess_cmd_lock, flags);
 }
@@ -2274,15 +2534,23 @@ void target_wait_for_sess_cmds(struct se_session *se_sess)
 {
 	struct se_cmd *se_cmd, *tmp_cmd;
 	unsigned long flags;
+	bool tas;
 
 	list_for_each_entry_safe(se_cmd, tmp_cmd,
 				&se_sess->sess_wait_list, se_cmd_list) {
-		list_del(&se_cmd->se_cmd_list);
-
 		pr_debug("Waiting for se_cmd: %p t_state: %d, fabric state:"
 			" %d\n", se_cmd, se_cmd->t_state,
 			se_cmd->se_tfo->get_cmd_state(se_cmd));
 
+		spin_lock_irqsave(&se_cmd->t_state_lock, flags);
+		tas = (se_cmd->transport_state & CMD_T_TAS);
+		spin_unlock_irqrestore(&se_cmd->t_state_lock, flags);
+
+		if (!target_put_sess_cmd(se_sess, se_cmd)) {
+			if (tas)
+				target_put_sess_cmd(se_sess, se_cmd);
+		}
+
 		wait_for_completion(&se_cmd->cmd_wait_comp);
 		pr_debug("After cmd_wait_comp: se_cmd: %p t_state: %d"
 			" fabric state: %d\n", se_cmd, se_cmd->t_state,
@@ -2298,164 +2566,23 @@ void target_wait_for_sess_cmds(struct se_session *se_sess)
 }
 EXPORT_SYMBOL(target_wait_for_sess_cmds);
 
-/*	transport_lun_wait_for_tasks():
- *
- *	Called from ConfigFS context to stop the passed struct se_cmd to allow
- *	an struct se_lun to be successfully shutdown.
- */
-static int transport_lun_wait_for_tasks(struct se_cmd *cmd, struct se_lun *lun)
-{
-	unsigned long flags;
-	int ret = 0;
-
-	/*
-	 * If the frontend has already requested this struct se_cmd to
-	 * be stopped, we can safely ignore this struct se_cmd.
-	 */
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	if (cmd->transport_state & CMD_T_STOP) {
-		cmd->transport_state &= ~CMD_T_LUN_STOP;
-
-		pr_debug("ConfigFS ITT[0x%08x] - CMD_T_STOP, skipping\n",
-			 cmd->se_tfo->get_task_tag(cmd));
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-		transport_cmd_check_stop(cmd, false);
-		return -EPERM;
-	}
-	cmd->transport_state |= CMD_T_LUN_FE_STOP;
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-
-	// XXX: audit task_flags checks.
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	if ((cmd->transport_state & CMD_T_BUSY) &&
-	    (cmd->transport_state & CMD_T_SENT)) {
-		if (!target_stop_cmd(cmd, &flags))
-			ret++;
-	}
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-
-	pr_debug("ConfigFS: cmd: %p stop tasks ret:"
-			" %d\n", cmd, ret);
-	if (!ret) {
-		pr_debug("ConfigFS: ITT[0x%08x] - stopping cmd....\n",
-				cmd->se_tfo->get_task_tag(cmd));
-		wait_for_completion(&cmd->transport_lun_stop_comp);
-		pr_debug("ConfigFS: ITT[0x%08x] - stopped cmd....\n",
-				cmd->se_tfo->get_task_tag(cmd));
-	}
-
-	return 0;
-}
-
-static void __transport_clear_lun_from_sessions(struct se_lun *lun)
-{
-	struct se_cmd *cmd = NULL;
-	unsigned long lun_flags, cmd_flags;
-	/*
-	 * Do exception processing and return CHECK_CONDITION status to the
-	 * Initiator Port.
-	 */
-	spin_lock_irqsave(&lun->lun_cmd_lock, lun_flags);
-	while (!list_empty(&lun->lun_cmd_list)) {
-		cmd = list_first_entry(&lun->lun_cmd_list,
-		       struct se_cmd, se_lun_node);
-		list_del_init(&cmd->se_lun_node);
-
-		spin_lock(&cmd->t_state_lock);
-		pr_debug("SE_LUN[%d] - Setting cmd->transport"
-			"_lun_stop for  ITT: 0x%08x\n",
-			cmd->se_lun->unpacked_lun,
-			cmd->se_tfo->get_task_tag(cmd));
-		cmd->transport_state |= CMD_T_LUN_STOP;
-		spin_unlock(&cmd->t_state_lock);
-
-		spin_unlock_irqrestore(&lun->lun_cmd_lock, lun_flags);
-
-		if (!cmd->se_lun) {
-			pr_err("ITT: 0x%08x, [i,t]_state: %u/%u\n",
-				cmd->se_tfo->get_task_tag(cmd),
-				cmd->se_tfo->get_cmd_state(cmd), cmd->t_state);
-			BUG();
-		}
-		/*
-		 * If the Storage engine still owns the iscsi_cmd_t, determine
-		 * and/or stop its context.
-		 */
-		pr_debug("SE_LUN[%d] - ITT: 0x%08x before transport"
-			"_lun_wait_for_tasks()\n", cmd->se_lun->unpacked_lun,
-			cmd->se_tfo->get_task_tag(cmd));
-
-		if (transport_lun_wait_for_tasks(cmd, cmd->se_lun) < 0) {
-			spin_lock_irqsave(&lun->lun_cmd_lock, lun_flags);
-			continue;
-		}
-
-		pr_debug("SE_LUN[%d] - ITT: 0x%08x after transport_lun"
-			"_wait_for_tasks(): SUCCESS\n",
-			cmd->se_lun->unpacked_lun,
-			cmd->se_tfo->get_task_tag(cmd));
-
-		spin_lock_irqsave(&cmd->t_state_lock, cmd_flags);
-		if (!(cmd->transport_state & CMD_T_DEV_ACTIVE)) {
-			spin_unlock_irqrestore(&cmd->t_state_lock, cmd_flags);
-			goto check_cond;
-		}
-		cmd->transport_state &= ~CMD_T_DEV_ACTIVE;
-		target_remove_from_state_list(cmd);
-		spin_unlock_irqrestore(&cmd->t_state_lock, cmd_flags);
-
-		/*
-		 * The Storage engine stopped this struct se_cmd before it was
-		 * send to the fabric frontend for delivery back to the
-		 * Initiator Node.  Return this SCSI CDB back with an
-		 * CHECK_CONDITION status.
-		 */
-check_cond:
-		transport_send_check_condition_and_sense(cmd,
-				TCM_NON_EXISTENT_LUN, 0);
-		/*
-		 *  If the fabric frontend is waiting for this iscsi_cmd_t to
-		 * be released, notify the waiting thread now that LU has
-		 * finished accessing it.
-		 */
-		spin_lock_irqsave(&cmd->t_state_lock, cmd_flags);
-		if (cmd->transport_state & CMD_T_LUN_FE_STOP) {
-			pr_debug("SE_LUN[%d] - Detected FE stop for"
-				" struct se_cmd: %p ITT: 0x%08x\n",
-				lun->unpacked_lun,
-				cmd, cmd->se_tfo->get_task_tag(cmd));
-
-			spin_unlock_irqrestore(&cmd->t_state_lock,
-					cmd_flags);
-			transport_cmd_check_stop(cmd, false);
-			complete(&cmd->transport_lun_fe_stop_comp);
-			spin_lock_irqsave(&lun->lun_cmd_lock, lun_flags);
-			continue;
-		}
-		pr_debug("SE_LUN[%d] - ITT: 0x%08x finished processing\n",
-			lun->unpacked_lun, cmd->se_tfo->get_task_tag(cmd));
-
-		spin_unlock_irqrestore(&cmd->t_state_lock, cmd_flags);
-		spin_lock_irqsave(&lun->lun_cmd_lock, lun_flags);
-	}
-	spin_unlock_irqrestore(&lun->lun_cmd_lock, lun_flags);
-}
-
-static int transport_clear_lun_thread(void *p)
+static int transport_clear_lun_ref_thread(void *p)
 {
 	struct se_lun *lun = p;
 
-	__transport_clear_lun_from_sessions(lun);
+	percpu_ref_kill(&lun->lun_ref);
+
+	wait_for_completion(&lun->lun_ref_comp);
 	complete(&lun->lun_shutdown_comp);
 
 	return 0;
 }
 
-int transport_clear_lun_from_sessions(struct se_lun *lun)
+int transport_clear_lun_ref(struct se_lun *lun)
 {
 	struct task_struct *kt;
 
-	kt = kthread_run(transport_clear_lun_thread, lun,
+	kt = kthread_run(transport_clear_lun_ref_thread, lun,
 			"tcm_cl_%u", lun->unpacked_lun);
 	if (IS_ERR(kt)) {
 		pr_err("Unable to start clear_lun thread\n");
@@ -2466,71 +2593,38 @@ int transport_clear_lun_from_sessions(struct se_lun *lun)
 	return 0;
 }
 
-/**
- * transport_wait_for_tasks - wait for completion to occur
- * @cmd:	command to wait
- *
- * Called from frontend fabric context to wait for storage engine
- * to pause and/or release frontend generated struct se_cmd.
- */
-bool transport_wait_for_tasks(struct se_cmd *cmd)
+static bool
+__transport_wait_for_tasks(struct se_cmd *cmd, bool fabric_stop,
+			   bool *aborted, bool *tas, unsigned long *flags)
+	__releases(&cmd->t_state_lock)
+	__acquires(&cmd->t_state_lock)
 {
-	unsigned long flags;
 
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	assert_spin_locked(&cmd->t_state_lock);
+	WARN_ON_ONCE(!irqs_disabled());
+
+	if (fabric_stop)
+		cmd->transport_state |= CMD_T_FABRIC_STOP;
+
+	if (cmd->transport_state & CMD_T_ABORTED)
+		*aborted = true;
+
+	if (cmd->transport_state & CMD_T_TAS)
+		*tas = true;
+
 	if (!(cmd->se_cmd_flags & SCF_SE_LUN_CMD) &&
-	    !(cmd->se_cmd_flags & SCF_SCSI_TMR_CDB)) {
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+	    !(cmd->se_cmd_flags & SCF_SCSI_TMR_CDB))
 		return false;
-	}
 
 	if (!(cmd->se_cmd_flags & SCF_SUPPORTED_SAM_OPCODE) &&
-	    !(cmd->se_cmd_flags & SCF_SCSI_TMR_CDB)) {
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+	    !(cmd->se_cmd_flags & SCF_SCSI_TMR_CDB))
 		return false;
-	}
-	/*
-	 * If we are already stopped due to an external event (ie: LUN shutdown)
-	 * sleep until the connection can have the passed struct se_cmd back.
-	 * The cmd->transport_lun_stopped_sem will be upped by
-	 * transport_clear_lun_from_sessions() once the ConfigFS context caller
-	 * has completed its operation on the struct se_cmd.
-	 */
-	if (cmd->transport_state & CMD_T_LUN_STOP) {
-		pr_debug("wait_for_tasks: Stopping"
-			" wait_for_completion(&cmd->t_tasktransport_lun_fe"
-			"_stop_comp); for ITT: 0x%08x\n",
-			cmd->se_tfo->get_task_tag(cmd));
-		/*
-		 * There is a special case for WRITES where a FE exception +
-		 * LUN shutdown means ConfigFS context is still sleeping on
-		 * transport_lun_stop_comp in transport_lun_wait_for_tasks().
-		 * We go ahead and up transport_lun_stop_comp just to be sure
-		 * here.
-		 */
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
-		complete(&cmd->transport_lun_stop_comp);
-		wait_for_completion(&cmd->transport_lun_fe_stop_comp);
-		spin_lock_irqsave(&cmd->t_state_lock, flags);
 
-		target_remove_from_state_list(cmd);
-		/*
-		 * At this point, the frontend who was the originator of this
-		 * struct se_cmd, now owns the structure and can be released through
-		 * normal means below.
-		 */
-		pr_debug("wait_for_tasks: Stopped"
-			" wait_for_completion(&cmd->t_tasktransport_lun_fe_"
-			"stop_comp); for ITT: 0x%08x\n",
-			cmd->se_tfo->get_task_tag(cmd));
-
-		cmd->transport_state &= ~CMD_T_LUN_STOP;
-	}
+	if (!(cmd->transport_state & CMD_T_ACTIVE))
+		return false;
 
-	if (!(cmd->transport_state & CMD_T_ACTIVE)) {
-		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+	if (fabric_stop && *aborted)
 		return false;
-	}
 
 	cmd->transport_state |= CMD_T_STOP;
 
@@ -2539,20 +2633,37 @@ bool transport_wait_for_tasks(struct se_cmd *cmd)
 		cmd, cmd->se_tfo->get_task_tag(cmd),
 		cmd->se_tfo->get_cmd_state(cmd), cmd->t_state);
 
-	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+	spin_unlock_irqrestore(&cmd->t_state_lock, *flags);
 
 	wait_for_completion(&cmd->t_transport_stop_comp);
 
-	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	spin_lock_irqsave(&cmd->t_state_lock, *flags);
 	cmd->transport_state &= ~(CMD_T_ACTIVE | CMD_T_STOP);
 
 	pr_debug("wait_for_tasks: Stopped wait_for_completion("
 		"&cmd->t_transport_stop_comp) for ITT: 0x%08x\n",
 		cmd->se_tfo->get_task_tag(cmd));
 
+	return true;
+}
+
+/**
+ * transport_wait_for_tasks - wait for completion to occur
+ * @cmd:	command to wait
+ *
+ * Called from frontend fabric context to wait for storage engine
+ * to pause and/or release frontend generated struct se_cmd.
+ */
+bool transport_wait_for_tasks(struct se_cmd *cmd)
+{
+	unsigned long flags;
+	bool ret, aborted = false, tas = false;
+
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	ret = __transport_wait_for_tasks(cmd, false, &aborted, &tas, &flags);
 	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
 
-	return true;
+	return ret;
 }
 EXPORT_SYMBOL(transport_wait_for_tasks);
 
@@ -2567,6 +2678,19 @@ static int transport_get_sense_codes(
 	return 0;
 }
 
+static
+void transport_err_sector_info(unsigned char *buffer, sector_t bad_sector)
+{
+	/* Place failed LBA in sense data information descriptor 0. */
+	buffer[SPC_ADD_SENSE_LEN_OFFSET] = 0xc;
+	buffer[SPC_DESC_TYPE_OFFSET] = 0; /* Information */
+	buffer[SPC_ADDITIONAL_DESC_LEN_OFFSET] = 0xa;
+	buffer[SPC_VALIDITY_OFFSET] = 0x80;
+
+	/* Descriptor Information: failing sector */
+	put_unaligned_be64(bad_sector, &buffer[12]);
+}
+
 int
 transport_send_check_condition_and_sense(struct se_cmd *cmd,
 		sense_reason_t reason, int from_transport)
@@ -2751,6 +2875,48 @@ transport_send_check_condition_and_sense(struct se_cmd *cmd,
 		buffer[SPC_ASC_KEY_OFFSET] = asc;
 		buffer[SPC_ASCQ_KEY_OFFSET] = ascq;
 		break;
+	case TCM_MISCOMPARE_VERIFY:
+		/* CURRENT ERROR */
+		buffer[0] = 0x70;
+		buffer[SPC_ADD_SENSE_LEN_OFFSET] = 10;
+		buffer[SPC_SENSE_KEY_OFFSET] = MISCOMPARE;
+		/* MISCOMPARE DURING VERIFY OPERATION */
+		buffer[SPC_ASC_KEY_OFFSET] = 0x1d;
+		buffer[SPC_ASCQ_KEY_OFFSET] = 0x00;
+		break;
+	case TCM_LOGICAL_BLOCK_GUARD_CHECK_FAILED:
+		/* CURRENT ERROR */
+		buffer[0] = 0x70;
+		buffer[SPC_ADD_SENSE_LEN_OFFSET] = 10;
+		/* ILLEGAL REQUEST */
+		buffer[SPC_SENSE_KEY_OFFSET] = ILLEGAL_REQUEST;
+		/* LOGICAL BLOCK GUARD CHECK FAILED */
+		buffer[SPC_ASC_KEY_OFFSET] = 0x10;
+		buffer[SPC_ASCQ_KEY_OFFSET] = 0x01;
+		transport_err_sector_info(buffer, cmd->bad_sector);
+		break;
+	case TCM_LOGICAL_BLOCK_APP_TAG_CHECK_FAILED:
+		/* CURRENT ERROR */
+		buffer[0] = 0x70;
+		buffer[SPC_ADD_SENSE_LEN_OFFSET] = 10;
+		/* ILLEGAL REQUEST */
+		buffer[SPC_SENSE_KEY_OFFSET] = ILLEGAL_REQUEST;
+		/* LOGICAL BLOCK APPLICATION TAG CHECK FAILED */
+		buffer[SPC_ASC_KEY_OFFSET] = 0x10;
+		buffer[SPC_ASCQ_KEY_OFFSET] = 0x02;
+		transport_err_sector_info(buffer, cmd->bad_sector);
+		break;
+	case TCM_LOGICAL_BLOCK_REF_TAG_CHECK_FAILED:
+		/* CURRENT ERROR */
+		buffer[0] = 0x70;
+		buffer[SPC_ADD_SENSE_LEN_OFFSET] = 10;
+		/* ILLEGAL REQUEST */
+		buffer[SPC_SENSE_KEY_OFFSET] = ILLEGAL_REQUEST;
+		/* LOGICAL BLOCK REFERENCE TAG CHECK FAILED */
+		buffer[SPC_ASC_KEY_OFFSET] = 0x10;
+		buffer[SPC_ASCQ_KEY_OFFSET] = 0x03;
+		transport_err_sector_info(buffer, cmd->bad_sector);
+		break;
 	case TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE:
 	default:
 		/* CURRENT ERROR */
@@ -2778,26 +2944,56 @@ transport_send_check_condition_and_sense(struct se_cmd *cmd,
 	cmd->scsi_sense_length  = TRANSPORT_SENSE_BUFFER;
 
 after_reason:
+	trace_target_cmd_complete(cmd);
 	return cmd->se_tfo->queue_status(cmd);
 }
 EXPORT_SYMBOL(transport_send_check_condition_and_sense);
 
-int transport_check_aborted_status(struct se_cmd *cmd, int send_status)
+static int __transport_check_aborted_status(struct se_cmd *cmd, int send_status)
+	__releases(&cmd->t_state_lock)
+	__acquires(&cmd->t_state_lock)
 {
+	assert_spin_locked(&cmd->t_state_lock);
+	WARN_ON_ONCE(!irqs_disabled());
+
 	if (!(cmd->transport_state & CMD_T_ABORTED))
 		return 0;
 
-	if (!send_status || (cmd->se_cmd_flags & SCF_SENT_DELAYED_TAS))
+	/*
+	 * If cmd has been aborted but either no status is to be sent or it has
+	 * already been sent, just return
+	 */
+	if (!send_status || !(cmd->se_cmd_flags & SCF_SEND_DELAYED_TAS)) {
+		if (send_status)
+			cmd->se_cmd_flags |= SCF_SEND_DELAYED_TAS;
 		return 1;
+	}
+
+	pr_debug("Sending delayed SAM_STAT_TASK_ABORTED status for CDB:"
+		" 0x%02x ITT: 0x%08x\n", cmd->t_task_cdb[0],
+		cmd->se_tfo->get_task_tag(cmd));
 
-	pr_debug("Sending delayed SAM_STAT_TASK_ABORTED status for CDB: 0x%02x ITT: 0x%08x\n",
-		 cmd->t_task_cdb[0], cmd->se_tfo->get_task_tag(cmd));
+	cmd->se_cmd_flags &= ~SCF_SEND_DELAYED_TAS;
+	cmd->scsi_status = SAM_STAT_TASK_ABORTED;
+	trace_target_cmd_complete(cmd);
 
-	cmd->se_cmd_flags |= SCF_SENT_DELAYED_TAS;
+	spin_unlock_irq(&cmd->t_state_lock);
 	cmd->se_tfo->queue_status(cmd);
+	spin_lock_irq(&cmd->t_state_lock);
 
 	return 1;
 }
+
+int transport_check_aborted_status(struct se_cmd *cmd, int send_status)
+{
+	int ret;
+
+	spin_lock_irq(&cmd->t_state_lock);
+	ret = __transport_check_aborted_status(cmd, send_status);
+	spin_unlock_irq(&cmd->t_state_lock);
+
+	return ret;
+}
 EXPORT_SYMBOL(transport_check_aborted_status);
 
 void transport_send_task_abort(struct se_cmd *cmd)
@@ -2805,7 +3001,7 @@ void transport_send_task_abort(struct se_cmd *cmd)
 	unsigned long flags;
 
 	spin_lock_irqsave(&cmd->t_state_lock, flags);
-	if (cmd->se_cmd_flags & (SCF_SENT_CHECK_CONDITION | SCF_SENT_DELAYED_TAS)) {
+	if (cmd->se_cmd_flags & (SCF_SENT_CHECK_CONDITION)) {
 		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
 		return;
 	}
@@ -2819,10 +3015,17 @@ void transport_send_task_abort(struct se_cmd *cmd)
 	 */
 	if (cmd->data_direction == DMA_TO_DEVICE) {
 		if (cmd->se_tfo->write_pending_status(cmd) != 0) {
-			cmd->transport_state |= CMD_T_ABORTED;
-			smp_mb__after_atomic_inc();
+			spin_lock_irqsave(&cmd->t_state_lock, flags);
+			if (cmd->se_cmd_flags & SCF_SEND_DELAYED_TAS) {
+				spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+				goto send_abort;
+			}
+			cmd->se_cmd_flags |= SCF_SEND_DELAYED_TAS;
+			spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+			return;
 		}
 	}
+send_abort:
 	cmd->scsi_status = SAM_STAT_TASK_ABORTED;
 
 	transport_lun_remove_cmd(cmd);
@@ -2831,6 +3034,7 @@ void transport_send_task_abort(struct se_cmd *cmd)
 		" ITT: 0x%08x\n", cmd->t_task_cdb[0],
 		cmd->se_tfo->get_task_tag(cmd));
 
+	trace_target_cmd_complete(cmd);
 	cmd->se_tfo->queue_status(cmd);
 }
 
@@ -2839,8 +3043,17 @@ static void target_tmr_work(struct work_struct *work)
 	struct se_cmd *cmd = container_of(work, struct se_cmd, work);
 	struct se_device *dev = cmd->se_dev;
 	struct se_tmr_req *tmr = cmd->se_tmr_req;
+	unsigned long flags;
 	int ret;
 
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	if (cmd->transport_state & CMD_T_ABORTED) {
+		tmr->response = TMR_FUNCTION_REJECTED;
+		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+		goto check_stop;
+	}
+	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+
 	switch (tmr->function) {
 	case TMR_ABORT_TASK:
 		core_tmr_abort_task(dev, tmr, cmd->se_sess);
@@ -2868,15 +3081,29 @@ static void target_tmr_work(struct work_struct *work)
 		break;
 	}
 
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	if (cmd->transport_state & CMD_T_ABORTED) {
+		spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+		goto check_stop;
+	}
 	cmd->t_state = TRANSPORT_ISTATE_PROCESSING;
+	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+
 	cmd->se_tfo->queue_tm_rsp(cmd);
 
+check_stop:
 	transport_cmd_check_stop_to_fabric(cmd);
 }
 
 int transport_generic_handle_tmr(
 	struct se_cmd *cmd)
 {
+	unsigned long flags;
+
+	spin_lock_irqsave(&cmd->t_state_lock, flags);
+	cmd->transport_state |= CMD_T_ACTIVE;
+	spin_unlock_irqrestore(&cmd->t_state_lock, flags);
+
 	INIT_WORK(&cmd->work, target_tmr_work);
 	queue_work(cmd->se_dev->tmr_wq, &cmd->work);
 	return 0;
diff --git a/drivers/target/target_core_ua.c b/drivers/target/target_core_ua.c
index bf0e390c..505519b 100644
--- a/drivers/target/target_core_ua.c
+++ b/drivers/target/target_core_ua.c
@@ -3,7 +3,7 @@
  *
  * This file contains logic for SPC-3 Unit Attention emulation
  *
- * (c) Copyright 2009-2012 RisingTide Systems LLC.
+ * (c) Copyright 2009-2013 Datera, Inc.
  *
  * Nicholas A. Bellinger <nab@kernel.org>
  *
@@ -98,7 +98,6 @@ int core_scsi3_ua_allocate(
 		pr_err("Unable to allocate struct se_ua\n");
 		return -ENOMEM;
 	}
-	INIT_LIST_HEAD(&ua->ua_dev_list);
 	INIT_LIST_HEAD(&ua->ua_nacl_list);
 
 	ua->ua_nacl = nacl;
diff --git a/drivers/target/target_core_ua.h b/drivers/target/target_core_ua.h
index 0204952..be912b3 100644
--- a/drivers/target/target_core_ua.h
+++ b/drivers/target/target_core_ua.h
@@ -19,7 +19,7 @@
 #define ASCQ_2AH_RESERVATIONS_RELEASED				0x04
 #define ASCQ_2AH_REGISTRATIONS_PREEMPTED			0x05
 #define ASCQ_2AH_ASYMMETRIC_ACCESS_STATE_CHANGED		0x06
-#define ASCQ_2AH_IMPLICT_ASYMMETRIC_ACCESS_STATE_TRANSITION_FAILED 0x07
+#define ASCQ_2AH_IMPLICIT_ASYMMETRIC_ACCESS_STATE_TRANSITION_FAILED 0x07
 #define ASCQ_2AH_PRIORITY_CHANGED				0x08
 
 #define ASCQ_2CH_PREVIOUS_RESERVATION_CONFLICT_STATUS		0x09
diff --git a/drivers/target/target_core_xcopy.c b/drivers/target/target_core_xcopy.c
new file mode 100644
index 00000000..669c536
--- /dev/null
+++ b/drivers/target/target_core_xcopy.c
@@ -0,0 +1,1081 @@
+/*******************************************************************************
+ * Filename: target_core_xcopy.c
+ *
+ * This file contains support for SPC-4 Extended-Copy offload with generic
+ * TCM backends.
+ *
+ * Copyright (c) 2011-2013 Datera, Inc. All rights reserved.
+ *
+ * Author:
+ * Nicholas A. Bellinger <nab@daterainc.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ ******************************************************************************/
+
+#include <linux/slab.h>
+#include <linux/spinlock.h>
+#include <linux/list.h>
+#include <linux/configfs.h>
+#include <scsi/scsi.h>
+#include <scsi/scsi_cmnd.h>
+#include <asm/unaligned.h>
+
+#include <target/target_core_base.h>
+#include <target/target_core_backend.h>
+#include <target/target_core_fabric.h>
+#include <target/target_core_configfs.h>
+
+#include "target_core_pr.h"
+#include "target_core_ua.h"
+#include "target_core_xcopy.h"
+
+static struct workqueue_struct *xcopy_wq = NULL;
+/*
+ * From target_core_device.c
+ */
+extern struct mutex g_device_mutex;
+extern struct list_head g_device_list;
+/*
+ * From target_core_configfs.c
+ */
+extern struct configfs_subsystem *target_core_subsystem[];
+
+static int target_xcopy_gen_naa_ieee(struct se_device *dev, unsigned char *buf)
+{
+	int off = 0;
+
+	buf[off++] = (0x6 << 4);
+	buf[off++] = 0x01;
+	buf[off++] = 0x40;
+	buf[off] = (0x5 << 4);
+
+	spc_parse_naa_6h_vendor_specific(dev, &buf[off]);
+	return 0;
+}
+
+static int target_xcopy_locate_se_dev_e4(struct se_cmd *se_cmd, struct xcopy_op *xop,
+					bool src)
+{
+	struct se_device *se_dev;
+	struct configfs_subsystem *subsys = target_core_subsystem[0];
+	unsigned char tmp_dev_wwn[XCOPY_NAA_IEEE_REGEX_LEN], *dev_wwn;
+	int rc;
+
+	if (src == true)
+		dev_wwn = &xop->dst_tid_wwn[0];
+	else
+		dev_wwn = &xop->src_tid_wwn[0];
+
+	mutex_lock(&g_device_mutex);
+	list_for_each_entry(se_dev, &g_device_list, g_dev_node) {
+
+		if (!se_dev->dev_attrib.emulate_3pc)
+			continue;
+
+		memset(&tmp_dev_wwn[0], 0, XCOPY_NAA_IEEE_REGEX_LEN);
+		target_xcopy_gen_naa_ieee(se_dev, &tmp_dev_wwn[0]);
+
+		rc = memcmp(&tmp_dev_wwn[0], dev_wwn, XCOPY_NAA_IEEE_REGEX_LEN);
+		if (rc != 0)
+			continue;
+
+		if (src == true) {
+			xop->dst_dev = se_dev;
+			pr_debug("XCOPY 0xe4: Setting xop->dst_dev: %p from located"
+				" se_dev\n", xop->dst_dev);
+		} else {
+			xop->src_dev = se_dev;
+			pr_debug("XCOPY 0xe4: Setting xop->src_dev: %p from located"
+				" se_dev\n", xop->src_dev);
+		}
+
+		rc = configfs_depend_item(subsys,
+				&se_dev->dev_group.cg_item);
+		if (rc != 0) {
+			pr_err("configfs_depend_item attempt failed:"
+				" %d for se_dev: %p\n", rc, se_dev);
+			mutex_unlock(&g_device_mutex);
+			return rc;
+		}
+
+		pr_debug("Called configfs_depend_item for subsys: %p se_dev: %p"
+			" se_dev->se_dev_group: %p\n", subsys, se_dev,
+			&se_dev->dev_group);
+
+		mutex_unlock(&g_device_mutex);
+		return 0;
+	}
+	mutex_unlock(&g_device_mutex);
+
+	pr_err("Unable to locate 0xe4 descriptor for EXTENDED_COPY\n");
+	return -EINVAL;
+}
+
+static int target_xcopy_parse_tiddesc_e4(struct se_cmd *se_cmd, struct xcopy_op *xop,
+				unsigned char *p, bool src)
+{
+	unsigned char *desc = p;
+	unsigned short ript;
+	u8 desig_len;
+	/*
+	 * Extract RELATIVE INITIATOR PORT IDENTIFIER
+	 */
+	ript = get_unaligned_be16(&desc[2]);
+	pr_debug("XCOPY 0xe4: RELATIVE INITIATOR PORT IDENTIFIER: %hu\n", ript);
+	/*
+	 * Check for supported code set, association, and designator type
+	 */
+	if ((desc[4] & 0x0f) != 0x1) {
+		pr_err("XCOPY 0xe4: code set of non binary type not supported\n");
+		return -EINVAL;
+	}
+	if ((desc[5] & 0x30) != 0x00) {
+		pr_err("XCOPY 0xe4: association other than LUN not supported\n");
+		return -EINVAL;
+	}
+	if ((desc[5] & 0x0f) != 0x3) {
+		pr_err("XCOPY 0xe4: designator type unsupported: 0x%02x\n",
+				(desc[5] & 0x0f));
+		return -EINVAL;
+	}
+	/*
+	 * Check for matching 16 byte length for NAA IEEE Registered Extended
+	 * Assigned designator
+	 */
+	desig_len = desc[7];
+	if (desig_len != 16) {
+		pr_err("XCOPY 0xe4: invalid desig_len: %d\n", (int)desig_len);
+		return -EINVAL;
+	}
+	pr_debug("XCOPY 0xe4: desig_len: %d\n", (int)desig_len);
+	/*
+	 * Check for NAA IEEE Registered Extended Assigned header..
+	 */
+	if ((desc[8] & 0xf0) != 0x60) {
+		pr_err("XCOPY 0xe4: Unsupported DESIGNATOR TYPE: 0x%02x\n",
+					(desc[8] & 0xf0));
+		return -EINVAL;
+	}
+
+	if (src == true) {
+		memcpy(&xop->src_tid_wwn[0], &desc[8], XCOPY_NAA_IEEE_REGEX_LEN);
+		/*
+		 * Determine if the source designator matches the local device
+		 */
+		if (!memcmp(&xop->local_dev_wwn[0], &xop->src_tid_wwn[0],
+				XCOPY_NAA_IEEE_REGEX_LEN)) {
+			xop->op_origin = XCOL_SOURCE_RECV_OP;
+			xop->src_dev = se_cmd->se_dev;
+			pr_debug("XCOPY 0xe4: Set xop->src_dev %p from source"
+					" received xop\n", xop->src_dev);
+		}
+	} else {
+		memcpy(&xop->dst_tid_wwn[0], &desc[8], XCOPY_NAA_IEEE_REGEX_LEN);
+		/*
+		 * Determine if the destination designator matches the local device
+		 */
+		if (!memcmp(&xop->local_dev_wwn[0], &xop->dst_tid_wwn[0],
+				XCOPY_NAA_IEEE_REGEX_LEN)) {
+			xop->op_origin = XCOL_DEST_RECV_OP;
+			xop->dst_dev = se_cmd->se_dev;
+			pr_debug("XCOPY 0xe4: Set xop->dst_dev: %p from destination"
+				" received xop\n", xop->dst_dev);
+		}
+	}
+
+	return 0;
+}
+
+static int target_xcopy_parse_target_descriptors(struct se_cmd *se_cmd,
+				struct xcopy_op *xop, unsigned char *p,
+				unsigned short tdll)
+{
+	struct se_device *local_dev = se_cmd->se_dev;
+	unsigned char *desc = p;
+	int offset = tdll % XCOPY_TARGET_DESC_LEN, rc, ret = 0;
+	unsigned short start = 0;
+	bool src = true;
+
+	if (offset != 0) {
+		pr_err("XCOPY target descriptor list length is not"
+			" multiple of %d\n", XCOPY_TARGET_DESC_LEN);
+		return -EINVAL;
+	}
+	if (tdll > 64) {
+		pr_err("XCOPY target descriptor supports a maximum"
+			" two src/dest descriptors, tdll: %hu too large..\n", tdll);
+		return -EINVAL;
+	}
+	/*
+	 * Generate an IEEE Registered Extended designator based upon the
+	 * se_device the XCOPY was received upon..
+	 */
+	memset(&xop->local_dev_wwn[0], 0, XCOPY_NAA_IEEE_REGEX_LEN);
+	target_xcopy_gen_naa_ieee(local_dev, &xop->local_dev_wwn[0]);
+
+	while (start < tdll) {
+		/*
+		 * Check target descriptor identification with 0xE4 type with
+		 * use VPD 0x83 WWPN matching ..
+		 */
+		switch (desc[0]) {
+		case 0xe4:
+			rc = target_xcopy_parse_tiddesc_e4(se_cmd, xop,
+							&desc[0], src);
+			if (rc != 0)
+				goto out;
+			/*
+			 * Assume target descriptors are in source -> destination order..
+			 */
+			if (src == true)
+				src = false;
+			else
+				src = true;
+			start += XCOPY_TARGET_DESC_LEN;
+			desc += XCOPY_TARGET_DESC_LEN;
+			ret++;
+			break;
+		default:
+			pr_err("XCOPY unsupported descriptor type code:"
+					" 0x%02x\n", desc[0]);
+			goto out;
+		}
+	}
+
+	if (xop->op_origin == XCOL_SOURCE_RECV_OP)
+		rc = target_xcopy_locate_se_dev_e4(se_cmd, xop, true);
+	else
+		rc = target_xcopy_locate_se_dev_e4(se_cmd, xop, false);
+
+	if (rc < 0)
+		goto out;
+
+	pr_debug("XCOPY TGT desc: Source dev: %p NAA IEEE WWN: 0x%16phN\n",
+		 xop->src_dev, &xop->src_tid_wwn[0]);
+	pr_debug("XCOPY TGT desc: Dest dev: %p NAA IEEE WWN: 0x%16phN\n",
+		 xop->dst_dev, &xop->dst_tid_wwn[0]);
+
+	return ret;
+
+out:
+	return -EINVAL;
+}
+
+static int target_xcopy_parse_segdesc_02(struct se_cmd *se_cmd, struct xcopy_op *xop,
+					unsigned char *p)
+{
+	unsigned char *desc = p;
+	int dc = (desc[1] & 0x02);
+	unsigned short desc_len;
+
+	desc_len = get_unaligned_be16(&desc[2]);
+	if (desc_len != 0x18) {
+		pr_err("XCOPY segment desc 0x02: Illegal desc_len:"
+				" %hu\n", desc_len);
+		return -EINVAL;
+	}
+
+	xop->stdi = get_unaligned_be16(&desc[4]);
+	xop->dtdi = get_unaligned_be16(&desc[6]);
+	pr_debug("XCOPY seg desc 0x02: desc_len: %hu stdi: %hu dtdi: %hu, DC: %d\n",
+		desc_len, xop->stdi, xop->dtdi, dc);
+
+	xop->nolb = get_unaligned_be16(&desc[10]);
+	xop->src_lba = get_unaligned_be64(&desc[12]);
+	xop->dst_lba = get_unaligned_be64(&desc[20]);
+	pr_debug("XCOPY seg desc 0x02: nolb: %hu src_lba: %llu dst_lba: %llu\n",
+		xop->nolb, (unsigned long long)xop->src_lba,
+		(unsigned long long)xop->dst_lba);
+
+	if (dc != 0) {
+		xop->dbl = (desc[29] & 0xff) << 16;
+		xop->dbl |= (desc[30] & 0xff) << 8;
+		xop->dbl |= desc[31] & 0xff;
+
+		pr_debug("XCOPY seg desc 0x02: DC=1 w/ dbl: %u\n", xop->dbl);
+	}
+	return 0;
+}
+
+static int target_xcopy_parse_segment_descriptors(struct se_cmd *se_cmd,
+				struct xcopy_op *xop, unsigned char *p,
+				unsigned int sdll)
+{
+	unsigned char *desc = p;
+	unsigned int start = 0;
+	int offset = sdll % XCOPY_SEGMENT_DESC_LEN, rc, ret = 0;
+
+	if (offset != 0) {
+		pr_err("XCOPY segment descriptor list length is not"
+			" multiple of %d\n", XCOPY_SEGMENT_DESC_LEN);
+		return -EINVAL;
+	}
+
+	while (start < sdll) {
+		/*
+		 * Check segment descriptor type code for block -> block
+		 */
+		switch (desc[0]) {
+		case 0x02:
+			rc = target_xcopy_parse_segdesc_02(se_cmd, xop, desc);
+			if (rc < 0)
+				goto out;
+
+			ret++;
+			start += XCOPY_SEGMENT_DESC_LEN;
+			desc += XCOPY_SEGMENT_DESC_LEN;
+			break;
+		default:
+			pr_err("XCOPY unspported segment descriptor"
+				"type: 0x%02x\n", desc[0]);
+			goto out;
+		}
+	}
+
+	return ret;
+
+out:
+	return -EINVAL;
+}
+
+/*
+ * Start xcopy_pt ops
+ */
+
+struct xcopy_pt_cmd {
+	bool remote_port;
+	struct se_cmd se_cmd;
+	struct xcopy_op *xcopy_op;
+	struct completion xpt_passthrough_sem;
+	unsigned char sense_buffer[TRANSPORT_SENSE_BUFFER];
+};
+
+static struct se_port xcopy_pt_port;
+static struct se_portal_group xcopy_pt_tpg;
+static struct se_session xcopy_pt_sess;
+static struct se_node_acl xcopy_pt_nacl;
+
+static char *xcopy_pt_get_fabric_name(void)
+{
+        return "xcopy-pt";
+}
+
+static u32 xcopy_pt_get_tag(struct se_cmd *se_cmd)
+{
+        return 0;
+}
+
+static int xcopy_pt_get_cmd_state(struct se_cmd *se_cmd)
+{
+        return 0;
+}
+
+static void xcopy_pt_undepend_remotedev(struct xcopy_op *xop)
+{
+	struct configfs_subsystem *subsys = target_core_subsystem[0];
+	struct se_device *remote_dev;
+
+	if (xop->op_origin == XCOL_SOURCE_RECV_OP)
+		remote_dev = xop->dst_dev;
+	else
+		remote_dev = xop->src_dev;
+
+	pr_debug("Calling configfs_undepend_item for subsys: %p"
+		  " remote_dev: %p remote_dev->dev_group: %p\n",
+		  subsys, remote_dev, &remote_dev->dev_group.cg_item);
+
+	configfs_undepend_item(subsys, &remote_dev->dev_group.cg_item);
+}
+
+static void xcopy_pt_release_cmd(struct se_cmd *se_cmd)
+{
+	struct xcopy_pt_cmd *xpt_cmd = container_of(se_cmd,
+				struct xcopy_pt_cmd, se_cmd);
+
+	kfree(xpt_cmd);
+}
+
+static int xcopy_pt_check_stop_free(struct se_cmd *se_cmd)
+{
+	struct xcopy_pt_cmd *xpt_cmd = container_of(se_cmd,
+				struct xcopy_pt_cmd, se_cmd);
+
+	complete(&xpt_cmd->xpt_passthrough_sem);
+	return 0;
+}
+
+static int xcopy_pt_write_pending(struct se_cmd *se_cmd)
+{
+	return 0;
+}
+
+static int xcopy_pt_write_pending_status(struct se_cmd *se_cmd)
+{
+	return 0;
+}
+
+static int xcopy_pt_queue_data_in(struct se_cmd *se_cmd)
+{
+	return 0;
+}
+
+static int xcopy_pt_queue_status(struct se_cmd *se_cmd)
+{
+	return 0;
+}
+
+static struct target_core_fabric_ops xcopy_pt_tfo = {
+	.get_fabric_name	= xcopy_pt_get_fabric_name,
+	.get_task_tag		= xcopy_pt_get_tag,
+	.get_cmd_state		= xcopy_pt_get_cmd_state,
+	.release_cmd		= xcopy_pt_release_cmd,
+	.check_stop_free	= xcopy_pt_check_stop_free,
+	.write_pending		= xcopy_pt_write_pending,
+	.write_pending_status	= xcopy_pt_write_pending_status,
+	.queue_data_in		= xcopy_pt_queue_data_in,
+	.queue_status		= xcopy_pt_queue_status,
+};
+
+/*
+ * End xcopy_pt_ops
+ */
+
+int target_xcopy_setup_pt(void)
+{
+	xcopy_wq = alloc_workqueue("xcopy_wq", WQ_MEM_RECLAIM, 0);
+	if (!xcopy_wq) {
+		pr_err("Unable to allocate xcopy_wq\n");
+		return -ENOMEM;
+	}
+
+	memset(&xcopy_pt_port, 0, sizeof(struct se_port));
+	INIT_LIST_HEAD(&xcopy_pt_port.sep_alua_list);
+	INIT_LIST_HEAD(&xcopy_pt_port.sep_list);
+	mutex_init(&xcopy_pt_port.sep_tg_pt_md_mutex);
+
+	memset(&xcopy_pt_tpg, 0, sizeof(struct se_portal_group));
+	INIT_LIST_HEAD(&xcopy_pt_tpg.se_tpg_node);
+	INIT_LIST_HEAD(&xcopy_pt_tpg.acl_node_list);
+	INIT_LIST_HEAD(&xcopy_pt_tpg.tpg_sess_list);
+
+	xcopy_pt_port.sep_tpg = &xcopy_pt_tpg;
+	xcopy_pt_tpg.se_tpg_tfo = &xcopy_pt_tfo;
+
+	memset(&xcopy_pt_nacl, 0, sizeof(struct se_node_acl));
+	INIT_LIST_HEAD(&xcopy_pt_nacl.acl_list);
+	INIT_LIST_HEAD(&xcopy_pt_nacl.acl_sess_list);
+	memset(&xcopy_pt_sess, 0, sizeof(struct se_session));
+	INIT_LIST_HEAD(&xcopy_pt_sess.sess_list);
+	INIT_LIST_HEAD(&xcopy_pt_sess.sess_acl_list);
+
+	xcopy_pt_nacl.se_tpg = &xcopy_pt_tpg;
+	xcopy_pt_nacl.nacl_sess = &xcopy_pt_sess;
+
+	xcopy_pt_sess.se_tpg = &xcopy_pt_tpg;
+	xcopy_pt_sess.se_node_acl = &xcopy_pt_nacl;
+
+	return 0;
+}
+
+void target_xcopy_release_pt(void)
+{
+	if (xcopy_wq)
+		destroy_workqueue(xcopy_wq);
+}
+
+static void target_xcopy_setup_pt_port(
+	struct xcopy_pt_cmd *xpt_cmd,
+	struct xcopy_op *xop,
+	bool remote_port)
+{
+	struct se_cmd *ec_cmd = xop->xop_se_cmd;
+	struct se_cmd *pt_cmd = &xpt_cmd->se_cmd;
+
+	if (xop->op_origin == XCOL_SOURCE_RECV_OP) {
+		/*
+		 * Honor destination port reservations for X-COPY PUSH emulation
+		 * when CDB is received on local source port, and READs blocks to
+		 * WRITE on remote destination port.
+		 */
+		if (remote_port) {
+			xpt_cmd->remote_port = remote_port;
+			pt_cmd->se_lun->lun_sep = &xcopy_pt_port;
+			pr_debug("Setup emulated remote DEST xcopy_pt_port: %p to"
+				" cmd->se_lun->lun_sep for X-COPY data PUSH\n",
+				pt_cmd->se_lun->lun_sep);
+		} else {
+			pt_cmd->se_lun = ec_cmd->se_lun;
+			pt_cmd->se_dev = ec_cmd->se_dev;
+
+			pr_debug("Honoring local SRC port from ec_cmd->se_dev:"
+				" %p\n", pt_cmd->se_dev);
+			pt_cmd->se_lun = ec_cmd->se_lun;
+			pr_debug("Honoring local SRC port from ec_cmd->se_lun: %p\n",
+				pt_cmd->se_lun);
+		}
+	} else {
+		/*
+		 * Honor source port reservation for X-COPY PULL emulation
+		 * when CDB is received on local desintation port, and READs
+		 * blocks from the remote source port to WRITE on local
+		 * destination port.
+		 */
+		if (remote_port) {
+			xpt_cmd->remote_port = remote_port;
+			pt_cmd->se_lun->lun_sep = &xcopy_pt_port;
+			pr_debug("Setup emulated remote SRC xcopy_pt_port: %p to"
+				" cmd->se_lun->lun_sep for X-COPY data PULL\n",
+				pt_cmd->se_lun->lun_sep);
+		} else {
+			pt_cmd->se_lun = ec_cmd->se_lun;
+			pt_cmd->se_dev = ec_cmd->se_dev;
+
+			pr_debug("Honoring local DST port from ec_cmd->se_dev:"
+				" %p\n", pt_cmd->se_dev);
+			pt_cmd->se_lun = ec_cmd->se_lun;
+			pr_debug("Honoring local DST port from ec_cmd->se_lun: %p\n",
+				pt_cmd->se_lun);
+		}
+	}
+}
+
+static int target_xcopy_init_pt_lun(
+	struct xcopy_pt_cmd *xpt_cmd,
+	struct xcopy_op *xop,
+	struct se_device *se_dev,
+	struct se_cmd *pt_cmd,
+	bool remote_port)
+{
+	/*
+	 * Don't allocate + init an pt_cmd->se_lun if honoring local port for
+	 * reservations.  The pt_cmd->se_lun pointer will be setup from within
+	 * target_xcopy_setup_pt_port()
+	 */
+	if (remote_port == false) {
+		pt_cmd->se_cmd_flags |= SCF_SE_LUN_CMD | SCF_CMD_XCOPY_PASSTHROUGH;
+		return 0;
+	}
+
+	pt_cmd->se_lun = &se_dev->xcopy_lun;
+	pt_cmd->se_dev = se_dev;
+
+	pr_debug("Setup emulated se_dev: %p from se_dev\n", pt_cmd->se_dev);
+	pt_cmd->se_cmd_flags |= SCF_SE_LUN_CMD | SCF_CMD_XCOPY_PASSTHROUGH;
+
+	pr_debug("Setup emulated se_dev: %p to pt_cmd->se_lun->lun_se_dev\n",
+		pt_cmd->se_lun->lun_se_dev);
+
+	return 0;
+}
+
+static int target_xcopy_setup_pt_cmd(
+	struct xcopy_pt_cmd *xpt_cmd,
+	struct xcopy_op *xop,
+	struct se_device *se_dev,
+	unsigned char *cdb,
+	bool remote_port,
+	bool alloc_mem)
+{
+	struct se_cmd *cmd = &xpt_cmd->se_cmd;
+	sense_reason_t sense_rc;
+	int ret = 0, rc;
+	/*
+	 * Setup LUN+port to honor reservations based upon xop->op_origin for
+	 * X-COPY PUSH or X-COPY PULL based upon where the CDB was received.
+	 */
+	rc = target_xcopy_init_pt_lun(xpt_cmd, xop, se_dev, cmd, remote_port);
+	if (rc < 0) {
+		ret = rc;
+		goto out;
+	}
+	xpt_cmd->xcopy_op = xop;
+	target_xcopy_setup_pt_port(xpt_cmd, xop, remote_port);
+
+	sense_rc = target_setup_cmd_from_cdb(cmd, cdb);
+	if (sense_rc) {
+		ret = -EINVAL;
+		goto out;
+	}
+
+	if (alloc_mem) {
+		rc = target_alloc_sgl(&cmd->t_data_sg, &cmd->t_data_nents,
+				      cmd->data_length, false);
+		if (rc < 0) {
+			ret = rc;
+			goto out;
+		}
+		/*
+		 * Set this bit so that transport_free_pages() allows the
+		 * caller to release SGLs + physical memory allocated by
+		 * transport_generic_get_mem()..
+		 */
+		cmd->se_cmd_flags |= SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC;
+	} else {
+		/*
+		 * Here the previously allocated SGLs for the internal READ
+		 * are mapped zero-copy to the internal WRITE.
+		 */
+		sense_rc = transport_generic_map_mem_to_cmd(cmd,
+					xop->xop_data_sg, xop->xop_data_nents,
+					NULL, 0);
+		if (sense_rc) {
+			ret = -EINVAL;
+			goto out;
+		}
+
+		pr_debug("Setup PASSTHROUGH_NOALLOC t_data_sg: %p t_data_nents:"
+			 " %u\n", cmd->t_data_sg, cmd->t_data_nents);
+	}
+
+	return 0;
+
+out:
+	return ret;
+}
+
+static int target_xcopy_issue_pt_cmd(struct xcopy_pt_cmd *xpt_cmd)
+{
+	struct se_cmd *se_cmd = &xpt_cmd->se_cmd;
+	sense_reason_t sense_rc;
+
+	sense_rc = transport_generic_new_cmd(se_cmd);
+	if (sense_rc)
+		return -EINVAL;
+
+	if (se_cmd->data_direction == DMA_TO_DEVICE)
+		target_execute_cmd(se_cmd);
+
+	wait_for_completion_interruptible(&xpt_cmd->xpt_passthrough_sem);
+
+	pr_debug("target_xcopy_issue_pt_cmd(): SCSI status: 0x%02x\n",
+			se_cmd->scsi_status);
+
+	return (se_cmd->scsi_status) ? -EINVAL : 0;
+}
+
+static int target_xcopy_read_source(
+	struct se_cmd *ec_cmd,
+	struct xcopy_op *xop,
+	struct se_device *src_dev,
+	sector_t src_lba,
+	u32 src_sectors)
+{
+	struct xcopy_pt_cmd *xpt_cmd;
+	struct se_cmd *se_cmd;
+	u32 length = (src_sectors * src_dev->dev_attrib.block_size);
+	int rc;
+	unsigned char cdb[16];
+	bool remote_port = (xop->op_origin == XCOL_DEST_RECV_OP);
+
+	xpt_cmd = kzalloc(sizeof(struct xcopy_pt_cmd), GFP_KERNEL);
+	if (!xpt_cmd) {
+		pr_err("Unable to allocate xcopy_pt_cmd\n");
+		return -ENOMEM;
+	}
+	init_completion(&xpt_cmd->xpt_passthrough_sem);
+	se_cmd = &xpt_cmd->se_cmd;
+
+	memset(&cdb[0], 0, 16);
+	cdb[0] = READ_16;
+	put_unaligned_be64(src_lba, &cdb[2]);
+	put_unaligned_be32(src_sectors, &cdb[10]);
+	pr_debug("XCOPY: Built READ_16: LBA: %llu Sectors: %u Length: %u\n",
+		(unsigned long long)src_lba, src_sectors, length);
+
+	transport_init_se_cmd(se_cmd, &xcopy_pt_tfo, NULL, length,
+			      DMA_FROM_DEVICE, 0, &xpt_cmd->sense_buffer[0]);
+	xop->src_pt_cmd = xpt_cmd;
+
+	rc = target_xcopy_setup_pt_cmd(xpt_cmd, xop, src_dev, &cdb[0],
+				remote_port, true);
+	if (rc < 0) {
+		transport_generic_free_cmd(se_cmd, 0);
+		return rc;
+	}
+
+	xop->xop_data_sg = se_cmd->t_data_sg;
+	xop->xop_data_nents = se_cmd->t_data_nents;
+	pr_debug("XCOPY-READ: Saved xop->xop_data_sg: %p, num: %u for READ"
+		" memory\n", xop->xop_data_sg, xop->xop_data_nents);
+
+	rc = target_xcopy_issue_pt_cmd(xpt_cmd);
+	if (rc < 0) {
+		transport_generic_free_cmd(se_cmd, 0);
+		return rc;
+	}
+	/*
+	 * Clear off the allocated t_data_sg, that has been saved for
+	 * zero-copy WRITE submission reuse in struct xcopy_op..
+	 */
+	se_cmd->t_data_sg = NULL;
+	se_cmd->t_data_nents = 0;
+
+	return 0;
+}
+
+static int target_xcopy_write_destination(
+	struct se_cmd *ec_cmd,
+	struct xcopy_op *xop,
+	struct se_device *dst_dev,
+	sector_t dst_lba,
+	u32 dst_sectors)
+{
+	struct xcopy_pt_cmd *xpt_cmd;
+	struct se_cmd *se_cmd;
+	u32 length = (dst_sectors * dst_dev->dev_attrib.block_size);
+	int rc;
+	unsigned char cdb[16];
+	bool remote_port = (xop->op_origin == XCOL_SOURCE_RECV_OP);
+
+	xpt_cmd = kzalloc(sizeof(struct xcopy_pt_cmd), GFP_KERNEL);
+	if (!xpt_cmd) {
+		pr_err("Unable to allocate xcopy_pt_cmd\n");
+		return -ENOMEM;
+	}
+	init_completion(&xpt_cmd->xpt_passthrough_sem);
+	se_cmd = &xpt_cmd->se_cmd;
+
+	memset(&cdb[0], 0, 16);
+	cdb[0] = WRITE_16;
+	put_unaligned_be64(dst_lba, &cdb[2]);
+	put_unaligned_be32(dst_sectors, &cdb[10]);
+	pr_debug("XCOPY: Built WRITE_16: LBA: %llu Sectors: %u Length: %u\n",
+		(unsigned long long)dst_lba, dst_sectors, length);
+
+	transport_init_se_cmd(se_cmd, &xcopy_pt_tfo, NULL, length,
+			      DMA_TO_DEVICE, 0, &xpt_cmd->sense_buffer[0]);
+	xop->dst_pt_cmd = xpt_cmd;
+
+	rc = target_xcopy_setup_pt_cmd(xpt_cmd, xop, dst_dev, &cdb[0],
+				remote_port, false);
+	if (rc < 0) {
+		struct se_cmd *src_cmd = &xop->src_pt_cmd->se_cmd;
+		/*
+		 * If the failure happened before the t_mem_list hand-off in
+		 * target_xcopy_setup_pt_cmd(), Reset memory + clear flag so that
+		 * core releases this memory on error during X-COPY WRITE I/O.
+		 */
+		src_cmd->se_cmd_flags &= ~SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC;
+		src_cmd->t_data_sg = xop->xop_data_sg;
+		src_cmd->t_data_nents = xop->xop_data_nents;
+
+		transport_generic_free_cmd(se_cmd, 0);
+		return rc;
+	}
+
+	rc = target_xcopy_issue_pt_cmd(xpt_cmd);
+	if (rc < 0) {
+		se_cmd->se_cmd_flags &= ~SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC;
+		transport_generic_free_cmd(se_cmd, 0);
+		return rc;
+	}
+
+	return 0;
+}
+
+static void target_xcopy_do_work(struct work_struct *work)
+{
+	struct xcopy_op *xop = container_of(work, struct xcopy_op, xop_work);
+	struct se_device *src_dev = xop->src_dev, *dst_dev = xop->dst_dev;
+	struct se_cmd *ec_cmd = xop->xop_se_cmd;
+	sector_t src_lba = xop->src_lba, dst_lba = xop->dst_lba, end_lba;
+	unsigned int max_sectors;
+	int rc;
+	unsigned short nolb = xop->nolb, cur_nolb, max_nolb, copied_nolb = 0;
+
+	end_lba = src_lba + nolb;
+	/*
+	 * Break up XCOPY I/O into hw_max_sectors sized I/O based on the
+	 * smallest max_sectors between src_dev + dev_dev, or
+	 */
+	max_sectors = min(src_dev->dev_attrib.hw_max_sectors,
+			  dst_dev->dev_attrib.hw_max_sectors);
+	max_sectors = min_t(u32, max_sectors, XCOPY_MAX_SECTORS);
+
+	max_nolb = min_t(u16, max_sectors, ((u16)(~0U)));
+
+	pr_debug("target_xcopy_do_work: nolb: %hu, max_nolb: %hu end_lba: %llu\n",
+			nolb, max_nolb, (unsigned long long)end_lba);
+	pr_debug("target_xcopy_do_work: Starting src_lba: %llu, dst_lba: %llu\n",
+			(unsigned long long)src_lba, (unsigned long long)dst_lba);
+
+	while (src_lba < end_lba) {
+		cur_nolb = min(nolb, max_nolb);
+
+		pr_debug("target_xcopy_do_work: Calling read src_dev: %p src_lba: %llu,"
+			" cur_nolb: %hu\n", src_dev, (unsigned long long)src_lba, cur_nolb);
+
+		rc = target_xcopy_read_source(ec_cmd, xop, src_dev, src_lba, cur_nolb);
+		if (rc < 0)
+			goto out;
+
+		src_lba += cur_nolb;
+		pr_debug("target_xcopy_do_work: Incremented READ src_lba to %llu\n",
+				(unsigned long long)src_lba);
+
+		pr_debug("target_xcopy_do_work: Calling write dst_dev: %p dst_lba: %llu,"
+			" cur_nolb: %hu\n", dst_dev, (unsigned long long)dst_lba, cur_nolb);
+
+		rc = target_xcopy_write_destination(ec_cmd, xop, dst_dev,
+						dst_lba, cur_nolb);
+		if (rc < 0) {
+			transport_generic_free_cmd(&xop->src_pt_cmd->se_cmd, 0);
+			goto out;
+		}
+
+		dst_lba += cur_nolb;
+		pr_debug("target_xcopy_do_work: Incremented WRITE dst_lba to %llu\n",
+				(unsigned long long)dst_lba);
+
+		copied_nolb += cur_nolb;
+		nolb -= cur_nolb;
+
+		transport_generic_free_cmd(&xop->src_pt_cmd->se_cmd, 0);
+		xop->dst_pt_cmd->se_cmd.se_cmd_flags &= ~SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC;
+
+		transport_generic_free_cmd(&xop->dst_pt_cmd->se_cmd, 0);
+	}
+
+	xcopy_pt_undepend_remotedev(xop);
+	kfree(xop);
+
+	pr_debug("target_xcopy_do_work: Final src_lba: %llu, dst_lba: %llu\n",
+		(unsigned long long)src_lba, (unsigned long long)dst_lba);
+	pr_debug("target_xcopy_do_work: Blocks copied: %hu, Bytes Copied: %u\n",
+		copied_nolb, copied_nolb * dst_dev->dev_attrib.block_size);
+
+	pr_debug("target_xcopy_do_work: Setting X-COPY GOOD status -> sending response\n");
+	target_complete_cmd(ec_cmd, SAM_STAT_GOOD);
+	return;
+
+out:
+	xcopy_pt_undepend_remotedev(xop);
+	kfree(xop);
+
+	pr_warn("target_xcopy_do_work: Setting X-COPY CHECK_CONDITION -> sending response\n");
+	ec_cmd->scsi_status = SAM_STAT_CHECK_CONDITION;
+	target_complete_cmd(ec_cmd, SAM_STAT_CHECK_CONDITION);
+}
+
+sense_reason_t target_do_xcopy(struct se_cmd *se_cmd)
+{
+	struct se_device *dev = se_cmd->se_dev;
+	struct xcopy_op *xop = NULL;
+	unsigned char *p = NULL, *seg_desc;
+	unsigned int list_id, list_id_usage, sdll, inline_dl, sa;
+	sense_reason_t ret = TCM_INVALID_PARAMETER_LIST;
+	int rc;
+	unsigned short tdll;
+
+	if (!dev->dev_attrib.emulate_3pc) {
+		pr_err("EXTENDED_COPY operation explicitly disabled\n");
+		return TCM_UNSUPPORTED_SCSI_OPCODE;
+	}
+
+	sa = se_cmd->t_task_cdb[1] & 0x1f;
+	if (sa != 0x00) {
+		pr_err("EXTENDED_COPY(LID4) not supported\n");
+		return TCM_UNSUPPORTED_SCSI_OPCODE;
+	}
+
+	xop = kzalloc(sizeof(struct xcopy_op), GFP_KERNEL);
+	if (!xop) {
+		pr_err("Unable to allocate xcopy_op\n");
+		return TCM_OUT_OF_RESOURCES;
+	}
+	xop->xop_se_cmd = se_cmd;
+
+	p = transport_kmap_data_sg(se_cmd);
+	if (!p) {
+		pr_err("transport_kmap_data_sg() failed in target_do_xcopy\n");
+		kfree(xop);
+		return TCM_OUT_OF_RESOURCES;
+	}
+
+	list_id = p[0];
+	list_id_usage = (p[1] & 0x18) >> 3;
+
+	/*
+	 * Determine TARGET DESCRIPTOR LIST LENGTH + SEGMENT DESCRIPTOR LIST LENGTH
+	 */
+	tdll = get_unaligned_be16(&p[2]);
+	sdll = get_unaligned_be32(&p[8]);
+
+	inline_dl = get_unaligned_be32(&p[12]);
+	if (inline_dl != 0) {
+		pr_err("XCOPY with non zero inline data length\n");
+		goto out;
+	}
+
+	pr_debug("Processing XCOPY with list_id: 0x%02x list_id_usage: 0x%02x"
+		" tdll: %hu sdll: %u inline_dl: %u\n", list_id, list_id_usage,
+		tdll, sdll, inline_dl);
+
+	rc = target_xcopy_parse_target_descriptors(se_cmd, xop, &p[16], tdll);
+	if (rc <= 0)
+		goto out;
+
+	if (xop->src_dev->dev_attrib.block_size !=
+	    xop->dst_dev->dev_attrib.block_size) {
+		pr_err("XCOPY: Non matching src_dev block_size: %u + dst_dev"
+		       " block_size: %u currently unsupported\n",
+			xop->src_dev->dev_attrib.block_size,
+			xop->dst_dev->dev_attrib.block_size);
+		xcopy_pt_undepend_remotedev(xop);
+		ret = TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE;
+		goto out;
+	}
+
+	pr_debug("XCOPY: Processed %d target descriptors, length: %u\n", rc,
+				rc * XCOPY_TARGET_DESC_LEN);
+	seg_desc = &p[16];
+	seg_desc += (rc * XCOPY_TARGET_DESC_LEN);
+
+	rc = target_xcopy_parse_segment_descriptors(se_cmd, xop, seg_desc, sdll);
+	if (rc <= 0) {
+		xcopy_pt_undepend_remotedev(xop);
+		goto out;
+	}
+	transport_kunmap_data_sg(se_cmd);
+
+	pr_debug("XCOPY: Processed %d segment descriptors, length: %u\n", rc,
+				rc * XCOPY_SEGMENT_DESC_LEN);
+	INIT_WORK(&xop->xop_work, target_xcopy_do_work);
+	queue_work(xcopy_wq, &xop->xop_work);
+	return TCM_NO_SENSE;
+
+out:
+	if (p)
+		transport_kunmap_data_sg(se_cmd);
+	kfree(xop);
+	return ret;
+}
+
+static sense_reason_t target_rcr_operating_parameters(struct se_cmd *se_cmd)
+{
+	unsigned char *p;
+
+	p = transport_kmap_data_sg(se_cmd);
+	if (!p) {
+		pr_err("transport_kmap_data_sg failed in"
+		       " target_rcr_operating_parameters\n");
+		return TCM_OUT_OF_RESOURCES;
+	}
+
+	if (se_cmd->data_length < 54) {
+		pr_err("Receive Copy Results Op Parameters length"
+		       " too small: %u\n", se_cmd->data_length);
+		transport_kunmap_data_sg(se_cmd);
+		return TCM_INVALID_CDB_FIELD;
+	}
+	/*
+	 * Set SNLID=1 (Supports no List ID)
+	 */
+	p[4] = 0x1;
+	/*
+	 * MAXIMUM TARGET DESCRIPTOR COUNT
+	 */
+	put_unaligned_be16(RCR_OP_MAX_TARGET_DESC_COUNT, &p[8]);
+	/*
+	 * MAXIMUM SEGMENT DESCRIPTOR COUNT
+	 */
+	put_unaligned_be16(RCR_OP_MAX_SG_DESC_COUNT, &p[10]);
+	/*
+	 * MAXIMUM DESCRIPTOR LIST LENGTH
+	 */
+	put_unaligned_be32(RCR_OP_MAX_DESC_LIST_LEN, &p[12]);
+	/*
+	 * MAXIMUM SEGMENT LENGTH
+	 */
+	put_unaligned_be32(RCR_OP_MAX_SEGMENT_LEN, &p[16]);
+	/*
+	 * MAXIMUM INLINE DATA LENGTH for SA 0x04 (NOT SUPPORTED)
+	 */
+	put_unaligned_be32(0x0, &p[20]);
+	/*
+	 * HELD DATA LIMIT
+	 */
+	put_unaligned_be32(0x0, &p[24]);
+	/*
+	 * MAXIMUM STREAM DEVICE TRANSFER SIZE
+	 */
+	put_unaligned_be32(0x0, &p[28]);
+	/*
+	 * TOTAL CONCURRENT COPIES
+	 */
+	put_unaligned_be16(RCR_OP_TOTAL_CONCURR_COPIES, &p[34]);
+	/*
+	 * MAXIMUM CONCURRENT COPIES
+	 */
+	p[36] = RCR_OP_MAX_CONCURR_COPIES;
+	/*
+	 * DATA SEGMENT GRANULARITY (log 2)
+	 */
+	p[37] = RCR_OP_DATA_SEG_GRAN_LOG2;
+	/*
+	 * INLINE DATA GRANULARITY log 2)
+	 */
+	p[38] = RCR_OP_INLINE_DATA_GRAN_LOG2;
+	/*
+	 * HELD DATA GRANULARITY
+	 */
+	p[39] = RCR_OP_HELD_DATA_GRAN_LOG2;
+	/*
+	 * IMPLEMENTED DESCRIPTOR LIST LENGTH
+	 */
+	p[43] = 0x2;
+	/*
+	 * List of implemented descriptor type codes (ordered)
+	 */
+	p[44] = 0x02; /* Copy Block to Block device */
+	p[45] = 0xe4; /* Identification descriptor target descriptor */
+
+	/*
+	 * AVAILABLE DATA (n-3)
+	 */
+	put_unaligned_be32(42, &p[0]);
+
+	transport_kunmap_data_sg(se_cmd);
+	target_complete_cmd(se_cmd, GOOD);
+
+	return TCM_NO_SENSE;
+}
+
+sense_reason_t target_do_receive_copy_results(struct se_cmd *se_cmd)
+{
+	unsigned char *cdb = &se_cmd->t_task_cdb[0];
+	int sa = (cdb[1] & 0x1f), list_id = cdb[2];
+	sense_reason_t rc = TCM_NO_SENSE;
+
+	pr_debug("Entering target_do_receive_copy_results: SA: 0x%02x, List ID:"
+		" 0x%02x, AL: %u\n", sa, list_id, se_cmd->data_length);
+
+	if (list_id != 0) {
+		pr_err("Receive Copy Results with non zero list identifier"
+		       " not supported\n");
+		return TCM_INVALID_CDB_FIELD;
+	}
+
+	switch (sa) {
+	case RCR_SA_OPERATING_PARAMETERS:
+		rc = target_rcr_operating_parameters(se_cmd);
+		break;
+	case RCR_SA_COPY_STATUS:
+	case RCR_SA_RECEIVE_DATA:
+	case RCR_SA_FAILED_SEGMENT_DETAILS:
+	default:
+		pr_err("Unsupported SA for receive copy results: 0x%02x\n", sa);
+		return TCM_INVALID_CDB_FIELD;
+	}
+
+	return rc;
+}
diff --git a/drivers/target/target_core_xcopy.h b/drivers/target/target_core_xcopy.h
new file mode 100644
index 00000000..700a981
--- /dev/null
+++ b/drivers/target/target_core_xcopy.h
@@ -0,0 +1,62 @@
+#define XCOPY_TARGET_DESC_LEN		32
+#define XCOPY_SEGMENT_DESC_LEN		28
+#define XCOPY_NAA_IEEE_REGEX_LEN	16
+#define XCOPY_MAX_SECTORS		1024
+
+enum xcopy_origin_list {
+	XCOL_SOURCE_RECV_OP = 0x01,
+	XCOL_DEST_RECV_OP = 0x02,
+};
+
+struct xcopy_pt_cmd;
+
+struct xcopy_op {
+	int op_origin;
+
+	struct se_cmd *xop_se_cmd;
+	struct se_device *src_dev;
+	unsigned char src_tid_wwn[XCOPY_NAA_IEEE_REGEX_LEN];
+	struct se_device *dst_dev;
+	unsigned char dst_tid_wwn[XCOPY_NAA_IEEE_REGEX_LEN];
+	unsigned char local_dev_wwn[XCOPY_NAA_IEEE_REGEX_LEN];
+
+	sector_t src_lba;
+	sector_t dst_lba;
+	unsigned short stdi;
+	unsigned short dtdi;
+	unsigned short nolb;
+	unsigned int dbl;
+
+	struct xcopy_pt_cmd *src_pt_cmd;
+	struct xcopy_pt_cmd *dst_pt_cmd;
+
+	u32 xop_data_nents;
+	struct scatterlist *xop_data_sg;
+	struct work_struct xop_work;
+};
+
+/*
+ * Receive Copy Results Sevice Actions
+ */
+#define RCR_SA_COPY_STATUS		0x00
+#define RCR_SA_RECEIVE_DATA		0x01
+#define RCR_SA_OPERATING_PARAMETERS	0x03
+#define RCR_SA_FAILED_SEGMENT_DETAILS	0x04
+
+/*
+ * Receive Copy Results defs for Operating Parameters
+ */
+#define RCR_OP_MAX_TARGET_DESC_COUNT	0x2
+#define RCR_OP_MAX_SG_DESC_COUNT	0x1
+#define RCR_OP_MAX_DESC_LIST_LEN	1024
+#define RCR_OP_MAX_SEGMENT_LEN		268435456 /* 256 MB */
+#define RCR_OP_TOTAL_CONCURR_COPIES	0x1 /* Must be <= 16384 */
+#define RCR_OP_MAX_CONCURR_COPIES	0x1 /* Must be <= 255 */
+#define RCR_OP_DATA_SEG_GRAN_LOG2	9 /* 512 bytes in log 2 */
+#define RCR_OP_INLINE_DATA_GRAN_LOG2	9 /* 512 bytes in log 2 */
+#define RCR_OP_HELD_DATA_GRAN_LOG2	9 /* 512 bytes in log 2 */
+
+extern int target_xcopy_setup_pt(void);
+extern void target_xcopy_release_pt(void);
+extern sense_reason_t target_do_xcopy(struct se_cmd *);
+extern sense_reason_t target_do_receive_copy_results(struct se_cmd *);
diff --git a/drivers/target/tcm_fc/tcm_fc.h b/drivers/target/tcm_fc/tcm_fc.h
index eea6935..4f4b971 100644
--- a/drivers/target/tcm_fc/tcm_fc.h
+++ b/drivers/target/tcm_fc/tcm_fc.h
@@ -22,6 +22,7 @@
 #define FT_NAMELEN 32		/* length of ASCII WWPNs including pad */
 #define FT_TPG_NAMELEN 32	/* max length of TPG name */
 #define FT_LUN_NAMELEN 32	/* max length of LUN name */
+#define TCM_FC_DEFAULT_TAGS 512	/* tags used for per-session preallocation */
 
 struct ft_transport_id {
 	__u8	format;
@@ -161,7 +162,8 @@ int ft_write_pending(struct se_cmd *);
 int ft_write_pending_status(struct se_cmd *);
 u32 ft_get_task_tag(struct se_cmd *);
 int ft_get_cmd_state(struct se_cmd *);
-int ft_queue_tm_resp(struct se_cmd *);
+void ft_queue_tm_resp(struct se_cmd *);
+void ft_aborted_task(struct se_cmd *);
 
 /*
  * other internal functions.
diff --git a/drivers/target/tcm_fc/tfc_cmd.c b/drivers/target/tcm_fc/tfc_cmd.c
index b406f17..f5fd515 100644
--- a/drivers/target/tcm_fc/tfc_cmd.c
+++ b/drivers/target/tcm_fc/tfc_cmd.c
@@ -28,6 +28,7 @@
 #include <linux/configfs.h>
 #include <linux/ctype.h>
 #include <linux/hash.h>
+#include <linux/percpu_ida.h>
 #include <asm/unaligned.h>
 #include <scsi/scsi.h>
 #include <scsi/scsi_host.h>
@@ -89,16 +90,18 @@ static void ft_free_cmd(struct ft_cmd *cmd)
 {
 	struct fc_frame *fp;
 	struct fc_lport *lport;
+	struct ft_sess *sess;
 
 	if (!cmd)
 		return;
+	sess = cmd->sess;
 	fp = cmd->req_frame;
 	lport = fr_dev(fp);
 	if (fr_seq(fp))
 		lport->tt.seq_release(fr_seq(fp));
 	fc_frame_free(fp);
-	ft_sess_put(cmd->sess);	/* undo get from lookup at recv */
-	kfree(cmd);
+	percpu_ida_free(&sess->se_sess->sess_tag_pool, cmd->se_cmd.map_tag);
+	ft_sess_put(sess);	/* undo get from lookup at recv */
 }
 
 void ft_release_cmd(struct se_cmd *se_cmd)
@@ -394,14 +397,14 @@ static void ft_send_tm(struct ft_cmd *cmd)
 /*
  * Send status from completed task management request.
  */
-int ft_queue_tm_resp(struct se_cmd *se_cmd)
+void ft_queue_tm_resp(struct se_cmd *se_cmd)
 {
 	struct ft_cmd *cmd = container_of(se_cmd, struct ft_cmd, se_cmd);
 	struct se_tmr_req *tmr = se_cmd->se_tmr_req;
 	enum fcp_resp_rsp_codes code;
 
 	if (cmd->aborted)
-		return 0;
+		return;
 	switch (tmr->response) {
 	case TMR_FUNCTION_COMPLETE:
 		code = FCP_TMF_CMPL;
@@ -413,10 +416,7 @@ int ft_queue_tm_resp(struct se_cmd *se_cmd)
 		code = FCP_TMF_REJECTED;
 		break;
 	case TMR_TASK_DOES_NOT_EXIST:
-	case TMR_TASK_STILL_ALLEGIANT:
-	case TMR_TASK_FAILOVER_NOT_SUPPORTED:
 	case TMR_TASK_MGMT_FUNCTION_NOT_SUPPORTED:
-	case TMR_FUNCTION_AUTHORIZATION_FAILED:
 	default:
 		code = FCP_TMF_FAILED;
 		break;
@@ -424,7 +424,11 @@ int ft_queue_tm_resp(struct se_cmd *se_cmd)
 	pr_debug("tmr fn %d resp %d fcp code %d\n",
 		  tmr->function, tmr->response, code);
 	ft_send_resp_code(cmd, code);
-	return 0;
+}
+
+void ft_aborted_task(struct se_cmd *se_cmd)
+{
+	return;
 }
 
 static void ft_send_work(struct work_struct *work);
@@ -436,14 +440,21 @@ static void ft_recv_cmd(struct ft_sess *sess, struct fc_frame *fp)
 {
 	struct ft_cmd *cmd;
 	struct fc_lport *lport = sess->tport->lport;
+	struct se_session *se_sess = sess->se_sess;
+	int tag;
 
-	cmd = kzalloc(sizeof(*cmd), GFP_ATOMIC);
-	if (!cmd)
+	tag = percpu_ida_alloc(&se_sess->sess_tag_pool, TASK_RUNNING);
+	if (tag < 0)
 		goto busy;
+
+	cmd = &((struct ft_cmd *)se_sess->sess_cmd_map)[tag];
+	memset(cmd, 0, sizeof(struct ft_cmd));
+
+	cmd->se_cmd.map_tag = tag;
 	cmd->sess = sess;
 	cmd->seq = lport->tt.seq_assign(lport, fp);
 	if (!cmd->seq) {
-		kfree(cmd);
+		percpu_ida_free(&se_sess->sess_tag_pool, tag);
 		goto busy;
 	}
 	cmd->req_frame = fp;		/* hold frame during cmd */
diff --git a/drivers/target/tcm_fc/tfc_conf.c b/drivers/target/tcm_fc/tfc_conf.c
index b74feb0..b8b5a71 100644
--- a/drivers/target/tcm_fc/tfc_conf.c
+++ b/drivers/target/tcm_fc/tfc_conf.c
@@ -267,7 +267,7 @@ struct ft_node_acl *ft_acl_get(struct ft_tpg *tpg, struct fc_rport_priv *rdata)
 	return found;
 }
 
-struct se_node_acl *ft_tpg_alloc_fabric_acl(struct se_portal_group *se_tpg)
+static struct se_node_acl *ft_tpg_alloc_fabric_acl(struct se_portal_group *se_tpg)
 {
 	struct ft_node_acl *acl;
 
@@ -311,7 +311,11 @@ static struct se_portal_group *ft_add_tpg(
 	 */
 	if (strstr(name, "tpgt_") != name)
 		return NULL;
-	if (strict_strtoul(name + 5, 10, &index) || index > UINT_MAX)
+
+	ret = kstrtoul(name + 5, 10, &index);
+	if (ret)
+		return NULL;
+	if (index > UINT_MAX)
 		return NULL;
 
 	lacl = container_of(wwn, struct ft_lport_acl, fc_lport_wwn);
@@ -532,6 +536,7 @@ static struct target_core_fabric_ops ft_fabric_ops = {
 	.queue_data_in =		ft_queue_data_in,
 	.queue_status =			ft_queue_status,
 	.queue_tm_rsp =			ft_queue_tm_resp,
+	.aborted_task =			ft_aborted_task,
 	/*
 	 * Setup function pointers for generic logic in
 	 * target_core_fabric_configfs.c
@@ -548,7 +553,7 @@ static struct target_core_fabric_ops ft_fabric_ops = {
 	.fabric_drop_nodeacl =		&ft_del_acl,
 };
 
-int ft_register_configfs(void)
+static int ft_register_configfs(void)
 {
 	struct target_fabric_configfs *fabric;
 	int ret;
@@ -567,16 +572,16 @@ int ft_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = ft_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs =
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = ft_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs =
 						    ft_nacl_base_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 	/*
 	 * register the fabric for use within TCM
 	 */
@@ -595,7 +600,7 @@ int ft_register_configfs(void)
 	return 0;
 }
 
-void ft_deregister_configfs(void)
+static void ft_deregister_configfs(void)
 {
 	if (!ft_configfs)
 		return;
diff --git a/drivers/target/tcm_fc/tfc_io.c b/drivers/target/tcm_fc/tfc_io.c
index e415af3..c67d3795 100644
--- a/drivers/target/tcm_fc/tfc_io.c
+++ b/drivers/target/tcm_fc/tfc_io.c
@@ -346,7 +346,7 @@ void ft_invl_hw_context(struct ft_cmd *cmd)
 		ep = fc_seq_exch(seq);
 		if (ep) {
 			lport = ep->lp;
-			if (lport && (ep->xid <= lport->lro_xid))
+			if (lport && (ep->xid <= lport->lro_xid)) {
 				/*
 				 * "ddp_done" trigger invalidation of HW
 				 * specific DDP context
@@ -361,6 +361,7 @@ void ft_invl_hw_context(struct ft_cmd *cmd)
 				 * identified using ep->xid)
 				 */
 				cmd->was_ddp_setup = 0;
+			}
 		}
 	}
 }
diff --git a/drivers/target/tcm_fc/tfc_sess.c b/drivers/target/tcm_fc/tfc_sess.c
index 4859505..e9fe60f 100644
--- a/drivers/target/tcm_fc/tfc_sess.c
+++ b/drivers/target/tcm_fc/tfc_sess.c
@@ -68,6 +68,7 @@ static struct ft_tport *ft_tport_create(struct fc_lport *lport)
 
 	if (tport) {
 		tport->tpg = tpg;
+		tpg->tport = tport;
 		return tport;
 	}
 
@@ -210,7 +211,8 @@ static struct ft_sess *ft_sess_create(struct ft_tport *tport, u32 port_id,
 	if (!sess)
 		return NULL;
 
-	sess->se_sess = transport_init_session();
+	sess->se_sess = transport_init_session_tags(TCM_FC_DEFAULT_TAGS,
+						    sizeof(struct ft_cmd));
 	if (IS_ERR(sess->se_sess)) {
 		kfree(sess);
 		return NULL;
diff --git a/drivers/usb/core/hub.c b/drivers/usb/core/hub.c
index c8b9fa0..e7f583c 100644
--- a/drivers/usb/core/hub.c
+++ b/drivers/usb/core/hub.c
@@ -517,6 +517,10 @@ static void led_work (struct work_struct *work)
 /* use a short timeout for hub/port status fetches */
 #define	USB_STS_TIMEOUT		1000
 #define	USB_STS_RETRIES		5
+#ifdef CONFIG_USB_ETRON_HUB
+#define	USB_STS_TIMEOUT_ETRON	500
+#define	USB_STS_RETRIES_ETRON	3
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 /*
  * USB 2.0 spec Section 11.24.2.6
@@ -526,12 +530,25 @@ static int get_hub_status(struct usb_device *hdev,
 {
 	int i, status = -ETIMEDOUT;
 
+#ifdef CONFIG_USB_ETRON_HUB
+	const int timeout = usb_is_etron_hcd(hdev)
+		? USB_STS_TIMEOUT_ETRON : USB_STS_TIMEOUT;
+	const int retries = usb_is_etron_hcd(hdev)
+		? USB_STS_RETRIES_ETRON : USB_STS_RETRIES;
+	for (i = 0; i < retries &&
+			(status == -ETIMEDOUT || status == -EPIPE); i++) {
+		status = usb_control_msg(hdev, usb_rcvctrlpipe(hdev, 0),
+			USB_REQ_GET_STATUS, USB_DIR_IN | USB_RT_HUB, 0, 0,
+			data, sizeof(*data), timeout);
+	}
+#else /*CONFIG_USB_ETRON_HUB*/
 	for (i = 0; i < USB_STS_RETRIES &&
 			(status == -ETIMEDOUT || status == -EPIPE); i++) {
 		status = usb_control_msg(hdev, usb_rcvctrlpipe(hdev, 0),
 			USB_REQ_GET_STATUS, USB_DIR_IN | USB_RT_HUB, 0, 0,
 			data, sizeof(*data), USB_STS_TIMEOUT);
 	}
+#endif /*CONFIG_USB_ETRON_HUB*/
 	return status;
 }
 
@@ -543,12 +560,25 @@ static int get_port_status(struct usb_device *hdev, int port1,
 {
 	int i, status = -ETIMEDOUT;
 
+#ifdef CONFIG_USB_ETRON_HUB
+	const int timeout = usb_is_etron_hcd(hdev)
+		? USB_STS_TIMEOUT_ETRON : USB_STS_TIMEOUT;
+	const int retries = usb_is_etron_hcd(hdev)
+		? USB_STS_RETRIES_ETRON : USB_STS_RETRIES;
+	for (i = 0; i < retries &&
+			(status == -ETIMEDOUT || status == -EPIPE); i++) {
+		status = usb_control_msg(hdev, usb_rcvctrlpipe(hdev, 0),
+			USB_REQ_GET_STATUS, USB_DIR_IN | USB_RT_PORT, 0, port1,
+			data, sizeof(*data), timeout);
+	}
+#else /*CONFIG_USB_ETRON_HUB*/
 	for (i = 0; i < USB_STS_RETRIES &&
 			(status == -ETIMEDOUT || status == -EPIPE); i++) {
 		status = usb_control_msg(hdev, usb_rcvctrlpipe(hdev, 0),
 			USB_REQ_GET_STATUS, USB_DIR_IN | USB_RT_PORT, 0, port1,
 			data, sizeof(*data), USB_STS_TIMEOUT);
 	}
+#endif /*CONFIG_USB_ETRON_HUB*/
 	return status;
 }
 
@@ -623,6 +653,25 @@ void usb_wakeup_notification(struct usb_device *hdev,
 }
 EXPORT_SYMBOL_GPL(usb_wakeup_notification);
 
+#ifdef CONFIG_USB_ETRON_HUB
+void usb_run_bot_mode_notification(struct usb_device *hdev,
+		unsigned int portnum)
+{
+	struct usb_hub *hub;
+
+	if (!hdev || !usb_is_etron_hcd(hdev))
+		return;
+
+	hub = usb_hub_to_struct_hub(hdev);
+	if (hub) {
+		set_bit(portnum, hub->bot_mode_bits);
+		set_bit(portnum, hub->change_bits);
+		kick_khubd(hub);
+	}
+}
+EXPORT_SYMBOL_GPL(usb_run_bot_mode_notification);
+#endif /*CONFIG_USB_ETRON_HUB*/
+
 /* completion function, fires on port status changes and various faults */
 static void hub_irq(struct urb *urb)
 {
@@ -994,6 +1043,9 @@ enum hub_activation_type {
 
 static void hub_init_func2(struct work_struct *ws);
 static void hub_init_func3(struct work_struct *ws);
+#ifdef CONFIG_USB_ETRON_HUB
+static bool hub_port_warm_reset_required(struct usb_hub *hub, u16 portstatus);
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 static void hub_activate(struct usb_hub *hub, enum hub_activation_type type)
 {
@@ -1129,12 +1181,25 @@ static void hub_activate(struct usb_hub *hub, enum hub_activation_type type)
 			usb_clear_port_feature(hub->hdev, port1,
 					USB_PORT_FEAT_C_ENABLE);
 		}
+		if (portchange & USB_PORT_STAT_C_RESET) {
+			need_debounce_delay = true;
+			usb_clear_port_feature(hub->hdev, port1,
+					USB_PORT_FEAT_C_RESET);
+		}
 		if ((portchange & USB_PORT_STAT_C_BH_RESET) &&
 				hub_is_superspeed(hub->hdev)) {
 			need_debounce_delay = true;
 			usb_clear_port_feature(hub->hdev, port1,
 					USB_PORT_FEAT_C_BH_PORT_RESET);
 		}
+#ifdef CONFIG_USB_ETRON_HUB
+		if (usb_is_etron_hcd(hdev) &&
+		    hub_port_warm_reset_required(hub, portstatus))
+		{
+			need_debounce_delay = true;
+			set_bit(port1, hub->change_bits);
+		}
+#endif /*CONFIG_USB_ETRON_HUB*/
 		/* We can forget about a "removed" device when there's a
 		 * physical disconnect or the connect status changes.
 		 */
@@ -1146,7 +1211,8 @@ static void hub_activate(struct usb_hub *hub, enum hub_activation_type type)
 			/* Tell khubd to disconnect the device or
 			 * check for a new connection
 			 */
-			if (udev || (portstatus & USB_PORT_STAT_CONNECTION))
+			if (udev || (portstatus & USB_PORT_STAT_CONNECTION) ||
+			    (portstatus & USB_PORT_STAT_OVERCURRENT))
 				set_bit(port1, hub->change_bits);
 
 		} else if (portstatus & USB_PORT_STAT_ENABLE) {
@@ -1197,6 +1263,14 @@ static void hub_activate(struct usb_hub *hub, enum hub_activation_type type)
 
 		/* Don't do a long sleep inside a workqueue routine */
 		if (type == HUB_INIT2) {
+#ifdef CONFIG_USB_ETRON_HUB
+			if (usb_is_etron_hcd(hdev))
+			if (hub_is_superspeed(hdev) &&
+				(hdev->descriptor.idVendor == cpu_to_le16(0x1c04) ||
+				hdev->descriptor.idProduct == cpu_to_le16(0x0008))) {
+				delay = 5000;
+			}
+#endif /*CONFIG_USB_ETRON_HUB*/
 			PREPARE_DELAYED_WORK(&hub->init_work, hub_init_func3);
 			schedule_delayed_work(&hub->init_work,
 					msecs_to_jiffies(delay));
@@ -1600,7 +1674,7 @@ static void hub_disconnect(struct usb_interface *intf)
 {
 	struct usb_hub *hub = usb_get_intfdata(intf);
 	struct usb_device *hdev = interface_to_usbdev(intf);
-	int i;
+	int port1;
 
 	/* Take the hub off the event list and don't let it be added again */
 	spin_lock_irq(&hub_event_lock);
@@ -1615,11 +1689,15 @@ static void hub_disconnect(struct usb_interface *intf)
 	hub->error = 0;
 	hub_quiesce(hub, HUB_DISCONNECT);
 
-	usb_set_intfdata (intf, NULL);
+	/* Avoid races with recursively_mark_NOTATTACHED() */
+	spin_lock_irq(&device_state_lock);
+	port1 = hdev->maxchild;
+	hdev->maxchild = 0;
+	usb_set_intfdata(intf, NULL);
+	spin_unlock_irq(&device_state_lock);
 
-	for (i = 0; i < hdev->maxchild; i++)
-		usb_hub_remove_port_device(hub, i + 1);
-	hub->hdev->maxchild = 0;
+	for (; port1 > 0; --port1)
+		usb_hub_remove_port_device(hub, port1);
 
 	if (hub->hdev->speed == USB_SPEED_HIGH)
 		highspeed_hubs--;
@@ -2557,6 +2635,15 @@ static int hub_port_wait_reset(struct usb_hub *hub, int port1,
 	if ((portstatus & USB_PORT_STAT_RESET))
 		return -EBUSY;
 
+#ifdef CONFIG_USB_ETRON_HUB
+	if (usb_is_etron_hcd(hub->hdev)) {
+		msleep(1000);
+
+		ret = hub_port_status(hub, port1, &portstatus, &portchange);
+		if (ret < 0)
+			return ret;
+	}
+#endif /*CONFIG_USB_ETRON_HUB*/
 	if (hub_port_warm_reset_required(hub, portstatus))
 		return -ENOTCONN;
 
@@ -4323,6 +4410,25 @@ hub_power_remaining (struct usb_hub *hub)
 	return remaining;
 }
 
+#ifdef CONFIG_USB_ETRON_HUB
+static void
+hub_enable_battery_charge(struct usb_hub *hub,  struct usb_device *udev)
+{
+	struct usb_device *hdev = hub->hdev;
+	struct usb_hcd *hcd = bus_to_hcd(hdev->bus);
+
+	if (!(hcd->chip_quirks & HCD_BATTERY_CHARGE_QUIRK))
+		return;
+
+	if (udev->descriptor.idVendor != cpu_to_le16(0x05ac))
+		return;
+
+	usb_control_msg(udev, usb_sndctrlpipe(udev, 0), 0x40,
+		USB_TYPE_VENDOR | USB_RECIP_DEVICE | USB_DIR_OUT,
+		0x6400, 0x6400, NULL, 0, 1000);
+}
+#endif /*CONFIG_USB_ETRON_HUB*/
+
 /* Handle physical or logical connection change events.
  * This routine is called when:
  * 	a port connection-change occurs;
@@ -4365,6 +4471,12 @@ static void hub_port_connect_change(struct usb_hub *hub, int port1,
 			udev->state != USB_STATE_NOTATTACHED) {
 		usb_lock_device(udev);
 		if (portstatus & USB_PORT_STAT_ENABLE) {
+#ifdef CONFIG_USB_ETRON_HUB
+			if (usb_is_etron_hcd(hdev) &&
+			    (portchange & USB_PORT_STAT_C_CONNECTION)) {
+				status = -ENODEV;
+			} else
+#endif /*CONFIG_USB_ETRON_HUB*/
 			status = 0;		/* Nothing to do */
 
 #ifdef CONFIG_PM_RUNTIME
@@ -4401,7 +4513,14 @@ static void hub_port_connect_change(struct usb_hub *hub, int port1,
 	 */
 	if (!(portstatus & USB_PORT_STAT_CONNECTION) ||
 			(portchange & USB_PORT_STAT_C_CONNECTION))
+#ifdef CONFIG_USB_ETRON_HUB
+	{
 		clear_bit(port1, hub->removed_bits);
+		clear_bit(port1, hub->bot_mode_bits);
+	}
+#else /*CONFIG_USB_ETRON_HUB*/
+		clear_bit(port1, hub->removed_bits);
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 	if (portchange & (USB_PORT_STAT_C_CONNECTION |
 				USB_PORT_STAT_C_ENABLE)) {
@@ -4546,6 +4665,9 @@ static void hub_port_connect_change(struct usb_hub *hub, int port1,
 		status = hub_power_remaining(hub);
 		if (status)
 			dev_dbg(hub_dev, "%dmA power budget left\n", status);
+#ifdef CONFIG_USB_ETRON_HUB
+		hub_enable_battery_charge(hub, udev);
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 		return;
 
@@ -4803,13 +4925,31 @@ static void hub_events(void)
 					hub->ports[i - 1]->child;
 
 				dev_dbg(hub_dev, "warm reset port %d\n", i);
-				if (!udev || !(portstatus &
-						USB_PORT_STAT_CONNECTION)) {
+				if (!udev ||
+				    !(portstatus & USB_PORT_STAT_CONNECTION) ||
+				    udev->state == USB_STATE_NOTATTACHED) {
 					status = hub_port_reset(hub, i,
 							NULL, HUB_BH_RESET_TIME,
 							true);
 					if (status < 0)
 						hub_port_disable(hub, i, 1);
+#ifdef CONFIG_USB_ETRON_HUB
+					else if (usb_is_etron_hcd(hdev)) {
+						ret = hub_port_status(hub, i,
+								&portstatus, &portchange);
+						if (ret < 0)
+							continue;
+
+						connect_change = 0;
+						if (!udev) {
+							if (portstatus & USB_PORT_STAT_CONNECTION)
+								connect_change = 1;
+						} else {
+							if (!(portstatus & USB_PORT_STAT_CONNECTION))
+								connect_change = 1;
+						}
+					}
+#endif /*CONFIG_USB_ETRON_HUB*/
 				} else {
 					usb_lock_device(udev);
 					status = usb_reset_device(udev);
@@ -5023,6 +5163,33 @@ static int descriptors_changed(struct usb_device *udev,
 	kfree(buf);
 	return changed;
 }
+#ifdef CONFIG_USB_ETRON_HUB
+static void usb_stop_device(struct usb_device *udev)
+{
+	int i;
+	struct usb_hcd *hcd = bus_to_hcd(udev->bus);
+	struct usb_host_endpoint *ep;
+
+
+	if (!usb_is_etron_hcd(udev))
+		return;
+	for (i = 1; i < 16; i++) {
+		ep = udev->ep_out[i];
+		if (ep) {
+			ep->enabled = 0;
+			if (hcd->driver->stop_endpoint)
+				hcd->driver->stop_endpoint(hcd, udev, ep);
+		}
+
+		ep = udev->ep_in[i];
+		if (ep) {
+			ep->enabled = 0;
+			if (hcd->driver->stop_endpoint)
+				hcd->driver->stop_endpoint(hcd, udev, ep);
+		}
+	}
+}
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 /**
  * usb_reset_and_verify_device - perform a USB port reset to reinitialize a device
@@ -5093,6 +5260,9 @@ static int usb_reset_and_verify_device(struct usb_device *udev)
 				__func__);
 		goto re_enumerate;
 	}
+#ifdef CONFIG_USB_ETRON_HUB
+	usb_stop_device(udev);
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 	set_bit(port1, parent_hub->busy_bits);
 	for (i = 0; i < SET_CONFIG_TRIES; ++i) {
@@ -5422,6 +5592,18 @@ void usb_hub_adjust_deviceremovable(struct usb_device *hdev,
 		desc->u.ss.DeviceRemovable = cpu_to_le16(port_removable);
 	}
 }
+#ifdef CONFIG_USB_ETRON_HUB
+int usb_is_etron_hcd(struct usb_device *udev)
+{
+	struct usb_hcd *hcd = bus_to_hcd(udev->bus);
+
+	if (hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168 ||
+		hcd->chip_id == HCD_CHIP_ID_ETRON_EJ188)
+		return 1;
+
+	return 0;
+}
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 #ifdef CONFIG_ACPI
 /**
diff --git a/drivers/usb/core/hub.h b/drivers/usb/core/hub.h
index f608b39..ebcd3c4 100644
--- a/drivers/usb/core/hub.h
+++ b/drivers/usb/core/hub.h
@@ -51,6 +51,9 @@ struct usb_hub {
 							device present */
 	unsigned long		wakeup_bits[1];	/* ports that have signaled
 							remote wakeup */
+#ifdef CONFIG_USB_ETRON_HUB
+	unsigned long		bot_mode_bits[1];
+#endif /*CONFIG_USB_ETRON_HUB*/
 #if USB_MAXCHILDREN > 31 /* 8*sizeof(unsigned long) - 1 */
 #error event_bits[] is too short!
 #endif
diff --git a/drivers/usb/core/message.c b/drivers/usb/core/message.c
index 444d30e..8dc6800 100644
--- a/drivers/usb/core/message.c
+++ b/drivers/usb/core/message.c
@@ -1152,6 +1152,13 @@ void usb_disable_device(struct usb_device *dev, int skip_ep0)
 		for (i = 0; i < dev->actconfig->desc.bNumInterfaces; i++)
 			dev->actconfig->interface[i]->unregistering = 1;
 
+#ifdef CONFIG_USB_ETRON_HCD
+		if (usb_is_etron_hcd(dev))
+		for (i = skip_ep0; i < 16; ++i) {
+			usb_disable_endpoint(dev, i, false);
+			usb_disable_endpoint(dev, i + USB_DIR_IN, false);
+		}
+#endif /*CONFIG_USB_ETRON_HCD*/
 		for (i = 0; i < dev->actconfig->desc.bNumInterfaces; i++) {
 			struct usb_interface	*interface;
 
diff --git a/drivers/usb/core/usb.h b/drivers/usb/core/usb.h
index c493836..41eb58c 100644
--- a/drivers/usb/core/usb.h
+++ b/drivers/usb/core/usb.h
@@ -70,6 +70,10 @@ extern int  usb_hub_init(void);
 extern void usb_hub_cleanup(void);
 extern int usb_major_init(void);
 extern void usb_major_cleanup(void);
+#ifdef CONFIG_USB_ETRON_HUB
+extern int usb_is_etron_hcd(struct usb_device *udev);
+extern void usb_run_bot_mode_notification(struct usb_device *hdev, unsigned int portnum);
+#endif /*CONFIG_USB_ETRON_HUB*/
 
 #ifdef	CONFIG_PM
 
diff --git a/drivers/usb/gadget/tcm_usb_gadget.c b/drivers/usb/gadget/tcm_usb_gadget.c
index 7cacd6a..cdec249 100644
--- a/drivers/usb/gadget/tcm_usb_gadget.c
+++ b/drivers/usb/gadget/tcm_usb_gadget.c
@@ -370,7 +370,7 @@ err:
 	return -ENOMEM;
 }
 
-void bot_cleanup_old_alt(struct f_uas *fu)
+static void bot_cleanup_old_alt(struct f_uas *fu)
 {
 	if (!(fu->flags & USBG_ENABLED))
 		return;
@@ -472,7 +472,7 @@ static int usbg_bot_setup(struct usb_function *f,
 		bot_enqueue_cmd_cbw(fu);
 		return 0;
 		break;
-	};
+	}
 	return -ENOTSUPP;
 }
 
@@ -617,7 +617,7 @@ static void uasp_status_data_cmpl(struct usb_ep *ep, struct usb_request *req)
 
 	default:
 		BUG();
-	};
+	}
 	return;
 
 cleanup:
@@ -1467,9 +1467,13 @@ static int usbg_get_cmd_state(struct se_cmd *se_cmd)
 	return 0;
 }
 
-static int usbg_queue_tm_rsp(struct se_cmd *se_cmd)
+static void usbg_queue_tm_rsp(struct se_cmd *se_cmd)
 {
-	return 0;
+}
+
+static void usbg_aborted_task(struct se_cmd *se_cmd)
+{
+	return;
 }
 
 static const char *usbg_check_wwn(const char *name)
@@ -1614,7 +1618,7 @@ static struct se_wwn *usbg_make_tport(
 		return ERR_PTR(-ENOMEM);
 	}
 	tport->tport_wwpn = wwpn;
-	snprintf(tport->tport_name, sizeof(tport->tport_name), wnn_name);
+	snprintf(tport->tport_name, sizeof(tport->tport_name), "%s", wnn_name);
 	return &tport->tport_wwn;
 }
 
@@ -1898,6 +1902,7 @@ static struct target_core_fabric_ops usbg_ops = {
 	.queue_data_in			= usbg_send_read_response,
 	.queue_status			= usbg_send_status_response,
 	.queue_tm_rsp			= usbg_queue_tm_rsp,
+	.aborted_task			= usbg_aborted_task,
 	.check_stop_free		= usbg_check_stop_free,
 
 	.fabric_make_wwn		= usbg_make_tport,
@@ -1924,15 +1929,15 @@ static int usbg_register_configfs(void)
 	}
 
 	fabric->tf_ops = usbg_ops;
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = usbg_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = usbg_base_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = usbg_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = usbg_base_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 	ret = target_fabric_configfs_register(fabric);
 	if (ret < 0) {
 		printk(KERN_ERR "target_fabric_configfs_register() failed"
diff --git a/drivers/usb/host/Kconfig b/drivers/usb/host/Kconfig
index 344d5e2..b97aac1 100644
--- a/drivers/usb/host/Kconfig
+++ b/drivers/usb/host/Kconfig
@@ -3,6 +3,23 @@
 #
 comment "USB Host Controller Drivers"
 
+config USB_ETRON_HCD
+	tristate "Etron HCD support"
+	depends on PCI
+	help
+	  The Etron EJ168A chip is USB 3.0 host controller.
+
+	  Enable this option to support this chip in host controller mode.
+	  If unsure, say N.
+
+	  To compile this driver as a module, choose M here: the
+	  module will be called etxhci-hcd.
+
+config USB_ETRON_HUB
+	bool
+	depends on USB_ETRON_HCD
+	default y
+
 config USB_C67X00_HCD
 	tristate "Cypress C67x00 HCD support"
 	help
diff --git a/drivers/usb/host/Makefile b/drivers/usb/host/Makefile
index 4fb73c1..524a980 100644
--- a/drivers/usb/host/Makefile
+++ b/drivers/usb/host/Makefile
@@ -41,6 +41,7 @@ obj-$(CONFIG_USB_OHCI_HCD)	+= ohci-hcd.o
 obj-$(CONFIG_USB_UHCI_HCD)	+= uhci-hcd.o
 obj-$(CONFIG_USB_FHCI_HCD)	+= fhci.o
 obj-$(CONFIG_USB_XHCI_HCD)	+= xhci-hcd.o
+obj-$(CONFIG_USB_ETRON_HCD)	+= xhci-ejxxx.o
 obj-$(CONFIG_USB_SL811_HCD)	+= sl811-hcd.o
 obj-$(CONFIG_USB_SL811_CS)	+= sl811_cs.o
 obj-$(CONFIG_USB_U132_HCD)	+= u132-hcd.o
diff --git a/drivers/usb/host/ehci-pci.c b/drivers/usb/host/ehci-pci.c
index 8fe401c..200c0ec 100644
--- a/drivers/usb/host/ehci-pci.c
+++ b/drivers/usb/host/ehci-pci.c
@@ -65,6 +65,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 
 	ehci->caps = hcd->regs;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/*
 	 * ehci_init() causes memory for DMA transfers to be
 	 * allocated.  Thus, any vendor-specific workarounds based on
@@ -199,6 +202,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 		ehci->frame_index_bug = 1;
 		break;
 	}
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	/* optional debug port, normally in the first BAR */
 	temp = pci_find_capability(pdev, PCI_CAP_ID_DBG);
@@ -224,6 +230,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 	if (retval)
 		return retval;
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* These workarounds need to be applied after ehci_setup() */
 	switch (pdev->vendor) {
 	case PCI_VENDOR_ID_NEC:
@@ -247,6 +256,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 		}
 		break;
 	}
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 
 	/* at least the Genesys GL880S needs fixup here */
 	temp = HCS_N_CC(ehci->hcs_params) * HCS_N_PCC(ehci->hcs_params);
@@ -258,6 +270,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 			HCS_N_PCC(ehci->hcs_params),
 			HCS_N_PORTS(ehci->hcs_params));
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+		if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 		switch (pdev->vendor) {
 		case 0x17a0:		/* GENESYS */
 			/* GL880S: should be PORTS=2 */
@@ -268,8 +283,14 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 			/* NF4: should be PCC=10 */
 			break;
 		}
+#ifdef CONFIG_BUFFALO_PLATFORM
+		}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	}
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+	if (hcd->self.controller->bus == &pci_bus_type) {
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 	/* Serial Bus Release Number is at PCI 0x60 offset */
 	if (pdev->vendor == PCI_VENDOR_ID_STMICRO
 	    && pdev->device == PCI_DEVICE_ID_STMICRO_USB_HOST)
@@ -298,6 +319,9 @@ static int ehci_pci_setup(struct usb_hcd *hcd)
 #endif
 
 	retval = ehci_pci_reinit(ehci, pdev);
+#ifdef CONFIG_BUFFALO_PLATFORM
+	}
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 done:
 	return retval;
 }
diff --git a/drivers/usb/host/pci-quirks.c b/drivers/usb/host/pci-quirks.c
index 4c338ec..c886928 100644
--- a/drivers/usb/host/pci-quirks.c
+++ b/drivers/usb/host/pci-quirks.c
@@ -946,6 +946,9 @@ hc_init:
 
 static void quirk_usb_early_handoff(struct pci_dev *pdev)
 {
+#ifdef CONFIG_ARCH_ALPINE
+	return;
+#endif
 	/* Skip Netlogic mips SoC's internal PCI USB controller.
 	 * This device does not need/support EHCI/OHCI handoff
 	 */
diff --git a/drivers/usb/host/xhci-dbg.c b/drivers/usb/host/xhci-dbg.c
index 5f3a7c7..2049626 100644
--- a/drivers/usb/host/xhci-dbg.c
+++ b/drivers/usb/host/xhci-dbg.c
@@ -572,3 +572,19 @@ void xhci_dbg_ctx(struct xhci_hcd *xhci,
 	xhci_dbg_slot_ctx(xhci, ctx);
 	xhci_dbg_ep_ctx(xhci, ctx, last_ep);
 }
+#ifdef CONFIG_USB_ETRON_HCD
+void xhci_dbg_stream_info(struct xhci_hcd *xhci,
+		unsigned int ep_index, struct xhci_stream_info *stream_info)
+{
+	 int i;
+
+	xhci_dbg(xhci, "Endpoint %d stream information:\n", ep_index);
+	xhci_dbg(xhci, "Stream ID %d\n", stream_info->num_streams);
+	xhci_dbg(xhci, "Stream context array %d, @%08llx (dma)\n",
+		stream_info->num_stream_ctxs, (unsigned long long)stream_info->ctx_array_dma);
+	for (i = 0; i < stream_info->num_stream_ctxs; i++) {
+		xhci_dbg(xhci, "Stream ID %d @%08llx (dma) - deq\n",
+			i, le64_to_cpu(stream_info->stream_ctx_array[i].stream_ring));
+	}
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
diff --git a/drivers/usb/host/xhci-ej168v0.0660.c b/drivers/usb/host/xhci-ej168v0.0660.c
new file mode 100644
index 00000000..2c2dd13
--- /dev/null
+++ b/drivers/usb/host/xhci-ej168v0.0660.c
@@ -0,0 +1,135 @@
+/*
+ * xHCI host controller driver PCI Bus Glue.
+ *
+ * Copyright (C) 2008 Intel Corp.
+ *
+ * Author: Sarah Sharp
+ * Some code borrowed from the Linux EHCI driver.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/pci.h>
+
+#include "xhci.h"
+
+static struct table_item cfg_s1_items_v00660[] = {
+		{0x9b, 0xa1},
+		{0x9c, 0x18},
+		{0xec, 0x04},
+		{0xf5, 0x40},
+};
+#define CFG_S1_ITEMS_V00660	((int)(sizeof(cfg_s1_items_v00660)/sizeof(cfg_s1_items_v00660[0])))
+
+static struct table_item cfg_s2_items_v00660[] = {
+		{0x44, 0x00000003},
+		{0x2c, 0x70231b6f},
+		{0x68, 0x19c001c1},
+		{0x68, 0x18005000},
+		{0x68, 0x198001d0},
+		{0x68, 0x18005000},
+		{0x68, 0x199001d1},
+		{0x68, 0x18005000},
+		{0x68, 0x19eb5003},
+		{0x68, 0x19305004},
+		{0x68, 0x19005005},
+		{0x68, 0x19045007},
+		{0x68, 0x19f05022},
+		{0x68, 0x190000ec},
+		{0x44, 0x00000000},
+};
+#define CFG_S2_ITEMS_V00660	((int)(sizeof(cfg_s2_items_v00660)/sizeof(cfg_s2_items_v00660[0])))
+
+static struct table_item mmio_items_v00660[] = {
+		{0x1811, 0x60},
+		{0x4000, 0x60},
+		{0x4001, 0x06},
+		{0x4002, 0x50},
+		{0x4003, 0x21},
+		{0x0008, 0xff},
+		{0x0010, 0xa5},
+		{0x0011, 0x40},
+		{0x4022, 0x10},
+		{0x4059, 0x80},
+		{0x405f, 0x04},
+		{0x4063, 0x01},
+		{0x4071, 0x23},
+		{0x4072, 0x76},
+		{0x4075, 0x80},
+		{0x4079, 0x02},
+		{0x407d, 0x20},
+		{0x407e, 0x80},
+		{0x4090, 0x00},
+		{0x4091, 0x30},
+		{0x40ac, 0xa8},
+		{0x40ad, 0x61},
+		{0x40bc, 0xa8},
+		{0x40bd, 0x61},
+		{0x40a4, 0x05},
+		{0x40b4, 0x05},
+		{0x4200, 0x08},
+		{0x4300, 0x08},
+		{0x4202, 0x58},
+		{0x4302, 0x58},
+		{0x40c0, 0x0e},
+		{0x40f4, 0x03},
+		{0x1811, 0x61},
+};
+
+#define MMIO_ITEMS_V00660	((int)(sizeof(mmio_items_v00660)/sizeof(mmio_items_v00660[0])))
+
+void xhci_init_ej168_v00660(struct xhci_hcd *xhci)
+{
+	int i, error_flag = 0;
+	struct usb_hcd *hcd = xhci_to_hcd(xhci);
+	struct pci_dev *pdev = to_pci_dev(hcd->self.controller);
+	u8 reg8 = 0;
+
+	for (i = 0; i < CFG_S1_ITEMS_V00660; i++) {
+		pci_write_config_byte(pdev, cfg_s1_items_v00660[i].offset,
+			(u8)cfg_s1_items_v00660[i].value);
+	}
+
+	for (i = 0; i < CFG_S2_ITEMS_V00660; i++) {
+		pci_write_config_dword(pdev, cfg_s2_items_v00660[i].offset,
+			cfg_s2_items_v00660[i].value);
+		if (cfg_s2_items_v00660[i].offset == 0x68 &&
+			cfg_s2_items_v00660[i].value != 0x18005000)
+			mdelay(1);
+	}
+
+	for (i = 0; i < MMIO_ITEMS_V00660; i++) {
+		xhci_writeb(xhci, mmio_items_v00660[i].value,
+			mmio_items_v00660[i].offset);
+	}
+
+	for (i = 0; i < MMIO_ITEMS_V00660; i++) {
+		if ((0x1811 != mmio_items_v00660[i].offset) && (0 == error_flag)) {
+			reg8 = xhci_readb(xhci, mmio_items_v00660[i].offset);
+			if (reg8 != (u8)mmio_items_v00660[i].value)
+				error_flag = 1;
+		}
+	}
+
+	if (error_flag) {
+		for (i = 0; i < MMIO_ITEMS_V00660; i++) {
+			if (0x1811 != mmio_items_v00660[i].offset) {
+				reg8 = xhci_readb(xhci, mmio_items_v00660[i].offset);
+				xhci_err(xhci, "%s - @%04x %02x\n",
+					__func__, mmio_items_v00660[i].offset, reg8);
+			}
+		}
+	}
+}
+
diff --git a/drivers/usb/host/xhci-ej188v0.03.01.500.c b/drivers/usb/host/xhci-ej188v0.03.01.500.c
new file mode 100644
index 00000000..b77c7c6
--- /dev/null
+++ b/drivers/usb/host/xhci-ej188v0.03.01.500.c
@@ -0,0 +1,243 @@
+/*
+ * xHCI host controller driver PCI Bus Glue.
+ *
+ * Copyright (C) 2008 Intel Corp.
+ *
+ * Author: Sarah Sharp
+ * Some code borrowed from the Linux EHCI driver.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/pci.h>
+
+#include "xhci.h"
+
+static struct table_item cfg_items_v00301500[] = {
+	{0x44, 0x03},
+	{0xf0, 0x00},
+	{0xf1, 0x51},
+	{0xf4, 0x00},
+	{0xf0, 0x01},
+	{0xf5, 0x15},
+	{0xf0, 0x02},
+	{0xf6, 0x30},
+	{0xf0, 0x03},
+	{0xf7, 0x00},
+	{0xf0, 0x00},
+	{0xf1, 0x00},
+	{0xf4, 0x6f},
+	{0xf0, 0x01},
+	{0xf5, 0x1b},
+	{0xf0, 0x02},
+	{0xf6, 0x52},
+	{0xf0, 0x03},
+	{0xf7, 0x70},
+	{0xf0, 0x2c},
+	{0xf4, 0x6f},
+	{0xf0, 0x2d},
+	{0xf5, 0x1b},
+	{0xf0, 0x2e},
+	{0xf6, 0x52},
+	{0xf0, 0x2f},
+	{0xf7, 0x70},
+	{0xf0, 0x98},
+	{0xf4, 0x24},
+	{0xf0, 0x11},
+	{0xf1, 0x50},
+	{0xf5, 0x00},
+	{0xf0, 0x16},
+	{0xf1, 0x30},
+	{0xf6, 0x89},
+	{0xf0, 0x17},
+	{0xf7, 0x08},
+	{0xf0, 0x18},
+	{0xf4, 0xfc},
+	{0xf0, 0x17},
+	{0xf7, 0x08},
+	{0xf0, 0x04},
+	{0xf1, 0x50},
+	{0xf4, 0x00},
+	{0xf0, 0x08},
+	{0xf4, 0x07},
+	{0xf0, 0x10},
+	{0xf4, 0x04},
+	{0x44, 0x00},
+};
+#define CFG_ITEMS_V00301500	((int)(sizeof(cfg_items_v00301500)/sizeof(cfg_items_v00301500[0])))
+
+static struct table_item mmio_items_v00301500[] = {
+	{0x1811, 0x60},
+	{0x5034, 0x6f},
+	{0x5035, 0x1b},
+	{0x0000, 0x20},
+	{0x0001, 0x00},
+	{0x0002, 0x00},
+	{0x0003, 0x01},
+	{0x0004, 0x50},
+	{0x0005, 0x04},
+	{0x0006, 0x00},
+	{0x0007, 0x08},
+	{0x0010, 0xa5},
+	{0x0011, 0x40},
+	{0x4011, 0x72},
+	{0x4012, 0x00},
+	{0x40f4, 0x02},
+	{0x4100, 0x8f},
+	{0x4101, 0x8f},
+	{0x4102, 0x00},
+	{0x4103, 0xff},
+	{0x4104, 0xff},
+	{0x4105, 0x0f},
+	{0x4108, 0x1f},
+	{0x4109, 0x0f},
+	{0x410a, 0x00},
+	{0x410b, 0xff},
+	{0x410c, 0xff},
+	{0x410d, 0x0f},
+	{0x4110, 0x42},
+	{0x4111, 0x42},
+	{0x4112, 0x00},
+	{0x4113, 0x44},
+	{0x4114, 0x44},
+	{0x4115, 0x04},
+	{0x4120, 0x8f},
+	{0x4121, 0x8f},
+	{0x4122, 0x00},
+	{0x4123, 0xff},
+	{0x4124, 0xff},
+	{0x4125, 0x0f},
+	{0x4128, 0x1f},
+	{0x4129, 0x0f},
+	{0x412a, 0x00},
+	{0x412b, 0xff},
+	{0x412c, 0xff},
+	{0x412d, 0x0f},
+	{0x4130, 0x44},
+	{0x4131, 0x44},
+	{0x4132, 0x00},
+	{0x4133, 0x44},
+	{0x4134, 0x40},
+	{0x4135, 0x04},
+	{0x4142, 0x10},
+	{0x4052, 0x01},
+	{0x4211, 0xa0},
+	{0x4251, 0xa0},
+	{0x4380, 0xd2},
+	{0x4381, 0x01},
+	{0x4213, 0x01},
+	{0x4253, 0x01},
+	{0x4203, 0x80},
+	{0x4243, 0x80},
+	{0x4280, 0x00},
+	{0x4281, 0x01},
+	{0x4282, 0x00},
+	{0x4283, 0x08},
+	{0x42c0, 0x00},
+	{0x42c1, 0x01},
+	{0x42c2, 0x00},
+	{0x42c3, 0x08},
+	{0x4286, 0x20},
+	{0x4287, 0x09},
+	{0x42c6, 0x20},
+	{0x42c7, 0x09},
+	{0x428c, 0xc2},
+	{0x42cc, 0xc2},
+	{0x4294, 0x0c},
+	{0x4297, 0x70},
+	{0x42d4, 0x0c},
+	{0x42d7, 0x70},
+	{0x4288, 0x10},
+	{0x4289, 0xf3},
+	{0x42c8, 0x10},
+	{0x42c9, 0xf3},
+	{0x4305, 0x84},
+	{0x4307, 0x10},
+	{0x4309, 0x02},
+	{0x430e, 0x80},
+	{0x4313, 0x88},
+	{0x440f, 0x10},
+	{0x4410, 0xa8},
+	{0x4411, 0x61},
+	{0x444f, 0x10},
+	{0x4450, 0xa8},
+	{0x4451, 0x61},
+	{0x448f, 0x10},
+	{0x4490, 0xa8},
+	{0x4491, 0x61},
+	{0x44cf, 0x10},
+	{0x44d0, 0xa8},
+	{0x44d1, 0x61},
+	{0x4424, 0x0d},
+	{0x4425, 0x08},
+	{0x4464, 0x0d},
+	{0x4465, 0x08},
+	{0x44a4, 0x0d},
+	{0x44a5, 0x08},
+	{0x44e4, 0x0d},
+	{0x44e5, 0x08},
+	{0x4428, 0xc8},
+	{0x4429, 0x60},
+	{0x442a, 0x58},
+	{0x4468, 0xc8},
+	{0x4469, 0x60},
+	{0x446a, 0x58},
+	{0x44a8, 0xc8},
+	{0x44a9, 0x60},
+	{0x44aa, 0x58},
+	{0x44e8, 0xc8},
+	{0x44e9, 0x60},
+	{0x44ea, 0x58},
+	{0x5036, 0x52},
+	{0x5037, 0x70},
+	{0x1811, 0x61},
+};
+#define MMIO_ITEMS_V00301500	((int)(sizeof(mmio_items_v00301500)/sizeof(mmio_items_v00301500[0])))
+
+void xhci_init_ej188_v00301500(struct xhci_hcd *xhci)
+{
+	int i, error_flag = 0;
+	struct usb_hcd *hcd = xhci_to_hcd(xhci);
+	struct pci_dev *pdev = to_pci_dev(hcd->self.controller);
+	u8 reg8 = 0;
+
+	for (i = 0; i < CFG_ITEMS_V00301500; i++) {
+		pci_write_config_byte(pdev, cfg_items_v00301500[i].offset,
+			cfg_items_v00301500[i].value);
+	}
+
+	for (i = 0; i < MMIO_ITEMS_V00301500; i++) {
+		xhci_writeb(xhci, mmio_items_v00301500[i].value,
+			mmio_items_v00301500[i].offset);
+	}
+
+	for (i = 0; i < MMIO_ITEMS_V00301500; i++) {
+		if ((0x1811 != mmio_items_v00301500[i].offset) && (0 == error_flag)) {
+			reg8 = xhci_readb(xhci, mmio_items_v00301500[i].offset);
+			if (reg8 != (u8)mmio_items_v00301500[i].value)
+				error_flag = 1;
+		}
+	}
+
+	if (error_flag) {
+		for (i = 0; i < MMIO_ITEMS_V00301500; i++) {
+			if (0x1811 != mmio_items_v00301500[i].offset) {
+				reg8 = xhci_readb(xhci, mmio_items_v00301500[i].offset);
+				xhci_err(xhci, "%s - @%04x %02x\n",
+					__func__, mmio_items_v00301500[i].offset, reg8);
+			}
+		}
+	}
+}
+
diff --git a/drivers/usb/host/xhci-ejxxx.c b/drivers/usb/host/xhci-ejxxx.c
new file mode 100644
index 00000000..0c37499
--- /dev/null
+++ b/drivers/usb/host/xhci-ejxxx.c
@@ -0,0 +1,59 @@
+/*
+ * xHCI host controller driver PCI Bus Glue.
+ *
+ * Copyright (C) 2008 Intel Corp.
+ *
+ * Author: Sarah Sharp
+ * Some code borrowed from the Linux EHCI driver.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+ * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+
+#include <linux/pci.h>
+
+#include "xhci.h"
+#include "xhci-ej168v0.0660.c"
+#include "xhci-ej188v0.03.01.500.c"
+
+void xhci_init_ejxxx(struct xhci_hcd *xhci)
+{
+	struct usb_hcd *hcd = xhci_to_hcd(xhci);
+	u32 reg32 = 0;
+
+	switch (xhci->hcc_params1 & 0xff) {
+	case 0x30:
+		xhci_init_ej168_v00660(xhci);
+
+		reg32 = xhci_readl(xhci, hcd->regs + 0x40c0);
+		reg32 = (reg32 & 0xffff00ff) | 0x0100;
+		xhci_writel(xhci, reg32, hcd->regs + 0x40c0);
+		reg32 = xhci_readl(xhci, hcd->regs + 0x40d4);
+		reg32 = (reg32 & 0xfffffffe) | 0x01;
+		xhci_writel(xhci, reg32, hcd->regs + 0x40d4);
+		break;
+	case 0x40:
+		xhci_init_ej188_v00301500(xhci);
+
+		reg32 = xhci_readl(xhci, hcd->regs + 0x4294);
+		reg32 = (reg32 & 0xfffffffe) | 0x01;
+		xhci_writel(xhci, reg32, hcd->regs + 0x4294);
+		reg32 = xhci_readl(xhci, hcd->regs + 0x42d4);
+		reg32 = (reg32 & 0xfffffffe) | 0x01;
+		xhci_writel(xhci, reg32, hcd->regs + 0x42d4);
+		break;
+	default:
+		break;
+	}
+}
+
diff --git a/drivers/usb/host/xhci-hub.c b/drivers/usb/host/xhci-hub.c
index 7cdcfd0..cf31368 100644
--- a/drivers/usb/host/xhci-hub.c
+++ b/drivers/usb/host/xhci-hub.c
@@ -382,6 +382,10 @@ static void xhci_clear_port_change_bit(struct xhci_hcd *xhci, u16 wValue,
 		status = PORT_PLC;
 		port_change_bit = "link state";
 		break;
+	case USB_PORT_FEAT_C_PORT_CONFIG_ERROR:
+		status = PORT_CEC;
+		port_change_bit = "config error";
+		break;
 	default:
 		/* Should never happen */
 		return;
@@ -621,6 +625,8 @@ int xhci_hub_control(struct usb_hcd *hcd, u16 typeReq, u16 wValue,
 				status |= USB_PORT_STAT_C_LINK_STATE << 16;
 			if ((temp & PORT_WRC))
 				status |= USB_PORT_STAT_C_BH_RESET << 16;
+			if ((temp & PORT_CEC))
+				status |= USB_PORT_STAT_C_CONFIG_ERROR << 16;
 		}
 
 		if (hcd->speed != HCD_USB3) {
@@ -695,6 +701,10 @@ int xhci_hub_control(struct usb_hcd *hcd, u16 typeReq, u16 wValue,
 		}
 		if (bus_state->port_c_suspend & (1 << wIndex))
 			status |= 1 << USB_PORT_FEAT_C_SUSPEND;
+#ifdef CONFIG_USB_ETRON_HCD
+		if (bus_state->port_c_connection & (1 << wIndex))
+			status |= USB_PORT_STAT_C_CONNECTION << 16;
+#endif /*CONFIG_USB_ETRON_HCD*/
 		xhci_dbg(xhci, "Get port status returned 0x%x\n", status);
 		put_unaligned(cpu_to_le32(status), (__le32 *) buf);
 		break;
@@ -926,14 +936,28 @@ int xhci_hub_control(struct usb_hcd *hcd, u16 typeReq, u16 wValue,
 			}
 			xhci_ring_device(xhci, slot_id);
 			break;
+#ifdef CONFIG_USB_ETRON_HCD
+		case USB_PORT_FEAT_C_CONNECTION:
+			if (bus_state->port_c_connection & (1 << wIndex)) {
+				bus_state->port_c_connection &= ~(1 << wIndex);
+				bus_state->resume_done[wIndex] = 0;
+				break;
+			}
+			goto case_USB_PORT_FEAT_C_CONNECTION;
+#endif /*CONFIG_USB_ETRON_HCD*/
 		case USB_PORT_FEAT_C_SUSPEND:
 			bus_state->port_c_suspend &= ~(1 << wIndex);
 		case USB_PORT_FEAT_C_RESET:
 		case USB_PORT_FEAT_C_BH_PORT_RESET:
+#ifdef CONFIG_USB_ETRON_HCD
+		case_USB_PORT_FEAT_C_CONNECTION:
+#else /*CONFIG_USB_ETRON_HCD*/
 		case USB_PORT_FEAT_C_CONNECTION:
+#endif /*CONFIG_USB_ETRON_HCD*/
 		case USB_PORT_FEAT_C_OVER_CURRENT:
 		case USB_PORT_FEAT_C_ENABLE:
 		case USB_PORT_FEAT_C_PORT_LINK_STATE:
+		case USB_PORT_FEAT_C_PORT_CONFIG_ERROR:
 			xhci_clear_port_change_bit(xhci, wValue, wIndex,
 					port_array[wIndex], temp);
 			break;
@@ -999,7 +1023,7 @@ int xhci_hub_status_data(struct usb_hcd *hcd, char *buf)
 	 */
 	status = bus_state->resuming_ports;
 
-	mask = PORT_CSC | PORT_PEC | PORT_OCC | PORT_PLC | PORT_WRC;
+	mask = PORT_CSC | PORT_PEC | PORT_OCC | PORT_PLC | PORT_WRC | PORT_CEC;
 
 	spin_lock_irqsave(&xhci->lock, flags);
 	/* For each port, did anything change?  If so, set that bit in buf. */
@@ -1010,6 +1034,9 @@ int xhci_hub_status_data(struct usb_hcd *hcd, char *buf)
 			break;
 		}
 		if ((temp & mask) != 0 ||
+#ifdef CONFIG_USB_ETRON_HCD
+			(bus_state->port_c_connection & 1 << i) ||
+#endif /*CONFIG_USB_ETRON_HCD*/
 			(bus_state->port_c_suspend & 1 << i) ||
 			(bus_state->resume_done[i] && time_after_eq(
 			    jiffies, bus_state->resume_done[i]))) {
@@ -1043,10 +1070,10 @@ int xhci_bus_suspend(struct usb_hcd *hcd)
 	spin_lock_irqsave(&xhci->lock, flags);
 
 	if (hcd->self.root_hub->do_remote_wakeup) {
-		if (bus_state->resuming_ports) {
+		if (bus_state->resuming_ports ||	/* USB2 */
+		    bus_state->port_remote_wakeup) {	/* USB3 */
 			spin_unlock_irqrestore(&xhci->lock, flags);
-			xhci_dbg(xhci, "suspend failed because "
-						"a port is resuming\n");
+			xhci_dbg(xhci, "suspend failed because a port is resuming\n");
 			return -EBUSY;
 		}
 	}
diff --git a/drivers/usb/host/xhci-mem.c b/drivers/usb/host/xhci-mem.c
index f2e57a1..3ce3456 100644
--- a/drivers/usb/host/xhci-mem.c
+++ b/drivers/usb/host/xhci-mem.c
@@ -147,14 +147,95 @@ static void xhci_link_rings(struct xhci_hcd *xhci, struct xhci_ring *ring,
 	}
 }
 
+/*
+ * We need a radix tree for mapping physical addresses of TRBs to which stream
+ * ID they belong to.  We need to do this because the host controller won't tell
+ * us which stream ring the TRB came from.  We could store the stream ID in an
+ * event data TRB, but that doesn't help us for the cancellation case, since the
+ * endpoint may stop before it reaches that event data TRB.
+ *
+ * The radix tree maps the upper portion of the TRB DMA address to a ring
+ * segment that has the same upper portion of DMA addresses.  For example, say I
+ * have segments of size 1KB, that are always 64-byte aligned.  A segment may
+ * start at 0x10c91000 and end at 0x10c913f0.  If I use the upper 10 bits, the
+ * key to the stream ID is 0x43244.  I can use the DMA address of the TRB to
+ * pass the radix tree a key to get the right stream ID:
+ *
+ *	0x10c90fff >> 10 = 0x43243
+ *	0x10c912c0 >> 10 = 0x43244
+ *	0x10c91400 >> 10 = 0x43245
+ *
+ * Obviously, only those TRBs with DMA addresses that are within the segment
+ * will make the radix tree return the stream ID for that ring.
+ *
+ * Caveats for the radix tree:
+ *
+ * The radix tree uses an unsigned long as a key pair.  On 32-bit systems, an
+ * unsigned long will be 32-bits; on a 64-bit system an unsigned long will be
+ * 64-bits.  Since we only request 32-bit DMA addresses, we can use that as the
+ * key on 32-bit or 64-bit systems (it would also be fine if we asked for 64-bit
+ * PCI DMA addresses on a 64-bit system).  There might be a problem on 32-bit
+ * extended systems (where the DMA address can be bigger than 32-bits),
+ * if we allow the PCI dma mask to be bigger than 32-bits.  So don't do that.
+ */
+static int xhci_update_stream_mapping(struct xhci_ring *ring, gfp_t mem_flags)
+{
+	struct xhci_segment *seg;
+	unsigned long key;
+	int ret;
+
+	if (WARN_ON_ONCE(ring->trb_address_map == NULL))
+		return 0;
+
+	seg = ring->first_seg;
+	do {
+		key = (unsigned long)(seg->dma >> TRB_SEGMENT_SHIFT);
+		/* Skip any segments that were already added. */
+		if (radix_tree_lookup(ring->trb_address_map, key))
+			continue;
+
+		ret = radix_tree_maybe_preload(mem_flags);
+		if (ret)
+			return ret;
+		ret = radix_tree_insert(ring->trb_address_map,
+				key, ring);
+		radix_tree_preload_end();
+		if (ret)
+			return ret;
+		seg = seg->next;
+	} while (seg != ring->first_seg);
+
+	return 0;
+}
+
+static void xhci_remove_stream_mapping(struct xhci_ring *ring)
+{
+	struct xhci_segment *seg;
+	unsigned long key;
+
+	if (WARN_ON_ONCE(ring->trb_address_map == NULL))
+		return;
+
+	seg = ring->first_seg;
+	do {
+		key = (unsigned long)(seg->dma >> TRB_SEGMENT_SHIFT);
+		if (radix_tree_lookup(ring->trb_address_map, key))
+			radix_tree_delete(ring->trb_address_map, key);
+		seg = seg->next;
+	} while (seg != ring->first_seg);
+}
+
 /* XXX: Do we need the hcd structure in all these functions? */
 void xhci_ring_free(struct xhci_hcd *xhci, struct xhci_ring *ring)
 {
 	if (!ring)
 		return;
 
-	if (ring->first_seg)
+	if (ring->first_seg) {
+		if (ring->type == TYPE_STREAM)
+			xhci_remove_stream_mapping(ring);
 		xhci_free_segments_for_ring(xhci, ring->first_seg);
+	}
 
 	kfree(ring);
 }
@@ -350,6 +431,11 @@ int xhci_ring_expansion(struct xhci_hcd *xhci, struct xhci_ring *ring,
 	xhci_dbg(xhci, "ring expansion succeed, now has %d segments\n",
 			ring->num_segs);
 
+	if (ring->type == TYPE_STREAM) {
+		ret = xhci_update_stream_mapping(ring, flags);
+		WARN_ON(ret); /* FIXME */
+	}
+
 	return 0;
 }
 
@@ -424,12 +510,12 @@ static void xhci_free_stream_ctx(struct xhci_hcd *xhci,
 		struct xhci_stream_ctx *stream_ctx, dma_addr_t dma)
 {
 	struct pci_dev *pdev = to_pci_dev(xhci_to_hcd(xhci)->self.controller);
+	size_t size = sizeof(struct xhci_stream_ctx) * num_stream_ctxs;
 
-	if (num_stream_ctxs > MEDIUM_STREAM_ARRAY_SIZE)
-		dma_free_coherent(&pdev->dev,
-				sizeof(struct xhci_stream_ctx)*num_stream_ctxs,
+	if (size > MEDIUM_STREAM_ARRAY_SIZE)
+		dma_free_coherent(&pdev->dev, size,
 				stream_ctx, dma);
-	else if (num_stream_ctxs <= SMALL_STREAM_ARRAY_SIZE)
+	else if (size <= SMALL_STREAM_ARRAY_SIZE)
 		return dma_pool_free(xhci->small_streams_pool,
 				stream_ctx, dma);
 	else
@@ -452,12 +538,12 @@ static struct xhci_stream_ctx *xhci_alloc_stream_ctx(struct xhci_hcd *xhci,
 		gfp_t mem_flags)
 {
 	struct pci_dev *pdev = to_pci_dev(xhci_to_hcd(xhci)->self.controller);
+	size_t size = sizeof(struct xhci_stream_ctx) * num_stream_ctxs;
 
-	if (num_stream_ctxs > MEDIUM_STREAM_ARRAY_SIZE)
-		return dma_alloc_coherent(&pdev->dev,
-				sizeof(struct xhci_stream_ctx)*num_stream_ctxs,
+	if (size > MEDIUM_STREAM_ARRAY_SIZE)
+		return dma_alloc_coherent(&pdev->dev, size,
 				dma, mem_flags);
-	else if (num_stream_ctxs <= SMALL_STREAM_ARRAY_SIZE)
+	else if (size <= SMALL_STREAM_ARRAY_SIZE)
 		return dma_pool_alloc(xhci->small_streams_pool,
 				mem_flags, dma);
 	else
@@ -563,36 +649,6 @@ static int xhci_test_radix_tree(struct xhci_hcd *xhci,
  * The number of stream contexts in the stream context array may be bigger than
  * the number of streams the driver wants to use.  This is because the number of
  * stream context array entries must be a power of two.
- *
- * We need a radix tree for mapping physical addresses of TRBs to which stream
- * ID they belong to.  We need to do this because the host controller won't tell
- * us which stream ring the TRB came from.  We could store the stream ID in an
- * event data TRB, but that doesn't help us for the cancellation case, since the
- * endpoint may stop before it reaches that event data TRB.
- *
- * The radix tree maps the upper portion of the TRB DMA address to a ring
- * segment that has the same upper portion of DMA addresses.  For example, say I
- * have segments of size 1KB, that are always 64-byte aligned.  A segment may
- * start at 0x10c91000 and end at 0x10c913f0.  If I use the upper 10 bits, the
- * key to the stream ID is 0x43244.  I can use the DMA address of the TRB to
- * pass the radix tree a key to get the right stream ID:
- *
- * 	0x10c90fff >> 10 = 0x43243
- * 	0x10c912c0 >> 10 = 0x43244
- * 	0x10c91400 >> 10 = 0x43245
- *
- * Obviously, only those TRBs with DMA addresses that are within the segment
- * will make the radix tree return the stream ID for that ring.
- *
- * Caveats for the radix tree:
- *
- * The radix tree uses an unsigned long as a key pair.  On 32-bit systems, an
- * unsigned long will be 32-bits; on a 64-bit system an unsigned long will be
- * 64-bits.  Since we only request 32-bit DMA addresses, we can use that as the
- * key on 32-bit or 64-bit systems (it would also be fine if we asked for 64-bit
- * PCI DMA addresses on a 64-bit system).  There might be a problem on 32-bit
- * extended systems (where the DMA address can be bigger than 32-bits),
- * if we allow the PCI dma mask to be bigger than 32-bits.  So don't do that.
  */
 struct xhci_stream_info *xhci_alloc_stream_info(struct xhci_hcd *xhci,
 		unsigned int num_stream_ctxs,
@@ -601,7 +657,6 @@ struct xhci_stream_info *xhci_alloc_stream_info(struct xhci_hcd *xhci,
 	struct xhci_stream_info *stream_info;
 	u32 cur_stream;
 	struct xhci_ring *cur_ring;
-	unsigned long key;
 	u64 addr;
 	int ret;
 
@@ -656,6 +711,7 @@ struct xhci_stream_info *xhci_alloc_stream_info(struct xhci_hcd *xhci,
 		if (!cur_ring)
 			goto cleanup_rings;
 		cur_ring->stream_id = cur_stream;
+		cur_ring->trb_address_map = &stream_info->trb_address_map;
 		/* Set deq ptr, cycle bit, and stream context type */
 		addr = cur_ring->first_seg->dma |
 			SCT_FOR_CTX(SCT_PRI_TR) |
@@ -665,10 +721,7 @@ struct xhci_stream_info *xhci_alloc_stream_info(struct xhci_hcd *xhci,
 		xhci_dbg(xhci, "Setting stream %d ring ptr to 0x%08llx\n",
 				cur_stream, (unsigned long long) addr);
 
-		key = (unsigned long)
-			(cur_ring->first_seg->dma >> TRB_SEGMENT_SHIFT);
-		ret = radix_tree_insert(&stream_info->trb_address_map,
-				key, cur_ring);
+		ret = xhci_update_stream_mapping(cur_ring, mem_flags);
 		if (ret) {
 			xhci_ring_free(xhci, cur_ring);
 			stream_info->stream_rings[cur_stream] = NULL;
@@ -695,9 +748,6 @@ cleanup_rings:
 	for (cur_stream = 1; cur_stream < num_streams; cur_stream++) {
 		cur_ring = stream_info->stream_rings[cur_stream];
 		if (cur_ring) {
-			addr = cur_ring->first_seg->dma;
-			radix_tree_delete(&stream_info->trb_address_map,
-					addr >> TRB_SEGMENT_SHIFT);
 			xhci_ring_free(xhci, cur_ring);
 			stream_info->stream_rings[cur_stream] = NULL;
 		}
@@ -730,6 +780,12 @@ void xhci_setup_streams_ep_input_ctx(struct xhci_hcd *xhci,
 	ep_ctx->ep_info &= cpu_to_le32(~EP_MAXPSTREAMS_MASK);
 	ep_ctx->ep_info |= cpu_to_le32(EP_MAXPSTREAMS(max_primary_streams)
 				       | EP_HAS_LSA);
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		ep_ctx->ep_info2 &= cpu_to_le32(~MAX_BURST_MASK);
+		ep_ctx->ep_info2 |= cpu_to_le32(MAX_BURST(15));
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ep_ctx->deq  = cpu_to_le64(stream_info->ctx_array_dma);
 }
 
@@ -757,7 +813,6 @@ void xhci_free_stream_info(struct xhci_hcd *xhci,
 {
 	int cur_stream;
 	struct xhci_ring *cur_ring;
-	dma_addr_t addr;
 
 	if (!stream_info)
 		return;
@@ -766,9 +821,6 @@ void xhci_free_stream_info(struct xhci_hcd *xhci,
 			cur_stream++) {
 		cur_ring = stream_info->stream_rings[cur_stream];
 		if (cur_ring) {
-			addr = cur_ring->first_seg->dma;
-			radix_tree_delete(&stream_info->trb_address_map,
-					addr >> TRB_SEGMENT_SHIFT);
 			xhci_ring_free(xhci, cur_ring);
 			stream_info->stream_rings[cur_stream] = NULL;
 		}
@@ -999,10 +1051,23 @@ void xhci_copy_ep0_dequeue_into_input_ctx(struct xhci_hcd *xhci,
 		struct usb_device *udev)
 {
 	struct xhci_virt_device *virt_dev;
+#ifdef CONFIG_USB_ETRON_HCD
+	struct xhci_input_control_ctx *ctrl_ctx;
+	struct xhci_slot_ctx *slot_ctx;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	struct xhci_ep_ctx	*ep0_ctx;
 	struct xhci_ring	*ep_ring;
 
 	virt_dev = xhci->devs[udev->slot_id];
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		ctrl_ctx = xhci_get_input_control_ctx(xhci, virt_dev->in_ctx);
+		ctrl_ctx->add_flags = cpu_to_le32(SLOT_FLAG | EP0_FLAG);
+		slot_ctx = xhci_get_slot_ctx(xhci, virt_dev->in_ctx);
+		slot_ctx->dev_info &= cpu_to_le32(~LAST_CTX_MASK);
+		slot_ctx->dev_info |= cpu_to_le32(LAST_CTX(1));
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ep0_ctx = xhci_get_ep_ctx(xhci, virt_dev->in_ctx, 0);
 	ep_ring = virt_dev->eps[0].ring;
 	/*
@@ -1372,6 +1437,61 @@ static u32 xhci_get_max_esit_payload(struct xhci_hcd *xhci,
 	return max_packet * (max_burst + 1);
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+static void xhci_apply_device_quirk(struct xhci_hcd * xhci,
+	struct usb_device * udev, struct usb_host_endpoint *ep)
+{
+#define XHCI_QUIRK_ONE_BURST_SIZE	(1 << 0)
+#define XHCI_QUIRK_BULK_OUT_ENDPOINT_DELAY	(1 << 1)
+#define XHCI_QUIRK_MANUAL_HALT_CLEANUP	(1 << 2)
+#define XHCI_QUIRK_DONOT_DATA_TOGGLE_CLEANUP (1 << 3)
+
+	static const struct usb_device_id quirk_device_ids[] = {
+		{ USB_DEVICE(0x1b80, 0xd3a4), .driver_info = XHCI_QUIRK_MANUAL_HALT_CLEANUP },
+		{ USB_DEVICE(0x07ca, 0x850a), .driver_info = XHCI_QUIRK_BULK_OUT_ENDPOINT_DELAY },
+		{ USB_DEVICE(0x15a4, 0x9016), .driver_info = XHCI_QUIRK_BULK_OUT_ENDPOINT_DELAY },
+		{ USB_DEVICE(0x1759, 0x5002), .driver_info = XHCI_QUIRK_ONE_BURST_SIZE },
+		{ USB_DEVICE(0x1759, 0x5000), .driver_info = XHCI_QUIRK_ONE_BURST_SIZE },
+		{ USB_DEVICE(0x0471, 0x0151), .driver_info = XHCI_QUIRK_DONOT_DATA_TOGGLE_CLEANUP },
+	};
+	int i;
+
+	if (!(udev->parent && !udev->parent->parent))
+		return;
+
+	for (i = 0; i < ARRAY_SIZE(quirk_device_ids); i++) {
+		const struct usb_device_id *id = &quirk_device_ids[i];
+
+		if ((id->idVendor == le16_to_cpu(udev->descriptor.idVendor)) &&
+			(id->idProduct == le16_to_cpu(udev->descriptor.idProduct))) {
+			struct xhci_virt_device *virt_dev = xhci->devs[udev->slot_id];
+
+			if (id->driver_info & XHCI_QUIRK_ONE_BURST_SIZE) {
+				if (udev->speed == USB_SPEED_SUPER && usb_endpoint_is_bulk_in(&ep->desc)) {
+					unsigned int ep_index = xhci_get_endpoint_index(&ep->desc);
+					struct xhci_ep_ctx *ep_ctx = xhci_get_ep_ctx(xhci, virt_dev->in_ctx, ep_index);
+					ep_ctx->ep_info2 &= cpu_to_le32(~MAX_BURST_MASK);
+					ep_ctx->ep_info2 |= cpu_to_le32(MAX_BURST(1));
+				}
+			}
+
+			if (id->driver_info & XHCI_QUIRK_BULK_OUT_ENDPOINT_DELAY) {
+				virt_dev->bulk_out_udelay = 100;
+			}
+
+			if (id->driver_info & XHCI_QUIRK_MANUAL_HALT_CLEANUP) {
+				virt_dev->manual_halt_cleanup = 1;
+			}
+
+			if (id->driver_info & XHCI_QUIRK_DONOT_DATA_TOGGLE_CLEANUP) {
+				virt_dev->donot_data_toggle_cleanup = 1;
+			}
+
+			break;
+		}
+	}
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
 /* Set up an endpoint with one ring segment.  Do not allocate stream rings.
  * Drivers will have to call usb_alloc_streams() to do that.
  */
@@ -1483,6 +1603,11 @@ int xhci_endpoint_init(struct xhci_hcd *xhci,
 			 cpu_to_le32(AVG_TRB_LENGTH_FOR_EP(max_esit_payload));
 
 	/* FIXME Debug endpoint context */
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		xhci_apply_device_quirk(xhci, udev, ep);
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	return 0;
 }
 
diff --git a/drivers/usb/host/xhci-pci.c b/drivers/usb/host/xhci-pci.c
index 159e3c6d..4e60792 100644
--- a/drivers/usb/host/xhci-pci.c
+++ b/drivers/usb/host/xhci-pci.c
@@ -33,6 +33,10 @@
 
 #define PCI_VENDOR_ID_ETRON		0x1b6f
 #define PCI_DEVICE_ID_ASROCK_P67	0x7023
+#ifdef CONFIG_USB_ETRON_HCD
+#define PCI_DEVICE_ID_ETRON_EJ168	0x7023
+#define PCI_DEVICE_ID_ETRON_EJ188	0x7052
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 static const char hcd_name[] = "xhci_hcd";
 
@@ -107,12 +111,41 @@ static void xhci_pci_quirks(struct device *dev, struct xhci_hcd *xhci)
 		xhci->quirks |= XHCI_SPURIOUS_REBOOT;
 		xhci->quirks |= XHCI_AVOID_BEI;
 	}
+#ifndef CONFIG_USB_ETRON_HCD
 	if (pdev->vendor == PCI_VENDOR_ID_ETRON &&
 			pdev->device == PCI_DEVICE_ID_ASROCK_P67) {
 		xhci->quirks |= XHCI_RESET_ON_RESUME;
 		xhci_dbg(xhci, "QUIRK: Resetting on resume\n");
 		xhci->quirks |= XHCI_TRUST_TX_LENGTH;
 	}
+#else /*CONFIG_USB_ETRON_HCD*/
+	if (pdev->vendor == PCI_VENDOR_ID_ETRON) {
+		struct usb_hcd *hcd = xhci_to_hcd(xhci);
+		pci_read_config_dword(pdev, 0x58, &xhci->hcc_params1);
+		xhci->hcc_params1 &= 0xffff;
+		xhci_init_ejxxx(xhci);
+
+		if (pdev->device == PCI_DEVICE_ID_ETRON_EJ168) {
+			hcd->chip_id = HCD_CHIP_ID_ETRON_EJ168;
+			if ((xhci->hcc_params1 & 0xff) == 0x30) {
+				charger_flags &=
+					~(XHCI_FLAG_HW_APPLE_CHARGE | XHCI_FLAG_HW_BATTERY_CHARGE);
+			}
+		} else if (pdev->device == PCI_DEVICE_ID_ETRON_EJ188) {
+			hcd->chip_id = HCD_CHIP_ID_ETRON_EJ188;
+		}
+
+		if (charger_flags & XHCI_FLAG_SW_APPLE_CHARGE)
+			hcd->chip_quirks |= HCD_BATTERY_CHARGE_QUIRK;
+
+		xhci_dbg(xhci, "Etron chip ID %02x\n", hcd->chip_id);
+		xhci->quirks |= XHCI_SPURIOUS_SUCCESS;
+		xhci->quirks |= XHCI_HUB_INFO_QUIRK;
+		xhci->quirks |= XHCI_RESET_ON_RESUME;
+		xhci->quirks |= XHCI_ETRON_HOST;
+		xhci_dbg(xhci, "QUIRK: Resetting on resume\n");
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	if (pdev->vendor == PCI_VENDOR_ID_VIA)
 		xhci->quirks |= XHCI_RESET_ON_RESUME;
 }
@@ -138,7 +171,14 @@ static int xhci_pci_setup(struct usb_hcd *hcd)
 	/* Find any debug ports */
 	retval = xhci_pci_reinit(xhci, pdev);
 	if (!retval)
+#ifdef CONFIG_USB_ETRON_HCD
+	{
+		xhci_set_hardware_charger(hcd, 1);
+		return retval;
+	}
+#else /*CONFIG_USB_ETRON_HCD*/
 		return retval;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	kfree(xhci);
 	return retval;
@@ -156,6 +196,10 @@ static int xhci_pci_probe(struct pci_dev *dev, const struct pci_device_id *id)
 	struct usb_hcd *hcd;
 
 	driver = (struct hc_driver *)id->driver_data;
+
+	/* Prevent runtime suspending between USB-2 and USB-3 initialization */
+	pm_runtime_get_noresume(&dev->dev);
+
 	/* Register the USB 2.0 roothub.
 	 * FIXME: USB core must know to register the USB 2.0 roothub first.
 	 * This is sort of silly, because we could just set the HCD driver flags
@@ -165,7 +209,7 @@ static int xhci_pci_probe(struct pci_dev *dev, const struct pci_device_id *id)
 	retval = usb_hcd_pci_probe(dev, id);
 
 	if (retval)
-		return retval;
+		goto put_runtime_pm;
 
 	/* USB 2.0 roothub is stored in the PCI device now. */
 	hcd = dev_get_drvdata(&dev->dev);
@@ -194,12 +238,17 @@ static int xhci_pci_probe(struct pci_dev *dev, const struct pci_device_id *id)
 	if (xhci->quirks & XHCI_LPM_SUPPORT)
 		hcd_to_bus(xhci->shared_hcd)->root_hub->lpm_capable = 1;
 
+	/* USB-2 and USB-3 roothubs initialized, allow runtime pm suspend */
+	pm_runtime_put_noidle(&dev->dev);
+
 	return 0;
 
 put_usb3_hcd:
 	usb_put_hcd(xhci->shared_hcd);
 dealloc_usb2_hcd:
 	usb_hcd_pci_remove(dev);
+put_runtime_pm:
+	pm_runtime_put_noidle(&dev->dev);
 	return retval;
 }
 
@@ -221,6 +270,9 @@ static int xhci_pci_suspend(struct usb_hcd *hcd, bool do_wakeup)
 {
 	struct xhci_hcd	*xhci = hcd_to_xhci(hcd);
 	struct pci_dev		*pdev = to_pci_dev(hcd->self.controller);
+#ifdef CONFIG_USB_ETRON_HCD
+	int			retval = 0;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	/*
 	 * Systems with the TI redriver that loses port status change events
@@ -229,7 +281,14 @@ static int xhci_pci_suspend(struct usb_hcd *hcd, bool do_wakeup)
 	if (xhci_compliance_mode_recovery_timer_quirk_check())
 		pdev->no_d3cold = true;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	retval = xhci_suspend(xhci);
+	if (!retval)
+		xhci_set_hardware_charger(hcd, 2);
+	return retval;
+#else /*CONFIG_USB_ETRON_HCD*/
 	return xhci_suspend(xhci);
+#endif /*CONFIG_USB_ETRON_HCD*/
 }
 
 static int xhci_pci_resume(struct usb_hcd *hcd, bool hibernated)
@@ -258,6 +317,10 @@ static int xhci_pci_resume(struct usb_hcd *hcd, bool hibernated)
 		usb_enable_xhci_ports(pdev);
 
 	retval = xhci_resume(xhci, hibernated);
+#ifdef CONFIG_USB_ETRON_HCD
+	if (!retval)
+		xhci_set_hardware_charger(hcd, 3);
+#endif /*CONFIG_USB_ETRON_HCD*/
 	return retval;
 }
 #endif /* CONFIG_PM */
@@ -292,10 +355,15 @@ static const struct hc_driver xhci_pci_hc_driver = {
 	.urb_dequeue =		xhci_urb_dequeue,
 	.alloc_dev =		xhci_alloc_dev,
 	.free_dev =		xhci_free_dev,
+#ifndef __NOTDEF__ /*CONFIG_USB_ETRON_HCD*/
 	.alloc_streams =	xhci_alloc_streams,
 	.free_streams =		xhci_free_streams,
+#endif /*CONFIG_USB_ETRON_HCD*/
 	.add_endpoint =		xhci_add_endpoint,
 	.drop_endpoint =	xhci_drop_endpoint,
+#ifdef CONFIG_USB_ETRON_HCD
+	.stop_endpoint =	xhci_stop_endpoint,
+#endif /*CONFIG_USB_ETRON_HCD*/
 	.endpoint_reset =	xhci_endpoint_reset,
 	.check_bandwidth =	xhci_check_bandwidth,
 	.reset_bandwidth =	xhci_reset_bandwidth,
diff --git a/drivers/usb/host/xhci-ring.c b/drivers/usb/host/xhci-ring.c
index bcfb08e..00f0ed8 100644
--- a/drivers/usb/host/xhci-ring.c
+++ b/drivers/usb/host/xhci-ring.c
@@ -449,6 +449,11 @@ static void ring_doorbell_for_active_rings(struct xhci_hcd *xhci,
 		return;
 	}
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		return;
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	for (stream_id = 1; stream_id < ep->stream_info->num_streams;
 			stream_id++) {
 		struct xhci_stream_info *stream_info = ep->stream_info;
@@ -577,6 +582,12 @@ void xhci_find_new_dequeue_state(struct xhci_hcd *xhci,
 	/* Dig out the cycle state saved by the xHC during the stop ep cmd */
 	xhci_dbg(xhci, "Finding endpoint context\n");
 	ep_ctx = xhci_get_ep_ctx(xhci, dev->out_ctx, ep_index);
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci) && (dev->eps[ep_index].ep_state & EP_HAS_STREAMS))
+		state->new_cycle_state = 0x1 &
+			le64_to_cpu(dev->eps[ep_index].stream_info->stream_ctx_array[stream_id].stream_ring);
+	else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	state->new_cycle_state = 0x1 & le64_to_cpu(ep_ctx->deq);
 
 	state->new_deq_ptr = cur_td->last_trb;
@@ -594,6 +605,16 @@ void xhci_find_new_dequeue_state(struct xhci_hcd *xhci,
 	    (trb->field[3] & cpu_to_le32(LINK_TOGGLE)))
 		state->new_cycle_state ^= 0x1;
 	next_trb(xhci, ep_ring, &state->new_deq_seg, &state->new_deq_ptr);
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci))
+	if (last_trb(xhci, ep_ring, state->new_deq_seg, state->new_deq_ptr)) {
+		trb = &state->new_deq_ptr->generic;
+		if (TRB_TYPE_LINK_LE32(trb->field[3]) &&
+			(trb->field[3] & cpu_to_le32(LINK_TOGGLE)))
+			state->new_cycle_state ^= 0x1;
+		next_trb(xhci, ep_ring, &state->new_deq_seg, &state->new_deq_ptr);
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	/*
 	 * If there is only one segment in a ring, find_trb_seg()'s while loop
@@ -782,6 +803,16 @@ static void handle_stopped_endpoint(struct xhci_hcd *xhci,
 				slot_id);
 		return;
 	}
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		slot_id = TRB_TO_SLOT_ID(le32_to_cpu(trb->generic.field[3]));
+		virt_dev = xhci->devs[slot_id];
+		if (!list_empty(&virt_dev->cmd_list) &&
+			handle_cmd_in_cmd_wait_list(xhci, virt_dev, event)) {
+			return;
+		}
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	memset(&deq_state, 0, sizeof(deq_state));
 	slot_id = TRB_TO_SLOT_ID(le32_to_cpu(trb->generic.field[3]));
@@ -1071,6 +1102,9 @@ static void handle_set_deq_completion(struct xhci_hcd *xhci,
 	struct xhci_virt_device *dev;
 	struct xhci_ep_ctx *ep_ctx;
 	struct xhci_slot_ctx *slot_ctx;
+#ifdef CONFIG_USB_ETRON_HCD
+	u64 addr;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	slot_id = TRB_TO_SLOT_ID(le32_to_cpu(trb->generic.field[3]));
 	ep_index = TRB_TO_EP_INDEX(le32_to_cpu(trb->generic.field[3]));
@@ -1128,9 +1162,19 @@ static void handle_set_deq_completion(struct xhci_hcd *xhci,
 	} else {
 		xhci_dbg(xhci, "Successful Set TR Deq Ptr cmd, deq = @%08llx\n",
 			 le64_to_cpu(ep_ctx->deq));
+#ifdef CONFIG_USB_ETRON_HCD
+		if (!(dev->eps[ep_index].ep_state & EP_HAS_STREAMS))
+			addr = le64_to_cpu(ep_ctx->deq) & ~(EP_CTX_CYCLE_MASK);
+		else
+			addr = le64_to_cpu(dev->eps[ep_index].stream_info->stream_ctx_array[stream_id].stream_ring) &
+				~(STREAM_CTX_SCT_MASK | STREAM_CTX_CYCLE_MASK);
+		if (xhci_trb_virt_to_dma(dev->eps[ep_index].queued_deq_seg,
+					 dev->eps[ep_index].queued_deq_ptr) == addr) {
+#else /*CONFIG_USB_ETRON_HCD*/
 		if (xhci_trb_virt_to_dma(dev->eps[ep_index].queued_deq_seg,
 					 dev->eps[ep_index].queued_deq_ptr) ==
 		    (le64_to_cpu(ep_ctx->deq) & ~(EP_CTX_CYCLE_MASK))) {
+#endif /*CONFIG_USB_ETRON_HCD*/ /*match}*/
 			/* Update the ring's dequeue segment and dequeue pointer
 			 * to reflect the new position.
 			 */
@@ -1180,6 +1224,9 @@ static void handle_reset_ep_completion(struct xhci_hcd *xhci,
 	} else {
 		/* Clear our internal halted state and restart the ring(s) */
 		xhci->devs[slot_id]->eps[ep_index].ep_state &= ~EP_HALTED;
+#ifdef CONFIG_USB_ETRON_HCD
+		if (!XHCI_IS_ETRON(xhci))
+#endif /*CONFIG_USB_ETRON_HCD*/
 		ring_doorbell_for_active_rings(xhci, slot_id, ep_index);
 	}
 }
@@ -1536,6 +1583,67 @@ static void handle_vendor_event(struct xhci_hcd *xhci,
 		handle_cmd_completion(xhci, &event->event_cmd);
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+static bool xhci_is_mass_storage_device(struct xhci_hcd *xhci,
+		int slot_id)
+{
+	int i;
+	struct xhci_virt_device *virt_dev;
+	struct usb_device *udev;
+	struct usb_interface_cache *intfc;
+	struct usb_host_interface *alts;
+	bool status = false;
+
+	virt_dev = xhci->devs[slot_id];
+	if (!virt_dev || !virt_dev->udev)
+		goto err_done;
+
+	udev = virt_dev->udev;
+	if (!(udev->parent && !udev->parent->parent))
+		goto err_done;
+
+	if (!udev->config || !udev->config[0].intf_cache[0])
+		goto err_done;
+
+	intfc = udev->config[0].intf_cache[0];
+	for (i = 0; i < intfc->num_altsetting; i++) {
+		alts = &intfc->altsetting[i];
+		if (alts->desc.bInterfaceClass == USB_CLASS_MASS_STORAGE) {
+			status = true;
+			break;
+		}
+	}
+
+err_done:
+	return status;
+}
+
+static void xhci_giveback_error_urb(struct xhci_hcd *xhci,
+		int slot_id)
+{
+	struct xhci_virt_device *virt_dev;
+	int i;
+
+	virt_dev = xhci->devs[slot_id];
+	for (i = LAST_EP_INDEX; i > 0; i--) {
+		struct xhci_virt_ep *ep = &virt_dev->eps[i];
+		struct xhci_ring *ring = ep->ring;
+		if (!ring)
+			continue;
+
+		if (!list_empty(&ring->td_list)) {
+			struct xhci_td *cur_td = list_first_entry(&ring->td_list,
+				struct xhci_td,
+				td_list);
+			list_del_init(&cur_td->td_list);
+			if (!list_empty(&cur_td->cancelled_td_list))
+				list_del_init(&cur_td->cancelled_td_list);
+			xhci_giveback_urb_in_irq(xhci, cur_td, -EPROTO, "killed");
+		}
+	}
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 /* @port_id: the one-based port ID from the hardware (indexed from array of all
  * port registers -- USB 3.0 and USB 2.0).
  *
@@ -1600,6 +1708,9 @@ static void handle_port_status(struct xhci_hcd *xhci,
 	struct usb_hcd *hcd;
 	u32 port_id;
 	u32 temp, temp1;
+#ifdef CONFIG_USB_ETRON_HCD
+	u32 mask;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	int max_ports;
 	int slot_id;
 	unsigned int faked_port_index;
@@ -1670,6 +1781,9 @@ static void handle_port_status(struct xhci_hcd *xhci,
 		usb_hcd_resume_root_hub(hcd);
 	}
 
+	if (hcd->speed == HCD_USB3 && (temp & PORT_PLS_MASK) == XDEV_INACTIVE)
+		bus_state->port_remote_wakeup &= ~(1 << faked_port_index);
+
 	if ((temp & PORT_PLC) && (temp & PORT_PLS_MASK) == XDEV_RESUME) {
 		xhci_dbg(xhci, "port resume event for port %d\n", port_id);
 
@@ -1705,6 +1819,42 @@ static void handle_port_status(struct xhci_hcd *xhci,
 			/* Do the rest in GetPortStatus */
 		}
 	}
+#ifdef CONFIG_USB_ETRON_HCD
+	else if (XHCI_IS_ETRON(xhci) && (temp & PORT_PLC) && (temp & PORT_PLS_MASK) == XDEV_INACTIVE) {
+		slot_id = xhci_find_slot_id_by_port(hcd, xhci,
+			faked_port_index + 1);
+		if (xhci_is_mass_storage_device(xhci, slot_id)) {
+			bogus_port_status = true;
+			temp = xhci_port_state_to_neutral(temp);
+			temp |= (PORT_WR | PORT_PLC | PORT_CSC);
+			xhci_writel(xhci, temp, port_array[faked_port_index]);
+			goto cleanup;
+		}
+	}
+	if (XHCI_IS_ETRON(xhci) && (temp & PORT_WRC)) {
+		slot_id = xhci_find_slot_id_by_port(hcd, xhci,
+			faked_port_index + 1);
+		if (xhci_is_mass_storage_device(xhci, slot_id)) {
+			bogus_port_status = true;
+			temp1 = xhci_port_state_to_neutral(temp);
+			temp1 |= (PORT_WRC | PORT_RC | PORT_PLC | PORT_CSC);
+			xhci_writel(xhci, temp1, port_array[faked_port_index]);
+			mask = PORT_PE | PORT_CONNECT;
+			if ((temp & mask) == mask) {
+				bus_state->port_c_connection &= ~(1 << faked_port_index);
+				bus_state->resume_done[faked_port_index] = 0;
+				xhci_giveback_error_urb(xhci, slot_id);
+			} else {
+				bus_state->port_c_connection |= 1 << faked_port_index;
+				bus_state->resume_done[faked_port_index] = jiffies +
+					msecs_to_jiffies(5000);
+				mod_timer(&hcd->rh_timer,
+					bus_state->resume_done[faked_port_index]);
+			}
+			goto cleanup;
+		}
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	if ((temp & PORT_PLC) && (temp & PORT_PLS_MASK) == XDEV_U0 &&
 			DEV_SUPERSPEED(temp)) {
@@ -1926,9 +2076,19 @@ static int finish_td(struct xhci_hcd *xhci, struct xhci_td *td,
 			 * the halt condition must be cleared first.  Let the
 			 * USB class driver clear the stall later.
 			 */
+#ifdef CONFIG_USB_ETRON_HCD
+			if (!xdev->manual_halt_cleanup) {
+#endif /*CONFIG_USB_ETRON_HCD*/
 			ep->stopped_td = td;
 			ep->stopped_trb = event_trb;
 			ep->stopped_stream = ep_ring->stream_id;
+#ifdef CONFIG_USB_ETRON_HCD
+			} else {
+				xhci_cleanup_halted_endpoint(xhci,
+						slot_id, ep_index, ep_ring->stream_id,
+						td, event_trb);
+			}
+#endif /*CONFIG_USB_ETRON_HCD*/
 		} else if (xhci_requires_manual_halt_cleanup(xhci,
 					ep_ctx, trb_comp_code)) {
 			/* Other types of errors halt the endpoint, but the
@@ -2065,7 +2225,7 @@ static int process_ctrl_td(struct xhci_hcd *xhci, struct xhci_td *td,
 	if (event_trb != ep_ring->dequeue) {
 		/* The event was for the status stage */
 		if (event_trb == td->last_trb) {
-			if (td->urb->actual_length != 0) {
+			if (td->urb_length_set) {
 				/* Don't overwrite a previously set error code
 				 */
 				if ((*status == -EINPROGRESS || *status == 0) &&
@@ -2079,7 +2239,13 @@ static int process_ctrl_td(struct xhci_hcd *xhci, struct xhci_td *td,
 					td->urb->transfer_buffer_length;
 			}
 		} else {
-		/* Maybe the event was for the data stage? */
+			/*
+			 * Maybe the event was for the data stage? If so, update
+			 * already the actual_length of the URB and flag it as
+			 * set, so that it is not overwritten in the event for
+			 * the last TRB.
+			 */
+			td->urb_length_set = true;
 			td->urb->actual_length =
 				td->urb->transfer_buffer_length -
 				EVENT_TRB_LEN(le32_to_cpu(event->transfer_len));
@@ -2468,6 +2634,16 @@ static int handle_tx_event(struct xhci_hcd *xhci,
 		ep->skip = true;
 		xhci_dbg(xhci, "Miss service interval error, set skip flag\n");
 		goto cleanup;
+#ifdef CONFIG_USB_ETRON_HCD
+	case COMP_STREAM_ERR:
+		xhci_warn(xhci, "WARN: Invalid Stream Type error on endpoint\n");
+		status = -EPROTO;
+		goto cleanup;
+	case COMP_STRID_ERR:
+		xhci_warn(xhci, "WARN: Invalid Stream ID error on endpoint\n");
+		status = -EPROTO;
+		goto cleanup;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	default:
 		if (xhci_is_vendor_info_code(xhci, trb_comp_code)) {
 			status = 0;
@@ -2707,7 +2883,22 @@ static int xhci_handle_event(struct xhci_hcd *xhci)
 		    TRB_TYPE(48))
 			handle_vendor_event(xhci, event);
 		else
+#ifdef CONFIG_USB_ETRON_HCD
+		{
+#endif /*CONFIG_USB_ETRON_HCD*/
 			xhci->error_bitmask |= 1 << 3;
+#ifdef CONFIG_USB_ETRON_HCD
+			xhci_err(xhci, "Unknown event TRB:\n");
+			xhci_err(xhci, "@%016llx %08x %08x %08x %08x\n",
+				(unsigned long long) xhci_trb_virt_to_dma(xhci->event_ring->deq_seg, event),
+				le32_to_cpu(event->generic.field[0]),
+				le32_to_cpu(event->generic.field[1]),
+				le32_to_cpu(event->generic.field[2]),
+				le32_to_cpu(event->generic.field[3]));
+			xhci_dbg(xhci, "Event ring:\n");
+			xhci_debug_segment(xhci, xhci->event_ring->deq_seg);
+		}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	}
 	/* Any of the above functions may drop and re-acquire the lock, so check
 	 * to make sure a watchdog timer didn't mark the host as non-responsive.
@@ -3036,6 +3227,26 @@ static void check_trb_math(struct urb *urb, int num_trbs, int running_total)
 				urb->transfer_buffer_length);
 }
 
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/	// [TBD]
+static void requeue_first_trb(struct xhci_hcd *xhci, int slot_id,
+		unsigned int ep_index, unsigned int stream_id,
+		struct xhci_generic_trb *start_trb,
+		struct xhci_generic_trb *temp_trb)
+{
+	/*
+	 * Pass all the TRBs to the hardware at once and make sure this write
+	 * isn't reordered.
+	 */
+	wmb();
+	start_trb->field[0] = temp_trb->field[0];
+	start_trb->field[1] = temp_trb->field[1];
+	start_trb->field[2] = temp_trb->field[2];
+	start_trb->field[3] = temp_trb->field[3];
+
+	xhci_ring_ep_doorbell(xhci, slot_id, ep_index, stream_id);
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 static void giveback_first_trb(struct xhci_hcd *xhci, int slot_id,
 		unsigned int ep_index, unsigned int stream_id, int start_cycle,
 		struct xhci_generic_trb *start_trb)
@@ -3160,6 +3371,9 @@ static int queue_bulk_sg_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 	bool more_trbs_coming;
 
 	struct xhci_generic_trb *start_trb;
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/ // [TBD]
+	struct xhci_generic_trb temp_trb;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	int start_cycle;
 
 	ep_ring = xhci_urb_to_transfer_ring(xhci, urb);
@@ -3262,6 +3476,16 @@ static int queue_bulk_sg_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 			more_trbs_coming = true;
 		else
 			more_trbs_coming = false;
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/ // [TBD]
+		if (XHCI_IS_ETRON(xhci) && first_trb) {
+			first_trb = false;
+			temp_trb.field[0] = cpu_to_le32(lower_32_bits(addr));
+			temp_trb.field[1] = cpu_to_le32(upper_32_bits(addr));
+			temp_trb.field[2] = cpu_to_le32(length_field);
+			temp_trb.field[3] = cpu_to_le32(field | TRB_TYPE(TRB_NORMAL));
+			inc_enq(xhci, ep_ring, more_trbs_coming);
+		} else
+#endif /*CONFIG_USB_ETRON_HCD*/
 		queue_trb(xhci, ep_ring, more_trbs_coming,
 				lower_32_bits(addr),
 				upper_32_bits(addr),
@@ -3294,6 +3518,12 @@ static int queue_bulk_sg_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 	} while (running_total < urb->transfer_buffer_length);
 
 	check_trb_math(urb, num_trbs, running_total);
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/ // [TBD]
+	if (XHCI_IS_ETRON(xhci)) {
+		requeue_first_trb(xhci, slot_id, ep_index, urb->stream_id,
+			start_trb, &temp_trb);
+	} else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	giveback_first_trb(xhci, slot_id, ep_index, urb->stream_id,
 			start_cycle, start_trb);
 	return 0;
@@ -3311,6 +3541,9 @@ int xhci_queue_bulk_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 	bool first_trb;
 	bool more_trbs_coming;
 	int start_cycle;
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/ // [TBD]
+	struct xhci_generic_trb temp_trb;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	u32 field, length_field;
 
 	int running_total, trb_buff_len, ret;
@@ -3417,6 +3650,16 @@ int xhci_queue_bulk_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 			more_trbs_coming = true;
 		else
 			more_trbs_coming = false;
+#if 0 /*#ifdef CONFIG_USB_ETRON_HCD*/ // [TBD]
+		if (XHCI_IS_ETRON(xhci) && first_trb) {
+			first_trb = false;
+			temp_trb.field[0] = cpu_to_le32(lower_32_bits(addr));
+			temp_trb.field[1] = cpu_to_le32(upper_32_bits(addr));
+			temp_trb.field[2] = cpu_to_le32(length_field);
+			temp_trb.field[3] = cpu_to_le32(field | TRB_TYPE(TRB_NORMAL));
+			inc_enq(xhci, ep_ring, more_trbs_coming);
+		} else {
+#endif /*CONFIG_USB_ETRON_HCD*/
 		queue_trb(xhci, ep_ring, more_trbs_coming,
 				lower_32_bits(addr),
 				upper_32_bits(addr),
@@ -3433,6 +3676,12 @@ int xhci_queue_bulk_tx(struct xhci_hcd *xhci, gfp_t mem_flags,
 	} while (running_total < urb->transfer_buffer_length);
 
 	check_trb_math(urb, num_trbs, running_total);
+#if 0 /*#ifndef CONFIG_USB_ETRON_HCD*/ // [TBD]
+	if (XHCI_IS_ETRON(xhci)) {
+		requeue_first_trb(xhci, slot_id, ep_index, urb->stream_id,
+			start_trb, &temp_trb);
+	} else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	giveback_first_trb(xhci, slot_id, ep_index, urb->stream_id,
 			start_cycle, start_trb);
 	return 0;
@@ -3590,7 +3839,7 @@ static unsigned int xhci_get_burst_count(struct xhci_hcd *xhci,
 		return 0;
 
 	max_burst = urb->ep->ss_ep_comp.bMaxBurst;
-	return roundup(total_packet_count, max_burst + 1) - 1;
+	return DIV_ROUND_UP(total_packet_count, max_burst + 1) - 1;
 }
 
 /*
@@ -4012,6 +4261,10 @@ static int queue_set_tr_deq(struct xhci_hcd *xhci, int slot_id,
 		xhci_warn(xhci, "A Set TR Deq Ptr command is pending.\n");
 		return 0;
 	}
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci) && (ep->ep_state & EP_HAS_STREAMS))
+		addr |= SCT_FOR_CTX(SCT_PRI_TR);
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ep->queued_deq_seg = deq_seg;
 	ep->queued_deq_ptr = deq_ptr;
 	return queue_command(xhci, lower_32_bits(addr) | cycle_state,
diff --git a/drivers/usb/host/xhci.c b/drivers/usb/host/xhci.c
index 4a5251f..3c9af16 100644
--- a/drivers/usb/host/xhci.c
+++ b/drivers/usb/host/xhci.c
@@ -37,6 +37,11 @@
 static int link_quirk;
 module_param(link_quirk, int, S_IRUGO | S_IWUSR);
 MODULE_PARM_DESC(link_quirk, "Don't clear the chain bit on a link TRB");
+#ifdef CONFIG_USB_ETRON_HCD
+unsigned long charger_flags = 0;
+module_param_named(charger_flags, charger_flags, ulong, S_IRUGO);
+MODULE_PARM_DESC(charger_flags, "Bits for enabling Apple/Battery Charger (default=0)");
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 /* TODO: copied from ehci-hcd.c - can this be refactored? */
 /*
@@ -167,6 +172,12 @@ int xhci_reset(struct xhci_hcd *xhci)
 	command |= CMD_RESET;
 	xhci_writel(xhci, command, &xhci->op_regs->command);
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+	ret = xhci_handshake(xhci, &xhci->op_regs->command,
+			CMD_RESET, 0, 250 * 1000);
+	} else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ret = xhci_handshake(xhci, &xhci->op_regs->command,
 			CMD_RESET, 0, 10 * 1000 * 1000);
 	if (ret)
@@ -177,6 +188,12 @@ int xhci_reset(struct xhci_hcd *xhci)
 	 * xHCI cannot write to any doorbells or operational registers other
 	 * than status until the "Controller Not Ready" flag is cleared.
 	 */
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+	ret = xhci_handshake(xhci, &xhci->op_regs->status,
+			STS_CNR, 0, 250 * 1000);
+	} else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ret = xhci_handshake(xhci, &xhci->op_regs->status,
 			STS_CNR, 0, 10 * 1000 * 1000);
 
@@ -184,6 +201,9 @@ int xhci_reset(struct xhci_hcd *xhci)
 		xhci->bus_state[i].port_c_suspend = 0;
 		xhci->bus_state[i].suspended_ports = 0;
 		xhci->bus_state[i].resuming_ports = 0;
+#ifdef CONFIG_USB_ETRON_HCD
+		xhci->bus_state[i].port_c_connection = 0;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	}
 
 	return ret;
@@ -661,6 +681,11 @@ int xhci_run(struct usb_hcd *hcd)
 	xhci_dbg(xhci, "// Set the interrupt modulation register\n");
 	temp = xhci_readl(xhci, &xhci->ir_set->irq_control);
 	temp &= ~ER_IRQ_INTERVAL_MASK;
+#ifndef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci))
+		temp |= (u32) 0;
+	else
+#endif /*CONFIG_USB_ETRON_HCD*/
 	temp |= (u32) 160;
 	xhci_writel(xhci, temp, &xhci->ir_set->irq_control);
 
@@ -1362,6 +1387,10 @@ int xhci_urb_enqueue(struct usb_hcd *hcd, struct urb *urb, gfp_t mem_flags)
 		if (ret)
 			goto free_priv;
 		spin_unlock_irqrestore(&xhci->lock, flags);
+#ifdef CONFIG_USB_ETRON_HCD
+		if (xhci->devs[slot_id]->bulk_out_udelay && usb_endpoint_dir_out(&urb->ep->desc))
+			udelay(xhci->devs[slot_id]->bulk_out_udelay);
+#endif /*CONFIG_USB_ETRON_HCD*/
 	} else if (usb_endpoint_xfer_int(&urb->ep->desc)) {
 		spin_lock_irqsave(&xhci->lock, flags);
 		if (xhci->xhc_state & XHCI_STATE_DYING)
@@ -1583,6 +1612,9 @@ int xhci_drop_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
 	u32 drop_flag;
 	u32 new_add_flags, new_drop_flags, new_slot_info;
 	int ret;
+#ifdef CONFIG_USB_ETRON_HCD
+	u32 cur_add_flags = 0;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	ret = xhci_check_args(hcd, udev, ep, 1, true, __func__);
 	if (ret <= 0)
@@ -1622,7 +1654,22 @@ int xhci_drop_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
 	ctrl_ctx->add_flags &= cpu_to_le32(~drop_flag);
 	new_add_flags = le32_to_cpu(ctrl_ctx->add_flags);
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		int i;
+		cur_add_flags = 2;
+		for (i = 1; i < 31; i++) {
+			ep_ctx = xhci_get_ep_ctx(xhci, out_ctx, i);
+			if ((ep_ctx->ep_info & cpu_to_le32(EP_STATE_MASK)) != cpu_to_le32(EP_STATE_DISABLED) &&
+				!(le32_to_cpu(ctrl_ctx->add_flags) & xhci_get_endpoint_flag_from_index(i)) &&
+				!(le32_to_cpu(ctrl_ctx->drop_flags) & xhci_get_endpoint_flag_from_index(i)))
+				cur_add_flags |= xhci_get_endpoint_flag_from_index(i);
+		}
+	}
+	last_ctx = xhci_last_valid_endpoint(le32_to_cpu(ctrl_ctx->add_flags) | cur_add_flags);
+#else /*CONFIG_USB_ETRON_HCD*/
 	last_ctx = xhci_last_valid_endpoint(le32_to_cpu(ctrl_ctx->add_flags));
+#endif /*CONFIG_USB_ETRON_HCD*/
 	slot_ctx = xhci_get_slot_ctx(xhci, in_ctx);
 	/* Update the last valid endpoint context, if we deleted the last one */
 	if ((le32_to_cpu(slot_ctx->dev_info) & LAST_CTX_MASK) >
@@ -1669,6 +1716,10 @@ int xhci_add_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
 	u32 new_add_flags, new_drop_flags, new_slot_info;
 	struct xhci_virt_device *virt_dev;
 	int ret = 0;
+#ifdef CONFIG_USB_ETRON_HCD
+	struct xhci_ep_ctx *ep_ctx;
+	u32 cur_add_flags = 0;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	ret = xhci_check_args(hcd, udev, ep, 1, true, __func__);
 	if (ret <= 0) {
@@ -1742,6 +1793,20 @@ int xhci_add_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
 	 */
 	new_drop_flags = le32_to_cpu(ctrl_ctx->drop_flags);
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+		int i;
+		cur_add_flags = 2;
+		for (i = 1; i < 31; i++) {
+			ep_ctx = xhci_get_ep_ctx(xhci, out_ctx, i);
+			if ((ep_ctx->ep_info & cpu_to_le32(EP_STATE_MASK)) != cpu_to_le32(EP_STATE_DISABLED) &&
+				!(le32_to_cpu(ctrl_ctx->add_flags) & xhci_get_endpoint_flag_from_index(i)) &&
+				!(le32_to_cpu(ctrl_ctx->drop_flags) & xhci_get_endpoint_flag_from_index(i)))
+				cur_add_flags |= xhci_get_endpoint_flag_from_index(i);
+		}
+		last_ctx = xhci_last_valid_endpoint(le32_to_cpu(ctrl_ctx->add_flags) | cur_add_flags);
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	slot_ctx = xhci_get_slot_ctx(xhci, in_ctx);
 	/* Update the last valid endpoint context, if we just added one past */
 	if ((le32_to_cpu(slot_ctx->dev_info) & LAST_CTX_MASK) <
@@ -1763,6 +1828,68 @@ int xhci_add_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
 	return 0;
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+void xhci_stop_endpoint(struct usb_hcd *hcd, struct usb_device *udev,
+		struct usb_host_endpoint *ep)
+{
+	struct xhci_hcd *xhci;
+	struct xhci_virt_device *virt_dev;
+	struct xhci_ep_ctx *ep_ctx;
+	struct xhci_command *cmd;
+	unsigned int ep_index;
+	unsigned long flags;
+	int ret, timeleft;
+
+	xhci = hcd_to_xhci(hcd);
+	if (!XHCI_IS_ETRON(xhci)) return;
+
+	ret = xhci_check_args(hcd, udev, ep, 1, true, __func__);
+	if (ret < 0)
+		return;
+
+	virt_dev = xhci->devs[udev->slot_id];
+	ep_index = xhci_get_endpoint_index(&ep->desc);
+	ep_ctx = xhci_get_ep_ctx(xhci, virt_dev->out_ctx, ep_index);
+	if ((ep_ctx->ep_info & cpu_to_le32(EP_STATE_MASK)) != cpu_to_le32(EP_STATE_RUNNING)) {
+		xhci_dbg(xhci, "xHCI %s called with non-running ep %p\n",
+				__func__, ep);
+		return;
+	}
+
+	cmd = xhci_alloc_command(xhci, false, true, GFP_NOIO);
+	if (!cmd) {
+		xhci_dbg(xhci, "Couldn't allocate command structure.\n");
+		return;
+	}
+
+	spin_lock_irqsave(&xhci->lock, flags);
+	cmd->command_trb = xhci_find_next_enqueue(xhci->cmd_ring);
+	list_add_tail(&cmd->cmd_list, &virt_dev->cmd_list);
+	xhci_queue_stop_endpoint(xhci, udev->slot_id, ep_index, 0);
+	xhci_ring_cmd_db(xhci);
+	spin_unlock_irqrestore(&xhci->lock, flags);
+
+	/* Wait for last stop endpoint command to finish */
+	timeleft = wait_for_completion_interruptible_timeout(
+			cmd->completion,
+			USB_CTRL_SET_TIMEOUT);
+	if (timeleft <= 0) {
+		xhci_warn(xhci, "%s while waiting for stop endpoint command\n",
+				timeleft == 0 ? "Timeout" : "Signal");
+		spin_lock_irqsave(&xhci->lock, flags);
+		/* The timeout might have raced with the event ring handler, so
+		 * only delete from the list if the item isn't poisoned.
+		 */
+		if (cmd->cmd_list.next != LIST_POISON1) {
+			list_del(&cmd->cmd_list);
+		}
+		spin_unlock_irqrestore(&xhci->lock, flags);
+	}
+
+	xhci_free_command(xhci, cmd);
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 static void xhci_zero_in_ctx(struct xhci_hcd *xhci, struct xhci_virt_device *virt_dev)
 {
 	struct xhci_input_control_ctx *ctrl_ctx;
@@ -1778,10 +1905,16 @@ static void xhci_zero_in_ctx(struct xhci_hcd *xhci, struct xhci_virt_device *vir
 	ctrl_ctx = xhci_get_input_control_ctx(xhci, virt_dev->in_ctx);
 	ctrl_ctx->drop_flags = 0;
 	ctrl_ctx->add_flags = 0;
+#ifdef CONFIG_USB_ETRON_HCD
+	if (!XHCI_IS_ETRON(xhci)) {
+#endif /*CONFIG_USB_ETRON_HCD*/
 	slot_ctx = xhci_get_slot_ctx(xhci, virt_dev->in_ctx);
 	slot_ctx->dev_info &= cpu_to_le32(~LAST_CTX_MASK);
 	/* Endpoint 0 is always valid */
 	slot_ctx->dev_info |= cpu_to_le32(LAST_CTX(1));
+#ifdef CONFIG_USB_ETRON_HCD
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	for (i = 1; i < 31; ++i) {
 		ep_ctx = xhci_get_ep_ctx(xhci, virt_dev->in_ctx, i);
 		ep_ctx->ep_info = 0;
@@ -2620,7 +2753,7 @@ static int xhci_configure_endpoint(struct xhci_hcd *xhci,
 	spin_unlock_irqrestore(&xhci->lock, flags);
 
 	/* Wait for the configure endpoint command to complete */
-	timeleft = wait_for_completion_interruptible_timeout(
+	timeleft = wait_for_completion_timeout(
 			cmd_completion,
 			XHCI_CMD_DEFAULT_TIMEOUT);
 	if (timeleft <= 0) {
@@ -2655,6 +2788,86 @@ static int xhci_configure_endpoint(struct xhci_hcd *xhci,
 	return ret;
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+static void xhci_get_hub_device_info(struct xhci_hcd *xhci,
+		struct usb_device *udev)
+{
+	int i, ret, size;
+	struct xhci_virt_device	*virt_dev;
+	struct xhci_slot_ctx *slot_ctx;
+	struct usb_hub_descriptor *descriptor = NULL;
+	u16 wHubCharacteristics;
+	unsigned dtype;
+
+	if (!(xhci->quirks & XHCI_HUB_INFO_QUIRK))
+		return;
+
+	if (udev->descriptor.bDeviceClass != USB_CLASS_HUB)
+		return;
+
+	virt_dev = xhci->devs[udev->slot_id];
+	slot_ctx = xhci_get_slot_ctx(xhci, virt_dev->in_ctx);
+	if (slot_ctx->dev_info & cpu_to_le32(DEV_HUB))
+		return;
+
+	descriptor = kmalloc(sizeof(*descriptor), GFP_KERNEL);
+	if (!descriptor)
+		goto fail;
+
+	if (udev->descriptor.bDeviceProtocol == 3) {
+		dtype = USB_DT_SS_HUB;
+		size = USB_DT_SS_HUB_SIZE;
+	} else {
+		dtype = USB_DT_HUB;
+		size = sizeof(struct usb_hub_descriptor);
+	}
+
+	for (i = 0; i < 3; i++) {
+		ret = usb_control_msg(udev, usb_rcvctrlpipe(udev, 0),
+			USB_REQ_GET_DESCRIPTOR, USB_DIR_IN | USB_RT_HUB,
+			dtype << 8, 0, descriptor, size,
+			USB_CTRL_GET_TIMEOUT);
+		if (ret >= (USB_DT_HUB_NONVAR_SIZE + 2))
+			break;
+	}
+
+	if (ret < 0)
+		goto fail;
+	if (descriptor->bNbrPorts > USB_MAXCHILDREN)
+		goto fail;
+
+	slot_ctx->dev_info |= cpu_to_le32(DEV_HUB);
+	if (udev->descriptor.bDeviceProtocol == 2)
+		slot_ctx->dev_info |= cpu_to_le32(DEV_MTT);
+
+	if (xhci->hci_version > 0x95) {
+		slot_ctx->dev_info2 |= cpu_to_le32(XHCI_MAX_PORTS(descriptor->bNbrPorts));
+		if (xhci->hci_version < 0x100 || udev->descriptor.bDeviceProtocol != 3) {
+			wHubCharacteristics = le16_to_cpu(descriptor->wHubCharacteristics);
+			switch (wHubCharacteristics & HUB_CHAR_TTTT) {
+				case HUB_TTTT_8_BITS:
+					if (udev->descriptor.bDeviceProtocol != 0)
+						slot_ctx->tt_info |= cpu_to_le32(TT_THINK_TIME(0));
+					break;
+				case HUB_TTTT_16_BITS:
+					slot_ctx->tt_info |= cpu_to_le32(TT_THINK_TIME(1));
+					break;
+				case HUB_TTTT_24_BITS:
+					slot_ctx->tt_info |= cpu_to_le32(TT_THINK_TIME(2));
+					break;
+				case HUB_TTTT_32_BITS:
+					slot_ctx->tt_info |= cpu_to_le32(TT_THINK_TIME(3));
+					break;
+			}
+		}
+	}
+
+fail:
+	if (descriptor)
+		kfree(descriptor);
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 /* Called after one or more calls to xhci_add_endpoint() or
  * xhci_drop_endpoint().  If this call fails, the USB core is expected
  * to call xhci_reset_bandwidth().
@@ -2695,6 +2908,9 @@ int xhci_check_bandwidth(struct usb_hcd *hcd, struct usb_device *udev)
 			ctrl_ctx->drop_flags == 0)
 		return 0;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	xhci_get_hub_device_info(xhci, udev);
+#endif /*CONFIG_USB_ETRON_HCD*/
 	xhci_dbg(xhci, "New Input Control Context:\n");
 	slot_ctx = xhci_get_slot_ctx(xhci, virt_dev->in_ctx);
 	xhci_dbg_ctx(xhci, virt_dev->in_ctx,
@@ -2842,6 +3058,129 @@ void xhci_cleanup_stalled_ring(struct xhci_hcd *xhci,
 	}
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+static void xhci_prev_endpoint_reset(struct usb_hcd *hcd,
+		struct usb_host_endpoint *ep)
+{
+	struct xhci_hcd *xhci;
+	struct usb_device *udev;
+	unsigned int ep_index;
+	unsigned int last_ctx = 0;
+	struct xhci_ep_ctx *out_ep_ctx;
+	struct xhci_ep_ctx *tmp_ep_ctx;
+	struct xhci_ep_ctx *in_ep_ctx;
+	struct xhci_container_ctx *in_ctx, *out_ctx;
+	struct xhci_input_control_ctx *ctrl_ctx;
+	struct xhci_slot_ctx *out_slot_ctx, *in_slot_ctx;
+	u32 cur_add_flags, drop_flag, add_flag;
+	int i, ret = 0;
+	struct xhci_virt_device *virt_dev;
+
+	if (!ep->hcpriv)
+		return;
+
+	udev = (struct usb_device *) ep->hcpriv;
+	if (USB_SPEED_SUPER == udev->speed)
+		return;
+
+	xhci = hcd_to_xhci(hcd);
+	if (!XHCI_IS_ETRON(xhci))
+		return;
+	virt_dev = xhci->devs[udev->slot_id];
+	if (virt_dev->donot_data_toggle_cleanup)
+		return;
+
+	ep_index = xhci_get_endpoint_index(&ep->desc);
+	in_ctx = virt_dev->in_ctx;
+	out_ctx = virt_dev->out_ctx;
+
+	out_ep_ctx = xhci_get_ep_ctx(xhci, out_ctx, ep_index);
+	in_ep_ctx = xhci_get_ep_ctx(xhci, in_ctx, ep_index);
+
+	out_slot_ctx = xhci_get_slot_ctx(xhci, out_ctx);
+	in_slot_ctx = xhci_get_slot_ctx(xhci, in_ctx);
+
+	ctrl_ctx = xhci_get_input_control_ctx(xhci, in_ctx);
+
+	if ((EP_STATE_RUNNING == (le32_to_cpu(out_ep_ctx->ep_info) & EP_STATE_MASK)) &&
+			(SLOT_STATE_CONFIGURED == GET_SLOT_STATE(le32_to_cpu(out_slot_ctx->dev_state)))) {
+
+		drop_flag = xhci_get_endpoint_flag_from_index(ep_index);
+		add_flag = 0;
+
+		xhci_slot_copy(xhci, in_ctx, out_ctx);
+		xhci_endpoint_copy(xhci, in_ctx, out_ctx, ep_index);
+
+		ctrl_ctx->drop_flags |= cpu_to_le32(drop_flag);
+		ctrl_ctx->add_flags &= cpu_to_le32(add_flag);
+
+		cur_add_flags = 2;
+		for (i = 1; i < 31; i++) {
+			tmp_ep_ctx = xhci_get_ep_ctx(xhci, out_ctx, i);
+			if ((tmp_ep_ctx->ep_info & cpu_to_le32(EP_STATE_MASK)) != cpu_to_le32(EP_STATE_DISABLED) &&
+				!(le32_to_cpu(ctrl_ctx->add_flags) & xhci_get_endpoint_flag_from_index(i)) &&
+				!(le32_to_cpu(ctrl_ctx->drop_flags) & xhci_get_endpoint_flag_from_index(i)))
+				cur_add_flags |= xhci_get_endpoint_flag_from_index(i);
+		}
+
+		last_ctx = xhci_last_valid_endpoint(le32_to_cpu(ctrl_ctx->add_flags) | cur_add_flags);
+		/* Update the last valid endpoint context, if we deleted the last one */
+		in_slot_ctx->dev_info &= cpu_to_le32(~LAST_CTX_MASK);
+		in_slot_ctx->dev_info |= cpu_to_le32(LAST_CTX(last_ctx));
+
+		xhci_dbg(xhci, "drop ep 0x%x, slot id %d, drop flag = %#x, add flag = %#x, new in slot info = %#x\n",
+				(unsigned int) ep->desc.bEndpointAddress,
+				udev->slot_id,
+				(unsigned int) drop_flag,
+				(unsigned int) add_flag,
+				(unsigned int) in_slot_ctx->dev_info);
+
+		ret = xhci_configure_endpoint(xhci, udev, NULL,
+			false, false);
+		if (ret)
+			xhci_warn(xhci, "%s - ret %d\n", __func__,ret);
+
+		drop_flag = 0;
+		add_flag = xhci_get_endpoint_flag_from_index(ep_index);
+
+		ctrl_ctx->drop_flags &= cpu_to_le32(drop_flag);
+		ctrl_ctx->add_flags |= cpu_to_le32(add_flag);
+
+		cur_add_flags = 2;
+		for (i = 1; i < 31; i++) {
+			tmp_ep_ctx = xhci_get_ep_ctx(xhci, out_ctx, i);
+			if ((tmp_ep_ctx->ep_info & cpu_to_le32(EP_STATE_MASK)) != cpu_to_le32(EP_STATE_DISABLED) &&
+				!(le32_to_cpu(ctrl_ctx->add_flags) & xhci_get_endpoint_flag_from_index(i)) &&
+				!(le32_to_cpu(ctrl_ctx->drop_flags) & xhci_get_endpoint_flag_from_index(i)))
+				cur_add_flags |= xhci_get_endpoint_flag_from_index(i);
+		}
+
+		last_ctx = xhci_last_valid_endpoint(le32_to_cpu(ctrl_ctx->add_flags) | cur_add_flags );
+		/* Update the last valid endpoint context, if we deleted the last one */
+		in_slot_ctx->dev_info &= cpu_to_le32(~LAST_CTX_MASK);
+		in_slot_ctx->dev_info |= cpu_to_le32(LAST_CTX(last_ctx));
+
+		ep->hcpriv = udev;
+
+		xhci_dbg(xhci, "add ep 0x%x, slot id %d, drop flag = %#x, add flag = %#x, new in slot info = %#x\n",
+				(unsigned int) ep->desc.bEndpointAddress,
+				udev->slot_id,
+				(unsigned int) drop_flag,
+				(unsigned int) add_flag,
+				(unsigned int) in_slot_ctx->dev_info);
+
+		ret = xhci_configure_endpoint(xhci, udev, NULL,
+			false, false);
+		if (ret)
+			xhci_warn(xhci, "%s - ret %d\n", __func__,ret);
+
+		xhci_zero_in_ctx(xhci, virt_dev);
+	}
+
+	return ;
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 /* Deal with stalled endpoints.  The core should have sent the control message
  * to clear the halt condition.  However, we need to make the xHCI hardware
  * reset its sequence number, since a device will expect a sequence number of
@@ -2868,6 +3207,9 @@ void xhci_endpoint_reset(struct usb_hcd *hcd,
 	ep_index = xhci_get_endpoint_index(&ep->desc);
 	virt_ep = &xhci->devs[udev->slot_id]->eps[ep_index];
 	if (!virt_ep->stopped_td) {
+#ifdef CONFIG_USB_ETRON_HCD
+		xhci_prev_endpoint_reset(hcd, ep);
+#endif /*CONFIG_USB_ETRON_HCD*/
 		xhci_dbg(xhci, "Endpoint 0x%x not halted, refusing to reset.\n",
 				ep->desc.bEndpointAddress);
 		return;
@@ -3062,11 +3404,22 @@ int xhci_alloc_streams(struct usb_hcd *hcd, struct usb_device *udev,
 	struct xhci_hcd *xhci;
 	struct xhci_virt_device *vdev;
 	struct xhci_command *config_cmd;
+#ifdef CONFIG_USB_ETRON_HCD
+	struct xhci_slot_ctx *slot_ctx;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	unsigned int ep_index;
 	unsigned int num_stream_ctxs;
 	unsigned long flags;
 	u32 changed_ep_bitmask = 0;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	xhci = hcd_to_xhci(hcd);
+	if (XHCI_IS_ETRON(xhci)) {
+	if ((hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168) &&
+		((xhci->hcc_params1 & 0xff) == 0x00))
+		return -EINVAL;
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	if (!eps)
 		return -EINVAL;
 
@@ -3131,6 +3484,10 @@ int xhci_alloc_streams(struct usb_hcd *hcd, struct usb_device *udev,
 		/* Set maxPstreams in endpoint context and update deq ptr to
 		 * point to stream context array. FIXME
 		 */
+#ifdef CONFIG_USB_ETRON_HCD
+		if (XHCI_IS_ETRON(xhci))
+		xhci_dbg_stream_info(xhci, ep_index, vdev->eps[ep_index].stream_info);
+#endif /*CONFIG_USB_ETRON_HCD*/
 	}
 
 	/* Set up the input context for a configure endpoint command. */
@@ -3162,6 +3519,14 @@ int xhci_alloc_streams(struct usb_hcd *hcd, struct usb_device *udev,
 	if (ret < 0)
 		goto cleanup;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+	xhci_dbg(xhci, "Output context after successful config ep cmd:\n");
+	slot_ctx = xhci_get_slot_ctx(xhci, vdev->out_ctx);
+	xhci_dbg_ctx(xhci, vdev->out_ctx,
+		     LAST_CTX_TO_EP_NUM(le32_to_cpu(slot_ctx->dev_info)));
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	spin_lock_irqsave(&xhci->lock, flags);
 	for (i = 0; i < num_eps; i++) {
 		ep_index = xhci_get_endpoint_index(&eps[i]->desc);
@@ -3797,8 +4162,15 @@ int xhci_address_device(struct usb_hcd *hcd, struct usb_device *udev)
 	virt_dev->address = (le32_to_cpu(slot_ctx->dev_state) & DEV_ADDR_MASK)
 		+ 1;
 	/* Zero the input context control for later use */
+#ifdef CONFIG_USB_ETRON_HCD
+	if (!XHCI_IS_ETRON(xhci)) {
+#endif /*CONFIG_USB_ETRON_HCD*/
 	ctrl_ctx->add_flags = 0;
 	ctrl_ctx->drop_flags = 0;
+#ifdef CONFIG_USB_ETRON_HCD
+	} else
+		xhci_zero_in_ctx(xhci, virt_dev);
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	xhci_dbg(xhci, "Internal device address = %d\n", virt_dev->address);
 
@@ -4562,6 +4934,10 @@ int xhci_update_hub_device(struct usb_hcd *hcd, struct usb_device *hdev,
 	unsigned think_time;
 	int ret;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (xhci->quirks & XHCI_HUB_INFO_QUIRK)
+		return 0;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	/* Ignore root hubs */
 	if (!hdev->parent)
 		return 0;
@@ -4578,6 +4954,9 @@ int xhci_update_hub_device(struct usb_hcd *hcd, struct usb_device *hdev,
 	}
 
 	spin_lock_irqsave(&xhci->lock, flags);
+#ifdef CONFIG_USB_ETRON_HCD
+	if (!XHCI_IS_ETRON(xhci))
+#endif /*CONFIG_USB_ETRON_HCD*/
 	if (hdev->speed == USB_SPEED_HIGH &&
 			xhci_alloc_tt_info(xhci, vdev, hdev, tt, GFP_ATOMIC)) {
 		xhci_dbg(xhci, "Could not allocate xHCI TT structure.\n");
@@ -4690,12 +5069,24 @@ int xhci_gen_setup(struct usb_hcd *hcd, xhci_get_quirks_t get_quirks)
 		} else {
 			dma_set_mask(hcd->self.controller, DMA_BIT_MASK(32));
 		}
+#ifdef CONFIG_USB_ETRON_HCD
+		hcd->chip_id = xhci->main_hcd->chip_id;
+		hcd->chip_quirks = xhci->main_hcd->chip_quirks;
+#endif /*CONFIG_USB_ETRON_HCD*/
 		return 0;
 	}
 
 	xhci->cap_regs = hcd->regs;
 	xhci->op_regs = hcd->regs +
 		HC_LENGTH(xhci_readl(xhci, &xhci->cap_regs->hc_capbase));
+#ifdef CONFIG_USB_ETRON_HCD
+	if (XHCI_IS_ETRON(xhci)) {
+	/* Make sure the HC is halted. */
+	retval = xhci_halt(xhci);
+	if (retval)
+		goto error;
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 	xhci->run_regs = hcd->regs +
 		(xhci_readl(xhci, &xhci->cap_regs->run_regs_off) & RTSOFF_MASK);
 	/* Cache read-only capability registers */
@@ -4716,10 +5107,16 @@ int xhci_gen_setup(struct usb_hcd *hcd, xhci_get_quirks_t get_quirks)
 	if (xhci->hci_version > 0x96)
 		xhci->quirks |= XHCI_SPURIOUS_SUCCESS;
 
+#ifdef CONFIG_USB_ETRON_HCD
+	if (!XHCI_IS_ETRON(xhci)) {
+#endif /*CONFIG_USB_ETRON_HCD*/
 	/* Make sure the HC is halted. */
 	retval = xhci_halt(xhci);
 	if (retval)
 		goto error;
+#ifdef CONFIG_USB_ETRON_HCD
+	}
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	xhci_dbg(xhci, "Resetting HCD\n");
 	/* Reset the internal HC memory state and registers. */
@@ -4748,6 +5145,448 @@ error:
 	return retval;
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+int xhci_update_uas_device(struct usb_hcd *hcd, struct usb_device *udev,
+		int type)
+{
+	struct xhci_hcd *xhci = hcd_to_xhci(hcd);
+	unsigned long flags;
+	u32 temp;
+
+#define UAS_PROBE	0
+#define UAS_DISCONNECT	1
+#define UAS_PREV_RESET	2
+#define UAS_POST_RESET	3
+
+	spin_lock_irqsave(&xhci->lock, flags);
+	switch (type) {
+	case UAS_PROBE:
+		if ((hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168) &&
+			((xhci->hcc_params1 & 0xff) == 0x30)) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x40c0);
+			temp = (temp & 0xffffff00) | 0x00;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x40c0);
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x40cc);
+			temp = (temp & 0xffffff00) | 0xc2;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x40cc);
+		}
+		break;
+	case UAS_DISCONNECT:
+		if ((hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168) &&
+			((xhci->hcc_params1 & 0xff) == 0x30)) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x40c0);
+			temp = (temp & 0xffffff00) | 0x0e;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x40c0);
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x40cc);
+			temp = (temp & 0xffffff00) | 0xc0;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x40cc);
+		}
+		break;
+	case UAS_PREV_RESET:
+		if ((hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168) &&
+			((xhci->hcc_params1 & 0xff) == 0x30)) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4060);
+			temp |= 0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4060);
+		} else if (hcd->chip_id == HCD_CHIP_ID_ETRON_EJ188) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4210);
+			temp |= 0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4210);
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4250);
+			temp |= 0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4250);
+		}
+		break;
+	case UAS_POST_RESET:
+		if ((hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168) &&
+			((xhci->hcc_params1 & 0xff) == 0x30)) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4060);
+			temp &= ~0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4060);
+		} else if (hcd->chip_id == HCD_CHIP_ID_ETRON_EJ188) {
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4210);
+			temp &= ~0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4210);
+			temp = xhci_readl(xhci, (void __iomem *)xhci->cap_regs + 0x4250);
+			temp &= ~0x01;
+			xhci_writel(xhci, temp, (void __iomem *)xhci->cap_regs + 0x4250);
+		}
+		break;
+	default:
+		break;
+	}
+	spin_unlock_irqrestore(&xhci->lock, flags);
+
+	return 0;
+}
+
+static void xhci_set_hardware_charger_ej168(struct usb_hcd *hcd, int state)
+{
+	struct pci_dev *pdev = to_pci_dev(hcd->self.controller);
+	struct xhci_hcd *xhci = hcd_to_xhci(hcd);
+	u32 __iomem *addr, temp;
+	int	i, ports;
+	u8 reg;
+
+	switch (state) {
+	case 1:	/* Initialize */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware Apple Charger\n");
+			pci_write_config_dword(pdev, 0x68, 0x190a5022);
+			mdelay(50);
+			pci_read_config_byte(pdev, 0xf5, &reg);
+			reg &= ~(1 << 0);
+			pci_write_config_byte(pdev, 0xf5, reg);
+
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+			break;
+		}
+
+		if (charger_flags & XHCI_FLAG_HW_BATTERY_CHARGE) {
+			xhci_dbg(xhci, "Enable hardware Battery Charger\n");
+			pci_read_config_byte(pdev, 0xf5, &reg);
+			reg |= (1 << 1);
+			pci_write_config_byte(pdev, 0xf5, reg);
+		}
+		break;
+
+	case 2:	/* Suspend/Hibernate */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Enable hardware Apple Charger\n");
+			pci_write_config_dword(pdev, 0x68, 0x19005022);
+			pci_read_config_byte(pdev, 0xf5, &reg);
+			reg |= (1 << 0);
+			pci_write_config_byte(pdev, 0xf5, reg);
+		}
+		break;
+
+	case 3:	/* Resume */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware Apple Charger\n");
+			pci_write_config_dword(pdev, 0x68, 0x190a5022);
+			mdelay(50);
+			pci_read_config_byte(pdev, 0xf5, &reg);
+			reg &= ~(1 << 0);
+			pci_write_config_byte(pdev, 0xf5, reg);
+			
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+		}
+		break;
+
+	default:
+		break;
+	}
+}
+
+static void xhci_set_hardware_charger_ej188(struct usb_hcd *hcd, int state)
+{
+	struct pci_dev *pdev = to_pci_dev(hcd->self.controller);
+	struct xhci_hcd *xhci = hcd_to_xhci(hcd);
+	u32 __iomem *addr, temp;
+	int	i, ports;
+	u8 reg;
+
+	switch (state) {
+	case 1:	/* Initialize */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware Apple Charger\n");
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+			break;
+		}
+
+		if (charger_flags & XHCI_FLAG_HW_BATTERY_CHARGE) {
+			xhci_dbg(xhci, "Enable hardware Battery Charger\n");
+			pci_read_config_byte(pdev, 0x44, &reg);
+			reg |= (1 << 0);
+			pci_write_config_byte(pdev, 0x44, reg);
+
+			pci_write_config_dword(pdev, 0xf0, 0x5010);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 16);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 0);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 0);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 0);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 0);
+			pci_write_config_dword(pdev, 0xf4, temp);
+			break;
+		}
+
+		if (charger_flags & XHCI_FLAG_HW_CHINA_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware China Charger\n");
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+		}
+		break;
+
+	case 2:	/* Suspend/Hibernate */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Enable hardware Apple Charger\n");
+			pci_read_config_byte(pdev, 0x44, &reg);
+			reg |= (1 << 0);
+			pci_write_config_byte(pdev, 0x44, reg);
+
+			pci_write_config_dword(pdev, 0xf0, 0x5010);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 16);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+			break;
+		}
+
+		if (charger_flags & XHCI_FLAG_HW_CHINA_CHARGE) {
+			xhci_dbg(xhci, "Enable hardware China Charger\n");
+			pci_read_config_byte(pdev, 0x44, &reg);
+			reg |= (1 << 1);
+			pci_write_config_byte(pdev, 0x44, reg);
+
+			pci_write_config_dword(pdev, 0xf0, 0x5010);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 16);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp |= (1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+		}
+		break;
+
+	case 3:	/* Resume */
+		if (charger_flags & XHCI_FLAG_HW_APPLE_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware Apple Charger\n");
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 4);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+			break;
+		}
+
+		if (charger_flags & XHCI_FLAG_HW_CHINA_CHARGE) {
+			xhci_dbg(xhci, "Disable hardware China Charger\n");
+
+			/* port 1 */
+			pci_write_config_dword(pdev, 0xf0, 0x5070);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 2 */
+			pci_write_config_dword(pdev, 0xf0, 0x5074);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 3 */
+			pci_write_config_dword(pdev, 0xf0, 0x5078);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			/* port 4 */
+			pci_write_config_dword(pdev, 0xf0, 0x507c);
+			pci_read_config_dword(pdev, 0xf4, &temp);
+			temp &= ~(1 << 1);
+			pci_write_config_dword(pdev, 0xf4, temp);
+
+			ports = HCS_MAX_PORTS(xhci->hcs_params1);
+			for (i = 0; i < ports; i++) {
+				addr = &xhci->op_regs->port_status_base + NUM_PORT_REGS * i;
+				temp = xhci_readl(xhci, addr);
+				temp &= ~PORT_POWER;
+				xhci_writel(xhci, temp, addr);
+			}
+
+			mdelay(100);
+		}
+		break;
+
+	default:
+		break;
+	}
+}
+
+void xhci_set_hardware_charger(struct usb_hcd *hcd, int state)
+{
+	if (hcd->chip_id == HCD_CHIP_ID_ETRON_EJ168)
+		xhci_set_hardware_charger_ej168(hcd, state);
+	else if (hcd->chip_id == HCD_CHIP_ID_ETRON_EJ188)
+		xhci_set_hardware_charger_ej188(hcd, state);
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_LICENSE("GPL");
diff --git a/drivers/usb/host/xhci.h b/drivers/usb/host/xhci.h
index 627fcd9..ab56f08 100644
--- a/drivers/usb/host/xhci.h
+++ b/drivers/usb/host/xhci.h
@@ -1,3 +1,4 @@
+
 /*
  * xHCI host controller driver
  *
@@ -88,9 +89,10 @@ struct xhci_cap_regs {
 #define HCS_IST(p)		(((p) >> 0) & 0xf)
 /* bits 4:7, max number of Event Ring segments */
 #define HCS_ERST_MAX(p)		(((p) >> 4) & 0xf)
+/* bits 21:25 Hi 5 bits of Scratchpad buffers SW must allocate for the HW */
 /* bit 26 Scratchpad restore - for save/restore HW state - not used yet */
-/* bits 27:31 number of Scratchpad buffers SW must allocate for the HW */
-#define HCS_MAX_SCRATCHPAD(p)   (((p) >> 27) & 0x1f)
+/* bits 27:31 Lo 5 bits of Scratchpad buffers SW must allocate for the HW */
+#define HCS_MAX_SCRATCHPAD(p)   ((((p) >> 16) & 0x3e0) | (((p) >> 27) & 0x1f))
 
 /* HCSPARAMS3 - hcs_params3 - bitmasks */
 /* bits 0:7, Max U1 to U0 latency for the roothub ports */
@@ -278,6 +280,7 @@ struct xhci_op_regs {
 #define XDEV_U0		(0x0 << 5)
 #define XDEV_U2		(0x2 << 5)
 #define XDEV_U3		(0x3 << 5)
+#define XDEV_INACTIVE	(0x6 << 5)
 #define XDEV_RESUME	(0xf << 5)
 /* true: port has power (see HCC_PPC) */
 #define PORT_POWER	(1 << 9)
@@ -659,6 +662,9 @@ struct xhci_ep_ctx {
 /* bit 6 reserved */
 /* bit 7 is Host Initiate Disable - for disabling stream selection */
 #define MAX_BURST(p)	(((p)&0xff) << 8)
+#ifdef CONFIG_USB_ETRON_HCD
+#define MAX_BURST_MASK	(0xff << 8)
+#endif /*CONFIG_USB_ETRON_HCD*/
 #define CTX_TO_MAX_BURST(p)	(((p) >> 8) & 0xff)
 #define MAX_PACKET(p)	(((p)&0xffff) << 16)
 #define MAX_PACKET_MASK		(0xffff << 16)
@@ -725,7 +731,7 @@ struct xhci_stream_ctx {
 };
 
 /* Stream Context Types (section 6.4.1) - bits 3:1 of stream ctx deq ptr */
-#define	SCT_FOR_CTX(p)		(((p) << 1) & 0x7)
+#define	SCT_FOR_CTX(p)		(((p) & 0x7) << 1)
 /* Secondary stream array type, dequeue pointer is to a transfer ring */
 #define	SCT_SEC_TR		0
 /* Primary stream array type, dequeue pointer is to a transfer ring */
@@ -737,6 +743,11 @@ struct xhci_stream_ctx {
 #define SCT_SSA_64		5
 #define SCT_SSA_128		6
 #define SCT_SSA_256		7
+#ifdef CONFIG_USB_ETRON_HCD
+/* deq bitmasks */
+#define STREAM_CTX_CYCLE_MASK		(1 << 0)
+#define STREAM_CTX_SCT_MASK		(0x7 << 1)
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 /* Assume no secondary streams for now */
 struct xhci_stream_info {
@@ -922,6 +933,11 @@ struct xhci_virt_device {
 	struct xhci_tt_bw_info		*tt_info;
 	/* The current max exit latency for the enabled USB3 link states. */
 	u16				current_mel;
+#ifdef CONFIG_USB_ETRON_HCD
+	int				bulk_out_udelay;
+	unsigned int	manual_halt_cleanup :1;
+	unsigned int	donot_data_toggle_cleanup :1;
+#endif /*CONFIG_USB_ETRON_HCD*/
 };
 
 /*
@@ -1235,7 +1251,11 @@ union xhci_trb {
  * since the command ring is 64-byte aligned.
  * It must also be greater than 16.
  */
+#ifdef CONFIG_USB_ETRON_HCD
+#define TRBS_PER_SEGMENT	128
+#else /*CONFIG_USB_ETRON_HCD*/
 #define TRBS_PER_SEGMENT	64
+#endif /*CONFIG_USB_ETRON_HCD*/
 /* Allow two commands + a link TRB, along with any reserved command TRBs */
 #define MAX_RSVD_CMD_TRBS	(TRBS_PER_SEGMENT - 3)
 #define TRB_SEGMENT_SIZE	(TRBS_PER_SEGMENT*16)
@@ -1258,6 +1278,8 @@ struct xhci_td {
 	struct xhci_segment	*start_seg;
 	union xhci_trb		*first_trb;
 	union xhci_trb		*last_trb;
+	/* actual_length of the URB has already been set */
+	bool			urb_length_set;
 };
 
 /* xHCI command default timeout value */
@@ -1308,6 +1330,7 @@ struct xhci_ring {
 	unsigned int		num_trbs_free_temp;
 	enum xhci_ring_type	type;
 	bool			last_td_was_short;
+	struct radix_tree_root	*trb_address_map;
 };
 
 struct xhci_erst_entry {
@@ -1345,7 +1368,11 @@ struct urb_priv {
  * (1K bytes * 8bytes/bit) / (4*32 bits) = 64 segment entries in the table,
  * meaning 64 ring segments.
  * Initial allocated size of the ERST, in number of entries */
+#ifdef CONFIG_USB_ETRON_HCD
+#define	ERST_NUM_SEGS	2
+#else /*CONFIG_USB_ETRON_HCD*/
 #define	ERST_NUM_SEGS	1
+#endif /*CONFIG_USB_ETRON_HCD*/
 /* Initial allocated size of the ERST, in number of entries */
 #define	ERST_SIZE	64
 /* Initial number of event segment rings allocated */
@@ -1381,6 +1408,9 @@ struct xhci_bus_state {
 	/* Port suspend arrays are indexed by the portnum of the fake roothub */
 	/* ports suspend status arrays - max 31 ports for USB2, 15 for USB3 */
 	u32			port_c_suspend;
+#ifdef CONFIG_USB_ETRON_HCD
+	u32			port_c_connection;
+#endif /*CONFIG_USB_ETRON_HCD*/
 	u32			suspended_ports;
 	u32			port_remote_wakeup;
 	unsigned long		resume_done[USB_MAXCHILDREN];
@@ -1413,6 +1443,9 @@ struct xhci_hcd {
 	__u32		hcs_params2;
 	__u32		hcs_params3;
 	__u32		hcc_params;
+#ifdef CONFIG_USB_ETRON_HCD
+	__u32		hcc_params1;
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 	spinlock_t	lock;
 
@@ -1517,6 +1550,11 @@ struct xhci_hcd {
 #define XHCI_COMP_MODE_QUIRK	(1 << 14)
 #define XHCI_AVOID_BEI		(1 << 15)
 #define XHCI_PLAT		(1 << 16)
+#ifdef CONFIG_USB_ETRON_HCD
+#define XHCI_HUB_INFO_QUIRK	(1 << 24)
+#define XHCI_ETRON_HOST		(1 << 25)
+#define XHCI_IS_ETRON(p)	((p)->quirks & XHCI_ETRON_HOST)
+#endif /*CONFIG_USB_ETRON_HCD*/
 	unsigned int		num_active_eps;
 	unsigned int		limit_active_eps;
 	/* There are two roothubs to keep track of bus suspend info for */
@@ -1540,6 +1578,21 @@ struct xhci_hcd {
 #define COMP_MODE_RCVRY_MSECS 2000
 };
 
+#ifdef CONFIG_USB_ETRON_HCD
+struct table_item {
+	int offset;
+	u32 value;
+};
+
+extern unsigned long charger_flags;
+#define XHCI_FLAG_SW_APPLE_CHARGE	(1 << 0)
+#define XHCI_FLAG_HW_APPLE_CHARGE	(1 << 1)
+#define XHCI_FLAG_HW_BATTERY_CHARGE	(1 << 2)
+#define XHCI_FLAG_HW_CHINA_CHARGE	(1 << 3)
+
+void xhci_set_hardware_charger(struct usb_hcd *hcd, int state);
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 /* convert between an HCD pointer and the corresponding EHCI_HCD */
 static inline struct xhci_hcd *hcd_to_xhci(struct usb_hcd *hcd)
 {
@@ -1581,6 +1634,34 @@ static inline void xhci_writel(struct xhci_hcd *xhci,
 	writel(val, regs);
 }
 
+#ifdef CONFIG_USB_ETRON_HCD
+static inline u8 xhci_readb(struct xhci_hcd *xhci,
+		unsigned int offset)
+{
+	struct usb_hcd *hcd = xhci_to_hcd(xhci);
+	unsigned int temp;
+
+	temp = xhci_readl(xhci, hcd->regs + (offset & 0xfffc));
+	temp = 0x0ff & (temp >> (8 * (offset & 3)));
+
+	return temp;
+}
+static inline void xhci_writeb(struct xhci_hcd *xhci,
+		unsigned int val, unsigned int offset)
+{
+	struct usb_hcd *hcd = xhci_to_hcd(xhci);
+	unsigned int mask, temp;
+
+	mask = 0x0ff;
+	temp = xhci_readl(xhci, hcd->regs + (offset & 0xfffc));
+
+	temp &= ~(mask << (8 * (offset & 3)));
+	temp |= (val & mask) << (8 * (offset & 3));
+
+	xhci_writel(xhci, temp, hcd->regs + (offset & 0xfffc));
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 /*
  * Registers should always be accessed with double word or quad word accesses.
  *
@@ -1632,6 +1713,10 @@ char *xhci_get_slot_state(struct xhci_hcd *xhci,
 void xhci_dbg_ep_rings(struct xhci_hcd *xhci,
 		unsigned int slot_id, unsigned int ep_index,
 		struct xhci_virt_ep *ep);
+#ifdef CONFIG_USB_ETRON_HCD
+void xhci_dbg_stream_info(struct xhci_hcd *xhci,
+		unsigned int ep_index, struct xhci_stream_info *stream_info);
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 /* xHCI memory management */
 void xhci_mem_cleanup(struct xhci_hcd *xhci);
@@ -1707,6 +1792,9 @@ void xhci_free_command(struct xhci_hcd *xhci,
 /* xHCI PCI glue */
 int xhci_register_pci(void);
 void xhci_unregister_pci(void);
+#ifdef CONFIG_USB_ETRON_HCD
+void xhci_init_ejxxx(struct xhci_hcd *xhci);
+#endif /*CONFIG_USB_ETRON_HCD*/
 #else
 static inline int xhci_register_pci(void) { return 0; }
 static inline void xhci_unregister_pci(void) {}
@@ -1769,10 +1857,17 @@ int xhci_urb_enqueue(struct usb_hcd *hcd, struct urb *urb, gfp_t mem_flags);
 int xhci_urb_dequeue(struct usb_hcd *hcd, struct urb *urb, int status);
 int xhci_add_endpoint(struct usb_hcd *hcd, struct usb_device *udev, struct usb_host_endpoint *ep);
 int xhci_drop_endpoint(struct usb_hcd *hcd, struct usb_device *udev, struct usb_host_endpoint *ep);
+#ifdef CONFIG_USB_ETRON_HCD
+void xhci_stop_endpoint(struct usb_hcd *hcd, struct usb_device *udev, struct usb_host_endpoint *ep);
+#endif /*CONFIG_USB_ETRON_HCD*/
 void xhci_endpoint_reset(struct usb_hcd *hcd, struct usb_host_endpoint *ep);
 int xhci_discover_or_reset_device(struct usb_hcd *hcd, struct usb_device *udev);
 int xhci_check_bandwidth(struct usb_hcd *hcd, struct usb_device *udev);
 void xhci_reset_bandwidth(struct usb_hcd *hcd, struct usb_device *udev);
+#ifdef CONFIG_USB_ETRON_HCD
+int xhci_update_uas_device(struct usb_hcd *hcd, struct usb_device *udev,
+		int type);
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 /* xHCI ring, segment, TRB, and TD functions */
 dma_addr_t xhci_trb_virt_to_dma(struct xhci_segment *seg, union xhci_trb *trb);
diff --git a/drivers/usb/serial/Makefile b/drivers/usb/serial/Makefile
index cec63fa..da1d2177 100644
--- a/drivers/usb/serial/Makefile
+++ b/drivers/usb/serial/Makefile
@@ -45,7 +45,10 @@ obj-$(CONFIG_USB_SERIAL_OMNINET)		+= omninet.o
 obj-$(CONFIG_USB_SERIAL_OPTICON)		+= opticon.o
 obj-$(CONFIG_USB_SERIAL_OPTION)			+= option.o
 obj-$(CONFIG_USB_SERIAL_OTI6858)		+= oti6858.o
+# pl2303: for ts3010/5010
 obj-$(CONFIG_USB_SERIAL_PL2303)			+= pl2303.o
+# pl2303g: for ts3020 BTS#261300#note-29
+obj-$(CONFIG_USB_SERIAL_PL2303)			+= pl2303g.o
 obj-$(CONFIG_USB_SERIAL_QCAUX)			+= qcaux.o
 obj-$(CONFIG_USB_SERIAL_QUALCOMM)		+= qcserial.o
 obj-$(CONFIG_USB_SERIAL_QT2)			+= quatech2.o
diff --git a/drivers/usb/serial/pl2303g.c b/drivers/usb/serial/pl2303g.c
new file mode 100644
index 00000000..0b6ee15
--- /dev/null
+++ b/drivers/usb/serial/pl2303g.c
@@ -0,0 +1,1476 @@
+/*
+ * Prolific PL2303 USB to serial adaptor driver
+ *
+ * Copyright (C) 2001-2007 Greg Kroah-Hartman (greg@kroah.com)
+ * Copyright (C) 2003 IBM Corp.
+ *
+ * Original driver for 2.2.x by anonymous
+ *
+ *	This program is free software; you can redistribute it and/or
+ *	modify it under the terms of the GNU General Public License version
+ *	2 as published by the Free Software Foundation.
+ *
+ * See Documentation/usb/usb-serial.txt for more information on using this
+ * driver
+ *
+ */
+
+#include <linux/kernel.h>
+#include <linux/errno.h>
+#include <linux/init.h>
+#include <linux/slab.h>
+#include <linux/tty.h>
+#include <linux/tty_driver.h>
+#include <linux/tty_flip.h>
+#include <linux/serial.h>
+#include <linux/module.h>
+#include <linux/moduleparam.h>
+#include <linux/spinlock.h>
+#include <linux/uaccess.h>
+#include <linux/usb.h>
+#include <linux/usb/serial.h>
+#include "pl2303g.h"
+
+/*
+ * Version Information
+ */
+#define DRIVER_DESC "Prolific PL2303 USB to serial adaptor driver"
+
+static const struct usb_device_id id_table[] = {
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_RSAQ2) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_DCU11) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_RSAQ3) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_PHAROS) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_ALDIGA) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_MMX) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_GPRS) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_HCR331) },
+	// { USB_DEVICE(PL2303_VENDOR_ID, PL2303_PRODUCT_ID_MOTOROLA) },
+	{ USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GC) }, /* Prolific PL2303GC chip */
+	{ USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GB) }, /* Prolific PL2303GB chip */
+	{ USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GT) }, /* Prolific PL2303GT chip */
+	{ USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GL) }, /* Prolific PL2303GL chip */
+	{ USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GE) }, /* Prolific PL2303GE chip */
+    { USB_DEVICE(PL2303_VENDOR_ID, PL2303G_PRODUCT_ID_GS) }, /* Prolific PL2303GS chip */
+	// { USB_DEVICE(IODATA_VENDOR_ID, IODATA_PRODUCT_ID) },
+	// { USB_DEVICE(IODATA_VENDOR_ID, IODATA_PRODUCT_ID_RSAQ5) },
+	// { USB_DEVICE(ATEN_VENDOR_ID, ATEN_PRODUCT_ID) },
+	// { USB_DEVICE(ATEN_VENDOR_ID2, ATEN_PRODUCT_ID) },
+	// { USB_DEVICE(ELCOM_VENDOR_ID, ELCOM_PRODUCT_ID) },
+	// { USB_DEVICE(ELCOM_VENDOR_ID, ELCOM_PRODUCT_ID_UCSGT) },
+	// { USB_DEVICE(ITEGNO_VENDOR_ID, ITEGNO_PRODUCT_ID) },
+	// { USB_DEVICE(ITEGNO_VENDOR_ID, ITEGNO_PRODUCT_ID_2080) },
+	// { USB_DEVICE(MA620_VENDOR_ID, MA620_PRODUCT_ID) },
+	// { USB_DEVICE(RATOC_VENDOR_ID, RATOC_PRODUCT_ID) },
+	// { USB_DEVICE(TRIPP_VENDOR_ID, TRIPP_PRODUCT_ID) },
+	// { USB_DEVICE(RADIOSHACK_VENDOR_ID, RADIOSHACK_PRODUCT_ID) },
+	// { USB_DEVICE(DCU10_VENDOR_ID, DCU10_PRODUCT_ID) },
+	// { USB_DEVICE(SITECOM_VENDOR_ID, SITECOM_PRODUCT_ID) },
+	// { USB_DEVICE(ALCATEL_VENDOR_ID, ALCATEL_PRODUCT_ID) },
+	// { USB_DEVICE(SAMSUNG_VENDOR_ID, SAMSUNG_PRODUCT_ID) },
+	// { USB_DEVICE(SIEMENS_VENDOR_ID, SIEMENS_PRODUCT_ID_SX1) },
+	// { USB_DEVICE(SIEMENS_VENDOR_ID, SIEMENS_PRODUCT_ID_X65) },
+	// { USB_DEVICE(SIEMENS_VENDOR_ID, SIEMENS_PRODUCT_ID_X75) },
+	// { USB_DEVICE(SIEMENS_VENDOR_ID, SIEMENS_PRODUCT_ID_EF81) },
+	// { USB_DEVICE(BENQ_VENDOR_ID, BENQ_PRODUCT_ID_S81) }, /* Benq/Siemens S81 */
+	// { USB_DEVICE(SYNTECH_VENDOR_ID, SYNTECH_PRODUCT_ID) },
+	// { USB_DEVICE(NOKIA_CA42_VENDOR_ID, NOKIA_CA42_PRODUCT_ID) },
+	// { USB_DEVICE(CA_42_CA42_VENDOR_ID, CA_42_CA42_PRODUCT_ID) },
+	// { USB_DEVICE(SAGEM_VENDOR_ID, SAGEM_PRODUCT_ID) },
+	// { USB_DEVICE(LEADTEK_VENDOR_ID, LEADTEK_9531_PRODUCT_ID) },
+	// { USB_DEVICE(SPEEDDRAGON_VENDOR_ID, SPEEDDRAGON_PRODUCT_ID) },
+	// { USB_DEVICE(DATAPILOT_U2_VENDOR_ID, DATAPILOT_U2_PRODUCT_ID) },
+	// { USB_DEVICE(BELKIN_VENDOR_ID, BELKIN_PRODUCT_ID) },
+	// { USB_DEVICE(ALCOR_VENDOR_ID, ALCOR_PRODUCT_ID) },
+	// { USB_DEVICE(WS002IN_VENDOR_ID, WS002IN_PRODUCT_ID) },
+	// { USB_DEVICE(COREGA_VENDOR_ID, COREGA_PRODUCT_ID) },
+	// { USB_DEVICE(YCCABLE_VENDOR_ID, YCCABLE_PRODUCT_ID) },
+	// { USB_DEVICE(SUPERIAL_VENDOR_ID, SUPERIAL_PRODUCT_ID) },
+	// { USB_DEVICE(HP_VENDOR_ID, HP_LD220_PRODUCT_ID) },
+	// { USB_DEVICE(CRESSI_VENDOR_ID, CRESSI_EDY_PRODUCT_ID) },
+	// { USB_DEVICE(ZEAGLE_VENDOR_ID, ZEAGLE_N2ITION3_PRODUCT_ID) },
+	// { USB_DEVICE(SONY_VENDOR_ID, SONY_QN3USB_PRODUCT_ID) },
+	// { USB_DEVICE(SANWA_VENDOR_ID, SANWA_PRODUCT_ID) },
+	// { USB_DEVICE(ADLINK_VENDOR_ID, ADLINK_ND6530_PRODUCT_ID) },
+	// { USB_DEVICE(SMART_VENDOR_ID, SMART_PRODUCT_ID) },
+	{ }					/* Terminating entry */
+};
+
+MODULE_DEVICE_TABLE(usb, id_table);
+
+#define SET_LINE_REQUEST_TYPE		0x21
+#define SET_LINE_REQUEST			0x20
+
+#define SET_CONTROL_REQUEST_TYPE	0x21
+#define SET_CONTROL_REQUEST			0x22
+#define CONTROL_DTR					0x01
+#define CONTROL_RTS					0x02
+
+#define BREAK_REQUEST_TYPE			0x21
+#define BREAK_REQUEST				0x23
+#define BREAK_ON					0xffff
+#define BREAK_OFF					0x0000
+
+#define GET_LINE_REQUEST_TYPE		0xa1
+#define GET_LINE_REQUEST			0x21
+
+#define VENDOR_WRITE_REQUEST_TYPE	0x40
+#define VENDOR_WRITE_REQUEST		0x80
+
+#define VENDOR_READ_REQUEST_TYPE	0xc0
+#define VENDOR_READ_REQUEST			0x81
+
+#define UART_STATE					0x08
+#define UART_STATE_TRANSIENT_MASK	0x74
+#define UART_DCD					0x01
+#define UART_DSR					0x02
+#define UART_BREAK_ERROR			0x04
+#define UART_RING					0x08
+#define UART_FRAME_ERROR			0x10
+#define UART_PARITY_ERROR			0x20
+#define UART_OVERRUN_ERROR			0x40
+#define UART_CTS					0x80
+
+
+enum pl2303_type {
+	type_0,		/* don't know the difference between type 0 and */
+	type_1,		/* type 1, until someone from prolific tells us... */
+	HX,		/* HX version of the pl2303 chip */
+};
+
+struct pl2303_serial_private {
+	enum pl2303_type type;
+};
+
+struct pl2303_private {
+	spinlock_t lock;
+	u8 line_control;
+	u8 line_status;
+
+	u8 line_settings[7];
+};
+
+static int pl2303_vendor_read(__u16 value, __u16 index,
+		struct usb_serial *serial, unsigned char *buf)
+{
+	int res = usb_control_msg(serial->dev, usb_rcvctrlpipe(serial->dev, 0),
+			VENDOR_READ_REQUEST, VENDOR_READ_REQUEST_TYPE,
+			value, index, buf, 1, 100);
+	dev_dbg(&serial->interface->dev, "0x%x:0x%x:0x%x:0x%x  %d - %x\n",
+		VENDOR_READ_REQUEST_TYPE, VENDOR_READ_REQUEST, value, index,
+		res, buf[0]);
+	return res;
+}
+
+static int pl2303_vendor_read_A1(__u16 value, __u16 index,
+		struct usb_serial *serial, u16 *data)
+{
+	int res = usb_control_msg(serial->dev, usb_rcvctrlpipe(serial->dev, 0),
+			VENDOR_READ_REQUEST, VENDOR_READ_REQUEST_TYPE,
+			value, index, data, 1, 100);
+	dev_dbg(&serial->interface->dev, "0x%x:0x%x:0x%x:0x%x  %d - %x\n",
+		VENDOR_READ_REQUEST_TYPE, VENDOR_READ_REQUEST, value, index,
+		res, *data);
+	return res;
+}
+
+static int pl2303_vendor_write(__u16 value, __u16 index,
+		struct usb_serial *serial)
+{
+	int res = usb_control_msg(serial->dev, usb_sndctrlpipe(serial->dev, 0),
+			VENDOR_WRITE_REQUEST, VENDOR_WRITE_REQUEST_TYPE,
+			value, index, NULL, 0, 100);
+	dev_dbg(&serial->interface->dev, "0x%x:0x%x:0x%x:0x%x  %d\n",
+		VENDOR_WRITE_REQUEST_TYPE, VENDOR_WRITE_REQUEST, value, index,
+		res);
+	return res;
+}
+
+static int pl2303_startup(struct usb_serial *serial)
+{
+	struct pl2303_serial_private *spriv;
+	enum pl2303_type type = type_0;
+	unsigned char *buf;
+
+	spriv = kzalloc(sizeof(*spriv), GFP_KERNEL);
+	if (!spriv)
+		return -ENOMEM;
+
+	buf = kmalloc(10, GFP_KERNEL);
+	if (!buf) {
+		kfree(spriv);
+		return -ENOMEM;
+	}
+
+	if (serial->dev->descriptor.bDeviceClass == 0x02)
+		type = type_0;
+	else if (serial->dev->descriptor.bMaxPacketSize0 == 0x40)
+		type = HX;
+	else if (serial->dev->descriptor.bDeviceClass == 0x00)
+		type = type_1;
+	else if (serial->dev->descriptor.bDeviceClass == 0xFF)
+		type = type_1;
+	
+	type = HX;
+	
+	dev_dbg(&serial->interface->dev, "device type: %d\n", type);
+
+	spriv->type = type;
+	usb_set_serial_data(serial, spriv);
+/*
+	pl2303_vendor_read(0x8484, 0, serial, buf);
+	pl2303_vendor_write(0x0404, 0, serial);
+	pl2303_vendor_read(0x8484, 0, serial, buf);
+	pl2303_vendor_read(0x8383, 0, serial, buf);
+	pl2303_vendor_read(0x8484, 0, serial, buf);
+	pl2303_vendor_write(0x0404, 1, serial);
+	pl2303_vendor_read(0x8484, 0, serial, buf);
+	pl2303_vendor_read(0x8383, 0, serial, buf);
+	pl2303_vendor_write(0, 1, serial);
+	pl2303_vendor_write(1, 0, serial);
+	if (type == HX)
+		pl2303_vendor_write(2, 0x44, serial);
+	else
+		pl2303_vendor_write(2, 0x24, serial);
+*/
+	pl2303_vendor_write(0x0505, 0xFF, serial);
+
+	kfree(buf);
+	return 0;
+}
+
+static void pl2303_release(struct usb_serial *serial)
+{
+	struct pl2303_serial_private *spriv;
+
+	spriv = usb_get_serial_data(serial);
+	kfree(spriv);
+}
+
+static int pl2303_port_probe(struct usb_serial_port *port)
+{
+	struct pl2303_private *priv;
+
+	priv = kzalloc(sizeof(*priv), GFP_KERNEL);
+	if (!priv)
+		return -ENOMEM;
+
+	spin_lock_init(&priv->lock);
+
+	usb_set_serial_port_data(port, priv);
+
+	return 0;
+}
+
+static int pl2303_port_remove(struct usb_serial_port *port)
+{
+	struct pl2303_private *priv;
+
+	priv = usb_get_serial_port_data(port);
+	kfree(priv);
+
+	return 0;
+}
+
+static int pl2303_set_control_lines(struct usb_serial_port *port, u8 value)
+{
+	struct usb_device *dev = port->serial->dev;
+	int retval;
+
+	retval = usb_control_msg(dev, usb_sndctrlpipe(dev, 0),
+				 SET_CONTROL_REQUEST, SET_CONTROL_REQUEST_TYPE,
+				 value, 0, NULL, 0, 100);
+	dev_dbg(&port->dev, "%s - value = %d, retval = %d\n", __func__,
+		value, retval);
+	return retval;
+}
+
+static void pl2303_set_termios(struct tty_struct *tty,
+		struct usb_serial_port *port, struct ktermios *old_termios)
+{
+	struct usb_serial *serial = port->serial;
+	struct pl2303_serial_private *spriv = usb_get_serial_data(serial);
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned long flags;
+	unsigned int cflag;
+	unsigned char *buf;
+	int baud;
+	int i;
+	u8 control;
+	const int baud_sup[] = { 75, 150, 300, 600, 1200, 1800, 2400, 3600,
+	                         4800, 7200, 9600, 14400, 19200, 28800, 38400,
+	                         57600, 115200, 230400, 460800, 614400,
+	                         921600, 1228800, 2457600, 3000000, 6000000 };
+	int baud_floor, baud_ceil;
+	int k;
+
+	if (old_termios && !tty_termios_hw_change(&tty->termios, old_termios))
+		return;
+
+	cflag = tty->termios.c_cflag;
+
+	buf = kzalloc(7, GFP_KERNEL);
+	if (!buf) {
+		dev_err(&port->dev, "%s - out of memory.\n", __func__);
+		/* Report back no change occurred */
+		if (old_termios)
+			tty->termios = *old_termios;
+		return;
+	}
+
+	i = usb_control_msg(serial->dev, usb_rcvctrlpipe(serial->dev, 0),
+			    GET_LINE_REQUEST, GET_LINE_REQUEST_TYPE,
+			    0, 0, buf, 7, 100);
+	dev_dbg(&port->dev, "0xa1:0x21:0:0  %d - %x %x %x %x %x %x %x\n", i,
+	    buf[0], buf[1], buf[2], buf[3], buf[4], buf[5], buf[6]);
+
+	switch (cflag & CSIZE) {
+	case CS5:
+		buf[6] = 5;
+		break;
+	case CS6:
+		buf[6] = 6;
+		break;
+	case CS7:
+		buf[6] = 7;
+		break;
+	default:
+	case CS8:
+		buf[6] = 8;
+		break;
+	}
+	dev_dbg(&port->dev, "data bits = %d\n", buf[6]);
+
+	/* For reference buf[0]:buf[3] baud rate value */
+	/* NOTE: Only the values defined in baud_sup are supported !
+	 *       => if unsupported values are set, the PL2303 seems to use
+	 *          9600 baud (at least my PL2303X always does)
+	 */
+	baud = tty_get_baud_rate(tty);
+	dev_dbg(&port->dev, "baud requested = %d\n", baud);
+	if (baud) {
+		/* Set baudrate to nearest supported value */
+		for (k=0; k<ARRAY_SIZE(baud_sup); k++) {
+			if (baud_sup[k] / baud) {
+				baud_ceil = baud_sup[k];
+				if (k==0) {
+					baud = baud_ceil;
+				} else {
+					baud_floor = baud_sup[k-1];
+					if ((baud_ceil % baud)
+					    > (baud % baud_floor))
+						baud = baud_floor;
+					else
+						baud = baud_ceil;
+				}
+				break;
+			}
+		}
+		if (baud > 1228800) {
+			/* type_0, type_1 only support up to 1228800 baud */
+			if (spriv->type != HX)
+				baud = 1228800;
+			else if (baud > 6000000)
+				baud = 6000000;
+		}
+		dev_dbg(&port->dev, "baud set = %d\n", baud);
+		if (baud <= 115200) {
+			buf[0] = baud & 0xff;
+			buf[1] = (baud >> 8) & 0xff;
+			buf[2] = (baud >> 16) & 0xff;
+			buf[3] = (baud >> 24) & 0xff;
+		} else {
+			/* apparently the formula for higher speeds is:
+			 * baudrate = 12M * 32 / (2^buf[1]) / buf[0]
+			 */
+			unsigned tmp = 12*1000*1000*32 / baud;
+			buf[3] = 0x80;
+			buf[2] = 0;
+			buf[1] = (tmp >= 256);
+			while (tmp >= 256) {
+				tmp >>= 2;
+				buf[1] <<= 1;
+			}
+			buf[0] = tmp;
+		}
+	}
+
+	/* For reference buf[4]=0 is 1 stop bits */
+	/* For reference buf[4]=1 is 1.5 stop bits */
+	/* For reference buf[4]=2 is 2 stop bits */
+	if (cflag & CSTOPB) {
+		/* NOTE: Comply with "real" UARTs / RS232:
+		 *       use 1.5 instead of 2 stop bits with 5 data bits
+		 */
+		if ((cflag & CSIZE) == CS5) {
+			buf[4] = 1;
+			dev_dbg(&port->dev, "stop bits = 1.5\n");
+		} else {
+			buf[4] = 2;
+			dev_dbg(&port->dev, "stop bits = 2\n");
+		}
+	} else {
+		buf[4] = 0;
+		dev_dbg(&port->dev, "stop bits = 1\n");
+	}
+
+	if (cflag & PARENB) {
+		/* For reference buf[5]=0 is none parity */
+		/* For reference buf[5]=1 is odd parity */
+		/* For reference buf[5]=2 is even parity */
+		/* For reference buf[5]=3 is mark parity */
+		/* For reference buf[5]=4 is space parity */
+		if (cflag & PARODD) {
+			if (cflag & CMSPAR) {
+				buf[5] = 3;
+				dev_dbg(&port->dev, "parity = mark\n");
+			} else {
+				buf[5] = 1;
+				dev_dbg(&port->dev, "parity = odd\n");
+			}
+		} else {
+			if (cflag & CMSPAR) {
+				buf[5] = 4;
+				dev_dbg(&port->dev, "parity = space\n");
+			} else {
+				buf[5] = 2;
+				dev_dbg(&port->dev, "parity = even\n");
+			}
+		}
+	} else {
+		buf[5] = 0;
+		dev_dbg(&port->dev, "parity = none\n");
+	}
+
+	/*
+	 * Some PL2303 are known to lose bytes if you change serial settings
+	 * even to the same values as before. Thus we actually need to filter
+	 * in this specific case.
+	 *
+	 * Note that the tty_termios_hw_change check above is not sufficient
+	 * as a previously requested baud rate may differ from the one
+	 * actually used (and stored in old_termios).
+	 *
+	 * NOTE: No additional locking needed for line_settings as it is
+	 *       only used in set_termios, which is serialised against itself.
+	 */
+	if (!old_termios || memcmp(buf, priv->line_settings, 7)) {
+		i = usb_control_msg(serial->dev,
+				    usb_sndctrlpipe(serial->dev, 0),
+				    SET_LINE_REQUEST, SET_LINE_REQUEST_TYPE,
+				    0, 0, buf, 7, 100);
+
+		dev_dbg(&port->dev, "0x21:0x20:0:0  %d\n", i);
+
+		if (i == 7)
+			memcpy(priv->line_settings, buf, 7);
+	}
+
+	/* change control lines if we are switching to or from B0 */
+	spin_lock_irqsave(&priv->lock, flags);
+	control = priv->line_control;
+	if ((cflag & CBAUD) == B0)
+		priv->line_control &= ~(CONTROL_DTR | CONTROL_RTS);
+	else if (old_termios && (old_termios->c_cflag & CBAUD) == B0)
+		priv->line_control |= (CONTROL_DTR | CONTROL_RTS);
+	if (control != priv->line_control) {
+		control = priv->line_control;
+		spin_unlock_irqrestore(&priv->lock, flags);
+		pl2303_set_control_lines(port, control);
+	} else {
+		spin_unlock_irqrestore(&priv->lock, flags);
+	}
+
+	buf[0] = buf[1] = buf[2] = buf[3] = buf[4] = buf[5] = buf[6] = 0;
+
+	i = usb_control_msg(serial->dev, usb_rcvctrlpipe(serial->dev, 0),
+			    GET_LINE_REQUEST, GET_LINE_REQUEST_TYPE,
+			    0, 0, buf, 7, 100);
+	dev_dbg(&port->dev, "0xa1:0x21:0:0  %d - %x %x %x %x %x %x %x\n", i,
+	     buf[0], buf[1], buf[2], buf[3], buf[4], buf[5], buf[6]);
+
+	if (cflag & CRTSCTS) {
+		if (spriv->type == HX)
+			pl2303_vendor_write(0x0A, 0xFA, serial);
+		else
+			pl2303_vendor_write(0x0, 0x41, serial);
+	} else {
+		pl2303_vendor_write(0x0A, 0xFF, serial);
+	}
+
+	/* Save resulting baud rate */
+	if (baud)
+		tty_encode_baud_rate(tty, baud, baud);
+
+	kfree(buf);
+}
+
+static void pl2303_dtr_rts(struct usb_serial_port *port, int on)
+{
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned long flags;
+	u8 control;
+
+	spin_lock_irqsave(&priv->lock, flags);
+	/* Change DTR and RTS */
+	if (on)
+		priv->line_control |= (CONTROL_DTR | CONTROL_RTS);
+	else
+		priv->line_control &= ~(CONTROL_DTR | CONTROL_RTS);
+	control = priv->line_control;
+	spin_unlock_irqrestore(&priv->lock, flags);
+	pl2303_set_control_lines(port, control);
+}
+
+static void pl2303_close(struct usb_serial_port *port)
+{
+	usb_serial_generic_close(port);
+	usb_kill_urb(port->interrupt_in_urb);
+}
+
+static int pl2303_open(struct tty_struct *tty, struct usb_serial_port *port)
+{
+	struct usb_serial *serial = port->serial;
+	struct pl2303_serial_private *spriv = usb_get_serial_data(serial);
+	int result;
+
+	
+	
+	if (spriv->type != HX) {
+		usb_clear_halt(serial->dev, port->write_urb->pipe);
+		usb_clear_halt(serial->dev, port->read_urb->pipe);
+	} else {
+		/* reset upstream data pipes */
+		//pl2303_vendor_write(8, 0, serial);
+		//pl2303_vendor_write(9, 0, serial);
+		pl2303_vendor_write(7, 0, serial);
+	}
+
+	/* Setup termios */
+	if (tty)
+		pl2303_set_termios(tty, port, NULL);
+	
+	pl2303_vendor_write(0x0505, 0xFF, serial);
+
+	result = usb_submit_urb(port->interrupt_in_urb, GFP_KERNEL);
+	if (result) {
+		dev_err(&port->dev, "%s - failed submitting interrupt urb,"
+			" error %d\n", __func__, result);
+		return result;
+	}
+
+	result = usb_serial_generic_open(tty, port);
+	if (result) {
+		usb_kill_urb(port->interrupt_in_urb);
+		return result;
+	}
+
+	port->port.drain_delay = 256;
+	return 0;
+}
+
+static int pl2303_tiocmset(struct tty_struct *tty,
+			   unsigned int set, unsigned int clear)
+{
+	struct usb_serial_port *port = tty->driver_data;
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned long flags;
+	u8 control;
+	int ret;
+
+	spin_lock_irqsave(&priv->lock, flags);
+	if (set & TIOCM_RTS)
+		priv->line_control |= CONTROL_RTS;
+	if (set & TIOCM_DTR)
+		priv->line_control |= CONTROL_DTR;
+	if (clear & TIOCM_RTS)
+		priv->line_control &= ~CONTROL_RTS;
+	if (clear & TIOCM_DTR)
+		priv->line_control &= ~CONTROL_DTR;
+	control = priv->line_control;
+	spin_unlock_irqrestore(&priv->lock, flags);
+
+	ret = pl2303_set_control_lines(port, control);
+	if (ret)
+		return usb_translate_errors(ret);
+
+	return 0;
+}
+
+static int pl2303_tiocmget(struct tty_struct *tty)
+{
+	struct usb_serial_port *port = tty->driver_data;
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned long flags;
+	unsigned int mcr;
+	unsigned int status;
+	unsigned int result;
+
+	spin_lock_irqsave(&priv->lock, flags);
+	mcr = priv->line_control;
+	status = priv->line_status;
+	spin_unlock_irqrestore(&priv->lock, flags);
+
+	result = ((mcr & CONTROL_DTR)		? TIOCM_DTR : 0)
+		  | ((mcr & CONTROL_RTS)	? TIOCM_RTS : 0)
+		  | ((status & UART_CTS)	? TIOCM_CTS : 0)
+		  | ((status & UART_DSR)	? TIOCM_DSR : 0)
+		  | ((status & UART_RING)	? TIOCM_RI  : 0)
+		  | ((status & UART_DCD)	? TIOCM_CD  : 0);
+
+	dev_dbg(&port->dev, "%s - result = %x\n", __func__, result);
+
+	return result;
+}
+
+static int pl2303_carrier_raised(struct usb_serial_port *port)
+{
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	if (priv->line_status & UART_DCD)
+		return 1;
+	return 0;
+}
+
+static int pl2303_tiocmiwait(struct tty_struct *tty, unsigned long arg)
+{
+	struct usb_serial_port *port = tty->driver_data;
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned long flags;
+	unsigned int prevstatus;
+	unsigned int status;
+	unsigned int changed;
+
+	spin_lock_irqsave(&priv->lock, flags);
+	prevstatus = priv->line_status;
+	spin_unlock_irqrestore(&priv->lock, flags);
+
+	while (1) {
+		interruptible_sleep_on(&port->port.delta_msr_wait);
+		/* see if a signal did it */
+		if (signal_pending(current))
+			return -ERESTARTSYS;
+
+		if (port->serial->disconnected)
+			return -EIO;
+
+		spin_lock_irqsave(&priv->lock, flags);
+		status = priv->line_status;
+		spin_unlock_irqrestore(&priv->lock, flags);
+
+		changed = prevstatus ^ status;
+
+		if (((arg & TIOCM_RNG) && (changed & UART_RING)) ||
+		    ((arg & TIOCM_DSR) && (changed & UART_DSR)) ||
+		    ((arg & TIOCM_CD)  && (changed & UART_DCD)) ||
+		    ((arg & TIOCM_CTS) && (changed & UART_CTS))) {
+			return 0;
+		}
+		prevstatus = status;
+	}
+	/* NOTREACHED */
+	return 0;
+}
+
+static int pl2303_ioctl(struct tty_struct *tty,
+			unsigned int cmd, unsigned long arg)
+{
+	void __user *data;
+	__u16 kdata;
+	__u16 buf_2;
+	int result=0;	
+	int retval=0;
+	
+	struct serial_struct ser;
+	struct usb_serial_port *port = tty->driver_data;
+	struct usb_serial *serial = port->serial;
+
+	dev_dbg(&port->dev, "%s cmd = 0x%04x\n", __func__, cmd);
+
+	switch (cmd) {
+	case TIOCGSERIAL:
+		memset(&ser, 0, sizeof ser);
+		ser.type = PORT_16654;
+		ser.line = port->serial->minor;
+		ser.port = port->number;
+		ser.baud_base = 460800;
+
+		if (copy_to_user((void __user *)arg, &ser, sizeof ser))
+			return -EFAULT;
+
+		return 0;
+		case GPB_0_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x01;
+			else
+				buf_2 &= ~0x01;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_1_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x02;
+			else
+				buf_2 &= ~0x02;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_2_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x04;
+			else
+				buf_2 &= ~0x04;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_3_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x08;
+			else
+				buf_2 &= ~0x08;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_4_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x10;
+			else
+				buf_2 &= ~0x10;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_5_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x20;
+			else
+				buf_2 &= ~0x20;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_6_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x40;
+			else
+				buf_2 &= ~0x40;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_7_OUTPUT_ENABLE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}	
+					
+			result=pl2303_vendor_read_A1(0x0303, 0, serial, &buf_2);
+
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}
+            
+			if (kdata)
+				buf_2 |= 0x80;
+			else
+				buf_2 &= ~0x80;
+			
+			result=pl2303_vendor_write(0x03, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;
+			case GPB_0_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x01;
+			else
+				buf_2 &= ~0x01;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_1_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x02;
+			else
+				buf_2 &= ~0x02;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_2_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x04;
+			else
+				buf_2 &= ~0x04;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_3_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x08;
+			else
+				buf_2 &= ~0x08;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_4_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x10;
+			else
+				buf_2 &= ~0x10;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_5_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x20;
+			else
+				buf_2 &= ~0x20;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_6_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x40;
+			else
+				buf_2 &= ~0x40;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+			case GPB_7_SET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;
+			if (copy_from_user(&kdata, data, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}			
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}	
+			       		
+			if (kdata)
+				buf_2 |= 0x80;
+			else
+				buf_2 &= ~0x80;
+			
+			result=pl2303_vendor_write(0x01, buf_2, serial);
+			
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			       
+			break;	
+		    case GPB_0_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x01)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_1_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x02)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_2_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x04)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_3_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x08)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_4_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x10)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_5_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x20)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_6_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x40)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+		    case GPB_7_GET_VALUE:
+			data = (void __user *) arg;
+			if (data == NULL)
+				break;	
+			result=pl2303_vendor_read_A1(0x0101, 0, serial, &buf_2);
+			if (result<0) {
+				retval = result;
+				goto err_out;
+			}			          
+			if (buf_2 & 0x80)
+				kdata = 1;
+			else
+				kdata = 0;
+			if (copy_to_user(data, &kdata, sizeof(__u16))) {
+				retval = -EFAULT;
+				goto err_out;
+			}				
+			break;
+	default:
+		dev_dbg(&port->dev, "%s not supported = 0x%04x\n", __func__, cmd);
+		retval= -ENOIOCTLCMD;
+		break;
+	}
+  err_out:
+   return retval;
+}
+
+static void pl2303_break_ctl(struct tty_struct *tty, int break_state)
+{
+	struct usb_serial_port *port = tty->driver_data;
+	struct usb_serial *serial = port->serial;
+	u16 state;
+	int result;
+
+	if (break_state == 0)
+		state = BREAK_OFF;
+	else
+		state = BREAK_ON;
+	dev_dbg(&port->dev, "%s - turning break %s\n", __func__,
+			state == BREAK_OFF ? "off" : "on");
+
+	result = usb_control_msg(serial->dev, usb_sndctrlpipe(serial->dev, 0),
+				 BREAK_REQUEST, BREAK_REQUEST_TYPE, state,
+				 0, NULL, 0, 100);
+	if (result)
+		dev_err(&port->dev, "error sending break = %d\n", result);
+}
+
+static void pl2303_update_line_status(struct usb_serial_port *port,
+				      unsigned char *data,
+				      unsigned int actual_length)
+{
+
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	struct tty_struct *tty;
+	unsigned long flags;
+	u8 status_idx = UART_STATE;
+	u8 length = UART_STATE + 1;
+	u8 prev_line_status;
+	u16 idv, idp;
+
+	idv = le16_to_cpu(port->serial->dev->descriptor.idVendor);
+	idp = le16_to_cpu(port->serial->dev->descriptor.idProduct);
+
+
+	if (idv == SIEMENS_VENDOR_ID) {
+		if (idp == SIEMENS_PRODUCT_ID_X65 ||
+		    idp == SIEMENS_PRODUCT_ID_SX1 ||
+		    idp == SIEMENS_PRODUCT_ID_X75) {
+
+			length = 1;
+			status_idx = 0;
+		}
+	}
+
+	if (actual_length < length)
+		return;
+
+	/* Save off the uart status for others to look at */
+	spin_lock_irqsave(&priv->lock, flags);
+	prev_line_status = priv->line_status;
+	priv->line_status = data[status_idx];
+	spin_unlock_irqrestore(&priv->lock, flags);
+	if (priv->line_status & UART_BREAK_ERROR)
+		usb_serial_handle_break(port);
+	wake_up_interruptible(&port->port.delta_msr_wait);
+
+	tty = tty_port_tty_get(&port->port);
+	if (!tty)
+		return;
+	if ((priv->line_status ^ prev_line_status) & UART_DCD)
+		usb_serial_handle_dcd_change(port, tty,
+				priv->line_status & UART_DCD);
+	tty_kref_put(tty);
+}
+
+static void pl2303_read_int_callback(struct urb *urb)
+{
+	struct usb_serial_port *port =  urb->context;
+	unsigned char *data = urb->transfer_buffer;
+	unsigned int actual_length = urb->actual_length;
+	int status = urb->status;
+	int retval;
+
+	switch (status) {
+	case 0:
+		/* success */
+		break;
+	case -ECONNRESET:
+	case -ENOENT:
+	case -ESHUTDOWN:
+		/* this urb is terminated, clean up */
+		dev_dbg(&port->dev, "%s - urb shutting down with status: %d\n",
+			__func__, status);
+		return;
+	default:
+		dev_dbg(&port->dev, "%s - nonzero urb status received: %d\n",
+			__func__, status);
+		goto exit;
+	}
+
+	usb_serial_debug_data(&port->dev, __func__,
+			      urb->actual_length, urb->transfer_buffer);
+
+	pl2303_update_line_status(port, data, actual_length);
+
+exit:
+	retval = usb_submit_urb(urb, GFP_ATOMIC);
+	if (retval)
+		dev_err(&port->dev,
+			"%s - usb_submit_urb failed with result %d\n",
+			__func__, retval);
+}
+
+static void pl2303_process_read_urb(struct urb *urb)
+{
+	struct usb_serial_port *port = urb->context;
+	struct pl2303_private *priv = usb_get_serial_port_data(port);
+	unsigned char *data = urb->transfer_buffer;
+	char tty_flag = TTY_NORMAL;
+	unsigned long flags;
+	u8 line_status;
+	int i;
+
+	/* update line status */
+	spin_lock_irqsave(&priv->lock, flags);
+	line_status = priv->line_status;
+	priv->line_status &= ~UART_STATE_TRANSIENT_MASK;
+	spin_unlock_irqrestore(&priv->lock, flags);
+	wake_up_interruptible(&port->port.delta_msr_wait);
+
+	if (!urb->actual_length)
+		return;
+
+	/* break takes precedence over parity, */
+	/* which takes precedence over framing errors */
+	if (line_status & UART_BREAK_ERROR)
+		tty_flag = TTY_BREAK;
+	else if (line_status & UART_PARITY_ERROR)
+		tty_flag = TTY_PARITY;
+	else if (line_status & UART_FRAME_ERROR)
+		tty_flag = TTY_FRAME;
+	dev_dbg(&port->dev, "%s - tty_flag = %d\n", __func__, tty_flag);
+
+	/* overrun is special, not associated with a char */
+	if (line_status & UART_OVERRUN_ERROR)
+		tty_insert_flip_char(&port->port, 0, TTY_OVERRUN);
+
+	if (port->port.console && port->sysrq) {
+		for (i = 0; i < urb->actual_length; ++i)
+			if (!usb_serial_handle_sysrq_char(port, data[i]))
+				tty_insert_flip_char(&port->port, data[i],
+						tty_flag);
+	} else {
+		tty_insert_flip_string_fixed_flag(&port->port, data, tty_flag,
+							urb->actual_length);
+	}
+
+	tty_flip_buffer_push(&port->port);
+}
+
+/* All of the device info needed for the PL2303 SIO serial converter */
+static struct usb_serial_driver pl2303_device = {
+	.driver = {
+		.owner =	THIS_MODULE,
+		.name =		"pl2303g",
+	},
+	.id_table =				id_table,
+	.num_ports =			1,
+	.bulk_in_size =			256,
+	.bulk_out_size =		256,
+	.open =					pl2303_open,
+	.close =				pl2303_close,
+	.dtr_rts = 				pl2303_dtr_rts,
+	.carrier_raised =		pl2303_carrier_raised,
+	.ioctl =				pl2303_ioctl,
+	.break_ctl =			pl2303_break_ctl,
+	.set_termios =			pl2303_set_termios,
+	.tiocmget =				pl2303_tiocmget,
+	.tiocmset =				pl2303_tiocmset,
+	.tiocmiwait =			pl2303_tiocmiwait,
+	.process_read_urb =		pl2303_process_read_urb,
+	.read_int_callback =	pl2303_read_int_callback,
+	.attach =				pl2303_startup,
+	.release =				pl2303_release,
+	.port_probe =			pl2303_port_probe,
+	.port_remove =			pl2303_port_remove,
+};
+
+static struct usb_serial_driver * const serial_drivers[] = {
+	&pl2303_device, NULL
+};
+
+module_usb_serial_driver(serial_drivers, id_table);
+
+MODULE_DESCRIPTION(DRIVER_DESC);
+MODULE_LICENSE("GPL");
diff --git a/drivers/usb/serial/pl2303g.h b/drivers/usb/serial/pl2303g.h
new file mode 100644
index 00000000..fab0cbe
--- /dev/null
+++ b/drivers/usb/serial/pl2303g.h
@@ -0,0 +1,186 @@
+/*
+ * Prolific PL2303 USB to serial adaptor driver header file
+ *
+ *	This program is free software; you can redistribute it and/or modify
+ *	it under the terms of the GNU General Public License as published by
+ *	the Free Software Foundation; either version 2 of the License, or
+ *	(at your option) any later version.
+ *
+ */
+
+#define BENQ_VENDOR_ID			0x04a5
+#define BENQ_PRODUCT_ID_S81		0x4027
+
+#define PL2303_VENDOR_ID	0x067b
+#define PL2303_PRODUCT_ID	0x2303
+#define PL2303_PRODUCT_ID_RSAQ2		0x04bb
+#define PL2303_PRODUCT_ID_DCU11		0x1234
+#define PL2303_PRODUCT_ID_PHAROS	0xaaa0
+#define PL2303_PRODUCT_ID_RSAQ3		0xaaa2
+#define PL2303_PRODUCT_ID_ALDIGA	0x0611
+#define PL2303_PRODUCT_ID_MMX		0x0612
+#define PL2303_PRODUCT_ID_GPRS		0x0609
+#define PL2303_PRODUCT_ID_HCR331	0x331a
+#define PL2303_PRODUCT_ID_MOTOROLA	0x0307
+
+/* PL2303N */
+#define PL2303G_PRODUCT_ID_GC	0x23A3
+#define PL2303G_PRODUCT_ID_GB	0x23B3
+#define PL2303G_PRODUCT_ID_GT	0x23C3
+#define PL2303G_PRODUCT_ID_GL	0x23D3
+#define PL2303G_PRODUCT_ID_GE	0x23E3
+#define PL2303G_PRODUCT_ID_GS	0x23F3
+
+#define ATEN_VENDOR_ID		0x0557
+#define ATEN_VENDOR_ID2		0x0547
+#define ATEN_PRODUCT_ID		0x2008
+
+#define IODATA_VENDOR_ID	0x04bb
+#define IODATA_PRODUCT_ID	0x0a03
+#define IODATA_PRODUCT_ID_RSAQ5	0x0a0e
+
+#define ELCOM_VENDOR_ID		0x056e
+#define ELCOM_PRODUCT_ID	0x5003
+#define ELCOM_PRODUCT_ID_UCSGT	0x5004
+
+#define ITEGNO_VENDOR_ID	0x0eba
+#define ITEGNO_PRODUCT_ID	0x1080
+#define ITEGNO_PRODUCT_ID_2080	0x2080
+
+#define MA620_VENDOR_ID		0x0df7
+#define MA620_PRODUCT_ID	0x0620
+
+#define RATOC_VENDOR_ID		0x0584
+#define RATOC_PRODUCT_ID	0xb000
+
+#define TRIPP_VENDOR_ID		0x2478
+#define TRIPP_PRODUCT_ID	0x2008
+
+#define RADIOSHACK_VENDOR_ID	0x1453
+#define RADIOSHACK_PRODUCT_ID	0x4026
+
+#define DCU10_VENDOR_ID		0x0731
+#define DCU10_PRODUCT_ID	0x0528
+
+#define SITECOM_VENDOR_ID	0x6189
+#define SITECOM_PRODUCT_ID	0x2068
+
+/* Alcatel OT535/735 USB cable */
+#define ALCATEL_VENDOR_ID	0x11f7
+#define ALCATEL_PRODUCT_ID	0x02df
+
+/* Samsung I330 phone cradle */
+#define SAMSUNG_VENDOR_ID	0x04e8
+#define SAMSUNG_PRODUCT_ID	0x8001
+
+#define SIEMENS_VENDOR_ID	0x11f5
+#define SIEMENS_PRODUCT_ID_SX1	0x0001
+#define SIEMENS_PRODUCT_ID_X65	0x0003
+#define SIEMENS_PRODUCT_ID_X75	0x0004
+#define SIEMENS_PRODUCT_ID_EF81	0x0005
+
+#define SYNTECH_VENDOR_ID	0x0745
+#define SYNTECH_PRODUCT_ID	0x0001
+
+/* Nokia CA-42 Cable */
+#define NOKIA_CA42_VENDOR_ID	0x078b
+#define NOKIA_CA42_PRODUCT_ID	0x1234
+
+/* CA-42 CLONE Cable www.ca-42.com chipset: Prolific Technology Inc */
+#define CA_42_CA42_VENDOR_ID	0x10b5
+#define CA_42_CA42_PRODUCT_ID	0xac70
+
+#define SAGEM_VENDOR_ID		0x079b
+#define SAGEM_PRODUCT_ID	0x0027
+
+/* Leadtek GPS 9531 (ID 0413:2101) */
+#define LEADTEK_VENDOR_ID	0x0413
+#define LEADTEK_9531_PRODUCT_ID	0x2101
+
+/* USB GSM cable from Speed Dragon Multimedia, Ltd */
+#define SPEEDDRAGON_VENDOR_ID	0x0e55
+#define SPEEDDRAGON_PRODUCT_ID	0x110b
+
+/* DATAPILOT Universal-2 Phone Cable */
+#define DATAPILOT_U2_VENDOR_ID	0x0731
+#define DATAPILOT_U2_PRODUCT_ID	0x2003
+
+/* Belkin "F5U257" Serial Adapter */
+#define BELKIN_VENDOR_ID	0x050d
+#define BELKIN_PRODUCT_ID	0x0257
+
+/* Alcor Micro Corp. USB 2.0 TO RS-232 */
+#define ALCOR_VENDOR_ID		0x058F
+#define ALCOR_PRODUCT_ID	0x9720
+
+/* Willcom WS002IN Data Driver (by NetIndex Inc.) */
+#define WS002IN_VENDOR_ID	0x11f6
+#define WS002IN_PRODUCT_ID	0x2001
+
+/* Corega CG-USBRS232R Serial Adapter */
+#define COREGA_VENDOR_ID	0x07aa
+#define COREGA_PRODUCT_ID	0x002a
+
+/* Y.C. Cable U.S.A., Inc - USB to RS-232 */
+#define YCCABLE_VENDOR_ID	0x05ad
+#define YCCABLE_PRODUCT_ID	0x0fba
+
+/* "Superial" USB - Serial */
+#define SUPERIAL_VENDOR_ID	0x5372
+#define SUPERIAL_PRODUCT_ID	0x2303
+
+/* Hewlett-Packard LD220-HP POS Pole Display */
+#define HP_VENDOR_ID		0x03f0
+#define HP_LD220_PRODUCT_ID	0x3524
+
+/* Cressi Edy (diving computer) PC interface */
+#define CRESSI_VENDOR_ID	0x04b8
+#define CRESSI_EDY_PRODUCT_ID	0x0521
+
+/* Zeagle dive computer interface */
+#define ZEAGLE_VENDOR_ID	0x04b8
+#define ZEAGLE_N2ITION3_PRODUCT_ID	0x0522
+
+/* Sony, USB data cable for CMD-Jxx mobile phones */
+#define SONY_VENDOR_ID		0x054c
+#define SONY_QN3USB_PRODUCT_ID	0x0437
+
+/* Sanwa KB-USB2 multimeter cable (ID: 11ad:0001) */
+#define SANWA_VENDOR_ID		0x11ad
+#define SANWA_PRODUCT_ID	0x0001
+
+/* ADLINK ND-6530 RS232,RS485 and RS422 adapter */
+#define ADLINK_VENDOR_ID		0x0b63
+#define ADLINK_ND6530_PRODUCT_ID	0x6530
+
+/* SMART USB Serial Adapter */
+#define SMART_VENDOR_ID	0x0b8c
+#define SMART_PRODUCT_ID	0x2303
+
+#define GPB_0_OUTPUT_ENABLE	  _IOW(0x81,0,int)
+#define GPB_1_OUTPUT_ENABLE	  _IOW(0x81,1,int)
+#define GPB_2_OUTPUT_ENABLE	  _IOW(0x81,2,int)
+#define GPB_3_OUTPUT_ENABLE	  _IOW(0x81,3,int)
+#define GPB_4_OUTPUT_ENABLE	  _IOW(0x81,4,int)
+#define GPB_5_OUTPUT_ENABLE	  _IOW(0x81,5,int)
+#define GPB_6_OUTPUT_ENABLE	  _IOW(0x81,6,int)
+#define GPB_7_OUTPUT_ENABLE	  _IOW(0x81,7,int)
+
+#define GPB_0_SET_VALUE		_IOW(0x81,8,int)
+#define GPB_1_SET_VALUE		_IOW(0x81,9,int)
+#define GPB_2_SET_VALUE		_IOW(0x81,10,int)
+#define GPB_3_SET_VALUE		_IOW(0x81,11,int)
+#define GPB_4_SET_VALUE		_IOW(0x81,12,int)
+#define GPB_5_SET_VALUE		_IOW(0x81,13,int)
+#define GPB_6_SET_VALUE		_IOW(0x81,14,int)
+#define GPB_7_SET_VALUE		_IOW(0x81,15,int)
+
+
+#define GPB_0_GET_VALUE		_IOR(0x81,16,int)
+#define GPB_1_GET_VALUE		_IOR(0x81,17,int)
+#define GPB_2_GET_VALUE		_IOR(0x81,18,int)
+#define GPB_3_GET_VALUE		_IOR(0x81,19,int)
+#define GPB_4_GET_VALUE		_IOR(0x81,20,int)
+#define GPB_5_GET_VALUE		_IOR(0x81,21,int)
+#define GPB_6_GET_VALUE		_IOR(0x81,22,int)
+#define GPB_7_GET_VALUE		_IOR(0x81,23,int)
\ No newline at end of file
diff --git a/drivers/usb/storage/scsiglue.c b/drivers/usb/storage/scsiglue.c
index 5db1532..27d622c 100644
--- a/drivers/usb/storage/scsiglue.c
+++ b/drivers/usb/storage/scsiglue.c
@@ -439,6 +439,29 @@ void usb_stor_report_bus_reset(struct us_data *us)
 /***********************************************************************
  * /proc/scsi/ functions
  ***********************************************************************/
+#ifdef CONFIG_BUFFALO_SCSI_GUID
+#define GUID(x)			__u32 x[3]
+#define GUID_EQUAL(x, y)	(x[0] == y[0] && x[1] == y[1] && x[2] == y[2])
+#define GUID_CLEAR(x)		x[0] = x[1] = x[2] = 0;
+#define GUID_NONE(x)		(!x[0] && !x[1] && !x[2])
+#define GUID_FORMAT		"%08x%08x%08x"
+#define GUID_ARGS(x)		x[0], x[1], x[2]
+static inline void
+make_guid( __u32 *pg, __u16 vendor, __u16 product, char *serial)
+{
+	pg[0] = (vendor << 16) | product;
+	pg[1] = pg[2] = 0;
+	while (*serial) {
+		pg[1] <<= 4;
+		pg[1] |= pg[2] >> 28;
+		pg[2] <<= 4;
+		if (*serial >= 'a')
+			*serial -= 'a' - 'A';
+		pg[2] |= (*serial <= '9' && *serial >= '0') ? *serial - '0' : *serial - 'A' + 10;
+		serial++;
+	}
+}
+#endif	/* CONFIG_BUFFALO_SCSI_GUID */
 
 static int write_info(struct Scsi_Host *host, char *buffer, int length)
 {
@@ -483,6 +506,34 @@ static int show_info (struct seq_file *m, struct Scsi_Host *host)
 	SPRINTF("     Protocol: %s\n", us->protocol_name);
 	SPRINTF("    Transport: %s\n", us->transport_name);
 
+#ifdef CONFIG_BUFFALO_SCSI_GUID
+	{
+		char serial[USB_STOR_STRING_LEN];       /* serial number */
+
+		GUID(guid);                     /* Global Unique Identifier */
+		GUID_CLEAR(guid);
+		memset(serial,0,sizeof(serial));
+
+		if (us->pusb_dev->descriptor.iSerialNumber /* && !(flags & US_FL_IGNORE_SER)*/)
+			usb_string(us->pusb_dev,
+				   us->pusb_dev->descriptor.iSerialNumber,
+				   serial, sizeof(serial));
+
+		/* Create a GUID for this device */
+		if (us->pusb_dev->descriptor.iSerialNumber && serial[0]) {
+			/* If we have a serial number, and it's a non-NULL string */
+			make_guid(guid, us->pusb_dev->descriptor.idVendor,
+				  us->pusb_dev->descriptor.idProduct, serial);
+		} else {
+			/* We don't have a serial number, so we use 0 */
+			make_guid(guid, us->pusb_dev->descriptor.idVendor,
+				  us->pusb_dev->descriptor.idProduct, "0");
+		}
+		/* show the GUID of the device */
+		SPRINTF("         GUID: " GUID_FORMAT "\n", GUID_ARGS(guid));
+	}
+#endif	/* CONFIG_BUFFALO_SCSI_GUID */
+
 	/* show the device flags */
 	SPRINTF("       Quirks:");
 
diff --git a/drivers/usb/storage/usb.c b/drivers/usb/storage/usb.c
index 5c4fe07..689187f 100644
--- a/drivers/usb/storage/usb.c
+++ b/drivers/usb/storage/usb.c
@@ -58,6 +58,10 @@
 #include <linux/kthread.h>
 #include <linux/mutex.h>
 #include <linux/utsname.h>
+#ifdef CONFIG_USB_ETRON_HCD
+#include <linux/usb.h>
+#include <linux/usb/hcd.h>
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 #include <scsi/scsi.h>
 #include <scsi/scsi_cmnd.h>
@@ -297,6 +301,22 @@ void fill_inquiry_response(struct us_data *us, unsigned char *data,
 }
 EXPORT_SYMBOL_GPL(fill_inquiry_response);
 
+#ifdef CONFIG_USB_ETRON_HCD
+static int usb_stor_no_test_unit_ready(struct us_data *us)
+{
+	struct usb_device *udev = us->pusb_dev;
+
+	if (us->srb->cmnd[0] != TEST_UNIT_READY)
+		return -EINVAL;
+
+	if (udev->descriptor.idVendor != cpu_to_le16(0x1759) ||
+		udev->descriptor.idProduct != cpu_to_le16(0x5002))
+		return -EINVAL;
+
+	return 0;
+}
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 static int usb_stor_control_thread(void * __us)
 {
 	struct us_data *us = (struct us_data *)__us;
@@ -367,6 +387,12 @@ static int usb_stor_control_thread(void * __us)
 			fill_inquiry_response(us, data_ptr, 36);
 			us->srb->result = SAM_STAT_GOOD;
 		}
+#ifdef CONFIG_USB_ETRON_HCD
+		else if (!usb_stor_no_test_unit_ready(us)) {
+			usb_stor_dbg(us, "Ignoring TEST_UNIT_READY command\n");
+			us->srb->result = SAM_STAT_GOOD;
+		}
+#endif /*CONFIG_USB_ETRON_HCD*/
 
 		/* we've got a command, let's do it! */
 		else {
diff --git a/drivers/vhost/Kconfig b/drivers/vhost/Kconfig
index 8b9226d..017a1e8 100644
--- a/drivers/vhost/Kconfig
+++ b/drivers/vhost/Kconfig
@@ -1,6 +1,7 @@
 config VHOST_NET
 	tristate "Host kernel accelerator for virtio net"
 	depends on NET && EVENTFD && (TUN || !TUN) && (MACVTAP || !MACVTAP)
+	select VHOST
 	select VHOST_RING
 	---help---
 	  This kernel module can be loaded in host kernel to accelerate
@@ -13,6 +14,7 @@ config VHOST_NET
 config VHOST_SCSI
 	tristate "VHOST_SCSI TCM fabric driver"
 	depends on TARGET_CORE && EVENTFD && m
+	select VHOST
 	select VHOST_RING
 	default n
 	---help---
@@ -24,3 +26,9 @@ config VHOST_RING
 	---help---
 	  This option is selected by any driver which needs to access
 	  the host side of a virtio ring.
+
+config VHOST
+	tristate
+	---help---
+	  This option is selected by any driver which needs to access
+	  the core of vhost.
diff --git a/drivers/vhost/Makefile b/drivers/vhost/Makefile
index 654e9afb..e0441c3 100644
--- a/drivers/vhost/Makefile
+++ b/drivers/vhost/Makefile
@@ -1,7 +1,8 @@
 obj-$(CONFIG_VHOST_NET) += vhost_net.o
-vhost_net-y := vhost.o net.o
+vhost_net-y := net.o
 
 obj-$(CONFIG_VHOST_SCSI) += vhost_scsi.o
 vhost_scsi-y := scsi.o
 
 obj-$(CONFIG_VHOST_RING) += vringh.o
+obj-$(CONFIG_VHOST)	+= vhost.o
diff --git a/drivers/vhost/net.c b/drivers/vhost/net.c
index b271ddb..e1e22e0 100644
--- a/drivers/vhost/net.c
+++ b/drivers/vhost/net.c
@@ -15,7 +15,6 @@
 #include <linux/moduleparam.h>
 #include <linux/mutex.h>
 #include <linux/workqueue.h>
-#include <linux/rcupdate.h>
 #include <linux/file.h>
 #include <linux/slab.h>
 
@@ -71,7 +70,12 @@ enum {
 };
 
 struct vhost_net_ubuf_ref {
-	struct kref kref;
+	/* refcount follows semantics similar to kref:
+	 *  0: object is released
+	 *  1: no outstanding ubufs
+	 * >1: outstanding ubufs
+	 */
+	atomic_t refcount;
 	wait_queue_head_t wait;
 	struct vhost_virtqueue *vq;
 };
@@ -117,14 +121,6 @@ static void vhost_net_enable_zcopy(int vq)
 	vhost_net_zcopy_mask |= 0x1 << vq;
 }
 
-static void vhost_net_zerocopy_done_signal(struct kref *kref)
-{
-	struct vhost_net_ubuf_ref *ubufs;
-
-	ubufs = container_of(kref, struct vhost_net_ubuf_ref, kref);
-	wake_up(&ubufs->wait);
-}
-
 static struct vhost_net_ubuf_ref *
 vhost_net_ubuf_alloc(struct vhost_virtqueue *vq, bool zcopy)
 {
@@ -135,21 +131,24 @@ vhost_net_ubuf_alloc(struct vhost_virtqueue *vq, bool zcopy)
 	ubufs = kmalloc(sizeof(*ubufs), GFP_KERNEL);
 	if (!ubufs)
 		return ERR_PTR(-ENOMEM);
-	kref_init(&ubufs->kref);
+	atomic_set(&ubufs->refcount, 1);
 	init_waitqueue_head(&ubufs->wait);
 	ubufs->vq = vq;
 	return ubufs;
 }
 
-static void vhost_net_ubuf_put(struct vhost_net_ubuf_ref *ubufs)
+static int vhost_net_ubuf_put(struct vhost_net_ubuf_ref *ubufs)
 {
-	kref_put(&ubufs->kref, vhost_net_zerocopy_done_signal);
+	int r = atomic_sub_return(1, &ubufs->refcount);
+	if (unlikely(!r))
+		wake_up(&ubufs->wait);
+	return r;
 }
 
 static void vhost_net_ubuf_put_and_wait(struct vhost_net_ubuf_ref *ubufs)
 {
-	kref_put(&ubufs->kref, vhost_net_zerocopy_done_signal);
-	wait_event(ubufs->wait, !atomic_read(&ubufs->kref.refcount));
+	vhost_net_ubuf_put(ubufs);
+	wait_event(ubufs->wait, !atomic_read(&ubufs->refcount));
 }
 
 static void vhost_net_ubuf_put_wait_and_free(struct vhost_net_ubuf_ref *ubufs)
@@ -168,7 +167,7 @@ static void vhost_net_clear_ubuf_info(struct vhost_net *n)
 	}
 }
 
-int vhost_net_set_ubuf_info(struct vhost_net *n)
+static int vhost_net_set_ubuf_info(struct vhost_net *n)
 {
 	bool zcopy;
 	int i;
@@ -189,7 +188,7 @@ err:
 	return -ENOMEM;
 }
 
-void vhost_net_vq_reset(struct vhost_net *n)
+static void vhost_net_vq_reset(struct vhost_net *n)
 {
 	int i;
 
@@ -277,12 +276,12 @@ static void copy_iovec_hdr(const struct iovec *from, struct iovec *to,
  * of used idx. Once lower device DMA done contiguously, we will signal KVM
  * guest used idx.
  */
-static int vhost_zerocopy_signal_used(struct vhost_net *net,
-				      struct vhost_virtqueue *vq)
+static void vhost_zerocopy_signal_used(struct vhost_net *net,
+				       struct vhost_virtqueue *vq)
 {
 	struct vhost_net_virtqueue *nvq =
 		container_of(vq, struct vhost_net_virtqueue, vq);
-	int i;
+	int i, add;
 	int j = 0;
 
 	for (i = nvq->done_idx; i != nvq->upend_idx; i = (i + 1) % UIO_MAXIOV) {
@@ -290,38 +289,43 @@ static int vhost_zerocopy_signal_used(struct vhost_net *net,
 			vhost_net_tx_err(net);
 		if (VHOST_DMA_IS_DONE(vq->heads[i].len)) {
 			vq->heads[i].len = VHOST_DMA_CLEAR_LEN;
-			vhost_add_used_and_signal(vq->dev, vq,
-						  vq->heads[i].id, 0);
 			++j;
 		} else
 			break;
 	}
-	if (j)
-		nvq->done_idx = i;
-	return j;
+	while (j) {
+		add = min(UIO_MAXIOV - nvq->done_idx, j);
+		vhost_add_used_and_signal_n(vq->dev, vq,
+					    &vq->heads[nvq->done_idx], add);
+		nvq->done_idx = (nvq->done_idx + add) % UIO_MAXIOV;
+		j -= add;
+	}
 }
 
 static void vhost_zerocopy_callback(struct ubuf_info *ubuf, bool success)
 {
 	struct vhost_net_ubuf_ref *ubufs = ubuf->ctx;
 	struct vhost_virtqueue *vq = ubufs->vq;
-	int cnt = atomic_read(&ubufs->kref.refcount);
+	int cnt;
+
+	rcu_read_lock_bh();
 
 	/* set len to mark this desc buffers done DMA */
 	vq->heads[ubuf->desc].len = success ?
 		VHOST_DMA_DONE_LEN : VHOST_DMA_FAILED_LEN;
-	vhost_net_ubuf_put(ubufs);
+	cnt = vhost_net_ubuf_put(ubufs);
 
 	/*
 	 * Trigger polling thread if guest stopped submitting new buffers:
-	 * in this case, the refcount after decrement will eventually reach 1
-	 * so here it is 2.
+	 * in this case, the refcount after decrement will eventually reach 1.
 	 * We also trigger polling periodically after each 16 packets
 	 * (the value 16 here is more or less arbitrary, it's tuned to trigger
 	 * less than 10% of times).
 	 */
-	if (cnt <= 2 || !(cnt % 16))
+	if (cnt <= 1 || !(cnt % 16))
 		vhost_poll_queue(&vq->poll);
+
+	rcu_read_unlock_bh();
 }
 
 /* Expects to be always run from workqueue - which acts as
@@ -347,12 +351,11 @@ static void handle_tx(struct vhost_net *net)
 	struct vhost_net_ubuf_ref *uninitialized_var(ubufs);
 	bool zcopy, zcopy_used;
 
-	/* TODO: check that we are running from vhost_worker? */
-	sock = rcu_dereference_check(vq->private_data, 1);
+	mutex_lock(&vq->mutex);
+	sock = vq->private_data;
 	if (!sock)
-		return;
+		goto out;
 
-	mutex_lock(&vq->mutex);
 	vhost_disable_notify(&net->dev, vq);
 
 	hdr_size = nvq->vhost_hlen;
@@ -363,6 +366,13 @@ static void handle_tx(struct vhost_net *net)
 		if (zcopy)
 			vhost_zerocopy_signal_used(net, vq);
 
+		/* If more outstanding DMAs, queue the work.
+		 * Handle upend_idx wrap around
+		 */
+		if (unlikely((nvq->upend_idx + vq->num - VHOST_MAX_PEND)
+			      % UIO_MAXIOV == nvq->done_idx))
+			break;
+
 		head = vhost_get_vq_desc(&net->dev, vq, vq->iov,
 					 ARRAY_SIZE(vq->iov),
 					 &out, &in,
@@ -372,17 +382,6 @@ static void handle_tx(struct vhost_net *net)
 			break;
 		/* Nothing new?  Wait for eventfd to tell us they refilled. */
 		if (head == vq->num) {
-			int num_pends;
-
-			/* If more outstanding DMAs, queue the work.
-			 * Handle upend_idx wrap around
-			 */
-			num_pends = likely(nvq->upend_idx >= nvq->done_idx) ?
-				    (nvq->upend_idx - nvq->done_idx) :
-				    (nvq->upend_idx + UIO_MAXIOV -
-				     nvq->done_idx);
-			if (unlikely(num_pends > VHOST_MAX_PEND))
-				break;
 			if (unlikely(vhost_enable_notify(&net->dev, vq))) {
 				vhost_disable_notify(&net->dev, vq);
 				continue;
@@ -405,43 +404,36 @@ static void handle_tx(struct vhost_net *net)
 			       iov_length(nvq->hdr, s), hdr_size);
 			break;
 		}
-		zcopy_used = zcopy && (len >= VHOST_GOODCOPY_LEN ||
-				       nvq->upend_idx != nvq->done_idx);
+
+		zcopy_used = zcopy && len >= VHOST_GOODCOPY_LEN
+				   && (nvq->upend_idx + 1) % UIO_MAXIOV !=
+				      nvq->done_idx
+				   && vhost_net_tx_select_zcopy(net);
 
 		/* use msg_control to pass vhost zerocopy ubuf info to skb */
 		if (zcopy_used) {
+			struct ubuf_info *ubuf;
+			ubuf = nvq->ubuf_info + nvq->upend_idx;
+
 			vq->heads[nvq->upend_idx].id = head;
-			if (!vhost_net_tx_select_zcopy(net) ||
-			    len < VHOST_GOODCOPY_LEN) {
-				/* copy don't need to wait for DMA done */
-				vq->heads[nvq->upend_idx].len =
-							VHOST_DMA_DONE_LEN;
-				msg.msg_control = NULL;
-				msg.msg_controllen = 0;
-				ubufs = NULL;
-			} else {
-				struct ubuf_info *ubuf;
-				ubuf = nvq->ubuf_info + nvq->upend_idx;
-
-				vq->heads[nvq->upend_idx].len =
-					VHOST_DMA_IN_PROGRESS;
-				ubuf->callback = vhost_zerocopy_callback;
-				ubuf->ctx = nvq->ubufs;
-				ubuf->desc = nvq->upend_idx;
-				msg.msg_control = ubuf;
-				msg.msg_controllen = sizeof(ubuf);
-				ubufs = nvq->ubufs;
-				kref_get(&ubufs->kref);
-			}
+			vq->heads[nvq->upend_idx].len = VHOST_DMA_IN_PROGRESS;
+			ubuf->callback = vhost_zerocopy_callback;
+			ubuf->ctx = nvq->ubufs;
+			ubuf->desc = nvq->upend_idx;
+			msg.msg_control = ubuf;
+			msg.msg_controllen = sizeof(ubuf);
+			ubufs = nvq->ubufs;
+			atomic_inc(&ubufs->refcount);
 			nvq->upend_idx = (nvq->upend_idx + 1) % UIO_MAXIOV;
-		} else
+		} else {
 			msg.msg_control = NULL;
+			ubufs = NULL;
+		}
 		/* TODO: Check specific error and bomb out unless ENOBUFS? */
 		err = sock->ops->sendmsg(NULL, sock, &msg, len);
 		if (unlikely(err < 0)) {
 			if (zcopy_used) {
-				if (ubufs)
-					vhost_net_ubuf_put(ubufs);
+				vhost_net_ubuf_put(ubufs);
 				nvq->upend_idx = ((unsigned)nvq->upend_idx - 1)
 					% UIO_MAXIOV;
 			}
@@ -462,7 +454,7 @@ static void handle_tx(struct vhost_net *net)
 			break;
 		}
 	}
-
+out:
 	mutex_unlock(&vq->mutex);
 }
 
@@ -505,7 +497,7 @@ static int get_rx_bufs(struct vhost_virtqueue *vq,
 	unsigned int out, in;
 	int seg = 0;
 	int headcount = 0;
-	int d;
+	unsigned d;
 	int r, nlogs = 0;
 
 	while (datalen > 0 && headcount < quota) {
@@ -513,13 +505,13 @@ static int get_rx_bufs(struct vhost_virtqueue *vq,
 			r = -ENOBUFS;
 			goto err;
 		}
-		d = vhost_get_vq_desc(vq->dev, vq, vq->iov + seg,
+		r = vhost_get_vq_desc(vq->dev, vq, vq->iov + seg,
 				      ARRAY_SIZE(vq->iov) - seg, &out,
 				      &in, log, log_num);
-		if (unlikely(d < 0)) {
-			r = d;
+		if (unlikely(r < 0))
 			goto err;
-		}
+
+		d = r;
 		if (d == vq->num) {
 			r = 0;
 			goto err;
@@ -544,6 +536,12 @@ static int get_rx_bufs(struct vhost_virtqueue *vq,
 	*iovcount = seg;
 	if (unlikely(log))
 		*log_num = nlogs;
+
+	/* Detect overrun */
+	if (unlikely(datalen > 0)) {
+		r = UIO_MAXIOV + 1;
+		goto err;
+	}
 	return headcount;
 err:
 	vhost_discard_vq_desc(vq, headcount);
@@ -575,14 +573,14 @@ static void handle_rx(struct vhost_net *net)
 	s16 headcount;
 	size_t vhost_hlen, sock_hlen;
 	size_t vhost_len, sock_len;
-	/* TODO: check that we are running from vhost_worker? */
-	struct socket *sock = rcu_dereference_check(vq->private_data, 1);
-
-	if (!sock)
-		return;
+	struct socket *sock;
 
 	mutex_lock(&vq->mutex);
+	sock = vq->private_data;
+	if (!sock)
+		goto out;
 	vhost_disable_notify(&net->dev, vq);
+
 	vhost_hlen = nvq->vhost_hlen;
 	sock_hlen = nvq->sock_hlen;
 
@@ -599,6 +597,14 @@ static void handle_rx(struct vhost_net *net)
 		/* On error, stop handling until the next kick. */
 		if (unlikely(headcount < 0))
 			break;
+		/* On overrun, truncate and discard */
+		if (unlikely(headcount > UIO_MAXIOV)) {
+			msg.msg_iovlen = 1;
+			err = sock->ops->recvmsg(NULL, sock, &msg,
+						 1, MSG_DONTWAIT | MSG_TRUNC);
+			pr_debug("Discarded rx packet: len %zd\n", sock_len);
+			continue;
+		}
 		/* OK, now we need to know about added descriptors. */
 		if (!headcount) {
 			if (unlikely(vhost_enable_notify(&net->dev, vq))) {
@@ -657,7 +663,7 @@ static void handle_rx(struct vhost_net *net)
 			break;
 		}
 	}
-
+out:
 	mutex_unlock(&vq->mutex);
 }
 
@@ -698,7 +704,7 @@ static int vhost_net_open(struct inode *inode, struct file *f)
 	struct vhost_net *n = kmalloc(sizeof *n, GFP_KERNEL);
 	struct vhost_dev *dev;
 	struct vhost_virtqueue **vqs;
-	int r, i;
+	int i;
 
 	if (!n)
 		return -ENOMEM;
@@ -721,12 +727,7 @@ static int vhost_net_open(struct inode *inode, struct file *f)
 		n->vqs[i].vhost_hlen = 0;
 		n->vqs[i].sock_hlen = 0;
 	}
-	r = vhost_dev_init(dev, vqs, VHOST_NET_VQ_MAX);
-	if (r < 0) {
-		kfree(n);
-		kfree(vqs);
-		return r;
-	}
+	vhost_dev_init(dev, vqs, VHOST_NET_VQ_MAX);
 
 	vhost_poll_init(n->poll + VHOST_NET_VQ_TX, handle_tx_net, POLLOUT, dev);
 	vhost_poll_init(n->poll + VHOST_NET_VQ_RX, handle_rx_net, POLLIN, dev);
@@ -755,8 +756,7 @@ static int vhost_net_enable_vq(struct vhost_net *n,
 	struct vhost_poll *poll = n->poll + (nvq - n->vqs);
 	struct socket *sock;
 
-	sock = rcu_dereference_protected(vq->private_data,
-					 lockdep_is_held(&vq->mutex));
+	sock = vq->private_data;
 	if (!sock)
 		return 0;
 
@@ -769,10 +769,9 @@ static struct socket *vhost_net_stop_vq(struct vhost_net *n,
 	struct socket *sock;
 
 	mutex_lock(&vq->mutex);
-	sock = rcu_dereference_protected(vq->private_data,
-					 lockdep_is_held(&vq->mutex));
+	sock = vq->private_data;
 	vhost_net_disable_vq(n, vq);
-	rcu_assign_pointer(vq->private_data, NULL);
+	vq->private_data = NULL;
 	mutex_unlock(&vq->mutex);
 	return sock;
 }
@@ -802,7 +801,7 @@ static void vhost_net_flush(struct vhost_net *n)
 		vhost_net_ubuf_put_and_wait(n->vqs[VHOST_NET_VQ_TX].ubufs);
 		mutex_lock(&n->vqs[VHOST_NET_VQ_TX].vq.mutex);
 		n->tx_flush = false;
-		kref_init(&n->vqs[VHOST_NET_VQ_TX].ubufs->kref);
+		atomic_set(&n->vqs[VHOST_NET_VQ_TX].ubufs->refcount, 1);
 		mutex_unlock(&n->vqs[VHOST_NET_VQ_TX].vq.mutex);
 	}
 }
@@ -822,6 +821,8 @@ static int vhost_net_release(struct inode *inode, struct file *f)
 		fput(tx_sock->file);
 	if (rx_sock)
 		fput(rx_sock->file);
+	/* Make sure no callbacks are outstanding */
+	synchronize_rcu_bh();
 	/* We do an extra flush before freeing memory,
 	 * since jobs can re-queue themselves. */
 	vhost_net_flush(n);
@@ -928,8 +929,7 @@ static long vhost_net_set_backend(struct vhost_net *n, unsigned index, int fd)
 	}
 
 	/* start polling new socket */
-	oldsock = rcu_dereference_protected(vq->private_data,
-					    lockdep_is_held(&vq->mutex));
+	oldsock = vq->private_data;
 	if (sock != oldsock) {
 		ubufs = vhost_net_ubuf_alloc(vq,
 					     sock && vhost_sock_zcopy(sock));
@@ -939,7 +939,7 @@ static long vhost_net_set_backend(struct vhost_net *n, unsigned index, int fd)
 		}
 
 		vhost_net_disable_vq(n, vq);
-		rcu_assign_pointer(vq->private_data, sock);
+		vq->private_data = sock;
 		r = vhost_init_used(vq);
 		if (r)
 			goto err_used;
@@ -973,7 +973,7 @@ static long vhost_net_set_backend(struct vhost_net *n, unsigned index, int fd)
 	return 0;
 
 err_used:
-	rcu_assign_pointer(vq->private_data, oldsock);
+	vq->private_data = oldsock;
 	vhost_net_enable_vq(n, vq);
 	if (ubufs)
 		vhost_net_ubuf_put_wait_and_free(ubufs);
diff --git a/drivers/vhost/scsi.c b/drivers/vhost/scsi.c
index 962c7e3..8f48f2b 100644
--- a/drivers/vhost/scsi.c
+++ b/drivers/vhost/scsi.c
@@ -1,12 +1,12 @@
 /*******************************************************************************
  * Vhost kernel TCM fabric driver for virtio SCSI initiators
  *
- * (C) Copyright 2010-2012 RisingTide Systems LLC.
+ * (C) Copyright 2010-2013 Datera, Inc.
  * (C) Copyright 2010-2012 IBM Corp.
  *
  * Licensed to the Linux Foundation under the General Public License (GPL) version 2.
  *
- * Authors: Nicholas A. Bellinger <nab@risingtidesystems.com>
+ * Authors: Nicholas A. Bellinger <nab@daterainc.com>
  *          Stefan Hajnoczi <stefanha@linux.vnet.ibm.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,13 +48,16 @@
 #include <linux/virtio_scsi.h>
 #include <linux/llist.h>
 #include <linux/bitmap.h>
+#include <linux/percpu_ida.h>
 
-#include "vhost.c"
 #include "vhost.h"
 
 #define TCM_VHOST_VERSION  "v0.1"
 #define TCM_VHOST_NAMELEN 256
 #define TCM_VHOST_MAX_CDB_SIZE 32
+#define TCM_VHOST_DEFAULT_TAGS 256
+#define TCM_VHOST_PREALLOC_SGLS 2048
+#define TCM_VHOST_PREALLOC_PAGES 2048
 
 struct vhost_scsi_inflight {
 	/* Wait for the flush operation to finish */
@@ -80,6 +83,7 @@ struct tcm_vhost_cmd {
 	u32 tvc_lun;
 	/* Pointer to the SGL formatted memory from virtio-scsi */
 	struct scatterlist *tvc_sgl;
+	struct page **tvc_upages;
 	/* Pointer to response */
 	struct virtio_scsi_cmd_resp __user *tvc_resp;
 	/* Pointer to vhost_scsi for our device */
@@ -116,7 +120,6 @@ struct tcm_vhost_nacl {
 	struct se_node_acl se_node_acl;
 };
 
-struct vhost_scsi;
 struct tcm_vhost_tpg {
 	/* Vhost port target portal group tag for TCM */
 	u16 tport_tpgt;
@@ -218,7 +221,7 @@ static int iov_num_pages(struct iovec *iov)
 	       ((unsigned long)iov->iov_base & PAGE_MASK)) >> PAGE_SHIFT;
 }
 
-void tcm_vhost_done_inflight(struct kref *kref)
+static void tcm_vhost_done_inflight(struct kref *kref)
 {
 	struct vhost_scsi_inflight *inflight;
 
@@ -329,11 +332,12 @@ static u32 tcm_vhost_get_default_depth(struct se_portal_group *se_tpg)
 	return 1;
 }
 
-static u32 tcm_vhost_get_pr_transport_id(struct se_portal_group *se_tpg,
-	struct se_node_acl *se_nacl,
-	struct t10_pr_registration *pr_reg,
-	int *format_code,
-	unsigned char *buf)
+static u32
+tcm_vhost_get_pr_transport_id(struct se_portal_group *se_tpg,
+			      struct se_node_acl *se_nacl,
+			      struct t10_pr_registration *pr_reg,
+			      int *format_code,
+			      unsigned char *buf)
 {
 	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
@@ -359,10 +363,11 @@ static u32 tcm_vhost_get_pr_transport_id(struct se_portal_group *se_tpg,
 			format_code, buf);
 }
 
-static u32 tcm_vhost_get_pr_transport_id_len(struct se_portal_group *se_tpg,
-	struct se_node_acl *se_nacl,
-	struct t10_pr_registration *pr_reg,
-	int *format_code)
+static u32
+tcm_vhost_get_pr_transport_id_len(struct se_portal_group *se_tpg,
+				  struct se_node_acl *se_nacl,
+				  struct t10_pr_registration *pr_reg,
+				  int *format_code)
 {
 	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
@@ -388,10 +393,11 @@ static u32 tcm_vhost_get_pr_transport_id_len(struct se_portal_group *se_tpg,
 			format_code);
 }
 
-static char *tcm_vhost_parse_pr_out_transport_id(struct se_portal_group *se_tpg,
-	const char *buf,
-	u32 *out_tid_len,
-	char **port_nexus_ptr)
+static char *
+tcm_vhost_parse_pr_out_transport_id(struct se_portal_group *se_tpg,
+				    const char *buf,
+				    u32 *out_tid_len,
+				    char **port_nexus_ptr)
 {
 	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
@@ -417,8 +423,8 @@ static char *tcm_vhost_parse_pr_out_transport_id(struct se_portal_group *se_tpg,
 			port_nexus_ptr);
 }
 
-static struct se_node_acl *tcm_vhost_alloc_fabric_acl(
-	struct se_portal_group *se_tpg)
+static struct se_node_acl *
+tcm_vhost_alloc_fabric_acl(struct se_portal_group *se_tpg)
 {
 	struct tcm_vhost_nacl *nacl;
 
@@ -431,8 +437,9 @@ static struct se_node_acl *tcm_vhost_alloc_fabric_acl(
 	return &nacl->se_node_acl;
 }
 
-static void tcm_vhost_release_fabric_acl(struct se_portal_group *se_tpg,
-	struct se_node_acl *se_nacl)
+static void
+tcm_vhost_release_fabric_acl(struct se_portal_group *se_tpg,
+			     struct se_node_acl *se_nacl)
 {
 	struct tcm_vhost_nacl *nacl = container_of(se_nacl,
 			struct tcm_vhost_nacl, se_node_acl);
@@ -446,7 +453,18 @@ static u32 tcm_vhost_tpg_get_inst_index(struct se_portal_group *se_tpg)
 
 static void tcm_vhost_release_cmd(struct se_cmd *se_cmd)
 {
-	return;
+	struct tcm_vhost_cmd *tv_cmd = container_of(se_cmd,
+				struct tcm_vhost_cmd, tvc_se_cmd);
+	struct se_session *se_sess = se_cmd->se_sess;
+
+	if (tv_cmd->tvc_sgl_count) {
+		u32 i;
+		for (i = 0; i < tv_cmd->tvc_sgl_count; i++)
+			put_page(sg_page(&tv_cmd->tvc_sgl[i]));
+	}
+
+	tcm_vhost_put_inflight(tv_cmd->inflight);
+	percpu_ida_free(&se_sess->sess_tag_pool, se_cmd->map_tag);
 }
 
 static int tcm_vhost_shutdown_session(struct se_session *se_sess)
@@ -491,34 +509,39 @@ static int tcm_vhost_get_cmd_state(struct se_cmd *se_cmd)
 	return 0;
 }
 
-static void vhost_scsi_complete_cmd(struct tcm_vhost_cmd *tv_cmd)
+static void vhost_scsi_complete_cmd(struct tcm_vhost_cmd *cmd)
 {
-	struct vhost_scsi *vs = tv_cmd->tvc_vhost;
+	struct vhost_scsi *vs = cmd->tvc_vhost;
 
-	llist_add(&tv_cmd->tvc_completion_list, &vs->vs_completion_list);
+	llist_add(&cmd->tvc_completion_list, &vs->vs_completion_list);
 
 	vhost_work_queue(&vs->dev, &vs->vs_completion_work);
 }
 
 static int tcm_vhost_queue_data_in(struct se_cmd *se_cmd)
 {
-	struct tcm_vhost_cmd *tv_cmd = container_of(se_cmd,
+	struct tcm_vhost_cmd *cmd = container_of(se_cmd,
 				struct tcm_vhost_cmd, tvc_se_cmd);
-	vhost_scsi_complete_cmd(tv_cmd);
+	vhost_scsi_complete_cmd(cmd);
 	return 0;
 }
 
 static int tcm_vhost_queue_status(struct se_cmd *se_cmd)
 {
-	struct tcm_vhost_cmd *tv_cmd = container_of(se_cmd,
+	struct tcm_vhost_cmd *cmd = container_of(se_cmd,
 				struct tcm_vhost_cmd, tvc_se_cmd);
-	vhost_scsi_complete_cmd(tv_cmd);
+	vhost_scsi_complete_cmd(cmd);
 	return 0;
 }
 
-static int tcm_vhost_queue_tm_rsp(struct se_cmd *se_cmd)
+static void tcm_vhost_queue_tm_rsp(struct se_cmd *se_cmd)
 {
-	return 0;
+	return;
+}
+
+static void tcm_vhost_aborted_task(struct se_cmd *se_cmd)
+{
+	return;
 }
 
 static void tcm_vhost_free_evt(struct vhost_scsi *vs, struct tcm_vhost_evt *evt)
@@ -527,8 +550,9 @@ static void tcm_vhost_free_evt(struct vhost_scsi *vs, struct tcm_vhost_evt *evt)
 	kfree(evt);
 }
 
-static struct tcm_vhost_evt *tcm_vhost_allocate_evt(struct vhost_scsi *vs,
-	u32 event, u32 reason)
+static struct tcm_vhost_evt *
+tcm_vhost_allocate_evt(struct vhost_scsi *vs,
+		       u32 event, u32 reason)
 {
 	struct vhost_virtqueue *vq = &vs->vqs[VHOST_SCSI_VQ_EVT].vq;
 	struct tcm_vhost_evt *evt;
@@ -552,28 +576,22 @@ static struct tcm_vhost_evt *tcm_vhost_allocate_evt(struct vhost_scsi *vs,
 	return evt;
 }
 
-static void vhost_scsi_free_cmd(struct tcm_vhost_cmd *tv_cmd)
+static void vhost_scsi_free_cmd(struct tcm_vhost_cmd *cmd)
 {
-	struct se_cmd *se_cmd = &tv_cmd->tvc_se_cmd;
+	struct se_cmd *se_cmd = &cmd->tvc_se_cmd;
 
 	/* TODO locking against target/backend threads? */
-	transport_generic_free_cmd(se_cmd, 1);
-
-	if (tv_cmd->tvc_sgl_count) {
-		u32 i;
-		for (i = 0; i < tv_cmd->tvc_sgl_count; i++)
-			put_page(sg_page(&tv_cmd->tvc_sgl[i]));
-
-		kfree(tv_cmd->tvc_sgl);
-	}
+	transport_generic_free_cmd(se_cmd, 0);
 
-	tcm_vhost_put_inflight(tv_cmd->inflight);
+}
 
-	kfree(tv_cmd);
+static int vhost_scsi_check_stop_free(struct se_cmd *se_cmd)
+{
+	return target_put_sess_cmd(se_cmd->se_sess, se_cmd);
 }
 
-static void tcm_vhost_do_evt_work(struct vhost_scsi *vs,
-	struct tcm_vhost_evt *evt)
+static void
+tcm_vhost_do_evt_work(struct vhost_scsi *vs, struct tcm_vhost_evt *evt)
 {
 	struct vhost_virtqueue *vq = &vs->vqs[VHOST_SCSI_VQ_EVT].vq;
 	struct virtio_scsi_event *event = &evt->event;
@@ -652,7 +670,7 @@ static void vhost_scsi_complete_cmd_work(struct vhost_work *work)
 					vs_completion_work);
 	DECLARE_BITMAP(signal, VHOST_SCSI_MAX_VQ);
 	struct virtio_scsi_cmd_resp v_rsp;
-	struct tcm_vhost_cmd *tv_cmd;
+	struct tcm_vhost_cmd *cmd;
 	struct llist_node *llnode;
 	struct se_cmd *se_cmd;
 	int ret, vq;
@@ -660,32 +678,32 @@ static void vhost_scsi_complete_cmd_work(struct vhost_work *work)
 	bitmap_zero(signal, VHOST_SCSI_MAX_VQ);
 	llnode = llist_del_all(&vs->vs_completion_list);
 	while (llnode) {
-		tv_cmd = llist_entry(llnode, struct tcm_vhost_cmd,
+		cmd = llist_entry(llnode, struct tcm_vhost_cmd,
 				     tvc_completion_list);
 		llnode = llist_next(llnode);
-		se_cmd = &tv_cmd->tvc_se_cmd;
+		se_cmd = &cmd->tvc_se_cmd;
 
 		pr_debug("%s tv_cmd %p resid %u status %#02x\n", __func__,
-			tv_cmd, se_cmd->residual_count, se_cmd->scsi_status);
+			cmd, se_cmd->residual_count, se_cmd->scsi_status);
 
 		memset(&v_rsp, 0, sizeof(v_rsp));
 		v_rsp.resid = se_cmd->residual_count;
 		/* TODO is status_qualifier field needed? */
 		v_rsp.status = se_cmd->scsi_status;
 		v_rsp.sense_len = se_cmd->scsi_sense_length;
-		memcpy(v_rsp.sense, tv_cmd->tvc_sense_buf,
+		memcpy(v_rsp.sense, cmd->tvc_sense_buf,
 		       v_rsp.sense_len);
-		ret = copy_to_user(tv_cmd->tvc_resp, &v_rsp, sizeof(v_rsp));
+		ret = copy_to_user(cmd->tvc_resp, &v_rsp, sizeof(v_rsp));
 		if (likely(ret == 0)) {
 			struct vhost_scsi_virtqueue *q;
-			vhost_add_used(tv_cmd->tvc_vq, tv_cmd->tvc_vq_desc, 0);
-			q = container_of(tv_cmd->tvc_vq, struct vhost_scsi_virtqueue, vq);
+			vhost_add_used(cmd->tvc_vq, cmd->tvc_vq_desc, 0);
+			q = container_of(cmd->tvc_vq, struct vhost_scsi_virtqueue, vq);
 			vq = q - vs->vqs;
 			__set_bit(vq, signal);
 		} else
 			pr_err("Faulted on virtio_scsi_cmd_resp\n");
 
-		vhost_scsi_free_cmd(tv_cmd);
+		vhost_scsi_free_cmd(cmd);
 	}
 
 	vq = -1;
@@ -694,35 +712,49 @@ static void vhost_scsi_complete_cmd_work(struct vhost_work *work)
 		vhost_signal(&vs->dev, &vs->vqs[vq].vq);
 }
 
-static struct tcm_vhost_cmd *vhost_scsi_allocate_cmd(
-	struct vhost_virtqueue *vq,
-	struct tcm_vhost_tpg *tv_tpg,
-	struct virtio_scsi_cmd_req *v_req,
-	u32 exp_data_len,
-	int data_direction)
+static struct tcm_vhost_cmd *
+vhost_scsi_get_tag(struct vhost_virtqueue *vq,
+			struct tcm_vhost_tpg *tpg,
+			struct virtio_scsi_cmd_req *v_req,
+			u32 exp_data_len,
+			int data_direction)
 {
-	struct tcm_vhost_cmd *tv_cmd;
+	struct tcm_vhost_cmd *cmd;
 	struct tcm_vhost_nexus *tv_nexus;
+	struct se_session *se_sess;
+	struct scatterlist *sg;
+	struct page **pages;
+	int tag;
 
-	tv_nexus = tv_tpg->tpg_nexus;
+	tv_nexus = tpg->tpg_nexus;
 	if (!tv_nexus) {
 		pr_err("Unable to locate active struct tcm_vhost_nexus\n");
 		return ERR_PTR(-EIO);
 	}
+	se_sess = tv_nexus->tvn_se_sess;
 
-	tv_cmd = kzalloc(sizeof(struct tcm_vhost_cmd), GFP_ATOMIC);
-	if (!tv_cmd) {
-		pr_err("Unable to allocate struct tcm_vhost_cmd\n");
+	tag = percpu_ida_alloc(&se_sess->sess_tag_pool, TASK_RUNNING);
+	if (tag < 0) {
+		pr_err("Unable to obtain tag for tcm_vhost_cmd\n");
 		return ERR_PTR(-ENOMEM);
 	}
-	tv_cmd->tvc_tag = v_req->tag;
-	tv_cmd->tvc_task_attr = v_req->task_attr;
-	tv_cmd->tvc_exp_data_len = exp_data_len;
-	tv_cmd->tvc_data_direction = data_direction;
-	tv_cmd->tvc_nexus = tv_nexus;
-	tv_cmd->inflight = tcm_vhost_get_inflight(vq);
 
-	return tv_cmd;
+	cmd = &((struct tcm_vhost_cmd *)se_sess->sess_cmd_map)[tag];
+	sg = cmd->tvc_sgl;
+	pages = cmd->tvc_upages;
+	memset(cmd, 0, sizeof(struct tcm_vhost_cmd));
+
+	cmd->tvc_sgl = sg;
+	cmd->tvc_upages = pages;
+	cmd->tvc_se_cmd.map_tag = tag;
+	cmd->tvc_tag = v_req->tag;
+	cmd->tvc_task_attr = v_req->task_attr;
+	cmd->tvc_exp_data_len = exp_data_len;
+	cmd->tvc_data_direction = data_direction;
+	cmd->tvc_nexus = tv_nexus;
+	cmd->inflight = tcm_vhost_get_inflight(vq);
+
+	return cmd;
 }
 
 /*
@@ -730,8 +762,12 @@ static struct tcm_vhost_cmd *vhost_scsi_allocate_cmd(
  *
  * Returns the number of scatterlist entries used or -errno on error.
  */
-static int vhost_scsi_map_to_sgl(struct scatterlist *sgl,
-	unsigned int sgl_count, struct iovec *iov, int write)
+static int
+vhost_scsi_map_to_sgl(struct tcm_vhost_cmd *tv_cmd,
+		      struct scatterlist *sgl,
+		      unsigned int sgl_count,
+		      struct iovec *iov,
+		      int write)
 {
 	unsigned int npages = 0, pages_nr, offset, nbytes;
 	struct scatterlist *sg = sgl;
@@ -740,13 +776,25 @@ static int vhost_scsi_map_to_sgl(struct scatterlist *sgl,
 	struct page **pages;
 	int ret, i;
 
+	if (sgl_count > TCM_VHOST_PREALLOC_SGLS) {
+		pr_err("vhost_scsi_map_to_sgl() psgl_count: %u greater than"
+		       " preallocated TCM_VHOST_PREALLOC_SGLS: %u\n",
+			sgl_count, TCM_VHOST_PREALLOC_SGLS);
+		return -ENOBUFS;
+	}
+
 	pages_nr = iov_num_pages(iov);
 	if (pages_nr > sgl_count)
 		return -ENOBUFS;
 
-	pages = kmalloc(pages_nr * sizeof(struct page *), GFP_KERNEL);
-	if (!pages)
-		return -ENOMEM;
+	if (pages_nr > TCM_VHOST_PREALLOC_PAGES) {
+		pr_err("vhost_scsi_map_to_sgl() pages_nr: %u greater than"
+		       " preallocated TCM_VHOST_PREALLOC_PAGES: %u\n",
+			pages_nr, TCM_VHOST_PREALLOC_PAGES);
+		return -ENOBUFS;
+	}
+
+	pages = tv_cmd->tvc_upages;
 
 	ret = get_user_pages_fast((unsigned long)ptr, pages_nr, write, pages);
 	/* No pages were pinned */
@@ -771,12 +819,14 @@ static int vhost_scsi_map_to_sgl(struct scatterlist *sgl,
 	}
 
 out:
-	kfree(pages);
 	return ret;
 }
 
-static int vhost_scsi_map_iov_to_sgl(struct tcm_vhost_cmd *tv_cmd,
-	struct iovec *iov, unsigned int niov, int write)
+static int
+vhost_scsi_map_iov_to_sgl(struct tcm_vhost_cmd *cmd,
+			  struct iovec *iov,
+			  unsigned int niov,
+			  int write)
 {
 	int ret;
 	unsigned int i;
@@ -792,25 +842,21 @@ static int vhost_scsi_map_iov_to_sgl(struct tcm_vhost_cmd *tv_cmd,
 
 	/* TODO overflow checking */
 
-	sg = kmalloc(sizeof(tv_cmd->tvc_sgl[0]) * sgl_count, GFP_ATOMIC);
-	if (!sg)
-		return -ENOMEM;
-	pr_debug("%s sg %p sgl_count %u is_err %d\n", __func__,
-	       sg, sgl_count, !sg);
+	sg = cmd->tvc_sgl;
+	pr_debug("%s sg %p sgl_count %u\n", __func__, sg, sgl_count);
 	sg_init_table(sg, sgl_count);
 
-	tv_cmd->tvc_sgl = sg;
-	tv_cmd->tvc_sgl_count = sgl_count;
+	cmd->tvc_sgl_count = sgl_count;
 
 	pr_debug("Mapping %u iovecs for %u pages\n", niov, sgl_count);
 	for (i = 0; i < niov; i++) {
-		ret = vhost_scsi_map_to_sgl(sg, sgl_count, &iov[i], write);
+		ret = vhost_scsi_map_to_sgl(cmd, sg, sgl_count, &iov[i],
+					    write);
 		if (ret < 0) {
-			for (i = 0; i < tv_cmd->tvc_sgl_count; i++)
-				put_page(sg_page(&tv_cmd->tvc_sgl[i]));
-			kfree(tv_cmd->tvc_sgl);
-			tv_cmd->tvc_sgl = NULL;
-			tv_cmd->tvc_sgl_count = 0;
+			for (i = 0; i < cmd->tvc_sgl_count; i++)
+				put_page(sg_page(&cmd->tvc_sgl[i]));
+
+			cmd->tvc_sgl_count = 0;
 			return ret;
 		}
 
@@ -820,17 +866,34 @@ static int vhost_scsi_map_iov_to_sgl(struct tcm_vhost_cmd *tv_cmd,
 	return 0;
 }
 
+static int vhost_scsi_to_tcm_attr(int attr)
+{
+	switch (attr) {
+	case VIRTIO_SCSI_S_SIMPLE:
+		return MSG_SIMPLE_TAG;
+	case VIRTIO_SCSI_S_ORDERED:
+		return MSG_ORDERED_TAG;
+	case VIRTIO_SCSI_S_HEAD:
+		return MSG_HEAD_TAG;
+	case VIRTIO_SCSI_S_ACA:
+		return MSG_ACA_TAG;
+	default:
+		break;
+	}
+	return MSG_SIMPLE_TAG;
+}
+
 static void tcm_vhost_submission_work(struct work_struct *work)
 {
-	struct tcm_vhost_cmd *tv_cmd =
+	struct tcm_vhost_cmd *cmd =
 		container_of(work, struct tcm_vhost_cmd, work);
 	struct tcm_vhost_nexus *tv_nexus;
-	struct se_cmd *se_cmd = &tv_cmd->tvc_se_cmd;
+	struct se_cmd *se_cmd = &cmd->tvc_se_cmd;
 	struct scatterlist *sg_ptr, *sg_bidi_ptr = NULL;
 	int rc, sg_no_bidi = 0;
 
-	if (tv_cmd->tvc_sgl_count) {
-		sg_ptr = tv_cmd->tvc_sgl;
+	if (cmd->tvc_sgl_count) {
+		sg_ptr = cmd->tvc_sgl;
 /* FIXME: Fix BIDI operation in tcm_vhost_submission_work() */
 #if 0
 		if (se_cmd->se_cmd_flags & SCF_BIDI) {
@@ -841,14 +904,15 @@ static void tcm_vhost_submission_work(struct work_struct *work)
 	} else {
 		sg_ptr = NULL;
 	}
-	tv_nexus = tv_cmd->tvc_nexus;
+	tv_nexus = cmd->tvc_nexus;
 
 	rc = target_submit_cmd_map_sgls(se_cmd, tv_nexus->tvn_se_sess,
-			tv_cmd->tvc_cdb, &tv_cmd->tvc_sense_buf[0],
-			tv_cmd->tvc_lun, tv_cmd->tvc_exp_data_len,
-			tv_cmd->tvc_task_attr, tv_cmd->tvc_data_direction,
-			0, sg_ptr, tv_cmd->tvc_sgl_count,
-			sg_bidi_ptr, sg_no_bidi);
+			cmd->tvc_cdb, &cmd->tvc_sense_buf[0],
+			cmd->tvc_lun, cmd->tvc_exp_data_len,
+			vhost_scsi_to_tcm_attr(cmd->tvc_task_attr),
+			cmd->tvc_data_direction, TARGET_SCF_ACK_KREF,
+			sg_ptr, cmd->tvc_sgl_count, sg_bidi_ptr, sg_no_bidi,
+			NULL, 0);
 	if (rc < 0) {
 		transport_send_check_condition_and_sense(se_cmd,
 				TCM_LOGICAL_UNIT_COMMUNICATION_FAILURE, 0);
@@ -856,8 +920,10 @@ static void tcm_vhost_submission_work(struct work_struct *work)
 	}
 }
 
-static void vhost_scsi_send_bad_target(struct vhost_scsi *vs,
-	struct vhost_virtqueue *vq, int head, unsigned out)
+static void
+vhost_scsi_send_bad_target(struct vhost_scsi *vs,
+			   struct vhost_virtqueue *vq,
+			   int head, unsigned out)
 {
 	struct virtio_scsi_cmd_resp __user *resp;
 	struct virtio_scsi_cmd_resp rsp;
@@ -873,31 +939,27 @@ static void vhost_scsi_send_bad_target(struct vhost_scsi *vs,
 		pr_err("Faulted on virtio_scsi_cmd_resp\n");
 }
 
-static void vhost_scsi_handle_vq(struct vhost_scsi *vs,
-	struct vhost_virtqueue *vq)
+static void
+vhost_scsi_handle_vq(struct vhost_scsi *vs, struct vhost_virtqueue *vq)
 {
 	struct tcm_vhost_tpg **vs_tpg;
 	struct virtio_scsi_cmd_req v_req;
-	struct tcm_vhost_tpg *tv_tpg;
-	struct tcm_vhost_cmd *tv_cmd;
+	struct tcm_vhost_tpg *tpg;
+	struct tcm_vhost_cmd *cmd;
 	u32 exp_data_len, data_first, data_num, data_direction;
 	unsigned out, in, i;
 	int head, ret;
 	u8 target;
 
+	mutex_lock(&vq->mutex);
 	/*
 	 * We can handle the vq only after the endpoint is setup by calling the
 	 * VHOST_SCSI_SET_ENDPOINT ioctl.
-	 *
-	 * TODO: Check that we are running from vhost_worker which acts
-	 * as read-side critical section for vhost kind of RCU.
-	 * See the comments in struct vhost_virtqueue in drivers/vhost/vhost.h
 	 */
-	vs_tpg = rcu_dereference_check(vq->private_data, 1);
+	vs_tpg = vq->private_data;
 	if (!vs_tpg)
-		return;
+		goto out;
 
-	mutex_lock(&vq->mutex);
 	vhost_disable_notify(&vs->dev, vq);
 
 	for (;;) {
@@ -962,12 +1024,18 @@ static void vhost_scsi_handle_vq(struct vhost_scsi *vs,
 			break;
 		}
 
+		/* virtio-scsi spec requires byte 0 of the lun to be 1 */
+		if (unlikely(v_req.lun[0] != 1)) {
+			vhost_scsi_send_bad_target(vs, vq, head, out);
+			continue;
+		}
+
 		/* Extract the tpgt */
 		target = v_req.lun[1];
-		tv_tpg = ACCESS_ONCE(vs_tpg[target]);
+		tpg = ACCESS_ONCE(vs_tpg[target]);
 
 		/* Target does not exist, fail the request */
-		if (unlikely(!tv_tpg)) {
+		if (unlikely(!tpg)) {
 			vhost_scsi_send_bad_target(vs, vq, head, out);
 			continue;
 		}
@@ -976,46 +1044,46 @@ static void vhost_scsi_handle_vq(struct vhost_scsi *vs,
 		for (i = 0; i < data_num; i++)
 			exp_data_len += vq->iov[data_first + i].iov_len;
 
-		tv_cmd = vhost_scsi_allocate_cmd(vq, tv_tpg, &v_req,
-					exp_data_len, data_direction);
-		if (IS_ERR(tv_cmd)) {
-			vq_err(vq, "vhost_scsi_allocate_cmd failed %ld\n",
-					PTR_ERR(tv_cmd));
+		cmd = vhost_scsi_get_tag(vq, tpg, &v_req,
+					 exp_data_len, data_direction);
+		if (IS_ERR(cmd)) {
+			vq_err(vq, "vhost_scsi_get_tag failed %ld\n",
+					PTR_ERR(cmd));
 			goto err_cmd;
 		}
 		pr_debug("Allocated tv_cmd: %p exp_data_len: %d, data_direction"
-			": %d\n", tv_cmd, exp_data_len, data_direction);
+			": %d\n", cmd, exp_data_len, data_direction);
 
-		tv_cmd->tvc_vhost = vs;
-		tv_cmd->tvc_vq = vq;
-		tv_cmd->tvc_resp = vq->iov[out].iov_base;
+		cmd->tvc_vhost = vs;
+		cmd->tvc_vq = vq;
+		cmd->tvc_resp = vq->iov[out].iov_base;
 
 		/*
-		 * Copy in the recieved CDB descriptor into tv_cmd->tvc_cdb
+		 * Copy in the recieved CDB descriptor into cmd->tvc_cdb
 		 * that will be used by tcm_vhost_new_cmd_map() and down into
 		 * target_setup_cmd_from_cdb()
 		 */
-		memcpy(tv_cmd->tvc_cdb, v_req.cdb, TCM_VHOST_MAX_CDB_SIZE);
+		memcpy(cmd->tvc_cdb, v_req.cdb, TCM_VHOST_MAX_CDB_SIZE);
 		/*
 		 * Check that the recieved CDB size does not exceeded our
 		 * hardcoded max for tcm_vhost
 		 */
 		/* TODO what if cdb was too small for varlen cdb header? */
-		if (unlikely(scsi_command_size(tv_cmd->tvc_cdb) >
+		if (unlikely(scsi_command_size(cmd->tvc_cdb) >
 					TCM_VHOST_MAX_CDB_SIZE)) {
 			vq_err(vq, "Received SCSI CDB with command_size: %d that"
 				" exceeds SCSI_MAX_VARLEN_CDB_SIZE: %d\n",
-				scsi_command_size(tv_cmd->tvc_cdb),
+				scsi_command_size(cmd->tvc_cdb),
 				TCM_VHOST_MAX_CDB_SIZE);
 			goto err_free;
 		}
-		tv_cmd->tvc_lun = ((v_req.lun[2] << 8) | v_req.lun[3]) & 0x3FFF;
+		cmd->tvc_lun = ((v_req.lun[2] << 8) | v_req.lun[3]) & 0x3FFF;
 
 		pr_debug("vhost_scsi got command opcode: %#02x, lun: %d\n",
-			tv_cmd->tvc_cdb[0], tv_cmd->tvc_lun);
+			cmd->tvc_cdb[0], cmd->tvc_lun);
 
 		if (data_direction != DMA_NONE) {
-			ret = vhost_scsi_map_iov_to_sgl(tv_cmd,
+			ret = vhost_scsi_map_iov_to_sgl(cmd,
 					&vq->iov[data_first], data_num,
 					data_direction == DMA_FROM_DEVICE);
 			if (unlikely(ret)) {
@@ -1029,24 +1097,25 @@ static void vhost_scsi_handle_vq(struct vhost_scsi *vs,
 		 * complete the virtio-scsi request in TCM callback context via
 		 * tcm_vhost_queue_data_in() and tcm_vhost_queue_status()
 		 */
-		tv_cmd->tvc_vq_desc = head;
+		cmd->tvc_vq_desc = head;
 		/*
 		 * Dispatch tv_cmd descriptor for cmwq execution in process
 		 * context provided by tcm_vhost_workqueue.  This also ensures
 		 * tv_cmd is executed on the same kworker CPU as this vhost
 		 * thread to gain positive L2 cache locality effects..
 		 */
-		INIT_WORK(&tv_cmd->work, tcm_vhost_submission_work);
-		queue_work(tcm_vhost_workqueue, &tv_cmd->work);
+		INIT_WORK(&cmd->work, tcm_vhost_submission_work);
+		queue_work(tcm_vhost_workqueue, &cmd->work);
 	}
 
 	mutex_unlock(&vq->mutex);
 	return;
 
 err_free:
-	vhost_scsi_free_cmd(tv_cmd);
+	vhost_scsi_free_cmd(cmd);
 err_cmd:
 	vhost_scsi_send_bad_target(vs, vq, head, out);
+out:
 	mutex_unlock(&vq->mutex);
 }
 
@@ -1055,8 +1124,12 @@ static void vhost_scsi_ctl_handle_kick(struct vhost_work *work)
 	pr_debug("%s: The handling func for control queue.\n", __func__);
 }
 
-static void tcm_vhost_send_evt(struct vhost_scsi *vs, struct tcm_vhost_tpg *tpg,
-	struct se_lun *lun, u32 event, u32 reason)
+static void
+tcm_vhost_send_evt(struct vhost_scsi *vs,
+		   struct tcm_vhost_tpg *tpg,
+		   struct se_lun *lun,
+		   u32 event,
+		   u32 reason)
 {
 	struct tcm_vhost_evt *evt;
 
@@ -1071,7 +1144,7 @@ static void tcm_vhost_send_evt(struct vhost_scsi *vs, struct tcm_vhost_tpg *tpg,
 		 * lun[4-7] need to be zero according to virtio-scsi spec.
 		 */
 		evt->event.lun[0] = 0x01;
-		evt->event.lun[1] = tpg->tport_tpgt & 0xFF;
+		evt->event.lun[1] = tpg->tport_tpgt;
 		if (lun->unpacked_lun >= 256)
 			evt->event.lun[2] = lun->unpacked_lun >> 8 | 0x40 ;
 		evt->event.lun[3] = lun->unpacked_lun & 0xFF;
@@ -1146,12 +1219,13 @@ static void vhost_scsi_flush(struct vhost_scsi *vs)
  *  The lock nesting rule is:
  *    tcm_vhost_mutex -> vs->dev.mutex -> tpg->tv_tpg_mutex -> vq->mutex
  */
-static int vhost_scsi_set_endpoint(
-	struct vhost_scsi *vs,
-	struct vhost_scsi_target *t)
+static int
+vhost_scsi_set_endpoint(struct vhost_scsi *vs,
+			struct vhost_scsi_target *t)
 {
+	struct se_portal_group *se_tpg;
 	struct tcm_vhost_tport *tv_tport;
-	struct tcm_vhost_tpg *tv_tpg;
+	struct tcm_vhost_tpg *tpg;
 	struct tcm_vhost_tpg **vs_tpg;
 	struct vhost_virtqueue *vq;
 	int index, ret, i, len;
@@ -1178,32 +1252,47 @@ static int vhost_scsi_set_endpoint(
 	if (vs->vs_tpg)
 		memcpy(vs_tpg, vs->vs_tpg, len);
 
-	list_for_each_entry(tv_tpg, &tcm_vhost_list, tv_tpg_list) {
-		mutex_lock(&tv_tpg->tv_tpg_mutex);
-		if (!tv_tpg->tpg_nexus) {
-			mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	list_for_each_entry(tpg, &tcm_vhost_list, tv_tpg_list) {
+		mutex_lock(&tpg->tv_tpg_mutex);
+		if (!tpg->tpg_nexus) {
+			mutex_unlock(&tpg->tv_tpg_mutex);
 			continue;
 		}
-		if (tv_tpg->tv_tpg_vhost_count != 0) {
-			mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		if (tpg->tv_tpg_vhost_count != 0) {
+			mutex_unlock(&tpg->tv_tpg_mutex);
 			continue;
 		}
-		tv_tport = tv_tpg->tport;
+		tv_tport = tpg->tport;
 
 		if (!strcmp(tv_tport->tport_name, t->vhost_wwpn)) {
-			if (vs->vs_tpg && vs->vs_tpg[tv_tpg->tport_tpgt]) {
+			if (vs->vs_tpg && vs->vs_tpg[tpg->tport_tpgt]) {
 				kfree(vs_tpg);
-				mutex_unlock(&tv_tpg->tv_tpg_mutex);
+				mutex_unlock(&tpg->tv_tpg_mutex);
 				ret = -EEXIST;
 				goto out;
 			}
-			tv_tpg->tv_tpg_vhost_count++;
-			tv_tpg->vhost_scsi = vs;
-			vs_tpg[tv_tpg->tport_tpgt] = tv_tpg;
+			/*
+			 * In order to ensure individual vhost-scsi configfs
+			 * groups cannot be removed while in use by vhost ioctl,
+			 * go ahead and take an explicit se_tpg->tpg_group.cg_item
+			 * dependency now.
+			 */
+			se_tpg = &tpg->se_tpg;
+			ret = configfs_depend_item(se_tpg->se_tpg_tfo->tf_subsys,
+						   &se_tpg->tpg_group.cg_item);
+			if (ret) {
+				pr_warn("configfs_depend_item() failed: %d\n", ret);
+				kfree(vs_tpg);
+				mutex_unlock(&tpg->tv_tpg_mutex);
+				goto out;
+			}
+			tpg->tv_tpg_vhost_count++;
+			tpg->vhost_scsi = vs;
+			vs_tpg[tpg->tport_tpgt] = tpg;
 			smp_mb__after_atomic_inc();
 			match = true;
 		}
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
 	}
 
 	if (match) {
@@ -1211,9 +1300,8 @@ static int vhost_scsi_set_endpoint(
 		       sizeof(vs->vs_vhost_wwpn));
 		for (i = 0; i < VHOST_SCSI_MAX_VQ; i++) {
 			vq = &vs->vqs[i].vq;
-			/* Flushing the vhost_work acts as synchronize_rcu */
 			mutex_lock(&vq->mutex);
-			rcu_assign_pointer(vq->private_data, vs_tpg);
+			vq->private_data = vs_tpg;
 			vhost_init_used(vq);
 			mutex_unlock(&vq->mutex);
 		}
@@ -1236,12 +1324,13 @@ out:
 	return ret;
 }
 
-static int vhost_scsi_clear_endpoint(
-	struct vhost_scsi *vs,
-	struct vhost_scsi_target *t)
+static int
+vhost_scsi_clear_endpoint(struct vhost_scsi *vs,
+			  struct vhost_scsi_target *t)
 {
+	struct se_portal_group *se_tpg;
 	struct tcm_vhost_tport *tv_tport;
-	struct tcm_vhost_tpg *tv_tpg;
+	struct tcm_vhost_tpg *tpg;
 	struct vhost_virtqueue *vq;
 	bool match = false;
 	int index, ret, i;
@@ -1264,37 +1353,43 @@ static int vhost_scsi_clear_endpoint(
 
 	for (i = 0; i < VHOST_SCSI_MAX_TARGET; i++) {
 		target = i;
-		tv_tpg = vs->vs_tpg[target];
-		if (!tv_tpg)
+		tpg = vs->vs_tpg[target];
+		if (!tpg)
 			continue;
 
-		mutex_lock(&tv_tpg->tv_tpg_mutex);
-		tv_tport = tv_tpg->tport;
+		mutex_lock(&tpg->tv_tpg_mutex);
+		tv_tport = tpg->tport;
 		if (!tv_tport) {
 			ret = -ENODEV;
 			goto err_tpg;
 		}
 
 		if (strcmp(tv_tport->tport_name, t->vhost_wwpn)) {
-			pr_warn("tv_tport->tport_name: %s, tv_tpg->tport_tpgt: %hu"
+			pr_warn("tv_tport->tport_name: %s, tpg->tport_tpgt: %hu"
 				" does not match t->vhost_wwpn: %s, t->vhost_tpgt: %hu\n",
-				tv_tport->tport_name, tv_tpg->tport_tpgt,
+				tv_tport->tport_name, tpg->tport_tpgt,
 				t->vhost_wwpn, t->vhost_tpgt);
 			ret = -EINVAL;
 			goto err_tpg;
 		}
-		tv_tpg->tv_tpg_vhost_count--;
-		tv_tpg->vhost_scsi = NULL;
+		tpg->tv_tpg_vhost_count--;
+		tpg->vhost_scsi = NULL;
 		vs->vs_tpg[target] = NULL;
 		match = true;
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
+		/*
+		 * Release se_tpg->tpg_group.cg_item configfs dependency now
+		 * to allow vhost-scsi WWPN se_tpg->tpg_group shutdown to occur.
+		 */
+		se_tpg = &tpg->se_tpg;
+		configfs_undepend_item(se_tpg->se_tpg_tfo->tf_subsys,
+				       &se_tpg->tpg_group.cg_item);
 	}
 	if (match) {
 		for (i = 0; i < VHOST_SCSI_MAX_VQ; i++) {
 			vq = &vs->vqs[i].vq;
-			/* Flushing the vhost_work acts as synchronize_rcu */
 			mutex_lock(&vq->mutex);
-			rcu_assign_pointer(vq->private_data, NULL);
+			vq->private_data = NULL;
 			mutex_unlock(&vq->mutex);
 		}
 	}
@@ -1311,7 +1406,7 @@ static int vhost_scsi_clear_endpoint(
 	return 0;
 
 err_tpg:
-	mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	mutex_unlock(&tpg->tv_tpg_mutex);
 err_dev:
 	mutex_unlock(&vs->dev.mutex);
 	mutex_unlock(&tcm_vhost_mutex);
@@ -1336,70 +1431,80 @@ static int vhost_scsi_set_features(struct vhost_scsi *vs, u64 features)
 	return 0;
 }
 
+static void vhost_scsi_free(struct vhost_scsi *vs)
+{
+	if (is_vmalloc_addr(vs))
+		vfree(vs);
+	else
+		kfree(vs);
+}
+
 static int vhost_scsi_open(struct inode *inode, struct file *f)
 {
-	struct vhost_scsi *s;
+	struct vhost_scsi *vs;
 	struct vhost_virtqueue **vqs;
-	int r, i;
+	int r = -ENOMEM, i;
 
-	s = kzalloc(sizeof(*s), GFP_KERNEL);
-	if (!s)
-		return -ENOMEM;
+	vs = kzalloc(sizeof(*vs), GFP_KERNEL | __GFP_NOWARN | __GFP_REPEAT);
+	if (!vs) {
+		vs = vzalloc(sizeof(*vs));
+		if (!vs)
+			goto err_vs;
+	}
 
 	vqs = kmalloc(VHOST_SCSI_MAX_VQ * sizeof(*vqs), GFP_KERNEL);
-	if (!vqs) {
-		kfree(s);
-		return -ENOMEM;
-	}
+	if (!vqs)
+		goto err_vqs;
 
-	vhost_work_init(&s->vs_completion_work, vhost_scsi_complete_cmd_work);
-	vhost_work_init(&s->vs_event_work, tcm_vhost_evt_work);
+	vhost_work_init(&vs->vs_completion_work, vhost_scsi_complete_cmd_work);
+	vhost_work_init(&vs->vs_event_work, tcm_vhost_evt_work);
 
-	s->vs_events_nr = 0;
-	s->vs_events_missed = false;
+	vs->vs_events_nr = 0;
+	vs->vs_events_missed = false;
 
-	vqs[VHOST_SCSI_VQ_CTL] = &s->vqs[VHOST_SCSI_VQ_CTL].vq;
-	vqs[VHOST_SCSI_VQ_EVT] = &s->vqs[VHOST_SCSI_VQ_EVT].vq;
-	s->vqs[VHOST_SCSI_VQ_CTL].vq.handle_kick = vhost_scsi_ctl_handle_kick;
-	s->vqs[VHOST_SCSI_VQ_EVT].vq.handle_kick = vhost_scsi_evt_handle_kick;
+	vqs[VHOST_SCSI_VQ_CTL] = &vs->vqs[VHOST_SCSI_VQ_CTL].vq;
+	vqs[VHOST_SCSI_VQ_EVT] = &vs->vqs[VHOST_SCSI_VQ_EVT].vq;
+	vs->vqs[VHOST_SCSI_VQ_CTL].vq.handle_kick = vhost_scsi_ctl_handle_kick;
+	vs->vqs[VHOST_SCSI_VQ_EVT].vq.handle_kick = vhost_scsi_evt_handle_kick;
 	for (i = VHOST_SCSI_VQ_IO; i < VHOST_SCSI_MAX_VQ; i++) {
-		vqs[i] = &s->vqs[i].vq;
-		s->vqs[i].vq.handle_kick = vhost_scsi_handle_kick;
+		vqs[i] = &vs->vqs[i].vq;
+		vs->vqs[i].vq.handle_kick = vhost_scsi_handle_kick;
 	}
-	r = vhost_dev_init(&s->dev, vqs, VHOST_SCSI_MAX_VQ);
-
-	tcm_vhost_init_inflight(s, NULL);
+	vhost_dev_init(&vs->dev, vqs, VHOST_SCSI_MAX_VQ);
 
-	if (r < 0) {
-		kfree(vqs);
-		kfree(s);
-		return r;
-	}
+	tcm_vhost_init_inflight(vs, NULL);
 
-	f->private_data = s;
+	f->private_data = vs;
 	return 0;
+
+err_vqs:
+	vhost_scsi_free(vs);
+err_vs:
+	return r;
 }
 
 static int vhost_scsi_release(struct inode *inode, struct file *f)
 {
-	struct vhost_scsi *s = f->private_data;
+	struct vhost_scsi *vs = f->private_data;
 	struct vhost_scsi_target t;
 
-	mutex_lock(&s->dev.mutex);
-	memcpy(t.vhost_wwpn, s->vs_vhost_wwpn, sizeof(t.vhost_wwpn));
-	mutex_unlock(&s->dev.mutex);
-	vhost_scsi_clear_endpoint(s, &t);
-	vhost_dev_stop(&s->dev);
-	vhost_dev_cleanup(&s->dev, false);
+	mutex_lock(&vs->dev.mutex);
+	memcpy(t.vhost_wwpn, vs->vs_vhost_wwpn, sizeof(t.vhost_wwpn));
+	mutex_unlock(&vs->dev.mutex);
+	vhost_scsi_clear_endpoint(vs, &t);
+	vhost_dev_stop(&vs->dev);
+	vhost_dev_cleanup(&vs->dev, false);
 	/* Jobs can re-queue themselves in evt kick handler. Do extra flush. */
-	vhost_scsi_flush(s);
-	kfree(s->dev.vqs);
-	kfree(s);
+	vhost_scsi_flush(vs);
+	kfree(vs->dev.vqs);
+	vhost_scsi_free(vs);
 	return 0;
 }
 
-static long vhost_scsi_ioctl(struct file *f, unsigned int ioctl,
-				unsigned long arg)
+static long
+vhost_scsi_ioctl(struct file *f,
+		 unsigned int ioctl,
+		 unsigned long arg)
 {
 	struct vhost_scsi *vs = f->private_data;
 	struct vhost_scsi_target backend;
@@ -1515,8 +1620,9 @@ static char *tcm_vhost_dump_proto_id(struct tcm_vhost_tport *tport)
 	return "Unknown";
 }
 
-static void tcm_vhost_do_plug(struct tcm_vhost_tpg *tpg,
-	struct se_lun *lun, bool plug)
+static void
+tcm_vhost_do_plug(struct tcm_vhost_tpg *tpg,
+		  struct se_lun *lun, bool plug)
 {
 
 	struct vhost_scsi *vs = tpg->vhost_scsi;
@@ -1556,18 +1662,18 @@ static void tcm_vhost_hotunplug(struct tcm_vhost_tpg *tpg, struct se_lun *lun)
 }
 
 static int tcm_vhost_port_link(struct se_portal_group *se_tpg,
-	struct se_lun *lun)
+			       struct se_lun *lun)
 {
-	struct tcm_vhost_tpg *tv_tpg = container_of(se_tpg,
+	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
 
 	mutex_lock(&tcm_vhost_mutex);
 
-	mutex_lock(&tv_tpg->tv_tpg_mutex);
-	tv_tpg->tv_tpg_port_count++;
-	mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	mutex_lock(&tpg->tv_tpg_mutex);
+	tpg->tv_tpg_port_count++;
+	mutex_unlock(&tpg->tv_tpg_mutex);
 
-	tcm_vhost_hotplug(tv_tpg, lun);
+	tcm_vhost_hotplug(tpg, lun);
 
 	mutex_unlock(&tcm_vhost_mutex);
 
@@ -1575,26 +1681,26 @@ static int tcm_vhost_port_link(struct se_portal_group *se_tpg,
 }
 
 static void tcm_vhost_port_unlink(struct se_portal_group *se_tpg,
-	struct se_lun *lun)
+				  struct se_lun *lun)
 {
-	struct tcm_vhost_tpg *tv_tpg = container_of(se_tpg,
+	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
 
 	mutex_lock(&tcm_vhost_mutex);
 
-	mutex_lock(&tv_tpg->tv_tpg_mutex);
-	tv_tpg->tv_tpg_port_count--;
-	mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	mutex_lock(&tpg->tv_tpg_mutex);
+	tpg->tv_tpg_port_count--;
+	mutex_unlock(&tpg->tv_tpg_mutex);
 
-	tcm_vhost_hotunplug(tv_tpg, lun);
+	tcm_vhost_hotunplug(tpg, lun);
 
 	mutex_unlock(&tcm_vhost_mutex);
 }
 
-static struct se_node_acl *tcm_vhost_make_nodeacl(
-	struct se_portal_group *se_tpg,
-	struct config_group *group,
-	const char *name)
+static struct se_node_acl *
+tcm_vhost_make_nodeacl(struct se_portal_group *se_tpg,
+		       struct config_group *group,
+		       const char *name)
 {
 	struct se_node_acl *se_nacl, *se_nacl_new;
 	struct tcm_vhost_nacl *nacl;
@@ -1635,35 +1741,78 @@ static void tcm_vhost_drop_nodeacl(struct se_node_acl *se_acl)
 	kfree(nacl);
 }
 
-static int tcm_vhost_make_nexus(struct tcm_vhost_tpg *tv_tpg,
-	const char *name)
+static void tcm_vhost_free_cmd_map_res(struct tcm_vhost_nexus *nexus,
+				       struct se_session *se_sess)
+{
+	struct tcm_vhost_cmd *tv_cmd;
+	unsigned int i;
+
+	if (!se_sess->sess_cmd_map)
+		return;
+
+	for (i = 0; i < TCM_VHOST_DEFAULT_TAGS; i++) {
+		tv_cmd = &((struct tcm_vhost_cmd *)se_sess->sess_cmd_map)[i];
+
+		kfree(tv_cmd->tvc_sgl);
+		kfree(tv_cmd->tvc_upages);
+	}
+}
+
+static int tcm_vhost_make_nexus(struct tcm_vhost_tpg *tpg,
+				const char *name)
 {
 	struct se_portal_group *se_tpg;
+	struct se_session *se_sess;
 	struct tcm_vhost_nexus *tv_nexus;
+	struct tcm_vhost_cmd *tv_cmd;
+	unsigned int i;
 
-	mutex_lock(&tv_tpg->tv_tpg_mutex);
-	if (tv_tpg->tpg_nexus) {
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
-		pr_debug("tv_tpg->tpg_nexus already exists\n");
+	mutex_lock(&tpg->tv_tpg_mutex);
+	if (tpg->tpg_nexus) {
+		mutex_unlock(&tpg->tv_tpg_mutex);
+		pr_debug("tpg->tpg_nexus already exists\n");
 		return -EEXIST;
 	}
-	se_tpg = &tv_tpg->se_tpg;
+	se_tpg = &tpg->se_tpg;
 
 	tv_nexus = kzalloc(sizeof(struct tcm_vhost_nexus), GFP_KERNEL);
 	if (!tv_nexus) {
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
 		pr_err("Unable to allocate struct tcm_vhost_nexus\n");
 		return -ENOMEM;
 	}
 	/*
-	 *  Initialize the struct se_session pointer
+	 *  Initialize the struct se_session pointer and setup tagpool
+	 *  for struct tcm_vhost_cmd descriptors
 	 */
-	tv_nexus->tvn_se_sess = transport_init_session();
+	tv_nexus->tvn_se_sess = transport_init_session_tags(
+					TCM_VHOST_DEFAULT_TAGS,
+					sizeof(struct tcm_vhost_cmd));
 	if (IS_ERR(tv_nexus->tvn_se_sess)) {
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
 		kfree(tv_nexus);
 		return -ENOMEM;
 	}
+	se_sess = tv_nexus->tvn_se_sess;
+	for (i = 0; i < TCM_VHOST_DEFAULT_TAGS; i++) {
+		tv_cmd = &((struct tcm_vhost_cmd *)se_sess->sess_cmd_map)[i];
+
+		tv_cmd->tvc_sgl = kzalloc(sizeof(struct scatterlist) *
+					TCM_VHOST_PREALLOC_SGLS, GFP_KERNEL);
+		if (!tv_cmd->tvc_sgl) {
+			mutex_unlock(&tpg->tv_tpg_mutex);
+			pr_err("Unable to allocate tv_cmd->tvc_sgl\n");
+			goto out;
+		}
+
+		tv_cmd->tvc_upages = kzalloc(sizeof(struct page *) *
+					TCM_VHOST_PREALLOC_PAGES, GFP_KERNEL);
+		if (!tv_cmd->tvc_upages) {
+			mutex_unlock(&tpg->tv_tpg_mutex);
+			pr_err("Unable to allocate tv_cmd->tvc_upages\n");
+			goto out;
+		}
+	}
 	/*
 	 * Since we are running in 'demo mode' this call with generate a
 	 * struct se_node_acl for the tcm_vhost struct se_portal_group with
@@ -1672,12 +1821,10 @@ static int tcm_vhost_make_nexus(struct tcm_vhost_tpg *tv_tpg,
 	tv_nexus->tvn_se_sess->se_node_acl = core_tpg_check_initiator_node_acl(
 				se_tpg, (unsigned char *)name);
 	if (!tv_nexus->tvn_se_sess->se_node_acl) {
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
 		pr_debug("core_tpg_check_initiator_node_acl() failed"
 				" for %s\n", name);
-		transport_free_session(tv_nexus->tvn_se_sess);
-		kfree(tv_nexus);
-		return -ENOMEM;
+		goto out;
 	}
 	/*
 	 * Now register the TCM vhost virtual I_T Nexus as active with the
@@ -1685,10 +1832,16 @@ static int tcm_vhost_make_nexus(struct tcm_vhost_tpg *tv_tpg,
 	 */
 	__transport_register_session(se_tpg, tv_nexus->tvn_se_sess->se_node_acl,
 			tv_nexus->tvn_se_sess, tv_nexus);
-	tv_tpg->tpg_nexus = tv_nexus;
+	tpg->tpg_nexus = tv_nexus;
 
-	mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	mutex_unlock(&tpg->tv_tpg_mutex);
 	return 0;
+
+out:
+	tcm_vhost_free_cmd_map_res(tv_nexus, se_sess);
+	transport_free_session(se_sess);
+	kfree(tv_nexus);
+	return -ENOMEM;
 }
 
 static int tcm_vhost_drop_nexus(struct tcm_vhost_tpg *tpg)
@@ -1728,6 +1881,8 @@ static int tcm_vhost_drop_nexus(struct tcm_vhost_tpg *tpg)
 	pr_debug("TCM_vhost_ConfigFS: Removing I_T Nexus to emulated"
 		" %s Initiator Port: %s\n", tcm_vhost_dump_proto_id(tpg->tport),
 		tv_nexus->tvn_se_sess->se_node_acl->initiatorname);
+
+	tcm_vhost_free_cmd_map_res(tv_nexus, se_sess);
 	/*
 	 * Release the SCSI I_T Nexus to the emulated vhost Target Port
 	 */
@@ -1740,40 +1895,40 @@ static int tcm_vhost_drop_nexus(struct tcm_vhost_tpg *tpg)
 }
 
 static ssize_t tcm_vhost_tpg_show_nexus(struct se_portal_group *se_tpg,
-	char *page)
+					char *page)
 {
-	struct tcm_vhost_tpg *tv_tpg = container_of(se_tpg,
+	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
 	struct tcm_vhost_nexus *tv_nexus;
 	ssize_t ret;
 
-	mutex_lock(&tv_tpg->tv_tpg_mutex);
-	tv_nexus = tv_tpg->tpg_nexus;
+	mutex_lock(&tpg->tv_tpg_mutex);
+	tv_nexus = tpg->tpg_nexus;
 	if (!tv_nexus) {
-		mutex_unlock(&tv_tpg->tv_tpg_mutex);
+		mutex_unlock(&tpg->tv_tpg_mutex);
 		return -ENODEV;
 	}
 	ret = snprintf(page, PAGE_SIZE, "%s\n",
 			tv_nexus->tvn_se_sess->se_node_acl->initiatorname);
-	mutex_unlock(&tv_tpg->tv_tpg_mutex);
+	mutex_unlock(&tpg->tv_tpg_mutex);
 
 	return ret;
 }
 
 static ssize_t tcm_vhost_tpg_store_nexus(struct se_portal_group *se_tpg,
-	const char *page,
-	size_t count)
+					 const char *page,
+					 size_t count)
 {
-	struct tcm_vhost_tpg *tv_tpg = container_of(se_tpg,
+	struct tcm_vhost_tpg *tpg = container_of(se_tpg,
 				struct tcm_vhost_tpg, se_tpg);
-	struct tcm_vhost_tport *tport_wwn = tv_tpg->tport;
+	struct tcm_vhost_tport *tport_wwn = tpg->tport;
 	unsigned char i_port[TCM_VHOST_NAMELEN], *ptr, *port_ptr;
 	int ret;
 	/*
 	 * Shutdown the active I_T nexus if 'NULL' is passed..
 	 */
 	if (!strncmp(page, "NULL", 4)) {
-		ret = tcm_vhost_drop_nexus(tv_tpg);
+		ret = tcm_vhost_drop_nexus(tpg);
 		return (!ret) ? count : ret;
 	}
 	/*
@@ -1831,7 +1986,7 @@ check_newline:
 	if (i_port[strlen(i_port)-1] == '\n')
 		i_port[strlen(i_port)-1] = '\0';
 
-	ret = tcm_vhost_make_nexus(tv_tpg, port_ptr);
+	ret = tcm_vhost_make_nexus(tpg, port_ptr);
 	if (ret < 0)
 		return ret;
 
@@ -1845,20 +2000,21 @@ static struct configfs_attribute *tcm_vhost_tpg_attrs[] = {
 	NULL,
 };
 
-static struct se_portal_group *tcm_vhost_make_tpg(struct se_wwn *wwn,
-	struct config_group *group,
-	const char *name)
+static struct se_portal_group *
+tcm_vhost_make_tpg(struct se_wwn *wwn,
+		   struct config_group *group,
+		   const char *name)
 {
 	struct tcm_vhost_tport *tport = container_of(wwn,
 			struct tcm_vhost_tport, tport_wwn);
 
 	struct tcm_vhost_tpg *tpg;
-	unsigned long tpgt;
+	u16 tpgt;
 	int ret;
 
 	if (strstr(name, "tpgt_") != name)
 		return ERR_PTR(-EINVAL);
-	if (kstrtoul(name + 5, 10, &tpgt) || tpgt > UINT_MAX)
+	if (kstrtou16(name + 5, 10, &tpgt) || tpgt >= VHOST_SCSI_MAX_TARGET)
 		return ERR_PTR(-EINVAL);
 
 	tpg = kzalloc(sizeof(struct tcm_vhost_tpg), GFP_KERNEL);
@@ -1903,9 +2059,10 @@ static void tcm_vhost_drop_tpg(struct se_portal_group *se_tpg)
 	kfree(tpg);
 }
 
-static struct se_wwn *tcm_vhost_make_tport(struct target_fabric_configfs *tf,
-	struct config_group *group,
-	const char *name)
+static struct se_wwn *
+tcm_vhost_make_tport(struct target_fabric_configfs *tf,
+		     struct config_group *group,
+		     const char *name)
 {
 	struct tcm_vhost_tport *tport;
 	char *ptr;
@@ -1975,9 +2132,9 @@ static void tcm_vhost_drop_tport(struct se_wwn *wwn)
 	kfree(tport);
 }
 
-static ssize_t tcm_vhost_wwn_show_attr_version(
-	struct target_fabric_configfs *tf,
-	char *page)
+static ssize_t
+tcm_vhost_wwn_show_attr_version(struct target_fabric_configfs *tf,
+				char *page)
 {
 	return sprintf(page, "TCM_VHOST fabric module %s on %s/%s"
 		"on "UTS_RELEASE"\n", TCM_VHOST_VERSION, utsname()->sysname,
@@ -2008,6 +2165,7 @@ static struct target_core_fabric_ops tcm_vhost_ops = {
 	.tpg_release_fabric_acl		= tcm_vhost_release_fabric_acl,
 	.tpg_get_inst_index		= tcm_vhost_tpg_get_inst_index,
 	.release_cmd			= tcm_vhost_release_cmd,
+	.check_stop_free		= vhost_scsi_check_stop_free,
 	.shutdown_session		= tcm_vhost_shutdown_session,
 	.close_session			= tcm_vhost_close_session,
 	.sess_get_index			= tcm_vhost_sess_get_index,
@@ -2020,6 +2178,7 @@ static struct target_core_fabric_ops tcm_vhost_ops = {
 	.queue_data_in			= tcm_vhost_queue_data_in,
 	.queue_status			= tcm_vhost_queue_status,
 	.queue_tm_rsp			= tcm_vhost_queue_tm_rsp,
+	.aborted_task			= tcm_vhost_aborted_task,
 	/*
 	 * Setup callers for generic logic in target_core_fabric_configfs.c
 	 */
@@ -2058,15 +2217,15 @@ static int tcm_vhost_register_configfs(void)
 	/*
 	 * Setup default attribute lists for various fabric->tf_cit_tmpl
 	 */
-	TF_CIT_TMPL(fabric)->tfc_wwn_cit.ct_attrs = tcm_vhost_wwn_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_base_cit.ct_attrs = tcm_vhost_tpg_attrs;
-	TF_CIT_TMPL(fabric)->tfc_tpg_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_param_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_np_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_base_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
-	TF_CIT_TMPL(fabric)->tfc_tpg_nacl_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_wwn_cit.ct_attrs = tcm_vhost_wwn_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_base_cit.ct_attrs = tcm_vhost_tpg_attrs;
+	fabric->tf_cit_tmpl.tfc_tpg_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_param_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_np_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_base_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_attrib_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_auth_cit.ct_attrs = NULL;
+	fabric->tf_cit_tmpl.tfc_tpg_nacl_param_cit.ct_attrs = NULL;
 	/*
 	 * Register the fabric for use within TCM
 	 */
diff --git a/drivers/vhost/test.c b/drivers/vhost/test.c
index 1ee45bc..c2a54fb 100644
--- a/drivers/vhost/test.c
+++ b/drivers/vhost/test.c
@@ -13,12 +13,11 @@
 #include <linux/module.h>
 #include <linux/mutex.h>
 #include <linux/workqueue.h>
-#include <linux/rcupdate.h>
 #include <linux/file.h>
 #include <linux/slab.h>
 
 #include "test.h"
-#include "vhost.c"
+#include "vhost.h"
 
 /* Max number of bytes transferred before requeueing the job.
  * Using this limit prevents one virtqueue from starving others. */
@@ -38,17 +37,19 @@ struct vhost_test {
  * read-size critical section for our kind of RCU. */
 static void handle_vq(struct vhost_test *n)
 {
-	struct vhost_virtqueue *vq = &n->dev.vqs[VHOST_TEST_VQ];
+	struct vhost_virtqueue *vq = &n->vqs[VHOST_TEST_VQ];
 	unsigned out, in;
 	int head;
 	size_t len, total_len = 0;
 	void *private;
 
-	private = rcu_dereference_check(vq->private_data, 1);
-	if (!private)
+	mutex_lock(&vq->mutex);
+	private = vq->private_data;
+	if (!private) {
+		mutex_unlock(&vq->mutex);
 		return;
+	}
 
-	mutex_lock(&vq->mutex);
 	vhost_disable_notify(&n->dev, vq);
 
 	for (;;) {
@@ -102,18 +103,20 @@ static int vhost_test_open(struct inode *inode, struct file *f)
 {
 	struct vhost_test *n = kmalloc(sizeof *n, GFP_KERNEL);
 	struct vhost_dev *dev;
-	int r;
+	struct vhost_virtqueue **vqs;
 
 	if (!n)
 		return -ENOMEM;
+	vqs = kmalloc(VHOST_TEST_VQ_MAX * sizeof(*vqs), GFP_KERNEL);
+	if (!vqs) {
+		kfree(n);
+		return -ENOMEM;
+	}
 
 	dev = &n->dev;
+	vqs[VHOST_TEST_VQ] = &n->vqs[VHOST_TEST_VQ];
 	n->vqs[VHOST_TEST_VQ].handle_kick = handle_vq_kick;
-	r = vhost_dev_init(dev, n->vqs, VHOST_TEST_VQ_MAX);
-	if (r < 0) {
-		kfree(n);
-		return r;
-	}
+	vhost_dev_init(dev, vqs, VHOST_TEST_VQ_MAX);
 
 	f->private_data = n;
 
@@ -126,9 +129,8 @@ static void *vhost_test_stop_vq(struct vhost_test *n,
 	void *private;
 
 	mutex_lock(&vq->mutex);
-	private = rcu_dereference_protected(vq->private_data,
-					 lockdep_is_held(&vq->mutex));
-	rcu_assign_pointer(vq->private_data, NULL);
+	private = vq->private_data;
+	vq->private_data = NULL;
 	mutex_unlock(&vq->mutex);
 	return private;
 }
@@ -140,7 +142,7 @@ static void vhost_test_stop(struct vhost_test *n, void **privatep)
 
 static void vhost_test_flush_vq(struct vhost_test *n, int index)
 {
-	vhost_poll_flush(&n->dev.vqs[index].poll);
+	vhost_poll_flush(&n->vqs[index].poll);
 }
 
 static void vhost_test_flush(struct vhost_test *n)
@@ -191,9 +193,8 @@ static long vhost_test_run(struct vhost_test *n, int test)
 		priv = test ? n : NULL;
 
 		/* start polling new socket */
-		oldpriv = rcu_dereference_protected(vq->private_data,
-						    lockdep_is_held(&vq->mutex));
-		rcu_assign_pointer(vq->private_data, priv);
+		oldpriv = vq->private_data;
+		vq->private_data = priv;
 
 		r = vhost_init_used(&n->vqs[index]);
 
@@ -268,14 +269,14 @@ static long vhost_test_ioctl(struct file *f, unsigned int ioctl,
 			return -EFAULT;
 		return vhost_test_run(n, test);
 	case VHOST_GET_FEATURES:
-		features = VHOST_NET_FEATURES;
+		features = VHOST_FEATURES;
 		if (copy_to_user(featurep, &features, sizeof features))
 			return -EFAULT;
 		return 0;
 	case VHOST_SET_FEATURES:
 		if (copy_from_user(&features, featurep, sizeof features))
 			return -EFAULT;
-		if (features & ~VHOST_NET_FEATURES)
+		if (features & ~VHOST_FEATURES)
 			return -EOPNOTSUPP;
 		return vhost_test_set_features(n, features);
 	case VHOST_RESET_OWNER:
diff --git a/drivers/vhost/vhost.c b/drivers/vhost/vhost.c
index a9deef9..85095d7 100644
--- a/drivers/vhost/vhost.c
+++ b/drivers/vhost/vhost.c
@@ -13,7 +13,7 @@
 
 #include <linux/eventfd.h>
 #include <linux/vhost.h>
-#include <linux/socket.h> /* memcpy_fromiovec */
+#include <linux/uio.h>
 #include <linux/mm.h>
 #include <linux/mmu_context.h>
 #include <linux/miscdevice.h>
@@ -25,6 +25,7 @@
 #include <linux/slab.h>
 #include <linux/kthread.h>
 #include <linux/cgroup.h>
+#include <linux/module.h>
 
 #include "vhost.h"
 
@@ -66,6 +67,7 @@ void vhost_work_init(struct vhost_work *work, vhost_work_fn_t fn)
 	work->flushing = 0;
 	work->queue_seq = work->done_seq = 0;
 }
+EXPORT_SYMBOL_GPL(vhost_work_init);
 
 /* Init poll structure */
 void vhost_poll_init(struct vhost_poll *poll, vhost_work_fn_t fn,
@@ -79,6 +81,7 @@ void vhost_poll_init(struct vhost_poll *poll, vhost_work_fn_t fn,
 
 	vhost_work_init(&poll->work, fn);
 }
+EXPORT_SYMBOL_GPL(vhost_poll_init);
 
 /* Start polling a file. We add ourselves to file's wait queue. The caller must
  * keep a reference to a file until after vhost_poll_stop is called. */
@@ -101,6 +104,7 @@ int vhost_poll_start(struct vhost_poll *poll, struct file *file)
 
 	return ret;
 }
+EXPORT_SYMBOL_GPL(vhost_poll_start);
 
 /* Stop polling a file. After this function returns, it becomes safe to drop the
  * file reference. You must also flush afterwards. */
@@ -111,6 +115,7 @@ void vhost_poll_stop(struct vhost_poll *poll)
 		poll->wqh = NULL;
 	}
 }
+EXPORT_SYMBOL_GPL(vhost_poll_stop);
 
 static bool vhost_work_seq_done(struct vhost_dev *dev, struct vhost_work *work,
 				unsigned seq)
@@ -123,7 +128,7 @@ static bool vhost_work_seq_done(struct vhost_dev *dev, struct vhost_work *work,
 	return left <= 0;
 }
 
-static void vhost_work_flush(struct vhost_dev *dev, struct vhost_work *work)
+void vhost_work_flush(struct vhost_dev *dev, struct vhost_work *work)
 {
 	unsigned seq;
 	int flushing;
@@ -138,6 +143,7 @@ static void vhost_work_flush(struct vhost_dev *dev, struct vhost_work *work)
 	spin_unlock_irq(&dev->work_lock);
 	BUG_ON(flushing < 0);
 }
+EXPORT_SYMBOL_GPL(vhost_work_flush);
 
 /* Flush any work that has been scheduled. When calling this, don't hold any
  * locks that are also used by the callback. */
@@ -145,6 +151,7 @@ void vhost_poll_flush(struct vhost_poll *poll)
 {
 	vhost_work_flush(poll->dev, &poll->work);
 }
+EXPORT_SYMBOL_GPL(vhost_poll_flush);
 
 void vhost_work_queue(struct vhost_dev *dev, struct vhost_work *work)
 {
@@ -154,15 +161,19 @@ void vhost_work_queue(struct vhost_dev *dev, struct vhost_work *work)
 	if (list_empty(&work->node)) {
 		list_add_tail(&work->node, &dev->work_list);
 		work->queue_seq++;
+		spin_unlock_irqrestore(&dev->work_lock, flags);
 		wake_up_process(dev->worker);
+	} else {
+		spin_unlock_irqrestore(&dev->work_lock, flags);
 	}
-	spin_unlock_irqrestore(&dev->work_lock, flags);
 }
+EXPORT_SYMBOL_GPL(vhost_work_queue);
 
 void vhost_poll_queue(struct vhost_poll *poll)
 {
 	vhost_work_queue(poll->dev, &poll->work);
 }
+EXPORT_SYMBOL_GPL(vhost_poll_queue);
 
 static void vhost_vq_reset(struct vhost_dev *dev,
 			   struct vhost_virtqueue *vq)
@@ -251,17 +262,16 @@ static void vhost_vq_free_iovecs(struct vhost_virtqueue *vq)
 /* Helper to allocate iovec buffers for all vqs. */
 static long vhost_dev_alloc_iovecs(struct vhost_dev *dev)
 {
+	struct vhost_virtqueue *vq;
 	int i;
 
 	for (i = 0; i < dev->nvqs; ++i) {
-		dev->vqs[i]->indirect = kmalloc(sizeof *dev->vqs[i]->indirect *
-					       UIO_MAXIOV, GFP_KERNEL);
-		dev->vqs[i]->log = kmalloc(sizeof *dev->vqs[i]->log * UIO_MAXIOV,
-					  GFP_KERNEL);
-		dev->vqs[i]->heads = kmalloc(sizeof *dev->vqs[i]->heads *
-					    UIO_MAXIOV, GFP_KERNEL);
-		if (!dev->vqs[i]->indirect || !dev->vqs[i]->log ||
-			!dev->vqs[i]->heads)
+		vq = dev->vqs[i];
+		vq->indirect = kmalloc(sizeof *vq->indirect * UIO_MAXIOV,
+				       GFP_KERNEL);
+		vq->log = kmalloc(sizeof *vq->log * UIO_MAXIOV, GFP_KERNEL);
+		vq->heads = kmalloc(sizeof *vq->heads * UIO_MAXIOV, GFP_KERNEL);
+		if (!vq->indirect || !vq->log || !vq->heads)
 			goto err_nomem;
 	}
 	return 0;
@@ -280,9 +290,10 @@ static void vhost_dev_free_iovecs(struct vhost_dev *dev)
 		vhost_vq_free_iovecs(dev->vqs[i]);
 }
 
-long vhost_dev_init(struct vhost_dev *dev,
+void vhost_dev_init(struct vhost_dev *dev,
 		    struct vhost_virtqueue **vqs, int nvqs)
 {
+	struct vhost_virtqueue *vq;
 	int i;
 
 	dev->vqs = vqs;
@@ -297,19 +308,19 @@ long vhost_dev_init(struct vhost_dev *dev,
 	dev->worker = NULL;
 
 	for (i = 0; i < dev->nvqs; ++i) {
-		dev->vqs[i]->log = NULL;
-		dev->vqs[i]->indirect = NULL;
-		dev->vqs[i]->heads = NULL;
-		dev->vqs[i]->dev = dev;
-		mutex_init(&dev->vqs[i]->mutex);
-		vhost_vq_reset(dev, dev->vqs[i]);
-		if (dev->vqs[i]->handle_kick)
-			vhost_poll_init(&dev->vqs[i]->poll,
-					dev->vqs[i]->handle_kick, POLLIN, dev);
+		vq = dev->vqs[i];
+		vq->log = NULL;
+		vq->indirect = NULL;
+		vq->heads = NULL;
+		vq->dev = dev;
+		mutex_init(&vq->mutex);
+		vhost_vq_reset(dev, vq);
+		if (vq->handle_kick)
+			vhost_poll_init(&vq->poll, vq->handle_kick,
+					POLLIN, dev);
 	}
-
-	return 0;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_init);
 
 /* Caller should have device mutex */
 long vhost_dev_check_owner(struct vhost_dev *dev)
@@ -317,6 +328,7 @@ long vhost_dev_check_owner(struct vhost_dev *dev)
 	/* Are you the owner? If not, I don't think you mean to do that */
 	return dev->mm == current->mm ? 0 : -EPERM;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_check_owner);
 
 struct vhost_attach_cgroups_struct {
 	struct vhost_work work;
@@ -348,6 +360,7 @@ bool vhost_dev_has_owner(struct vhost_dev *dev)
 {
 	return dev->mm;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_has_owner);
 
 /* Caller should have device mutex */
 long vhost_dev_set_owner(struct vhost_dev *dev)
@@ -391,11 +404,13 @@ err_worker:
 err_mm:
 	return err;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_set_owner);
 
 struct vhost_memory *vhost_dev_reset_owner_prepare(void)
 {
 	return kmalloc(offsetof(struct vhost_memory, regions), GFP_KERNEL);
 }
+EXPORT_SYMBOL_GPL(vhost_dev_reset_owner_prepare);
 
 /* Caller should have device mutex */
 void vhost_dev_reset_owner(struct vhost_dev *dev, struct vhost_memory *memory)
@@ -406,6 +421,7 @@ void vhost_dev_reset_owner(struct vhost_dev *dev, struct vhost_memory *memory)
 	memory->nregions = 0;
 	RCU_INIT_POINTER(dev->memory, memory);
 }
+EXPORT_SYMBOL_GPL(vhost_dev_reset_owner);
 
 void vhost_dev_stop(struct vhost_dev *dev)
 {
@@ -418,6 +434,7 @@ void vhost_dev_stop(struct vhost_dev *dev)
 		}
 	}
 }
+EXPORT_SYMBOL_GPL(vhost_dev_stop);
 
 /* Caller should have device mutex if and only if locked is set */
 void vhost_dev_cleanup(struct vhost_dev *dev, bool locked)
@@ -458,6 +475,7 @@ void vhost_dev_cleanup(struct vhost_dev *dev, bool locked)
 		mmput(dev->mm);
 	dev->mm = NULL;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_cleanup);
 
 static int log_access_ok(void __user *log_base, u64 addr, unsigned long sz)
 {
@@ -543,6 +561,7 @@ int vhost_log_access_ok(struct vhost_dev *dev)
 				       lockdep_is_held(&dev->mutex));
 	return memory_access_ok(dev, mp, 1);
 }
+EXPORT_SYMBOL_GPL(vhost_log_access_ok);
 
 /* Verify access for write logging. */
 /* Caller should have vq mutex and device mutex */
@@ -568,6 +587,7 @@ int vhost_vq_access_ok(struct vhost_virtqueue *vq)
 	return vq_access_ok(vq->dev, vq->num, vq->desc, vq->avail, vq->used) &&
 		vq_log_access_ok(vq->dev, vq, vq->log_base);
 }
+EXPORT_SYMBOL_GPL(vhost_vq_access_ok);
 
 static long vhost_set_memory(struct vhost_dev *d, struct vhost_memory __user *m)
 {
@@ -797,6 +817,7 @@ long vhost_vring_ioctl(struct vhost_dev *d, int ioctl, void __user *argp)
 		vhost_poll_flush(&vq->poll);
 	return r;
 }
+EXPORT_SYMBOL_GPL(vhost_vring_ioctl);
 
 /* Caller must have device mutex */
 long vhost_dev_ioctl(struct vhost_dev *d, unsigned int ioctl, void __user *argp)
@@ -855,6 +876,7 @@ long vhost_dev_ioctl(struct vhost_dev *d, unsigned int ioctl, void __user *argp)
 		}
 		if (eventfp != d->log_file) {
 			filep = d->log_file;
+			d->log_file = eventfp;
 			ctx = d->log_ctx;
 			d->log_ctx = eventfp ?
 				eventfd_ctx_fileget(eventfp) : NULL;
@@ -877,6 +899,7 @@ long vhost_dev_ioctl(struct vhost_dev *d, unsigned int ioctl, void __user *argp)
 done:
 	return r;
 }
+EXPORT_SYMBOL_GPL(vhost_dev_ioctl);
 
 static const struct vhost_memory_region *find_region(struct vhost_memory *mem,
 						     __u64 addr, __u32 len)
@@ -968,6 +991,7 @@ int vhost_log_write(struct vhost_virtqueue *vq, struct vhost_log *log,
 	BUG();
 	return 0;
 }
+EXPORT_SYMBOL_GPL(vhost_log_write);
 
 static int vhost_update_used_flags(struct vhost_virtqueue *vq)
 {
@@ -1019,6 +1043,7 @@ int vhost_init_used(struct vhost_virtqueue *vq)
 	vq->signalled_used_valid = false;
 	return get_user(vq->last_used_idx, &vq->used->idx);
 }
+EXPORT_SYMBOL_GPL(vhost_init_used);
 
 static int translate_desc(struct vhost_dev *dev, u64 addr, u32 len,
 			  struct iovec iov[], int iov_size)
@@ -1295,60 +1320,24 @@ int vhost_get_vq_desc(struct vhost_dev *dev, struct vhost_virtqueue *vq,
 	BUG_ON(!(vq->used_flags & VRING_USED_F_NO_NOTIFY));
 	return head;
 }
+EXPORT_SYMBOL_GPL(vhost_get_vq_desc);
 
 /* Reverse the effect of vhost_get_vq_desc. Useful for error handling. */
 void vhost_discard_vq_desc(struct vhost_virtqueue *vq, int n)
 {
 	vq->last_avail_idx -= n;
 }
+EXPORT_SYMBOL_GPL(vhost_discard_vq_desc);
 
 /* After we've used one of their buffers, we tell them about it.  We'll then
  * want to notify the guest, using eventfd. */
 int vhost_add_used(struct vhost_virtqueue *vq, unsigned int head, int len)
 {
-	struct vring_used_elem __user *used;
+	struct vring_used_elem heads = { head, len };
 
-	/* The virtqueue contains a ring of used buffers.  Get a pointer to the
-	 * next entry in that used ring. */
-	used = &vq->used->ring[vq->last_used_idx % vq->num];
-	if (__put_user(head, &used->id)) {
-		vq_err(vq, "Failed to write used id");
-		return -EFAULT;
-	}
-	if (__put_user(len, &used->len)) {
-		vq_err(vq, "Failed to write used len");
-		return -EFAULT;
-	}
-	/* Make sure buffer is written before we update index. */
-	smp_wmb();
-	if (__put_user(vq->last_used_idx + 1, &vq->used->idx)) {
-		vq_err(vq, "Failed to increment used idx");
-		return -EFAULT;
-	}
-	if (unlikely(vq->log_used)) {
-		/* Make sure data is seen before log. */
-		smp_wmb();
-		/* Log used ring entry write. */
-		log_write(vq->log_base,
-			  vq->log_addr +
-			   ((void __user *)used - (void __user *)vq->used),
-			  sizeof *used);
-		/* Log used index update. */
-		log_write(vq->log_base,
-			  vq->log_addr + offsetof(struct vring_used, idx),
-			  sizeof vq->used->idx);
-		if (vq->log_ctx)
-			eventfd_signal(vq->log_ctx, 1);
-	}
-	vq->last_used_idx++;
-	/* If the driver never bothers to signal in a very long while,
-	 * used index might wrap around. If that happens, invalidate
-	 * signalled_used index we stored. TODO: make sure driver
-	 * signals at least once in 2^16 and remove this. */
-	if (unlikely(vq->last_used_idx == vq->signalled_used))
-		vq->signalled_used_valid = false;
-	return 0;
+	return vhost_add_used_n(vq, &heads, 1);
 }
+EXPORT_SYMBOL_GPL(vhost_add_used);
 
 static int __vhost_add_used_n(struct vhost_virtqueue *vq,
 			    struct vring_used_elem *heads,
@@ -1360,7 +1349,16 @@ static int __vhost_add_used_n(struct vhost_virtqueue *vq,
 
 	start = vq->last_used_idx % vq->num;
 	used = vq->used->ring + start;
-	if (__copy_to_user(used, heads, count * sizeof *used)) {
+	if (count == 1) {
+		if (__put_user(heads[0].id, &used->id)) {
+			vq_err(vq, "Failed to write used id");
+			return -EFAULT;
+		}
+		if (__put_user(heads[0].len, &used->len)) {
+			vq_err(vq, "Failed to write used len");
+			return -EFAULT;
+		}
+	} else if (__copy_to_user(used, heads, count * sizeof *used)) {
 		vq_err(vq, "Failed to write used");
 		return -EFAULT;
 	}
@@ -1404,7 +1402,7 @@ int vhost_add_used_n(struct vhost_virtqueue *vq, struct vring_used_elem *heads,
 
 	/* Make sure buffer is written before we update index. */
 	smp_wmb();
-	if (__put_user(vq->last_used_idx, &vq->used->idx)) {
+	if (put_user(vq->last_used_idx, &vq->used->idx)) {
 		vq_err(vq, "Failed to increment used idx");
 		return -EFAULT;
 	}
@@ -1418,6 +1416,7 @@ int vhost_add_used_n(struct vhost_virtqueue *vq, struct vring_used_elem *heads,
 	}
 	return r;
 }
+EXPORT_SYMBOL_GPL(vhost_add_used_n);
 
 static bool vhost_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
 {
@@ -1448,7 +1447,7 @@ static bool vhost_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
 	if (unlikely(!v))
 		return true;
 
-	if (__get_user(event, vhost_used_event(vq))) {
+	if (get_user(event, vhost_used_event(vq))) {
 		vq_err(vq, "Failed to get used event idx");
 		return true;
 	}
@@ -1462,6 +1461,7 @@ void vhost_signal(struct vhost_dev *dev, struct vhost_virtqueue *vq)
 	if (vq->call_ctx && vhost_notify(dev, vq))
 		eventfd_signal(vq->call_ctx, 1);
 }
+EXPORT_SYMBOL_GPL(vhost_signal);
 
 /* And here's the combo meal deal.  Supersize me! */
 void vhost_add_used_and_signal(struct vhost_dev *dev,
@@ -1471,6 +1471,7 @@ void vhost_add_used_and_signal(struct vhost_dev *dev,
 	vhost_add_used(vq, head, len);
 	vhost_signal(dev, vq);
 }
+EXPORT_SYMBOL_GPL(vhost_add_used_and_signal);
 
 /* multi-buffer version of vhost_add_used_and_signal */
 void vhost_add_used_and_signal_n(struct vhost_dev *dev,
@@ -1480,6 +1481,7 @@ void vhost_add_used_and_signal_n(struct vhost_dev *dev,
 	vhost_add_used_n(vq, heads, count);
 	vhost_signal(dev, vq);
 }
+EXPORT_SYMBOL_GPL(vhost_add_used_and_signal_n);
 
 /* OK, now we need to know about added descriptors. */
 bool vhost_enable_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
@@ -1517,6 +1519,7 @@ bool vhost_enable_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
 
 	return avail_idx != vq->avail_idx;
 }
+EXPORT_SYMBOL_GPL(vhost_enable_notify);
 
 /* We don't need to be notified again. */
 void vhost_disable_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
@@ -1533,3 +1536,21 @@ void vhost_disable_notify(struct vhost_dev *dev, struct vhost_virtqueue *vq)
 			       &vq->used->flags, r);
 	}
 }
+EXPORT_SYMBOL_GPL(vhost_disable_notify);
+
+static int __init vhost_init(void)
+{
+	return 0;
+}
+
+static void __exit vhost_exit(void)
+{
+}
+
+module_init(vhost_init);
+module_exit(vhost_exit);
+
+MODULE_VERSION("0.0.1");
+MODULE_LICENSE("GPL v2");
+MODULE_AUTHOR("Michael S. Tsirkin");
+MODULE_DESCRIPTION("Host kernel accelerator for virtio");
diff --git a/drivers/vhost/vhost.h b/drivers/vhost/vhost.h
index 64adcf9..35eeb2a 100644
--- a/drivers/vhost/vhost.h
+++ b/drivers/vhost/vhost.h
@@ -46,6 +46,8 @@ int vhost_poll_start(struct vhost_poll *poll, struct file *file);
 void vhost_poll_stop(struct vhost_poll *poll);
 void vhost_poll_flush(struct vhost_poll *poll);
 void vhost_poll_queue(struct vhost_poll *poll);
+void vhost_work_flush(struct vhost_dev *dev, struct vhost_work *work);
+long vhost_vring_ioctl(struct vhost_dev *d, int ioctl, void __user *argp);
 
 struct vhost_log {
 	u64 addr;
@@ -101,14 +103,8 @@ struct vhost_virtqueue {
 	struct iovec iov[UIO_MAXIOV];
 	struct iovec *indirect;
 	struct vring_used_elem *heads;
-	/* We use a kind of RCU to access private pointer.
-	 * All readers access it from worker, which makes it possible to
-	 * flush the vhost_work instead of synchronize_rcu. Therefore readers do
-	 * not need to call rcu_read_lock/rcu_read_unlock: the beginning of
-	 * vhost_work execution acts instead of rcu_read_lock() and the end of
-	 * vhost_work execution acts instead of rcu_read_unlock().
-	 * Writers use virtqueue mutex. */
-	void __rcu *private_data;
+	/* Protected by virtqueue mutex. */
+	void *private_data;
 	/* Log write descriptors */
 	void __user *log_base;
 	struct vhost_log *log;
@@ -131,7 +127,7 @@ struct vhost_dev {
 	struct task_struct *worker;
 };
 
-long vhost_dev_init(struct vhost_dev *, struct vhost_virtqueue **vqs, int nvqs);
+void vhost_dev_init(struct vhost_dev *, struct vhost_virtqueue **vqs, int nvqs);
 long vhost_dev_set_owner(struct vhost_dev *dev);
 bool vhost_dev_has_owner(struct vhost_dev *dev);
 long vhost_dev_check_owner(struct vhost_dev *);
diff --git a/fs/Kconfig b/fs/Kconfig
index b7b85bf..8ee26a8 100644
--- a/fs/Kconfig
+++ b/fs/Kconfig
@@ -198,6 +198,7 @@ if MISC_FILESYSTEMS
 source "fs/adfs/Kconfig"
 source "fs/affs/Kconfig"
 source "fs/ecryptfs/Kconfig"
+source "fs/unionfs/Kconfig"
 source "fs/hfs/Kconfig"
 source "fs/hfsplus/Kconfig"
 source "fs/befs/Kconfig"
diff --git a/fs/Makefile b/fs/Makefile
index 4fe6df3..0416e63 100644
--- a/fs/Makefile
+++ b/fs/Makefile
@@ -82,6 +82,7 @@ obj-$(CONFIG_ISO9660_FS)	+= isofs/
 obj-$(CONFIG_HFSPLUS_FS)	+= hfsplus/ # Before hfs to find wrapped HFS+
 obj-$(CONFIG_HFS_FS)		+= hfs/
 obj-$(CONFIG_ECRYPT_FS)		+= ecryptfs/
+obj-$(CONFIG_UNION_FS)		+= unionfs/
 obj-$(CONFIG_VXFS_FS)		+= freevxfs/
 obj-$(CONFIG_NFS_FS)		+= nfs/
 obj-$(CONFIG_EXPORTFS)		+= exportfs/
diff --git a/fs/cifs/cifs_fs_sb.h b/fs/cifs/cifs_fs_sb.h
index 37e4a72..ae4e35b 100644
--- a/fs/cifs/cifs_fs_sb.h
+++ b/fs/cifs/cifs_fs_sb.h
@@ -45,6 +45,9 @@
 #define CIFS_MOUNT_POSIXACL	0x100000 /* mirror of MS_POSIXACL in mnt_cifs_flags */
 #define CIFS_MOUNT_CIFS_BACKUPUID 0x200000 /* backup intent bit for a user */
 #define CIFS_MOUNT_CIFS_BACKUPGID 0x400000 /* backup intent bit for a group */
+#define CIFS_MOUNT_USE_PREFIX_PATH 0x1000000 /* make subpath with unaccessible
+					      * root mountable
+					      */
 
 struct cifs_sb_info {
 	struct rb_root tlink_tree;
@@ -65,5 +68,6 @@ struct cifs_sb_info {
 	char   *mountdata; /* options received at mount time or via DFS refs */
 	struct backing_dev_info bdi;
 	struct delayed_work prune_tlinks;
+	char *prepath;
 };
 #endif				/* _CIFS_FS_SB_H */
diff --git a/fs/cifs/cifs_unicode.c b/fs/cifs/cifs_unicode.c
index 0227b45..15e9505 100644
--- a/fs/cifs/cifs_unicode.c
+++ b/fs/cifs/cifs_unicode.c
@@ -290,7 +290,8 @@ int
 cifsConvertToUTF16(__le16 *target, const char *source, int srclen,
 		 const struct nls_table *cp, int mapChars)
 {
-	int i, j, charlen;
+	int i, charlen;
+	int j = 0;
 	char src_char;
 	__le16 dst_char;
 	wchar_t tmp;
@@ -298,12 +299,11 @@ cifsConvertToUTF16(__le16 *target, const char *source, int srclen,
 	if (!mapChars)
 		return cifs_strtoUTF16(target, source, PATH_MAX, cp);
 
-	for (i = 0, j = 0; i < srclen; j++) {
+	for (i = 0; i < srclen; j++) {
 		src_char = source[i];
 		charlen = 1;
 		switch (src_char) {
 		case 0:
-			put_unaligned(0, &target[j]);
 			goto ctoUTF16_out;
 		case ':':
 			dst_char = cpu_to_le16(UNI_COLON);
@@ -350,6 +350,7 @@ cifsConvertToUTF16(__le16 *target, const char *source, int srclen,
 	}
 
 ctoUTF16_out:
+	put_unaligned(0, &target[j]); /* Null terminate target unicode string */
 	return j;
 }
 
diff --git a/fs/cifs/cifsacl.c b/fs/cifs/cifsacl.c
index 51f5e0e..494b683 100644
--- a/fs/cifs/cifsacl.c
+++ b/fs/cifs/cifsacl.c
@@ -1027,15 +1027,30 @@ id_mode_to_cifs_acl(struct inode *inode, const char *path, __u64 nmode,
 	__u32 secdesclen = 0;
 	struct cifs_ntsd *pntsd = NULL; /* acl obtained from server */
 	struct cifs_ntsd *pnntsd = NULL; /* modified acl to be sent to server */
+	struct cifs_sb_info *cifs_sb = CIFS_SB(inode->i_sb);
+	struct tcon_link *tlink = cifs_sb_tlink(cifs_sb);
+	struct cifs_tcon *tcon;
+
+	if (IS_ERR(tlink))
+		return PTR_ERR(tlink);
+	tcon = tlink_tcon(tlink);
 
 	cifs_dbg(NOISY, "set ACL from mode for %s\n", path);
 
 	/* Get the security descriptor */
-	pntsd = get_cifs_acl(CIFS_SB(inode->i_sb), inode, path, &secdesclen);
+
+	if (tcon->ses->server->ops->get_acl == NULL) {
+		cifs_put_tlink(tlink);
+		return -EOPNOTSUPP;
+	}
+
+	pntsd = tcon->ses->server->ops->get_acl(cifs_sb, inode, path,
+						&secdesclen);
 	if (IS_ERR(pntsd)) {
 		rc = PTR_ERR(pntsd);
 		cifs_dbg(VFS, "%s: error %d getting sec desc\n", __func__, rc);
-		goto out;
+		cifs_put_tlink(tlink);
+		return rc;
 	}
 
 	/*
@@ -1048,6 +1063,7 @@ id_mode_to_cifs_acl(struct inode *inode, const char *path, __u64 nmode,
 	pnntsd = kmalloc(secdesclen, GFP_KERNEL);
 	if (!pnntsd) {
 		kfree(pntsd);
+		cifs_put_tlink(tlink);
 		return -ENOMEM;
 	}
 
@@ -1056,14 +1072,18 @@ id_mode_to_cifs_acl(struct inode *inode, const char *path, __u64 nmode,
 
 	cifs_dbg(NOISY, "build_sec_desc rc: %d\n", rc);
 
+	if (tcon->ses->server->ops->set_acl == NULL)
+		rc = -EOPNOTSUPP;
+
 	if (!rc) {
 		/* Set the security descriptor */
-		rc = set_cifs_acl(pnntsd, secdesclen, inode, path, aclflag);
+		rc = tcon->ses->server->ops->set_acl(pnntsd, secdesclen, inode,
+						     path, aclflag);
 		cifs_dbg(NOISY, "set_cifs_acl rc: %d\n", rc);
 	}
+	cifs_put_tlink(tlink);
 
 	kfree(pnntsd);
 	kfree(pntsd);
-out:
 	return rc;
 }
diff --git a/fs/cifs/cifsencrypt.c b/fs/cifs/cifsencrypt.c
index 5c807b2..182e82f 100644
--- a/fs/cifs/cifsencrypt.c
+++ b/fs/cifs/cifsencrypt.c
@@ -591,7 +591,7 @@ setup_ntlmv2_rsp(struct cifs_ses *ses, const struct nls_table *nls_cp)
 
 	ses->auth_key.response = kmalloc(baselen + tilen, GFP_KERNEL);
 	if (!ses->auth_key.response) {
-		rc = ENOMEM;
+		rc = -ENOMEM;
 		ses->auth_key.len = 0;
 		goto setup_ntlmv2_rsp_ret;
 	}
diff --git a/fs/cifs/cifsfs.c b/fs/cifs/cifsfs.c
index 3752b9f..e4e2152 100644
--- a/fs/cifs/cifsfs.c
+++ b/fs/cifs/cifsfs.c
@@ -565,6 +565,9 @@ cifs_get_root(struct smb_vol *vol, struct super_block *sb)
 	char *s, *p;
 	char sep;
 
+	if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_USE_PREFIX_PATH)
+		return dget(sb->s_root);
+
 	full_path = cifs_build_path_to_root(vol, cifs_sb,
 					    cifs_sb_master_tcon(cifs_sb));
 	if (full_path == NULL)
@@ -644,10 +647,14 @@ cifs_do_mount(struct file_system_type *fs_type,
 	cifs_sb->mountdata = kstrndup(data, PAGE_SIZE, GFP_KERNEL);
 	if (cifs_sb->mountdata == NULL) {
 		root = ERR_PTR(-ENOMEM);
-		goto out_cifs_sb;
+		goto out_free;
 	}
 
-	cifs_setup_cifs_sb(volume_info, cifs_sb);
+	rc = cifs_setup_cifs_sb(volume_info, cifs_sb);
+	if (rc) {
+		root = ERR_PTR(rc);
+		goto out_free;
+	}
 
 	rc = cifs_mount(cifs_sb, volume_info);
 	if (rc) {
@@ -655,7 +662,7 @@ cifs_do_mount(struct file_system_type *fs_type,
 			cifs_dbg(VFS, "cifs_mount failed w/return code = %d\n",
 				 rc);
 		root = ERR_PTR(rc);
-		goto out_mountdata;
+		goto out_free;
 	}
 
 	mnt_data.vol = volume_info;
@@ -698,9 +705,9 @@ out:
 	cifs_cleanup_volume_info(volume_info);
 	return root;
 
-out_mountdata:
+out_free:
+	kfree(cifs_sb->prepath);
 	kfree(cifs_sb->mountdata);
-out_cifs_sb:
 	kfree(cifs_sb);
 out_nls:
 	unload_nls(volume_info->local_nls);
diff --git a/fs/cifs/cifsglob.h b/fs/cifs/cifsglob.h
index ea3a0b3..b7f5899 100644
--- a/fs/cifs/cifsglob.h
+++ b/fs/cifs/cifsglob.h
@@ -74,11 +74,6 @@
 #define SERVER_NAME_LENGTH 40
 #define SERVER_NAME_LEN_WITH_NULL     (SERVER_NAME_LENGTH + 1)
 
-/* used to define string lengths for reversing unicode strings */
-/*         (256+1)*2 = 514                                     */
-/*           (max path length + 1 for null) * 2 for unicode    */
-#define MAX_NAME 514
-
 /* SMB echo "timeout" -- FIXME: tunable? */
 #define SMB_ECHO_INTERVAL (60 * HZ)
 
@@ -370,6 +365,18 @@ struct smb_version_operations {
 	void (*new_lease_key)(struct cifs_fid *fid);
 	int (*calc_signature)(struct smb_rqst *rqst,
 				   struct TCP_Server_Info *server);
+	ssize_t (*query_all_EAs)(const unsigned int, struct cifs_tcon *,
+			const unsigned char *, const unsigned char *, char *,
+			size_t, const struct nls_table *, int);
+	int (*set_EA)(const unsigned int, struct cifs_tcon *, const char *,
+			const char *, const void *, const __u16,
+			const struct nls_table *, int);
+	struct cifs_ntsd * (*get_acl)(struct cifs_sb_info *, struct inode *,
+			const char *, u32 *);
+	int (*set_acl)(struct cifs_ntsd *, __u32, struct inode *, const char *,
+			int);
+	/* check if we need to issue closedir */
+	bool (*dir_needs_close)(struct cifsFileInfo *);
 };
 
 struct smb_version_values {
@@ -569,6 +576,8 @@ struct TCP_Server_Info {
 #ifdef CONFIG_CIFS_SMB2
 	unsigned int	max_read;
 	unsigned int	max_write;
+	struct delayed_work reconnect; /* reconnect workqueue job */
+	struct mutex reconnect_mutex; /* prevent simultaneous reconnects */
 #endif /* CONFIG_CIFS_SMB2 */
 };
 
@@ -743,6 +752,7 @@ cap_unix(struct cifs_ses *ses)
 struct cifs_tcon {
 	struct list_head tcon_list;
 	int tc_count;
+	struct list_head rlist; /* reconnect list */
 	struct list_head openFileList;
 	struct cifs_ses *ses;	/* pointer to session associated with */
 	char treeName[MAX_TREE_SIZE + 1]; /* UNC name of resource in ASCII */
@@ -816,7 +826,6 @@ struct cifs_tcon {
 	bool need_reconnect:1; /* connection reset, tid now invalid */
 #ifdef CONFIG_CIFS_SMB2
 	bool print:1;		/* set if connection to printer share */
-	bool bad_network_name:1; /* set if ret status STATUS_BAD_NETWORK_NAME */
 	__u32 capabilities;
 	__u32 share_flags;
 	__u32 maximal_access;
diff --git a/fs/cifs/cifsproto.h b/fs/cifs/cifsproto.h
index dda188a..871a309 100644
--- a/fs/cifs/cifsproto.h
+++ b/fs/cifs/cifsproto.h
@@ -174,7 +174,7 @@ extern int cifs_read_from_socket(struct TCP_Server_Info *server, char *buf,
 extern int cifs_readv_from_socket(struct TCP_Server_Info *server,
 		struct kvec *iov_orig, unsigned int nr_segs,
 		unsigned int to_read);
-extern void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
+extern int cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 			       struct cifs_sb_info *cifs_sb);
 extern int cifs_match_super(struct super_block *, void *);
 extern void cifs_cleanup_volume_info(struct smb_vol *pvolume_info);
@@ -194,6 +194,9 @@ extern void cifs_add_pending_open_locked(struct cifs_fid *fid,
 					 struct tcon_link *tlink,
 					 struct cifs_pending_open *open);
 extern void cifs_del_pending_open(struct cifs_pending_open *open);
+extern void cifs_put_tcp_session(struct TCP_Server_Info *server,
+				 int from_reconnect);
+extern void cifs_put_tcon(struct cifs_tcon *tcon);
 
 #if IS_ENABLED(CONFIG_CIFS_DFS_UPCALL)
 extern void cifs_dfs_release_automount_timer(void);
diff --git a/fs/cifs/cifssmb.c b/fs/cifs/cifssmb.c
index a58dc77..4c86850 100644
--- a/fs/cifs/cifssmb.c
+++ b/fs/cifs/cifssmb.c
@@ -1389,11 +1389,10 @@ openRetry:
  * current bigbuf.
  */
 static int
-cifs_readv_discard(struct TCP_Server_Info *server, struct mid_q_entry *mid)
+discard_remaining_data(struct TCP_Server_Info *server)
 {
 	unsigned int rfclen = get_rfc1002_length(server->smallbuf);
 	int remaining = rfclen + 4 - server->total_read;
-	struct cifs_readdata *rdata = mid->callback_data;
 
 	while (remaining > 0) {
 		int length;
@@ -1407,10 +1406,20 @@ cifs_readv_discard(struct TCP_Server_Info *server, struct mid_q_entry *mid)
 		remaining -= length;
 	}
 
-	dequeue_mid(mid, rdata->result);
 	return 0;
 }
 
+static int
+cifs_readv_discard(struct TCP_Server_Info *server, struct mid_q_entry *mid)
+{
+	int length;
+	struct cifs_readdata *rdata = mid->callback_data;
+
+	length = discard_remaining_data(server);
+	dequeue_mid(mid, rdata->result);
+	return length;
+}
+
 int
 cifs_readv_receive(struct TCP_Server_Info *server, struct mid_q_entry *mid)
 {
@@ -1439,6 +1448,12 @@ cifs_readv_receive(struct TCP_Server_Info *server, struct mid_q_entry *mid)
 		return length;
 	server->total_read += length;
 
+	if (server->ops->is_status_pending &&
+	    server->ops->is_status_pending(buf, server, 0)) {
+		discard_remaining_data(server);
+		return -1;
+	}
+
 	/* Was the SMB read successful? */
 	rdata->result = server->ops->map_error(buf, false);
 	if (rdata->result != 0) {
@@ -3306,11 +3321,13 @@ static __u16 ACL_to_cifs_posix(char *parm_data, const char *pACL,
 		return 0;
 	}
 	cifs_acl->version = cpu_to_le16(1);
-	if (acl_type == ACL_TYPE_ACCESS)
+	if (acl_type == ACL_TYPE_ACCESS) {
 		cifs_acl->access_entry_count = cpu_to_le16(count);
-	else if (acl_type == ACL_TYPE_DEFAULT)
+		cifs_acl->default_entry_count = __constant_cpu_to_le16(0xFFFF);
+	} else if (acl_type == ACL_TYPE_DEFAULT) {
 		cifs_acl->default_entry_count = cpu_to_le16(count);
-	else {
+		cifs_acl->access_entry_count = __constant_cpu_to_le16(0xFFFF);
+	} else {
 		cifs_dbg(FYI, "unknown ACL type %d\n", acl_type);
 		return 0;
 	}
diff --git a/fs/cifs/connect.c b/fs/cifs/connect.c
index d05a300..417ce0a 100644
--- a/fs/cifs/connect.c
+++ b/fs/cifs/connect.c
@@ -52,6 +52,9 @@
 #include "nterr.h"
 #include "rfc1002pdu.h"
 #include "fscache.h"
+#ifdef CONFIG_CIFS_SMB2
+#include "smb2proto.h"
+#endif
 
 #define CIFS_PORT 445
 #define RFC1001_PORT 139
@@ -408,7 +411,9 @@ cifs_echo_request(struct work_struct *work)
 	 * server->ops->need_neg() == true. Also, no need to ping if
 	 * we got a response recently.
 	 */
-	if (!server->ops->need_neg || server->ops->need_neg(server) ||
+
+	if (server->tcpStatus == CifsNeedReconnect ||
+	    server->tcpStatus == CifsExiting || server->tcpStatus == CifsNew ||
 	    (server->ops->can_echo && !server->ops->can_echo(server)) ||
 	    time_before(jiffies, server->lstrp + SMB_ECHO_INTERVAL - HZ))
 		goto requeue_echo;
@@ -2068,8 +2073,8 @@ cifs_find_tcp_session(struct smb_vol *vol)
 	return NULL;
 }
 
-static void
-cifs_put_tcp_session(struct TCP_Server_Info *server)
+void
+cifs_put_tcp_session(struct TCP_Server_Info *server, int from_reconnect)
 {
 	struct task_struct *task;
 
@@ -2086,6 +2091,19 @@ cifs_put_tcp_session(struct TCP_Server_Info *server)
 
 	cancel_delayed_work_sync(&server->echo);
 
+#ifdef CONFIG_CIFS_SMB2
+	if (from_reconnect)
+		/*
+		 * Avoid deadlock here: reconnect work calls
+		 * cifs_put_tcp_session() at its end. Need to be sure
+		 * that reconnect work does nothing with server pointer after
+		 * that step.
+		 */
+		cancel_delayed_work(&server->reconnect);
+	else
+		cancel_delayed_work_sync(&server->reconnect);
+#endif
+
 	spin_lock(&GlobalMid_Lock);
 	server->tcpStatus = CifsExiting;
 	spin_unlock(&GlobalMid_Lock);
@@ -2156,6 +2174,10 @@ cifs_get_tcp_session(struct smb_vol *volume_info)
 	INIT_LIST_HEAD(&tcp_ses->tcp_ses_list);
 	INIT_LIST_HEAD(&tcp_ses->smb_ses_list);
 	INIT_DELAYED_WORK(&tcp_ses->echo, cifs_echo_request);
+#ifdef CONFIG_CIFS_SMB2
+	INIT_DELAYED_WORK(&tcp_ses->reconnect, smb2_reconnect_server);
+	mutex_init(&tcp_ses->reconnect_mutex);
+#endif
 	memcpy(&tcp_ses->srcaddr, &volume_info->srcaddr,
 	       sizeof(tcp_ses->srcaddr));
 	memcpy(&tcp_ses->dstaddr, &volume_info->dstaddr,
@@ -2286,7 +2308,7 @@ cifs_put_smb_ses(struct cifs_ses *ses)
 		_free_xid(xid);
 	}
 	sesInfoFree(ses);
-	cifs_put_tcp_session(server);
+	cifs_put_tcp_session(server, 0);
 }
 
 #ifdef CONFIG_KEYS
@@ -2459,7 +2481,7 @@ cifs_get_smb_ses(struct TCP_Server_Info *server, struct smb_vol *volume_info)
 		mutex_unlock(&ses->session_mutex);
 
 		/* existing SMB ses has a server reference already */
-		cifs_put_tcp_session(server);
+		cifs_put_tcp_session(server, 0);
 		free_xid(xid);
 		return ses;
 	}
@@ -2548,7 +2570,7 @@ cifs_find_tcon(struct cifs_ses *ses, const char *unc)
 	return NULL;
 }
 
-static void
+void
 cifs_put_tcon(struct cifs_tcon *tcon)
 {
 	unsigned int xid;
@@ -2713,6 +2735,24 @@ compare_mount_options(struct super_block *sb, struct cifs_mnt_data *mnt_data)
 	return 1;
 }
 
+static int
+match_prepath(struct super_block *sb, struct cifs_mnt_data *mnt_data)
+{
+	struct cifs_sb_info *old = CIFS_SB(sb);
+	struct cifs_sb_info *new = mnt_data->cifs_sb;
+
+	if (old->mnt_cifs_flags & CIFS_MOUNT_USE_PREFIX_PATH) {
+		if (!(new->mnt_cifs_flags & CIFS_MOUNT_USE_PREFIX_PATH))
+			return 0;
+		/* The prepath should be null terminated strings */
+		if (strcmp(new->prepath, old->prepath))
+			return 0;
+
+		return 1;
+	}
+	return 0;
+}
+
 int
 cifs_match_super(struct super_block *sb, void *data)
 {
@@ -2740,7 +2780,8 @@ cifs_match_super(struct super_block *sb, void *data)
 
 	if (!match_server(tcp_srv, volume_info) ||
 	    !match_session(ses, volume_info) ||
-	    !match_tcon(tcon, volume_info->UNC)) {
+	    !match_tcon(tcon, volume_info->UNC) ||
+	    !match_prepath(sb, mnt_data)) {
 		rc = 0;
 		goto out;
 	}
@@ -3156,7 +3197,7 @@ void reset_cifs_unix_caps(unsigned int xid, struct cifs_tcon *tcon,
 	}
 }
 
-void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
+int cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 			struct cifs_sb_info *cifs_sb)
 {
 	INIT_DELAYED_WORK(&cifs_sb->prune_tlinks, cifs_prune_tlinks);
@@ -3238,6 +3279,15 @@ void cifs_setup_cifs_sb(struct smb_vol *pvolume_info,
 
 	if ((pvolume_info->cifs_acl) && (pvolume_info->dynperm))
 		cifs_dbg(VFS, "mount option dynperm ignored if cifsacl mount option supported\n");
+
+
+	if (pvolume_info->prepath) {
+		cifs_sb->prepath = kstrdup(pvolume_info->prepath, GFP_KERNEL);
+		if (cifs_sb->prepath == NULL)
+			return -ENOMEM;
+	}
+
+	return 0;
 }
 
 static void
@@ -3408,6 +3458,44 @@ cifs_get_volume_info(char *mount_data, const char *devname)
 	return volume_info;
 }
 
+static int
+cifs_are_all_path_components_accessible(struct TCP_Server_Info *server,
+					unsigned int xid,
+					struct cifs_tcon *tcon,
+					struct cifs_sb_info *cifs_sb,
+					char *full_path)
+{
+	int rc;
+	char *s;
+	char sep, tmp;
+
+	sep = CIFS_DIR_SEP(cifs_sb);
+	s = full_path;
+
+	rc = server->ops->is_path_accessible(xid, tcon, cifs_sb, "");
+	while (rc == 0) {
+		/* skip separators */
+		while (*s == sep)
+			s++;
+		if (!*s)
+			break;
+		/* next separator */
+		while (*s && *s != sep)
+			s++;
+
+		/*
+		 * temporarily null-terminate the path at the end of
+		 * the current component
+		 */
+		tmp = *s;
+		*s = 0;
+		rc = server->ops->is_path_accessible(xid, tcon, cifs_sb,
+						     full_path);
+		*s = tmp;
+	}
+	return rc;
+}
+
 int
 cifs_mount(struct cifs_sb_info *cifs_sb, struct smb_vol *volume_info)
 {
@@ -3534,6 +3622,17 @@ remote_path_check:
 			kfree(full_path);
 			goto mount_fail_check;
 		}
+		if (rc != -EREMOTE) {
+			rc = cifs_are_all_path_components_accessible(server,
+								     xid, tcon, cifs_sb,
+								     full_path);
+			if (rc != 0) {
+				cifs_dbg(VFS, "cannot query dirs between root and final path, "
+					 "enabling CIFS_MOUNT_USE_PREFIX_PATH\n");
+				cifs_sb->mnt_cifs_flags |= CIFS_MOUNT_USE_PREFIX_PATH;
+				rc = 0;
+			}
+		}
 		kfree(full_path);
 	}
 
@@ -3597,7 +3696,7 @@ mount_fail_check:
 		else if (ses)
 			cifs_put_smb_ses(ses);
 		else
-			cifs_put_tcp_session(server);
+			cifs_put_tcp_session(server, 0);
 		bdi_destroy(&cifs_sb->bdi);
 	}
 
@@ -3791,6 +3890,7 @@ cifs_umount(struct cifs_sb_info *cifs_sb)
 
 	bdi_destroy(&cifs_sb->bdi);
 	kfree(cifs_sb->mountdata);
+	kfree(cifs_sb->prepath);
 	unload_nls(cifs_sb->local_nls);
 	kfree(cifs_sb);
 }
@@ -3930,7 +4030,7 @@ cifs_construct_tcon(struct cifs_sb_info *cifs_sb, kuid_t fsuid)
 	ses = cifs_get_smb_ses(master_tcon->ses->server, vol_info);
 	if (IS_ERR(ses)) {
 		tcon = (struct cifs_tcon *)ses;
-		cifs_put_tcp_session(master_tcon->ses->server);
+		cifs_put_tcp_session(master_tcon->ses->server, 0);
 		goto out;
 	}
 
diff --git a/fs/cifs/dir.c b/fs/cifs/dir.c
index 0c2425b..5431247 100644
--- a/fs/cifs/dir.c
+++ b/fs/cifs/dir.c
@@ -83,6 +83,7 @@ build_path_from_dentry(struct dentry *direntry)
 	struct dentry *temp;
 	int namelen;
 	int dfsplen;
+	int pplen = 0;
 	char *full_path;
 	char dirsep;
 	struct cifs_sb_info *cifs_sb = CIFS_SB(direntry->d_sb);
@@ -94,8 +95,12 @@ build_path_from_dentry(struct dentry *direntry)
 		dfsplen = strnlen(tcon->treeName, MAX_TREE_SIZE + 1);
 	else
 		dfsplen = 0;
+
+	if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_USE_PREFIX_PATH)
+		pplen = cifs_sb->prepath ? strlen(cifs_sb->prepath) + 1 : 0;
+
 cifs_bp_rename_retry:
-	namelen = dfsplen;
+	namelen = dfsplen + pplen;
 	seq = read_seqbegin(&rename_lock);
 	rcu_read_lock();
 	for (temp = direntry; !IS_ROOT(temp);) {
@@ -136,7 +141,7 @@ cifs_bp_rename_retry:
 		}
 	}
 	rcu_read_unlock();
-	if (namelen != dfsplen || read_seqretry(&rename_lock, seq)) {
+	if (namelen != dfsplen + pplen || read_seqretry(&rename_lock, seq)) {
 		cifs_dbg(FYI, "did not end path lookup where expected. namelen=%ddfsplen=%d\n",
 			 namelen, dfsplen);
 		/* presumably this is only possible if racing with a rename
@@ -152,6 +157,17 @@ cifs_bp_rename_retry:
 	   those safely to '/' if any are found in the middle of the prepath */
 	/* BB test paths to Windows with '/' in the midst of prepath */
 
+	if (pplen) {
+		int i;
+
+		cifs_dbg(FYI, "using cifs_sb prepath <%s>\n", cifs_sb->prepath);
+		memcpy(full_path+dfsplen+1, cifs_sb->prepath, pplen-1);
+		full_path[dfsplen] = '\\';
+		for (i = 0; i < pplen-1; i++)
+			if (full_path[dfsplen+1+i] == '/')
+				full_path[dfsplen+1+i] = CIFS_DIR_SEP(cifs_sb);
+	}
+
 	if (dfsplen) {
 		strncpy(full_path, tcon->treeName, dfsplen);
 		if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_POSIX_PATHS) {
@@ -227,6 +243,13 @@ cifs_do_create(struct inode *inode, struct dentry *direntry, unsigned int xid,
 				goto cifs_create_get_file_info;
 			}
 
+			if (S_ISDIR(newinode->i_mode)) {
+				CIFSSMBClose(xid, tcon, fid->netfid);
+				iput(newinode);
+				rc = -EISDIR;
+				goto out;
+			}
+
 			if (!S_ISREG(newinode->i_mode)) {
 				/*
 				 * The server may allow us to open things like
@@ -391,10 +414,14 @@ cifs_create_set_dentry:
 	if (rc != 0) {
 		cifs_dbg(FYI, "Create worked, get_inode_info failed rc = %d\n",
 			 rc);
-		if (server->ops->close)
-			server->ops->close(xid, tcon, fid);
-		goto out;
+		goto out_err;
 	}
+
+	if (S_ISDIR(newinode->i_mode)) {
+		rc = -EISDIR;
+		goto out_err;
+	}
+
 	d_drop(direntry);
 	d_add(direntry, newinode);
 
@@ -402,6 +429,13 @@ out:
 	kfree(buf);
 	kfree(full_path);
 	return rc;
+
+out_err:
+	if (server->ops->close)
+		server->ops->close(xid, tcon, fid);
+	if (newinode)
+		iput(newinode);
+	goto out;
 }
 
 int
diff --git a/fs/cifs/file.c b/fs/cifs/file.c
index 1c3b70c..46e8673 100644
--- a/fs/cifs/file.c
+++ b/fs/cifs/file.c
@@ -735,7 +735,7 @@ int cifs_closedir(struct inode *inode, struct file *file)
 
 	cifs_dbg(FYI, "Freeing private data in close dir\n");
 	spin_lock(&cifs_file_list_lock);
-	if (!cfile->srch_inf.endOfSearch && !cfile->invalidHandle) {
+	if (server->ops->dir_needs_close(cfile)) {
 		cfile->invalidHandle = true;
 		spin_unlock(&cifs_file_list_lock);
 		if (server->ops->close_dir)
@@ -1519,8 +1519,20 @@ cifs_setlk(struct file *file, struct file_lock *flock, __u32 type,
 		rc = server->ops->mand_unlock_range(cfile, flock, xid);
 
 out:
-	if (flock->fl_flags & FL_POSIX)
-		posix_lock_file_wait(file, flock);
+	if (flock->fl_flags & FL_POSIX) {
+		/*
+		 * If this is a request to remove all locks because we
+		 * are closing the file, it doesn't matter if the
+		 * unlocking failed as both cifs.ko and the SMB server
+		 * remove the lock on file close
+		 */
+		if (rc) {
+			cifs_dbg(VFS, "%s failed rc=%d\n", __func__, rc);
+			if (!(flock->fl_flags & FL_CLOSE))
+				return rc;
+		}
+		rc = posix_lock_file_wait(file, flock);
+	}
 	return rc;
 }
 
@@ -1789,6 +1801,7 @@ refind_writable:
 			cifsFileInfo_put(inv_file);
 			spin_lock(&cifs_file_list_lock);
 			++refind;
+			inv_file = NULL;
 			goto refind_writable;
 		}
 	}
@@ -2353,7 +2366,7 @@ cifs_iovec_write(struct file *file, const struct iovec *iov,
 		 unsigned long nr_segs, loff_t *poffset)
 {
 	unsigned long nr_pages, i;
-	size_t copied, len, cur_len;
+	size_t bytes, copied, len, cur_len;
 	ssize_t total_written = 0;
 	loff_t offset;
 	struct iov_iter it;
@@ -2408,14 +2421,45 @@ cifs_iovec_write(struct file *file, const struct iovec *iov,
 
 		save_len = cur_len;
 		for (i = 0; i < nr_pages; i++) {
-			copied = min_t(const size_t, cur_len, PAGE_SIZE);
+			bytes = min_t(const size_t, cur_len, PAGE_SIZE);
 			copied = iov_iter_copy_from_user(wdata->pages[i], &it,
-							 0, copied);
+							 0, bytes);
 			cur_len -= copied;
 			iov_iter_advance(&it, copied);
+			/*
+			 * If we didn't copy as much as we expected, then that
+			 * may mean we trod into an unmapped area. Stop copying
+			 * at that point. On the next pass through the big
+			 * loop, we'll likely end up getting a zero-length
+			 * write and bailing out of it.
+			 */
+			if (copied < bytes)
+				break;
 		}
 		cur_len = save_len - cur_len;
 
+		/*
+		 * If we have no data to send, then that probably means that
+		 * the copy above failed altogether. That's most likely because
+		 * the address in the iovec was bogus. Set the rc to -EFAULT,
+		 * free anything we allocated and bail out.
+		 */
+		if (!cur_len) {
+			for (i = 0; i < nr_pages; i++)
+				put_page(wdata->pages[i]);
+			kfree(wdata);
+			rc = -EFAULT;
+			break;
+		}
+
+		/*
+		 * i + 1 now represents the number of pages we actually used in
+		 * the copy phase above. Bring nr_pages down to that, and free
+		 * any pages that we didn't use.
+		 */
+		for ( ; nr_pages > i + 1; nr_pages--)
+			put_page(wdata->pages[nr_pages - 1]);
+
 		wdata->sync_mode = WB_SYNC_ALL;
 		wdata->nr_pages = nr_pages;
 		wdata->offset = (__u64)offset;
@@ -2778,7 +2822,7 @@ cifs_uncached_read_into_pages(struct TCP_Server_Info *server,
 		total_read += result;
 	}
 
-	return total_read > 0 ? total_read : result;
+	return total_read > 0 && result != -EAGAIN ? total_read : result;
 }
 
 static ssize_t
@@ -3201,7 +3245,7 @@ cifs_readpages_read_into_pages(struct TCP_Server_Info *server,
 		total_read += result;
 	}
 
-	return total_read > 0 ? total_read : result;
+	return total_read > 0 && result != -EAGAIN ? total_read : result;
 }
 
 static int cifs_readpages(struct file *file, struct address_space *mapping,
diff --git a/fs/cifs/inode.c b/fs/cifs/inode.c
index 449b6cf..5416bc8 100644
--- a/fs/cifs/inode.c
+++ b/fs/cifs/inode.c
@@ -490,10 +490,15 @@ static int cifs_sfu_mode(struct cifs_fattr *fattr, const unsigned char *path,
 		return PTR_ERR(tlink);
 	tcon = tlink_tcon(tlink);
 
-	rc = CIFSSMBQAllEAs(xid, tcon, path, "SETFILEBITS",
-			    ea_value, 4 /* size of buf */, cifs_sb->local_nls,
-			    cifs_sb->mnt_cifs_flags &
-				CIFS_MOUNT_MAP_SPECIAL_CHR);
+	if (tcon->ses->server->ops->query_all_EAs == NULL) {
+		cifs_put_tlink(tlink);
+		return -EOPNOTSUPP;
+	}
+
+	rc = tcon->ses->server->ops->query_all_EAs(xid, tcon, path,
+			"SETFILEBITS", ea_value, 4 /* size of buf */,
+			cifs_sb->local_nls,
+			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
 	cifs_put_tlink(tlink);
 	if (rc < 0)
 		return (int)rc;
@@ -890,12 +895,29 @@ struct inode *cifs_root_iget(struct super_block *sb)
 	struct inode *inode = NULL;
 	long rc;
 	struct cifs_tcon *tcon = cifs_sb_master_tcon(cifs_sb);
+	char *path = NULL;
+	int len;
+
+	if ((cifs_sb->mnt_cifs_flags & CIFS_MOUNT_USE_PREFIX_PATH)
+	    && cifs_sb->prepath) {
+		len = strlen(cifs_sb->prepath);
+		path = kzalloc(len + 2 /* leading sep + null */, GFP_KERNEL);
+		if (path == NULL)
+			return ERR_PTR(-ENOMEM);
+		path[0] = '/';
+		memcpy(path+1, cifs_sb->prepath, len);
+	} else {
+		path = kstrdup("", GFP_KERNEL);
+		if (path == NULL)
+			return ERR_PTR(-ENOMEM);
+	}
 
 	xid = get_xid();
+	convert_delimiter(path, CIFS_DIR_SEP(cifs_sb));
 	if (tcon->unix_ext)
-		rc = cifs_get_inode_info_unix(&inode, "", sb, xid);
+		rc = cifs_get_inode_info_unix(&inode, path, sb, xid);
 	else
-		rc = cifs_get_inode_info(&inode, "", NULL, sb, xid, NULL);
+		rc = cifs_get_inode_info(&inode, path, NULL, sb, xid, NULL);
 
 	if (!inode) {
 		inode = ERR_PTR(rc);
@@ -923,6 +945,7 @@ struct inode *cifs_root_iget(struct super_block *sb)
 	}
 
 out:
+	kfree(path);
 	/* can not call macro free_xid here since in a void func
 	 * TODO: This is no longer true
 	 */
@@ -1635,13 +1658,22 @@ cifs_rename(struct inode *source_dir, struct dentry *source_dentry,
 unlink_target:
 	/* Try unlinking the target dentry if it's not negative */
 	if (target_dentry->d_inode && (rc == -EACCES || rc == -EEXIST)) {
-		tmprc = cifs_unlink(target_dir, target_dentry);
+		if (S_ISDIR(target_dentry->d_inode->i_mode))
+			tmprc = cifs_rmdir(target_dir, target_dentry);
+		else
+			tmprc = cifs_unlink(target_dir, target_dentry);
 		if (tmprc)
 			goto cifs_rename_exit;
 		rc = cifs_do_rename(xid, source_dentry, from_name,
 				    target_dentry, to_name);
 	}
 
+	/* force revalidate to go get info when needed */
+	CIFS_I(source_dir)->time = CIFS_I(target_dir)->time = 0;
+
+	source_dir->i_ctime = source_dir->i_mtime = target_dir->i_ctime =
+		target_dir->i_mtime = current_fs_time(source_dir->i_sb);
+
 cifs_rename_exit:
 	kfree(info_buf_source);
 	kfree(from_name);
@@ -1726,6 +1758,7 @@ int cifs_revalidate_dentry_attr(struct dentry *dentry)
 	struct inode *inode = dentry->d_inode;
 	struct super_block *sb = dentry->d_sb;
 	char *full_path = NULL;
+	int count = 0;
 
 	if (inode == NULL)
 		return -ENOENT;
@@ -1747,15 +1780,18 @@ int cifs_revalidate_dentry_attr(struct dentry *dentry)
 		 full_path, inode, inode->i_count.counter,
 		 dentry, dentry->d_time, jiffies);
 
+again:
 	if (cifs_sb_master_tcon(CIFS_SB(sb))->unix_ext)
 		rc = cifs_get_inode_info_unix(&inode, full_path, sb, xid);
 	else
 		rc = cifs_get_inode_info(&inode, full_path, NULL, sb,
 					 xid, NULL);
-
+	if (rc == -EAGAIN && count++ < 10)
+		goto again;
 out:
 	kfree(full_path);
 	free_xid(xid);
+
 	return rc;
 }
 
diff --git a/fs/cifs/readdir.c b/fs/cifs/readdir.c
index 036279c..85ebdaa 100644
--- a/fs/cifs/readdir.c
+++ b/fs/cifs/readdir.c
@@ -582,11 +582,11 @@ find_cifs_entry(const unsigned int xid, struct cifs_tcon *tcon,
 		/* close and restart search */
 		cifs_dbg(FYI, "search backing up - close and restart search\n");
 		spin_lock(&cifs_file_list_lock);
-		if (!cfile->srch_inf.endOfSearch && !cfile->invalidHandle) {
+		if (server->ops->dir_needs_close(cfile)) {
 			cfile->invalidHandle = true;
 			spin_unlock(&cifs_file_list_lock);
-			if (server->ops->close)
-				server->ops->close(xid, tcon, &cfile->fid);
+			if (server->ops->close_dir)
+				server->ops->close_dir(xid, tcon, &cfile->fid);
 		} else
 			spin_unlock(&cifs_file_list_lock);
 		if (cfile->srch_inf.ntwrk_buf_start) {
diff --git a/fs/cifs/sess.c b/fs/cifs/sess.c
index 8edc9eb..d65e16e 100644
--- a/fs/cifs/sess.c
+++ b/fs/cifs/sess.c
@@ -487,19 +487,27 @@ int build_ntlmssp_auth_blob(unsigned char *pbuffer,
 	sec_blob->LmChallengeResponse.MaximumLength = 0;
 
 	sec_blob->NtChallengeResponse.BufferOffset = cpu_to_le32(tmp - pbuffer);
-	rc = setup_ntlmv2_rsp(ses, nls_cp);
-	if (rc) {
-		cifs_dbg(VFS, "Error %d during NTLMSSP authentication\n", rc);
-		goto setup_ntlmv2_ret;
-	}
-	memcpy(tmp, ses->auth_key.response + CIFS_SESS_KEY_SIZE,
-			ses->auth_key.len - CIFS_SESS_KEY_SIZE);
-	tmp += ses->auth_key.len - CIFS_SESS_KEY_SIZE;
+	if (ses->user_name != NULL) {
+		rc = setup_ntlmv2_rsp(ses, nls_cp);
+		if (rc) {
+			cifs_dbg(VFS, "Error %d during NTLMSSP authentication\n", rc);
+			goto setup_ntlmv2_ret;
+		}
+		memcpy(tmp, ses->auth_key.response + CIFS_SESS_KEY_SIZE,
+				ses->auth_key.len - CIFS_SESS_KEY_SIZE);
+		tmp += ses->auth_key.len - CIFS_SESS_KEY_SIZE;
 
-	sec_blob->NtChallengeResponse.Length =
-			cpu_to_le16(ses->auth_key.len - CIFS_SESS_KEY_SIZE);
-	sec_blob->NtChallengeResponse.MaximumLength =
-			cpu_to_le16(ses->auth_key.len - CIFS_SESS_KEY_SIZE);
+		sec_blob->NtChallengeResponse.Length =
+				cpu_to_le16(ses->auth_key.len - CIFS_SESS_KEY_SIZE);
+		sec_blob->NtChallengeResponse.MaximumLength =
+				cpu_to_le16(ses->auth_key.len - CIFS_SESS_KEY_SIZE);
+	} else {
+		/*
+		 * don't send an NT Response for anonymous access
+		 */
+		sec_blob->NtChallengeResponse.Length = 0;
+		sec_blob->NtChallengeResponse.MaximumLength = 0;
+	}
 
 	if (ses->domainName == NULL) {
 		sec_blob->DomainName.BufferOffset = cpu_to_le32(tmp - pbuffer);
diff --git a/fs/cifs/smb1ops.c b/fs/cifs/smb1ops.c
index 3efdb9d..d97841e 100644
--- a/fs/cifs/smb1ops.c
+++ b/fs/cifs/smb1ops.c
@@ -885,6 +885,21 @@ cifs_mand_lock(const unsigned int xid, struct cifsFileInfo *cfile, __u64 offset,
 			   (__u8)type, wait, 0);
 }
 
+static bool
+cifs_dir_needs_close(struct cifsFileInfo *cfile)
+{
+	return !cfile->srch_inf.endOfSearch && !cfile->invalidHandle;
+}
+
+static bool
+cifs_can_echo(struct TCP_Server_Info *server)
+{
+	if (server->tcpStatus == CifsGood)
+		return true;
+
+	return false;
+}
+
 struct smb_version_operations smb1_operations = {
 	.send_cancel = send_nt_cancel,
 	.compare_fids = cifs_compare_fids,
@@ -917,6 +932,7 @@ struct smb_version_operations smb1_operations = {
 	.get_dfs_refer = CIFSGetDFSRefer,
 	.qfs_tcon = cifs_qfs_tcon,
 	.is_path_accessible = cifs_is_path_accessible,
+	.can_echo = cifs_can_echo,
 	.query_path_info = cifs_query_path_info,
 	.query_file_info = cifs_query_file_info,
 	.get_srv_inum = cifs_get_srv_inum,
@@ -948,6 +964,15 @@ struct smb_version_operations smb1_operations = {
 	.mand_lock = cifs_mand_lock,
 	.mand_unlock_range = cifs_unlock_range,
 	.push_mand_locks = cifs_push_mandatory_locks,
+	.dir_needs_close = cifs_dir_needs_close,
+#ifdef CONFIG_CIFS_XATTR
+	.query_all_EAs = CIFSSMBQAllEAs,
+	.set_EA = CIFSSMBSetEA,
+#endif /* CIFS_XATTR */
+#ifdef CONFIG_CIFS_ACL
+	.get_acl = get_cifs_acl,
+	.set_acl = set_cifs_acl,
+#endif /* CIFS_ACL */
 };
 
 struct smb_version_values smb1_values = {
diff --git a/fs/cifs/smb2file.c b/fs/cifs/smb2file.c
index 5da1b55..866caf1 100644
--- a/fs/cifs/smb2file.c
+++ b/fs/cifs/smb2file.c
@@ -73,7 +73,7 @@ smb2_open_file(const unsigned int xid, struct cifs_tcon *tcon, const char *path,
 		goto out;
 	}
 
-	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + MAX_NAME * 2,
+	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + PATH_MAX * 2,
 			    GFP_KERNEL);
 	if (smb2_data == NULL) {
 		rc = -ENOMEM;
@@ -266,7 +266,7 @@ smb2_push_mandatory_locks(struct cifsFileInfo *cfile)
 	 * and check it for zero before using.
 	 */
 	max_buf = tlink_tcon(cfile->tlink)->ses->server->maxBuf;
-	if (!max_buf) {
+	if (max_buf < sizeof(struct smb2_lock_element)) {
 		free_xid(xid);
 		return -EINVAL;
 	}
diff --git a/fs/cifs/smb2glob.h b/fs/cifs/smb2glob.h
index 7c0e214..cc592ef 100644
--- a/fs/cifs/smb2glob.h
+++ b/fs/cifs/smb2glob.h
@@ -55,4 +55,7 @@
 #define SMB2_NTLMV2_SESSKEY_SIZE (16)
 #define SMB2_HMACSHA256_SIZE (32)
 
+/* Maximum buffer size value we can send with 1 credit */
+#define SMB2_MAX_BUFFER_SIZE 65536
+
 #endif	/* _SMB2_GLOB_H */
diff --git a/fs/cifs/smb2inode.c b/fs/cifs/smb2inode.c
index fff6dfb..6d53579 100644
--- a/fs/cifs/smb2inode.c
+++ b/fs/cifs/smb2inode.c
@@ -123,7 +123,7 @@ smb2_query_path_info(const unsigned int xid, struct cifs_tcon *tcon,
 
 	*adjust_tz = false;
 
-	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + MAX_NAME * 2,
+	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + PATH_MAX * 2,
 			    GFP_KERNEL);
 	if (smb2_data == NULL)
 		return -ENOMEM;
diff --git a/fs/cifs/smb2maperror.c b/fs/cifs/smb2maperror.c
index 7c2f45c..4768cf8 100644
--- a/fs/cifs/smb2maperror.c
+++ b/fs/cifs/smb2maperror.c
@@ -214,7 +214,7 @@ static const struct status_to_posix_error smb2_error_map_table[] = {
 	{STATUS_BREAKPOINT, -EIO, "STATUS_BREAKPOINT"},
 	{STATUS_SINGLE_STEP, -EIO, "STATUS_SINGLE_STEP"},
 	{STATUS_BUFFER_OVERFLOW, -EIO, "STATUS_BUFFER_OVERFLOW"},
-	{STATUS_NO_MORE_FILES, -EIO, "STATUS_NO_MORE_FILES"},
+	{STATUS_NO_MORE_FILES, -ENODATA, "STATUS_NO_MORE_FILES"},
 	{STATUS_WAKE_SYSTEM_DEBUGGER, -EIO, "STATUS_WAKE_SYSTEM_DEBUGGER"},
 	{STATUS_HANDLES_CLOSED, -EIO, "STATUS_HANDLES_CLOSED"},
 	{STATUS_NO_INHERITANCE, -EIO, "STATUS_NO_INHERITANCE"},
@@ -605,7 +605,7 @@ static const struct status_to_posix_error smb2_error_map_table[] = {
 	{STATUS_MAPPED_FILE_SIZE_ZERO, -EIO, "STATUS_MAPPED_FILE_SIZE_ZERO"},
 	{STATUS_TOO_MANY_OPENED_FILES, -EMFILE, "STATUS_TOO_MANY_OPENED_FILES"},
 	{STATUS_CANCELLED, -EIO, "STATUS_CANCELLED"},
-	{STATUS_CANNOT_DELETE, -EIO, "STATUS_CANNOT_DELETE"},
+	{STATUS_CANNOT_DELETE, -EACCES, "STATUS_CANNOT_DELETE"},
 	{STATUS_INVALID_COMPUTER_NAME, -EIO, "STATUS_INVALID_COMPUTER_NAME"},
 	{STATUS_FILE_DELETED, -EIO, "STATUS_FILE_DELETED"},
 	{STATUS_SPECIAL_ACCOUNT, -EIO, "STATUS_SPECIAL_ACCOUNT"},
diff --git a/fs/cifs/smb2ops.c b/fs/cifs/smb2ops.c
index f2e76f3..66202da 100644
--- a/fs/cifs/smb2ops.c
+++ b/fs/cifs/smb2ops.c
@@ -48,9 +48,13 @@ change_conf(struct TCP_Server_Info *server)
 		break;
 	default:
 		server->echoes = true;
-		server->oplocks = true;
+		if (enable_oplocks) {
+			server->oplocks = true;
+			server->oplock_credits = 1;
+		} else
+			server->oplocks = false;
+
 		server->echo_credits = 1;
-		server->oplock_credits = 1;
 	}
 	server->credits -= server->echo_credits + server->oplock_credits;
 	return 0;
@@ -181,11 +185,8 @@ smb2_negotiate_wsize(struct cifs_tcon *tcon, struct smb_vol *volume_info)
 	/* start with specified wsize, or default */
 	wsize = volume_info->wsize ? volume_info->wsize : CIFS_DEFAULT_IOSIZE;
 	wsize = min_t(unsigned int, wsize, server->max_write);
-	/*
-	 * limit write size to 2 ** 16, because we don't support multicredit
-	 * requests now.
-	 */
-	wsize = min_t(unsigned int, wsize, 2 << 15);
+	/* set it to the maximum buffer size value we can send with 1 credit */
+	wsize = min_t(unsigned int, wsize, SMB2_MAX_BUFFER_SIZE);
 
 	return wsize;
 }
@@ -199,11 +200,8 @@ smb2_negotiate_rsize(struct cifs_tcon *tcon, struct smb_vol *volume_info)
 	/* start with specified rsize, or default */
 	rsize = volume_info->rsize ? volume_info->rsize : CIFS_DEFAULT_IOSIZE;
 	rsize = min_t(unsigned int, rsize, server->max_read);
-	/*
-	 * limit write size to 2 ** 16, because we don't support multicredit
-	 * requests now.
-	 */
-	rsize = min_t(unsigned int, rsize, 2 << 15);
+	/* set it to the maximum buffer size value we can send with 1 credit */
+	rsize = min_t(unsigned int, rsize, SMB2_MAX_BUFFER_SIZE);
 
 	return rsize;
 }
@@ -249,7 +247,7 @@ smb2_query_file_info(const unsigned int xid, struct cifs_tcon *tcon,
 	int rc;
 	struct smb2_file_all_info *smb2_data;
 
-	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + MAX_NAME * 2,
+	smb2_data = kzalloc(sizeof(struct smb2_file_all_info) + PATH_MAX * 2,
 			    GFP_KERNEL);
 	if (smb2_data == NULL)
 		return -ENOMEM;
@@ -560,6 +558,12 @@ smb2_new_lease_key(struct cifs_fid *fid)
 	get_random_bytes(fid->lease_key, SMB2_LEASE_KEY_SIZE);
 }
 
+static bool
+smb2_dir_needs_close(struct cifsFileInfo *cfile)
+{
+	return !cfile->invalidHandle;
+}
+
 struct smb_version_operations smb21_operations = {
 	.compare_fids = smb2_compare_fids,
 	.setup_request = smb2_setup_request,
@@ -624,6 +628,7 @@ struct smb_version_operations smb21_operations = {
 	.set_lease_key = smb2_set_lease_key,
 	.new_lease_key = smb2_new_lease_key,
 	.calc_signature = smb2_calc_signature,
+	.dir_needs_close = smb2_dir_needs_close,
 };
 
 
@@ -691,6 +696,7 @@ struct smb_version_operations smb30_operations = {
 	.set_lease_key = smb2_set_lease_key,
 	.new_lease_key = smb2_new_lease_key,
 	.calc_signature = smb3_calc_signature,
+	.dir_needs_close = smb2_dir_needs_close,
 };
 
 struct smb_version_values smb20_values = {
diff --git a/fs/cifs/smb2pdu.c b/fs/cifs/smb2pdu.c
index 2b95ce2b..67b26b7 100644
--- a/fs/cifs/smb2pdu.c
+++ b/fs/cifs/smb2pdu.c
@@ -254,7 +254,7 @@ out:
 	case SMB2_CHANGE_NOTIFY:
 	case SMB2_QUERY_INFO:
 	case SMB2_SET_INFO:
-		return -EAGAIN;
+		rc = -EAGAIN;
 	}
 	unload_nls(nls_codepage);
 	return rc;
@@ -408,6 +408,9 @@ SMB2_negotiate(const unsigned int xid, struct cifs_ses *ses)
 	server->dialect = le16_to_cpu(rsp->DialectRevision);
 
 	server->maxBuf = le32_to_cpu(rsp->MaxTransactSize);
+	/* set it to the maximum buffer size value we can send with 1 credit */
+	server->maxBuf = min_t(unsigned int, le32_to_cpu(rsp->MaxTransactSize),
+			       SMB2_MAX_BUFFER_SIZE);
 	server->max_read = le32_to_cpu(rsp->MaxReadSize);
 	server->max_write = le32_to_cpu(rsp->MaxWriteSize);
 	/* BB Do we need to validate the SecurityMode? */
@@ -717,9 +720,6 @@ SMB2_tcon(const unsigned int xid, struct cifs_ses *ses, const char *tree,
 	else
 		return -EIO;
 
-	if (tcon && tcon->bad_network_name)
-		return -ENOENT;
-
 	unc_path = kmalloc(MAX_SHARENAME_LENGTH * 2, GFP_KERNEL);
 	if (unc_path == NULL)
 		return -ENOMEM;
@@ -731,6 +731,10 @@ SMB2_tcon(const unsigned int xid, struct cifs_ses *ses, const char *tree,
 		return -EINVAL;
 	}
 
+	/* SMB2 TREE_CONNECT request must be called with TreeId == 0 */
+	if (tcon)
+		tcon->tid = 0;
+
 	rc = small_smb2_init(SMB2_TREE_CONNECT, tcon, (void **) &req);
 	if (rc) {
 		kfree(unc_path);
@@ -806,7 +810,6 @@ tcon_exit:
 tcon_error_exit:
 	if (rsp->hdr.Status == STATUS_BAD_NETWORK_NAME) {
 		cifs_dbg(VFS, "BAD_NETWORK_NAME: %s\n", tree);
-		tcon->bad_network_name = true;
 	}
 	goto tcon_exit;
 }
@@ -959,8 +962,10 @@ SMB2_open(const unsigned int xid, struct cifs_tcon *tcon, __le16 *path,
 				copy_size += 8;
 
 			copy_path = kzalloc(copy_size, GFP_KERNEL);
-			if (!copy_path)
+			if (!copy_path) {
+				cifs_small_buf_release(req);
 				return -ENOMEM;
+			}
 			memcpy((char *)copy_path, (const char *)path,
 				uni_path_len);
 			uni_path_len = copy_size;
@@ -1200,7 +1205,7 @@ SMB2_query_info(const unsigned int xid, struct cifs_tcon *tcon,
 {
 	return query_info(xid, tcon, persistent_fid, volatile_fid,
 			  FILE_ALL_INFORMATION,
-			  sizeof(struct smb2_file_all_info) + MAX_NAME * 2,
+			  sizeof(struct smb2_file_all_info) + PATH_MAX * 2,
 			  sizeof(struct smb2_file_all_info), data);
 }
 
@@ -1235,6 +1240,54 @@ smb2_echo_callback(struct mid_q_entry *mid)
 	add_credits(server, credits_received, CIFS_ECHO_OP);
 }
 
+void smb2_reconnect_server(struct work_struct *work)
+{
+	struct TCP_Server_Info *server = container_of(work,
+					struct TCP_Server_Info, reconnect.work);
+	struct cifs_ses *ses;
+	struct cifs_tcon *tcon, *tcon2;
+	struct list_head tmp_list;
+	int tcon_exist = false;
+
+	/* Prevent simultaneous reconnects that can corrupt tcon->rlist list */
+	mutex_lock(&server->reconnect_mutex);
+
+	INIT_LIST_HEAD(&tmp_list);
+	cifs_dbg(FYI, "Need negotiate, reconnecting tcons\n");
+
+	spin_lock(&cifs_tcp_ses_lock);
+	list_for_each_entry(ses, &server->smb_ses_list, smb_ses_list) {
+		list_for_each_entry(tcon, &ses->tcon_list, tcon_list) {
+			if (tcon->need_reconnect) {
+				tcon->tc_count++;
+				list_add_tail(&tcon->rlist, &tmp_list);
+				tcon_exist = true;
+			}
+		}
+	}
+	/*
+	 * Get the reference to server struct to be sure that the last call of
+	 * cifs_put_tcon() in the loop below won't release the server pointer.
+	 */
+	if (tcon_exist)
+		server->srv_count++;
+
+	spin_unlock(&cifs_tcp_ses_lock);
+
+	list_for_each_entry_safe(tcon, tcon2, &tmp_list, rlist) {
+		smb2_reconnect(SMB2_ECHO, tcon);
+		list_del_init(&tcon->rlist);
+		cifs_put_tcon(tcon);
+	}
+
+	cifs_dbg(FYI, "Reconnecting tcons finished\n");
+	mutex_unlock(&server->reconnect_mutex);
+
+	/* now we can safely release srv struct */
+	if (tcon_exist)
+		cifs_put_tcp_session(server, 1);
+}
+
 int
 SMB2_echo(struct TCP_Server_Info *server)
 {
@@ -1246,6 +1299,12 @@ SMB2_echo(struct TCP_Server_Info *server)
 
 	cifs_dbg(FYI, "In echo request\n");
 
+	if (server->tcpStatus == CifsNeedNegotiate) {
+		/* No need to send echo on newly established connections */
+		queue_delayed_work(cifsiod_wq, &server->reconnect, 0);
+		return rc;
+	}
+
 	rc = small_smb2_init(SMB2_ECHO, NULL, (void **)&req);
 	if (rc)
 		return rc;
@@ -1796,6 +1855,10 @@ SMB2_query_directory(const unsigned int xid, struct cifs_tcon *tcon,
 	rsp = (struct smb2_query_directory_rsp *)iov[0].iov_base;
 
 	if (rc) {
+		if (rc == -ENODATA && rsp->hdr.Status == STATUS_NO_MORE_FILES) {
+			srch_inf->endOfSearch = true;
+			rc = 0;
+		}
 		cifs_stats_fail_inc(tcon, SMB2_QUERY_DIRECTORY_HE);
 		goto qdir_exit;
 	}
@@ -1833,11 +1896,6 @@ SMB2_query_directory(const unsigned int xid, struct cifs_tcon *tcon,
 	else
 		cifs_dbg(VFS, "illegal search buffer type\n");
 
-	if (rsp->hdr.Status == STATUS_NO_MORE_FILES)
-		srch_inf->endOfSearch = 1;
-	else
-		srch_inf->endOfSearch = 0;
-
 	return rc;
 
 qdir_exit:
diff --git a/fs/cifs/smb2proto.h b/fs/cifs/smb2proto.h
index 2aa3535..d0cd166 100644
--- a/fs/cifs/smb2proto.h
+++ b/fs/cifs/smb2proto.h
@@ -93,6 +93,7 @@ extern void smb2_set_oplock_level(struct cifsInodeInfo *cinode, __u32 oplock);
 extern int smb2_unlock_range(struct cifsFileInfo *cfile,
 			     struct file_lock *flock, const unsigned int xid);
 extern int smb2_push_mandatory_locks(struct cifsFileInfo *cfile);
+extern void smb2_reconnect_server(struct work_struct *work);
 
 /*
  * SMB2 Worker functions - most of protocol specific implementation details
diff --git a/fs/cifs/xattr.c b/fs/cifs/xattr.c
index 09afda4..5ac836a 100644
--- a/fs/cifs/xattr.c
+++ b/fs/cifs/xattr.c
@@ -82,9 +82,11 @@ int cifs_removexattr(struct dentry *direntry, const char *ea_name)
 			goto remove_ea_exit;
 
 		ea_name += XATTR_USER_PREFIX_LEN; /* skip past user. prefix */
-		rc = CIFSSMBSetEA(xid, pTcon, full_path, ea_name, NULL,
-			(__u16)0, cifs_sb->local_nls,
-			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
+		if (pTcon->ses->server->ops->set_EA)
+			rc = pTcon->ses->server->ops->set_EA(xid, pTcon,
+				full_path, ea_name, NULL, (__u16)0,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 	}
 remove_ea_exit:
 	kfree(full_path);
@@ -149,18 +151,22 @@ int cifs_setxattr(struct dentry *direntry, const char *ea_name,
 			cifs_dbg(FYI, "attempt to set cifs inode metadata\n");
 
 		ea_name += XATTR_USER_PREFIX_LEN; /* skip past user. prefix */
-		rc = CIFSSMBSetEA(xid, pTcon, full_path, ea_name, ea_value,
-			(__u16)value_size, cifs_sb->local_nls,
-			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
+		if (pTcon->ses->server->ops->set_EA)
+			rc = pTcon->ses->server->ops->set_EA(xid, pTcon,
+				full_path, ea_name, ea_value, (__u16)value_size,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 	} else if (strncmp(ea_name, XATTR_OS2_PREFIX, XATTR_OS2_PREFIX_LEN)
 		   == 0) {
 		if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_NO_XATTR)
 			goto set_ea_exit;
 
 		ea_name += XATTR_OS2_PREFIX_LEN; /* skip past os2. prefix */
-		rc = CIFSSMBSetEA(xid, pTcon, full_path, ea_name, ea_value,
-			(__u16)value_size, cifs_sb->local_nls,
-			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
+		if (pTcon->ses->server->ops->set_EA)
+			rc = pTcon->ses->server->ops->set_EA(xid, pTcon,
+				full_path, ea_name, ea_value, (__u16)value_size,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 	} else if (strncmp(ea_name, CIFS_XATTR_CIFS_ACL,
 			strlen(CIFS_XATTR_CIFS_ACL)) == 0) {
 #ifdef CONFIG_CIFS_ACL
@@ -170,8 +176,12 @@ int cifs_setxattr(struct dentry *direntry, const char *ea_name,
 			rc = -ENOMEM;
 		} else {
 			memcpy(pacl, ea_value, value_size);
-			rc = set_cifs_acl(pacl, value_size,
-				direntry->d_inode, full_path, CIFS_ACL_DACL);
+			if (pTcon->ses->server->ops->set_acl)
+				rc = pTcon->ses->server->ops->set_acl(pacl,
+						value_size, direntry->d_inode,
+						full_path, CIFS_ACL_DACL);
+			else
+				rc = -EOPNOTSUPP;
 			if (rc == 0) /* force revalidate of the inode */
 				CIFS_I(direntry->d_inode)->time = 0;
 			kfree(pacl);
@@ -272,17 +282,21 @@ ssize_t cifs_getxattr(struct dentry *direntry, const char *ea_name,
 			/* revalidate/getattr then populate from inode */
 		} /* BB add else when above is implemented */
 		ea_name += XATTR_USER_PREFIX_LEN; /* skip past user. prefix */
-		rc = CIFSSMBQAllEAs(xid, pTcon, full_path, ea_name, ea_value,
-			buf_size, cifs_sb->local_nls,
-			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
+		if (pTcon->ses->server->ops->query_all_EAs)
+			rc = pTcon->ses->server->ops->query_all_EAs(xid, pTcon,
+				full_path, ea_name, ea_value, buf_size,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 	} else if (strncmp(ea_name, XATTR_OS2_PREFIX, XATTR_OS2_PREFIX_LEN) == 0) {
 		if (cifs_sb->mnt_cifs_flags & CIFS_MOUNT_NO_XATTR)
 			goto get_ea_exit;
 
 		ea_name += XATTR_OS2_PREFIX_LEN; /* skip past os2. prefix */
-		rc = CIFSSMBQAllEAs(xid, pTcon, full_path, ea_name, ea_value,
-			buf_size, cifs_sb->local_nls,
-			cifs_sb->mnt_cifs_flags & CIFS_MOUNT_MAP_SPECIAL_CHR);
+		if (pTcon->ses->server->ops->query_all_EAs)
+			rc = pTcon->ses->server->ops->query_all_EAs(xid, pTcon,
+				full_path, ea_name, ea_value, buf_size,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 	} else if (strncmp(ea_name, POSIX_ACL_XATTR_ACCESS,
 			  strlen(POSIX_ACL_XATTR_ACCESS)) == 0) {
 #ifdef CONFIG_CIFS_POSIX
@@ -313,8 +327,11 @@ ssize_t cifs_getxattr(struct dentry *direntry, const char *ea_name,
 			u32 acllen;
 			struct cifs_ntsd *pacl;
 
-			pacl = get_cifs_acl(cifs_sb, direntry->d_inode,
-						full_path, &acllen);
+			if (pTcon->ses->server->ops->get_acl == NULL)
+				goto get_ea_exit; /* rc already EOPNOTSUPP */
+
+			pacl = pTcon->ses->server->ops->get_acl(cifs_sb,
+					direntry->d_inode, full_path, &acllen);
 			if (IS_ERR(pacl)) {
 				rc = PTR_ERR(pacl);
 				cifs_dbg(VFS, "%s: error %zd getting sec desc\n",
@@ -400,11 +417,12 @@ ssize_t cifs_listxattr(struct dentry *direntry, char *data, size_t buf_size)
 	/* if proc/fs/cifs/streamstoxattr is set then
 		search server for EAs or streams to
 		returns as xattrs */
-	rc = CIFSSMBQAllEAs(xid, pTcon, full_path, NULL, data,
-				buf_size, cifs_sb->local_nls,
-				cifs_sb->mnt_cifs_flags &
-					CIFS_MOUNT_MAP_SPECIAL_CHR);
 
+	if (pTcon->ses->server->ops->query_all_EAs)
+		rc = pTcon->ses->server->ops->query_all_EAs(xid, pTcon,
+				full_path, NULL, data, buf_size,
+				cifs_sb->local_nls, cifs_sb->mnt_cifs_flags &
+					CIFS_MOUNT_MAP_SPECIAL_CHR);
 list_ea_exit:
 	kfree(full_path);
 	free_xid(xid);
diff --git a/fs/ext2/super.c b/fs/ext2/super.c
index 2885349..d37aace 100644
--- a/fs/ext2/super.c
+++ b/fs/ext2/super.c
@@ -829,7 +829,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 	sbi->s_es = es;
 	sb->s_magic = le16_to_cpu(es->s_magic);
 
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if ((sb->s_magic != EXT2_SUPER_MAGIC) &&
+	    (sb->s_magic != MEL_EXT2_SUPER_MAGIC))
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if (sb->s_magic != EXT2_SUPER_MAGIC)
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		goto cantfind_ext2;
 
 	/* Set defaults before we parse the mount options */
@@ -927,7 +932,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 		}
 		es = (struct ext2_super_block *) (((char *)bh->b_data) + offset);
 		sbi->s_es = es;
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+		if ((sb->s_magic != cpu_to_le16(EXT2_SUPER_MAGIC)) &&
+		    (sb->s_magic != cpu_to_le16(MEL_EXT2_SUPER_MAGIC))) {
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		if (es->s_magic != cpu_to_le16(EXT2_SUPER_MAGIC)) {
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 			ext2_msg(sb, KERN_ERR, "error: magic mismatch");
 			goto failed_mount;
 		}
@@ -978,7 +988,12 @@ static int ext2_fill_super(struct super_block *sb, void *data, int silent)
 	sbi->s_desc_per_block_bits =
 		ilog2 (EXT2_DESC_PER_BLOCK(sb));
 
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if ((sb->s_magic != EXT2_SUPER_MAGIC) &&
+	    (sb->s_magic != MEL_EXT2_SUPER_MAGIC))
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if (sb->s_magic != EXT2_SUPER_MAGIC)
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		goto cantfind_ext2;
 
 	if (sb->s_blocksize != bh->b_size) {
diff --git a/fs/ext3/super.c b/fs/ext3/super.c
index 6356665..d143e18 100644
--- a/fs/ext3/super.c
+++ b/fs/ext3/super.c
@@ -1690,7 +1690,12 @@ static int ext3_fill_super (struct super_block *sb, void *data, int silent)
 	es = (struct ext3_super_block *) (bh->b_data + offset);
 	sbi->s_es = es;
 	sb->s_magic = le16_to_cpu(es->s_magic);
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if ((sb->s_magic != EXT3_SUPER_MAGIC) &&
+	    (sb->s_magic != MEL_EXT3_SUPER_MAGIC))
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if (sb->s_magic != EXT3_SUPER_MAGIC)
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		goto cantfind_ext3;
 
 	/* Set defaults before we parse the mount options */
@@ -1802,7 +1807,12 @@ static int ext3_fill_super (struct super_block *sb, void *data, int silent)
 		}
 		es = (struct ext3_super_block *)(bh->b_data + offset);
 		sbi->s_es = es;
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+		if ((es->s_magic != le16_to_cpu(EXT3_SUPER_MAGIC)) &&
+		    (es->s_magic != le16_to_cpu(MEL_EXT3_SUPER_MAGIC))) {
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 		if (es->s_magic != cpu_to_le16(EXT3_SUPER_MAGIC)) {
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 			ext3_msg(sb, KERN_ERR,
 				"error: magic mismatch");
 			goto failed_mount;
@@ -2200,7 +2210,12 @@ static journal_t *ext3_get_dev_journal(struct super_block *sb,
 	}
 
 	es = (struct ext3_super_block *) (bh->b_data + offset);
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+	if (((le16_to_cpu(es->s_magic) != EXT3_SUPER_MAGIC) &&
+	     (le16_to_cpu(es->s_magic) != MEL_EXT3_SUPER_MAGIC)) ||
+#else	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	if ((le16_to_cpu(es->s_magic) != EXT3_SUPER_MAGIC) ||
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 	    !(le32_to_cpu(es->s_feature_incompat) &
 	      EXT3_FEATURE_INCOMPAT_JOURNAL_DEV)) {
 		ext3_msg(sb, KERN_ERR, "error: external journal has "
diff --git a/fs/fs-writeback.c b/fs/fs-writeback.c
index 3be5718..7d47104 100644
--- a/fs/fs-writeback.c
+++ b/fs/fs-writeback.c
@@ -87,16 +87,29 @@ static inline struct inode *wb_inode(struct list_head *head)
 #define CREATE_TRACE_POINTS
 #include <trace/events/writeback.h>
 
+static void bdi_wakeup_thread(struct backing_dev_info *bdi)
+{
+	spin_lock_bh(&bdi->wb_lock);
+	if (test_bit(BDI_registered, &bdi->state))
+		mod_delayed_work(bdi_wq, &bdi->wb.dwork, 0);
+	spin_unlock_bh(&bdi->wb_lock);
+}
+
 static void bdi_queue_work(struct backing_dev_info *bdi,
 			   struct wb_writeback_work *work)
 {
 	trace_writeback_queue(bdi, work);
 
 	spin_lock_bh(&bdi->wb_lock);
+	if (!test_bit(BDI_registered, &bdi->state)) {
+		if (work->done)
+			complete(work->done);
+		goto out_unlock;
+	}
 	list_add_tail(&work->list, &bdi->work_list);
-	spin_unlock_bh(&bdi->wb_lock);
-
 	mod_delayed_work(bdi_wq, &bdi->wb.dwork, 0);
+out_unlock:
+	spin_unlock_bh(&bdi->wb_lock);
 }
 
 static void
@@ -112,7 +125,7 @@ __bdi_start_writeback(struct backing_dev_info *bdi, long nr_pages,
 	work = kzalloc(sizeof(*work), GFP_ATOMIC);
 	if (!work) {
 		trace_writeback_nowork(bdi);
-		mod_delayed_work(bdi_wq, &bdi->wb.dwork, 0);
+		bdi_wakeup_thread(bdi);
 		return;
 	}
 
@@ -159,7 +172,7 @@ void bdi_start_background_writeback(struct backing_dev_info *bdi)
 	 * writeback as soon as there is no other work to do.
 	 */
 	trace_writeback_wake_background(bdi);
-	mod_delayed_work(bdi_wq, &bdi->wb.dwork, 0);
+	bdi_wakeup_thread(bdi);
 }
 
 /*
@@ -1013,7 +1026,7 @@ void bdi_writeback_workfn(struct work_struct *work)
 	current->flags |= PF_SWAPWRITE;
 
 	if (likely(!current_is_workqueue_rescuer() ||
-		   list_empty(&bdi->bdi_list))) {
+		   !test_bit(BDI_registered, &bdi->state))) {
 		/*
 		 * The normal path.  Keep writing back @bdi until its
 		 * work_list is empty.  Note that this path is also taken
@@ -1035,10 +1048,10 @@ void bdi_writeback_workfn(struct work_struct *work)
 		trace_writeback_pages_written(pages_written);
 	}
 
-	if (!list_empty(&bdi->work_list) ||
-	    (wb_has_dirty_io(wb) && dirty_writeback_interval))
-		queue_delayed_work(bdi_wq, &wb->dwork,
-			msecs_to_jiffies(dirty_writeback_interval * 10));
+	if (!list_empty(&bdi->work_list))
+		mod_delayed_work(bdi_wq, &wb->dwork, 0);
+	else if (wb_has_dirty_io(wb) && dirty_writeback_interval)
+		bdi_wakeup_thread_delayed(bdi);
 
 	current->flags &= ~PF_SWAPWRITE;
 }
diff --git a/fs/fscache/page.c b/fs/fscache/page.c
index ff000e5..54aab33 100644
--- a/fs/fscache/page.c
+++ b/fs/fscache/page.c
@@ -875,7 +875,7 @@ int __fscache_write_page(struct fscache_cookie *cookie,
 			       fscache_release_write_op);
 	op->op.flags = FSCACHE_OP_ASYNC | (1 << FSCACHE_OP_WAITING);
 
-	ret = radix_tree_preload(gfp & ~__GFP_HIGHMEM);
+	ret = radix_tree_maybe_preload(gfp & ~__GFP_HIGHMEM);
 	if (ret < 0)
 		goto nomem_free;
 
diff --git a/fs/nfsd/nfscache.c b/fs/nfsd/nfscache.c
index e76244e..02e8e9a 100644
--- a/fs/nfsd/nfscache.c
+++ b/fs/nfsd/nfscache.c
@@ -395,22 +395,8 @@ nfsd_cache_lookup(struct svc_rqst *rqstp)
 
 	/*
 	 * Since the common case is a cache miss followed by an insert,
-	 * preallocate an entry. First, try to reuse the first entry on the LRU
-	 * if it works, then go ahead and prune the LRU list.
+	 * preallocate an entry.
 	 */
-	spin_lock(&cache_lock);
-	if (!list_empty(&lru_head)) {
-		rp = list_first_entry(&lru_head, struct svc_cacherep, c_lru);
-		if (nfsd_cache_entry_expired(rp) ||
-		    num_drc_entries >= max_drc_entries) {
-			lru_put_end(rp);
-			prune_cache_entries();
-			goto search_cache;
-		}
-	}
-
-	/* No expired ones available, allocate a new one. */
-	spin_unlock(&cache_lock);
 	rp = nfsd_reply_cache_alloc();
 	spin_lock(&cache_lock);
 	if (likely(rp)) {
@@ -418,7 +404,9 @@ nfsd_cache_lookup(struct svc_rqst *rqstp)
 		drc_mem_usage += sizeof(*rp);
 	}
 
-search_cache:
+	/* go ahead and prune the cache */
+	prune_cache_entries();
+
 	found = nfsd_cache_search(rqstp, csum);
 	if (found) {
 		if (likely(rp))
@@ -432,15 +420,6 @@ search_cache:
 		goto out;
 	}
 
-	/*
-	 * We're keeping the one we just allocated. Are we now over the
-	 * limit? Prune one off the tip of the LRU in trade for the one we
-	 * just allocated if so.
-	 */
-	if (num_drc_entries >= max_drc_entries)
-		nfsd_reply_cache_free_locked(list_first_entry(&lru_head,
-						struct svc_cacherep, c_lru));
-
 	nfsdstats.rcmisses++;
 	rqstp->rq_cacherep = rp;
 	rp->c_state = RC_INPROG;
diff --git a/fs/splice.c b/fs/splice.c
index dc31faf..ce31738 100644
--- a/fs/splice.c
+++ b/fs/splice.c
@@ -1096,8 +1096,8 @@ EXPORT_SYMBOL(generic_splice_sendpage);
 /*
  * Attempt to initiate a splice from pipe to file.
  */
-static long do_splice_from(struct pipe_inode_info *pipe, struct file *out,
-			   loff_t *ppos, size_t len, unsigned int flags)
+long vfs_splice_from(struct pipe_inode_info *pipe, struct file *out,
+		     loff_t *ppos, size_t len, unsigned int flags)
 {
 	ssize_t (*splice_write)(struct pipe_inode_info *, struct file *,
 				loff_t *, size_t, unsigned int);
@@ -1123,13 +1123,14 @@ static long do_splice_from(struct pipe_inode_info *pipe, struct file *out,
 	file_end_write(out);
 	return ret;
 }
+EXPORT_SYMBOL_GPL(vfs_splice_from);
 
 /*
  * Attempt to initiate a splice from a file to a pipe.
  */
-static long do_splice_to(struct file *in, loff_t *ppos,
-			 struct pipe_inode_info *pipe, size_t len,
-			 unsigned int flags)
+long vfs_splice_to(struct file *in, loff_t *ppos,
+		   struct pipe_inode_info *pipe, size_t len,
+		   unsigned int flags)
 {
 	ssize_t (*splice_read)(struct file *, loff_t *,
 			       struct pipe_inode_info *, size_t, unsigned int);
@@ -1149,6 +1150,7 @@ static long do_splice_to(struct file *in, loff_t *ppos,
 
 	return splice_read(in, ppos, pipe, len, flags);
 }
+EXPORT_SYMBOL_GPL(vfs_splice_to);
 
 /**
  * splice_direct_to_actor - splices data directly between two non-pipes
@@ -1218,7 +1220,7 @@ ssize_t splice_direct_to_actor(struct file *in, struct splice_desc *sd,
 		size_t read_len;
 		loff_t pos = sd->pos, prev_pos = pos;
 
-		ret = do_splice_to(in, &pos, pipe, len, flags);
+		ret = vfs_splice_to(in, &pos, pipe, len, flags);
 		if (unlikely(ret <= 0))
 			goto out_release;
 
@@ -1277,8 +1279,8 @@ static int direct_splice_actor(struct pipe_inode_info *pipe,
 {
 	struct file *file = sd->u.file;
 
-	return do_splice_from(pipe, file, sd->opos, sd->total_len,
-			      sd->flags);
+	return vfs_splice_from(pipe, file, sd->opos, sd->total_len,
+			       sd->flags);
 }
 
 /**
@@ -1365,7 +1367,7 @@ static long do_splice(struct file *in, loff_t __user *off_in,
 			offset = out->f_pos;
 		}
 
-		ret = do_splice_from(ipipe, out, &offset, len, flags);
+		ret = vfs_splice_from(ipipe, out, &offset, len, flags);
 
 		if (!off_out)
 			out->f_pos = offset;
@@ -1387,7 +1389,7 @@ static long do_splice(struct file *in, loff_t __user *off_in,
 			offset = in->f_pos;
 		}
 
-		ret = do_splice_to(in, &offset, opipe, len, flags);
+		ret = vfs_splice_to(in, &offset, opipe, len, flags);
 
 		if (!off_in)
 			in->f_pos = offset;
diff --git a/fs/ubifs/file.c b/fs/ubifs/file.c
index d6960df..0e0f921 100644
--- a/fs/ubifs/file.c
+++ b/fs/ubifs/file.c
@@ -1517,8 +1517,7 @@ static int ubifs_vm_page_mkwrite(struct vm_area_struct *vma,
 	}
 
 	wait_for_stable_page(page);
-	unlock_page(page);
-	return 0;
+	return VM_FAULT_LOCKED;
 
 out_unlock:
 	unlock_page(page);
diff --git a/fs/unionfs/Kconfig b/fs/unionfs/Kconfig
new file mode 100644
index 00000000..5c35617
--- /dev/null
+++ b/fs/unionfs/Kconfig
@@ -0,0 +1,23 @@
+config UNION_FS
+	tristate "Union file system"
+	help
+	  Unionfs is a stackable unification file system, which appears to
+	  merge the contents of several directories (branches), while keeping
+	  their physical content separate.
+
+	  See <http://unionfs.filesystems.org> for details
+
+config UNION_FS_XATTR
+	bool "Unionfs extended attributes"
+	depends on UNION_FS
+	help
+	  Extended attributes are name:value pairs associated with inodes by
+	  the kernel or by users (see the attr(5) manual page).
+
+	  If unsure, say N.
+
+config UNION_FS_DEBUG
+	bool "Debug Unionfs"
+	depends on UNION_FS
+	help
+	  If you say Y here, you can turn on debugging output from Unionfs.
diff --git a/fs/unionfs/Makefile b/fs/unionfs/Makefile
new file mode 100644
index 00000000..85a3d5f
--- /dev/null
+++ b/fs/unionfs/Makefile
@@ -0,0 +1,17 @@
+UNIONFS_VERSION="2.6 (for 3.10.53)"
+
+EXTRA_CFLAGS += -DUNIONFS_VERSION=\"$(UNIONFS_VERSION)\"
+
+obj-$(CONFIG_UNION_FS) += unionfs.o
+
+unionfs-y := subr.o dentry.o file.o inode.o main.o super.o \
+	rdstate.o copyup.o dirhelper.o rename.o unlink.o \
+	lookup.o commonfops.o dirfops.o sioq.o mmap.o whiteout.o
+
+unionfs-$(CONFIG_UNION_FS_XATTR) += xattr.o
+
+unionfs-$(CONFIG_UNION_FS_DEBUG) += debug.o
+
+ifeq ($(CONFIG_UNION_FS_DEBUG),y)
+EXTRA_CFLAGS += -DDEBUG
+endif
diff --git a/fs/unionfs/commonfops.c b/fs/unionfs/commonfops.c
new file mode 100644
index 00000000..15da6c2
--- /dev/null
+++ b/fs/unionfs/commonfops.c
@@ -0,0 +1,958 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+#define __NFDBITS	(8 * sizeof(unsigned long))
+#define __FDSET_LONGS	(__FD_SETSIZE/__NFDBITS)
+static inline void __FD_SET(unsigned long __fd, __kernel_fd_set *__fdsetp)
+{
+	unsigned long __tmp = __fd / __NFDBITS;
+	unsigned long __rem = __fd % __NFDBITS;
+	__fdsetp->fds_bits[__tmp] |= (1UL<<__rem);
+}
+static inline void __FD_ZERO(__kernel_fd_set *__p)
+{
+	unsigned long *__tmp = __p->fds_bits;
+	int __i;
+
+	if (__builtin_constant_p(__FDSET_LONGS)) {
+		switch (__FDSET_LONGS) {
+		case 16:
+			__tmp[ 0] = 0; __tmp[ 1] = 0;
+			__tmp[ 2] = 0; __tmp[ 3] = 0;
+			__tmp[ 4] = 0; __tmp[ 5] = 0;
+			__tmp[ 6] = 0; __tmp[ 7] = 0;
+			__tmp[ 8] = 0; __tmp[ 9] = 0;
+			__tmp[10] = 0; __tmp[11] = 0;
+			__tmp[12] = 0; __tmp[13] = 0;
+			__tmp[14] = 0; __tmp[15] = 0;
+			return;
+
+		case 8:
+			__tmp[ 0] = 0; __tmp[ 1] = 0;
+			__tmp[ 2] = 0; __tmp[ 3] = 0;
+			__tmp[ 4] = 0; __tmp[ 5] = 0;
+			__tmp[ 6] = 0; __tmp[ 7] = 0;
+			return;
+
+		case 4:
+			__tmp[ 0] = 0; __tmp[ 1] = 0;
+			__tmp[ 2] = 0; __tmp[ 3] = 0;
+			return;
+		}
+	}
+	__i = __FDSET_LONGS;
+	while (__i) {
+		__i--;
+		*__tmp = 0;
+		__tmp++;
+	}
+}
+
+
+/*
+ * 1) Copyup the file
+ * 2) Rename the file to '.unionfs<original inode#><counter>' - obviously
+ * stolen from NFS's silly rename
+ */
+static int copyup_deleted_file(struct file *file, struct dentry *dentry,
+			       struct dentry *parent, int bstart, int bindex)
+{
+	static unsigned int counter;
+	const int i_inosize = sizeof(dentry->d_inode->i_ino) * 2;
+	const int countersize = sizeof(counter) * 2;
+	const int nlen = sizeof(".unionfs") + i_inosize + countersize - 1;
+	char name[nlen + 1];
+	int err;
+	struct dentry *tmp_dentry = NULL;
+	struct dentry *lower_dentry;
+	struct dentry *lower_dir_dentry = NULL;
+
+	lower_dentry = unionfs_lower_dentry_idx(dentry, bstart);
+
+	sprintf(name, ".unionfs%*.*lx",
+		i_inosize, i_inosize, lower_dentry->d_inode->i_ino);
+
+	/*
+	 * Loop, looking for an unused temp name to copyup to.
+	 *
+	 * It's somewhat silly that we look for a free temp tmp name in the
+	 * source branch (bstart) instead of the dest branch (bindex), where
+	 * the final name will be created.  We _will_ catch it if somehow
+	 * the name exists in the dest branch, but it'd be nice to catch it
+	 * sooner than later.
+	 */
+retry:
+	tmp_dentry = NULL;
+	do {
+		char *suffix = name + nlen - countersize;
+
+		dput(tmp_dentry);
+		counter++;
+		sprintf(suffix, "%*.*x", countersize, countersize, counter);
+
+		pr_debug("unionfs: trying to rename %s to %s\n",
+			 dentry->d_name.name, name);
+
+		tmp_dentry = lookup_lck_len(name, lower_dentry->d_parent,
+					    nlen);
+		if (IS_ERR(tmp_dentry)) {
+			err = PTR_ERR(tmp_dentry);
+			goto out;
+		}
+	} while (tmp_dentry->d_inode != NULL);	/* need negative dentry */
+	dput(tmp_dentry);
+
+	err = copyup_named_file(parent->d_inode, file, name, bstart, bindex,
+				i_size_read(file->f_path.dentry->d_inode));
+	if (err) {
+		if (unlikely(err == -EEXIST))
+			goto retry;
+		goto out;
+	}
+
+	/* bring it to the same state as an unlinked file */
+	lower_dentry = unionfs_lower_dentry_idx(dentry, dbstart(dentry));
+	if (!unionfs_lower_inode_idx(dentry->d_inode, bindex)) {
+		atomic_inc(&lower_dentry->d_inode->i_count);
+		unionfs_set_lower_inode_idx(dentry->d_inode, bindex,
+					    lower_dentry->d_inode);
+	}
+	lower_dir_dentry = lock_parent(lower_dentry);
+	err = vfs_unlink(lower_dir_dentry->d_inode, lower_dentry);
+	unlock_dir(lower_dir_dentry);
+
+out:
+	if (!err)
+		unionfs_check_dentry(dentry);
+	return err;
+}
+
+/*
+ * put all references held by upper struct file and free lower file pointer
+ * array
+ */
+static void cleanup_file(struct file *file)
+{
+	int bindex, bstart, bend;
+	struct file **lower_files;
+	struct file *lower_file;
+	struct super_block *sb = file->f_path.dentry->d_sb;
+
+	lower_files = UNIONFS_F(file)->lower_files;
+	bstart = fbstart(file);
+	bend = fbend(file);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		int i;	/* holds (possibly) updated branch index */
+		int old_bid;
+
+		lower_file = unionfs_lower_file_idx(file, bindex);
+		if (!lower_file)
+			continue;
+
+		/*
+		 * Find new index of matching branch with an open
+		 * file, since branches could have been added or
+		 * deleted causing the one with open files to shift.
+		 */
+		old_bid = UNIONFS_F(file)->saved_branch_ids[bindex];
+		i = branch_id_to_idx(sb, old_bid);
+		if (unlikely(i < 0)) {
+			printk(KERN_ERR "unionfs: no superblock for "
+			       "file %p\n", file);
+			continue;
+		}
+
+		/* decrement count of open files */
+		branchput(sb, i);
+		/*
+		 * fput will perform an mntput for us on the correct branch.
+		 * Although we're using the file's old branch configuration,
+		 * bindex, which is the old index, correctly points to the
+		 * right branch in the file's branch list.  In other words,
+		 * we're going to mntput the correct branch even if branches
+		 * have been added/removed.
+		 */
+		fput(lower_file);
+		UNIONFS_F(file)->lower_files[bindex] = NULL;
+		UNIONFS_F(file)->saved_branch_ids[bindex] = -1;
+	}
+
+	UNIONFS_F(file)->lower_files = NULL;
+	kfree(lower_files);
+	kfree(UNIONFS_F(file)->saved_branch_ids);
+	/* set to NULL because caller needs to know if to kfree on error */
+	UNIONFS_F(file)->saved_branch_ids = NULL;
+}
+
+/* open all lower files for a given file */
+static int open_all_files(struct file *file)
+{
+	int bindex, bstart, bend, err = 0;
+	struct file *lower_file;
+	struct dentry *lower_dentry;
+	struct dentry *dentry = file->f_path.dentry;
+	struct super_block *sb = dentry->d_sb;
+	struct path path;
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+
+		dget(lower_dentry);
+		unionfs_mntget(dentry, bindex);
+		branchget(sb, bindex);
+
+		path.dentry = lower_dentry;
+		path.mnt = unionfs_lower_mnt_idx(dentry, bindex);
+		lower_file = dentry_open(&path, file->f_flags, current_cred());
+		path_put(&path);
+		if (IS_ERR(lower_file)) {
+			branchput(sb, bindex);
+			err = PTR_ERR(lower_file);
+			goto out;
+		} else {
+			unionfs_set_lower_file_idx(file, bindex, lower_file);
+		}
+	}
+out:
+	return err;
+}
+
+/* open the highest priority file for a given upper file */
+static int open_highest_file(struct file *file, bool willwrite)
+{
+	int bindex, bstart, bend, err = 0;
+	struct file *lower_file;
+	struct dentry *lower_dentry;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent = dget_parent(dentry);
+	struct inode *parent_inode = parent->d_inode;
+	struct super_block *sb = dentry->d_sb;
+	struct path path;
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+	if (willwrite && IS_WRITE_FLAG(file->f_flags) && is_robranch(dentry)) {
+		for (bindex = bstart - 1; bindex >= 0; bindex--) {
+			err = copyup_file(parent_inode, file, bstart, bindex,
+					  i_size_read(dentry->d_inode));
+			if (!err)
+				break;
+		}
+		atomic_set(&UNIONFS_F(file)->generation,
+			   atomic_read(&UNIONFS_I(dentry->d_inode)->
+				       generation));
+		goto out;
+	}
+
+	dget(lower_dentry);
+	unionfs_mntget(dentry, bstart);
+	path.dentry = lower_dentry;
+	path.mnt = unionfs_lower_mnt_idx(dentry, bstart);
+	lower_file = dentry_open(&path, file->f_flags, current_cred());
+	path_put(&path);
+	if (IS_ERR(lower_file)) {
+		err = PTR_ERR(lower_file);
+		goto out;
+	}
+	branchget(sb, bstart);
+	unionfs_set_lower_file(file, lower_file);
+	/* Fix up the position. */
+	lower_file->f_pos = file->f_pos;
+
+	memcpy(&lower_file->f_ra, &file->f_ra, sizeof(struct file_ra_state));
+out:
+	dput(parent);
+	return err;
+}
+
+/* perform a delayed copyup of a read-write file on a read-only branch */
+static int do_delayed_copyup(struct file *file, struct dentry *parent)
+{
+	int bindex, bstart, bend, err = 0;
+	struct dentry *dentry = file->f_path.dentry;
+	struct inode *parent_inode = parent->d_inode;
+
+	bstart = fbstart(file);
+	bend = fbend(file);
+
+	BUG_ON(!S_ISREG(dentry->d_inode->i_mode));
+
+	unionfs_check_file(file);
+	for (bindex = bstart - 1; bindex >= 0; bindex--) {
+		if (!d_deleted(dentry))
+			err = copyup_file(parent_inode, file, bstart,
+					  bindex,
+					  i_size_read(dentry->d_inode));
+		else
+			err = copyup_deleted_file(file, dentry, parent,
+						  bstart, bindex);
+		/* if succeeded, set lower open-file flags and break */
+		if (!err) {
+			struct file *lower_file;
+			lower_file = unionfs_lower_file_idx(file, bindex);
+			lower_file->f_flags = file->f_flags;
+			break;
+		}
+	}
+	if (err || (bstart <= fbstart(file)))
+		goto out;
+	bend = fbend(file);
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		if (unionfs_lower_file_idx(file, bindex)) {
+			branchput(dentry->d_sb, bindex);
+			fput(unionfs_lower_file_idx(file, bindex));
+			unionfs_set_lower_file_idx(file, bindex, NULL);
+		}
+	}
+	path_put_lowers(dentry, bstart, bend, false);
+	iput_lowers(dentry->d_inode, bstart, bend, false);
+	/* for reg file, we only open it "once" */
+	fbend(file) = fbstart(file);
+	dbend(dentry) = dbstart(dentry);
+	ibend(dentry->d_inode) = ibstart(dentry->d_inode);
+
+out:
+	unionfs_check_file(file);
+	return err;
+}
+
+/*
+ * Helper function for unionfs_file_revalidate/locked.
+ * Expects dentry/parent to be locked already, and revalidated.
+ */
+static int __unionfs_file_revalidate(struct file *file, struct dentry *dentry,
+				     struct dentry *parent,
+				     struct super_block *sb, int sbgen,
+				     int dgen, bool willwrite)
+{
+	int fgen;
+	int bstart, bend, orig_brid;
+	int size;
+	int err = 0;
+
+	fgen = atomic_read(&UNIONFS_F(file)->generation);
+
+	/*
+	 * There are two cases we are interested in.  The first is if the
+	 * generation is lower than the super-block.  The second is if
+	 * someone has copied up this file from underneath us, we also need
+	 * to refresh things.
+	 */
+	if (d_deleted(dentry) ||
+	    (sbgen <= fgen &&
+	     dbstart(dentry) == fbstart(file) &&
+	     unionfs_lower_file(file)))
+		goto out_may_copyup;
+
+	/* save orig branch ID */
+	orig_brid = UNIONFS_F(file)->saved_branch_ids[fbstart(file)];
+
+	/* First we throw out the existing files. */
+	cleanup_file(file);
+
+	/* Now we reopen the file(s) as in unionfs_open. */
+	bstart = fbstart(file) = dbstart(dentry);
+	bend = fbend(file) = dbend(dentry);
+
+	size = sizeof(struct file *) * sbmax(sb);
+	UNIONFS_F(file)->lower_files = kzalloc(size, GFP_KERNEL);
+	if (unlikely(!UNIONFS_F(file)->lower_files)) {
+		err = -ENOMEM;
+		goto out;
+	}
+	size = sizeof(int) * sbmax(sb);
+	UNIONFS_F(file)->saved_branch_ids = kzalloc(size, GFP_KERNEL);
+	if (unlikely(!UNIONFS_F(file)->saved_branch_ids)) {
+		err = -ENOMEM;
+		goto out;
+	}
+
+	if (S_ISDIR(dentry->d_inode->i_mode)) {
+		/* We need to open all the files. */
+		err = open_all_files(file);
+		if (err)
+			goto out;
+	} else {
+		int new_brid;
+		/* We only open the highest priority branch. */
+		err = open_highest_file(file, willwrite);
+		if (err)
+			goto out;
+		new_brid = UNIONFS_F(file)->saved_branch_ids[fbstart(file)];
+		if (unlikely(new_brid != orig_brid && sbgen > fgen)) {
+			/*
+			 * If we re-opened the file on a different branch
+			 * than the original one, and this was due to a new
+			 * branch inserted, then update the mnt counts of
+			 * the old and new branches accordingly.
+			 */
+			unionfs_mntget(dentry, bstart);
+			unionfs_mntput(sb->s_root,
+				       branch_id_to_idx(sb, orig_brid));
+		}
+		/* regular files have only one open lower file */
+		fbend(file) = fbstart(file);
+	}
+	atomic_set(&UNIONFS_F(file)->generation,
+		   atomic_read(&UNIONFS_I(dentry->d_inode)->generation));
+
+out_may_copyup:
+	/* Copyup on the first write to a file on a readonly branch. */
+	if (willwrite && IS_WRITE_FLAG(file->f_flags) &&
+	    !IS_WRITE_FLAG(unionfs_lower_file(file)->f_flags) &&
+	    is_robranch(dentry)) {
+		pr_debug("unionfs: do delay copyup of \"%s\"\n",
+			 dentry->d_name.name);
+		err = do_delayed_copyup(file, parent);
+		/* regular files have only one open lower file */
+		if (!err && !S_ISDIR(dentry->d_inode->i_mode))
+			fbend(file) = fbstart(file);
+	}
+
+out:
+	if (err) {
+		kfree(UNIONFS_F(file)->lower_files);
+		kfree(UNIONFS_F(file)->saved_branch_ids);
+	}
+	return err;
+}
+
+/*
+ * Revalidate the struct file
+ * @file: file to revalidate
+ * @parent: parent dentry (locked by caller)
+ * @willwrite: true if caller may cause changes to the file; false otherwise.
+ * Caller must lock/unlock dentry's branch configuration.
+ */
+int unionfs_file_revalidate(struct file *file, struct dentry *parent,
+			    bool willwrite)
+{
+	struct super_block *sb;
+	struct dentry *dentry;
+	int sbgen, dgen;
+	int err = 0;
+
+	dentry = file->f_path.dentry;
+	sb = dentry->d_sb;
+	verify_locked(dentry);
+	verify_locked(parent);
+
+	/*
+	 * First revalidate the dentry inside struct file,
+	 * but not unhashed dentries.
+	 */
+	if (!d_deleted(dentry) &&
+	    !__unionfs_d_revalidate(dentry, parent, willwrite, 0)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	sbgen = atomic_read(&UNIONFS_SB(sb)->generation);
+	dgen = atomic_read(&UNIONFS_D(dentry)->generation);
+
+	if (unlikely(sbgen > dgen)) { /* XXX: should never happen */
+		pr_debug("unionfs: failed to revalidate dentry (%s)\n",
+			 dentry->d_name.name);
+		err = -ESTALE;
+		goto out;
+	}
+
+	err = __unionfs_file_revalidate(file, dentry, parent, sb,
+					sbgen, dgen, willwrite);
+out:
+	return err;
+}
+
+/* unionfs_open helper function: open a directory */
+static int __open_dir(struct inode *inode, struct file *file,
+		      struct dentry *parent)
+{
+	struct dentry *lower_dentry;
+	struct file *lower_file;
+	int bindex, bstart, bend;
+	struct vfsmount *lower_mnt;
+	struct dentry *dentry = file->f_path.dentry;
+	struct path path;
+
+	bstart = fbstart(file) = dbstart(dentry);
+	bend = fbend(file) = dbend(dentry);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry =
+			unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+
+		dget(lower_dentry);
+		lower_mnt = unionfs_mntget(dentry, bindex);
+		if (!lower_mnt)
+			lower_mnt = unionfs_mntget(parent, bindex);
+		path.dentry = lower_dentry;
+		path.mnt = lower_mnt;
+		lower_file = dentry_open(&path, file->f_flags, current_cred());
+		path_put(&path);
+		if (IS_ERR(lower_file))
+			return PTR_ERR(lower_file);
+
+		unionfs_set_lower_file_idx(file, bindex, lower_file);
+		if (!unionfs_lower_mnt_idx(dentry, bindex))
+			unionfs_set_lower_mnt_idx(dentry, bindex, lower_mnt);
+
+		/*
+		 * The branchget goes after the open, because otherwise
+		 * we would miss the reference on release.
+		 */
+		branchget(inode->i_sb, bindex);
+	}
+
+	return 0;
+}
+
+/* unionfs_open helper function: open a file */
+static int __open_file(struct inode *inode, struct file *file,
+		       struct dentry *parent)
+{
+	struct dentry *lower_dentry;
+	struct file *lower_file;
+	int lower_flags;
+	int bindex, bstart, bend;
+	struct dentry *dentry = file->f_path.dentry;
+	struct vfsmount *lower_mnt;
+	struct path path;
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+	lower_flags = file->f_flags;
+
+	bstart = fbstart(file) = dbstart(dentry);
+	bend = fbend(file) = dbend(dentry);
+
+	/*
+	 * check for the permission for lower file.  If the error is
+	 * COPYUP_ERR, copyup the file.
+	 */
+	if (lower_dentry->d_inode && is_robranch(dentry)) {
+		/*
+		 * if the open will change the file, copy it up otherwise
+		 * defer it.
+		 */
+		if (lower_flags & O_TRUNC) {
+			int size = 0;
+			int err = -EROFS;
+
+			/* copyup the file */
+			for (bindex = bstart - 1; bindex >= 0; bindex--) {
+				err = copyup_file(parent->d_inode, file,
+						  bstart, bindex, size);
+				if (!err) {
+					/* only one regular file open */
+					fbend(file) = fbstart(file);
+					break;
+				}
+			}
+			return err;
+		} else {
+			/*
+			 * turn off writeable flags, to force delayed copyup
+			 * by caller.
+			 */
+			lower_flags &= ~(OPEN_WRITE_FLAGS);
+		}
+	}
+
+	dget(lower_dentry);
+
+	/*
+	 * dentry_open used to decrement mnt refcnt if err.
+	 * otherwise fput() will do an mntput() for us upon file close.
+	 */
+	lower_mnt = unionfs_mntget(dentry, bstart);
+	path.dentry = lower_dentry;
+	path.mnt = lower_mnt;
+	lower_file = dentry_open(&path, lower_flags, current_cred());
+	path_put(&path);
+	if (IS_ERR(lower_file))
+		return PTR_ERR(lower_file);
+
+	unionfs_set_lower_file(file, lower_file);
+	branchget(inode->i_sb, bstart);
+
+	return 0;
+}
+
+int unionfs_open(struct inode *inode, struct file *file)
+{
+	int err = 0;
+	struct file *lower_file = NULL;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	int bindex = 0, bstart = 0, bend = 0;
+	int size;
+	int valid = 0;
+
+	unionfs_read_lock(inode->i_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	/* don't open unhashed/deleted files */
+	if (d_deleted(dentry)) {
+		err = -ENOENT;
+		goto out_nofree;
+	}
+
+	/* XXX: should I change 'false' below to the 'willwrite' flag? */
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out_nofree;
+	}
+
+	file->private_data =
+		kzalloc(sizeof(struct unionfs_file_info), GFP_KERNEL);
+	if (unlikely(!UNIONFS_F(file))) {
+		err = -ENOMEM;
+		goto out_nofree;
+	}
+	fbstart(file) = -1;
+	fbend(file) = -1;
+	atomic_set(&UNIONFS_F(file)->generation,
+		   atomic_read(&UNIONFS_I(inode)->generation));
+
+	size = sizeof(struct file *) * sbmax(inode->i_sb);
+	UNIONFS_F(file)->lower_files = kzalloc(size, GFP_KERNEL);
+	if (unlikely(!UNIONFS_F(file)->lower_files)) {
+		err = -ENOMEM;
+		goto out;
+	}
+	size = sizeof(int) * sbmax(inode->i_sb);
+	UNIONFS_F(file)->saved_branch_ids = kzalloc(size, GFP_KERNEL);
+	if (unlikely(!UNIONFS_F(file)->saved_branch_ids)) {
+		err = -ENOMEM;
+		goto out;
+	}
+
+	bstart = fbstart(file) = dbstart(dentry);
+	bend = fbend(file) = dbend(dentry);
+
+	/*
+	 * open all directories and make the unionfs file struct point to
+	 * these lower file structs
+	 */
+	if (S_ISDIR(inode->i_mode))
+		err = __open_dir(inode, file, parent); /* open a dir */
+	else
+		err = __open_file(inode, file, parent);	/* open a file */
+
+	/* freeing the allocated resources, and fput the opened files */
+	if (err) {
+		for (bindex = bstart; bindex <= bend; bindex++) {
+			lower_file = unionfs_lower_file_idx(file, bindex);
+			if (!lower_file)
+				continue;
+
+			branchput(dentry->d_sb, bindex);
+			/* fput calls dput for lower_dentry */
+			fput(lower_file);
+		}
+	}
+
+out:
+	if (err) {
+		kfree(UNIONFS_F(file)->lower_files);
+		kfree(UNIONFS_F(file)->saved_branch_ids);
+		kfree(UNIONFS_F(file));
+	}
+out_nofree:
+	if (!err) {
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_copy_attr_times(inode);
+		unionfs_check_file(file);
+		unionfs_check_inode(inode);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(inode->i_sb);
+	return err;
+}
+
+/*
+ * release all lower object references & free the file info structure
+ *
+ * No need to grab sb info's rwsem.
+ */
+int unionfs_file_release(struct inode *inode, struct file *file)
+{
+	struct file *lower_file = NULL;
+	struct unionfs_file_info *fileinfo;
+	struct unionfs_inode_info *inodeinfo;
+	struct super_block *sb = inode->i_sb;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	int bindex, bstart, bend;
+	int err = 0;
+
+	/*
+	 * Since mm/memory.c:might_fault() (under PROVE_LOCKING) was
+	 * modified in 2.6.29-rc1 to call might_lock_read on mmap_sem, this
+	 * has been causing false positives in file system stacking layers.
+	 * In particular, our ->mmap is called after sys_mmap2 already holds
+	 * mmap_sem, then we lock our own mutexes; but earlier, it's
+	 * possible for lockdep to have locked our mutexes first, and then
+	 * we call a lower ->readdir which could call might_fault.  The
+	 * different ordering of the locks is what lockdep complains about
+	 * -- unnecessarily.  Therefore, we have no choice but to tell
+	 * lockdep to temporarily turn off lockdep here.  Note: the comments
+	 * inside might_sleep also suggest that it would have been
+	 * nicer to only annotate paths that needs that might_lock_read.
+	 */
+	lockdep_off();
+	unionfs_read_lock(sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	/*
+	 * We try to revalidate, but the VFS ignores return return values
+	 * from file->release, so we must always try to succeed here,
+	 * including to do the kfree and dput below.  So if revalidation
+	 * failed, all we can do is print some message and keep going.
+	 */
+	err = unionfs_file_revalidate(file, parent,
+				      UNIONFS_F(file)->wrote_to_file);
+	if (!err)
+		unionfs_check_file(file);
+	fileinfo = UNIONFS_F(file);
+	BUG_ON(file->f_path.dentry->d_inode != inode);
+	inodeinfo = UNIONFS_I(inode);
+
+	/* fput all the lower files */
+	bstart = fbstart(file);
+	bend = fbend(file);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_file = unionfs_lower_file_idx(file, bindex);
+
+		if (lower_file) {
+			unionfs_set_lower_file_idx(file, bindex, NULL);
+			fput(lower_file);
+			branchput(sb, bindex);
+		}
+
+		/* if there are no more refs to the dentry, dput it */
+		if (d_deleted(dentry)) {
+			dput(unionfs_lower_dentry_idx(dentry, bindex));
+			unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+		}
+	}
+
+	kfree(fileinfo->lower_files);
+	kfree(fileinfo->saved_branch_ids);
+
+	if (fileinfo->rdstate) {
+		fileinfo->rdstate->access = jiffies;
+		spin_lock(&inodeinfo->rdlock);
+		inodeinfo->rdcount++;
+		list_add_tail(&fileinfo->rdstate->cache,
+			      &inodeinfo->readdircache);
+		mark_inode_dirty(inode);
+		spin_unlock(&inodeinfo->rdlock);
+		fileinfo->rdstate = NULL;
+	}
+	kfree(fileinfo);
+
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(sb);
+	lockdep_on();
+	return err;
+}
+
+/* pass the ioctl to the lower fs */
+static long do_ioctl(struct file *file, unsigned int cmd, unsigned long arg)
+{
+	struct file *lower_file;
+	int err;
+
+	lower_file = unionfs_lower_file(file);
+
+	err = -ENOTTY;
+	if (!lower_file || !lower_file->f_op)
+		goto out;
+	if (lower_file->f_op->unlocked_ioctl) {
+		err = lower_file->f_op->unlocked_ioctl(lower_file, cmd, arg);
+#ifdef CONFIG_COMPAT
+	} else if (lower_file->f_op->compat_ioctl) {
+		err = lower_file->f_op->compat_ioctl(lower_file, cmd, arg);
+#endif
+	}
+
+out:
+	return err;
+}
+
+/*
+ * return to user-space the branch indices containing the file in question
+ *
+ * We use fd_set and therefore we are limited to the number of the branches
+ * to FD_SETSIZE, which is currently 1024 - plenty for most people
+ */
+static int unionfs_ioctl_queryfile(struct file *file, struct dentry *parent,
+				   unsigned int cmd, unsigned long arg)
+{
+	int err = 0;
+	fd_set branchlist;
+	int bstart = 0, bend = 0, bindex = 0;
+	int orig_bstart, orig_bend;
+	struct dentry *dentry, *lower_dentry;
+	struct vfsmount *mnt;
+
+	dentry = file->f_path.dentry;
+	orig_bstart = dbstart(dentry);
+	orig_bend = dbend(dentry);
+	err = unionfs_partial_lookup(dentry, parent);
+	if (err)
+		goto out;
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	__FD_ZERO(&branchlist);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+		if (likely(lower_dentry->d_inode))
+			__FD_SET(bindex, &branchlist);
+		/* purge any lower objects after partial_lookup */
+		if (bindex < orig_bstart || bindex > orig_bend) {
+			dput(lower_dentry);
+			unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+			iput(unionfs_lower_inode_idx(dentry->d_inode, bindex));
+			unionfs_set_lower_inode_idx(dentry->d_inode, bindex,
+						    NULL);
+			mnt = unionfs_lower_mnt_idx(dentry, bindex);
+			if (!mnt)
+				continue;
+			unionfs_mntput(dentry, bindex);
+			unionfs_set_lower_mnt_idx(dentry, bindex, NULL);
+		}
+	}
+	/* restore original dentry's offsets */
+	dbstart(dentry) = orig_bstart;
+	dbend(dentry) = orig_bend;
+	ibstart(dentry->d_inode) = orig_bstart;
+	ibend(dentry->d_inode) = orig_bend;
+
+	err = copy_to_user((void __user *)arg, &branchlist, sizeof(fd_set));
+	if (unlikely(err))
+		err = -EFAULT;
+
+out:
+	return err < 0 ? err : bend;
+}
+
+long unionfs_ioctl(struct file *file, unsigned int cmd, unsigned long arg)
+{
+	long err;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+
+	/* check if asked for local commands */
+	switch (cmd) {
+	case UNIONFS_IOCTL_INCGEN:
+		/* Increment the superblock generation count */
+		pr_info("unionfs: incgen ioctl deprecated; "
+			"use \"-o remount,incgen\"\n");
+		err = -ENOSYS;
+		break;
+
+	case UNIONFS_IOCTL_QUERYFILE:
+		/* Return list of branches containing the given file */
+		err = unionfs_ioctl_queryfile(file, parent, cmd, arg);
+		break;
+
+	default:
+		/* pass the ioctl down */
+		err = do_ioctl(file, cmd, arg);
+		break;
+	}
+
+out:
+	unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+int unionfs_flush(struct file *file, fl_owner_t id)
+{
+	int err = 0;
+	struct file *lower_file = NULL;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	int bindex, bstart, bend;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent,
+				      UNIONFS_F(file)->wrote_to_file);
+	if (unlikely(err))
+		goto out;
+	unionfs_check_file(file);
+
+	bstart = fbstart(file);
+	bend = fbend(file);
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_file = unionfs_lower_file_idx(file, bindex);
+
+		if (lower_file && lower_file->f_op &&
+		    lower_file->f_op->flush) {
+			err = lower_file->f_op->flush(lower_file, id);
+			if (err)
+				goto out;
+		}
+
+	}
+
+out:
+	if (!err)
+		unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
diff --git a/fs/unionfs/copyup.c b/fs/unionfs/copyup.c
new file mode 100644
index 00000000..92963bf
--- /dev/null
+++ b/fs/unionfs/copyup.c
@@ -0,0 +1,899 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * For detailed explanation of copyup see:
+ * Documentation/filesystems/unionfs/concepts.txt
+ */
+
+#ifdef CONFIG_UNION_FS_XATTR
+/* copyup all extended attrs for a given dentry */
+static int copyup_xattrs(struct dentry *old_lower_dentry,
+			 struct dentry *new_lower_dentry)
+{
+	int err = 0;
+	ssize_t list_size = -1;
+	char *name_list = NULL;
+	char *attr_value = NULL;
+	char *name_list_buf = NULL;
+
+	/* query the actual size of the xattr list */
+	list_size = vfs_listxattr(old_lower_dentry, NULL, 0);
+	if (list_size <= 0) {
+		err = list_size;
+		goto out;
+	}
+
+	/* allocate space for the actual list */
+	name_list = unionfs_xattr_alloc(list_size + 1, XATTR_LIST_MAX);
+	if (unlikely(!name_list || IS_ERR(name_list))) {
+		err = PTR_ERR(name_list);
+		goto out;
+	}
+
+	name_list_buf = name_list; /* save for kfree at end */
+
+	/* now get the actual xattr list of the source file */
+	list_size = vfs_listxattr(old_lower_dentry, name_list, list_size);
+	if (list_size <= 0) {
+		err = list_size;
+		goto out;
+	}
+
+	/* allocate space to hold each xattr's value */
+	attr_value = unionfs_xattr_alloc(XATTR_SIZE_MAX, XATTR_SIZE_MAX);
+	if (unlikely(!attr_value || IS_ERR(attr_value))) {
+		err = PTR_ERR(name_list);
+		goto out;
+	}
+
+	/* in a loop, get and set each xattr from src to dst file */
+	while (*name_list) {
+		ssize_t size;
+
+		/* Lock here since vfs_getxattr doesn't lock for us */
+		mutex_lock(&old_lower_dentry->d_inode->i_mutex);
+		size = vfs_getxattr(old_lower_dentry, name_list,
+				    attr_value, XATTR_SIZE_MAX);
+		mutex_unlock(&old_lower_dentry->d_inode->i_mutex);
+		if (size < 0) {
+			err = size;
+			goto out;
+		}
+		if (size > XATTR_SIZE_MAX) {
+			err = -E2BIG;
+			goto out;
+		}
+		/* Don't lock here since vfs_setxattr does it for us. */
+		err = vfs_setxattr(new_lower_dentry, name_list, attr_value,
+				   size, 0);
+		/*
+		 * Selinux depends on "security.*" xattrs, so to maintain
+		 * the security of copied-up files, if Selinux is active,
+		 * then we must copy these xattrs as well.  So we need to
+		 * temporarily get FOWNER privileges.
+		 * XXX: move entire copyup code to SIOQ.
+		 */
+		if (err == -EPERM && !capable(CAP_FOWNER)) {
+			const struct cred *old_creds;
+			struct cred *new_creds;
+
+			new_creds = prepare_creds();
+			if (unlikely(!new_creds)) {
+				err = -ENOMEM;
+				goto out;
+			}
+			cap_raise(new_creds->cap_effective, CAP_FOWNER);
+			old_creds = override_creds(new_creds);
+			err = vfs_setxattr(new_lower_dentry, name_list,
+					   attr_value, size, 0);
+			revert_creds(old_creds);
+		}
+		if (err < 0)
+			goto out;
+		name_list += strlen(name_list) + 1;
+	}
+out:
+	unionfs_xattr_kfree(name_list_buf);
+	unionfs_xattr_kfree(attr_value);
+	/* Ignore if xattr isn't supported */
+	if (err == -ENOTSUPP || err == -EOPNOTSUPP)
+		err = 0;
+	return err;
+}
+#endif /* CONFIG_UNION_FS_XATTR */
+
+/*
+ * Determine the mode based on the copyup flags, and the existing dentry.
+ *
+ * Handle file systems which may not support certain options.  For example
+ * jffs2 doesn't allow one to chmod a symlink.  So we ignore such harmless
+ * errors, rather than propagating them up, which results in copyup errors
+ * and errors returned back to users.
+ */
+static int copyup_permissions(struct super_block *sb,
+			      struct dentry *old_lower_dentry,
+			      struct dentry *new_lower_dentry)
+{
+	struct inode *i = old_lower_dentry->d_inode;
+	struct iattr newattrs;
+	int err;
+
+	newattrs.ia_atime = i->i_atime;
+	newattrs.ia_mtime = i->i_mtime;
+	newattrs.ia_ctime = i->i_ctime;
+	newattrs.ia_gid = i->i_gid;
+	newattrs.ia_uid = i->i_uid;
+	newattrs.ia_valid = ATTR_CTIME | ATTR_ATIME | ATTR_MTIME |
+		ATTR_ATIME_SET | ATTR_MTIME_SET | ATTR_FORCE |
+		ATTR_GID | ATTR_UID;
+	mutex_lock(&new_lower_dentry->d_inode->i_mutex);
+	err = notify_change(new_lower_dentry, &newattrs);
+	if (err)
+		goto out;
+
+	/* now try to change the mode and ignore EOPNOTSUPP on symlinks */
+	newattrs.ia_mode = i->i_mode;
+	newattrs.ia_valid = ATTR_MODE | ATTR_FORCE;
+	err = notify_change(new_lower_dentry, &newattrs);
+	if (err == -EOPNOTSUPP &&
+	    S_ISLNK(new_lower_dentry->d_inode->i_mode)) {
+		printk(KERN_WARNING
+		       "unionfs: changing \"%s\" symlink mode unsupported\n",
+		       new_lower_dentry->d_name.name);
+		err = 0;
+	}
+
+out:
+	mutex_unlock(&new_lower_dentry->d_inode->i_mutex);
+	return err;
+}
+
+/*
+ * create the new device/file/directory - use copyup_permission to copyup
+ * times, and mode
+ *
+ * if the object being copied up is a regular file, the file is only created,
+ * the contents have to be copied up separately
+ */
+static int __copyup_ndentry(struct dentry *old_lower_dentry,
+			    struct dentry *new_lower_dentry,
+			    struct dentry *new_lower_parent_dentry,
+			    char *symbuf)
+{
+	int err = 0;
+	umode_t old_mode = old_lower_dentry->d_inode->i_mode;
+	struct sioq_args args;
+
+	if (S_ISDIR(old_mode)) {
+		args.mkdir.parent = new_lower_parent_dentry->d_inode;
+		args.mkdir.dentry = new_lower_dentry;
+		args.mkdir.mode = old_mode;
+
+		run_sioq(__unionfs_mkdir, &args);
+		err = args.err;
+	} else if (S_ISLNK(old_mode)) {
+		args.symlink.parent = new_lower_parent_dentry->d_inode;
+		args.symlink.dentry = new_lower_dentry;
+		args.symlink.symbuf = symbuf;
+
+		run_sioq(__unionfs_symlink, &args);
+		err = args.err;
+	} else if (S_ISBLK(old_mode) || S_ISCHR(old_mode) ||
+		   S_ISFIFO(old_mode) || S_ISSOCK(old_mode)) {
+		args.mknod.parent = new_lower_parent_dentry->d_inode;
+		args.mknod.dentry = new_lower_dentry;
+		args.mknod.mode = old_mode;
+		args.mknod.dev = old_lower_dentry->d_inode->i_rdev;
+
+		run_sioq(__unionfs_mknod, &args);
+		err = args.err;
+	} else if (S_ISREG(old_mode)) {
+		args.create.parent = new_lower_parent_dentry->d_inode;
+		args.create.dentry = new_lower_dentry;
+		args.create.mode = old_mode;
+		args.create.want_excl = false; /* XXX: pass to this fxn */
+
+		run_sioq(__unionfs_create, &args);
+		err = args.err;
+	} else {
+		printk(KERN_CRIT "unionfs: unknown inode type %d\n",
+		       old_mode);
+		BUG();
+	}
+
+	return err;
+}
+
+static int __copyup_reg_data(struct dentry *dentry,
+			     struct dentry *new_lower_dentry, int new_bindex,
+			     struct dentry *old_lower_dentry, int old_bindex,
+			     struct file **copyup_file, loff_t len)
+{
+	struct super_block *sb = dentry->d_sb;
+	struct file *input_file;
+	struct file *output_file;
+	struct vfsmount *output_mnt;
+	mm_segment_t old_fs;
+	char *buf = NULL;
+	ssize_t read_bytes, write_bytes;
+	loff_t size;
+	int err = 0;
+	struct path input_path, output_path;
+
+	/* open old file */
+	unionfs_mntget(dentry, old_bindex);
+	branchget(sb, old_bindex);
+	/* dentry_open used to call dput and mntput if it returns an error */
+	input_path.dentry = old_lower_dentry;
+	input_path.mnt = unionfs_lower_mnt_idx(dentry, old_bindex);
+	input_file = dentry_open(&input_path,
+				 O_RDONLY | O_LARGEFILE, current_cred());
+	path_put(&input_path);
+	if (IS_ERR(input_file)) {
+		dput(old_lower_dentry);
+		err = PTR_ERR(input_file);
+		goto out;
+	}
+	if (unlikely(!input_file->f_op || !input_file->f_op->read)) {
+		err = -EINVAL;
+		goto out_close_in;
+	}
+
+	/* open new file */
+	dget(new_lower_dentry);
+	output_mnt = unionfs_mntget(sb->s_root, new_bindex);
+	branchget(sb, new_bindex);
+	output_path.dentry = new_lower_dentry;
+	output_path.mnt = output_mnt;
+	output_file = dentry_open(&output_path,
+				  O_RDWR | O_LARGEFILE, current_cred());
+	path_put(&output_path);
+	if (IS_ERR(output_file)) {
+		err = PTR_ERR(output_file);
+		goto out_close_in2;
+	}
+	if (unlikely(!output_file->f_op || !output_file->f_op->write)) {
+		err = -EINVAL;
+		goto out_close_out;
+	}
+
+	/* allocating a buffer */
+	buf = kmalloc(PAGE_SIZE, GFP_KERNEL);
+	if (unlikely(!buf)) {
+		err = -ENOMEM;
+		goto out_close_out;
+	}
+
+	input_file->f_pos = 0;
+	output_file->f_pos = 0;
+
+	old_fs = get_fs();
+	set_fs(KERNEL_DS);
+
+	size = len;
+	err = 0;
+	do {
+		if (len >= PAGE_SIZE)
+			size = PAGE_SIZE;
+		else if ((len < PAGE_SIZE) && (len > 0))
+			size = len;
+
+		len -= PAGE_SIZE;
+
+		read_bytes =
+			input_file->f_op->read(input_file,
+					       (char __user *)buf, size,
+					       &input_file->f_pos);
+		if (read_bytes <= 0) {
+			err = read_bytes;
+			break;
+		}
+
+		/* see Documentation/filesystems/unionfs/issues.txt */
+		lockdep_off();
+		write_bytes =
+			output_file->f_op->write(output_file,
+						 (char __user *)buf,
+						 read_bytes,
+						 &output_file->f_pos);
+		lockdep_on();
+		if ((write_bytes < 0) || (write_bytes < read_bytes)) {
+			err = write_bytes;
+			break;
+		}
+	} while ((read_bytes > 0) && (len > 0));
+
+	set_fs(old_fs);
+
+	kfree(buf);
+
+#if 0
+	/* XXX: code no longer needed? */
+	if (!err)
+		err = output_file->f_op->fsync(output_file, 0);
+#endif
+
+	if (err)
+		goto out_close_out;
+
+	if (copyup_file) {
+		*copyup_file = output_file;
+		goto out_close_in;
+	}
+
+out_close_out:
+	fput(output_file);
+
+out_close_in2:
+	branchput(sb, new_bindex);
+
+out_close_in:
+	fput(input_file);
+
+out:
+	branchput(sb, old_bindex);
+
+	return err;
+}
+
+/*
+ * dput the lower references for old and new dentry & clear a lower dentry
+ * pointer
+ */
+static void __clear(struct dentry *dentry, struct dentry *old_lower_dentry,
+		    int old_bstart, int old_bend,
+		    struct dentry *new_lower_dentry, int new_bindex)
+{
+	/* get rid of the lower dentry and all its traces */
+	unionfs_set_lower_dentry_idx(dentry, new_bindex, NULL);
+	dbstart(dentry) = old_bstart;
+	dbend(dentry) = old_bend;
+
+	dput(new_lower_dentry);
+	dput(old_lower_dentry);
+}
+
+/*
+ * Copy up a dentry to a file of specified name.
+ *
+ * @dir: used to pull the ->i_sb to access other branches
+ * @dentry: the non-negative dentry whose lower_inode we should copy
+ * @bstart: the branch of the lower_inode to copy from
+ * @new_bindex: the branch to create the new file in
+ * @name: the name of the file to create
+ * @namelen: length of @name
+ * @copyup_file: the "struct file" to return (optional)
+ * @len: how many bytes to copy-up?
+ */
+int copyup_dentry(struct inode *dir, struct dentry *dentry, int bstart,
+		  int new_bindex, const char *name, int namelen,
+		  struct file **copyup_file, loff_t len)
+{
+	struct dentry *new_lower_dentry;
+	struct dentry *old_lower_dentry = NULL;
+	struct super_block *sb;
+	int err = 0;
+	int old_bindex;
+	int old_bstart;
+	int old_bend;
+	struct dentry *new_lower_parent_dentry = NULL;
+	mm_segment_t oldfs;
+	char *symbuf = NULL;
+
+	verify_locked(dentry);
+
+	old_bindex = bstart;
+	old_bstart = dbstart(dentry);
+	old_bend = dbend(dentry);
+
+	BUG_ON(new_bindex < 0);
+	BUG_ON(new_bindex >= old_bindex);
+
+	sb = dir->i_sb;
+
+	err = is_robranch_super(sb, new_bindex);
+	if (err)
+		goto out;
+
+	/* Create the directory structure above this dentry. */
+	new_lower_dentry = create_parents(dir, dentry, name, new_bindex);
+	if (IS_ERR(new_lower_dentry)) {
+		err = PTR_ERR(new_lower_dentry);
+		goto out;
+	}
+
+	old_lower_dentry = unionfs_lower_dentry_idx(dentry, old_bindex);
+	/* we conditionally dput this old_lower_dentry at end of function */
+	dget(old_lower_dentry);
+
+	/* For symlinks, we must read the link before we lock the directory. */
+	if (S_ISLNK(old_lower_dentry->d_inode->i_mode)) {
+
+		symbuf = kmalloc(PATH_MAX, GFP_KERNEL);
+		if (unlikely(!symbuf)) {
+			__clear(dentry, old_lower_dentry,
+				old_bstart, old_bend,
+				new_lower_dentry, new_bindex);
+			err = -ENOMEM;
+			goto out_free;
+		}
+
+		oldfs = get_fs();
+		set_fs(KERNEL_DS);
+		err = old_lower_dentry->d_inode->i_op->readlink(
+			old_lower_dentry,
+			(char __user *)symbuf,
+			PATH_MAX);
+		set_fs(oldfs);
+		if (err < 0) {
+			__clear(dentry, old_lower_dentry,
+				old_bstart, old_bend,
+				new_lower_dentry, new_bindex);
+			goto out_free;
+		}
+		symbuf[err] = '\0';
+	}
+
+	/* Now we lock the parent, and create the object in the new branch. */
+	new_lower_parent_dentry = lock_parent(new_lower_dentry);
+
+	/* create the new inode */
+	err = __copyup_ndentry(old_lower_dentry, new_lower_dentry,
+			       new_lower_parent_dentry, symbuf);
+
+	if (err) {
+		__clear(dentry, old_lower_dentry,
+			old_bstart, old_bend,
+			new_lower_dentry, new_bindex);
+		goto out_unlock;
+	}
+
+	/* We actually copyup the file here. */
+	if (S_ISREG(old_lower_dentry->d_inode->i_mode))
+		err = __copyup_reg_data(dentry, new_lower_dentry, new_bindex,
+					old_lower_dentry, old_bindex,
+					copyup_file, len);
+	if (err)
+		goto out_unlink;
+
+	/* Set permissions. */
+	err = copyup_permissions(sb, old_lower_dentry, new_lower_dentry);
+	if (err)
+		goto out_unlink;
+
+#ifdef CONFIG_UNION_FS_XATTR
+	/* Selinux uses extended attributes for permissions. */
+	err = copyup_xattrs(old_lower_dentry, new_lower_dentry);
+	if (err)
+		goto out_unlink;
+#endif /* CONFIG_UNION_FS_XATTR */
+
+	/* do not allow files getting deleted to be re-interposed */
+	if (!d_deleted(dentry))
+		unionfs_reinterpose(dentry);
+
+	goto out_unlock;
+
+out_unlink:
+	/*
+	 * copyup failed, because we possibly ran out of space or
+	 * quota, or something else happened so let's unlink; we don't
+	 * really care about the return value of vfs_unlink
+	 */
+	vfs_unlink(new_lower_parent_dentry->d_inode, new_lower_dentry);
+
+	if (copyup_file) {
+		/* need to close the file */
+
+		fput(*copyup_file);
+		branchput(sb, new_bindex);
+	}
+
+	/*
+	 * TODO: should we reset the error to something like -EIO?
+	 *
+	 * If we don't reset, the user may get some nonsensical errors, but
+	 * on the other hand, if we reset to EIO, we guarantee that the user
+	 * will get a "confusing" error message.
+	 */
+
+out_unlock:
+	unlock_dir(new_lower_parent_dentry);
+
+out_free:
+	/*
+	 * If old_lower_dentry was not a file, then we need to dput it.  If
+	 * it was a file, then it was already dput indirectly by other
+	 * functions we call above which operate on regular files.
+	 */
+	if (old_lower_dentry && old_lower_dentry->d_inode &&
+	    !S_ISREG(old_lower_dentry->d_inode->i_mode))
+		dput(old_lower_dentry);
+	kfree(symbuf);
+
+	if (err) {
+		/*
+		 * if directory creation succeeded, but inode copyup failed,
+		 * then purge new dentries.
+		 */
+		if (dbstart(dentry) < old_bstart &&
+		    ibstart(dentry->d_inode) > dbstart(dentry))
+			__clear(dentry, NULL, old_bstart, old_bend,
+				unionfs_lower_dentry(dentry), dbstart(dentry));
+		goto out;
+	}
+	if (!S_ISDIR(dentry->d_inode->i_mode)) {
+		unionfs_postcopyup_release(dentry);
+		if (!unionfs_lower_inode(dentry->d_inode)) {
+			/*
+			 * If we got here, then we copied up to an
+			 * unlinked-open file, whose name is .unionfsXXXXX.
+			 */
+			struct inode *inode = new_lower_dentry->d_inode;
+			atomic_inc(&inode->i_count);
+			unionfs_set_lower_inode_idx(dentry->d_inode,
+						    ibstart(dentry->d_inode),
+						    inode);
+		}
+	}
+	unionfs_postcopyup_setmnt(dentry);
+	/* sync inode times from copied-up inode to our inode */
+	unionfs_copy_attr_times(dentry->d_inode);
+	unionfs_check_inode(dir);
+	unionfs_check_dentry(dentry);
+out:
+	return err;
+}
+
+/*
+ * This function creates a copy of a file represented by 'file' which
+ * currently resides in branch 'bstart' to branch 'new_bindex.'  The copy
+ * will be named "name".
+ */
+int copyup_named_file(struct inode *dir, struct file *file, char *name,
+		      int bstart, int new_bindex, loff_t len)
+{
+	int err = 0;
+	struct file *output_file = NULL;
+
+	err = copyup_dentry(dir, file->f_path.dentry, bstart, new_bindex,
+			    name, strlen(name), &output_file, len);
+	if (!err) {
+		fbstart(file) = new_bindex;
+		unionfs_set_lower_file_idx(file, new_bindex, output_file);
+	}
+
+	return err;
+}
+
+/*
+ * This function creates a copy of a file represented by 'file' which
+ * currently resides in branch 'bstart' to branch 'new_bindex'.
+ */
+int copyup_file(struct inode *dir, struct file *file, int bstart,
+		int new_bindex, loff_t len)
+{
+	int err = 0;
+	struct file *output_file = NULL;
+	struct dentry *dentry = file->f_path.dentry;
+
+	err = copyup_dentry(dir, dentry, bstart, new_bindex,
+			    dentry->d_name.name, dentry->d_name.len,
+			    &output_file, len);
+	if (!err) {
+		fbstart(file) = new_bindex;
+		unionfs_set_lower_file_idx(file, new_bindex, output_file);
+	}
+
+	return err;
+}
+
+/* purge a dentry's lower-branch states (dput/mntput, etc.) */
+static void __cleanup_dentry(struct dentry *dentry, int bindex,
+			     int old_bstart, int old_bend)
+{
+	int loop_start;
+	int loop_end;
+	int new_bstart = -1;
+	int new_bend = -1;
+	int i;
+
+	loop_start = min(old_bstart, bindex);
+	loop_end = max(old_bend, bindex);
+
+	/*
+	 * This loop sets the bstart and bend for the new dentry by
+	 * traversing from left to right.  It also dputs all negative
+	 * dentries except bindex
+	 */
+	for (i = loop_start; i <= loop_end; i++) {
+		if (!unionfs_lower_dentry_idx(dentry, i))
+			continue;
+
+		if (i == bindex) {
+			new_bend = i;
+			if (new_bstart < 0)
+				new_bstart = i;
+			continue;
+		}
+
+		if (!unionfs_lower_dentry_idx(dentry, i)->d_inode) {
+			dput(unionfs_lower_dentry_idx(dentry, i));
+			unionfs_set_lower_dentry_idx(dentry, i, NULL);
+
+			unionfs_mntput(dentry, i);
+			unionfs_set_lower_mnt_idx(dentry, i, NULL);
+		} else {
+			if (new_bstart < 0)
+				new_bstart = i;
+			new_bend = i;
+		}
+	}
+
+	if (new_bstart < 0)
+		new_bstart = bindex;
+	if (new_bend < 0)
+		new_bend = bindex;
+	dbstart(dentry) = new_bstart;
+	dbend(dentry) = new_bend;
+
+}
+
+/* set lower inode ptr and update bstart & bend if necessary */
+static void __set_inode(struct dentry *upper, struct dentry *lower,
+			int bindex)
+{
+	unionfs_set_lower_inode_idx(upper->d_inode, bindex,
+				    igrab(lower->d_inode));
+	if (likely(ibstart(upper->d_inode) > bindex))
+		ibstart(upper->d_inode) = bindex;
+	if (likely(ibend(upper->d_inode) < bindex))
+		ibend(upper->d_inode) = bindex;
+
+}
+
+/* set lower dentry ptr and update bstart & bend if necessary */
+static void __set_dentry(struct dentry *upper, struct dentry *lower,
+			 int bindex)
+{
+	unionfs_set_lower_dentry_idx(upper, bindex, lower);
+	if (likely(dbstart(upper) > bindex))
+		dbstart(upper) = bindex;
+	if (likely(dbend(upper) < bindex))
+		dbend(upper) = bindex;
+}
+
+/*
+ * This function replicates the directory structure up-to given dentry
+ * in the bindex branch.
+ */
+struct dentry *create_parents(struct inode *dir, struct dentry *dentry,
+			      const char *name, int bindex)
+{
+	int err;
+	struct dentry *child_dentry;
+	struct dentry *parent_dentry;
+	struct dentry *lower_parent_dentry = NULL;
+	struct dentry *lower_dentry = NULL;
+	const char *childname;
+	unsigned int childnamelen;
+	int nr_dentry;
+	int count = 0;
+	int old_bstart;
+	int old_bend;
+	struct dentry **path = NULL;
+	struct super_block *sb;
+
+	verify_locked(dentry);
+
+	err = is_robranch_super(dir->i_sb, bindex);
+	if (err) {
+		lower_dentry = ERR_PTR(err);
+		goto out;
+	}
+
+	old_bstart = dbstart(dentry);
+	old_bend = dbend(dentry);
+
+	lower_dentry = ERR_PTR(-ENOMEM);
+
+	/* There is no sense allocating any less than the minimum. */
+	nr_dentry = 1;
+	path = kmalloc(nr_dentry * sizeof(struct dentry *), GFP_KERNEL);
+	if (unlikely(!path))
+		goto out;
+
+	/* assume the negative dentry of unionfs as the parent dentry */
+	parent_dentry = dentry;
+
+	/*
+	 * This loop finds the first parent that exists in the given branch.
+	 * We start building the directory structure from there.  At the end
+	 * of the loop, the following should hold:
+	 *  - child_dentry is the first nonexistent child
+	 *  - parent_dentry is the first existent parent
+	 *  - path[0] is the = deepest child
+	 *  - path[count] is the first child to create
+	 */
+	do {
+		child_dentry = parent_dentry;
+
+		/* find the parent directory dentry in unionfs */
+		parent_dentry = dget_parent(child_dentry);
+
+		/* find out the lower_parent_dentry in the given branch */
+		lower_parent_dentry =
+			unionfs_lower_dentry_idx(parent_dentry, bindex);
+
+		/* grow path table */
+		if (count == nr_dentry) {
+			void *p;
+
+			nr_dentry *= 2;
+			p = krealloc(path, nr_dentry * sizeof(struct dentry *),
+				     GFP_KERNEL);
+			if (unlikely(!p)) {
+				lower_dentry = ERR_PTR(-ENOMEM);
+				goto out;
+			}
+			path = p;
+		}
+
+		/* store the child dentry */
+		path[count++] = child_dentry;
+	} while (!lower_parent_dentry);
+	count--;
+
+	sb = dentry->d_sb;
+
+	/*
+	 * This code goes between the begin/end labels and basically
+	 * emulates a while(child_dentry != dentry), only cleaner and
+	 * shorter than what would be a much longer while loop.
+	 */
+begin:
+	/* get lower parent dir in the current branch */
+	lower_parent_dentry = unionfs_lower_dentry_idx(parent_dentry, bindex);
+	dput(parent_dentry);
+
+	/* init the values to lookup */
+	childname = child_dentry->d_name.name;
+	childnamelen = child_dentry->d_name.len;
+
+	if (child_dentry != dentry) {
+		/* lookup child in the underlying file system */
+		lower_dentry = lookup_lck_len(childname, lower_parent_dentry,
+					      childnamelen);
+		if (IS_ERR(lower_dentry))
+			goto out;
+	} else {
+		/*
+		 * Is the name a whiteout of the child name ?  lookup the
+		 * whiteout child in the underlying file system
+		 */
+		lower_dentry = lookup_lck_len(name, lower_parent_dentry,
+					      strlen(name));
+		if (IS_ERR(lower_dentry))
+			goto out;
+
+		/* Replace the current dentry (if any) with the new one */
+		dput(unionfs_lower_dentry_idx(dentry, bindex));
+		unionfs_set_lower_dentry_idx(dentry, bindex,
+					     lower_dentry);
+
+		__cleanup_dentry(dentry, bindex, old_bstart, old_bend);
+		goto out;
+	}
+
+	if (lower_dentry->d_inode) {
+		/*
+		 * since this already exists we dput to avoid
+		 * multiple references on the same dentry
+		 */
+		dput(lower_dentry);
+	} else {
+		struct sioq_args args;
+
+		/* it's a negative dentry, create a new dir */
+		lower_parent_dentry = lock_parent(lower_dentry);
+
+		args.mkdir.parent = lower_parent_dentry->d_inode;
+		args.mkdir.dentry = lower_dentry;
+		args.mkdir.mode = child_dentry->d_inode->i_mode;
+
+		run_sioq(__unionfs_mkdir, &args);
+		err = args.err;
+
+		if (!err)
+			err = copyup_permissions(dir->i_sb, child_dentry,
+						 lower_dentry);
+		unlock_dir(lower_parent_dentry);
+		if (err) {
+			dput(lower_dentry);
+			lower_dentry = ERR_PTR(err);
+			goto out;
+		}
+
+	}
+
+	__set_inode(child_dentry, lower_dentry, bindex);
+	__set_dentry(child_dentry, lower_dentry, bindex);
+	/*
+	 * update times of this dentry, but also the parent, because if
+	 * we changed, the parent may have changed too.
+	 */
+	fsstack_copy_attr_times(parent_dentry->d_inode,
+				lower_parent_dentry->d_inode);
+	unionfs_copy_attr_times(child_dentry->d_inode);
+
+	parent_dentry = child_dentry;
+	child_dentry = path[--count];
+	goto begin;
+out:
+	/* cleanup any leftover locks from the do/while loop above */
+	if (IS_ERR(lower_dentry))
+		while (count)
+			dput(path[count--]);
+	kfree(path);
+	return lower_dentry;
+}
+
+/*
+ * Post-copyup helper to ensure we have valid mnts: set lower mnt of
+ * dentry+parents to the first parent node that has an mnt.
+ */
+void unionfs_postcopyup_setmnt(struct dentry *dentry)
+{
+	struct dentry *parent, *hasone;
+	int bindex = dbstart(dentry);
+
+	if (unionfs_lower_mnt_idx(dentry, bindex))
+		return;
+	hasone = dentry->d_parent;
+	/* this loop should stop at root dentry */
+	while (!unionfs_lower_mnt_idx(hasone, bindex))
+		hasone = hasone->d_parent;
+	parent = dentry;
+	while (!unionfs_lower_mnt_idx(parent, bindex)) {
+		unionfs_set_lower_mnt_idx(parent, bindex,
+					  unionfs_mntget(hasone, bindex));
+		parent = parent->d_parent;
+	}
+}
+
+/*
+ * Post-copyup helper to release all non-directory source objects of a
+ * copied-up file.  Regular files should have only one lower object.
+ */
+void unionfs_postcopyup_release(struct dentry *dentry)
+{
+	int bstart, bend;
+
+	BUG_ON(S_ISDIR(dentry->d_inode->i_mode));
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	path_put_lowers(dentry, bstart + 1, bend, false);
+	iput_lowers(dentry->d_inode, bstart + 1, bend, false);
+
+	dbend(dentry) = bstart;
+	ibend(dentry->d_inode) = ibstart(dentry->d_inode) = bstart;
+}
diff --git a/fs/unionfs/debug.c b/fs/unionfs/debug.c
new file mode 100644
index 00000000..4d072c5
--- /dev/null
+++ b/fs/unionfs/debug.c
@@ -0,0 +1,531 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+#include "../mount.h"
+
+/*
+ * Helper debugging functions for maintainers (and for users to report back
+ * useful information back to maintainers)
+ */
+
+/* it's always useful to know what part of the code called us */
+#define PRINT_CALLER(fname, fxn, line)					\
+	do {								\
+		if (!printed_caller) {					\
+			pr_debug("PC:%s:%s:%d\n", (fname), (fxn), (line)); \
+			printed_caller = 1;				\
+		}							\
+	} while (0)
+
+/*
+ * __unionfs_check_{inode,dentry,file} perform exhaustive sanity checking on
+ * the fan-out of various Unionfs objects.  We check that no lower objects
+ * exist  outside the start/end branch range; that all objects within are
+ * non-NULL (with some allowed exceptions); that for every lower file
+ * there's a lower dentry+inode; that the start/end ranges match for all
+ * corresponding lower objects; that open files/symlinks have only one lower
+ * objects, but directories can have several; and more.
+ */
+void __unionfs_check_inode(const struct inode *inode,
+			   const char *fname, const char *fxn, int line)
+{
+	int bindex;
+	int istart, iend;
+	struct inode *lower_inode;
+	struct super_block *sb;
+	int printed_caller = 0;
+	void *poison_ptr;
+
+	/* for inodes now */
+	BUG_ON(!inode);
+	sb = inode->i_sb;
+	istart = ibstart(inode);
+	iend = ibend(inode);
+	/* don't check inode if no lower branches */
+	if (istart < 0 && iend < 0)
+		return;
+	if (unlikely(istart > iend)) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" Ci0: inode=%p istart/end=%d:%d\n",
+			 inode, istart, iend);
+	}
+	if (unlikely((istart == -1 && iend != -1) ||
+		     (istart != -1 && iend == -1))) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" Ci1: inode=%p istart/end=%d:%d\n",
+			 inode, istart, iend);
+	}
+	if (!S_ISDIR(inode->i_mode)) {
+		if (unlikely(iend != istart)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" Ci2: inode=%p istart=%d iend=%d\n",
+				 inode, istart, iend);
+		}
+	}
+
+	for (bindex = sbstart(sb); bindex < sbmax(sb); bindex++) {
+		if (unlikely(!UNIONFS_I(inode))) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" Ci3: no inode_info %p\n", inode);
+			return;
+		}
+		if (unlikely(!UNIONFS_I(inode)->lower_inodes)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" Ci4: no lower_inodes %p\n", inode);
+			return;
+		}
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (lower_inode) {
+			memset(&poison_ptr, POISON_INUSE, sizeof(void *));
+			if (unlikely(bindex < istart || bindex > iend)) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" Ci5: inode/linode=%p:%p bindex=%d "
+					 "istart/end=%d:%d\n", inode,
+					 lower_inode, bindex, istart, iend);
+			} else if (unlikely(lower_inode == poison_ptr)) {
+				/* freed inode! */
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" Ci6: inode/linode=%p:%p bindex=%d "
+					 "istart/end=%d:%d\n", inode,
+					 lower_inode, bindex, istart, iend);
+			}
+			continue;
+		}
+		/* if we get here, then lower_inode == NULL */
+		if (bindex < istart || bindex > iend)
+			continue;
+		/*
+		 * directories can have NULL lower inodes in b/t start/end,
+		 * but NOT if at the start/end range.
+		 */
+		if (unlikely(S_ISDIR(inode->i_mode) &&
+			     bindex > istart && bindex < iend))
+			continue;
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" Ci7: inode/linode=%p:%p "
+			 "bindex=%d istart/end=%d:%d\n",
+			 inode, lower_inode, bindex, istart, iend);
+	}
+}
+
+void __unionfs_check_dentry(const struct dentry *dentry,
+			    const char *fname, const char *fxn, int line)
+{
+	int bindex;
+	int dstart, dend, istart, iend;
+	struct dentry *lower_dentry;
+	struct inode *inode, *lower_inode;
+	struct super_block *sb;
+	struct vfsmount *lower_mnt;
+	int printed_caller = 0;
+	void *poison_ptr;
+
+	BUG_ON(!dentry);
+	sb = dentry->d_sb;
+	inode = dentry->d_inode;
+	dstart = dbstart(dentry);
+	dend = dbend(dentry);
+	/* don't check dentry/mnt if no lower branches */
+	if (dstart < 0 && dend < 0)
+		goto check_inode;
+	BUG_ON(dstart > dend);
+
+	if (unlikely((dstart == -1 && dend != -1) ||
+		     (dstart != -1 && dend == -1))) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CD0: dentry=%p dstart/end=%d:%d\n",
+			 dentry, dstart, dend);
+	}
+	/*
+	 * check for NULL dentries inside the start/end range, or
+	 * non-NULL dentries outside the start/end range.
+	 */
+	for (bindex = sbstart(sb); bindex < sbmax(sb); bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (lower_dentry) {
+			if (unlikely(bindex < dstart || bindex > dend)) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CD1: dentry/lower=%p:%p(%p) "
+					 "bindex=%d dstart/end=%d:%d\n",
+					 dentry, lower_dentry,
+					 (lower_dentry ? lower_dentry->d_inode :
+					  (void *) -1L),
+					 bindex, dstart, dend);
+			}
+		} else {	/* lower_dentry == NULL */
+			if (bindex < dstart || bindex > dend)
+				continue;
+			/*
+			 * Directories can have NULL lower inodes in b/t
+			 * start/end, but NOT if at the start/end range.
+			 * Ignore this rule, however, if this is a NULL
+			 * dentry or a deleted dentry.
+			 */
+			if (unlikely(!d_deleted((struct dentry *) dentry) &&
+				     inode &&
+				     !(inode && S_ISDIR(inode->i_mode) &&
+				       bindex > dstart && bindex < dend))) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CD2: dentry/lower=%p:%p(%p) "
+					 "bindex=%d dstart/end=%d:%d\n",
+					 dentry, lower_dentry,
+					 (lower_dentry ?
+					  lower_dentry->d_inode :
+					  (void *) -1L),
+					 bindex, dstart, dend);
+			}
+		}
+	}
+
+	/* check for vfsmounts same as for dentries */
+	for (bindex = sbstart(sb); bindex < sbmax(sb); bindex++) {
+		lower_mnt = unionfs_lower_mnt_idx(dentry, bindex);
+		if (lower_mnt) {
+			if (unlikely(bindex < dstart || bindex > dend)) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CM0: dentry/lmnt=%p:%p bindex=%d "
+					 "dstart/end=%d:%d\n", dentry,
+					 lower_mnt, bindex, dstart, dend);
+			}
+		} else {	/* lower_mnt == NULL */
+			if (bindex < dstart || bindex > dend)
+				continue;
+			/*
+			 * Directories can have NULL lower inodes in b/t
+			 * start/end, but NOT if at the start/end range.
+			 * Ignore this rule, however, if this is a NULL
+			 * dentry.
+			 */
+			if (unlikely(inode &&
+				     !(inode && S_ISDIR(inode->i_mode) &&
+				       bindex > dstart && bindex < dend))) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CM1: dentry/lmnt=%p:%p "
+					 "bindex=%d dstart/end=%d:%d\n",
+					 dentry, lower_mnt, bindex,
+					 dstart, dend);
+			}
+		}
+	}
+
+check_inode:
+	/* for inodes now */
+	if (!inode)
+		return;
+	istart = ibstart(inode);
+	iend = ibend(inode);
+	/* don't check inode if no lower branches */
+	if (istart < 0 && iend < 0)
+		return;
+	BUG_ON(istart > iend);
+	if (unlikely((istart == -1 && iend != -1) ||
+		     (istart != -1 && iend == -1))) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CI0: dentry/inode=%p:%p istart/end=%d:%d\n",
+			 dentry, inode, istart, iend);
+	}
+	if (unlikely(istart != dstart)) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CI1: dentry/inode=%p:%p istart=%d dstart=%d\n",
+			 dentry, inode, istart, dstart);
+	}
+	if (unlikely(iend != dend)) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CI2: dentry/inode=%p:%p iend=%d dend=%d\n",
+			 dentry, inode, iend, dend);
+	}
+
+	if (!S_ISDIR(inode->i_mode)) {
+		if (unlikely(dend != dstart)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" CI3: dentry/inode=%p:%p dstart=%d dend=%d\n",
+				 dentry, inode, dstart, dend);
+		}
+		if (unlikely(iend != istart)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" CI4: dentry/inode=%p:%p istart=%d iend=%d\n",
+				 dentry, inode, istart, iend);
+		}
+	}
+
+	for (bindex = sbstart(sb); bindex < sbmax(sb); bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (lower_inode) {
+			memset(&poison_ptr, POISON_INUSE, sizeof(void *));
+			if (unlikely(bindex < istart || bindex > iend)) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CI5: dentry/linode=%p:%p bindex=%d "
+					 "istart/end=%d:%d\n", dentry,
+					 lower_inode, bindex, istart, iend);
+			} else if (unlikely(lower_inode == poison_ptr)) {
+				/* freed inode! */
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CI6: dentry/linode=%p:%p bindex=%d "
+					 "istart/end=%d:%d\n", dentry,
+					 lower_inode, bindex, istart, iend);
+			}
+			continue;
+		}
+		/* if we get here, then lower_inode == NULL */
+		if (bindex < istart || bindex > iend)
+			continue;
+		/*
+		 * directories can have NULL lower inodes in b/t start/end,
+		 * but NOT if at the start/end range.
+		 */
+		if (unlikely(S_ISDIR(inode->i_mode) &&
+			     bindex > istart && bindex < iend))
+			continue;
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CI7: dentry/linode=%p:%p "
+			 "bindex=%d istart/end=%d:%d\n",
+			 dentry, lower_inode, bindex, istart, iend);
+	}
+
+	/*
+	 * If it's a directory, then intermediate objects b/t start/end can
+	 * be NULL.  But, check that all three are NULL: lower dentry, mnt,
+	 * and inode.
+	 */
+	if (dstart >= 0 && dend >= 0 && S_ISDIR(inode->i_mode))
+		for (bindex = dstart+1; bindex < dend; bindex++) {
+			lower_inode = unionfs_lower_inode_idx(inode, bindex);
+			lower_dentry = unionfs_lower_dentry_idx(dentry,
+								bindex);
+			lower_mnt = unionfs_lower_mnt_idx(dentry, bindex);
+			if (unlikely(!((lower_inode && lower_dentry &&
+					lower_mnt) ||
+				       (!lower_inode &&
+					!lower_dentry && !lower_mnt)))) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" Cx: lmnt/ldentry/linode=%p:%p:%p "
+					 "bindex=%d dstart/end=%d:%d\n",
+					 lower_mnt, lower_dentry, lower_inode,
+					 bindex, dstart, dend);
+			}
+		}
+	/* check if lower inode is newer than upper one (it shouldn't) */
+	if (unlikely(is_newer_lower(dentry) && !is_negative_lower(dentry))) {
+		PRINT_CALLER(fname, fxn, line);
+		for (bindex = ibstart(inode); bindex <= ibend(inode);
+		     bindex++) {
+			lower_inode = unionfs_lower_inode_idx(inode, bindex);
+			if (unlikely(!lower_inode))
+				continue;
+			pr_debug(" CI8: bindex=%d mtime/lmtime=%lu.%lu/%lu.%lu "
+				 "ctime/lctime=%lu.%lu/%lu.%lu\n",
+				 bindex,
+				 inode->i_mtime.tv_sec,
+				 inode->i_mtime.tv_nsec,
+				 lower_inode->i_mtime.tv_sec,
+				 lower_inode->i_mtime.tv_nsec,
+				 inode->i_ctime.tv_sec,
+				 inode->i_ctime.tv_nsec,
+				 lower_inode->i_ctime.tv_sec,
+				 lower_inode->i_ctime.tv_nsec);
+		}
+	}
+}
+
+void __unionfs_check_file(const struct file *file,
+			  const char *fname, const char *fxn, int line)
+{
+	int bindex;
+	int dstart, dend, fstart, fend;
+	struct dentry *dentry;
+	struct file *lower_file;
+	struct inode *inode;
+	struct super_block *sb;
+	int printed_caller = 0;
+
+	BUG_ON(!file);
+	dentry = file->f_path.dentry;
+	sb = dentry->d_sb;
+	dstart = dbstart(dentry);
+	dend = dbend(dentry);
+	BUG_ON(dstart > dend);
+	fstart = fbstart(file);
+	fend = fbend(file);
+	BUG_ON(fstart > fend);
+
+	if (unlikely((fstart == -1 && fend != -1) ||
+		     (fstart != -1 && fend == -1))) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CF0: file/dentry=%p:%p fstart/end=%d:%d\n",
+			 file, dentry, fstart, fend);
+	}
+	/* d_deleted dentries can be ignored for this test */
+	if (unlikely(fstart != dstart) && !d_deleted(dentry)) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CF1: file/dentry=%p:%p fstart=%d dstart=%d\n",
+			 file, dentry, fstart, dstart);
+	}
+	if (unlikely(fend != dend) && !d_deleted(dentry)) {
+		PRINT_CALLER(fname, fxn, line);
+		pr_debug(" CF2: file/dentry=%p:%p fend=%d dend=%d\n",
+			 file, dentry, fend, dend);
+	}
+	inode = dentry->d_inode;
+	if (!S_ISDIR(inode->i_mode)) {
+		if (unlikely(fend != fstart)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" CF3: file/inode=%p:%p fstart=%d fend=%d\n",
+				 file, inode, fstart, fend);
+		}
+		if (unlikely(dend != dstart)) {
+			PRINT_CALLER(fname, fxn, line);
+			pr_debug(" CF4: file/dentry=%p:%p dstart=%d dend=%d\n",
+				 file, dentry, dstart, dend);
+		}
+	}
+
+	/*
+	 * check for NULL dentries inside the start/end range, or
+	 * non-NULL dentries outside the start/end range.
+	 */
+	for (bindex = sbstart(sb); bindex < sbmax(sb); bindex++) {
+		lower_file = unionfs_lower_file_idx(file, bindex);
+		if (lower_file) {
+			if (unlikely(bindex < fstart || bindex > fend)) {
+				PRINT_CALLER(fname, fxn, line);
+				pr_debug(" CF5: file/lower=%p:%p bindex=%d "
+					 "fstart/end=%d:%d\n", file,
+					 lower_file, bindex, fstart, fend);
+			}
+		} else {	/* lower_file == NULL */
+			if (bindex >= fstart && bindex <= fend) {
+				/*
+				 * directories can have NULL lower inodes in
+				 * b/t start/end, but NOT if at the
+				 * start/end range.
+				 */
+				if (unlikely(!(S_ISDIR(inode->i_mode) &&
+					       bindex > fstart &&
+					       bindex < fend))) {
+					PRINT_CALLER(fname, fxn, line);
+					pr_debug(" CF6: file/lower=%p:%p "
+						 "bindex=%d fstart/end=%d:%d\n",
+						 file, lower_file, bindex,
+						 fstart, fend);
+				}
+			}
+		}
+	}
+
+	__unionfs_check_dentry(dentry, fname, fxn, line);
+}
+
+static unsigned int __mnt_get_count(struct vfsmount *mnt)
+{
+	struct mount *m = real_mount(mnt);
+#ifdef CONFIG_SMP
+	unsigned int count = 0;
+	int cpu;
+
+	for_each_possible_cpu(cpu) {
+		count += per_cpu_ptr(m->mnt_pcp, cpu)->mnt_count;
+	}
+
+	return count;
+#else
+	return m->mnt_count;
+#endif
+}
+
+/* useful to track vfsmount leaks that could cause EBUSY on unmount */
+void __show_branch_counts(const struct super_block *sb,
+			  const char *file, const char *fxn, int line)
+{
+	int i;
+	struct vfsmount *mnt;
+
+	pr_debug("BC:");
+	for (i = 0; i < sbmax(sb); i++) {
+		if (likely(sb->s_root))
+			mnt = UNIONFS_D(sb->s_root)->lower_paths[i].mnt;
+		else
+			mnt = NULL;
+		printk(KERN_CONT "%d:",
+		       (mnt ? __mnt_get_count(mnt) : -99));
+	}
+	printk(KERN_CONT "%s:%s:%d\n", file, fxn, line);
+}
+
+void __show_inode_times(const struct inode *inode,
+			const char *file, const char *fxn, int line)
+{
+	struct inode *lower_inode;
+	int bindex;
+
+	for (bindex = ibstart(inode); bindex <= ibend(inode); bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (unlikely(!lower_inode))
+			continue;
+		pr_debug("IT(%lu:%d): %s:%s:%d "
+			 "um=%lu/%lu lm=%lu/%lu uc=%lu/%lu lc=%lu/%lu\n",
+			 inode->i_ino, bindex,
+			 file, fxn, line,
+			 inode->i_mtime.tv_sec, inode->i_mtime.tv_nsec,
+			 lower_inode->i_mtime.tv_sec,
+			 lower_inode->i_mtime.tv_nsec,
+			 inode->i_ctime.tv_sec, inode->i_ctime.tv_nsec,
+			 lower_inode->i_ctime.tv_sec,
+			 lower_inode->i_ctime.tv_nsec);
+	}
+}
+
+void __show_dinode_times(const struct dentry *dentry,
+			const char *file, const char *fxn, int line)
+{
+	struct inode *inode = dentry->d_inode;
+	struct inode *lower_inode;
+	int bindex;
+
+	for (bindex = ibstart(inode); bindex <= ibend(inode); bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode)
+			continue;
+		pr_debug("DT(%s:%lu:%d): %s:%s:%d "
+			 "um=%lu/%lu lm=%lu/%lu uc=%lu/%lu lc=%lu/%lu\n",
+			 dentry->d_name.name, inode->i_ino, bindex,
+			 file, fxn, line,
+			 inode->i_mtime.tv_sec, inode->i_mtime.tv_nsec,
+			 lower_inode->i_mtime.tv_sec,
+			 lower_inode->i_mtime.tv_nsec,
+			 inode->i_ctime.tv_sec, inode->i_ctime.tv_nsec,
+			 lower_inode->i_ctime.tv_sec,
+			 lower_inode->i_ctime.tv_nsec);
+	}
+}
+
+void __show_inode_counts(const struct inode *inode,
+			const char *file, const char *fxn, int line)
+{
+	struct inode *lower_inode;
+	int bindex;
+
+	if (unlikely(!inode)) {
+		pr_debug("SiC: Null inode\n");
+		return;
+	}
+	for (bindex = sbstart(inode->i_sb); bindex <= sbend(inode->i_sb);
+	     bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (unlikely(!lower_inode))
+			continue;
+		pr_debug("SIC(%lu:%d:%d): lc=%d %s:%s:%d\n",
+			 inode->i_ino, bindex,
+			 atomic_read(&(inode)->i_count),
+			 atomic_read(&(lower_inode)->i_count),
+			 file, fxn, line);
+	}
+}
diff --git a/fs/unionfs/dentry.c b/fs/unionfs/dentry.c
new file mode 100644
index 00000000..5f0c57a
--- /dev/null
+++ b/fs/unionfs/dentry.c
@@ -0,0 +1,397 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+bool is_negative_lower(const struct dentry *dentry)
+{
+	int bindex;
+	struct dentry *lower_dentry;
+
+	BUG_ON(!dentry);
+	/* cache coherency: check if file was deleted on lower branch */
+	if (dbstart(dentry) < 0)
+		return true;
+	for (bindex = dbstart(dentry); bindex <= dbend(dentry); bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		/* unhashed (i.e., unlinked) lower dentries don't count */
+		if (lower_dentry && lower_dentry->d_inode &&
+		    !d_deleted(lower_dentry) &&
+		    !(lower_dentry->d_flags & DCACHE_NFSFS_RENAMED))
+			return false;
+	}
+	return true;
+}
+
+static inline void __dput_lowers(struct dentry *dentry, int start, int end)
+{
+	struct dentry *lower_dentry;
+	int bindex;
+
+	if (start < 0)
+		return;
+	for (bindex = start; bindex <= end; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+		unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+		dput(lower_dentry);
+	}
+}
+
+/*
+ * Purge and invalidate as many data pages of a unionfs inode.  This is
+ * called when the lower inode has changed, and we want to force processes
+ * to re-get the new data.
+ */
+static inline void purge_inode_data(struct inode *inode)
+{
+	/* remove all non-private mappings */
+	unmap_mapping_range(inode->i_mapping, 0, 0, 0);
+	/* invalidate as many pages as possible */
+	invalidate_mapping_pages(inode->i_mapping, 0, -1);
+	/*
+	 * Don't try to truncate_inode_pages here, because this could lead
+	 * to a deadlock between some of address_space ops and dentry
+	 * revalidation: the address space op is invoked with a lock on our
+	 * own page, and truncate_inode_pages will block on locked pages.
+	 */
+}
+
+/*
+ * Revalidate a single file/symlink/special dentry.  Assume that info nodes
+ * of the @dentry and its @parent are locked.  Assume parent is valid,
+ * otherwise return false (and let's hope the VFS will try to re-lookup this
+ * dentry).  Returns true if valid, false otherwise.
+ */
+bool __unionfs_d_revalidate(struct dentry *dentry, struct dentry *parent,
+			    bool willwrite, unsigned int flags)
+{
+	bool valid = true;	/* default is valid */
+	struct dentry *lower_dentry;
+	struct dentry *result;
+	int bindex, bstart, bend;
+	int sbgen, dgen, pdgen;
+	int positive = 0;
+	int interpose_flag;
+
+	verify_locked(dentry);
+	verify_locked(parent);
+
+	/* if the dentry is unhashed, do NOT revalidate */
+	if (d_deleted(dentry))
+		goto out;
+
+	dgen = atomic_read(&UNIONFS_D(dentry)->generation);
+
+	if (is_newer_lower(dentry)) {
+		/* root dentry is always valid */
+		if (IS_ROOT(dentry)) {
+			unionfs_copy_attr_times(dentry->d_inode);
+		} else {
+			/*
+			 * reset generation number to zero, guaranteed to be
+			 * "old"
+			 */
+			dgen = 0;
+			atomic_set(&UNIONFS_D(dentry)->generation, dgen);
+		}
+		if (!willwrite)
+			purge_inode_data(dentry->d_inode);
+	}
+
+	sbgen = atomic_read(&UNIONFS_SB(dentry->d_sb)->generation);
+
+	BUG_ON(dbstart(dentry) == -1);
+	if (dentry->d_inode)
+		positive = 1;
+
+	/* if our dentry is valid, then validate all lower ones */
+	if (sbgen == dgen)
+		goto validate_lowers;
+
+	/* The root entry should always be valid */
+	BUG_ON(IS_ROOT(dentry));
+
+	/* We can't work correctly if our parent isn't valid. */
+	pdgen = atomic_read(&UNIONFS_D(parent)->generation);
+
+	/* Free the pointers for our inodes and this dentry. */
+	path_put_lowers_all(dentry, false);
+
+	interpose_flag = INTERPOSE_REVAL_NEG;
+	if (positive) {
+		interpose_flag = INTERPOSE_REVAL;
+		iput_lowers_all(dentry->d_inode, true);
+	}
+
+	if (realloc_dentry_private_data(dentry) != 0) {
+		valid = false;
+		goto out;
+	}
+
+	result = unionfs_lookup_full(dentry, parent, interpose_flag);
+	if (result) {
+		if (IS_ERR(result)) {
+			valid = false;
+			goto out;
+		}
+		/*
+		 * current unionfs_lookup_backend() doesn't return
+		 * a valid dentry
+		 */
+		dput(dentry);
+		dentry = result;
+	}
+
+	if (unlikely(positive && is_negative_lower(dentry))) {
+		/* call make_bad_inode here ? */
+		d_drop(dentry);
+		valid = false;
+		goto out;
+	}
+
+	/*
+	 * if we got here then we have revalidated our dentry and all lower
+	 * ones, so we can return safely.
+	 */
+	if (!valid)		/* lower dentry revalidation failed */
+		goto out;
+
+	/*
+	 * If the parent's gen no.  matches the superblock's gen no., then
+	 * we can update our denty's gen no.  If they didn't match, then it
+	 * was OK to revalidate this dentry with a stale parent, but we'll
+	 * purposely not update our dentry's gen no. (so it can be redone);
+	 * and, we'll mark our parent dentry as invalid so it'll force it
+	 * (and our dentry) to be revalidated.
+	 */
+	if (pdgen == sbgen)
+		atomic_set(&UNIONFS_D(dentry)->generation, sbgen);
+	goto out;
+
+validate_lowers:
+
+	/* The revalidation must occur across all branches */
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+	BUG_ON(bstart == -1);
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry || !lower_dentry->d_op
+		    || !lower_dentry->d_op->d_revalidate)
+			continue;
+		if (!lower_dentry->d_op->d_revalidate(lower_dentry, flags))
+			valid = false;
+	}
+
+	if (!dentry->d_inode ||
+	    ibstart(dentry->d_inode) < 0 ||
+	    ibend(dentry->d_inode) < 0) {
+		valid = false;
+		goto out;
+	}
+
+	if (valid) {
+		/*
+		 * If we get here, and we copy the meta-data from the lower
+		 * inode to our inode, then it is vital that we have already
+		 * purged all unionfs-level file data.  We do that in the
+		 * caller (__unionfs_d_revalidate) by calling
+		 * purge_inode_data.
+		 */
+		unionfs_copy_attr_all(dentry->d_inode,
+				      unionfs_lower_inode(dentry->d_inode));
+		fsstack_copy_inode_size(dentry->d_inode,
+					unionfs_lower_inode(dentry->d_inode));
+	}
+
+out:
+	return valid;
+}
+
+/*
+ * Determine if the lower inode objects have changed from below the unionfs
+ * inode.  Return true if changed, false otherwise.
+ *
+ * We check if the mtime or ctime have changed.  However, the inode times
+ * can be changed by anyone without much protection, including
+ * asynchronously.  This can sometimes cause unionfs to find that the lower
+ * file system doesn't change its inode times quick enough, resulting in a
+ * false positive indication (which is harmless, it just makes unionfs do
+ * extra work in re-validating the objects).  To minimize the chances of
+ * these situations, we still consider such small time changes valid, but we
+ * don't print debugging messages unless the time changes are greater than
+ * UNIONFS_MIN_CC_TIME (which defaults to 3 seconds, as with NFS's acregmin)
+ * because significant changes are more likely due to users manually
+ * touching lower files.
+ */
+bool is_newer_lower(const struct dentry *dentry)
+{
+	int bindex;
+	struct inode *inode;
+	struct inode *lower_inode;
+
+	/* ignore if we're called on semi-initialized dentries/inodes */
+	if (!dentry || !UNIONFS_D(dentry))
+		return false;
+	inode = dentry->d_inode;
+	if (!inode || !UNIONFS_I(inode)->lower_inodes ||
+	    ibstart(inode) < 0 || ibend(inode) < 0)
+		return false;
+
+	for (bindex = ibstart(inode); bindex <= ibend(inode); bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode)
+			continue;
+
+		/* check if mtime/ctime have changed */
+		if (unlikely(timespec_compare(&inode->i_mtime,
+					      &lower_inode->i_mtime) < 0)) {
+			if ((lower_inode->i_mtime.tv_sec -
+			     inode->i_mtime.tv_sec) > UNIONFS_MIN_CC_TIME) {
+				pr_info("unionfs: new lower inode mtime "
+					"(bindex=%d, name=%s)\n", bindex,
+					dentry->d_name.name);
+				show_dinode_times(dentry);
+			}
+			return true;
+		}
+		if (unlikely(timespec_compare(&inode->i_ctime,
+					      &lower_inode->i_ctime) < 0)) {
+			if ((lower_inode->i_ctime.tv_sec -
+			     inode->i_ctime.tv_sec) > UNIONFS_MIN_CC_TIME) {
+				pr_info("unionfs: new lower inode ctime "
+					"(bindex=%d, name=%s)\n", bindex,
+					dentry->d_name.name);
+				show_dinode_times(dentry);
+			}
+			return true;
+		}
+	}
+
+	/*
+	 * Last check: if this is a positive dentry, but somehow all lower
+	 * dentries are negative or unhashed, then this dentry needs to be
+	 * revalidated, because someone probably deleted the objects from
+	 * the lower branches directly.
+	 */
+	if (is_negative_lower(dentry))
+		return true;
+
+	return false;		/* default: lower is not newer */
+}
+
+static int unionfs_d_revalidate(struct dentry *dentry, unsigned int flags)
+{
+	bool valid = true;
+	int err = 1;		/* 1 means valid for the VFS */
+	struct dentry *parent;
+
+	if (flags & LOOKUP_RCU)
+		return -ECHILD;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	if (!unionfs_lower_dentry(dentry)) {
+		err = 0;
+		goto out;
+	}
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, flags);
+	if (valid) {
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_check_dentry(dentry);
+	} else {
+		d_drop(dentry);
+		err = valid;
+	}
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+
+	return err;
+}
+
+static void unionfs_d_release(struct dentry *dentry)
+{
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	if (unlikely(!UNIONFS_D(dentry)))
+		goto out;	/* skip if no lower branches */
+	/* must lock our branch configuration here */
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	unionfs_check_dentry(dentry);
+	/* this could be a negative dentry, so check first */
+	if (dbstart(dentry) < 0) {
+		unionfs_unlock_dentry(dentry);
+		goto out;	/* due to a (normal) failed lookup */
+	}
+
+	/* Release all the lower dentries */
+	path_put_lowers_all(dentry, true);
+
+	unionfs_unlock_dentry(dentry);
+
+out:
+	free_dentry_private_data(dentry);
+	unionfs_read_unlock(dentry->d_sb);
+	return;
+}
+
+/*
+ * Called when we're removing the last reference to our dentry.  So we
+ * should drop all lower references too.
+ */
+static void unionfs_d_iput(struct dentry *dentry, struct inode *inode)
+{
+	int rc;
+
+	BUG_ON(!dentry);
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	if (!UNIONFS_D(dentry) || dbstart(dentry) < 0)
+		goto drop_lower_inodes;
+	path_put_lowers_all(dentry, false);
+
+drop_lower_inodes:
+	rc = atomic_read(&inode->i_count);
+	if (rc == 1 && inode->i_nlink == 1 && ibstart(inode) >= 0) {
+		/* see Documentation/filesystems/unionfs/issues.txt */
+		lockdep_off();
+		iput(unionfs_lower_inode(inode));
+		lockdep_on();
+		unionfs_set_lower_inode(inode, NULL);
+		/* XXX: may need to set start/end to -1? */
+	}
+
+	iput(inode);
+
+	unionfs_unlock_dentry(dentry);
+	unionfs_read_unlock(dentry->d_sb);
+}
+
+struct dentry_operations unionfs_dops = {
+	.d_revalidate	= unionfs_d_revalidate,
+	.d_release	= unionfs_d_release,
+	.d_iput		= unionfs_d_iput,
+};
diff --git a/fs/unionfs/dirfops.c b/fs/unionfs/dirfops.c
new file mode 100644
index 00000000..b79b437
--- /dev/null
+++ b/fs/unionfs/dirfops.c
@@ -0,0 +1,302 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/* Make sure our rdstate is playing by the rules. */
+static void verify_rdstate_offset(struct unionfs_dir_state *rdstate)
+{
+	BUG_ON(rdstate->offset >= DIREOF);
+	BUG_ON(rdstate->cookie >= MAXRDCOOKIE);
+}
+
+struct unionfs_getdents_callback {
+	struct unionfs_dir_state *rdstate;
+	void *dirent;
+	int entries_written;
+	int filldir_called;
+	int filldir_error;
+	filldir_t filldir;
+	struct super_block *sb;
+};
+
+/* based on generic filldir in fs/readir.c */
+static int unionfs_filldir(void *dirent, const char *oname, int namelen,
+			   loff_t offset, u64 ino, unsigned int d_type)
+{
+	struct unionfs_getdents_callback *buf = dirent;
+	struct filldir_node *found = NULL;
+	int err = 0;
+	int is_whiteout;
+	char *name = (char *) oname;
+
+	buf->filldir_called++;
+
+	is_whiteout = is_whiteout_name(&name, &namelen);
+
+	found = find_filldir_node(buf->rdstate, name, namelen, is_whiteout);
+
+	if (found) {
+		/*
+		 * If we had non-whiteout entry in dir cache, then mark it
+		 * as a whiteout and but leave it in the dir cache.
+		 */
+		if (is_whiteout && !found->whiteout)
+			found->whiteout = is_whiteout;
+		goto out;
+	}
+
+	/* if 'name' isn't a whiteout, filldir it. */
+	if (!is_whiteout) {
+		off_t pos = rdstate2offset(buf->rdstate);
+		u64 unionfs_ino = ino;
+
+		err = buf->filldir(buf->dirent, name, namelen, pos,
+				   unionfs_ino, d_type);
+		buf->rdstate->offset++;
+		verify_rdstate_offset(buf->rdstate);
+	}
+	/*
+	 * If we did fill it, stuff it in our hash, otherwise return an
+	 * error.
+	 */
+	if (err) {
+		buf->filldir_error = err;
+		goto out;
+	}
+	buf->entries_written++;
+	err = add_filldir_node(buf->rdstate, name, namelen,
+			       buf->rdstate->bindex, is_whiteout);
+	if (err)
+		buf->filldir_error = err;
+
+out:
+	return err;
+}
+
+static int unionfs_readdir(struct file *file, void *dirent, filldir_t filldir)
+{
+	int err = 0;
+	struct file *lower_file = NULL;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	struct inode *inode = NULL;
+	struct unionfs_getdents_callback buf;
+	struct unionfs_dir_state *uds;
+	int bend;
+	loff_t offset;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, false);
+	if (unlikely(err))
+		goto out;
+
+	inode = dentry->d_inode;
+
+	uds = UNIONFS_F(file)->rdstate;
+	if (!uds) {
+		if (file->f_pos == DIREOF) {
+			goto out;
+		} else if (file->f_pos > 0) {
+			uds = find_rdstate(inode, file->f_pos);
+			if (unlikely(!uds)) {
+				err = -ESTALE;
+				goto out;
+			}
+			UNIONFS_F(file)->rdstate = uds;
+		} else {
+			init_rdstate(file);
+			uds = UNIONFS_F(file)->rdstate;
+		}
+	}
+	bend = fbend(file);
+
+	while (uds->bindex <= bend) {
+		lower_file = unionfs_lower_file_idx(file, uds->bindex);
+		if (!lower_file) {
+			uds->bindex++;
+			uds->dirpos = 0;
+			continue;
+		}
+
+		/* prepare callback buffer */
+		buf.filldir_called = 0;
+		buf.filldir_error = 0;
+		buf.entries_written = 0;
+		buf.dirent = dirent;
+		buf.filldir = filldir;
+		buf.rdstate = uds;
+		buf.sb = inode->i_sb;
+
+		/* Read starting from where we last left off. */
+		offset = vfs_llseek(lower_file, uds->dirpos, SEEK_SET);
+		if (offset < 0) {
+			err = offset;
+			goto out;
+		}
+		err = vfs_readdir(lower_file, unionfs_filldir, &buf);
+
+		/* Save the position for when we continue. */
+		offset = vfs_llseek(lower_file, 0, SEEK_CUR);
+		if (offset < 0) {
+			err = offset;
+			goto out;
+		}
+		uds->dirpos = offset;
+
+		/* Copy the atime. */
+		fsstack_copy_attr_atime(inode,
+					lower_file->f_path.dentry->d_inode);
+
+		if (err < 0)
+			goto out;
+
+		if (buf.filldir_error)
+			break;
+
+		if (!buf.entries_written) {
+			uds->bindex++;
+			uds->dirpos = 0;
+		}
+	}
+
+	if (!buf.filldir_error && uds->bindex >= bend) {
+		/* Save the number of hash entries for next time. */
+		UNIONFS_I(inode)->hashsize = uds->hashentries;
+		free_rdstate(uds);
+		UNIONFS_F(file)->rdstate = NULL;
+		file->f_pos = DIREOF;
+	} else {
+		file->f_pos = rdstate2offset(uds);
+	}
+
+out:
+	if (!err)
+		unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * This is not meant to be a generic repositioning function.  If you do
+ * things that aren't supported, then we return EINVAL.
+ *
+ * What is allowed:
+ *  (1) seeking to the same position that you are currently at
+ *	This really has no effect, but returns where you are.
+ *  (2) seeking to the beginning of the file
+ *	This throws out all state, and lets you begin again.
+ */
+static loff_t unionfs_dir_llseek(struct file *file, loff_t offset, int origin)
+{
+	struct unionfs_dir_state *rdstate;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	loff_t err;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, false);
+	if (unlikely(err))
+		goto out;
+
+	rdstate = UNIONFS_F(file)->rdstate;
+
+	/*
+	 * we let users seek to their current position, but not anywhere
+	 * else.
+	 */
+	if (!offset) {
+		switch (origin) {
+		case SEEK_SET:
+			if (rdstate) {
+				free_rdstate(rdstate);
+				UNIONFS_F(file)->rdstate = NULL;
+			}
+			init_rdstate(file);
+			err = 0;
+			break;
+		case SEEK_CUR:
+			err = file->f_pos;
+			break;
+		case SEEK_END:
+			/* Unsupported, because we would break everything.  */
+			err = -EINVAL;
+			break;
+		}
+	} else {
+		switch (origin) {
+		case SEEK_SET:
+			if (rdstate) {
+				if (offset == rdstate2offset(rdstate))
+					err = offset;
+				else if (file->f_pos == DIREOF)
+					err = DIREOF;
+				else
+					err = -EINVAL;
+			} else {
+				struct inode *inode;
+				inode = dentry->d_inode;
+				rdstate = find_rdstate(inode, offset);
+				if (rdstate) {
+					UNIONFS_F(file)->rdstate = rdstate;
+					err = rdstate->offset;
+				} else {
+					err = -EINVAL;
+				}
+			}
+			break;
+		case SEEK_CUR:
+		case SEEK_END:
+			/* Unsupported, because we would break everything.  */
+			err = -EINVAL;
+			break;
+		}
+	}
+
+out:
+	if (!err)
+		unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * Trimmed directory options, we shouldn't pass everything down since
+ * we don't want to operate on partial directories.
+ */
+struct file_operations unionfs_dir_fops = {
+	.llseek		= unionfs_dir_llseek,
+	.read		= generic_read_dir,
+	.readdir	= unionfs_readdir,
+	.unlocked_ioctl	= unionfs_ioctl,
+	.open		= unionfs_open,
+	.release	= unionfs_file_release,
+	.flush		= unionfs_flush,
+	.fsync		= unionfs_fsync,
+	.fasync		= unionfs_fasync,
+};
diff --git a/fs/unionfs/dirhelper.c b/fs/unionfs/dirhelper.c
new file mode 100644
index 00000000..7ef669d
--- /dev/null
+++ b/fs/unionfs/dirhelper.c
@@ -0,0 +1,162 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+#define RD_NONE 0
+#define RD_CHECK_EMPTY 1
+/* The callback structure for check_empty. */
+struct unionfs_rdutil_callback {
+	int err;
+	int filldir_called;
+	struct unionfs_dir_state *rdstate;
+	int mode;
+};
+
+/* This filldir function makes sure only whiteouts exist within a directory. */
+static int readdir_util_callback(void *dirent, const char *oname, int namelen,
+				 loff_t offset, u64 ino, unsigned int d_type)
+{
+	int err = 0;
+	struct unionfs_rdutil_callback *buf = dirent;
+	int is_whiteout;
+	struct filldir_node *found;
+	char *name = (char *) oname;
+
+	buf->filldir_called = 1;
+
+	if (name[0] == '.' && (namelen == 1 ||
+			       (name[1] == '.' && namelen == 2)))
+		goto out;
+
+	is_whiteout = is_whiteout_name(&name, &namelen);
+
+	found = find_filldir_node(buf->rdstate, name, namelen, is_whiteout);
+	/* If it was found in the table there was a previous whiteout. */
+	if (found)
+		goto out;
+
+	/*
+	 * if it wasn't found and isn't a whiteout, the directory isn't
+	 * empty.
+	 */
+	err = -ENOTEMPTY;
+	if ((buf->mode == RD_CHECK_EMPTY) && !is_whiteout)
+		goto out;
+
+	err = add_filldir_node(buf->rdstate, name, namelen,
+			       buf->rdstate->bindex, is_whiteout);
+
+out:
+	buf->err = err;
+	return err;
+}
+
+/* Is a directory logically empty? */
+int check_empty(struct dentry *dentry, struct dentry *parent,
+		struct unionfs_dir_state **namelist)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct vfsmount *mnt;
+	struct super_block *sb;
+	struct file *lower_file;
+	struct unionfs_rdutil_callback *buf = NULL;
+	int bindex, bstart, bend, bopaque;
+	struct path path;
+
+	sb = dentry->d_sb;
+
+
+	BUG_ON(!S_ISDIR(dentry->d_inode->i_mode));
+
+	err = unionfs_partial_lookup(dentry, parent);
+	if (err)
+		goto out;
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+	bopaque = dbopaque(dentry);
+	if (0 <= bopaque && bopaque < bend)
+		bend = bopaque;
+
+	buf = kmalloc(sizeof(struct unionfs_rdutil_callback), GFP_KERNEL);
+	if (unlikely(!buf)) {
+		err = -ENOMEM;
+		goto out;
+	}
+	buf->err = 0;
+	buf->mode = RD_CHECK_EMPTY;
+	buf->rdstate = alloc_rdstate(dentry->d_inode, bstart);
+	if (unlikely(!buf->rdstate)) {
+		err = -ENOMEM;
+		goto out;
+	}
+
+	/* Process the lower directories with rdutil_callback as a filldir. */
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+		if (!lower_dentry->d_inode)
+			continue;
+		if (!S_ISDIR(lower_dentry->d_inode->i_mode))
+			continue;
+
+		dget(lower_dentry);
+		mnt = unionfs_mntget(dentry, bindex);
+		branchget(sb, bindex);
+		path.dentry = lower_dentry;
+		path.mnt = mnt;
+		lower_file = dentry_open(&path, O_RDONLY, current_cred());
+		path_put(&path);
+		if (IS_ERR(lower_file)) {
+			err = PTR_ERR(lower_file);
+			branchput(sb, bindex);
+			goto out;
+		}
+
+		do {
+			buf->filldir_called = 0;
+			buf->rdstate->bindex = bindex;
+			err = vfs_readdir(lower_file,
+					  readdir_util_callback, buf);
+			if (buf->err)
+				err = buf->err;
+		} while ((err >= 0) && buf->filldir_called);
+
+		/* fput calls dput for lower_dentry */
+		fput(lower_file);
+		branchput(sb, bindex);
+
+		if (err < 0)
+			goto out;
+	}
+
+out:
+	if (buf) {
+		if (namelist && !err)
+			*namelist = buf->rdstate;
+		else if (buf->rdstate)
+			free_rdstate(buf->rdstate);
+		kfree(buf);
+	}
+
+
+	return err;
+}
diff --git a/fs/unionfs/fanout.h b/fs/unionfs/fanout.h
new file mode 100644
index 00000000..1e5e996
--- /dev/null
+++ b/fs/unionfs/fanout.h
@@ -0,0 +1,407 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#ifndef _FANOUT_H_
+#define _FANOUT_H_
+
+/*
+ * Inode to private data
+ *
+ * Since we use containers and the struct inode is _inside_ the
+ * unionfs_inode_info structure, UNIONFS_I will always (given a non-NULL
+ * inode pointer), return a valid non-NULL pointer.
+ */
+static inline struct unionfs_inode_info *UNIONFS_I(const struct inode *inode)
+{
+	return container_of(inode, struct unionfs_inode_info, vfs_inode);
+}
+
+#define ibstart(ino) (UNIONFS_I(ino)->bstart)
+#define ibend(ino) (UNIONFS_I(ino)->bend)
+
+/* Dentry to private data */
+#define UNIONFS_D(dent) ((struct unionfs_dentry_info *)(dent)->d_fsdata)
+#define dbstart(dent) (UNIONFS_D(dent)->bstart)
+#define dbend(dent) (UNIONFS_D(dent)->bend)
+#define dbopaque(dent) (UNIONFS_D(dent)->bopaque)
+
+/* Superblock to private data */
+#define UNIONFS_SB(super) ((struct unionfs_sb_info *)(super)->s_fs_info)
+#define sbstart(sb) 0
+#define sbend(sb) (UNIONFS_SB(sb)->bend)
+#define sbmax(sb) (UNIONFS_SB(sb)->bend + 1)
+#define sbhbid(sb) (UNIONFS_SB(sb)->high_branch_id)
+
+/* File to private Data */
+#define UNIONFS_F(file) ((struct unionfs_file_info *)((file)->private_data))
+#define fbstart(file) (UNIONFS_F(file)->bstart)
+#define fbend(file) (UNIONFS_F(file)->bend)
+
+/* macros to manipulate branch IDs in stored in our superblock */
+static inline int branch_id(struct super_block *sb, int index)
+{
+	BUG_ON(!sb || index < 0);
+	return UNIONFS_SB(sb)->data[index].branch_id;
+}
+
+static inline void set_branch_id(struct super_block *sb, int index, int val)
+{
+	BUG_ON(!sb || index < 0);
+	UNIONFS_SB(sb)->data[index].branch_id = val;
+}
+
+static inline void new_branch_id(struct super_block *sb, int index)
+{
+	BUG_ON(!sb || index < 0);
+	set_branch_id(sb, index, ++UNIONFS_SB(sb)->high_branch_id);
+}
+
+/*
+ * Find new index of matching branch with an existing superblock of a known
+ * (possibly old) id.  This is needed because branches could have been
+ * added/deleted causing the branches of any open files to shift.
+ *
+ * @sb: the new superblock which may have new/different branch IDs
+ * @id: the old/existing id we're looking for
+ * Returns index of newly found branch (0 or greater), -1 otherwise.
+ */
+static inline int branch_id_to_idx(struct super_block *sb, int id)
+{
+	int i;
+	for (i = 0; i < sbmax(sb); i++) {
+		if (branch_id(sb, i) == id)
+			return i;
+	}
+	/* in the non-ODF code, this should really never happen */
+	printk(KERN_WARNING "unionfs: cannot find branch with id %d\n", id);
+	return -1;
+}
+
+/* File to lower file. */
+static inline struct file *unionfs_lower_file(const struct file *f)
+{
+	BUG_ON(!f);
+	return UNIONFS_F(f)->lower_files[fbstart(f)];
+}
+
+static inline struct file *unionfs_lower_file_idx(const struct file *f,
+						  int index)
+{
+	BUG_ON(!f || index < 0);
+	return UNIONFS_F(f)->lower_files[index];
+}
+
+static inline void unionfs_set_lower_file_idx(struct file *f, int index,
+					      struct file *val)
+{
+	BUG_ON(!f || index < 0);
+	UNIONFS_F(f)->lower_files[index] = val;
+	/* save branch ID (may be redundant?) */
+	UNIONFS_F(f)->saved_branch_ids[index] =
+		branch_id((f)->f_path.dentry->d_sb, index);
+}
+
+static inline void unionfs_set_lower_file(struct file *f, struct file *val)
+{
+	BUG_ON(!f);
+	unionfs_set_lower_file_idx((f), fbstart(f), (val));
+}
+
+/* Inode to lower inode. */
+static inline struct inode *unionfs_lower_inode(const struct inode *i)
+{
+	BUG_ON(!i);
+	return UNIONFS_I(i)->lower_inodes[ibstart(i)];
+}
+
+static inline struct inode *unionfs_lower_inode_idx(const struct inode *i,
+						    int index)
+{
+	BUG_ON(!i || index < 0);
+	return UNIONFS_I(i)->lower_inodes[index];
+}
+
+static inline void unionfs_set_lower_inode_idx(struct inode *i, int index,
+					       struct inode *val)
+{
+	BUG_ON(!i || index < 0);
+	UNIONFS_I(i)->lower_inodes[index] = val;
+}
+
+static inline void unionfs_set_lower_inode(struct inode *i, struct inode *val)
+{
+	BUG_ON(!i);
+	UNIONFS_I(i)->lower_inodes[ibstart(i)] = val;
+}
+
+/* Superblock to lower superblock. */
+static inline struct super_block *unionfs_lower_super(
+					const struct super_block *sb)
+{
+	BUG_ON(!sb);
+	return UNIONFS_SB(sb)->data[sbstart(sb)].sb;
+}
+
+static inline struct super_block *unionfs_lower_super_idx(
+					const struct super_block *sb,
+					int index)
+{
+	BUG_ON(!sb || index < 0);
+	return UNIONFS_SB(sb)->data[index].sb;
+}
+
+static inline void unionfs_set_lower_super_idx(struct super_block *sb,
+					       int index,
+					       struct super_block *val)
+{
+	BUG_ON(!sb || index < 0);
+	UNIONFS_SB(sb)->data[index].sb = val;
+}
+
+static inline void unionfs_set_lower_super(struct super_block *sb,
+					   struct super_block *val)
+{
+	BUG_ON(!sb);
+	UNIONFS_SB(sb)->data[sbstart(sb)].sb = val;
+}
+
+/* Branch count macros. */
+static inline int branch_count(const struct super_block *sb, int index)
+{
+	BUG_ON(!sb || index < 0);
+	return atomic_read(&UNIONFS_SB(sb)->data[index].open_files);
+}
+
+static inline void set_branch_count(struct super_block *sb, int index, int val)
+{
+	BUG_ON(!sb || index < 0);
+	atomic_set(&UNIONFS_SB(sb)->data[index].open_files, val);
+}
+
+static inline void branchget(struct super_block *sb, int index)
+{
+	BUG_ON(!sb || index < 0);
+	atomic_inc(&UNIONFS_SB(sb)->data[index].open_files);
+}
+
+static inline void branchput(struct super_block *sb, int index)
+{
+	BUG_ON(!sb || index < 0);
+	atomic_dec(&UNIONFS_SB(sb)->data[index].open_files);
+}
+
+/* Dentry macros */
+static inline void unionfs_set_lower_dentry_idx(struct dentry *dent, int index,
+						struct dentry *val)
+{
+	BUG_ON(!dent || index < 0);
+	UNIONFS_D(dent)->lower_paths[index].dentry = val;
+}
+
+static inline struct dentry *unionfs_lower_dentry_idx(
+				const struct dentry *dent,
+				int index)
+{
+	BUG_ON(!dent || index < 0);
+	return UNIONFS_D(dent)->lower_paths[index].dentry;
+}
+
+static inline struct dentry *unionfs_lower_dentry(const struct dentry *dent)
+{
+	BUG_ON(!dent);
+	return unionfs_lower_dentry_idx(dent, dbstart(dent));
+}
+
+static inline void unionfs_set_lower_mnt_idx(struct dentry *dent, int index,
+					     struct vfsmount *mnt)
+{
+	BUG_ON(!dent || index < 0);
+	UNIONFS_D(dent)->lower_paths[index].mnt = mnt;
+}
+
+static inline struct vfsmount *unionfs_lower_mnt_idx(
+					const struct dentry *dent,
+					int index)
+{
+	BUG_ON(!dent || index < 0);
+	return UNIONFS_D(dent)->lower_paths[index].mnt;
+}
+
+static inline struct vfsmount *unionfs_lower_mnt(const struct dentry *dent)
+{
+	BUG_ON(!dent);
+	return unionfs_lower_mnt_idx(dent, dbstart(dent));
+}
+
+/* Macros for locking a dentry. */
+enum unionfs_dentry_lock_class {
+	UNIONFS_DMUTEX_NORMAL,
+	UNIONFS_DMUTEX_ROOT,
+	UNIONFS_DMUTEX_PARENT,
+	UNIONFS_DMUTEX_CHILD,
+	UNIONFS_DMUTEX_WHITEOUT,
+	UNIONFS_DMUTEX_REVAL_PARENT, /* for file/dentry revalidate */
+	UNIONFS_DMUTEX_REVAL_CHILD,   /* for file/dentry revalidate */
+};
+
+static inline void unionfs_lock_dentry(struct dentry *d,
+				       unsigned int subclass)
+{
+	BUG_ON(!d);
+	mutex_lock_nested(&UNIONFS_D(d)->lock, subclass);
+}
+
+static inline void unionfs_unlock_dentry(struct dentry *d)
+{
+	BUG_ON(!d);
+	mutex_unlock(&UNIONFS_D(d)->lock);
+}
+
+static inline struct dentry *unionfs_lock_parent(struct dentry *d,
+						 unsigned int subclass)
+{
+	struct dentry *p;
+
+	BUG_ON(!d);
+	p = dget_parent(d);
+	if (p != d)
+		mutex_lock_nested(&UNIONFS_D(p)->lock, subclass);
+	return p;
+}
+
+static inline void unionfs_unlock_parent(struct dentry *d, struct dentry *p)
+{
+	BUG_ON(!d);
+	BUG_ON(!p);
+	if (p != d) {
+		BUG_ON(!mutex_is_locked(&UNIONFS_D(p)->lock));
+		mutex_unlock(&UNIONFS_D(p)->lock);
+	}
+	dput(p);
+}
+
+static inline void verify_locked(struct dentry *d)
+{
+	BUG_ON(!d);
+	BUG_ON(!mutex_is_locked(&UNIONFS_D(d)->lock));
+}
+
+/* macros to put lower objects */
+
+/*
+ * iput lower inodes of an unionfs dentry, from bstart to bend.  If
+ * @free_lower is true, then also kfree the memory used to hold the lower
+ * object pointers.
+ */
+static inline void iput_lowers(struct inode *inode,
+			       int bstart, int bend, bool free_lower)
+{
+	struct inode *lower_inode;
+	int bindex;
+
+	BUG_ON(!inode);
+	BUG_ON(!UNIONFS_I(inode));
+	BUG_ON(bstart < 0);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (lower_inode) {
+			unionfs_set_lower_inode_idx(inode, bindex, NULL);
+			/* see Documentation/filesystems/unionfs/issues.txt */
+			lockdep_off();
+			iput(lower_inode);
+			lockdep_on();
+		}
+	}
+
+	if (free_lower) {
+		kfree(UNIONFS_I(inode)->lower_inodes);
+		UNIONFS_I(inode)->lower_inodes = NULL;
+	}
+}
+
+/* iput all lower inodes, and reset start/end branch indices to -1 */
+static inline void iput_lowers_all(struct inode *inode, bool free_lower)
+{
+	int bstart, bend;
+
+	BUG_ON(!inode);
+	BUG_ON(!UNIONFS_I(inode));
+	bstart = ibstart(inode);
+	bend = ibend(inode);
+	BUG_ON(bstart < 0);
+
+	iput_lowers(inode, bstart, bend, free_lower);
+	ibstart(inode) = ibend(inode) = -1;
+}
+
+/*
+ * dput/mntput all lower dentries and vfsmounts of an unionfs dentry, from
+ * bstart to bend.  If @free_lower is true, then also kfree the memory used
+ * to hold the lower object pointers.
+ *
+ * XXX: implement using path_put VFS macros
+ */
+static inline void path_put_lowers(struct dentry *dentry,
+				   int bstart, int bend, bool free_lower)
+{
+	struct dentry *lower_dentry;
+	struct vfsmount *lower_mnt;
+	int bindex;
+
+	BUG_ON(!dentry);
+	BUG_ON(!UNIONFS_D(dentry));
+	BUG_ON(bstart < 0);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (lower_dentry) {
+			unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+			dput(lower_dentry);
+		}
+		lower_mnt = unionfs_lower_mnt_idx(dentry, bindex);
+		if (lower_mnt) {
+			unionfs_set_lower_mnt_idx(dentry, bindex, NULL);
+			mntput(lower_mnt);
+		}
+	}
+
+	if (free_lower) {
+		kfree(UNIONFS_D(dentry)->lower_paths);
+		UNIONFS_D(dentry)->lower_paths = NULL;
+	}
+}
+
+/*
+ * dput/mntput all lower dentries and vfsmounts, and reset start/end branch
+ * indices to -1.
+ */
+static inline void path_put_lowers_all(struct dentry *dentry, bool free_lower)
+{
+	int bstart, bend;
+
+	BUG_ON(!dentry);
+	BUG_ON(!UNIONFS_D(dentry));
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+	BUG_ON(bstart < 0);
+
+	path_put_lowers(dentry, bstart, bend, free_lower);
+	dbstart(dentry) = dbend(dentry) = -1;
+}
+
+#endif	/* not _FANOUT_H */
diff --git a/fs/unionfs/file.c b/fs/unionfs/file.c
new file mode 100644
index 00000000..5141afdb
--- /dev/null
+++ b/fs/unionfs/file.c
@@ -0,0 +1,472 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+static ssize_t unionfs_read(struct file *file, char __user *buf,
+			    size_t count, loff_t *ppos)
+{
+	int err;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, false);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	err = vfs_read(lower_file, buf, count, ppos);
+	/* update our inode atime upon a successful lower read */
+	if (err >= 0) {
+		fsstack_copy_attr_atime(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		unionfs_check_file(file);
+	}
+
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static ssize_t unionfs_write(struct file *file, const char __user *buf,
+			     size_t count, loff_t *ppos)
+{
+	int err = 0;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	err = vfs_write(lower_file, buf, count, ppos);
+	/* update our inode times+sizes upon a successful lower write */
+	if (err >= 0) {
+		fsstack_copy_inode_size(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		fsstack_copy_attr_times(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		UNIONFS_F(file)->wrote_to_file = true; /* for delayed copyup */
+		unionfs_check_file(file);
+	}
+
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static ssize_t unionfs_aio_read(struct kiocb *iocb, const struct iovec
+				*iov, unsigned long nr_segs, loff_t pos)
+{
+	int err = -EINVAL;
+	struct file *file = iocb->ki_filp, *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	if (!lower_file->f_op->aio_read)
+		goto out;
+
+	get_file(lower_file);
+	iocb->ki_filp = lower_file;
+	err = lower_file->f_op->aio_read(iocb, iov, nr_segs, pos);
+	iocb->ki_filp = file;
+	fput(lower_file);
+
+	/* update our inode atime upon a successful lower read */
+	/* XXX: need to update upper inode atime when AIO completes */
+	if (err >= 0) {
+		fsstack_copy_attr_atime(dentry->d_inode,
+					file_inode(lower_file));
+		unionfs_check_file(file);
+	}
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static ssize_t unionfs_aio_write(struct kiocb *iocb, const struct iovec
+		*iov, unsigned long nr_segs, loff_t pos)
+{
+	int err = -EINVAL;
+	struct file *file = iocb->ki_filp, *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	if (!lower_file->f_op->aio_write)
+		goto out;
+
+	get_file(lower_file);
+	iocb->ki_filp = lower_file;
+	err = lower_file->f_op->aio_write(iocb, iov, nr_segs, pos);
+	iocb->ki_filp = file;
+	fput(lower_file);
+
+	/* update our inode times+sizes upon a successful lower write */
+	/* XXX: need to update upper inode times/sizes when AIO completes */
+	if (err >= 0) {
+		fsstack_copy_inode_size(dentry->d_inode,
+					file_inode(lower_file));
+		fsstack_copy_attr_times(dentry->d_inode,
+					file_inode(lower_file));
+		UNIONFS_F(file)->wrote_to_file = true; /* for delayed copyup */
+		unionfs_check_file(file);
+	}
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static int unionfs_file_readdir(struct file *file, void *dirent,
+				filldir_t filldir)
+{
+	return -ENOTDIR;
+}
+
+static int unionfs_mmap(struct file *file, struct vm_area_struct *vma)
+{
+	int err = 0;
+	bool willwrite;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	const struct vm_operations_struct *saved_vm_ops = NULL;
+
+	/*
+	 * Since mm/memory.c:might_fault() (under PROVE_LOCKING) was
+	 * modified in 2.6.29-rc1 to call might_lock_read on mmap_sem, this
+	 * has been causing false positives in file system stacking layers.
+	 * In particular, our ->mmap is called after sys_mmap2 already holds
+	 * mmap_sem, then we lock our own mutexes; but earlier, it's
+	 * possible for lockdep to have locked our mutexes first, and then
+	 * we call a lower ->readdir which could call might_fault.  The
+	 * different ordering of the locks is what lockdep complains about
+	 * -- unnecessarily.  Therefore, we have no choice but to tell
+	 * lockdep to temporarily turn off lockdep here.  Note: the comments
+	 * inside might_sleep also suggest that it would have been
+	 * nicer to only annotate paths that needs that might_lock_read.
+	 */
+	lockdep_off();
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	/* This might be deferred to mmap's writepage */
+	willwrite = ((vma->vm_flags | VM_SHARED | VM_WRITE) == vma->vm_flags);
+	err = unionfs_file_revalidate(file, parent, willwrite);
+	if (unlikely(err))
+		goto out;
+	unionfs_check_file(file);
+
+	/*
+	 * File systems which do not implement ->writepage may use
+	 * generic_file_readonly_mmap as their ->mmap op.  If you call
+	 * generic_file_readonly_mmap with VM_WRITE, you'd get an -EINVAL.
+	 * But we cannot call the lower ->mmap op, so we can't tell that
+	 * writeable mappings won't work.  Therefore, our only choice is to
+	 * check if the lower file system supports the ->writepage, and if
+	 * not, return EINVAL (the same error that
+	 * generic_file_readonly_mmap returns in that case).
+	 */
+	lower_file = unionfs_lower_file(file);
+	if (willwrite && !lower_file->f_mapping->a_ops->writepage) {
+		err = -EINVAL;
+		printk(KERN_ERR "unionfs: branch %d file system does not "
+		       "support writeable mmap\n", fbstart(file));
+		goto out;
+	}
+
+	/*
+	 * find and save lower vm_ops.
+	 *
+	 * XXX: the VFS should have a cleaner way of finding the lower vm_ops
+	 */
+	if (!UNIONFS_F(file)->lower_vm_ops) {
+		err = lower_file->f_op->mmap(lower_file, vma);
+		if (err) {
+			printk(KERN_ERR "unionfs: lower mmap failed %d\n", err);
+			goto out;
+		}
+		saved_vm_ops = vma->vm_ops;
+		up_write(&current->mm->mmap_sem); /* VFS already holds sema... */
+		err = vm_munmap(vma->vm_start, vma->vm_end - vma->vm_start);
+		down_write(&current->mm->mmap_sem);
+		if (err) {
+			printk(KERN_ERR "unionfs: do_munmap failed %d\n", err);
+			goto out;
+		}
+	}
+
+	file->f_mapping->a_ops = &unionfs_dummy_aops;
+	err = generic_file_mmap(file, vma);
+	file->f_mapping->a_ops = &unionfs_aops;
+	if (err) {
+		printk(KERN_ERR "unionfs: generic_file_mmap failed %d\n", err);
+		goto out;
+	}
+	vma->vm_ops = &unionfs_vm_ops;
+	if (!UNIONFS_F(file)->lower_vm_ops)
+		UNIONFS_F(file)->lower_vm_ops = saved_vm_ops;
+
+out:
+	if (!err) {
+		/* copyup could cause parent dir times to change */
+		unionfs_copy_attr_times(parent->d_inode);
+		unionfs_check_file(file);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	lockdep_on();
+	return err;
+}
+
+int unionfs_fsync(struct file *file, loff_t start, loff_t end, int datasync)
+{
+	int bindex, bstart, bend;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *lower_dentry;
+	struct dentry *parent;
+	struct inode *lower_inode, *inode;
+	int err = -EINVAL;
+
+	lockdep_off();
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+	unionfs_check_file(file);
+
+	err = generic_file_fsync(file, start, end, datasync);
+	if (err)
+		goto out;
+
+	bstart = fbstart(file);
+	bend = fbend(file);
+	if (bstart < 0 || bend < 0)
+		goto out;
+
+	inode = dentry->d_inode;
+	if (unlikely(!inode)) {
+		printk(KERN_ERR
+		       "unionfs: null lower inode in unionfs_fsync\n");
+		goto out;
+	}
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode || !lower_inode->i_fop->fsync)
+			continue;
+		lower_file = unionfs_lower_file_idx(file, bindex);
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		err = vfs_fsync_range(lower_file, start, end, datasync);
+		if (!err && bindex == bstart)
+			fsstack_copy_attr_times(inode, lower_inode);
+		if (err)
+			goto out;
+	}
+
+out:
+	if (!err)
+		unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	lockdep_on();
+	return err;
+}
+
+int unionfs_fasync(int fd, struct file *file, int flag)
+{
+	int bindex, bstart, bend;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+	struct inode *lower_inode, *inode;
+	int err = 0;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+	unionfs_check_file(file);
+
+	bstart = fbstart(file);
+	bend = fbend(file);
+	if (bstart < 0 || bend < 0)
+		goto out;
+
+	inode = dentry->d_inode;
+	if (unlikely(!inode)) {
+		printk(KERN_ERR
+		       "unionfs: null lower inode in unionfs_fasync\n");
+		goto out;
+	}
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode || !lower_inode->i_fop->fasync)
+			continue;
+		lower_file = unionfs_lower_file_idx(file, bindex);
+		mutex_lock(&lower_inode->i_mutex);
+		err = lower_inode->i_fop->fasync(fd, lower_file, flag);
+		if (!err && bindex == bstart)
+			fsstack_copy_attr_times(inode, lower_inode);
+		mutex_unlock(&lower_inode->i_mutex);
+		if (err)
+			goto out;
+	}
+
+out:
+	if (!err)
+		unionfs_check_file(file);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static ssize_t unionfs_splice_read(struct file *file, loff_t *ppos,
+				   struct pipe_inode_info *pipe, size_t len,
+				   unsigned int flags)
+{
+	ssize_t err;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, false);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	err = vfs_splice_to(lower_file, ppos, pipe, len, flags);
+	/* update our inode atime upon a successful lower splice-read */
+	if (err >= 0) {
+		fsstack_copy_attr_atime(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		unionfs_check_file(file);
+	}
+
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static ssize_t unionfs_splice_write(struct pipe_inode_info *pipe,
+				    struct file *file, loff_t *ppos,
+				    size_t len, unsigned int flags)
+{
+	ssize_t err = 0;
+	struct file *lower_file;
+	struct dentry *dentry = file->f_path.dentry;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_PARENT);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	err = unionfs_file_revalidate(file, parent, true);
+	if (unlikely(err))
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	err = vfs_splice_from(pipe, lower_file, ppos, len, flags);
+	/* update our inode times+sizes upon a successful lower write */
+	if (err >= 0) {
+		fsstack_copy_inode_size(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		fsstack_copy_attr_times(dentry->d_inode,
+					lower_file->f_path.dentry->d_inode);
+		unionfs_check_file(file);
+	}
+
+out:
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+struct file_operations unionfs_main_fops = {
+	.llseek		= generic_file_llseek,
+	.read		= unionfs_read,
+	.write		= unionfs_write,
+	.aio_read	= unionfs_aio_read,
+	.aio_write	= unionfs_aio_write,
+	.readdir	= unionfs_file_readdir,
+	.unlocked_ioctl	= unionfs_ioctl,
+#ifdef CONFIG_COMPAT
+	.compat_ioctl	= unionfs_ioctl,
+#endif
+	.mmap		= unionfs_mmap,
+	.open		= unionfs_open,
+	.flush		= unionfs_flush,
+	.release	= unionfs_file_release,
+	.fsync		= unionfs_fsync,
+	.fasync		= unionfs_fasync,
+	.splice_read	= unionfs_splice_read,
+	.splice_write	= unionfs_splice_write,
+};
diff --git a/fs/unionfs/inode.c b/fs/unionfs/inode.c
new file mode 100644
index 00000000..61c5d02
--- /dev/null
+++ b/fs/unionfs/inode.c
@@ -0,0 +1,1071 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * Find a writeable branch to create new object in.  Checks all writeble
+ * branches of the parent inode, from istart to iend order; if none are
+ * suitable, also tries branch 0 (which may require a copyup).
+ *
+ * Return a lower_dentry we can use to create object in, or ERR_PTR.
+ */
+static struct dentry *find_writeable_branch(struct inode *parent,
+					    struct dentry *dentry)
+{
+	int err = -EINVAL;
+	int bindex, istart, iend;
+	struct dentry *lower_dentry = NULL;
+
+	istart = ibstart(parent);
+	iend = ibend(parent);
+	if (istart < 0)
+		goto out;
+
+begin:
+	for (bindex = istart; bindex <= iend; bindex++) {
+		/* skip non-writeable branches */
+		err = is_robranch_super(dentry->d_sb, bindex);
+		if (err) {
+			err = -EROFS;
+			continue;
+		}
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+		/*
+		 * check for whiteouts in writeable branch, and remove them
+		 * if necessary.
+		 */
+		err = check_unlink_whiteout(dentry, lower_dentry, bindex);
+		if (err > 0)	/* ignore if whiteout found and removed */
+			err = 0;
+		if (err)
+			continue;
+		/* if get here, we can write to the branch */
+		break;
+	}
+	/*
+	 * If istart wasn't already branch 0, and we got any error, then try
+	 * branch 0 (which may require copyup)
+	 */
+	if (err && istart > 0) {
+		istart = iend = 0;
+		goto begin;
+	}
+
+	/*
+	 * If we tried even branch 0, and still got an error, abort.  But if
+	 * the error was an EROFS, then we should try to copyup.
+	 */
+	if (err && err != -EROFS)
+		goto out;
+
+	/*
+	 * If we get here, then check if copyup needed.  If lower_dentry is
+	 * NULL, create the entire dentry directory structure in branch 0.
+	 */
+	if (!lower_dentry) {
+		bindex = 0;
+		lower_dentry = create_parents(parent, dentry,
+					      dentry->d_name.name, bindex);
+		if (IS_ERR(lower_dentry)) {
+			err = PTR_ERR(lower_dentry);
+			goto out;
+		}
+	}
+	err = 0;		/* all's well */
+out:
+	if (err)
+		return ERR_PTR(err);
+	return lower_dentry;
+}
+
+static int unionfs_create(struct inode *dir, struct dentry *dentry,
+			  umode_t mode, bool want_excl)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct dentry *lower_parent_dentry = NULL;
+	struct dentry *parent;
+	int valid = 0;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;	/* same as what real_lookup does */
+		goto out;
+	}
+
+	lower_dentry = find_writeable_branch(dir, dentry);
+	if (IS_ERR(lower_dentry)) {
+		err = PTR_ERR(lower_dentry);
+		goto out;
+	}
+
+	lower_parent_dentry = lock_parent(lower_dentry);
+	if (IS_ERR(lower_parent_dentry)) {
+		err = PTR_ERR(lower_parent_dentry);
+		goto out_unlock;
+	}
+
+	err = vfs_create(lower_parent_dentry->d_inode, lower_dentry, mode,
+			 want_excl);
+	if (!err) {
+		err = PTR_ERR(unionfs_interpose(dentry, dir->i_sb, 0));
+		if (!err) {
+			unionfs_copy_attr_times(dir);
+			fsstack_copy_inode_size(dir,
+						lower_parent_dentry->d_inode);
+			/* update no. of links on parent directory */
+			set_nlink(dir, unionfs_get_nlinks(dir));
+		}
+	}
+
+out_unlock:
+	unlock_dir(lower_parent_dentry);
+out:
+	if (!err) {
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_check_inode(dir);
+		unionfs_check_dentry(dentry);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * unionfs_lookup is the only special function which takes a dentry, yet we
+ * do NOT want to call __unionfs_d_revalidate_chain because by definition,
+ * we don't have a valid dentry here yet.
+ */
+static struct dentry *unionfs_lookup(struct inode *dir,
+				     struct dentry *dentry,
+				     /* XXX: pass flags to lower? */
+				     unsigned int flags_unused)
+{
+	struct dentry *ret, *parent;
+	int err = 0;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+
+	/*
+	 * As long as we lock/dget the parent, then can skip validating the
+	 * parent now; we may have to rebuild this dentry on the next
+	 * ->d_revalidate, however.
+	 */
+
+	/* allocate dentry private data.  We free it in ->d_release */
+	err = new_dentry_private_data(dentry, UNIONFS_DMUTEX_CHILD);
+	if (unlikely(err)) {
+		ret = ERR_PTR(err);
+		goto out;
+	}
+
+	ret = unionfs_lookup_full(dentry, parent, INTERPOSE_LOOKUP);
+
+	if (!IS_ERR(ret)) {
+		if (ret)
+			dentry = ret;
+		/* lookup_full can return multiple positive dentries */
+		if (dentry->d_inode && !S_ISDIR(dentry->d_inode->i_mode)) {
+			BUG_ON(dbstart(dentry) < 0);
+			unionfs_postcopyup_release(dentry);
+		}
+		unionfs_copy_attr_times(dentry->d_inode);
+	}
+
+	unionfs_check_inode(dir);
+	if (!IS_ERR(ret))
+		unionfs_check_dentry(dentry);
+	unionfs_check_dentry(parent);
+	unionfs_unlock_dentry(dentry); /* locked in new_dentry_private data */
+
+out:
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+
+	return ret;
+}
+
+static int unionfs_link(struct dentry *old_dentry, struct inode *dir,
+			struct dentry *new_dentry)
+{
+	int err = 0;
+	struct dentry *lower_old_dentry = NULL;
+	struct dentry *lower_new_dentry = NULL;
+	struct dentry *lower_dir_dentry = NULL;
+	struct dentry *old_parent, *new_parent;
+	char *name = NULL;
+	bool valid;
+
+	unionfs_read_lock(old_dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	old_parent = dget_parent(old_dentry);
+	new_parent = dget_parent(new_dentry);
+	unionfs_double_lock_parents(old_parent, new_parent);
+	unionfs_double_lock_dentry(old_dentry, new_dentry);
+
+	valid = __unionfs_d_revalidate(old_dentry, old_parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+	if (new_dentry->d_inode) {
+		valid = __unionfs_d_revalidate(new_dentry, new_parent, false, 0);
+		if (unlikely(!valid)) {
+			err = -ESTALE;
+			goto out;
+		}
+	}
+
+	lower_new_dentry = unionfs_lower_dentry(new_dentry);
+
+	/* check for a whiteout in new dentry branch, and delete it */
+	err = check_unlink_whiteout(new_dentry, lower_new_dentry,
+				    dbstart(new_dentry));
+	if (err > 0) {	       /* whiteout found and removed successfully */
+		lower_dir_dentry = dget_parent(lower_new_dentry);
+		fsstack_copy_attr_times(dir, lower_dir_dentry->d_inode);
+		dput(lower_dir_dentry);
+		set_nlink(dir, unionfs_get_nlinks(dir));
+		err = 0;
+	}
+	if (err)
+		goto out;
+
+	/* check if parent hierachy is needed, then link in same branch */
+	if (dbstart(old_dentry) != dbstart(new_dentry)) {
+		lower_new_dentry = create_parents(dir, new_dentry,
+						  new_dentry->d_name.name,
+						  dbstart(old_dentry));
+		err = PTR_ERR(lower_new_dentry);
+		if (IS_COPYUP_ERR(err))
+			goto docopyup;
+		if (!lower_new_dentry || IS_ERR(lower_new_dentry))
+			goto out;
+	}
+	lower_new_dentry = unionfs_lower_dentry(new_dentry);
+	lower_old_dentry = unionfs_lower_dentry(old_dentry);
+
+	BUG_ON(dbstart(old_dentry) != dbstart(new_dentry));
+	lower_dir_dentry = lock_parent(lower_new_dentry);
+	err = is_robranch(old_dentry);
+	if (!err) {
+		/* see Documentation/filesystems/unionfs/issues.txt */
+		lockdep_off();
+		err = vfs_link(lower_old_dentry, lower_dir_dentry->d_inode,
+			       lower_new_dentry);
+		lockdep_on();
+	}
+	unlock_dir(lower_dir_dentry);
+
+docopyup:
+	if (IS_COPYUP_ERR(err)) {
+		int old_bstart = dbstart(old_dentry);
+		int bindex;
+
+		for (bindex = old_bstart - 1; bindex >= 0; bindex--) {
+			err = copyup_dentry(old_parent->d_inode,
+					    old_dentry, old_bstart,
+					    bindex, old_dentry->d_name.name,
+					    old_dentry->d_name.len, NULL,
+					    i_size_read(old_dentry->d_inode));
+			if (err)
+				continue;
+			lower_new_dentry =
+				create_parents(dir, new_dentry,
+					       new_dentry->d_name.name,
+					       bindex);
+			lower_old_dentry = unionfs_lower_dentry(old_dentry);
+			lower_dir_dentry = lock_parent(lower_new_dentry);
+			/* see Documentation/filesystems/unionfs/issues.txt */
+			lockdep_off();
+			/* do vfs_link */
+			err = vfs_link(lower_old_dentry,
+				       lower_dir_dentry->d_inode,
+				       lower_new_dentry);
+			lockdep_on();
+			unlock_dir(lower_dir_dentry);
+			goto check_link;
+		}
+		goto out;
+	}
+
+check_link:
+	if (err || !lower_new_dentry->d_inode)
+		goto out;
+
+	/* Its a hard link, so use the same inode */
+	new_dentry->d_inode = igrab(old_dentry->d_inode);
+	d_add(new_dentry, new_dentry->d_inode);
+	unionfs_copy_attr_all(dir, lower_new_dentry->d_parent->d_inode);
+	fsstack_copy_inode_size(dir, lower_new_dentry->d_parent->d_inode);
+
+	/* propagate number of hard-links */
+	set_nlink(old_dentry->d_inode,
+		  unionfs_get_nlinks(old_dentry->d_inode));
+	/* new dentry's ctime may have changed due to hard-link counts */
+	unionfs_copy_attr_times(new_dentry->d_inode);
+
+out:
+	if (!new_dentry->d_inode)
+		d_drop(new_dentry);
+
+	kfree(name);
+	if (!err)
+		unionfs_postcopyup_setmnt(new_dentry);
+
+	unionfs_check_inode(dir);
+	unionfs_check_dentry(new_dentry);
+	unionfs_check_dentry(old_dentry);
+
+	unionfs_double_unlock_dentry(old_dentry, new_dentry);
+	unionfs_double_unlock_parents(old_parent, new_parent);
+	dput(new_parent);
+	dput(old_parent);
+	unionfs_read_unlock(old_dentry->d_sb);
+
+	return err;
+}
+
+static int unionfs_symlink(struct inode *dir, struct dentry *dentry,
+			   const char *symname)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct dentry *wh_dentry = NULL;
+	struct dentry *lower_parent_dentry = NULL;
+	struct dentry *parent;
+	char *name = NULL;
+	int valid = 0;
+	umode_t mode;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	/*
+	 * It's only a bug if this dentry was not negative and couldn't be
+	 * revalidated (shouldn't happen).
+	 */
+	BUG_ON(!valid && dentry->d_inode);
+
+	lower_dentry = find_writeable_branch(dir, dentry);
+	if (IS_ERR(lower_dentry)) {
+		err = PTR_ERR(lower_dentry);
+		goto out;
+	}
+
+	lower_parent_dentry = lock_parent(lower_dentry);
+	if (IS_ERR(lower_parent_dentry)) {
+		err = PTR_ERR(lower_parent_dentry);
+		goto out_unlock;
+	}
+
+	mode = S_IALLUGO;
+	err = vfs_symlink(lower_parent_dentry->d_inode, lower_dentry, symname);
+	if (!err) {
+		err = PTR_ERR(unionfs_interpose(dentry, dir->i_sb, 0));
+		if (!err) {
+			unionfs_copy_attr_times(dir);
+			fsstack_copy_inode_size(dir,
+						lower_parent_dentry->d_inode);
+			/* update no. of links on parent directory */
+			set_nlink(dir, unionfs_get_nlinks(dir));
+		}
+	}
+
+out_unlock:
+	unlock_dir(lower_parent_dentry);
+out:
+	dput(wh_dentry);
+	kfree(name);
+
+	if (!err) {
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_check_inode(dir);
+		unionfs_check_dentry(dentry);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static int unionfs_mkdir(struct inode *dir, struct dentry *dentry, umode_t mode)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct dentry *lower_parent_dentry = NULL;
+	struct dentry *parent;
+	int bindex = 0, bstart;
+	char *name = NULL;
+	int valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;	/* same as what real_lookup does */
+		goto out;
+	}
+
+	bstart = dbstart(dentry);
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	/* check for a whiteout in new dentry branch, and delete it */
+	err = check_unlink_whiteout(dentry, lower_dentry, bstart);
+	if (err > 0)	       /* whiteout found and removed successfully */
+		err = 0;
+	if (err) {
+		/* exit if the error returned was NOT -EROFS */
+		if (!IS_COPYUP_ERR(err))
+			goto out;
+		bstart--;
+	}
+
+	/* check if copyup's needed, and mkdir */
+	for (bindex = bstart; bindex >= 0; bindex--) {
+		int i;
+		int bend = dbend(dentry);
+
+		if (is_robranch_super(dentry->d_sb, bindex))
+			continue;
+
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry) {
+			lower_dentry = create_parents(dir, dentry,
+						      dentry->d_name.name,
+						      bindex);
+			if (!lower_dentry || IS_ERR(lower_dentry)) {
+				printk(KERN_ERR "unionfs: lower dentry "
+				       " NULL for bindex = %d\n", bindex);
+				continue;
+			}
+		}
+
+		lower_parent_dentry = lock_parent(lower_dentry);
+
+		if (IS_ERR(lower_parent_dentry)) {
+			err = PTR_ERR(lower_parent_dentry);
+			goto out;
+		}
+
+		err = vfs_mkdir(lower_parent_dentry->d_inode, lower_dentry,
+				mode);
+
+		unlock_dir(lower_parent_dentry);
+
+		/* did the mkdir succeed? */
+		if (err)
+			break;
+
+		for (i = bindex + 1; i <= bend; i++) {
+			/* XXX: use path_put_lowers? */
+			if (unionfs_lower_dentry_idx(dentry, i)) {
+				dput(unionfs_lower_dentry_idx(dentry, i));
+				unionfs_set_lower_dentry_idx(dentry, i, NULL);
+			}
+		}
+		dbend(dentry) = bindex;
+
+		/*
+		 * Only INTERPOSE_LOOKUP can return a value other than 0 on
+		 * err.
+		 */
+		err = PTR_ERR(unionfs_interpose(dentry, dir->i_sb, 0));
+		if (!err) {
+			unionfs_copy_attr_times(dir);
+			fsstack_copy_inode_size(dir,
+						lower_parent_dentry->d_inode);
+
+			/* update number of links on parent directory */
+			set_nlink(dir, unionfs_get_nlinks(dir));
+		}
+
+		err = make_dir_opaque(dentry, dbstart(dentry));
+		if (err) {
+			printk(KERN_ERR "unionfs: mkdir: error creating "
+			       ".wh.__dir_opaque: %d\n", err);
+			goto out;
+		}
+
+		/* we are done! */
+		break;
+	}
+
+out:
+	if (!dentry->d_inode)
+		d_drop(dentry);
+
+	kfree(name);
+
+	if (!err) {
+		unionfs_copy_attr_times(dentry->d_inode);
+		unionfs_postcopyup_setmnt(dentry);
+	}
+	unionfs_check_inode(dir);
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+
+	return err;
+}
+
+static int unionfs_mknod(struct inode *dir, struct dentry *dentry, umode_t mode,
+			 dev_t dev)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct dentry *wh_dentry = NULL;
+	struct dentry *lower_parent_dentry = NULL;
+	struct dentry *parent;
+	char *name = NULL;
+	int valid = 0;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	/*
+	 * It's only a bug if this dentry was not negative and couldn't be
+	 * revalidated (shouldn't happen).
+	 */
+	BUG_ON(!valid && dentry->d_inode);
+
+	lower_dentry = find_writeable_branch(dir, dentry);
+	if (IS_ERR(lower_dentry)) {
+		err = PTR_ERR(lower_dentry);
+		goto out;
+	}
+
+	lower_parent_dentry = lock_parent(lower_dentry);
+	if (IS_ERR(lower_parent_dentry)) {
+		err = PTR_ERR(lower_parent_dentry);
+		goto out_unlock;
+	}
+
+	err = vfs_mknod(lower_parent_dentry->d_inode, lower_dentry, mode, dev);
+	if (!err) {
+		err = PTR_ERR(unionfs_interpose(dentry, dir->i_sb, 0));
+		if (!err) {
+			unionfs_copy_attr_times(dir);
+			fsstack_copy_inode_size(dir,
+						lower_parent_dentry->d_inode);
+			/* update no. of links on parent directory */
+			set_nlink(dir, unionfs_get_nlinks(dir));
+		}
+	}
+
+out_unlock:
+	unlock_dir(lower_parent_dentry);
+out:
+	dput(wh_dentry);
+	kfree(name);
+
+	if (!err) {
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_check_inode(dir);
+		unionfs_check_dentry(dentry);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/* requires sb, dentry, and parent to already be locked */
+static int __unionfs_readlink(struct dentry *dentry, char __user *buf,
+			      int bufsiz)
+{
+	int err;
+	struct dentry *lower_dentry;
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	if (!lower_dentry->d_inode->i_op ||
+	    !lower_dentry->d_inode->i_op->readlink) {
+		err = -EINVAL;
+		goto out;
+	}
+
+	err = lower_dentry->d_inode->i_op->readlink(lower_dentry,
+						    buf, bufsiz);
+	if (err >= 0)
+		fsstack_copy_attr_atime(dentry->d_inode,
+					lower_dentry->d_inode);
+
+out:
+	return err;
+}
+
+static int unionfs_readlink(struct dentry *dentry, char __user *buf,
+			    int bufsiz)
+{
+	int err;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	if (unlikely(!__unionfs_d_revalidate(dentry, parent, false, 0))) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	err = __unionfs_readlink(dentry, buf, bufsiz);
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+
+	return err;
+}
+
+static void *unionfs_follow_link(struct dentry *dentry, struct nameidata *nd)
+{
+	char *buf;
+	int len = PAGE_SIZE, err;
+	mm_segment_t old_fs;
+	struct dentry *parent;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	/* This is freed by the put_link method assuming a successful call. */
+	buf = kmalloc(len, GFP_KERNEL);
+	if (unlikely(!buf)) {
+		err = -ENOMEM;
+		goto out;
+	}
+
+	/* read the symlink, and then we will follow it */
+	old_fs = get_fs();
+	set_fs(KERNEL_DS);
+	err = __unionfs_readlink(dentry, buf, len);
+	set_fs(old_fs);
+	if (err < 0) {
+		kfree(buf);
+		buf = NULL;
+		goto out;
+	}
+	buf[err] = 0;
+	nd_set_link(nd, buf);
+	err = 0;
+
+out:
+	if (err >= 0)
+		unionfs_check_dentry(dentry);
+
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+
+	return ERR_PTR(err);
+}
+
+/* this @nd *IS* still used */
+static void unionfs_put_link(struct dentry *dentry, struct nameidata *nd,
+			     void *cookie)
+{
+	struct dentry *parent;
+	char *buf;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	if (unlikely(!__unionfs_d_revalidate(dentry, parent, false, 0)))
+		printk(KERN_ERR
+		       "unionfs: put_link failed to revalidate dentry\n");
+
+	unionfs_check_dentry(dentry);
+	buf = nd_get_link(nd);
+	if (!IS_ERR(buf))
+		kfree(buf);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+}
+
+/*
+ * This is a variant of fs/namei.c:permission() or inode_permission() which
+ * skips over EROFS tests (because we perform copyup on EROFS).
+ */
+static int __inode_permission(struct inode *inode, int mask)
+{
+	int retval;
+
+	/* nobody gets write access to an immutable file */
+	if ((mask & MAY_WRITE) && IS_IMMUTABLE(inode))
+		return -EACCES;
+
+	/* Ordinary permission routines do not understand MAY_APPEND. */
+	if (inode->i_op && inode->i_op->permission) {
+		retval = inode->i_op->permission(inode, mask);
+		if (!retval) {
+			/*
+			 * Exec permission on a regular file is denied if none
+			 * of the execute bits are set.
+			 *
+			 * This check should be done by the ->permission()
+			 * method.
+			 */
+			if ((mask & MAY_EXEC) && S_ISREG(inode->i_mode) &&
+			    !(inode->i_mode & S_IXUGO))
+				return -EACCES;
+		}
+	} else {
+		retval = generic_permission(inode, mask);
+	}
+	if (retval)
+		return retval;
+
+	return security_inode_permission(inode,
+			mask & (MAY_READ|MAY_WRITE|MAY_EXEC|MAY_APPEND));
+}
+
+/*
+ * Don't grab the superblock read-lock in unionfs_permission, which prevents
+ * a deadlock with the branch-management "add branch" code (which grabbed
+ * the write lock).  It is safe to not grab the read lock here, because even
+ * with branch management taking place, there is no chance that
+ * unionfs_permission, or anything it calls, will use stale branch
+ * information.
+ */
+static int unionfs_permission(struct inode *inode, int mask)
+{
+	struct inode *lower_inode = NULL;
+	int err = 0;
+	int bindex, bstart, bend;
+	int is_file;
+	const int write_mask = (mask & MAY_WRITE) && !(mask & MAY_READ);
+	struct inode *inode_grabbed;
+
+	inode_grabbed = igrab(inode);
+	is_file = !S_ISDIR(inode->i_mode);
+
+	if (!UNIONFS_I(inode)->lower_inodes) {
+		if (is_file)	/* dirs can be unlinked but chdir'ed to */
+			err = -ESTALE;	/* force revalidate */
+		goto out;
+	}
+	bstart = ibstart(inode);
+	bend = ibend(inode);
+	if (unlikely(bstart < 0 || bend < 0)) {
+		/*
+		 * With branch-management, we can get a stale inode here.
+		 * If so, we return ESTALE back to link_path_walk, which
+		 * would discard the dcache entry and re-lookup the
+		 * dentry+inode.  This should be equivalent to issuing
+		 * __unionfs_d_revalidate_chain on nd.dentry here.
+		 */
+		if (is_file)	/* dirs can be unlinked but chdir'ed to */
+			err = -ESTALE;	/* force revalidate */
+		goto out;
+	}
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode)
+			continue;
+
+		/*
+		 * check the condition for D-F-D underlying files/directories,
+		 * we don't have to check for files, if we are checking for
+		 * directories.
+		 */
+		if (!is_file && !S_ISDIR(lower_inode->i_mode))
+			continue;
+
+		/*
+		 * We check basic permissions, but we ignore any conditions
+		 * such as readonly file systems or branches marked as
+		 * readonly, because those conditions should lead to a
+		 * copyup taking place later on.  However, if user never had
+		 * access to the file, then no copyup could ever take place.
+		 */
+		err = __inode_permission(lower_inode, mask);
+		if (err && err != -EACCES && err != EPERM && bindex > 0) {
+			umode_t mode = lower_inode->i_mode;
+			if ((is_robranch_super(inode->i_sb, bindex) ||
+			     __is_rdonly(lower_inode)) &&
+			    (S_ISREG(mode) || S_ISDIR(mode) || S_ISLNK(mode)))
+				err = 0;
+			if (IS_COPYUP_ERR(err))
+				err = 0;
+		}
+
+		/*
+		 * NFS HACK: NFSv2/3 return EACCES on readonly-exported,
+		 * locally readonly-mounted file systems, instead of EROFS
+		 * like other file systems do.  So we have no choice here
+		 * but to intercept this and ignore it for NFS branches
+		 * marked readonly.  Specifically, we avoid using NFS's own
+		 * "broken" ->permission method, and rely on
+		 * generic_permission() to do basic checking for us.
+		 */
+		if (err && err == -EACCES &&
+		    is_robranch_super(inode->i_sb, bindex) &&
+		    lower_inode->i_sb->s_magic == NFS_SUPER_MAGIC)
+			err = generic_permission(lower_inode, mask);
+
+		/*
+		 * The permissions are an intersection of the overall directory
+		 * permissions, so we fail if one fails.
+		 */
+		if (err)
+			goto out;
+
+		/* only the leftmost file matters. */
+		if (is_file || write_mask) {
+			if (is_file && write_mask) {
+				err = get_write_access(lower_inode);
+				if (!err)
+					put_write_access(lower_inode);
+			}
+			break;
+		}
+	}
+	/* sync times which may have changed (asynchronously) below */
+	unionfs_copy_attr_times(inode);
+
+out:
+	unionfs_check_inode(inode);
+	iput(inode_grabbed);
+	return err;
+}
+
+static int unionfs_setattr(struct dentry *dentry, struct iattr *ia)
+{
+	int err = 0;
+	struct dentry *lower_dentry;
+	struct dentry *parent;
+	struct inode *inode;
+	struct inode *lower_inode;
+	int bstart, bend, bindex;
+	loff_t size;
+	struct iattr lower_ia;
+
+	/* check if user has permission to change inode */
+	err = inode_change_ok(dentry->d_inode, ia);
+	if (err)
+		goto out_err;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	if (unlikely(!__unionfs_d_revalidate(dentry, parent, false, 0))) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+	inode = dentry->d_inode;
+
+	/*
+	 * mode change is for clearing setuid/setgid. Allow lower filesystem
+	 * to reinterpret it in its own way.
+	 */
+	if (ia->ia_valid & (ATTR_KILL_SUID | ATTR_KILL_SGID))
+		ia->ia_valid &= ~ATTR_MODE;
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+	if (!lower_dentry) { /* should never happen after above revalidate */
+		err = -EINVAL;
+		goto out;
+	}
+
+	/*
+	 * Get the lower inode directly from lower dentry, in case ibstart
+	 * is -1 (which happens when the file is open but unlinked.
+	 */
+	lower_inode = lower_dentry->d_inode;
+
+	/* check if user has permission to change lower inode */
+	err = inode_change_ok(lower_inode, ia);
+	if (err)
+		goto out;
+
+	/* copyup if the file is on a read only branch */
+	if (is_robranch_super(dentry->d_sb, bstart)
+	    || __is_rdonly(lower_inode)) {
+		/* check if we have a branch to copy up to */
+		if (bstart <= 0) {
+			err = -EACCES;
+			goto out;
+		}
+
+		if (ia->ia_valid & ATTR_SIZE)
+			size = ia->ia_size;
+		else
+			size = i_size_read(inode);
+		/* copyup to next available branch */
+		for (bindex = bstart - 1; bindex >= 0; bindex--) {
+			err = copyup_dentry(parent->d_inode,
+					    dentry, bstart, bindex,
+					    dentry->d_name.name,
+					    dentry->d_name.len,
+					    NULL, size);
+			if (!err)
+				break;
+		}
+		if (err)
+			goto out;
+		/* get updated lower_dentry/inode after copyup */
+		lower_dentry = unionfs_lower_dentry(dentry);
+		lower_inode = unionfs_lower_inode(inode);
+		/*
+		 * check for whiteouts in writeable branch, and remove them
+		 * if necessary.
+		 */
+		if (lower_dentry) {
+			err = check_unlink_whiteout(dentry, lower_dentry,
+						    bindex);
+			if (err > 0) /* ignore if whiteout found and removed */
+				err = 0;
+		}
+	}
+
+	/*
+	 * If shrinking, first truncate upper level to cancel writing dirty
+	 * pages beyond the new eof; and also if its' maxbytes is more
+	 * limiting (fail with -EFBIG before making any change to the lower
+	 * level).  There is no need to vmtruncate the upper level
+	 * afterwards in the other cases: we fsstack_copy_inode_size from
+	 * the lower level.
+	 */
+	if (ia->ia_valid & ATTR_SIZE) {
+		err = inode_newsize_ok(inode, ia->ia_size);
+		if (err)
+			goto out;
+		truncate_setsize(inode, ia->ia_size);
+	}
+
+	/* notify the (possibly copied-up) lower inode */
+	/*
+	 * Note: we use lower_dentry->d_inode, because lower_inode may be
+	 * unlinked (no inode->i_sb and i_ino==0.  This happens if someone
+	 * tries to open(), unlink(), then ftruncate() a file.
+	 */
+	/* prepare our own lower struct iattr (with our own lower file) */
+	memcpy(&lower_ia, ia, sizeof(lower_ia));
+	if (ia->ia_valid & ATTR_FILE) {
+		lower_ia.ia_file = unionfs_lower_file(ia->ia_file);
+		BUG_ON(!lower_ia.ia_file); // XXX?
+	}
+
+	mutex_lock(&lower_dentry->d_inode->i_mutex);
+	err = notify_change(lower_dentry, &lower_ia);
+	mutex_unlock(&lower_dentry->d_inode->i_mutex);
+	if (err)
+		goto out;
+
+	/* get attributes from the first lower inode */
+	if (ibstart(inode) >= 0)
+		unionfs_copy_attr_all(inode, lower_inode);
+	/*
+	 * unionfs_copy_attr_all will copy the lower times to our inode if
+	 * the lower ones are newer (useful for cache coherency).  However,
+	 * ->setattr is the only place in which we may have to copy the
+	 * lower inode times absolutely, to support utimes(2).
+	 */
+	if (ia->ia_valid & ATTR_MTIME_SET)
+		inode->i_mtime = lower_inode->i_mtime;
+	if (ia->ia_valid & ATTR_CTIME)
+		inode->i_ctime = lower_inode->i_ctime;
+	if (ia->ia_valid & ATTR_ATIME_SET)
+		inode->i_atime = lower_inode->i_atime;
+	fsstack_copy_inode_size(inode, lower_inode);
+
+out:
+	if (!err)
+		unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+out_err:
+	return err;
+}
+
+struct inode_operations unionfs_symlink_iops = {
+	.readlink	= unionfs_readlink,
+	.permission	= unionfs_permission,
+	.follow_link	= unionfs_follow_link,
+	.setattr	= unionfs_setattr,
+	.put_link	= unionfs_put_link,
+};
+
+struct inode_operations unionfs_dir_iops = {
+	.create		= unionfs_create,
+	.lookup		= unionfs_lookup,
+	.link		= unionfs_link,
+	.unlink		= unionfs_unlink,
+	.symlink	= unionfs_symlink,
+	.mkdir		= unionfs_mkdir,
+	.rmdir		= unionfs_rmdir,
+	.mknod		= unionfs_mknod,
+	.rename		= unionfs_rename,
+	.permission	= unionfs_permission,
+	.setattr	= unionfs_setattr,
+#ifdef CONFIG_UNION_FS_XATTR
+	.setxattr	= unionfs_setxattr,
+	.getxattr	= unionfs_getxattr,
+	.removexattr	= unionfs_removexattr,
+	.listxattr	= unionfs_listxattr,
+#endif /* CONFIG_UNION_FS_XATTR */
+};
+
+struct inode_operations unionfs_main_iops = {
+	.permission	= unionfs_permission,
+	.setattr	= unionfs_setattr,
+#ifdef CONFIG_UNION_FS_XATTR
+	.setxattr	= unionfs_setxattr,
+	.getxattr	= unionfs_getxattr,
+	.removexattr	= unionfs_removexattr,
+	.listxattr	= unionfs_listxattr,
+#endif /* CONFIG_UNION_FS_XATTR */
+};
diff --git a/fs/unionfs/lookup.c b/fs/unionfs/lookup.c
new file mode 100644
index 00000000..5a0fe8a7
--- /dev/null
+++ b/fs/unionfs/lookup.c
@@ -0,0 +1,501 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * Lookup one path component @name relative to a <base,mnt> path pair.
+ * Behaves nearly the same as lookup_one_len (i.e., return negative dentry
+ * on ENOENT), but uses the @mnt passed, so it can cross bind mounts and
+ * other lower mounts properly.  If @new_mnt is non-null, will fill in the
+ * new mnt there.  Caller is responsible to dput/mntput/path_put returned
+ * @dentry and @new_mnt.
+ */
+struct dentry *__lookup_one(struct dentry *base, struct vfsmount *mnt,
+			    const char *name, struct vfsmount **new_mnt)
+{
+	struct dentry *dentry = NULL;
+	struct path lower_path = {NULL, NULL};
+	int err;
+
+	/* we use flags=0 to get basic lookup */
+	err = vfs_path_lookup(base, mnt, name, 0, &lower_path);
+
+	switch (err) {
+	case 0: /* no error */
+		dentry = lower_path.dentry;
+		if (new_mnt)
+			*new_mnt = lower_path.mnt; /* rc already inc'ed */
+		break;
+	case -ENOENT:
+		 /*
+		  * We don't consider ENOENT an error, and we want to return
+		  * a negative dentry (ala lookup_one_len).  As we know
+		  * there was no inode for this name before (-ENOENT), then
+		  * it's safe to call lookup_one_len (which doesn't take a
+		  * vfsmount).
+		  */
+		dentry = lookup_lck_len(name, base, strlen(name));
+		if (new_mnt)
+			*new_mnt = mntget(lower_path.mnt);
+		break;
+	default: /* all other real errors */
+		dentry = ERR_PTR(err);
+		break;
+	}
+
+	return dentry;
+}
+
+/*
+ * This is a utility function that fills in a unionfs dentry.
+ * Caller must lock this dentry with unionfs_lock_dentry.
+ *
+ * Returns: 0 (ok), or -ERRNO if an error occurred.
+ * XXX: get rid of _partial_lookup and make callers call _lookup_full directly
+ */
+int unionfs_partial_lookup(struct dentry *dentry, struct dentry *parent)
+{
+	struct dentry *tmp;
+	int err = -ENOSYS;
+
+	tmp = unionfs_lookup_full(dentry, parent, INTERPOSE_PARTIAL);
+
+	if (!tmp) {
+		err = 0;
+		goto out;
+	}
+	if (IS_ERR(tmp)) {
+		err = PTR_ERR(tmp);
+		goto out;
+	}
+	/* XXX: need to change the interface */
+	BUG_ON(tmp != dentry);
+out:
+	return err;
+}
+
+/* The dentry cache is just so we have properly sized dentries. */
+static struct kmem_cache *unionfs_dentry_cachep;
+int unionfs_init_dentry_cache(void)
+{
+	unionfs_dentry_cachep =
+		kmem_cache_create("unionfs_dentry",
+				  sizeof(struct unionfs_dentry_info),
+				  0, SLAB_RECLAIM_ACCOUNT, NULL);
+
+	return (unionfs_dentry_cachep ? 0 : -ENOMEM);
+}
+
+void unionfs_destroy_dentry_cache(void)
+{
+	if (unionfs_dentry_cachep)
+		kmem_cache_destroy(unionfs_dentry_cachep);
+}
+
+void free_dentry_private_data(struct dentry *dentry)
+{
+	if (!dentry || !dentry->d_fsdata)
+		return;
+	kfree(UNIONFS_D(dentry)->lower_paths);
+	UNIONFS_D(dentry)->lower_paths = NULL;
+	kmem_cache_free(unionfs_dentry_cachep, dentry->d_fsdata);
+	dentry->d_fsdata = NULL;
+}
+
+static inline int __realloc_dentry_private_data(struct dentry *dentry)
+{
+	struct unionfs_dentry_info *info = UNIONFS_D(dentry);
+	void *p;
+	int size;
+
+	BUG_ON(!info);
+
+	size = sizeof(struct path) * sbmax(dentry->d_sb);
+	p = krealloc(info->lower_paths, size, GFP_ATOMIC);
+	if (unlikely(!p))
+		return -ENOMEM;
+
+	info->lower_paths = p;
+
+	info->bstart = -1;
+	info->bend = -1;
+	info->bopaque = -1;
+	info->bcount = sbmax(dentry->d_sb);
+	atomic_set(&info->generation,
+			atomic_read(&UNIONFS_SB(dentry->d_sb)->generation));
+
+	memset(info->lower_paths, 0, size);
+
+	return 0;
+}
+
+/* UNIONFS_D(dentry)->lock must be locked */
+int realloc_dentry_private_data(struct dentry *dentry)
+{
+	if (!__realloc_dentry_private_data(dentry))
+		return 0;
+
+	kfree(UNIONFS_D(dentry)->lower_paths);
+	free_dentry_private_data(dentry);
+	return -ENOMEM;
+}
+
+/* allocate new dentry private data */
+int new_dentry_private_data(struct dentry *dentry, int subclass)
+{
+	struct unionfs_dentry_info *info = UNIONFS_D(dentry);
+
+	BUG_ON(info);
+
+	info = kmem_cache_alloc(unionfs_dentry_cachep, GFP_ATOMIC);
+	if (unlikely(!info))
+		return -ENOMEM;
+
+	mutex_init(&info->lock);
+	mutex_lock_nested(&info->lock, subclass);
+
+	info->lower_paths = NULL;
+
+	dentry->d_fsdata = info;
+
+	if (!__realloc_dentry_private_data(dentry))
+		return 0;
+
+	mutex_unlock(&info->lock);
+	free_dentry_private_data(dentry);
+	return -ENOMEM;
+}
+
+/*
+ * scan through the lower dentry objects, and set bstart to reflect the
+ * starting branch
+ */
+void update_bstart(struct dentry *dentry)
+{
+	int bindex;
+	int bstart = dbstart(dentry);
+	int bend = dbend(dentry);
+	struct dentry *lower_dentry;
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+		if (lower_dentry->d_inode) {
+			dbstart(dentry) = bindex;
+			break;
+		}
+		dput(lower_dentry);
+		unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+	}
+}
+
+/*
+ * Main (and complex) driver function for Unionfs's lookup
+ *
+ * Returns: NULL (ok), ERR_PTR if an error occurred, or a non-null non-error
+ * PTR if d_splice returned a different dentry.
+ *
+ * If lookupmode is INTERPOSE_PARTIAL/REVAL/REVAL_NEG, the passed dentry's
+ * inode info must be locked.  If lookupmode is INTERPOSE_LOOKUP (i.e., a
+ * newly looked-up dentry), then unionfs_lookup_backend will return a locked
+ * dentry's info, which the caller must unlock.
+ */
+struct dentry *unionfs_lookup_full(struct dentry *dentry,
+				   struct dentry *parent, int lookupmode)
+{
+	int err = 0;
+	struct dentry *lower_dentry = NULL;
+	struct vfsmount *lower_mnt;
+	struct vfsmount *lower_dir_mnt;
+	struct dentry *wh_lower_dentry = NULL;
+	struct dentry *lower_dir_dentry = NULL;
+	struct dentry *d_interposed = NULL;
+	int bindex, bstart, bend, bopaque;
+	int opaque, num_positive = 0;
+	const char *name;
+	int namelen;
+	int pos_start, pos_end;
+
+	/*
+	 * We should already have a lock on this dentry in the case of a
+	 * partial lookup, or a revalidation.  Otherwise it is returned from
+	 * new_dentry_private_data already locked.
+	 */
+	verify_locked(dentry);
+	verify_locked(parent);
+
+	/* must initialize dentry operations */
+	if (lookupmode == INTERPOSE_LOOKUP)
+		d_set_d_op(dentry, &unionfs_dops);
+
+	/* We never partial lookup the root directory. */
+	if (IS_ROOT(dentry))
+		goto out;
+
+	name = dentry->d_name.name;
+	namelen = dentry->d_name.len;
+
+	/* No dentries should get created for possible whiteout names. */
+	if (!is_validname(name)) {
+		err = -EPERM;
+		goto out_free;
+	}
+
+	/* Now start the actual lookup procedure. */
+	bstart = dbstart(parent);
+	bend = dbend(parent);
+	bopaque = dbopaque(parent);
+	BUG_ON(bstart < 0);
+
+	/* adjust bend to bopaque if needed */
+	if ((bopaque >= 0) && (bopaque < bend))
+		bend = bopaque;
+
+	/* lookup all possible dentries */
+	for (bindex = bstart; bindex <= bend; bindex++) {
+
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		lower_mnt = unionfs_lower_mnt_idx(dentry, bindex);
+
+		/* skip if we already have a positive lower dentry */
+		if (lower_dentry) {
+			if (dbstart(dentry) < 0)
+				dbstart(dentry) = bindex;
+			if (bindex > dbend(dentry))
+				dbend(dentry) = bindex;
+			if (lower_dentry->d_inode)
+				num_positive++;
+			continue;
+		}
+
+		lower_dir_dentry =
+			unionfs_lower_dentry_idx(parent, bindex);
+		/* if the lower dentry's parent does not exist, skip this */
+		if (!lower_dir_dentry || !lower_dir_dentry->d_inode)
+			continue;
+
+		/* also skip it if the parent isn't a directory. */
+		if (!S_ISDIR(lower_dir_dentry->d_inode->i_mode))
+			continue; /* XXX: should be BUG_ON */
+
+		/* check for whiteouts: stop lookup if found */
+		wh_lower_dentry = lookup_whiteout(name, lower_dir_dentry);
+		if (IS_ERR(wh_lower_dentry)) {
+			err = PTR_ERR(wh_lower_dentry);
+			goto out_free;
+		}
+		if (wh_lower_dentry->d_inode) {
+			dbend(dentry) = dbopaque(dentry) = bindex;
+			if (dbstart(dentry) < 0)
+				dbstart(dentry) = bindex;
+			dput(wh_lower_dentry);
+			break;
+		}
+		dput(wh_lower_dentry);
+
+		/* Now do regular lookup; lookup @name */
+		lower_dir_mnt = unionfs_lower_mnt_idx(parent, bindex);
+		lower_mnt = NULL; /* XXX: needed? */
+
+		lower_dentry = __lookup_one(lower_dir_dentry, lower_dir_mnt,
+					    name, &lower_mnt);
+
+		if (IS_ERR(lower_dentry)) {
+			err = PTR_ERR(lower_dentry);
+			goto out_free;
+		}
+		unionfs_set_lower_dentry_idx(dentry, bindex, lower_dentry);
+		if (!lower_mnt)
+			lower_mnt = unionfs_mntget(dentry->d_sb->s_root,
+						   bindex);
+		unionfs_set_lower_mnt_idx(dentry, bindex, lower_mnt);
+
+		/* adjust dbstart/end */
+		if (dbstart(dentry) < 0)
+			dbstart(dentry) = bindex;
+		if (bindex > dbend(dentry))
+			dbend(dentry) = bindex;
+		/*
+		 * We always store the lower dentries above, and update
+		 * dbstart/dbend, even if the whole unionfs dentry is
+		 * negative (i.e., no lower inodes).
+		 */
+		if (!lower_dentry->d_inode)
+			continue;
+		num_positive++;
+
+		/*
+		 * check if we just found an opaque directory, if so, stop
+		 * lookups here.
+		 */
+		if (!S_ISDIR(lower_dentry->d_inode->i_mode))
+			continue;
+		opaque = is_opaque_dir(dentry, bindex);
+		if (opaque < 0) {
+			err = opaque;
+			goto out_free;
+		} else if (opaque) {
+			dbend(dentry) = dbopaque(dentry) = bindex;
+			break;
+		}
+		dbend(dentry) = bindex;
+
+		/* update parent directory's atime with the bindex */
+		fsstack_copy_attr_atime(parent->d_inode,
+					lower_dir_dentry->d_inode);
+	}
+
+	/* sanity checks, then decide if to process a negative dentry */
+	BUG_ON(dbstart(dentry) < 0 && dbend(dentry) >= 0);
+	BUG_ON(dbstart(dentry) >= 0 && dbend(dentry) < 0);
+
+	if (num_positive > 0)
+		goto out_positive;
+
+	/*** handle NEGATIVE dentries ***/
+
+	/*
+	 * If negative, keep only first lower negative dentry, to save on
+	 * memory.
+	 */
+	if (dbstart(dentry) < dbend(dentry)) {
+		path_put_lowers(dentry, dbstart(dentry) + 1,
+				dbend(dentry), false);
+		dbend(dentry) = dbstart(dentry);
+	}
+	if (lookupmode == INTERPOSE_PARTIAL)
+		goto out;
+	if (lookupmode == INTERPOSE_LOOKUP) {
+		/*
+		 * If all we found was a whiteout in the first available
+		 * branch, then create a negative dentry for a possibly new
+		 * file to be created.
+		 */
+		if (dbopaque(dentry) < 0)
+			goto out;
+		/* XXX: need to get mnt here */
+		bindex = dbstart(dentry);
+		if (unionfs_lower_dentry_idx(dentry, bindex))
+			goto out;
+		lower_dir_dentry =
+			unionfs_lower_dentry_idx(parent, bindex);
+		if (!lower_dir_dentry || !lower_dir_dentry->d_inode)
+			goto out;
+		if (!S_ISDIR(lower_dir_dentry->d_inode->i_mode))
+			goto out; /* XXX: should be BUG_ON */
+		/* XXX: do we need to cross bind mounts here? */
+		lower_dentry = lookup_lck_len(name, lower_dir_dentry, namelen);
+		if (IS_ERR(lower_dentry)) {
+			err = PTR_ERR(lower_dentry);
+			goto out;
+		}
+		/* XXX: need to mntget/mntput as needed too! */
+		unionfs_set_lower_dentry_idx(dentry, bindex, lower_dentry);
+		/* XXX: wrong mnt for crossing bind mounts! */
+		lower_mnt = unionfs_mntget(dentry->d_sb->s_root, bindex);
+		unionfs_set_lower_mnt_idx(dentry, bindex, lower_mnt);
+
+		goto out;
+	}
+
+	/* if we're revalidating a positive dentry, don't make it negative */
+	if (lookupmode != INTERPOSE_REVAL)
+		d_add(dentry, NULL);
+
+	goto out;
+
+out_positive:
+	/*** handle POSITIVE dentries ***/
+
+	/*
+	 * This unionfs dentry is positive (at least one lower inode
+	 * exists), so scan entire dentry from beginning to end, and remove
+	 * any negative lower dentries, if any.  Then, update dbstart/dbend
+	 * to reflect the start/end of positive dentries.
+	 */
+	pos_start = pos_end = -1;
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry,
+							bindex);
+		if (lower_dentry && lower_dentry->d_inode) {
+			if (pos_start < 0)
+				pos_start = bindex;
+			if (bindex > pos_end)
+				pos_end = bindex;
+			continue;
+		}
+		path_put_lowers(dentry, bindex, bindex, false);
+	}
+	if (pos_start >= 0)
+		dbstart(dentry) = pos_start;
+	if (pos_end >= 0)
+		dbend(dentry) = pos_end;
+
+	/* Partial lookups need to re-interpose, or throw away older negs. */
+	if (lookupmode == INTERPOSE_PARTIAL) {
+		if (dentry->d_inode) {
+			unionfs_reinterpose(dentry);
+			goto out;
+		}
+
+		/*
+		 * This dentry was positive, so it is as if we had a
+		 * negative revalidation.
+		 */
+		lookupmode = INTERPOSE_REVAL_NEG;
+		update_bstart(dentry);
+	}
+
+	/*
+	 * Interpose can return a dentry if d_splice returned a different
+	 * dentry.
+	 */
+	d_interposed = unionfs_interpose(dentry, dentry->d_sb, lookupmode);
+	if (IS_ERR(d_interposed))
+		err = PTR_ERR(d_interposed);
+	else if (d_interposed)
+		dentry = d_interposed;
+
+	if (!err)
+		goto out;
+	d_drop(dentry);
+
+out_free:
+	/* should dput/mntput all the underlying dentries on error condition */
+	if (dbstart(dentry) >= 0)
+		path_put_lowers_all(dentry, false);
+	/* free lower_paths unconditionally */
+	kfree(UNIONFS_D(dentry)->lower_paths);
+	UNIONFS_D(dentry)->lower_paths = NULL;
+
+out:
+	if (dentry && UNIONFS_D(dentry)) {
+		BUG_ON(dbstart(dentry) < 0 && dbend(dentry) >= 0);
+		BUG_ON(dbstart(dentry) >= 0 && dbend(dentry) < 0);
+	}
+	if (d_interposed && UNIONFS_D(d_interposed)) {
+		BUG_ON(dbstart(d_interposed) < 0 && dbend(d_interposed) >= 0);
+		BUG_ON(dbstart(d_interposed) >= 0 && dbend(d_interposed) < 0);
+	}
+
+	if (!err && d_interposed)
+		return d_interposed;
+	return ERR_PTR(err);
+}
diff --git a/fs/unionfs/main.c b/fs/unionfs/main.c
new file mode 100644
index 00000000..f8c0e3b
--- /dev/null
+++ b/fs/unionfs/main.c
@@ -0,0 +1,753 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+#include <linux/module.h>
+#include <linux/moduleparam.h>
+
+static void unionfs_fill_inode(struct dentry *dentry,
+			       struct inode *inode)
+{
+	struct inode *lower_inode;
+	struct dentry *lower_dentry;
+	int bindex, bstart, bend;
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry) {
+			unionfs_set_lower_inode_idx(inode, bindex, NULL);
+			continue;
+		}
+
+		/* Initialize the lower inode to the new lower inode. */
+		if (!lower_dentry->d_inode)
+			continue;
+
+		unionfs_set_lower_inode_idx(inode, bindex,
+					    igrab(lower_dentry->d_inode));
+	}
+
+	ibstart(inode) = dbstart(dentry);
+	ibend(inode) = dbend(dentry);
+
+	/* Use attributes from the first branch. */
+	lower_inode = unionfs_lower_inode(inode);
+
+	/* Use different set of inode ops for symlinks & directories */
+	if (S_ISLNK(lower_inode->i_mode))
+		inode->i_op = &unionfs_symlink_iops;
+	else if (S_ISDIR(lower_inode->i_mode))
+		inode->i_op = &unionfs_dir_iops;
+
+	/* Use different set of file ops for directories */
+	if (S_ISDIR(lower_inode->i_mode))
+		inode->i_fop = &unionfs_dir_fops;
+
+	/* properly initialize special inodes */
+	if (S_ISBLK(lower_inode->i_mode) || S_ISCHR(lower_inode->i_mode) ||
+	    S_ISFIFO(lower_inode->i_mode) || S_ISSOCK(lower_inode->i_mode))
+		init_special_inode(inode, lower_inode->i_mode,
+				   lower_inode->i_rdev);
+
+	/* all well, copy inode attributes */
+	unionfs_copy_attr_all(inode, lower_inode);
+	fsstack_copy_inode_size(inode, lower_inode);
+}
+
+/*
+ * Connect a unionfs inode dentry/inode with several lower ones.  This is
+ * the classic stackable file system "vnode interposition" action.
+ *
+ * @sb: unionfs's super_block
+ */
+struct dentry *unionfs_interpose(struct dentry *dentry, struct super_block *sb,
+				 int flag)
+{
+	int err = 0;
+	struct inode *inode;
+	int need_fill_inode = 1;
+	struct dentry *spliced = NULL;
+
+	verify_locked(dentry);
+
+	/*
+	 * We allocate our new inode below by calling unionfs_iget,
+	 * which will initialize some of the new inode's fields
+	 */
+
+	/*
+	 * On revalidate we've already got our own inode and just need
+	 * to fix it up.
+	 */
+	if (flag == INTERPOSE_REVAL) {
+		inode = dentry->d_inode;
+		UNIONFS_I(inode)->bstart = -1;
+		UNIONFS_I(inode)->bend = -1;
+		atomic_set(&UNIONFS_I(inode)->generation,
+			   atomic_read(&UNIONFS_SB(sb)->generation));
+
+		UNIONFS_I(inode)->lower_inodes =
+			kcalloc(sbmax(sb), sizeof(struct inode *), GFP_KERNEL);
+		if (unlikely(!UNIONFS_I(inode)->lower_inodes)) {
+			err = -ENOMEM;
+			goto out;
+		}
+	} else {
+		/* get unique inode number for unionfs */
+		inode = unionfs_iget(sb, iunique(sb, UNIONFS_ROOT_INO));
+		if (IS_ERR(inode)) {
+			err = PTR_ERR(inode);
+			goto out;
+		}
+		if (atomic_read(&inode->i_count) > 1)
+			goto skip;
+	}
+
+	need_fill_inode = 0;
+	unionfs_fill_inode(dentry, inode);
+
+skip:
+	/* only (our) lookup wants to do a d_add */
+	switch (flag) {
+	case INTERPOSE_DEFAULT:
+		/* for operations which create new inodes */
+		d_add(dentry, inode);
+		break;
+	case INTERPOSE_REVAL_NEG:
+		d_instantiate(dentry, inode);
+		break;
+	case INTERPOSE_LOOKUP:
+		spliced = d_splice_alias(inode, dentry);
+		if (spliced && spliced != dentry) {
+			/*
+			 * d_splice can return a dentry if it was
+			 * disconnected and had to be moved.  We must ensure
+			 * that the private data of the new dentry is
+			 * correct and that the inode info was filled
+			 * properly.  Finally we must return this new
+			 * dentry.
+			 */
+			d_set_d_op(spliced, &unionfs_dops);
+			spliced->d_fsdata = dentry->d_fsdata;
+			dentry->d_fsdata = NULL;
+			dentry = spliced;
+			if (need_fill_inode) {
+				need_fill_inode = 0;
+				unionfs_fill_inode(dentry, inode);
+			}
+			goto out_spliced;
+		} else if (!spliced) {
+			if (need_fill_inode) {
+				need_fill_inode = 0;
+				unionfs_fill_inode(dentry, inode);
+				goto out_spliced;
+			}
+		}
+		break;
+	case INTERPOSE_REVAL:
+		/* Do nothing. */
+		break;
+	default:
+		printk(KERN_CRIT "unionfs: invalid interpose flag passed!\n");
+		BUG();
+	}
+	goto out;
+
+out_spliced:
+	if (!err)
+		return spliced;
+out:
+	return ERR_PTR(err);
+}
+
+/* like interpose above, but for an already existing dentry */
+void unionfs_reinterpose(struct dentry *dentry)
+{
+	struct dentry *lower_dentry;
+	struct inode *inode;
+	int bindex, bstart, bend;
+
+	verify_locked(dentry);
+
+	/* This is pre-allocated inode */
+	inode = dentry->d_inode;
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry)
+			continue;
+
+		if (!lower_dentry->d_inode)
+			continue;
+		if (unionfs_lower_inode_idx(inode, bindex))
+			continue;
+		unionfs_set_lower_inode_idx(inode, bindex,
+					    igrab(lower_dentry->d_inode));
+	}
+	ibstart(inode) = dbstart(dentry);
+	ibend(inode) = dbend(dentry);
+}
+
+/*
+ * make sure the branch we just looked up (nd) makes sense:
+ *
+ * 1) we're not trying to stack unionfs on top of unionfs
+ * 2) it exists
+ * 3) is a directory
+ */
+int check_branch(const struct path *path)
+{
+	/* XXX: remove in ODF code -- stacking unions allowed there */
+	if (!strcmp(path->dentry->d_sb->s_type->name, UNIONFS_NAME))
+		return -EINVAL;
+	if (!path->dentry->d_inode)
+		return -ENOENT;
+	if (!S_ISDIR(path->dentry->d_inode->i_mode))
+		return -ENOTDIR;
+	return 0;
+}
+
+/* checks if two lower_dentries have overlapping branches */
+static int is_branch_overlap(struct dentry *dent1, struct dentry *dent2)
+{
+	struct dentry *dent = NULL;
+
+	dent = dent1;
+	while ((dent != dent2) && (dent->d_parent != dent))
+		dent = dent->d_parent;
+
+	if (dent == dent2)
+		return 1;
+
+	dent = dent2;
+	while ((dent != dent1) && (dent->d_parent != dent))
+		dent = dent->d_parent;
+
+	return (dent == dent1);
+}
+
+/*
+ * Parse "ro" or "rw" options, but default to "rw" if no mode options was
+ * specified.  Fill the mode bits in @perms.  If encounter an unknown
+ * string, return -EINVAL.  Otherwise return 0.
+ */
+int parse_branch_mode(const char *name, int *perms)
+{
+	if (!name || !strcmp(name, "rw")) {
+		*perms = MAY_READ | MAY_WRITE;
+		return 0;
+	}
+	if (!strcmp(name, "ro")) {
+		*perms = MAY_READ;
+		return 0;
+	}
+	return -EINVAL;
+}
+
+/*
+ * parse the dirs= mount argument
+ *
+ * We don't need to lock the superblock private data's rwsem, as we get
+ * called only by unionfs_read_super - it is still a long time before anyone
+ * can even get a reference to us.
+ */
+static int parse_dirs_option(struct super_block *sb, struct unionfs_dentry_info
+			     *lower_root_info, char *options)
+{
+	struct path path;
+	char *name;
+	int err = 0;
+	int branches = 1;
+	int bindex = 0;
+	int i = 0;
+	int j = 0;
+	struct dentry *dent1;
+	struct dentry *dent2;
+
+	if (options[0] == '\0') {
+		printk(KERN_ERR "unionfs: no branches specified\n");
+		err = -EINVAL;
+		goto out_return;
+	}
+
+	/*
+	 * Each colon means we have a separator, this is really just a rough
+	 * guess, since strsep will handle empty fields for us.
+	 */
+	for (i = 0; options[i]; i++)
+		if (options[i] == ':')
+			branches++;
+
+	/* allocate space for underlying pointers to lower dentry */
+	UNIONFS_SB(sb)->data =
+		kcalloc(branches, sizeof(struct unionfs_data), GFP_KERNEL);
+	if (unlikely(!UNIONFS_SB(sb)->data)) {
+		err = -ENOMEM;
+		goto out_return;
+	}
+
+	lower_root_info->lower_paths =
+		kcalloc(branches, sizeof(struct path), GFP_KERNEL);
+	if (unlikely(!lower_root_info->lower_paths)) {
+		err = -ENOMEM;
+		/* free the underlying pointer array */
+		kfree(UNIONFS_SB(sb)->data);
+		UNIONFS_SB(sb)->data = NULL;
+		goto out_return;
+	}
+
+	/* now parsing a string such as "b1:b2=rw:b3=ro:b4" */
+	branches = 0;
+	while ((name = strsep(&options, ":")) != NULL) {
+		int perms;
+		char *mode = strchr(name, '=');
+
+		if (!name)
+			continue;
+		if (!*name) {	/* bad use of ':' (extra colons) */
+			err = -EINVAL;
+			goto out;
+		}
+
+		branches++;
+
+		/* strip off '=' if any */
+		if (mode)
+			*mode++ = '\0';
+
+		err = parse_branch_mode(mode, &perms);
+		if (err) {
+			printk(KERN_ERR "unionfs: invalid mode \"%s\" for "
+			       "branch %d\n", mode, bindex);
+			goto out;
+		}
+		/* ensure that leftmost branch is writeable */
+		if (!bindex && !(perms & MAY_WRITE)) {
+			printk(KERN_ERR "unionfs: leftmost branch cannot be "
+			       "read-only (use \"-o ro\" to create a "
+			       "read-only union)\n");
+			err = -EINVAL;
+			goto out;
+		}
+
+		err = kern_path(name, LOOKUP_FOLLOW, &path);
+		if (err) {
+			printk(KERN_ERR "unionfs: error accessing "
+			       "lower directory '%s' (error %d)\n",
+			       name, err);
+			goto out;
+		}
+
+		err = check_branch(&path);
+		if (err) {
+			printk(KERN_ERR "unionfs: lower directory "
+			       "'%s' is not a valid branch\n", name);
+			path_put(&path);
+			goto out;
+		}
+
+		lower_root_info->lower_paths[bindex].dentry = path.dentry;
+		lower_root_info->lower_paths[bindex].mnt = path.mnt;
+
+		set_branchperms(sb, bindex, perms);
+		set_branch_count(sb, bindex, 0);
+		new_branch_id(sb, bindex);
+
+		if (lower_root_info->bstart < 0)
+			lower_root_info->bstart = bindex;
+		lower_root_info->bend = bindex;
+		bindex++;
+	}
+
+	if (branches == 0) {
+		printk(KERN_ERR "unionfs: no branches specified\n");
+		err = -EINVAL;
+		goto out;
+	}
+
+	BUG_ON(branches != (lower_root_info->bend + 1));
+
+	/*
+	 * Ensure that no overlaps exist in the branches.
+	 *
+	 * This test is required because the Linux kernel has no support
+	 * currently for ensuring coherency between stackable layers and
+	 * branches.  If we were to allow overlapping branches, it would be
+	 * possible, for example, to delete a file via one branch, which
+	 * would not be reflected in another branch.  Such incoherency could
+	 * lead to inconsistencies and even kernel oopses.  Rather than
+	 * implement hacks to work around some of these cache-coherency
+	 * problems, we prevent branch overlapping, for now.  A complete
+	 * solution will involve proper kernel/VFS support for cache
+	 * coherency, at which time we could safely remove this
+	 * branch-overlapping test.
+	 */
+	for (i = 0; i < branches; i++) {
+		dent1 = lower_root_info->lower_paths[i].dentry;
+		for (j = i + 1; j < branches; j++) {
+			dent2 = lower_root_info->lower_paths[j].dentry;
+			if (is_branch_overlap(dent1, dent2)) {
+				printk(KERN_ERR "unionfs: branches %d and "
+				       "%d overlap\n", i, j);
+				err = -EINVAL;
+				goto out;
+			}
+		}
+	}
+
+out:
+	if (err) {
+		for (i = 0; i < branches; i++)
+			path_put(&lower_root_info->lower_paths[i]);
+
+		kfree(lower_root_info->lower_paths);
+		kfree(UNIONFS_SB(sb)->data);
+
+		/*
+		 * MUST clear the pointers to prevent potential double free if
+		 * the caller dies later on
+		 */
+		lower_root_info->lower_paths = NULL;
+		UNIONFS_SB(sb)->data = NULL;
+	}
+out_return:
+	return err;
+}
+
+/*
+ * Parse mount options.  See the manual page for usage instructions.
+ *
+ * Returns the dentry object of the lower-level (lower) directory;
+ * We want to mount our stackable file system on top of that lower directory.
+ */
+static struct unionfs_dentry_info *unionfs_parse_options(
+					 struct super_block *sb,
+					 char *options)
+{
+	struct unionfs_dentry_info *lower_root_info;
+	char *optname;
+	int err = 0;
+	int bindex;
+	int dirsfound = 0;
+
+	/* allocate private data area */
+	err = -ENOMEM;
+	lower_root_info =
+		kzalloc(sizeof(struct unionfs_dentry_info), GFP_KERNEL);
+	if (unlikely(!lower_root_info))
+		goto out_error;
+	lower_root_info->bstart = -1;
+	lower_root_info->bend = -1;
+	lower_root_info->bopaque = -1;
+
+	while ((optname = strsep(&options, ",")) != NULL) {
+		char *optarg;
+
+		if (!optname || !*optname)
+			continue;
+
+		optarg = strchr(optname, '=');
+		if (optarg)
+			*optarg++ = '\0';
+
+		/*
+		 * All of our options take an argument now. Insert ones that
+		 * don't, above this check.
+		 */
+		if (!optarg) {
+			printk(KERN_ERR "unionfs: %s requires an argument\n",
+			       optname);
+			err = -EINVAL;
+			goto out_error;
+		}
+
+		if (!strcmp("dirs", optname)) {
+			if (++dirsfound > 1) {
+				printk(KERN_ERR
+				       "unionfs: multiple dirs specified\n");
+				err = -EINVAL;
+				goto out_error;
+			}
+			err = parse_dirs_option(sb, lower_root_info, optarg);
+			if (err)
+				goto out_error;
+			continue;
+		}
+
+		err = -EINVAL;
+		printk(KERN_ERR
+		       "unionfs: unrecognized option '%s'\n", optname);
+		goto out_error;
+	}
+	if (dirsfound != 1) {
+		printk(KERN_ERR "unionfs: dirs option required\n");
+		err = -EINVAL;
+		goto out_error;
+	}
+	goto out;
+
+out_error:
+	if (lower_root_info && lower_root_info->lower_paths) {
+		for (bindex = lower_root_info->bstart;
+		     bindex >= 0 && bindex <= lower_root_info->bend;
+		     bindex++)
+			path_put(&lower_root_info->lower_paths[bindex]);
+	}
+
+	kfree(lower_root_info->lower_paths);
+	kfree(lower_root_info);
+
+	kfree(UNIONFS_SB(sb)->data);
+	UNIONFS_SB(sb)->data = NULL;
+
+	lower_root_info = ERR_PTR(err);
+out:
+	return lower_root_info;
+}
+
+/*
+ * There is no need to lock the unionfs_super_info's rwsem as there is no
+ * way anyone can have a reference to the superblock at this point in time.
+ */
+static int unionfs_read_super(struct super_block *sb, void *raw_data,
+			      int silent)
+{
+	int err = 0;
+	struct unionfs_dentry_info *lower_root_info = NULL;
+	int bindex, bstart, bend;
+	struct inode *inode = NULL;
+
+	if (!raw_data) {
+		printk(KERN_ERR
+		       "unionfs: read_super: missing data argument\n");
+		err = -EINVAL;
+		goto out;
+	}
+
+	/* Allocate superblock private data */
+	sb->s_fs_info = kzalloc(sizeof(struct unionfs_sb_info), GFP_KERNEL);
+	if (unlikely(!UNIONFS_SB(sb))) {
+		printk(KERN_CRIT "unionfs: read_super: out of memory\n");
+		err = -ENOMEM;
+		goto out;
+	}
+
+	UNIONFS_SB(sb)->bend = -1;
+	atomic_set(&UNIONFS_SB(sb)->generation, 1);
+	init_rwsem(&UNIONFS_SB(sb)->rwsem);
+	UNIONFS_SB(sb)->high_branch_id = -1; /* -1 == invalid branch ID */
+
+	lower_root_info = unionfs_parse_options(sb, raw_data);
+	if (IS_ERR(lower_root_info)) {
+		printk(KERN_ERR
+		       "unionfs: read_super: error while parsing options "
+		       "(err = %ld)\n", PTR_ERR(lower_root_info));
+		err = PTR_ERR(lower_root_info);
+		lower_root_info = NULL;
+		goto out_free;
+	}
+	if (lower_root_info->bstart == -1) {
+		err = -ENOENT;
+		goto out_free;
+	}
+
+	/* set the lower superblock field of upper superblock */
+	bstart = lower_root_info->bstart;
+	BUG_ON(bstart != 0);
+	sbend(sb) = bend = lower_root_info->bend;
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		struct dentry *d = lower_root_info->lower_paths[bindex].dentry;
+		atomic_inc(&d->d_sb->s_active);
+		unionfs_set_lower_super_idx(sb, bindex, d->d_sb);
+	}
+
+	/* max Bytes is the maximum bytes from highest priority branch */
+	sb->s_maxbytes = unionfs_lower_super_idx(sb, 0)->s_maxbytes;
+
+	/*
+	 * Our c/m/atime granularity is 1 ns because we may stack on file
+	 * systems whose granularity is as good.  This is important for our
+	 * time-based cache coherency.
+	 */
+	sb->s_time_gran = 1;
+
+	sb->s_op = &unionfs_sops;
+
+	/* get a new inode and allocate our root dentry */
+	inode = unionfs_iget(sb, iunique(sb, UNIONFS_ROOT_INO));
+	if (IS_ERR(inode)) {
+		err = PTR_ERR(inode);
+		goto out_dput;
+	}
+	sb->s_root = d_make_root(inode);
+	if (unlikely(!sb->s_root)) {
+		err = -ENOMEM;
+		goto out_iput;
+	}
+	d_set_d_op(sb->s_root, &unionfs_dops);
+
+	/* link the upper and lower dentries */
+	sb->s_root->d_fsdata = NULL;
+	err = new_dentry_private_data(sb->s_root, UNIONFS_DMUTEX_ROOT);
+	if (unlikely(err))
+		goto out_freedpd;
+
+	/* if get here: cannot have error */
+
+	/* Set the lower dentries for s_root */
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		struct dentry *d;
+		struct vfsmount *m;
+
+		d = lower_root_info->lower_paths[bindex].dentry;
+		m = lower_root_info->lower_paths[bindex].mnt;
+
+		unionfs_set_lower_dentry_idx(sb->s_root, bindex, d);
+		unionfs_set_lower_mnt_idx(sb->s_root, bindex, m);
+	}
+	dbstart(sb->s_root) = bstart;
+	dbend(sb->s_root) = bend;
+
+	/* Set the generation number to one, since this is for the mount. */
+	atomic_set(&UNIONFS_D(sb->s_root)->generation, 1);
+
+	if (atomic_read(&inode->i_count) <= 1)
+		unionfs_fill_inode(sb->s_root, inode);
+
+	/*
+	 * No need to call interpose because we already have a positive
+	 * dentry, which was instantiated by d_alloc_root.  Just need to
+	 * d_rehash it.
+	 */
+	d_rehash(sb->s_root);
+
+	unionfs_unlock_dentry(sb->s_root);
+	goto out; /* all is well */
+
+out_freedpd:
+	if (UNIONFS_D(sb->s_root)) {
+		kfree(UNIONFS_D(sb->s_root)->lower_paths);
+		free_dentry_private_data(sb->s_root);
+	}
+	dput(sb->s_root);
+
+out_iput:
+	iput(inode);
+
+out_dput:
+	if (lower_root_info && !IS_ERR(lower_root_info)) {
+		for (bindex = lower_root_info->bstart;
+		     bindex <= lower_root_info->bend; bindex++) {
+			struct dentry *d;
+			d = lower_root_info->lower_paths[bindex].dentry;
+			/* drop refs we took earlier */
+			atomic_dec(&d->d_sb->s_active);
+			path_put(&lower_root_info->lower_paths[bindex]);
+		}
+		kfree(lower_root_info->lower_paths);
+		kfree(lower_root_info);
+		lower_root_info = NULL;
+	}
+
+out_free:
+	kfree(UNIONFS_SB(sb)->data);
+	kfree(UNIONFS_SB(sb));
+	sb->s_fs_info = NULL;
+
+out:
+	if (lower_root_info && !IS_ERR(lower_root_info)) {
+		kfree(lower_root_info->lower_paths);
+		kfree(lower_root_info);
+	}
+	return err;
+}
+
+static struct dentry *unionfs_mount(struct file_system_type *fs_type,
+				    int flags, const char *dev_name,
+				    void *raw_data)
+{
+	struct dentry *dentry;
+
+	dentry = mount_nodev(fs_type, flags, raw_data, unionfs_read_super);
+	if (!IS_ERR(dentry))
+		UNIONFS_SB(dentry->d_sb)->dev_name =
+			kstrdup(dev_name, GFP_KERNEL);
+	return dentry;
+}
+
+static struct file_system_type unionfs_fs_type = {
+	.owner		= THIS_MODULE,
+	.name		= UNIONFS_NAME,
+	.mount		= unionfs_mount,
+	.kill_sb	= generic_shutdown_super,
+	.fs_flags	= 0,
+};
+MODULE_ALIAS_FS(UNIONFS_NAME);
+
+static int __init init_unionfs_fs(void)
+{
+	int err;
+
+	pr_info("Registering unionfs " UNIONFS_VERSION "\n");
+
+	err = unionfs_init_filldir_cache();
+	if (unlikely(err))
+		goto out;
+	err = unionfs_init_inode_cache();
+	if (unlikely(err))
+		goto out;
+	err = unionfs_init_dentry_cache();
+	if (unlikely(err))
+		goto out;
+	err = init_sioq();
+	if (unlikely(err))
+		goto out;
+	err = register_filesystem(&unionfs_fs_type);
+out:
+	if (unlikely(err)) {
+		stop_sioq();
+		unionfs_destroy_filldir_cache();
+		unionfs_destroy_inode_cache();
+		unionfs_destroy_dentry_cache();
+	}
+	return err;
+}
+
+static void __exit exit_unionfs_fs(void)
+{
+	stop_sioq();
+	unionfs_destroy_filldir_cache();
+	unionfs_destroy_inode_cache();
+	unionfs_destroy_dentry_cache();
+	unregister_filesystem(&unionfs_fs_type);
+	pr_info("Completed unionfs module unload\n");
+}
+
+MODULE_AUTHOR("Erez Zadok, Filesystems and Storage Lab, Stony Brook University"
+	      " (http://www.fsl.cs.sunysb.edu)");
+MODULE_DESCRIPTION("Unionfs " UNIONFS_VERSION
+		   " (http://unionfs.filesystems.org)");
+MODULE_LICENSE("GPL");
+
+module_init(init_unionfs_fs);
+module_exit(exit_unionfs_fs);
diff --git a/fs/unionfs/mmap.c b/fs/unionfs/mmap.c
new file mode 100644
index 00000000..bf719a0
--- /dev/null
+++ b/fs/unionfs/mmap.c
@@ -0,0 +1,159 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2006      Shaya Potter
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+
+/*
+ * XXX: we need a dummy readpage handler because generic_file_mmap (which we
+ * use in unionfs_mmap) checks for the existence of
+ * mapping->a_ops->readpage, else it returns -ENOEXEC.  The VFS will need to
+ * be fixed to allow a file system to define vm_ops->fault without any
+ * address_space_ops whatsoever.
+ *
+ * Otherwise, we don't want to use our readpage method at all.
+ */
+static int unionfs_readpage(struct file *file, struct page *page)
+{
+	BUG();
+	return -EINVAL;
+}
+
+static int unionfs_fault(struct vm_area_struct *vma, struct vm_fault *vmf)
+{
+	int err;
+	struct file *file, *lower_file;
+	const struct vm_operations_struct *lower_vm_ops;
+	struct vm_area_struct lower_vma;
+
+	BUG_ON(!vma);
+	memcpy(&lower_vma, vma, sizeof(struct vm_area_struct));
+	file = lower_vma.vm_file;
+	lower_vm_ops = UNIONFS_F(file)->lower_vm_ops;
+	BUG_ON(!lower_vm_ops);
+
+	lower_file = unionfs_lower_file(file);
+	BUG_ON(!lower_file);
+	/*
+	 * XXX: vm_ops->fault may be called in parallel.  Because we have to
+	 * resort to temporarily changing the vma->vm_file to point to the
+	 * lower file, a concurrent invocation of unionfs_fault could see a
+	 * different value.  In this workaround, we keep a different copy of
+	 * the vma structure in our stack, so we never expose a different
+	 * value of the vma->vm_file called to us, even temporarily.  A
+	 * better fix would be to change the calling semantics of ->fault to
+	 * take an explicit file pointer.
+	 */
+	lower_vma.vm_file = lower_file;
+	err = lower_vm_ops->fault(&lower_vma, vmf);
+	return err;
+}
+
+static int unionfs_page_mkwrite(struct vm_area_struct *vma,
+				struct vm_fault *vmf)
+{
+	int err = 0;
+	struct file *file, *lower_file;
+	const struct vm_operations_struct *lower_vm_ops;
+	struct vm_area_struct lower_vma;
+
+	BUG_ON(!vma);
+	memcpy(&lower_vma, vma, sizeof(struct vm_area_struct));
+	file = lower_vma.vm_file;
+	lower_vm_ops = UNIONFS_F(file)->lower_vm_ops;
+	BUG_ON(!lower_vm_ops);
+	if (!lower_vm_ops->page_mkwrite)
+		goto out;
+
+	lower_file = unionfs_lower_file(file);
+	BUG_ON(!lower_file);
+	/*
+	 * XXX: vm_ops->page_mkwrite may be called in parallel.
+	 * Because we have to resort to temporarily changing the
+	 * vma->vm_file to point to the lower file, a concurrent
+	 * invocation of unionfs_page_mkwrite could see a different
+	 * value.  In this workaround, we keep a different copy of the
+	 * vma structure in our stack, so we never expose a different
+	 * value of the vma->vm_file called to us, even temporarily.
+	 * A better fix would be to change the calling semantics of
+	 * ->page_mkwrite to take an explicit file pointer.
+	 */
+	lower_vma.vm_file = lower_file;
+	err = lower_vm_ops->page_mkwrite(&lower_vma, vmf);
+out:
+	return err;
+}
+
+/*
+ * This function should never be called directly.
+ * It's here only for the check a_ops->direct_IO during vfs_open.
+ */
+static ssize_t unionfs_direct_IO(int rw, struct kiocb *iocb,
+				 const struct iovec *iov, loff_t offset,
+				 unsigned long nr_segs)
+{
+	return -EINVAL;
+}
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+/* synchronize vma_interval_tree to writable lower-file */
+static void unionfs_update_mapping(struct vm_area_struct *vma)
+{
+	struct file *upper_file;
+
+	BUG_ON(!vma);
+	upper_file = vma->vm_file;
+	BUG_ON(!upper_file);
+	/* copy vam_interval_tree in mapping from upper-file to lower-file */
+	if ((vma->vm_flags | VM_SHARED | VM_WRITE) == vma->vm_flags) {
+		struct file *lower_file = unionfs_lower_file(upper_file);
+		BUG_ON(!lower_file);
+		lower_file->f_mapping->i_mmap_writable =
+		upper_file->f_mapping->i_mmap_writable;
+		if (unlikely(vma->vm_flags & VM_NONLINEAR)) {
+			lower_file->f_mapping->i_mmap_nonlinear =
+			upper_file->f_mapping->i_mmap_nonlinear;
+		} else {
+			lower_file->f_mapping->i_mmap =
+			upper_file->f_mapping->i_mmap;
+		}
+	}
+}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
+
+struct address_space_operations unionfs_aops = {
+	.direct_IO	= unionfs_direct_IO,
+};
+
+/*
+ * XXX: we need a second, dummy address_space_ops vector, to be used
+ * temporarily during unionfs_mmap, because the latter calls
+ * generic_file_mmap, which checks if ->readpage exists, else returns
+ * -ENOEXEC.
+ */
+struct address_space_operations unionfs_dummy_aops = {
+	.readpage	= unionfs_readpage,
+};
+
+struct vm_operations_struct unionfs_vm_ops = {
+	.fault		= unionfs_fault,
+	.page_mkwrite	= unionfs_page_mkwrite,
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+	.update_mapping = unionfs_update_mapping,
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
+};
diff --git a/fs/unionfs/rdstate.c b/fs/unionfs/rdstate.c
new file mode 100644
index 00000000..732cc2b
--- /dev/null
+++ b/fs/unionfs/rdstate.c
@@ -0,0 +1,285 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/* This file contains the routines for maintaining readdir state. */
+
+/*
+ * There are two structures here, rdstate which is a hash table
+ * of the second structure which is a filldir_node.
+ */
+
+/*
+ * This is a struct kmem_cache for filldir nodes, because we allocate a lot
+ * of them and they shouldn't waste memory.  If the node has a small name
+ * (as defined by the dentry structure), then we use an inline name to
+ * preserve kmalloc space.
+ */
+static struct kmem_cache *unionfs_filldir_cachep;
+
+int unionfs_init_filldir_cache(void)
+{
+	unionfs_filldir_cachep =
+		kmem_cache_create("unionfs_filldir",
+				  sizeof(struct filldir_node), 0,
+				  SLAB_RECLAIM_ACCOUNT, NULL);
+
+	return (unionfs_filldir_cachep ? 0 : -ENOMEM);
+}
+
+void unionfs_destroy_filldir_cache(void)
+{
+	if (unionfs_filldir_cachep)
+		kmem_cache_destroy(unionfs_filldir_cachep);
+}
+
+/*
+ * This is a tuning parameter that tells us roughly how big to make the
+ * hash table in directory entries per page.  This isn't perfect, but
+ * at least we get a hash table size that shouldn't be too overloaded.
+ * The following averages are based on my home directory.
+ * 14.44693	Overall
+ * 12.29	Single Page Directories
+ * 117.93	Multi-page directories
+ */
+#define DENTPAGE 4096
+#define DENTPERONEPAGE 12
+#define DENTPERPAGE 118
+#define MINHASHSIZE 1
+static int guesstimate_hash_size(struct inode *inode)
+{
+	struct inode *lower_inode;
+	int bindex;
+	int hashsize = MINHASHSIZE;
+
+	if (UNIONFS_I(inode)->hashsize > 0)
+		return UNIONFS_I(inode)->hashsize;
+
+	for (bindex = ibstart(inode); bindex <= ibend(inode); bindex++) {
+		lower_inode = unionfs_lower_inode_idx(inode, bindex);
+		if (!lower_inode)
+			continue;
+
+		if (i_size_read(lower_inode) == DENTPAGE)
+			hashsize += DENTPERONEPAGE;
+		else
+			hashsize += (i_size_read(lower_inode) / DENTPAGE) *
+				DENTPERPAGE;
+	}
+
+	return hashsize;
+}
+
+int init_rdstate(struct file *file)
+{
+	BUG_ON(sizeof(loff_t) !=
+	       (sizeof(unsigned int) + sizeof(unsigned int)));
+	BUG_ON(UNIONFS_F(file)->rdstate != NULL);
+
+	UNIONFS_F(file)->rdstate = alloc_rdstate(file->f_path.dentry->d_inode,
+						 fbstart(file));
+
+	return (UNIONFS_F(file)->rdstate ? 0 : -ENOMEM);
+}
+
+struct unionfs_dir_state *find_rdstate(struct inode *inode, loff_t fpos)
+{
+	struct unionfs_dir_state *rdstate = NULL;
+	struct list_head *pos;
+
+	spin_lock(&UNIONFS_I(inode)->rdlock);
+	list_for_each(pos, &UNIONFS_I(inode)->readdircache) {
+		struct unionfs_dir_state *r =
+			list_entry(pos, struct unionfs_dir_state, cache);
+		if (fpos == rdstate2offset(r)) {
+			UNIONFS_I(inode)->rdcount--;
+			list_del(&r->cache);
+			rdstate = r;
+			break;
+		}
+	}
+	spin_unlock(&UNIONFS_I(inode)->rdlock);
+	return rdstate;
+}
+
+struct unionfs_dir_state *alloc_rdstate(struct inode *inode, int bindex)
+{
+	int i = 0;
+	int hashsize;
+	unsigned long mallocsize = sizeof(struct unionfs_dir_state);
+	struct unionfs_dir_state *rdstate;
+
+	hashsize = guesstimate_hash_size(inode);
+	mallocsize += hashsize * sizeof(struct list_head);
+	mallocsize = __roundup_pow_of_two(mallocsize);
+
+	/* This should give us about 500 entries anyway. */
+	if (mallocsize > PAGE_SIZE)
+		mallocsize = PAGE_SIZE;
+
+	hashsize = (mallocsize - sizeof(struct unionfs_dir_state)) /
+		sizeof(struct list_head);
+
+	rdstate = kmalloc(mallocsize, GFP_KERNEL);
+	if (unlikely(!rdstate))
+		return NULL;
+
+	spin_lock(&UNIONFS_I(inode)->rdlock);
+	if (UNIONFS_I(inode)->cookie >= (MAXRDCOOKIE - 1))
+		UNIONFS_I(inode)->cookie = 1;
+	else
+		UNIONFS_I(inode)->cookie++;
+
+	rdstate->cookie = UNIONFS_I(inode)->cookie;
+	spin_unlock(&UNIONFS_I(inode)->rdlock);
+	rdstate->offset = 1;
+	rdstate->access = jiffies;
+	rdstate->bindex = bindex;
+	rdstate->dirpos = 0;
+	rdstate->hashentries = 0;
+	rdstate->size = hashsize;
+	for (i = 0; i < rdstate->size; i++)
+		INIT_LIST_HEAD(&rdstate->list[i]);
+
+	return rdstate;
+}
+
+static void free_filldir_node(struct filldir_node *node)
+{
+	if (node->namelen >= DNAME_INLINE_LEN)
+		kfree(node->name);
+	kmem_cache_free(unionfs_filldir_cachep, node);
+}
+
+void free_rdstate(struct unionfs_dir_state *state)
+{
+	struct filldir_node *tmp;
+	int i;
+
+	for (i = 0; i < state->size; i++) {
+		struct list_head *head = &(state->list[i]);
+		struct list_head *pos, *n;
+
+		/* traverse the list and deallocate space */
+		list_for_each_safe(pos, n, head) {
+			tmp = list_entry(pos, struct filldir_node, file_list);
+			list_del(&tmp->file_list);
+			free_filldir_node(tmp);
+		}
+	}
+
+	kfree(state);
+}
+
+struct filldir_node *find_filldir_node(struct unionfs_dir_state *rdstate,
+				       const char *name, int namelen,
+				       int is_whiteout)
+{
+	int index;
+	unsigned int hash;
+	struct list_head *head;
+	struct list_head *pos;
+	struct filldir_node *cursor = NULL;
+	int found = 0;
+
+	BUG_ON(namelen <= 0);
+
+	hash = full_name_hash(name, namelen);
+	index = hash % rdstate->size;
+
+	head = &(rdstate->list[index]);
+	list_for_each(pos, head) {
+		cursor = list_entry(pos, struct filldir_node, file_list);
+
+		if (cursor->namelen == namelen && cursor->hash == hash &&
+		    !strncmp(cursor->name, name, namelen)) {
+			/*
+			 * a duplicate exists, and hence no need to create
+			 * entry to the list
+			 */
+			found = 1;
+
+			/*
+			 * if a duplicate is found in this branch, and is
+			 * not due to the caller looking for an entry to
+			 * whiteout, then the file system may be corrupted.
+			 */
+			if (unlikely(!is_whiteout &&
+				     cursor->bindex == rdstate->bindex))
+				printk(KERN_ERR "unionfs: filldir: possible "
+				       "I/O error: a file is duplicated "
+				       "in the same branch %d: %s\n",
+				       rdstate->bindex, cursor->name);
+			break;
+		}
+	}
+
+	if (!found)
+		cursor = NULL;
+
+	return cursor;
+}
+
+int add_filldir_node(struct unionfs_dir_state *rdstate, const char *name,
+		     int namelen, int bindex, int whiteout)
+{
+	struct filldir_node *new;
+	unsigned int hash;
+	int index;
+	int err = 0;
+	struct list_head *head;
+
+	BUG_ON(namelen <= 0);
+
+	hash = full_name_hash(name, namelen);
+	index = hash % rdstate->size;
+	head = &(rdstate->list[index]);
+
+	new = kmem_cache_alloc(unionfs_filldir_cachep, GFP_KERNEL);
+	if (unlikely(!new)) {
+		err = -ENOMEM;
+		goto out;
+	}
+
+	INIT_LIST_HEAD(&new->file_list);
+	new->namelen = namelen;
+	new->hash = hash;
+	new->bindex = bindex;
+	new->whiteout = whiteout;
+
+	if (namelen < DNAME_INLINE_LEN) {
+		new->name = new->iname;
+	} else {
+		new->name = kmalloc(namelen + 1, GFP_KERNEL);
+		if (unlikely(!new->name)) {
+			kmem_cache_free(unionfs_filldir_cachep, new);
+			new = NULL;
+			goto out;
+		}
+	}
+
+	memcpy(new->name, name, namelen);
+	new->name[namelen] = '\0';
+
+	rdstate->hashentries++;
+
+	list_add(&(new->file_list), head);
+out:
+	return err;
+}
diff --git a/fs/unionfs/rename.c b/fs/unionfs/rename.c
new file mode 100644
index 00000000..d69e4c7
--- /dev/null
+++ b/fs/unionfs/rename.c
@@ -0,0 +1,517 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * This is a helper function for rename, used when rename ends up with hosed
+ * over dentries and we need to revert.
+ */
+static int unionfs_refresh_lower_dentry(struct dentry *dentry,
+					struct dentry *parent, int bindex)
+{
+	struct dentry *lower_dentry;
+	struct dentry *lower_parent;
+	int err = 0;
+
+	verify_locked(dentry);
+
+	lower_parent = unionfs_lower_dentry_idx(parent, bindex);
+
+	BUG_ON(!S_ISDIR(lower_parent->d_inode->i_mode));
+
+	lower_dentry = lookup_one_len(dentry->d_name.name, lower_parent,
+				      dentry->d_name.len); // XXX: pass flags?
+	if (IS_ERR(lower_dentry)) {
+		err = PTR_ERR(lower_dentry);
+		goto out;
+	}
+
+	dput(unionfs_lower_dentry_idx(dentry, bindex));
+	iput(unionfs_lower_inode_idx(dentry->d_inode, bindex));
+	unionfs_set_lower_inode_idx(dentry->d_inode, bindex, NULL);
+
+	if (!lower_dentry->d_inode) {
+		dput(lower_dentry);
+		unionfs_set_lower_dentry_idx(dentry, bindex, NULL);
+	} else {
+		unionfs_set_lower_dentry_idx(dentry, bindex, lower_dentry);
+		unionfs_set_lower_inode_idx(dentry->d_inode, bindex,
+					    igrab(lower_dentry->d_inode));
+	}
+
+out:
+	return err;
+}
+
+static int __unionfs_rename(struct inode *old_dir, struct dentry *old_dentry,
+			    struct dentry *old_parent,
+			    struct inode *new_dir, struct dentry *new_dentry,
+			    struct dentry *new_parent,
+			    int bindex)
+{
+	int err = 0;
+	struct dentry *lower_old_dentry;
+	struct dentry *lower_new_dentry;
+	struct dentry *lower_old_dir_dentry;
+	struct dentry *lower_new_dir_dentry;
+	struct dentry *trap;
+
+	lower_new_dentry = unionfs_lower_dentry_idx(new_dentry, bindex);
+	lower_old_dentry = unionfs_lower_dentry_idx(old_dentry, bindex);
+
+	if (!lower_new_dentry) {
+		lower_new_dentry =
+			create_parents(new_parent->d_inode,
+				       new_dentry, new_dentry->d_name.name,
+				       bindex);
+		if (IS_ERR(lower_new_dentry)) {
+			err = PTR_ERR(lower_new_dentry);
+			if (IS_COPYUP_ERR(err))
+				goto out;
+			printk(KERN_ERR "unionfs: error creating directory "
+			       "tree for rename, bindex=%d err=%d\n",
+			       bindex, err);
+			goto out;
+		}
+	}
+
+	/* check for and remove whiteout, if any */
+	err = check_unlink_whiteout(new_dentry, lower_new_dentry, bindex);
+	if (err > 0) /* ignore if whiteout found and successfully removed */
+		err = 0;
+	if (err)
+		goto out;
+
+	/* check of old_dentry branch is writable */
+	err = is_robranch_super(old_dentry->d_sb, bindex);
+	if (err)
+		goto out;
+
+	dget(lower_old_dentry);
+	dget(lower_new_dentry);
+	lower_old_dir_dentry = dget_parent(lower_old_dentry);
+	lower_new_dir_dentry = dget_parent(lower_new_dentry);
+
+	trap = lock_rename(lower_old_dir_dentry, lower_new_dir_dentry);
+	/* source should not be ancenstor of target */
+	if (trap == lower_old_dentry) {
+		err = -EINVAL;
+		goto out_err_unlock;
+	}
+	/* target should not be ancenstor of source */
+	if (trap == lower_new_dentry) {
+		err = -ENOTEMPTY;
+		goto out_err_unlock;
+	}
+	err = vfs_rename(lower_old_dir_dentry->d_inode, lower_old_dentry,
+			 lower_new_dir_dentry->d_inode, lower_new_dentry);
+out_err_unlock:
+	if (!err) {
+		/* update parent dir times */
+		fsstack_copy_attr_times(old_dir, lower_old_dir_dentry->d_inode);
+		fsstack_copy_attr_times(new_dir, lower_new_dir_dentry->d_inode);
+	}
+	unlock_rename(lower_old_dir_dentry, lower_new_dir_dentry);
+
+	dput(lower_old_dir_dentry);
+	dput(lower_new_dir_dentry);
+	dput(lower_old_dentry);
+	dput(lower_new_dentry);
+
+out:
+	if (!err) {
+		/* Fixup the new_dentry. */
+		if (bindex < dbstart(new_dentry))
+			dbstart(new_dentry) = bindex;
+		else if (bindex > dbend(new_dentry))
+			dbend(new_dentry) = bindex;
+	}
+
+	return err;
+}
+
+/*
+ * Main rename code.  This is sufficiently complex, that it's documented in
+ * Documentation/filesystems/unionfs/rename.txt.  This routine calls
+ * __unionfs_rename() above to perform some of the work.
+ */
+static int do_unionfs_rename(struct inode *old_dir,
+			     struct dentry *old_dentry,
+			     struct dentry *old_parent,
+			     struct inode *new_dir,
+			     struct dentry *new_dentry,
+			     struct dentry *new_parent)
+{
+	int err = 0;
+	int bindex;
+	int old_bstart, old_bend;
+	int new_bstart, new_bend;
+	int do_copyup = -1;
+	int local_err = 0;
+	int eio = 0;
+	int revert = 0;
+
+	old_bstart = dbstart(old_dentry);
+	old_bend = dbend(old_dentry);
+
+	new_bstart = dbstart(new_dentry);
+	new_bend = dbend(new_dentry);
+
+	/* Rename source to destination. */
+	err = __unionfs_rename(old_dir, old_dentry, old_parent,
+			       new_dir, new_dentry, new_parent,
+			       old_bstart);
+	if (err) {
+		if (!IS_COPYUP_ERR(err))
+			goto out;
+		do_copyup = old_bstart - 1;
+	} else {
+		revert = 1;
+	}
+
+	/*
+	 * Unlink all instances of destination that exist to the left of
+	 * bstart of source. On error, revert back, goto out.
+	 */
+	for (bindex = old_bstart - 1; bindex >= new_bstart; bindex--) {
+		struct dentry *unlink_dentry;
+		struct dentry *unlink_dir_dentry;
+
+		BUG_ON(bindex < 0);
+		unlink_dentry = unionfs_lower_dentry_idx(new_dentry, bindex);
+		if (!unlink_dentry)
+			continue;
+
+		unlink_dir_dentry = lock_parent(unlink_dentry);
+		err = is_robranch_super(old_dir->i_sb, bindex);
+		if (!err)
+			err = vfs_unlink(unlink_dir_dentry->d_inode,
+					 unlink_dentry);
+
+		fsstack_copy_attr_times(new_parent->d_inode,
+					unlink_dir_dentry->d_inode);
+		/* propagate number of hard-links */
+		set_nlink(new_parent->d_inode,
+			  unionfs_get_nlinks(new_parent->d_inode));
+
+		unlock_dir(unlink_dir_dentry);
+		if (!err) {
+			if (bindex != new_bstart) {
+				dput(unlink_dentry);
+				unionfs_set_lower_dentry_idx(new_dentry,
+							     bindex, NULL);
+			}
+		} else if (IS_COPYUP_ERR(err)) {
+			do_copyup = bindex - 1;
+		} else if (revert) {
+			goto revert;
+		}
+	}
+
+	if (do_copyup != -1) {
+		for (bindex = do_copyup; bindex >= 0; bindex--) {
+			/*
+			 * copyup the file into some left directory, so that
+			 * you can rename it
+			 */
+			err = copyup_dentry(old_parent->d_inode,
+					    old_dentry, old_bstart, bindex,
+					    old_dentry->d_name.name,
+					    old_dentry->d_name.len, NULL,
+					    i_size_read(old_dentry->d_inode));
+			/* if copyup failed, try next branch to the left */
+			if (err)
+				continue;
+			/*
+			 * create whiteout before calling __unionfs_rename
+			 * because the latter will change the old_dentry's
+			 * lower name and parent dir, resulting in the
+			 * whiteout getting created in the wrong dir.
+			 */
+			err = create_whiteout(old_dentry, bindex);
+			if (err) {
+				printk(KERN_ERR "unionfs: can't create a "
+				       "whiteout for %s in rename (err=%d)\n",
+				       old_dentry->d_name.name, err);
+				continue;
+			}
+			err = __unionfs_rename(old_dir, old_dentry, old_parent,
+					       new_dir, new_dentry, new_parent,
+					       bindex);
+			break;
+		}
+	}
+
+	/* make it opaque */
+	if (S_ISDIR(old_dentry->d_inode->i_mode)) {
+		err = make_dir_opaque(old_dentry, dbstart(old_dentry));
+		if (err)
+			goto revert;
+	}
+
+	/*
+	 * Create whiteout for source, only if:
+	 * (1) There is more than one underlying instance of source.
+	 * (We did a copy_up is taken care of above).
+	 */
+	if ((old_bstart != old_bend) && (do_copyup == -1)) {
+		err = create_whiteout(old_dentry, old_bstart);
+		if (err) {
+			/* can't fix anything now, so we exit with -EIO */
+			printk(KERN_ERR "unionfs: can't create a whiteout for "
+			       "%s in rename!\n", old_dentry->d_name.name);
+			err = -EIO;
+		}
+	}
+
+out:
+	return err;
+
+revert:
+	/* Do revert here. */
+	local_err = unionfs_refresh_lower_dentry(new_dentry, new_parent,
+						 old_bstart);
+	if (local_err) {
+		printk(KERN_ERR "unionfs: revert failed in rename: "
+		       "the new refresh failed\n");
+		eio = -EIO;
+	}
+
+	local_err = unionfs_refresh_lower_dentry(old_dentry, old_parent,
+						 old_bstart);
+	if (local_err) {
+		printk(KERN_ERR "unionfs: revert failed in rename: "
+		       "the old refresh failed\n");
+		eio = -EIO;
+		goto revert_out;
+	}
+
+	if (!unionfs_lower_dentry_idx(new_dentry, bindex) ||
+	    !unionfs_lower_dentry_idx(new_dentry, bindex)->d_inode) {
+		printk(KERN_ERR "unionfs: revert failed in rename: "
+		       "the object disappeared from under us!\n");
+		eio = -EIO;
+		goto revert_out;
+	}
+
+	if (unionfs_lower_dentry_idx(old_dentry, bindex) &&
+	    unionfs_lower_dentry_idx(old_dentry, bindex)->d_inode) {
+		printk(KERN_ERR "unionfs: revert failed in rename: "
+		       "the object was created underneath us!\n");
+		eio = -EIO;
+		goto revert_out;
+	}
+
+	local_err = __unionfs_rename(new_dir, new_dentry, new_parent,
+				     old_dir, old_dentry, old_parent,
+				     old_bstart);
+
+	/* If we can't fix it, then we cop-out with -EIO. */
+	if (local_err) {
+		printk(KERN_ERR "unionfs: revert failed in rename!\n");
+		eio = -EIO;
+	}
+
+	local_err = unionfs_refresh_lower_dentry(new_dentry, new_parent,
+						 bindex);
+	if (local_err)
+		eio = -EIO;
+	local_err = unionfs_refresh_lower_dentry(old_dentry, old_parent,
+						 bindex);
+	if (local_err)
+		eio = -EIO;
+
+revert_out:
+	if (eio)
+		err = eio;
+	return err;
+}
+
+/*
+ * We can't copyup a directory, because it may involve huge numbers of
+ * children, etc.  Doing that in the kernel would be bad, so instead we
+ * return EXDEV to the user-space utility that caused this, and let the
+ * user-space recurse and ask us to copy up each file separately.
+ */
+static int may_rename_dir(struct dentry *dentry, struct dentry *parent)
+{
+	int err, bstart;
+
+	err = check_empty(dentry, parent, NULL);
+	if (err == -ENOTEMPTY) {
+		if (is_robranch(dentry))
+			return -EXDEV;
+	} else if (err) {
+		return err;
+	}
+
+	bstart = dbstart(dentry);
+	if (dbend(dentry) == bstart || dbopaque(dentry) == bstart)
+		return 0;
+
+	dbstart(dentry) = bstart + 1;
+	err = check_empty(dentry, parent, NULL);
+	dbstart(dentry) = bstart;
+	if (err == -ENOTEMPTY)
+		err = -EXDEV;
+	return err;
+}
+
+/*
+ * The locking rules in unionfs_rename are complex.  We could use a simpler
+ * superblock-level name-space lock for renames and copy-ups.
+ */
+int unionfs_rename(struct inode *old_dir, struct dentry *old_dentry,
+		   struct inode *new_dir, struct dentry *new_dentry)
+{
+	int err = 0;
+	struct dentry *wh_dentry;
+	struct dentry *old_parent, *new_parent;
+	int valid = true;
+
+	unionfs_read_lock(old_dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	old_parent = dget_parent(old_dentry);
+	new_parent = dget_parent(new_dentry);
+	/* un/lock parent dentries only if they differ from old/new_dentry */
+	if (old_parent != old_dentry &&
+	    old_parent != new_dentry)
+		unionfs_lock_dentry(old_parent, UNIONFS_DMUTEX_REVAL_PARENT);
+	if (new_parent != old_dentry &&
+	    new_parent != new_dentry &&
+	    new_parent != old_parent)
+		unionfs_lock_dentry(new_parent, UNIONFS_DMUTEX_REVAL_CHILD);
+	unionfs_double_lock_dentry(old_dentry, new_dentry);
+
+	valid = __unionfs_d_revalidate(old_dentry, old_parent, false, 0);
+	if (!valid) {
+		err = -ESTALE;
+		goto out;
+	}
+	if (!d_deleted(new_dentry) && new_dentry->d_inode) {
+		valid = __unionfs_d_revalidate(new_dentry, new_parent, false, 0);
+		if (!valid) {
+			err = -ESTALE;
+			goto out;
+		}
+	}
+
+	if (!S_ISDIR(old_dentry->d_inode->i_mode))
+		err = unionfs_partial_lookup(old_dentry, old_parent);
+	else
+		err = may_rename_dir(old_dentry, old_parent);
+
+	if (err)
+		goto out;
+
+	err = unionfs_partial_lookup(new_dentry, new_parent);
+	if (err)
+		goto out;
+
+	/*
+	 * if new_dentry is already lower because of whiteout,
+	 * simply override it even if the whited-out dir is not empty.
+	 */
+	wh_dentry = find_first_whiteout(new_dentry);
+	if (!IS_ERR(wh_dentry)) {
+		dput(wh_dentry);
+	} else if (new_dentry->d_inode) {
+		if (S_ISDIR(old_dentry->d_inode->i_mode) !=
+		    S_ISDIR(new_dentry->d_inode->i_mode)) {
+			err = S_ISDIR(old_dentry->d_inode->i_mode) ?
+				-ENOTDIR : -EISDIR;
+			goto out;
+		}
+
+		if (S_ISDIR(new_dentry->d_inode->i_mode)) {
+			struct unionfs_dir_state *namelist = NULL;
+			/* check if this unionfs directory is empty or not */
+			err = check_empty(new_dentry, new_parent, &namelist);
+			if (err)
+				goto out;
+
+			if (!is_robranch(new_dentry))
+				err = delete_whiteouts(new_dentry,
+						       dbstart(new_dentry),
+						       namelist);
+
+			free_rdstate(namelist);
+
+			if (err)
+				goto out;
+		}
+	}
+
+	err = do_unionfs_rename(old_dir, old_dentry, old_parent,
+				new_dir, new_dentry, new_parent);
+	if (err)
+		goto out;
+
+	/*
+	 * force re-lookup since the dir on ro branch is not renamed, and
+	 * lower dentries still indicate the un-renamed ones.
+	 */
+	if (S_ISDIR(old_dentry->d_inode->i_mode))
+		atomic_dec(&UNIONFS_D(old_dentry)->generation);
+	else
+		unionfs_postcopyup_release(old_dentry);
+	if (new_dentry->d_inode && !S_ISDIR(new_dentry->d_inode->i_mode)) {
+		unionfs_postcopyup_release(new_dentry);
+		unionfs_postcopyup_setmnt(new_dentry);
+		if (!unionfs_lower_inode(new_dentry->d_inode)) {
+			/*
+			 * If we get here, it means that no copyup was
+			 * needed, and that a file by the old name already
+			 * existing on the destination branch; that file got
+			 * renamed earlier in this function, so all we need
+			 * to do here is set the lower inode.
+			 */
+			struct inode *inode;
+			inode = unionfs_lower_inode(old_dentry->d_inode);
+			igrab(inode);
+			unionfs_set_lower_inode_idx(new_dentry->d_inode,
+						    dbstart(new_dentry),
+						    inode);
+		}
+	}
+	/* if all of this renaming succeeded, update our times */
+	unionfs_copy_attr_times(old_dentry->d_inode);
+	unionfs_copy_attr_times(new_dentry->d_inode);
+	unionfs_check_inode(old_dir);
+	unionfs_check_inode(new_dir);
+	unionfs_check_dentry(old_dentry);
+	unionfs_check_dentry(new_dentry);
+
+out:
+	if (err)		/* clear the new_dentry stuff created */
+		d_drop(new_dentry);
+
+	unionfs_double_unlock_dentry(old_dentry, new_dentry);
+	if (new_parent != old_dentry &&
+	    new_parent != new_dentry &&
+	    new_parent != old_parent)
+		unionfs_unlock_dentry(new_parent);
+	if (old_parent != old_dentry &&
+	    old_parent != new_dentry)
+		unionfs_unlock_dentry(old_parent);
+	dput(new_parent);
+	dput(old_parent);
+	unionfs_read_unlock(old_dentry->d_sb);
+
+	return err;
+}
diff --git a/fs/unionfs/sioq.c b/fs/unionfs/sioq.c
new file mode 100644
index 00000000..8a4c55a
--- /dev/null
+++ b/fs/unionfs/sioq.c
@@ -0,0 +1,101 @@
+/*
+ * Copyright (c) 2006-2014 Erez Zadok
+ * Copyright (c) 2006      Charles P. Wright
+ * Copyright (c) 2006-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2006      Junjiro Okajima
+ * Copyright (c) 2006      David P. Quigley
+ * Copyright (c) 2006-2014 Stony Brook University
+ * Copyright (c) 2006-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * Super-user IO work Queue - sometimes we need to perform actions which
+ * would fail due to the unix permissions on the parent directory (e.g.,
+ * rmdir a directory which appears empty, but in reality contains
+ * whiteouts).
+ */
+
+static struct workqueue_struct *superio_workqueue;
+
+int __init init_sioq(void)
+{
+	int err;
+
+	superio_workqueue = create_workqueue("unionfs_siod");
+	if (!IS_ERR(superio_workqueue))
+		return 0;
+
+	err = PTR_ERR(superio_workqueue);
+	printk(KERN_ERR "unionfs: create_workqueue failed %d\n", err);
+	superio_workqueue = NULL;
+	return err;
+}
+
+void stop_sioq(void)
+{
+	if (superio_workqueue)
+		destroy_workqueue(superio_workqueue);
+}
+
+void run_sioq(work_func_t func, struct sioq_args *args)
+{
+	INIT_WORK(&args->work, func);
+
+	init_completion(&args->comp);
+	while (!queue_work(superio_workqueue, &args->work)) {
+		/* TODO: do accounting if needed */
+		schedule();
+	}
+	wait_for_completion(&args->comp);
+}
+
+void __unionfs_create(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct create_args *c = &args->create;
+
+	args->err = vfs_create(c->parent, c->dentry, c->mode, c->want_excl);
+	complete(&args->comp);
+}
+
+void __unionfs_mkdir(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct mkdir_args *m = &args->mkdir;
+
+	args->err = vfs_mkdir(m->parent, m->dentry, m->mode);
+	complete(&args->comp);
+}
+
+void __unionfs_mknod(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct mknod_args *m = &args->mknod;
+
+	args->err = vfs_mknod(m->parent, m->dentry, m->mode, m->dev);
+	complete(&args->comp);
+}
+
+void __unionfs_symlink(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct symlink_args *s = &args->symlink;
+
+	args->err = vfs_symlink(s->parent, s->dentry, s->symbuf);
+	complete(&args->comp);
+}
+
+void __unionfs_unlink(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct unlink_args *u = &args->unlink;
+
+	args->err = vfs_unlink(u->parent, u->dentry);
+	complete(&args->comp);
+}
diff --git a/fs/unionfs/sioq.h b/fs/unionfs/sioq.h
new file mode 100644
index 00000000..cf74aa2
--- /dev/null
+++ b/fs/unionfs/sioq.h
@@ -0,0 +1,91 @@
+/*
+ * Copyright (c) 2006-2014 Erez Zadok
+ * Copyright (c) 2006      Charles P. Wright
+ * Copyright (c) 2006-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2006      Junjiro Okajima
+ * Copyright (c) 2006      David P. Quigley
+ * Copyright (c) 2006-2014 Stony Brook University
+ * Copyright (c) 2006-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#ifndef _SIOQ_H
+#define _SIOQ_H
+
+struct deletewh_args {
+	struct unionfs_dir_state *namelist;
+	struct dentry *dentry;
+	int bindex;
+};
+
+struct is_opaque_args {
+	struct dentry *dentry;
+};
+
+struct create_args {
+	struct inode *parent;
+	struct dentry *dentry;
+	umode_t mode;
+	bool want_excl;
+};
+
+struct mkdir_args {
+	struct inode *parent;
+	struct dentry *dentry;
+	umode_t mode;
+};
+
+struct mknod_args {
+	struct inode *parent;
+	struct dentry *dentry;
+	umode_t mode;
+	dev_t dev;
+};
+
+struct symlink_args {
+	struct inode *parent;
+	struct dentry *dentry;
+	char *symbuf;
+};
+
+struct unlink_args {
+	struct inode *parent;
+	struct dentry *dentry;
+};
+
+
+struct sioq_args {
+	struct completion comp;
+	struct work_struct work;
+	int err;
+	void *ret;
+
+	union {
+		struct deletewh_args deletewh;
+		struct is_opaque_args is_opaque;
+		struct create_args create;
+		struct mkdir_args mkdir;
+		struct mknod_args mknod;
+		struct symlink_args symlink;
+		struct unlink_args unlink;
+	};
+};
+
+/* Extern definitions for SIOQ functions */
+extern int __init init_sioq(void);
+extern void stop_sioq(void);
+extern void run_sioq(work_func_t func, struct sioq_args *args);
+
+/* Extern definitions for our privilege escalation helpers */
+extern void __unionfs_create(struct work_struct *work);
+extern void __unionfs_mkdir(struct work_struct *work);
+extern void __unionfs_mknod(struct work_struct *work);
+extern void __unionfs_symlink(struct work_struct *work);
+extern void __unionfs_unlink(struct work_struct *work);
+extern void __delete_whiteouts(struct work_struct *work);
+extern void __is_opaque_dir(struct work_struct *work);
+
+#endif /* not _SIOQ_H */
diff --git a/fs/unionfs/subr.c b/fs/unionfs/subr.c
new file mode 100644
index 00000000..01794d5
--- /dev/null
+++ b/fs/unionfs/subr.c
@@ -0,0 +1,95 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * returns the right n_link value based on the inode type
+ */
+int unionfs_get_nlinks(const struct inode *inode)
+{
+	/* don't bother to do all the work since we're unlinked */
+	if (inode->i_nlink == 0)
+		return 0;
+
+	if (!S_ISDIR(inode->i_mode))
+		return unionfs_lower_inode(inode)->i_nlink;
+
+	/*
+	 * For directories, we return 1. The only place that could cares
+	 * about links is readdir, and there's d_type there so even that
+	 * doesn't matter.
+	 */
+	return 1;
+}
+
+/* copy a/m/ctime from the lower branch with the newest times */
+void unionfs_copy_attr_times(struct inode *upper)
+{
+	int bindex;
+	struct inode *lower;
+
+	if (!upper)
+		return;
+	if (ibstart(upper) < 0) {
+#ifdef CONFIG_UNION_FS_DEBUG
+		WARN_ON(ibstart(upper) < 0);
+#endif /* CONFIG_UNION_FS_DEBUG */
+		return;
+	}
+	for (bindex = ibstart(upper); bindex <= ibend(upper); bindex++) {
+		lower = unionfs_lower_inode_idx(upper, bindex);
+		if (!lower)
+			continue; /* not all lower dir objects may exist */
+		if (unlikely(timespec_compare(&upper->i_mtime,
+					      &lower->i_mtime) < 0))
+			upper->i_mtime = lower->i_mtime;
+		if (unlikely(timespec_compare(&upper->i_ctime,
+					      &lower->i_ctime) < 0))
+			upper->i_ctime = lower->i_ctime;
+		if (unlikely(timespec_compare(&upper->i_atime,
+					      &lower->i_atime) < 0))
+			upper->i_atime = lower->i_atime;
+	}
+}
+
+/*
+ * A unionfs/fanout version of fsstack_copy_attr_all.  Uses a
+ * unionfs_get_nlinks to properly calcluate the number of links to a file.
+ * Also, copies the max() of all a/m/ctimes for all lower inodes (which is
+ * important if the lower inode is a directory type)
+ */
+void unionfs_copy_attr_all(struct inode *dest,
+			   const struct inode *src)
+{
+	dest->i_mode = src->i_mode;
+	dest->i_uid = src->i_uid;
+	dest->i_gid = src->i_gid;
+	dest->i_rdev = src->i_rdev;
+
+	unionfs_copy_attr_times(dest);
+
+	dest->i_blkbits = src->i_blkbits;
+	dest->i_flags = src->i_flags;
+
+	/*
+	 * Update the nlinks AFTER updating the above fields, because the
+	 * get_links callback may depend on them.
+	 */
+	set_nlink(dest, unionfs_get_nlinks(dest));
+}
diff --git a/fs/unionfs/super.c b/fs/unionfs/super.c
new file mode 100644
index 00000000..b95ac07
--- /dev/null
+++ b/fs/unionfs/super.c
@@ -0,0 +1,1030 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * The inode cache is used with alloc_inode for both our inode info and the
+ * vfs inode.
+ */
+static struct kmem_cache *unionfs_inode_cachep;
+
+struct inode *unionfs_iget(struct super_block *sb, unsigned long ino)
+{
+	int size;
+	struct unionfs_inode_info *info;
+	struct inode *inode;
+
+	inode = iget_locked(sb, ino);
+	if (!inode)
+		return ERR_PTR(-ENOMEM);
+	if (!(inode->i_state & I_NEW))
+		return inode;
+
+	info = UNIONFS_I(inode);
+	memset(info, 0, offsetof(struct unionfs_inode_info, vfs_inode));
+	info->bstart = -1;
+	info->bend = -1;
+	atomic_set(&info->generation,
+		   atomic_read(&UNIONFS_SB(inode->i_sb)->generation));
+	spin_lock_init(&info->rdlock);
+	info->rdcount = 1;
+	info->hashsize = -1;
+	INIT_LIST_HEAD(&info->readdircache);
+
+	size = sbmax(inode->i_sb) * sizeof(struct inode *);
+	info->lower_inodes = kzalloc(size, GFP_KERNEL);
+	if (unlikely(!info->lower_inodes)) {
+		printk(KERN_CRIT "unionfs: no kernel memory when allocating "
+		       "lower-pointer array!\n");
+		iget_failed(inode);
+		return ERR_PTR(-ENOMEM);
+	}
+
+	inode->i_version++;
+	inode->i_op = &unionfs_main_iops;
+	inode->i_fop = &unionfs_main_fops;
+
+	inode->i_mapping->a_ops = &unionfs_aops;
+
+	/*
+	 * reset times so unionfs_copy_attr_all can keep out time invariants
+	 * right (upper inode time being the max of all lower ones).
+	 */
+	inode->i_atime.tv_sec = inode->i_atime.tv_nsec = 0;
+	inode->i_mtime.tv_sec = inode->i_mtime.tv_nsec = 0;
+	inode->i_ctime.tv_sec = inode->i_ctime.tv_nsec = 0;
+	unlock_new_inode(inode);
+	return inode;
+}
+
+/*
+ * final actions when unmounting a file system
+ *
+ * No need to lock rwsem.
+ */
+static void unionfs_put_super(struct super_block *sb)
+{
+	int bindex, bstart, bend;
+	struct unionfs_sb_info *spd;
+	int leaks = 0;
+
+	spd = UNIONFS_SB(sb);
+	if (!spd)
+		return;
+
+	bstart = sbstart(sb);
+	bend = sbend(sb);
+
+	/* Make sure we have no leaks of branchget/branchput. */
+	for (bindex = bstart; bindex <= bend; bindex++)
+		if (unlikely(branch_count(sb, bindex) != 0)) {
+			printk(KERN_CRIT
+			       "unionfs: branch %d has %d references left!\n",
+			       bindex, branch_count(sb, bindex));
+			leaks = 1;
+		}
+	WARN_ON(leaks != 0);
+
+	/* decrement lower super references */
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		struct super_block *s;
+		s = unionfs_lower_super_idx(sb, bindex);
+		unionfs_set_lower_super_idx(sb, bindex, NULL);
+		atomic_dec(&s->s_active);
+	}
+
+	kfree(spd->dev_name);
+	kfree(spd->data);
+	kfree(spd);
+	sb->s_fs_info = NULL;
+}
+
+/*
+ * Since people use this to answer the "How big of a file can I write?"
+ * question, we report the size of the highest priority branch as the size of
+ * the union.
+ */
+static int unionfs_statfs(struct dentry *dentry, struct kstatfs *buf)
+{
+	int err	= 0;
+	struct super_block *sb;
+	struct dentry *lower_dentry;
+	struct dentry *parent;
+	struct path lower_path;
+	bool valid;
+
+	sb = dentry->d_sb;
+
+	unionfs_read_lock(sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+	unionfs_check_dentry(dentry);
+
+	lower_dentry = unionfs_lower_dentry(sb->s_root);
+	lower_path.dentry = lower_dentry;
+	lower_path.mnt = unionfs_mntget(sb->s_root, 0);
+	err = vfs_statfs(&lower_path, buf);
+	mntput(lower_path.mnt);
+
+	/* set return buf to our f/s to avoid confusing user-level utils */
+	buf->f_type = UNIONFS_SUPER_MAGIC;
+	/*
+	 * Our maximum file name can is shorter by a few bytes because every
+	 * file name could potentially be whited-out.
+	 *
+	 * XXX: this restriction goes away with ODF.
+	 */
+	unionfs_set_max_namelen(&buf->f_namelen);
+
+	/*
+	 * reset two fields to avoid confusing user-land.
+	 * XXX: is this still necessary?
+	 */
+	memset(&buf->f_fsid, 0, sizeof(__kernel_fsid_t));
+	memset(&buf->f_spare, 0, sizeof(buf->f_spare));
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(sb);
+	return err;
+}
+
+/* handle mode changing during remount */
+static noinline_for_stack int do_remount_mode_option(
+					char *optarg,
+					int cur_branches,
+					struct unionfs_data *new_data,
+					struct path *new_lower_paths)
+{
+	int err = -EINVAL;
+	int perms, idx;
+	char *modename = strchr(optarg, '=');
+	struct path path;
+
+	/* by now, optarg contains the branch name */
+	if (!*optarg) {
+		printk(KERN_ERR
+		       "unionfs: no branch specified for mode change\n");
+		goto out;
+	}
+	if (!modename) {
+		printk(KERN_ERR "unionfs: branch \"%s\" requires a mode\n",
+		       optarg);
+		goto out;
+	}
+	*modename++ = '\0';
+	err = parse_branch_mode(modename, &perms);
+	if (err) {
+		printk(KERN_ERR "unionfs: invalid mode \"%s\" for \"%s\"\n",
+		       modename, optarg);
+		goto out;
+	}
+
+	/*
+	 * Find matching branch index.  For now, this assumes that nothing
+	 * has been mounted on top of this Unionfs stack.  Once we have /odf
+	 * and cache-coherency resolved, we'll address the branch-path
+	 * uniqueness.
+	 */
+	err = kern_path(optarg, LOOKUP_FOLLOW, &path);
+	if (err) {
+		printk(KERN_ERR "unionfs: error accessing "
+		       "lower directory \"%s\" (error %d)\n",
+		       optarg, err);
+		goto out;
+	}
+	for (idx = 0; idx < cur_branches; idx++)
+		if (path.mnt == new_lower_paths[idx].mnt &&
+		    path.dentry == new_lower_paths[idx].dentry)
+			break;
+	path_put(&path);	/* no longer needed */
+	if (idx == cur_branches) {
+		err = -ENOENT;	/* err may have been reset above */
+		printk(KERN_ERR "unionfs: branch \"%s\" "
+		       "not found\n", optarg);
+		goto out;
+	}
+	/* check/change mode for existing branch */
+	/* we don't warn if perms==branchperms */
+	new_data[idx].branchperms = perms;
+	err = 0;
+out:
+	return err;
+}
+
+/* handle branch deletion during remount */
+static noinline_for_stack int do_remount_del_option(
+					char *optarg, int cur_branches,
+					struct unionfs_data *new_data,
+					struct path *new_lower_paths)
+{
+	int err = -EINVAL;
+	int idx;
+	struct path path;
+
+	/* optarg contains the branch name to delete */
+
+	/*
+	 * Find matching branch index.  For now, this assumes that nothing
+	 * has been mounted on top of this Unionfs stack.  Once we have /odf
+	 * and cache-coherency resolved, we'll address the branch-path
+	 * uniqueness.
+	 */
+	err = kern_path(optarg, LOOKUP_FOLLOW, &path);
+	if (err) {
+		printk(KERN_ERR "unionfs: error accessing "
+		       "lower directory \"%s\" (error %d)\n",
+		       optarg, err);
+		goto out;
+	}
+	for (idx = 0; idx < cur_branches; idx++)
+		if (path.mnt == new_lower_paths[idx].mnt &&
+		    path.dentry == new_lower_paths[idx].dentry)
+			break;
+	path_put(&path);	/* no longer needed */
+	if (idx == cur_branches) {
+		printk(KERN_ERR "unionfs: branch \"%s\" "
+		       "not found\n", optarg);
+		err = -ENOENT;
+		goto out;
+	}
+	/* check if there are any open files on the branch to be deleted */
+	if (atomic_read(&new_data[idx].open_files) > 0) {
+		err = -EBUSY;
+		goto out;
+	}
+
+	/*
+	 * Now we have to delete the branch.  First, release any handles it
+	 * has.  Then, move the remaining array indexes past "idx" in
+	 * new_data and new_lower_paths one to the left.  Finally, adjust
+	 * cur_branches.
+	 */
+	path_put(&new_lower_paths[idx]);
+
+	if (idx < cur_branches - 1) {
+		/* if idx==cur_branches-1, we delete last branch: easy */
+		memmove(&new_data[idx], &new_data[idx+1],
+			(cur_branches - 1 - idx) *
+			sizeof(struct unionfs_data));
+		memmove(&new_lower_paths[idx], &new_lower_paths[idx+1],
+			(cur_branches - 1 - idx) * sizeof(struct path));
+	}
+
+	err = 0;
+out:
+	return err;
+}
+
+/* handle branch insertion during remount */
+static noinline_for_stack int do_remount_add_option(
+					char *optarg, int cur_branches,
+					struct unionfs_data *new_data,
+					struct path *new_lower_paths,
+					int *high_branch_id)
+{
+	int err = -EINVAL;
+	int perms;
+	int idx = 0;		/* default: insert at beginning */
+	char *new_branch , *modename = NULL;
+	struct path path;
+
+	/*
+	 * optarg can be of several forms:
+	 *
+	 * /bar:/foo		insert /foo before /bar
+	 * /bar:/foo=ro		insert /foo in ro mode before /bar
+	 * /foo			insert /foo in the beginning (prepend)
+	 * :/foo		insert /foo at the end (append)
+	 */
+	if (*optarg == ':') {	/* append? */
+		new_branch = optarg + 1; /* skip ':' */
+		idx = cur_branches;
+		goto found_insertion_point;
+	}
+	new_branch = strchr(optarg, ':');
+	if (!new_branch) {	/* prepend? */
+		new_branch = optarg;
+		goto found_insertion_point;
+	}
+	*new_branch++ = '\0';	/* holds path+mode of new branch */
+
+	/*
+	 * Find matching branch index.  For now, this assumes that nothing
+	 * has been mounted on top of this Unionfs stack.  Once we have /odf
+	 * and cache-coherency resolved, we'll address the branch-path
+	 * uniqueness.
+	 */
+	err = kern_path(optarg, LOOKUP_FOLLOW, &path);
+	if (err) {
+		printk(KERN_ERR "unionfs: error accessing "
+		       "lower directory \"%s\" (error %d)\n",
+		       optarg, err);
+		goto out;
+	}
+	for (idx = 0; idx < cur_branches; idx++)
+		if (path.mnt == new_lower_paths[idx].mnt &&
+		    path.dentry == new_lower_paths[idx].dentry)
+			break;
+	path_put(&path);	/* no longer needed */
+	if (idx == cur_branches) {
+		printk(KERN_ERR "unionfs: branch \"%s\" "
+		       "not found\n", optarg);
+		err = -ENOENT;
+		goto out;
+	}
+
+	/*
+	 * At this point idx will hold the index where the new branch should
+	 * be inserted before.
+	 */
+found_insertion_point:
+	/* find the mode for the new branch */
+	if (new_branch)
+		modename = strchr(new_branch, '=');
+	if (modename)
+		*modename++ = '\0';
+	if (!new_branch || !*new_branch) {
+		printk(KERN_ERR "unionfs: null new branch\n");
+		err = -EINVAL;
+		goto out;
+	}
+	err = parse_branch_mode(modename, &perms);
+	if (err) {
+		printk(KERN_ERR "unionfs: invalid mode \"%s\" for "
+		       "branch \"%s\"\n", modename, new_branch);
+		goto out;
+	}
+	err = kern_path(new_branch, LOOKUP_FOLLOW, &path);
+	if (err) {
+		printk(KERN_ERR "unionfs: error accessing "
+		       "lower directory \"%s\" (error %d)\n",
+		       new_branch, err);
+		goto out;
+	}
+	/*
+	 * It's probably safe to check_mode the new branch to insert.  Note:
+	 * we don't allow inserting branches which are unionfs's by
+	 * themselves (check_branch returns EINVAL in that case).  This is
+	 * because this code base doesn't support stacking unionfs: the ODF
+	 * code base supports that correctly.
+	 */
+	err = check_branch(&path);
+	if (err) {
+		printk(KERN_ERR "unionfs: lower directory "
+		       "\"%s\" is not a valid branch\n", optarg);
+		path_put(&path);
+		goto out;
+	}
+
+	/*
+	 * Now we have to insert the new branch.  But first, move the bits
+	 * to make space for the new branch, if needed.  Finally, adjust
+	 * cur_branches.
+	 * We don't release nd here; it's kept until umount/remount.
+	 */
+	if (idx < cur_branches) {
+		/* if idx==cur_branches, we append: easy */
+		memmove(&new_data[idx+1], &new_data[idx],
+			(cur_branches - idx) * sizeof(struct unionfs_data));
+		memmove(&new_lower_paths[idx+1], &new_lower_paths[idx],
+			(cur_branches - idx) * sizeof(struct path));
+	}
+	new_lower_paths[idx].dentry = path.dentry;
+	new_lower_paths[idx].mnt = path.mnt;
+
+	new_data[idx].sb = path.dentry->d_sb;
+	atomic_set(&new_data[idx].open_files, 0);
+	new_data[idx].branchperms = perms;
+	new_data[idx].branch_id = ++*high_branch_id; /* assign new branch ID */
+
+	err = 0;
+out:
+	return err;
+}
+
+
+/*
+ * Support branch management options on remount.
+ *
+ * See Documentation/filesystems/unionfs/ for details.
+ *
+ * @flags: numeric mount options
+ * @options: mount options string
+ *
+ * This function can rearrange a mounted union dynamically, adding and
+ * removing branches, including changing branch modes.  Clearly this has to
+ * be done safely and atomically.  Luckily, the VFS already calls this
+ * function with lock_super(sb) and lock_kernel() held, preventing
+ * concurrent mixing of new mounts, remounts, and unmounts.  Moreover,
+ * do_remount_sb(), our caller function, already called shrink_dcache_sb(sb)
+ * to purge dentries/inodes from our superblock, and also called
+ * fsync_super(sb) to purge any dirty pages.  So we're good.
+ *
+ * XXX: however, our remount code may also need to invalidate mapped pages
+ * so as to force them to be re-gotten from the (newly reconfigured) lower
+ * branches.  This has to wait for proper mmap and cache coherency support
+ * in the VFS.
+ *
+ */
+static int unionfs_remount_fs(struct super_block *sb, int *flags,
+			      char *options)
+{
+	int err = 0;
+	int i;
+	char *optionstmp, *tmp_to_free;	/* kstrdup'ed of "options" */
+	char *optname;
+	int cur_branches = 0;	/* no. of current branches */
+	int new_branches = 0;	/* no. of branches actually left in the end */
+	int add_branches;	/* est. no. of branches to add */
+	int del_branches;	/* est. no. of branches to del */
+	int max_branches;	/* max possible no. of branches */
+	struct unionfs_data *new_data = NULL, *tmp_data = NULL;
+	struct path *new_lower_paths = NULL, *tmp_lower_paths = NULL;
+	struct inode **new_lower_inodes = NULL;
+	int new_high_branch_id;	/* new high branch ID */
+	int size;		/* memory allocation size, temp var */
+	int old_ibstart, old_ibend;
+
+	unionfs_write_lock(sb);
+
+	/*
+	 * The VFS will take care of "ro" and "rw" flags, and we can safely
+	 * ignore MS_SILENT, but anything else left over is an error.  So we
+	 * need to check if any other flags may have been passed (none are
+	 * allowed/supported as of now).
+	 */
+	if ((*flags & ~(MS_RDONLY | MS_SILENT)) != 0) {
+		printk(KERN_ERR
+		       "unionfs: remount flags 0x%x unsupported\n", *flags);
+		err = -EINVAL;
+		goto out_error;
+	}
+
+	/*
+	 * If 'options' is NULL, it's probably because the user just changed
+	 * the union to a "ro" or "rw" and the VFS took care of it.  So
+	 * nothing to do and we're done.
+	 */
+	if (!options || options[0] == '\0')
+		goto out_error;
+
+	/*
+	 * Find out how many branches we will have in the end, counting
+	 * "add" and "del" commands.  Copy the "options" string because
+	 * strsep modifies the string and we need it later.
+	 */
+	tmp_to_free = kstrdup(options, GFP_KERNEL);
+	optionstmp = tmp_to_free;
+	if (unlikely(!optionstmp)) {
+		err = -ENOMEM;
+		goto out_free;
+	}
+	cur_branches = sbmax(sb); /* current no. branches */
+	new_branches = sbmax(sb);
+	del_branches = 0;
+	add_branches = 0;
+	new_high_branch_id = sbhbid(sb); /* save current high_branch_id */
+	while ((optname = strsep(&optionstmp, ",")) != NULL) {
+		char *optarg;
+
+		if (!optname || !*optname)
+			continue;
+
+		optarg = strchr(optname, '=');
+		if (optarg)
+			*optarg++ = '\0';
+
+		if (!strcmp("add", optname))
+			add_branches++;
+		else if (!strcmp("del", optname))
+			del_branches++;
+	}
+	kfree(tmp_to_free);
+	/* after all changes, will we have at least one branch left? */
+	if ((new_branches + add_branches - del_branches) < 1) {
+		printk(KERN_ERR
+		       "unionfs: no branches left after remount\n");
+		err = -EINVAL;
+		goto out_free;
+	}
+
+	/*
+	 * Since we haven't actually parsed all the add/del options, nor
+	 * have we checked them for errors, we don't know for sure how many
+	 * branches we will have after all changes have taken place.  In
+	 * fact, the total number of branches left could be less than what
+	 * we have now.  So we need to allocate space for a temporary
+	 * placeholder that is at least as large as the maximum number of
+	 * branches we *could* have, which is the current number plus all
+	 * the additions.  Once we're done with these temp placeholders, we
+	 * may have to re-allocate the final size, copy over from the temp,
+	 * and then free the temps (done near the end of this function).
+	 */
+	max_branches = cur_branches + add_branches;
+	/* allocate space for new pointers to lower dentry */
+	tmp_data = kcalloc(max_branches,
+			   sizeof(struct unionfs_data), GFP_KERNEL);
+	if (unlikely(!tmp_data)) {
+		err = -ENOMEM;
+		goto out_free;
+	}
+	/* allocate space for new pointers to lower paths */
+	tmp_lower_paths = kcalloc(max_branches,
+				  sizeof(struct path), GFP_KERNEL);
+	if (unlikely(!tmp_lower_paths)) {
+		err = -ENOMEM;
+		goto out_free;
+	}
+	/* copy current info into new placeholders, incrementing refcnts */
+	memcpy(tmp_data, UNIONFS_SB(sb)->data,
+	       cur_branches * sizeof(struct unionfs_data));
+	memcpy(tmp_lower_paths, UNIONFS_D(sb->s_root)->lower_paths,
+	       cur_branches * sizeof(struct path));
+	for (i = 0; i < cur_branches; i++)
+		path_get(&tmp_lower_paths[i]); /* drop refs at end of fxn */
+
+	/*******************************************************************
+	 * For each branch command, do kern_path on the requested branch,
+	 * and apply the change to a temp branch list.  To handle errors, we
+	 * already dup'ed the old arrays (above), and increased the refcnts
+	 * on various f/s objects.  So now we can do all the kern_path'ss
+	 * and branch-management commands on the new arrays.  If it fail mid
+	 * way, we free the tmp arrays and *put all objects.  If we succeed,
+	 * then we free old arrays and *put its objects, and then replace
+	 * the arrays with the new tmp list (we may have to re-allocate the
+	 * memory because the temp lists could have been larger than what we
+	 * actually needed).
+	 *******************************************************************/
+
+	while ((optname = strsep(&options, ",")) != NULL) {
+		char *optarg;
+
+		if (!optname || !*optname)
+			continue;
+		/*
+		 * At this stage optname holds a comma-delimited option, but
+		 * without the commas.  Next, we need to break the string on
+		 * the '=' symbol to separate CMD=ARG, where ARG itself can
+		 * be KEY=VAL.  For example, in mode=/foo=rw, CMD is "mode",
+		 * KEY is "/foo", and VAL is "rw".
+		 */
+		optarg = strchr(optname, '=');
+		if (optarg)
+			*optarg++ = '\0';
+		/* incgen remount option (instead of old ioctl) */
+		if (!strcmp("incgen", optname)) {
+			err = 0;
+			goto out_no_change;
+		}
+
+		/*
+		 * All of our options take an argument now.  (Insert ones
+		 * that don't above this check.)  So at this stage optname
+		 * contains the CMD part and optarg contains the ARG part.
+		 */
+		if (!optarg || !*optarg) {
+			printk(KERN_ERR "unionfs: all remount options require "
+			       "an argument (%s)\n", optname);
+			err = -EINVAL;
+			goto out_release;
+		}
+
+		if (!strcmp("add", optname)) {
+			err = do_remount_add_option(optarg, new_branches,
+						    tmp_data,
+						    tmp_lower_paths,
+						    &new_high_branch_id);
+			if (err)
+				goto out_release;
+			new_branches++;
+			if (new_branches > UNIONFS_MAX_BRANCHES) {
+				printk(KERN_ERR "unionfs: command exceeds "
+				       "%d branches\n", UNIONFS_MAX_BRANCHES);
+				err = -E2BIG;
+				goto out_release;
+			}
+			continue;
+		}
+		if (!strcmp("del", optname)) {
+			err = do_remount_del_option(optarg, new_branches,
+						    tmp_data,
+						    tmp_lower_paths);
+			if (err)
+				goto out_release;
+			new_branches--;
+			continue;
+		}
+		if (!strcmp("mode", optname)) {
+			err = do_remount_mode_option(optarg, new_branches,
+						     tmp_data,
+						     tmp_lower_paths);
+			if (err)
+				goto out_release;
+			continue;
+		}
+
+		/*
+		 * When you use "mount -o remount,ro", mount(8) will
+		 * reportedly pass the original dirs= string from
+		 * /proc/mounts.  So for now, we have to ignore dirs= and
+		 * not consider it an error, unless we want to allow users
+		 * to pass dirs= in remount.  Note that to allow the VFS to
+		 * actually process the ro/rw remount options, we have to
+		 * return 0 from this function.
+		 */
+		if (!strcmp("dirs", optname)) {
+			printk(KERN_WARNING
+			       "unionfs: remount ignoring option \"%s\"\n",
+			       optname);
+			continue;
+		}
+
+		err = -EINVAL;
+		printk(KERN_ERR
+		       "unionfs: unrecognized option \"%s\"\n", optname);
+		goto out_release;
+	}
+
+out_no_change:
+
+	/******************************************************************
+	 * WE'RE ALMOST DONE: check if leftmost branch might be read-only,
+	 * see if we need to allocate a small-sized new vector, copy the
+	 * vectors to their correct place, release the refcnt of the older
+	 * ones, and return.  Also handle invalidating any pages that will
+	 * have to be re-read.
+	 *******************************************************************/
+
+	if (!(tmp_data[0].branchperms & MAY_WRITE)) {
+		printk(KERN_ERR "unionfs: leftmost branch cannot be read-only "
+		       "(use \"remount,ro\" to create a read-only union)\n");
+		err = -EINVAL;
+		goto out_release;
+	}
+
+	/* (re)allocate space for new pointers to lower dentry */
+	size = new_branches * sizeof(struct unionfs_data);
+	new_data = krealloc(tmp_data, size, GFP_KERNEL);
+	if (unlikely(!new_data)) {
+		err = -ENOMEM;
+		goto out_release;
+	}
+
+	/* allocate space for new pointers to lower paths */
+	size = new_branches * sizeof(struct path);
+	new_lower_paths = krealloc(tmp_lower_paths, size, GFP_KERNEL);
+	if (unlikely(!new_lower_paths)) {
+		err = -ENOMEM;
+		goto out_release;
+	}
+
+	/* allocate space for new pointers to lower inodes */
+	new_lower_inodes = kcalloc(new_branches,
+				   sizeof(struct inode *), GFP_KERNEL);
+	if (unlikely(!new_lower_inodes)) {
+		err = -ENOMEM;
+		goto out_release;
+	}
+
+	/*
+	 * OK, just before we actually put the new set of branches in place,
+	 * we need to ensure that our own f/s has no dirty objects left.
+	 * Luckily, do_remount_sb() already calls shrink_dcache_sb(sb) and
+	 * fsync_super(sb), taking care of dentries, inodes, and dirty
+	 * pages.  So all that's left is for us to invalidate any leftover
+	 * (non-dirty) pages to ensure that they will be re-read from the
+	 * new lower branches (and to support mmap).
+	 */
+
+	/*
+	 * Once we finish the remounting successfully, our superblock
+	 * generation number will have increased.  This will be detected by
+	 * our dentry-revalidation code upon subsequent f/s operations
+	 * through unionfs.  The revalidation code will rebuild the union of
+	 * lower inodes for a given unionfs inode and invalidate any pages
+	 * of such "stale" inodes (by calling our purge_inode_data
+	 * function).  This revalidation will happen lazily and
+	 * incrementally, as users perform operations on cached inodes.  We
+	 * would like to encourage this revalidation to happen sooner if
+	 * possible, so we like to try to invalidate as many other pages in
+	 * our superblock as we can.  We used to call drop_pagecache_sb() or
+	 * a variant thereof, but either method was racy (drop_caches alone
+	 * is known to be racy).  So now we let the revalidation happen on a
+	 * per file basis in ->d_revalidate.
+	 */
+
+	/* grab new lower super references; release old ones */
+	for (i = 0; i < new_branches; i++)
+		atomic_inc(&new_data[i].sb->s_active);
+	for (i = 0; i < sbmax(sb); i++)
+		atomic_dec(&UNIONFS_SB(sb)->data[i].sb->s_active);
+
+	/* copy new vectors into their correct place */
+	tmp_data = UNIONFS_SB(sb)->data;
+	UNIONFS_SB(sb)->data = new_data;
+	new_data = NULL;	/* so don't free good pointers below */
+	tmp_lower_paths = UNIONFS_D(sb->s_root)->lower_paths;
+	UNIONFS_D(sb->s_root)->lower_paths = new_lower_paths;
+	new_lower_paths = NULL;	/* so don't free good pointers below */
+
+	/* update our unionfs_sb_info and root dentry index of last branch */
+	i = sbmax(sb);		/* save no. of branches to release at end */
+	sbend(sb) = new_branches - 1;
+	dbend(sb->s_root) = new_branches - 1;
+	old_ibstart = ibstart(sb->s_root->d_inode);
+	old_ibend = ibend(sb->s_root->d_inode);
+	ibend(sb->s_root->d_inode) = new_branches - 1;
+	UNIONFS_D(sb->s_root)->bcount = new_branches;
+	new_branches = i; /* no. of branches to release below */
+
+	/*
+	 * Update lower inodes: 3 steps
+	 * 1. grab ref on all new lower inodes
+	 */
+	for (i = dbstart(sb->s_root); i <= dbend(sb->s_root); i++) {
+		struct dentry *lower_dentry =
+			unionfs_lower_dentry_idx(sb->s_root, i);
+		igrab(lower_dentry->d_inode);
+		new_lower_inodes[i] = lower_dentry->d_inode;
+	}
+	/* 2. release reference on all older lower inodes */
+	iput_lowers(sb->s_root->d_inode, old_ibstart, old_ibend, true);
+	/* 3. update root dentry's inode to new lower_inodes array */
+	UNIONFS_I(sb->s_root->d_inode)->lower_inodes = new_lower_inodes;
+	new_lower_inodes = NULL;
+
+	/* maxbytes may have changed */
+	sb->s_maxbytes = unionfs_lower_super_idx(sb, 0)->s_maxbytes;
+	/* update high branch ID */
+	sbhbid(sb) = new_high_branch_id;
+
+	/* update our sb->generation for revalidating objects */
+	i = atomic_inc_return(&UNIONFS_SB(sb)->generation);
+	atomic_set(&UNIONFS_D(sb->s_root)->generation, i);
+	atomic_set(&UNIONFS_I(sb->s_root->d_inode)->generation, i);
+	if (!(*flags & MS_SILENT))
+		pr_info("unionfs: %s: new generation number %d\n",
+			UNIONFS_SB(sb)->dev_name, i);
+	/* finally, update the root dentry's times */
+	unionfs_copy_attr_times(sb->s_root->d_inode);
+	err = 0;		/* reset to success */
+
+	/*
+	 * The code above falls through to the next label, and releases the
+	 * refcnts of the older ones (stored in tmp_*): if we fell through
+	 * here, it means success.  However, if we jump directly to this
+	 * label from any error above, then an error occurred after we
+	 * grabbed various refcnts, and so we have to release the
+	 * temporarily constructed structures.
+	 */
+out_release:
+	/* no need to cleanup/release anything in tmp_data */
+	if (tmp_lower_paths)
+		for (i = 0; i < new_branches; i++)
+			path_put(&tmp_lower_paths[i]);
+out_free:
+	kfree(tmp_lower_paths);
+	kfree(tmp_data);
+	kfree(new_lower_paths);
+	kfree(new_data);
+	kfree(new_lower_inodes);
+out_error:
+	unionfs_check_dentry(sb->s_root);
+	unionfs_write_unlock(sb);
+	return err;
+}
+
+/*
+ * Called by iput() when the inode reference count reached zero
+ * and the inode is not hashed anywhere.  Used to clear anything
+ * that needs to be, before the inode is completely destroyed and put
+ * on the inode free list.
+ *
+ * No need to lock sb info's rwsem.
+ */
+static void unionfs_evict_inode(struct inode *inode)
+{
+	int bindex, bstart, bend;
+	struct inode *lower_inode;
+	struct list_head *pos, *n;
+	struct unionfs_dir_state *rdstate;
+
+	truncate_inode_pages(&inode->i_data, 0);
+	clear_inode(inode);
+
+	list_for_each_safe(pos, n, &UNIONFS_I(inode)->readdircache) {
+		rdstate = list_entry(pos, struct unionfs_dir_state, cache);
+		list_del(&rdstate->cache);
+		free_rdstate(rdstate);
+	}
+
+	/*
+	 * Decrement a reference to a lower_inode, which was incremented
+	 * by our read_inode when it was created initially.
+	 */
+	bstart = ibstart(inode);
+	bend = ibend(inode);
+	if (bstart >= 0) {
+		for (bindex = bstart; bindex <= bend; bindex++) {
+			lower_inode = unionfs_lower_inode_idx(inode, bindex);
+			if (!lower_inode)
+				continue;
+			unionfs_set_lower_inode_idx(inode, bindex, NULL);
+			/* see Documentation/filesystems/unionfs/issues.txt */
+			lockdep_off();
+			iput(lower_inode);
+			lockdep_on();
+		}
+	}
+
+	kfree(UNIONFS_I(inode)->lower_inodes);
+	UNIONFS_I(inode)->lower_inodes = NULL;
+}
+
+static struct inode *unionfs_alloc_inode(struct super_block *sb)
+{
+	struct unionfs_inode_info *i;
+
+	i = kmem_cache_alloc(unionfs_inode_cachep, GFP_KERNEL);
+	if (unlikely(!i))
+		return NULL;
+
+	/* memset everything up to the inode to 0 */
+	memset(i, 0, offsetof(struct unionfs_inode_info, vfs_inode));
+
+	i->vfs_inode.i_version = 1;
+	return &i->vfs_inode;
+}
+
+static void unionfs_destroy_inode(struct inode *inode)
+{
+	kmem_cache_free(unionfs_inode_cachep, UNIONFS_I(inode));
+}
+
+/* unionfs inode cache constructor */
+static void init_once(void *obj)
+{
+	struct unionfs_inode_info *i = obj;
+
+	inode_init_once(&i->vfs_inode);
+}
+
+int unionfs_init_inode_cache(void)
+{
+	int err = 0;
+
+	unionfs_inode_cachep =
+		kmem_cache_create("unionfs_inode_cache",
+				  sizeof(struct unionfs_inode_info), 0,
+				  SLAB_RECLAIM_ACCOUNT, init_once);
+	if (unlikely(!unionfs_inode_cachep))
+		err = -ENOMEM;
+	return err;
+}
+
+/* unionfs inode cache destructor */
+void unionfs_destroy_inode_cache(void)
+{
+	if (unionfs_inode_cachep)
+		kmem_cache_destroy(unionfs_inode_cachep);
+}
+
+/*
+ * Called when we have a dirty inode, right here we only throw out
+ * parts of our readdir list that are too old.
+ *
+ * No need to grab sb info's rwsem.
+ */
+static int unionfs_write_inode(struct inode *inode,
+			       struct writeback_control *wbc)
+{
+	struct list_head *pos, *n;
+	struct unionfs_dir_state *rdstate;
+
+	spin_lock(&UNIONFS_I(inode)->rdlock);
+	list_for_each_safe(pos, n, &UNIONFS_I(inode)->readdircache) {
+		rdstate = list_entry(pos, struct unionfs_dir_state, cache);
+		/* We keep this list in LRU order. */
+		if ((rdstate->access + RDCACHE_JIFFIES) > jiffies)
+			break;
+		UNIONFS_I(inode)->rdcount--;
+		list_del(&rdstate->cache);
+		free_rdstate(rdstate);
+	}
+	spin_unlock(&UNIONFS_I(inode)->rdlock);
+
+	return 0;
+}
+
+/*
+ * Used only in nfs, to kill any pending RPC tasks, so that subsequent
+ * code can actually succeed and won't leave tasks that need handling.
+ */
+static void unionfs_umount_begin(struct super_block *sb)
+{
+	struct super_block *lower_sb;
+	int bindex, bstart, bend;
+
+	unionfs_read_lock(sb, UNIONFS_SMUTEX_CHILD);
+
+	bstart = sbstart(sb);
+	bend = sbend(sb);
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_sb = unionfs_lower_super_idx(sb, bindex);
+
+		if (lower_sb && lower_sb->s_op &&
+		    lower_sb->s_op->umount_begin)
+			lower_sb->s_op->umount_begin(lower_sb);
+	}
+
+	unionfs_read_unlock(sb);
+}
+
+static int unionfs_show_options(struct seq_file *m, struct dentry *root)
+{
+	struct super_block *sb = root->d_sb;
+	int ret = 0;
+	char *tmp_page;
+	char *path;
+	int bindex, bstart, bend;
+	int perms;
+
+	/* to prevent a silly lockdep warning with namespace_sem */
+	lockdep_off();
+	unionfs_read_lock(sb, UNIONFS_SMUTEX_CHILD);
+	unionfs_lock_dentry(sb->s_root, UNIONFS_DMUTEX_CHILD);
+
+	tmp_page = (char *) __get_free_page(GFP_KERNEL);
+	if (unlikely(!tmp_page)) {
+		ret = -ENOMEM;
+		goto out;
+	}
+
+	bstart = sbstart(sb);
+	bend = sbend(sb);
+
+	seq_printf(m, ",dirs=");
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		struct path p;
+		p.dentry = unionfs_lower_dentry_idx(sb->s_root, bindex);
+		p.mnt = unionfs_lower_mnt_idx(sb->s_root, bindex);
+		path = d_path(&p, tmp_page, PAGE_SIZE);
+		if (IS_ERR(path)) {
+			ret = PTR_ERR(path);
+			goto out;
+		}
+
+		perms = branchperms(sb, bindex);
+
+		seq_printf(m, "%s=%s", path,
+			   perms & MAY_WRITE ? "rw" : "ro");
+		if (bindex != bend)
+			seq_printf(m, ":");
+	}
+
+out:
+	free_page((unsigned long) tmp_page);
+
+	unionfs_unlock_dentry(sb->s_root);
+	unionfs_read_unlock(sb);
+	lockdep_on();
+
+	return ret;
+}
+
+struct super_operations unionfs_sops = {
+	.put_super	= unionfs_put_super,
+	.statfs		= unionfs_statfs,
+	.remount_fs	= unionfs_remount_fs,
+	.evict_inode	= unionfs_evict_inode,
+	.umount_begin	= unionfs_umount_begin,
+	.show_options	= unionfs_show_options,
+	.write_inode	= unionfs_write_inode,
+	.alloc_inode	= unionfs_alloc_inode,
+	.destroy_inode	= unionfs_destroy_inode,
+};
diff --git a/fs/unionfs/union.h b/fs/unionfs/union.h
new file mode 100644
index 00000000..39f122a
--- /dev/null
+++ b/fs/unionfs/union.h
@@ -0,0 +1,669 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#ifndef _UNION_H_
+#define _UNION_H_
+
+#include <linux/dcache.h>
+#include <linux/file.h>
+#include <linux/list.h>
+#include <linux/fs.h>
+#include <linux/aio.h>
+#include <linux/mm.h>
+#include <linux/module.h>
+#include <linux/mount.h>
+#include <linux/namei.h>
+#include <linux/page-flags.h>
+#include <linux/pagemap.h>
+#include <linux/poll.h>
+#include <linux/security.h>
+#include <linux/seq_file.h>
+#include <linux/slab.h>
+#include <linux/spinlock.h>
+#include <linux/statfs.h>
+#include <linux/string.h>
+#include <linux/vmalloc.h>
+#include <linux/writeback.h>
+#include <linux/buffer_head.h>
+#include <linux/xattr.h>
+#include <linux/fs_stack.h>
+#include <linux/magic.h>
+#include <linux/log2.h>
+#include <linux/poison.h>
+#include <linux/mman.h>
+#include <linux/backing-dev.h>
+#include <linux/splice.h>
+#include <linux/sched.h>
+
+#include <linux/union_fs.h>
+
+/* the file system name */
+#define UNIONFS_NAME "unionfs"
+
+/* unionfs root inode number */
+#define UNIONFS_ROOT_INO     1
+
+/* number of times we try to get a unique temporary file name */
+#define GET_TMPNAM_MAX_RETRY	5
+
+/* maximum number of branches we support, to avoid memory blowup */
+#define UNIONFS_MAX_BRANCHES	128
+
+/* minimum time (seconds) required for time-based cache-coherency */
+#define UNIONFS_MIN_CC_TIME	3
+
+/* Operations vectors defined in specific files. */
+extern struct file_operations unionfs_main_fops;
+extern struct file_operations unionfs_dir_fops;
+extern struct inode_operations unionfs_main_iops;
+extern struct inode_operations unionfs_dir_iops;
+extern struct inode_operations unionfs_symlink_iops;
+extern struct super_operations unionfs_sops;
+extern struct dentry_operations unionfs_dops;
+extern struct address_space_operations unionfs_aops, unionfs_dummy_aops;
+extern struct vm_operations_struct unionfs_vm_ops;
+
+/* How long should an entry be allowed to persist */
+#define RDCACHE_JIFFIES	(5*HZ)
+
+/* compatibility with Real-Time patches */
+#ifdef CONFIG_PREEMPT_RT
+# define unionfs_rw_semaphore	compat_rw_semaphore
+#else /* not CONFIG_PREEMPT_RT */
+# define unionfs_rw_semaphore	rw_semaphore
+#endif /* not CONFIG_PREEMPT_RT */
+
+/* file private data. */
+struct unionfs_file_info {
+	int bstart;
+	int bend;
+	atomic_t generation;
+
+	struct unionfs_dir_state *rdstate;
+	struct file **lower_files;
+	int *saved_branch_ids; /* IDs of branches when file was opened */
+	const struct vm_operations_struct *lower_vm_ops;
+	bool wrote_to_file;	/* for delayed copyup */
+};
+
+/* unionfs inode data in memory */
+struct unionfs_inode_info {
+	int bstart;
+	int bend;
+	atomic_t generation;
+	/* Stuff for readdir over NFS. */
+	spinlock_t rdlock;
+	struct list_head readdircache;
+	int rdcount;
+	int hashsize;
+	int cookie;
+
+	/* The lower inodes */
+	struct inode **lower_inodes;
+
+	struct inode vfs_inode;
+};
+
+/* unionfs dentry data in memory */
+struct unionfs_dentry_info {
+	/*
+	 * The semaphore is used to lock the dentry as soon as we get into a
+	 * unionfs function from the VFS.  Our lock ordering is that children
+	 * go before their parents.
+	 */
+	struct mutex lock;
+	int bstart;
+	int bend;
+	int bopaque;
+	int bcount;
+	atomic_t generation;
+	struct path *lower_paths;
+};
+
+/* These are the pointers to our various objects. */
+struct unionfs_data {
+	struct super_block *sb;	/* lower super_block */
+	atomic_t open_files;	/* number of open files on branch */
+	int branchperms;
+	int branch_id;		/* unique branch ID at re/mount time */
+};
+
+/* unionfs super-block data in memory */
+struct unionfs_sb_info {
+	int bend;
+
+	atomic_t generation;
+
+	/*
+	 * This rwsem is used to make sure that a branch management
+	 * operation...
+	 *   1) will not begin before all currently in-flight operations
+	 *      complete.
+	 *   2) any new operations do not execute until the currently
+	 *      running branch management operation completes.
+	 *
+	 * The write_lock_owner records the PID of the task which grabbed
+	 * the rw_sem for writing.  If the same task also tries to grab the
+	 * read lock, we allow it.  This prevents a self-deadlock when
+	 * branch-management is used on a pivot_root'ed union, because we
+	 * have to ->lookup paths which belong to the same union.
+	 */
+	struct unionfs_rw_semaphore rwsem;
+	pid_t write_lock_owner;	/* PID of rw_sem owner (write lock) */
+	int high_branch_id;	/* last unique branch ID given */
+	char *dev_name;		/* to identify different unions in pr_debug */
+	struct unionfs_data *data;
+};
+
+/*
+ * structure for making the linked list of entries by readdir on left branch
+ * to compare with entries on right branch
+ */
+struct filldir_node {
+	struct list_head file_list;	/* list for directory entries */
+	char *name;		/* name entry */
+	int hash;		/* name hash */
+	int namelen;		/* name len since name is not 0 terminated */
+
+	/*
+	 * we can check for duplicate whiteouts and files in the same branch
+	 * in order to return -EIO.
+	 */
+	int bindex;
+
+	/* is this a whiteout entry? */
+	int whiteout;
+
+	/* Inline name, so we don't need to separately kmalloc small ones */
+	char iname[DNAME_INLINE_LEN];
+};
+
+/* Directory hash table. */
+struct unionfs_dir_state {
+	unsigned int cookie;	/* the cookie, based off of rdversion */
+	unsigned int offset;	/* The entry we have returned. */
+	int bindex;
+	loff_t dirpos;		/* offset within the lower level directory */
+	int size;		/* How big is the hash table? */
+	int hashentries;	/* How many entries have been inserted? */
+	unsigned long access;
+
+	/* This cache list is used when the inode keeps us around. */
+	struct list_head cache;
+	struct list_head list[0];
+};
+
+/* externs needed for fanout.h or sioq.h */
+extern int unionfs_get_nlinks(const struct inode *inode);
+extern void unionfs_copy_attr_times(struct inode *upper);
+extern void unionfs_copy_attr_all(struct inode *dest, const struct inode *src);
+
+/* include miscellaneous macros */
+#include "fanout.h"
+#include "sioq.h"
+
+/* externs for cache creation/deletion routines */
+extern void unionfs_destroy_filldir_cache(void);
+extern int unionfs_init_filldir_cache(void);
+extern int unionfs_init_inode_cache(void);
+extern void unionfs_destroy_inode_cache(void);
+extern int unionfs_init_dentry_cache(void);
+extern void unionfs_destroy_dentry_cache(void);
+
+/* Initialize and free readdir-specific  state. */
+extern int init_rdstate(struct file *file);
+extern struct unionfs_dir_state *alloc_rdstate(struct inode *inode,
+					       int bindex);
+extern struct unionfs_dir_state *find_rdstate(struct inode *inode,
+					      loff_t fpos);
+extern void free_rdstate(struct unionfs_dir_state *state);
+extern int add_filldir_node(struct unionfs_dir_state *rdstate,
+			    const char *name, int namelen, int bindex,
+			    int whiteout);
+extern struct filldir_node *find_filldir_node(struct unionfs_dir_state *rdstate,
+					      const char *name, int namelen,
+					      int is_whiteout);
+
+extern struct dentry **alloc_new_dentries(int objs);
+extern struct unionfs_data *alloc_new_data(int objs);
+
+/* We can only use 32-bits of offset for rdstate --- blech! */
+#define DIREOF (0xfffff)
+#define RDOFFBITS 20		/* This is the number of bits in DIREOF. */
+#define MAXRDCOOKIE (0xfff)
+/* Turn an rdstate into an offset. */
+static inline off_t rdstate2offset(struct unionfs_dir_state *buf)
+{
+	off_t tmp;
+
+	tmp = ((buf->cookie & MAXRDCOOKIE) << RDOFFBITS)
+		| (buf->offset & DIREOF);
+	return tmp;
+}
+
+/* Macros for locking a super_block. */
+enum unionfs_super_lock_class {
+	UNIONFS_SMUTEX_NORMAL,
+	UNIONFS_SMUTEX_PARENT,	/* when locking on behalf of file */
+	UNIONFS_SMUTEX_CHILD,	/* when locking on behalf of dentry */
+};
+static inline void unionfs_read_lock(struct super_block *sb, int subclass)
+{
+	if (UNIONFS_SB(sb)->write_lock_owner &&
+	    UNIONFS_SB(sb)->write_lock_owner == current->pid)
+		return;
+	down_read_nested(&UNIONFS_SB(sb)->rwsem, subclass);
+}
+static inline void unionfs_read_unlock(struct super_block *sb)
+{
+	if (UNIONFS_SB(sb)->write_lock_owner &&
+	    UNIONFS_SB(sb)->write_lock_owner == current->pid)
+		return;
+	up_read(&UNIONFS_SB(sb)->rwsem);
+}
+static inline void unionfs_write_lock(struct super_block *sb)
+{
+	down_write(&UNIONFS_SB(sb)->rwsem);
+	UNIONFS_SB(sb)->write_lock_owner = current->pid;
+}
+static inline void unionfs_write_unlock(struct super_block *sb)
+{
+	up_write(&UNIONFS_SB(sb)->rwsem);
+	UNIONFS_SB(sb)->write_lock_owner = 0;
+}
+
+static inline void unionfs_double_lock_dentry(struct dentry *d1,
+					      struct dentry *d2)
+{
+	BUG_ON(d1 == d2);
+	if (d1 < d2) {
+		unionfs_lock_dentry(d1, UNIONFS_DMUTEX_PARENT);
+		unionfs_lock_dentry(d2, UNIONFS_DMUTEX_CHILD);
+	} else {
+		unionfs_lock_dentry(d2, UNIONFS_DMUTEX_PARENT);
+		unionfs_lock_dentry(d1, UNIONFS_DMUTEX_CHILD);
+	}
+}
+
+static inline void unionfs_double_unlock_dentry(struct dentry *d1,
+						struct dentry *d2)
+{
+	BUG_ON(d1 == d2);
+	if (d1 < d2) { /* unlock in reverse order than double_lock_dentry */
+		unionfs_unlock_dentry(d1);
+		unionfs_unlock_dentry(d2);
+	} else {
+		unionfs_unlock_dentry(d2);
+		unionfs_unlock_dentry(d1);
+	}
+}
+
+static inline void unionfs_double_lock_parents(struct dentry *p1,
+					       struct dentry *p2)
+{
+	if (p1 == p2) {
+		unionfs_lock_dentry(p1, UNIONFS_DMUTEX_REVAL_PARENT);
+		return;
+	}
+	if (p1 < p2) {
+		unionfs_lock_dentry(p1, UNIONFS_DMUTEX_REVAL_PARENT);
+		unionfs_lock_dentry(p2, UNIONFS_DMUTEX_REVAL_CHILD);
+	} else {
+		unionfs_lock_dentry(p2, UNIONFS_DMUTEX_REVAL_PARENT);
+		unionfs_lock_dentry(p1, UNIONFS_DMUTEX_REVAL_CHILD);
+	}
+}
+
+static inline void unionfs_double_unlock_parents(struct dentry *p1,
+						 struct dentry *p2)
+{
+	if (p1 == p2) {
+		unionfs_unlock_dentry(p1);
+		return;
+	}
+	if (p1 < p2) { /* unlock in reverse order of double_lock_parents */
+		unionfs_unlock_dentry(p1);
+		unionfs_unlock_dentry(p2);
+	} else {
+		unionfs_unlock_dentry(p2);
+		unionfs_unlock_dentry(p1);
+	}
+}
+
+extern int new_dentry_private_data(struct dentry *dentry, int subclass);
+extern int realloc_dentry_private_data(struct dentry *dentry);
+extern void free_dentry_private_data(struct dentry *dentry);
+extern void update_bstart(struct dentry *dentry);
+
+/*
+ * EXTERNALS:
+ */
+
+/* replicates the directory structure up to given dentry in given branch */
+extern struct dentry *create_parents(struct inode *dir, struct dentry *dentry,
+				     const char *name, int bindex);
+
+/* partial lookup */
+extern int unionfs_partial_lookup(struct dentry *dentry,
+				  struct dentry *parent);
+extern struct dentry *unionfs_lookup_full(struct dentry *dentry,
+					  struct dentry *parent,
+					  int lookupmode);
+
+/* copies a file from dbstart to newbindex branch */
+extern int copyup_file(struct inode *dir, struct file *file, int bstart,
+		       int newbindex, loff_t size);
+extern int copyup_named_file(struct inode *dir, struct file *file,
+			     char *name, int bstart, int new_bindex,
+			     loff_t len);
+/* copies a dentry from dbstart to newbindex branch */
+extern int copyup_dentry(struct inode *dir, struct dentry *dentry,
+			 int bstart, int new_bindex, const char *name,
+			 int namelen, struct file **copyup_file, loff_t len);
+/* helper functions for post-copyup actions */
+extern void unionfs_postcopyup_setmnt(struct dentry *dentry);
+extern void unionfs_postcopyup_release(struct dentry *dentry);
+
+/* Is this directory empty: 0 if it is empty, -ENOTEMPTY if not. */
+extern int check_empty(struct dentry *dentry, struct dentry *parent,
+		       struct unionfs_dir_state **namelist);
+/* whiteout and opaque directory helpers */
+extern char *alloc_whname(const char *name, int len);
+extern bool is_whiteout_name(char **namep, int *namelenp);
+extern bool is_validname(const char *name);
+extern struct dentry *lookup_whiteout(const char *name,
+				      struct dentry *lower_parent);
+extern struct dentry *find_first_whiteout(struct dentry *dentry);
+extern int unlink_whiteout(struct dentry *wh_dentry);
+extern int check_unlink_whiteout(struct dentry *dentry,
+				 struct dentry *lower_dentry, int bindex);
+extern int create_whiteout(struct dentry *dentry, int start);
+extern int delete_whiteouts(struct dentry *dentry, int bindex,
+			    struct unionfs_dir_state *namelist);
+extern int is_opaque_dir(struct dentry *dentry, int bindex);
+extern int make_dir_opaque(struct dentry *dir, int bindex);
+extern void unionfs_set_max_namelen(long *namelen);
+
+extern void unionfs_reinterpose(struct dentry *this_dentry);
+extern struct super_block *unionfs_duplicate_super(struct super_block *sb);
+
+/* Locking functions. */
+extern int unionfs_setlk(struct file *file, int cmd, struct file_lock *fl);
+extern int unionfs_getlk(struct file *file, struct file_lock *fl);
+
+/* Common file operations. */
+extern int unionfs_file_revalidate(struct file *file, struct dentry *parent,
+				   bool willwrite);
+extern int unionfs_open(struct inode *inode, struct file *file);
+extern int unionfs_file_release(struct inode *inode, struct file *file);
+extern int unionfs_flush(struct file *file, fl_owner_t id);
+extern long unionfs_ioctl(struct file *file, unsigned int cmd,
+			  unsigned long arg);
+extern int unionfs_fsync(struct file *file, loff_t start, loff_t end,
+			 int datasync);
+extern int unionfs_fasync(int fd, struct file *file, int flag);
+
+/* Inode operations */
+extern struct inode *unionfs_iget(struct super_block *sb, unsigned long ino);
+extern int unionfs_rename(struct inode *old_dir, struct dentry *old_dentry,
+			  struct inode *new_dir, struct dentry *new_dentry);
+extern int unionfs_unlink(struct inode *dir, struct dentry *dentry);
+extern int unionfs_rmdir(struct inode *dir, struct dentry *dentry);
+
+extern bool __unionfs_d_revalidate(struct dentry *dentry,
+				   struct dentry *parent, bool willwrite,
+				   unsigned int flags);
+extern bool is_negative_lower(const struct dentry *dentry);
+extern bool is_newer_lower(const struct dentry *dentry);
+extern void purge_sb_data(struct super_block *sb);
+
+/* The values for unionfs_interpose's flag. */
+#define INTERPOSE_DEFAULT	0
+#define INTERPOSE_LOOKUP	1
+#define INTERPOSE_REVAL		2
+#define INTERPOSE_REVAL_NEG	3
+#define INTERPOSE_PARTIAL	4
+
+extern struct dentry *unionfs_interpose(struct dentry *this_dentry,
+					struct super_block *sb, int flag);
+
+#ifdef CONFIG_UNION_FS_XATTR
+/* Extended attribute functions. */
+extern void *unionfs_xattr_alloc(size_t size, size_t limit);
+static inline void unionfs_xattr_kfree(const void *p)
+{
+	kfree(p);
+}
+extern ssize_t unionfs_getxattr(struct dentry *dentry, const char *name,
+				void *value, size_t size);
+extern int unionfs_removexattr(struct dentry *dentry, const char *name);
+extern ssize_t unionfs_listxattr(struct dentry *dentry, char *list,
+				 size_t size);
+extern int unionfs_setxattr(struct dentry *dentry, const char *name,
+			    const void *value, size_t size, int flags);
+#endif /* CONFIG_UNION_FS_XATTR */
+
+/* The root directory is unhashed, but isn't deleted. */
+static inline int d_deleted(struct dentry *d)
+{
+	return d_unhashed(d) && (d != d->d_sb->s_root);
+}
+
+/* unionfs_permission, check if we should bypass error to facilitate copyup */
+#define IS_COPYUP_ERR(err) ((err) == -EROFS)
+
+/* unionfs_open, check if we need to copyup the file */
+#define OPEN_WRITE_FLAGS (O_WRONLY | O_RDWR | O_APPEND)
+#define IS_WRITE_FLAG(flag) ((flag) & OPEN_WRITE_FLAGS)
+
+static inline int branchperms(const struct super_block *sb, int index)
+{
+	BUG_ON(index < 0);
+	return UNIONFS_SB(sb)->data[index].branchperms;
+}
+
+static inline int set_branchperms(struct super_block *sb, int index, int perms)
+{
+	BUG_ON(index < 0);
+	UNIONFS_SB(sb)->data[index].branchperms = perms;
+	return perms;
+}
+
+/* check if readonly lower inode, but possibly unlinked (no inode->i_sb) */
+static inline int __is_rdonly(const struct inode *inode)
+{
+	/* if unlinked, can't be readonly (?) */
+	if (!inode->i_sb)
+		return 0;
+	return IS_RDONLY(inode);
+
+}
+/* Is this file on a read-only branch? */
+static inline int is_robranch_super(const struct super_block *sb, int index)
+{
+	int ret;
+
+	ret = (!(branchperms(sb, index) & MAY_WRITE)) ? -EROFS : 0;
+	return ret;
+}
+
+/* Is this file on a read-only branch? */
+static inline int is_robranch_idx(const struct dentry *dentry, int index)
+{
+	struct super_block *lower_sb;
+
+	BUG_ON(index < 0);
+
+	if (!(branchperms(dentry->d_sb, index) & MAY_WRITE))
+		return -EROFS;
+
+	lower_sb = unionfs_lower_super_idx(dentry->d_sb, index);
+	BUG_ON(lower_sb == NULL);
+	/*
+	 * test sb flags directly, not IS_RDONLY(lower_inode) because the
+	 * lower_dentry could be a negative.
+	 */
+	if (lower_sb->s_flags & MS_RDONLY)
+		return -EROFS;
+
+	return 0;
+}
+
+static inline int is_robranch(const struct dentry *dentry)
+{
+	int index;
+
+	index = UNIONFS_D(dentry)->bstart;
+	BUG_ON(index < 0);
+
+	return is_robranch_idx(dentry, index);
+}
+
+/*
+ * EXTERNALS:
+ */
+extern int check_branch(const struct path *path);
+extern int parse_branch_mode(const char *name, int *perms);
+
+/* locking helpers */
+static inline struct dentry *lock_parent(struct dentry *dentry)
+{
+	struct dentry *dir = dget_parent(dentry);
+	mutex_lock_nested(&dir->d_inode->i_mutex, I_MUTEX_PARENT);
+	return dir;
+}
+static inline struct dentry *lock_parent_wh(struct dentry *dentry)
+{
+	struct dentry *dir = dget_parent(dentry);
+
+	mutex_lock_nested(&dir->d_inode->i_mutex, UNIONFS_DMUTEX_WHITEOUT);
+	return dir;
+}
+
+static inline void unlock_dir(struct dentry *dir)
+{
+	mutex_unlock(&dir->d_inode->i_mutex);
+	dput(dir);
+}
+
+/* lock base inode mutex before calling lookup_one_len */
+static inline struct dentry *lookup_lck_len(const char *name,
+					    struct dentry *base, int len)
+{
+	struct dentry *d;
+
+	mutex_lock(&base->d_inode->i_mutex);
+	d = lookup_one_len(name, base, len); // XXX: pass flags?
+	mutex_unlock(&base->d_inode->i_mutex);
+
+	return d;
+}
+
+static inline struct vfsmount *unionfs_mntget(struct dentry *dentry,
+					      int bindex)
+{
+	struct vfsmount *mnt;
+
+	BUG_ON(!dentry || bindex < 0);
+
+	mnt = mntget(unionfs_lower_mnt_idx(dentry, bindex));
+#ifdef CONFIG_UNION_FS_DEBUG
+	if (!mnt)
+		pr_debug("unionfs: mntget: mnt=%p bindex=%d\n",
+			 mnt, bindex);
+#endif /* CONFIG_UNION_FS_DEBUG */
+
+	return mnt;
+}
+
+static inline void unionfs_mntput(struct dentry *dentry, int bindex)
+{
+	struct vfsmount *mnt;
+
+	if (!dentry && bindex < 0)
+		return;
+	BUG_ON(!dentry || bindex < 0);
+
+	mnt = unionfs_lower_mnt_idx(dentry, bindex);
+#ifdef CONFIG_UNION_FS_DEBUG
+	/*
+	 * Directories can have NULL lower objects in between start/end, but
+	 * NOT if at the start/end range.  We cannot verify that this dentry
+	 * is a type=DIR, because it may already be a negative dentry.  But
+	 * if dbstart is greater than dbend, we know that this couldn't have
+	 * been a regular file: it had to have been a directory.
+	 */
+	if (!mnt && !(bindex > dbstart(dentry) && bindex < dbend(dentry)))
+		pr_debug("unionfs: mntput: mnt=%p bindex=%d\n", mnt, bindex);
+#endif /* CONFIG_UNION_FS_DEBUG */
+	mntput(mnt);
+}
+
+#ifdef CONFIG_UNION_FS_DEBUG
+
+/* useful for tracking code reachability */
+#define UDBG pr_debug("DBG:%s:%s:%d\n", __FILE__, __func__, __LINE__)
+
+#define unionfs_check_inode(i)	__unionfs_check_inode((i),	\
+	__FILE__, __func__, __LINE__)
+#define unionfs_check_dentry(d)	__unionfs_check_dentry((d),	\
+	__FILE__, __func__, __LINE__)
+#define unionfs_check_file(f)	__unionfs_check_file((f),	\
+	__FILE__, __func__, __LINE__)
+#define unionfs_check_nd(n)	__unionfs_check_nd((n),		\
+	__FILE__, __func__, __LINE__)
+#define show_branch_counts(sb)	__show_branch_counts((sb),	\
+	__FILE__, __func__, __LINE__)
+#define show_inode_times(i)	__show_inode_times((i),		\
+	__FILE__, __func__, __LINE__)
+#define show_dinode_times(d)	__show_dinode_times((d),	\
+	__FILE__, __func__, __LINE__)
+#define show_inode_counts(i)	__show_inode_counts((i),	\
+	__FILE__, __func__, __LINE__)
+
+extern void __unionfs_check_inode(const struct inode *inode, const char *fname,
+				  const char *fxn, int line);
+extern void __unionfs_check_dentry(const struct dentry *dentry,
+				   const char *fname, const char *fxn,
+				   int line);
+extern void __unionfs_check_file(const struct file *file,
+				 const char *fname, const char *fxn, int line);
+extern void __show_branch_counts(const struct super_block *sb,
+				 const char *file, const char *fxn, int line);
+extern void __show_inode_times(const struct inode *inode,
+			       const char *file, const char *fxn, int line);
+extern void __show_dinode_times(const struct dentry *dentry,
+				const char *file, const char *fxn, int line);
+extern void __show_inode_counts(const struct inode *inode,
+				const char *file, const char *fxn, int line);
+
+#else /* not CONFIG_UNION_FS_DEBUG */
+
+/* we leave useful hooks for these check functions throughout the code */
+#define unionfs_check_inode(i)		do { } while (0)
+#define unionfs_check_dentry(d)		do { } while (0)
+#define unionfs_check_file(f)		do { } while (0)
+#define unionfs_check_nd(n)		do { } while (0)
+#define show_branch_counts(sb)		do { } while (0)
+#define show_inode_times(i)		do { } while (0)
+#define show_dinode_times(d)		do { } while (0)
+#define show_inode_counts(i)		do { } while (0)
+#define UDBG				do { } while (0)
+
+#endif /* not CONFIG_UNION_FS_DEBUG */
+
+#endif	/* not _UNION_H_ */
diff --git a/fs/unionfs/unlink.c b/fs/unionfs/unlink.c
new file mode 100644
index 00000000..bd43fbd
--- /dev/null
+++ b/fs/unionfs/unlink.c
@@ -0,0 +1,278 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * Helper function for Unionfs's unlink operation.
+ *
+ * The main goal of this function is to optimize the unlinking of non-dir
+ * objects in unionfs by deleting all possible lower inode objects from the
+ * underlying branches having same dentry name as the non-dir dentry on
+ * which this unlink operation is called.  This way we delete as many lower
+ * inodes as possible, and save space.  Whiteouts need to be created in
+ * branch0 only if unlinking fails on any of the lower branch other than
+ * branch0, or if a lower branch is marked read-only.
+ *
+ * Also, while unlinking a file, if we encounter any dir type entry in any
+ * intermediate branch, then we remove the directory by calling vfs_rmdir.
+ * The following special cases are also handled:
+
+ * (1) If an error occurs in branch0 during vfs_unlink, then we return
+ *     appropriate error.
+ *
+ * (2) If we get an error during unlink in any of other lower branch other
+ *     than branch0, then we create a whiteout in branch0.
+ *
+ * (3) If a whiteout already exists in any intermediate branch, we delete
+ *     all possible inodes only up to that branch (this is an "opaqueness"
+ *     as as per Documentation/filesystems/unionfs/concepts.txt).
+ *
+ */
+static int unionfs_unlink_whiteout(struct inode *dir, struct dentry *dentry,
+				   struct dentry *parent)
+{
+	struct dentry *lower_dentry;
+	struct dentry *lower_dir_dentry;
+	int bindex;
+	int err = 0;
+
+	err = unionfs_partial_lookup(dentry, parent);
+	if (err)
+		goto out;
+
+	/* trying to unlink all possible valid instances */
+	for (bindex = dbstart(dentry); bindex <= dbend(dentry); bindex++) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+		if (!lower_dentry || !lower_dentry->d_inode)
+			continue;
+
+		lower_dir_dentry = lock_parent(lower_dentry);
+
+		/* avoid destroying the lower inode if the object is in use */
+		dget(lower_dentry);
+		err = is_robranch_super(dentry->d_sb, bindex);
+		if (!err) {
+			/* see Documentation/filesystems/unionfs/issues.txt */
+			lockdep_off();
+			if (!S_ISDIR(lower_dentry->d_inode->i_mode))
+				err = vfs_unlink(lower_dir_dentry->d_inode,
+								lower_dentry);
+			else
+				err = vfs_rmdir(lower_dir_dentry->d_inode,
+								lower_dentry);
+			lockdep_on();
+		}
+
+		/* if lower object deletion succeeds, update inode's times */
+		if (!err)
+			unionfs_copy_attr_times(dentry->d_inode);
+		dput(lower_dentry);
+		fsstack_copy_attr_times(dir, lower_dir_dentry->d_inode);
+		unlock_dir(lower_dir_dentry);
+
+		if (err)
+			break;
+	}
+
+	/*
+	 * Create the whiteout in branch 0 (highest priority) only if (a)
+	 * there was an error in any intermediate branch other than branch 0
+	 * due to failure of vfs_unlink/vfs_rmdir or (b) a branch marked or
+	 * mounted read-only.
+	 */
+	if (err) {
+		if ((bindex == 0) ||
+		    ((bindex == dbstart(dentry)) &&
+		     (!IS_COPYUP_ERR(err))))
+			goto out;
+		else {
+			if (!IS_COPYUP_ERR(err))
+				pr_debug("unionfs: lower object deletion "
+					     "failed in branch:%d\n", bindex);
+			err = create_whiteout(dentry, sbstart(dentry->d_sb));
+		}
+	}
+
+out:
+	if (!err)
+		inode_dec_link_count(dentry->d_inode);
+
+	/* We don't want to leave negative leftover dentries for revalidate. */
+	if (!err && (dbopaque(dentry) != -1))
+		update_bstart(dentry);
+
+	return err;
+}
+
+int unionfs_unlink(struct inode *dir, struct dentry *dentry)
+{
+	int err = 0;
+	struct inode *inode = dentry->d_inode;
+	struct dentry *parent;
+	int valid;
+
+	BUG_ON(S_ISDIR(inode->i_mode));
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+	unionfs_check_dentry(dentry);
+
+	err = unionfs_unlink_whiteout(dir, dentry, parent);
+	/* call d_drop so the system "forgets" about us */
+	if (!err) {
+		unionfs_postcopyup_release(dentry);
+		unionfs_postcopyup_setmnt(parent);
+		if (inode->i_nlink == 0) /* drop lower inodes */
+			iput_lowers_all(inode, false);
+		d_drop(dentry);
+		/*
+		 * if unlink/whiteout succeeded, parent dir mtime has
+		 * changed
+		 */
+		unionfs_copy_attr_times(dir);
+	}
+
+out:
+	if (!err) {
+		unionfs_check_dentry(dentry);
+		unionfs_check_inode(dir);
+	}
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+static int unionfs_rmdir_first(struct inode *dir, struct dentry *dentry,
+			       struct unionfs_dir_state *namelist)
+{
+	int err;
+	struct dentry *lower_dentry;
+	struct dentry *lower_dir_dentry = NULL;
+
+	/* Here we need to remove whiteout entries. */
+	err = delete_whiteouts(dentry, dbstart(dentry), namelist);
+	if (err)
+		goto out;
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	lower_dir_dentry = lock_parent(lower_dentry);
+
+	/* avoid destroying the lower inode if the file is in use */
+	dget(lower_dentry);
+	err = is_robranch(dentry);
+	if (!err)
+		err = vfs_rmdir(lower_dir_dentry->d_inode, lower_dentry);
+	dput(lower_dentry);
+
+	fsstack_copy_attr_times(dir, lower_dir_dentry->d_inode);
+	/* propagate number of hard-links */
+	set_nlink(dentry->d_inode, unionfs_get_nlinks(dentry->d_inode));
+
+out:
+	if (lower_dir_dentry)
+		unlock_dir(lower_dir_dentry);
+	return err;
+}
+
+int unionfs_rmdir(struct inode *dir, struct dentry *dentry)
+{
+	int err = 0;
+	struct unionfs_dir_state *namelist = NULL;
+	struct dentry *parent;
+	int dstart, dend;
+	bool valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+	unionfs_check_dentry(dentry);
+
+	/* check if this unionfs directory is empty or not */
+	err = check_empty(dentry, parent, &namelist);
+	if (err)
+		goto out;
+
+	err = unionfs_rmdir_first(dir, dentry, namelist);
+	dstart = dbstart(dentry);
+	dend = dbend(dentry);
+	/*
+	 * We create a whiteout for the directory if there was an error to
+	 * rmdir the first directory entry in the union.  Otherwise, we
+	 * create a whiteout only if there is no chance that a lower
+	 * priority branch might also have the same named directory.  IOW,
+	 * if there is not another same-named directory at a lower priority
+	 * branch, then we don't need to create a whiteout for it.
+	 */
+	if (!err) {
+		if (dstart < dend)
+			err = create_whiteout(dentry, dstart);
+	} else {
+		int new_err;
+
+		if (dstart == 0)
+			goto out;
+
+		/* exit if the error returned was NOT -EROFS */
+		if (!IS_COPYUP_ERR(err))
+			goto out;
+
+		new_err = create_whiteout(dentry, dstart - 1);
+		if (new_err != -EEXIST)
+			err = new_err;
+	}
+
+out:
+	/*
+	 * Drop references to lower dentry/inode so storage space for them
+	 * can be reclaimed.  Then, call d_drop so the system "forgets"
+	 * about us.
+	 */
+	if (!err) {
+		iput_lowers_all(dentry->d_inode, false);
+		dput(unionfs_lower_dentry_idx(dentry, dstart));
+		unionfs_set_lower_dentry_idx(dentry, dstart, NULL);
+		d_drop(dentry);
+		/* update our lower vfsmnts, in case a copyup took place */
+		unionfs_postcopyup_setmnt(dentry);
+		unionfs_check_dentry(dentry);
+		unionfs_check_inode(dir);
+	}
+
+	if (namelist)
+		free_rdstate(namelist);
+
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
diff --git a/fs/unionfs/whiteout.c b/fs/unionfs/whiteout.c
new file mode 100644
index 00000000..ebb3a91
--- /dev/null
+++ b/fs/unionfs/whiteout.c
@@ -0,0 +1,578 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/*
+ * whiteout and opaque directory helpers
+ */
+
+/* What do we use for whiteouts. */
+#define UNIONFS_WHPFX ".wh."
+#define UNIONFS_WHLEN 4
+/*
+ * If a directory contains this file, then it is opaque.  We start with the
+ * .wh. flag so that it is blocked by lookup.
+ */
+#define UNIONFS_DIR_OPAQUE_NAME "__dir_opaque"
+#define UNIONFS_DIR_OPAQUE UNIONFS_WHPFX UNIONFS_DIR_OPAQUE_NAME
+
+/* construct whiteout filename */
+char *alloc_whname(const char *name, int len)
+{
+	char *buf;
+
+	buf = kmalloc(len + UNIONFS_WHLEN + 1, GFP_KERNEL);
+	if (unlikely(!buf))
+		return ERR_PTR(-ENOMEM);
+
+	strcpy(buf, UNIONFS_WHPFX);
+	strlcat(buf, name, len + UNIONFS_WHLEN + 1);
+
+	return buf;
+}
+
+/*
+ * XXX: this can be inline or CPP macro, but is here to keep all whiteout
+ * code in one place.
+ */
+void unionfs_set_max_namelen(long *namelen)
+{
+	*namelen -= UNIONFS_WHLEN;
+}
+
+/* check if @namep is a whiteout, update @namep and @namelenp accordingly */
+bool is_whiteout_name(char **namep, int *namelenp)
+{
+	if (*namelenp > UNIONFS_WHLEN &&
+	    !strncmp(*namep, UNIONFS_WHPFX, UNIONFS_WHLEN)) {
+		*namep += UNIONFS_WHLEN;
+		*namelenp -= UNIONFS_WHLEN;
+		return true;
+	}
+	return false;
+}
+
+/* is the filename valid == !(whiteout for a file or opaque dir marker) */
+bool is_validname(const char *name)
+{
+	if (!strncmp(name, UNIONFS_WHPFX, UNIONFS_WHLEN))
+		return false;
+	if (!strncmp(name, UNIONFS_DIR_OPAQUE_NAME,
+		     sizeof(UNIONFS_DIR_OPAQUE_NAME) - 1))
+		return false;
+	return true;
+}
+
+/*
+ * Look for a whiteout @name in @lower_parent directory.  If error, return
+ * ERR_PTR.  Caller must dput() the returned dentry if not an error.
+ *
+ * XXX: some callers can reuse the whname allocated buffer to avoid repeated
+ * free then re-malloc calls.  Need to provide a different API for those
+ * callers.
+ */
+struct dentry *lookup_whiteout(const char *name, struct dentry *lower_parent)
+{
+	char *whname = NULL;
+	int err = 0, namelen;
+	struct dentry *wh_dentry = NULL;
+
+	namelen = strlen(name);
+	whname = alloc_whname(name, namelen);
+	if (unlikely(IS_ERR(whname))) {
+		err = PTR_ERR(whname);
+		goto out;
+	}
+
+	/* check if whiteout exists in this branch: lookup .wh.foo */
+	wh_dentry = lookup_lck_len(whname, lower_parent, strlen(whname));
+	if (IS_ERR(wh_dentry)) {
+		err = PTR_ERR(wh_dentry);
+		goto out;
+	}
+
+	/* check if negative dentry (ENOENT) */
+	if (!wh_dentry->d_inode)
+		goto out;
+
+	/* whiteout found: check if valid type */
+	if (!S_ISREG(wh_dentry->d_inode->i_mode)) {
+		printk(KERN_ERR "unionfs: invalid whiteout %s entry type %d\n",
+		       whname, wh_dentry->d_inode->i_mode);
+		dput(wh_dentry);
+		err = -EIO;
+		goto out;
+	}
+
+out:
+	kfree(whname);
+	if (err)
+		wh_dentry = ERR_PTR(err);
+	return wh_dentry;
+}
+
+/* find and return first whiteout in parent directory, else ENOENT */
+struct dentry *find_first_whiteout(struct dentry *dentry)
+{
+	int bindex, bstart, bend;
+	struct dentry *parent, *lower_parent, *wh_dentry;
+
+	parent = dget_parent(dentry);
+
+	bstart = dbstart(parent);
+	bend = dbend(parent);
+	wh_dentry = ERR_PTR(-ENOENT);
+
+	for (bindex = bstart; bindex <= bend; bindex++) {
+		lower_parent = unionfs_lower_dentry_idx(parent, bindex);
+		if (!lower_parent)
+			continue;
+		wh_dentry = lookup_whiteout(dentry->d_name.name, lower_parent);
+		if (IS_ERR(wh_dentry))
+			continue;
+		if (wh_dentry->d_inode)
+			break;
+		dput(wh_dentry);
+		wh_dentry = ERR_PTR(-ENOENT);
+	}
+
+	dput(parent);
+
+	return wh_dentry;
+}
+
+/*
+ * Unlink a whiteout dentry.  Returns 0 or -errno.  Caller must hold and
+ * release dentry reference.
+ */
+int unlink_whiteout(struct dentry *wh_dentry)
+{
+	int err;
+	struct dentry *lower_dir_dentry;
+
+	/* dget and lock parent dentry */
+	lower_dir_dentry = lock_parent_wh(wh_dentry);
+
+	/* see Documentation/filesystems/unionfs/issues.txt */
+	lockdep_off();
+	err = vfs_unlink(lower_dir_dentry->d_inode, wh_dentry);
+	lockdep_on();
+	unlock_dir(lower_dir_dentry);
+
+	/*
+	 * Whiteouts are special files and should be deleted no matter what
+	 * (as if they never existed), in order to allow this create
+	 * operation to succeed.  This is especially important in sticky
+	 * directories: a whiteout may have been created by one user, but
+	 * the newly created file may be created by another user.
+	 * Therefore, in order to maintain Unix semantics, if the vfs_unlink
+	 * above failed, then we have to try to directly unlink the
+	 * whiteout.  Note: in the ODF version of unionfs, whiteout are
+	 * handled much more cleanly.
+	 */
+	if (err == -EPERM) {
+		struct inode *inode = lower_dir_dentry->d_inode;
+		err = inode->i_op->unlink(inode, wh_dentry);
+	}
+	if (err)
+		printk(KERN_ERR "unionfs: could not unlink whiteout %s, "
+		       "err = %d\n", wh_dentry->d_name.name, err);
+
+	return err;
+
+}
+
+/*
+ * Helper function when creating new objects (create, symlink, mknod, etc.).
+ * Checks to see if there's a whiteout in @lower_dentry's parent directory,
+ * whose name is taken from @dentry.  Then tries to remove that whiteout, if
+ * found.  If <dentry,bindex> is a branch marked readonly, return -EROFS.
+ * If it finds both a regular file and a whiteout, delete whiteout (this
+ * should never happen).
+ *
+ * Return 0 if no whiteout was found.  Return 1 if one was found and
+ * successfully removed.  Therefore a value >= 0 tells the caller that
+ * @lower_dentry belongs to a good branch to create the new object in).
+ * Return -ERRNO if an error occurred during whiteout lookup or in trying to
+ * unlink the whiteout.
+ */
+int check_unlink_whiteout(struct dentry *dentry, struct dentry *lower_dentry,
+			  int bindex)
+{
+	int err;
+	struct dentry *wh_dentry = NULL;
+	struct dentry *lower_dir_dentry = NULL;
+
+	/* look for whiteout dentry first */
+	lower_dir_dentry = dget_parent(lower_dentry);
+	wh_dentry = lookup_whiteout(dentry->d_name.name, lower_dir_dentry);
+	dput(lower_dir_dentry);
+	if (IS_ERR(wh_dentry)) {
+		err = PTR_ERR(wh_dentry);
+		goto out;
+	}
+
+	if (!wh_dentry->d_inode) { /* no whiteout exists*/
+		err = 0;
+		goto out_dput;
+	}
+
+	/* check if regular file and whiteout were both found */
+	if (unlikely(lower_dentry->d_inode))
+		printk(KERN_WARNING "unionfs: removing whiteout; regular "
+		       "file exists in directory %s (branch %d)\n",
+		       lower_dir_dentry->d_name.name, bindex);
+
+	/* check if branch is writeable */
+	err = is_robranch_super(dentry->d_sb, bindex);
+	if (err)
+		goto out_dput;
+
+	/* .wh.foo has been found, so let's unlink it */
+	err = unlink_whiteout(wh_dentry);
+	if (!err)
+		err = 1; /* a whiteout was found and successfully removed */
+out_dput:
+	dput(wh_dentry);
+out:
+	return err;
+}
+
+/*
+ * Pass an unionfs dentry and an index.  It will try to create a whiteout
+ * for the filename in dentry, and will try in branch 'index'.  On error,
+ * it will proceed to a branch to the left.
+ */
+int create_whiteout(struct dentry *dentry, int start)
+{
+	int bstart, bend, bindex;
+	struct dentry *lower_dir_dentry;
+	struct dentry *lower_dentry;
+	struct dentry *lower_wh_dentry;
+	char *name = NULL;
+	int err = -EINVAL;
+
+	verify_locked(dentry);
+
+	bstart = dbstart(dentry);
+	bend = dbend(dentry);
+
+	/* create dentry's whiteout equivalent */
+	name = alloc_whname(dentry->d_name.name, dentry->d_name.len);
+	if (unlikely(IS_ERR(name))) {
+		err = PTR_ERR(name);
+		goto out;
+	}
+
+	for (bindex = start; bindex >= 0; bindex--) {
+		lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+
+		if (!lower_dentry) {
+			/*
+			 * if lower dentry is not present, create the
+			 * entire lower dentry directory structure and go
+			 * ahead.  Since we want to just create whiteout, we
+			 * only want the parent dentry, and hence get rid of
+			 * this dentry.
+			 */
+			lower_dentry = create_parents(dentry->d_inode,
+						      dentry,
+						      dentry->d_name.name,
+						      bindex);
+			if (!lower_dentry || IS_ERR(lower_dentry)) {
+				int ret = PTR_ERR(lower_dentry);
+				if (!IS_COPYUP_ERR(ret))
+					printk(KERN_ERR
+					       "unionfs: create_parents for "
+					       "whiteout failed: bindex=%d "
+					       "err=%d\n", bindex, ret);
+				continue;
+			}
+		}
+
+		lower_wh_dentry =
+			lookup_lck_len(name, lower_dentry->d_parent,
+				       dentry->d_name.len + UNIONFS_WHLEN);
+		if (IS_ERR(lower_wh_dentry))
+			continue;
+
+		/*
+		 * The whiteout already exists. This used to be impossible,
+		 * but now is possible because of opaqueness.
+		 */
+		if (lower_wh_dentry->d_inode) {
+			dput(lower_wh_dentry);
+			err = 0;
+			goto out;
+		}
+
+		lower_dir_dentry = lock_parent_wh(lower_wh_dentry);
+		err = is_robranch_super(dentry->d_sb, bindex);
+		if (!err)
+			err = vfs_create(lower_dir_dentry->d_inode,
+					 lower_wh_dentry,
+					 current_umask() & S_IRUGO,
+					 0); // XXX: pass want_excl?
+		unlock_dir(lower_dir_dentry);
+		dput(lower_wh_dentry);
+
+		if (!err || !IS_COPYUP_ERR(err))
+			break;
+	}
+
+	/* set dbopaque so that lookup will not proceed after this branch */
+	if (!err)
+		dbopaque(dentry) = bindex;
+
+out:
+	kfree(name);
+	return err;
+}
+
+/*
+ * Delete all of the whiteouts in a given directory for rmdir.
+ *
+ * lower directory inode should be locked
+ */
+static int do_delete_whiteouts(struct dentry *dentry, int bindex,
+			       struct unionfs_dir_state *namelist)
+{
+	int err = 0;
+	struct dentry *lower_dir_dentry = NULL;
+	struct dentry *lower_dentry;
+	char *name = NULL, *p;
+	struct inode *lower_dir;
+	int i;
+	struct list_head *pos;
+	struct filldir_node *cursor;
+
+	/* Find out lower parent dentry */
+	lower_dir_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+	BUG_ON(!S_ISDIR(lower_dir_dentry->d_inode->i_mode));
+	lower_dir = lower_dir_dentry->d_inode;
+	BUG_ON(!S_ISDIR(lower_dir->i_mode));
+
+	err = -ENOMEM;
+	name = __getname();
+	if (unlikely(!name))
+		goto out;
+	strcpy(name, UNIONFS_WHPFX);
+	p = name + UNIONFS_WHLEN;
+
+	err = 0;
+	for (i = 0; !err && i < namelist->size; i++) {
+		list_for_each(pos, &namelist->list[i]) {
+			cursor =
+				list_entry(pos, struct filldir_node,
+					   file_list);
+			/* Only operate on whiteouts in this branch. */
+			if (cursor->bindex != bindex)
+				continue;
+			if (!cursor->whiteout)
+				continue;
+
+			strlcpy(p, cursor->name, PATH_MAX - UNIONFS_WHLEN);
+			lower_dentry =
+				lookup_lck_len(name, lower_dir_dentry,
+					       cursor->namelen +
+					       UNIONFS_WHLEN);
+			if (IS_ERR(lower_dentry)) {
+				err = PTR_ERR(lower_dentry);
+				break;
+			}
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+			mutex_lock(&lower_dir->i_mutex);
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
+			if (lower_dentry->d_inode)
+				err = vfs_unlink(lower_dir, lower_dentry);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+			mutex_unlock(&lower_dir->i_mutex);
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
+			dput(lower_dentry);
+			if (err)
+				break;
+		}
+	}
+
+	__putname(name);
+
+	/* After all of the removals, we should copy the attributes once. */
+	fsstack_copy_attr_times(dentry->d_inode, lower_dir_dentry->d_inode);
+
+out:
+	return err;
+}
+
+
+void __delete_whiteouts(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+	struct deletewh_args *d = &args->deletewh;
+
+	args->err = do_delete_whiteouts(d->dentry, d->bindex, d->namelist);
+	complete(&args->comp);
+}
+
+/* delete whiteouts in a dir (for rmdir operation) using sioq if necessary */
+int delete_whiteouts(struct dentry *dentry, int bindex,
+		     struct unionfs_dir_state *namelist)
+{
+	int err;
+	struct super_block *sb;
+	struct dentry *lower_dir_dentry;
+	struct inode *lower_dir;
+	struct sioq_args args;
+
+	sb = dentry->d_sb;
+
+	BUG_ON(!S_ISDIR(dentry->d_inode->i_mode));
+	BUG_ON(bindex < dbstart(dentry));
+	BUG_ON(bindex > dbend(dentry));
+	err = is_robranch_super(sb, bindex);
+	if (err)
+		goto out;
+
+	lower_dir_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+	BUG_ON(!S_ISDIR(lower_dir_dentry->d_inode->i_mode));
+	lower_dir = lower_dir_dentry->d_inode;
+	BUG_ON(!S_ISDIR(lower_dir->i_mode));
+
+	if (!inode_permission(lower_dir, MAY_WRITE | MAY_EXEC)) {
+		err = do_delete_whiteouts(dentry, bindex, namelist);
+	} else {
+		args.deletewh.namelist = namelist;
+		args.deletewh.dentry = dentry;
+		args.deletewh.bindex = bindex;
+		run_sioq(__delete_whiteouts, &args);
+		err = args.err;
+	}
+
+out:
+	return err;
+}
+
+/****************************************************************************
+ * Opaque directory helpers                                                 *
+ ****************************************************************************/
+
+/*
+ * is_opaque_dir: returns 0 if it is NOT an opaque dir, 1 if it is, and
+ * -errno if an error occurred trying to figure this out.
+ */
+int is_opaque_dir(struct dentry *dentry, int bindex)
+{
+	int err = 0;
+	struct dentry *lower_dentry;
+	struct dentry *wh_lower_dentry;
+	struct inode *lower_inode;
+	struct sioq_args args;
+
+	lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+	lower_inode = lower_dentry->d_inode;
+
+	BUG_ON(!S_ISDIR(lower_inode->i_mode));
+
+	mutex_lock(&lower_inode->i_mutex);
+
+	if (!inode_permission(lower_inode, MAY_EXEC)) {
+		wh_lower_dentry =
+			lookup_one_len(UNIONFS_DIR_OPAQUE, lower_dentry,
+				       sizeof(UNIONFS_DIR_OPAQUE) - 1); // XXX: pass flags?
+	} else {
+		args.is_opaque.dentry = lower_dentry;
+		run_sioq(__is_opaque_dir, &args);
+		wh_lower_dentry = args.ret;
+	}
+
+	mutex_unlock(&lower_inode->i_mutex);
+
+	if (IS_ERR(wh_lower_dentry)) {
+		err = PTR_ERR(wh_lower_dentry);
+		goto out;
+	}
+
+	/* This is an opaque dir iff wh_lower_dentry is positive */
+	err = !!wh_lower_dentry->d_inode;
+
+	dput(wh_lower_dentry);
+out:
+	return err;
+}
+
+void __is_opaque_dir(struct work_struct *work)
+{
+	struct sioq_args *args = container_of(work, struct sioq_args, work);
+
+	args->ret = lookup_one_len(UNIONFS_DIR_OPAQUE,
+				   args->is_opaque.dentry,
+				   sizeof(UNIONFS_DIR_OPAQUE) - 1); // XXX: pass flags?
+	complete(&args->comp);
+}
+
+int make_dir_opaque(struct dentry *dentry, int bindex)
+{
+	int err = 0;
+	struct dentry *lower_dentry, *diropq;
+	struct inode *lower_dir;
+	const struct cred *old_creds;
+	struct cred *new_creds;
+
+	/*
+	 * Opaque directory whiteout markers are special files (like regular
+	 * whiteouts), and should appear to the users as if they don't
+	 * exist.  They should be created/deleted regardless of directory
+	 * search/create permissions, but only for the duration of this
+	 * creation of the .wh.__dir_opaque: file.  Note, this does not
+	 * circumvent normal ->permission).
+	 */
+	new_creds = prepare_creds();
+	if (unlikely(!new_creds)) {
+		err = -ENOMEM;
+		goto out_err;
+	}
+	cap_raise(new_creds->cap_effective, CAP_DAC_READ_SEARCH);
+	cap_raise(new_creds->cap_effective, CAP_DAC_OVERRIDE);
+	old_creds = override_creds(new_creds);
+
+	lower_dentry = unionfs_lower_dentry_idx(dentry, bindex);
+	lower_dir = lower_dentry->d_inode;
+	BUG_ON(!S_ISDIR(dentry->d_inode->i_mode) ||
+	       !S_ISDIR(lower_dir->i_mode));
+
+	mutex_lock(&lower_dir->i_mutex);
+	diropq = lookup_one_len(UNIONFS_DIR_OPAQUE, lower_dentry,
+				sizeof(UNIONFS_DIR_OPAQUE) - 1); // XXX: pass flags?
+	if (IS_ERR(diropq)) {
+		err = PTR_ERR(diropq);
+		goto out;
+	}
+
+	if (!diropq->d_inode)
+		err = vfs_create(lower_dir, diropq, S_IRUGO, 0); // XXX: pass want_excl?
+	if (!err)
+		dbopaque(dentry) = bindex;
+
+	dput(diropq);
+
+out:
+	mutex_unlock(&lower_dir->i_mutex);
+	revert_creds(old_creds);
+out_err:
+	return err;
+}
diff --git a/fs/unionfs/xattr.c b/fs/unionfs/xattr.c
new file mode 100644
index 00000000..7db36cfa
--- /dev/null
+++ b/fs/unionfs/xattr.c
@@ -0,0 +1,173 @@
+/*
+ * Copyright (c) 2003-2014 Erez Zadok
+ * Copyright (c) 2003-2006 Charles P. Wright
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2005-2006 Junjiro Okajima
+ * Copyright (c) 2005      Arun M. Krishnakumar
+ * Copyright (c) 2004-2006 David P. Quigley
+ * Copyright (c) 2003-2004 Mohammad Nayyer Zubair
+ * Copyright (c) 2003      Puja Gupta
+ * Copyright (c) 2003      Harikesavan Krishnan
+ * Copyright (c) 2003-2014 Stony Brook University
+ * Copyright (c) 2003-2014 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#include "union.h"
+
+/* This is lifted from fs/xattr.c */
+void *unionfs_xattr_alloc(size_t size, size_t limit)
+{
+	void *ptr;
+
+	if (size > limit)
+		return ERR_PTR(-E2BIG);
+
+	if (!size)		/* size request, no buffer is needed */
+		return NULL;
+
+	ptr = kmalloc(size, GFP_KERNEL);
+	if (unlikely(!ptr))
+		return ERR_PTR(-ENOMEM);
+	return ptr;
+}
+
+/*
+ * BKL held by caller.
+ * dentry->d_inode->i_mutex locked
+ */
+ssize_t unionfs_getxattr(struct dentry *dentry, const char *name, void *value,
+			 size_t size)
+{
+	struct dentry *lower_dentry = NULL;
+	struct dentry *parent;
+	int err = -EOPNOTSUPP;
+	bool valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	err = vfs_getxattr(lower_dentry, (char *) name, value, size);
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * BKL held by caller.
+ * dentry->d_inode->i_mutex locked
+ */
+int unionfs_setxattr(struct dentry *dentry, const char *name,
+		     const void *value, size_t size, int flags)
+{
+	struct dentry *lower_dentry = NULL;
+	struct dentry *parent;
+	int err = -EOPNOTSUPP;
+	bool valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	err = vfs_setxattr(lower_dentry, (char *) name, (void *) value,
+			   size, flags);
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * BKL held by caller.
+ * dentry->d_inode->i_mutex locked
+ */
+int unionfs_removexattr(struct dentry *dentry, const char *name)
+{
+	struct dentry *lower_dentry = NULL;
+	struct dentry *parent;
+	int err = -EOPNOTSUPP;
+	bool valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	err = vfs_removexattr(lower_dentry, (char *) name);
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
+
+/*
+ * BKL held by caller.
+ * dentry->d_inode->i_mutex locked
+ */
+ssize_t unionfs_listxattr(struct dentry *dentry, char *list, size_t size)
+{
+	struct dentry *lower_dentry = NULL;
+	struct dentry *parent;
+	int err = -EOPNOTSUPP;
+	char *encoded_list = NULL;
+	bool valid;
+
+	unionfs_read_lock(dentry->d_sb, UNIONFS_SMUTEX_CHILD);
+	parent = unionfs_lock_parent(dentry, UNIONFS_DMUTEX_PARENT);
+	unionfs_lock_dentry(dentry, UNIONFS_DMUTEX_CHILD);
+
+	valid = __unionfs_d_revalidate(dentry, parent, false, 0);
+	if (unlikely(!valid)) {
+		err = -ESTALE;
+		goto out;
+	}
+
+	lower_dentry = unionfs_lower_dentry(dentry);
+
+	encoded_list = list;
+	err = vfs_listxattr(lower_dentry, encoded_list, size);
+
+out:
+	unionfs_check_dentry(dentry);
+	unionfs_unlock_dentry(dentry);
+	unionfs_unlock_parent(dentry, parent);
+	unionfs_read_unlock(dentry->d_sb);
+	return err;
+}
diff --git a/fs/xfs/xfs_aops.c b/fs/xfs/xfs_aops.c
index 41a6950..6ec1fc7 100644
--- a/fs/xfs/xfs_aops.c
+++ b/fs/xfs/xfs_aops.c
@@ -725,6 +725,8 @@ xfs_convert_page(
 			(xfs_off_t)(page->index + 1) << PAGE_CACHE_SHIFT,
 			i_size_read(inode));
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+#else
 	/*
 	 * If the current map does not span the entire page we are about to try
 	 * to write, then give up. The only way we can write a page that spans
@@ -743,6 +745,7 @@ xfs_convert_page(
 	 */
 	if (!xfs_imap_valid(inode, imap, end_offset))
 		goto fail_unlock_page;
+#endif
 
 	len = 1 << inode->i_blkbits;
 	p_offset = min_t(unsigned long, end_offset & (PAGE_CACHE_SIZE - 1),
@@ -972,6 +975,16 @@ xfs_vm_writepage(
 	if (page->index >= end_index) {
 		unsigned offset_into_page = offset & (PAGE_CACHE_SIZE - 1);
 
+#ifdef CONFIG_BUFFALO_PLATFORM
+		/*
+		 * Just skip the page if it is fully outside i_size, e.g. due
+		 * to a truncate operation that is in progress.
+		 */
+		if (page->index >= end_index + 1 || offset_into_page == 0) {
+			unlock_page(page);
+			return 0;
+		}
+#else
 		/*
 		 * Skip the page if it is fully outside i_size, e.g. due to a
 		 * truncate operation that is in progress. We must redirty the
@@ -980,6 +993,7 @@ xfs_vm_writepage(
 		 */
 		if (page->index >= end_index + 1 || offset_into_page == 0)
 			goto redirty;
+#endif
 
 		/*
 		 * The page straddles i_size.  It must be zeroed out on each
diff --git a/fs/xfs/xfs_attr.c b/fs/xfs/xfs_attr.c
index 20fe3fe..0ccc319 100644
--- a/fs/xfs/xfs_attr.c
+++ b/fs/xfs/xfs_attr.c
@@ -211,7 +211,7 @@ xfs_attr_calc_size(
 		 * Out of line attribute, cannot double split, but
 		 * make room for the attribute value itself.
 		 */
-		uint	dblocks = XFS_B_TO_FSB(mp, valuelen);
+		uint	dblocks = xfs_attr3_rmt_blocks(mp, valuelen);
 		nblks += dblocks;
 		nblks += XFS_NEXTENTADD_SPACE_RES(mp, dblocks, XFS_ATTR_FORK);
 	}
@@ -919,11 +919,22 @@ xfs_attr_leaf_addname(xfs_da_args_t *args)
 
 		trace_xfs_attr_leaf_replace(args);
 
+		/* save the attribute state for later removal*/
 		args->op_flags |= XFS_DA_OP_RENAME;	/* an atomic rename */
 		args->blkno2 = args->blkno;		/* set 2nd entry info*/
 		args->index2 = args->index;
 		args->rmtblkno2 = args->rmtblkno;
 		args->rmtblkcnt2 = args->rmtblkcnt;
+		args->rmtvaluelen2 = args->rmtvaluelen;
+
+		/*
+		 * clear the remote attr state now that it is saved so that the
+		 * values reflect the state of the attribute we are about to
+		 * add, not the attribute we just found and will remove later.
+		 */
+		args->rmtblkno = 0;
+		args->rmtblkcnt = 0;
+		args->rmtvaluelen = 0;
 	}
 
 	/*
@@ -1015,6 +1026,7 @@ xfs_attr_leaf_addname(xfs_da_args_t *args)
 		args->blkno = args->blkno2;
 		args->rmtblkno = args->rmtblkno2;
 		args->rmtblkcnt = args->rmtblkcnt2;
+		args->rmtvaluelen = args->rmtvaluelen2;
 		if (args->rmtblkno) {
 			error = xfs_attr_rmtval_remove(args);
 			if (error)
@@ -1242,13 +1254,22 @@ restart:
 
 		trace_xfs_attr_node_replace(args);
 
+		/* save the attribute state for later removal*/
 		args->op_flags |= XFS_DA_OP_RENAME;	/* atomic rename op */
 		args->blkno2 = args->blkno;		/* set 2nd entry info*/
 		args->index2 = args->index;
 		args->rmtblkno2 = args->rmtblkno;
 		args->rmtblkcnt2 = args->rmtblkcnt;
+		args->rmtvaluelen2 = args->rmtvaluelen;
+
+		/*
+		 * clear the remote attr state now that it is saved so that the
+		 * values reflect the state of the attribute we are about to
+		 * add, not the attribute we just found and will remove later.
+		 */
 		args->rmtblkno = 0;
 		args->rmtblkcnt = 0;
+		args->rmtvaluelen = 0;
 	}
 
 	retval = xfs_attr3_leaf_add(blk->bp, state->args);
@@ -1375,6 +1396,7 @@ restart:
 		args->blkno = args->blkno2;
 		args->rmtblkno = args->rmtblkno2;
 		args->rmtblkcnt = args->rmtblkcnt2;
+		args->rmtvaluelen = args->rmtvaluelen2;
 		if (args->rmtblkno) {
 			error = xfs_attr_rmtval_remove(args);
 			if (error)
diff --git a/fs/xfs/xfs_attr_leaf.c b/fs/xfs/xfs_attr_leaf.c
index 31d3cd1..29054db 100644
--- a/fs/xfs/xfs_attr_leaf.c
+++ b/fs/xfs/xfs_attr_leaf.c
@@ -1413,6 +1413,7 @@ xfs_attr3_leaf_add_work(
 		name_rmt->valueblk = 0;
 		args->rmtblkno = 1;
 		args->rmtblkcnt = xfs_attr3_rmt_blocks(mp, args->valuelen);
+		args->rmtvaluelen = args->valuelen;
 	}
 	xfs_trans_log_buf(args->trans, bp,
 	     XFS_DA_LOGRANGE(leaf, xfs_attr3_leaf_name(leaf, args->index),
@@ -2352,11 +2353,11 @@ xfs_attr3_leaf_lookup_int(
 			if (!xfs_attr_namesp_match(args->flags, entry->flags))
 				continue;
 			args->index = probe;
-			args->valuelen = be32_to_cpu(name_rmt->valuelen);
+			args->rmtvaluelen = be32_to_cpu(name_rmt->valuelen);
 			args->rmtblkno = be32_to_cpu(name_rmt->valueblk);
 			args->rmtblkcnt = xfs_attr3_rmt_blocks(
 							args->dp->i_mount,
-							args->valuelen);
+							args->rmtvaluelen);
 			return XFS_ERROR(EEXIST);
 		}
 	}
@@ -2405,19 +2406,19 @@ xfs_attr3_leaf_getvalue(
 		name_rmt = xfs_attr3_leaf_name_remote(leaf, args->index);
 		ASSERT(name_rmt->namelen == args->namelen);
 		ASSERT(memcmp(args->name, name_rmt->name, args->namelen) == 0);
-		valuelen = be32_to_cpu(name_rmt->valuelen);
+		args->rmtvaluelen = be32_to_cpu(name_rmt->valuelen);
 		args->rmtblkno = be32_to_cpu(name_rmt->valueblk);
 		args->rmtblkcnt = xfs_attr3_rmt_blocks(args->dp->i_mount,
-						       valuelen);
+						       args->rmtvaluelen);
 		if (args->flags & ATTR_KERNOVAL) {
-			args->valuelen = valuelen;
+			args->valuelen = args->rmtvaluelen;
 			return 0;
 		}
-		if (args->valuelen < valuelen) {
-			args->valuelen = valuelen;
+		if (args->valuelen < args->rmtvaluelen) {
+			args->valuelen = args->rmtvaluelen;
 			return XFS_ERROR(ERANGE);
 		}
-		args->valuelen = valuelen;
+		args->valuelen = args->rmtvaluelen;
 	}
 	return 0;
 }
@@ -2732,6 +2733,7 @@ xfs_attr3_leaf_list_int(
 				args.dp = context->dp;
 				args.whichfork = XFS_ATTR_FORK;
 				args.valuelen = valuelen;
+				args.rmtvaluelen = valuelen;
 				args.value = kmem_alloc(valuelen, KM_SLEEP | KM_NOFS);
 				args.rmtblkno = be32_to_cpu(name_rmt->valueblk);
 				args.rmtblkcnt = xfs_attr3_rmt_blocks(
@@ -2828,7 +2830,7 @@ xfs_attr3_leaf_clearflag(
 		ASSERT((entry->flags & XFS_ATTR_LOCAL) == 0);
 		name_rmt = xfs_attr3_leaf_name_remote(leaf, args->index);
 		name_rmt->valueblk = cpu_to_be32(args->rmtblkno);
-		name_rmt->valuelen = cpu_to_be32(args->valuelen);
+		name_rmt->valuelen = cpu_to_be32(args->rmtvaluelen);
 		xfs_trans_log_buf(args->trans, bp,
 			 XFS_DA_LOGRANGE(leaf, name_rmt, sizeof(*name_rmt)));
 	}
@@ -2986,7 +2988,7 @@ xfs_attr3_leaf_flipflags(
 		ASSERT((entry1->flags & XFS_ATTR_LOCAL) == 0);
 		name_rmt = xfs_attr3_leaf_name_remote(leaf1, args->index);
 		name_rmt->valueblk = cpu_to_be32(args->rmtblkno);
-		name_rmt->valuelen = cpu_to_be32(args->valuelen);
+		name_rmt->valuelen = cpu_to_be32(args->rmtvaluelen);
 		xfs_trans_log_buf(args->trans, bp1,
 			 XFS_DA_LOGRANGE(leaf1, name_rmt, sizeof(*name_rmt)));
 	}
diff --git a/fs/xfs/xfs_attr_remote.c b/fs/xfs/xfs_attr_remote.c
index ef6b0c1..2006e0d 100644
--- a/fs/xfs/xfs_attr_remote.c
+++ b/fs/xfs/xfs_attr_remote.c
@@ -338,7 +338,7 @@ xfs_attr_rmtval_get(
 	struct xfs_buf		*bp;
 	xfs_dablk_t		lblkno = args->rmtblkno;
 	char			*dst = args->value;
-	int			valuelen = args->valuelen;
+	int			valuelen;
 	int			nmap;
 	int			error;
 	int			blkcnt = args->rmtblkcnt;
@@ -348,7 +348,9 @@ xfs_attr_rmtval_get(
 	trace_xfs_attr_rmtval_get(args);
 
 	ASSERT(!(args->flags & ATTR_KERNOVAL));
+	ASSERT(args->rmtvaluelen == args->valuelen);
 
+	valuelen = args->rmtvaluelen;
 	while (valuelen > 0) {
 		nmap = ATTR_RMTVALUE_MAPSIZE;
 		error = xfs_bmapi_read(args->dp, (xfs_fileoff_t)lblkno,
@@ -416,7 +418,7 @@ xfs_attr_rmtval_set(
 	 * attributes have headers, we can't just do a straight byte to FSB
 	 * conversion and have to take the header space into account.
 	 */
-	blkcnt = xfs_attr3_rmt_blocks(mp, args->valuelen);
+	blkcnt = xfs_attr3_rmt_blocks(mp, args->rmtvaluelen);
 	error = xfs_bmap_first_unused(args->trans, args->dp, blkcnt, &lfileoff,
 						   XFS_ATTR_FORK);
 	if (error)
@@ -481,7 +483,7 @@ xfs_attr_rmtval_set(
 	 */
 	lblkno = args->rmtblkno;
 	blkcnt = args->rmtblkcnt;
-	valuelen = args->valuelen;
+	valuelen = args->rmtvaluelen;
 	while (valuelen > 0) {
 		struct xfs_buf	*bp;
 		xfs_daddr_t	dblkno;
diff --git a/fs/xfs/xfs_buf_item.c b/fs/xfs/xfs_buf_item.c
index 4ec4317..ed8acca 100644
--- a/fs/xfs/xfs_buf_item.c
+++ b/fs/xfs/xfs_buf_item.c
@@ -1023,6 +1023,15 @@ xfs_buf_iodone_callbacks(
 	}
 	lasttarg = bp->b_target;
 
+	/* At unmount we may treat errors differently */
+	if ((mp->m_flags & XFS_MOUNT_UNMOUNTING)) {
+		xfs_force_shutdown(mp, SHUTDOWN_META_IO_ERROR);
+		xfs_buf_stale(bp);
+		XFS_BUF_DONE(bp);
+		trace_xfs_buf_item_iodone(bp, _RET_IP_);
+		goto do_callbacks;
+	}
+
 	/*
 	 * If the write was asynchronous then no one will be looking for the
 	 * error.  Clear the error state and write the buffer out again.
diff --git a/fs/xfs/xfs_da_btree.c b/fs/xfs/xfs_da_btree.c
index eca6f9d..79ddbaf 100644
--- a/fs/xfs/xfs_da_btree.c
+++ b/fs/xfs/xfs_da_btree.c
@@ -1334,7 +1334,7 @@ xfs_da3_fixhashpath(
 		node = blk->bp->b_addr;
 		xfs_da3_node_hdr_from_disk(&nodehdr, node);
 		btree = xfs_da3_node_tree_p(node);
-		if (be32_to_cpu(btree->hashval) == lasthash)
+		if (be32_to_cpu(btree[blk->index].hashval) == lasthash)
 			break;
 		blk->hashval = lasthash;
 		btree[blk->index].hashval = cpu_to_be32(lasthash);
diff --git a/fs/xfs/xfs_da_btree.h b/fs/xfs/xfs_da_btree.h
index 6fb3371c..0c4772e 100644
--- a/fs/xfs/xfs_da_btree.h
+++ b/fs/xfs/xfs_da_btree.h
@@ -191,10 +191,12 @@ typedef struct xfs_da_args {
 	int		index;		/* index of attr of interest in blk */
 	xfs_dablk_t	rmtblkno;	/* remote attr value starting blkno */
 	int		rmtblkcnt;	/* remote attr value block count */
+	int		rmtvaluelen;	/* remote attr value length in bytes */
 	xfs_dablk_t	blkno2;		/* blkno of 2nd attr leaf of interest */
 	int		index2;		/* index of 2nd attr in blk */
 	xfs_dablk_t	rmtblkno2;	/* remote attr value starting blkno */
 	int		rmtblkcnt2;	/* remote attr value block count */
+	int		rmtvaluelen2;	/* remote attr value length in bytes */
 	int		op_flags;	/* operation flags */
 	enum xfs_dacmp	cmpresult;	/* name compare result for lookups */
 } xfs_da_args_t;
diff --git a/fs/xfs/xfs_inode.c b/fs/xfs/xfs_inode.c
index 7f7be5f..baca023 100644
--- a/fs/xfs/xfs_inode.c
+++ b/fs/xfs/xfs_inode.c
@@ -1372,6 +1372,8 @@ xfs_ialloc(
 					di_flags |= XFS_DIFLAG_EXTSZINHERIT;
 					ip->i_d.di_extsize = pip->i_d.di_extsize;
 				}
+				if (pip->i_d.di_flags & XFS_DIFLAG_PROJINHERIT)
+					di_flags |= XFS_DIFLAG_PROJINHERIT;
 			} else if (S_ISREG(mode)) {
 				if (pip->i_d.di_flags & XFS_DIFLAG_RTINHERIT)
 					di_flags |= XFS_DIFLAG_REALTIME;
@@ -1392,8 +1394,6 @@ xfs_ialloc(
 			if ((pip->i_d.di_flags & XFS_DIFLAG_NOSYMLINKS) &&
 			    xfs_inherit_nosymlinks)
 				di_flags |= XFS_DIFLAG_NOSYMLINKS;
-			if (pip->i_d.di_flags & XFS_DIFLAG_PROJINHERIT)
-				di_flags |= XFS_DIFLAG_PROJINHERIT;
 			if ((pip->i_d.di_flags & XFS_DIFLAG_NODEFRAG) &&
 			    xfs_inherit_nodefrag)
 				di_flags |= XFS_DIFLAG_NODEFRAG;
diff --git a/fs/xfs/xfs_ioctl.c b/fs/xfs/xfs_ioctl.c
index 5e99968..c47ead9 100644
--- a/fs/xfs/xfs_ioctl.c
+++ b/fs/xfs/xfs_ioctl.c
@@ -865,8 +865,6 @@ xfs_set_diflags(
 		di_flags |= XFS_DIFLAG_NOATIME;
 	if (xflags & XFS_XFLAG_NODUMP)
 		di_flags |= XFS_DIFLAG_NODUMP;
-	if (xflags & XFS_XFLAG_PROJINHERIT)
-		di_flags |= XFS_DIFLAG_PROJINHERIT;
 	if (xflags & XFS_XFLAG_NODEFRAG)
 		di_flags |= XFS_DIFLAG_NODEFRAG;
 	if (xflags & XFS_XFLAG_FILESTREAM)
@@ -878,6 +876,8 @@ xfs_set_diflags(
 			di_flags |= XFS_DIFLAG_NOSYMLINKS;
 		if (xflags & XFS_XFLAG_EXTSZINHERIT)
 			di_flags |= XFS_DIFLAG_EXTSZINHERIT;
+		if (xflags & XFS_XFLAG_PROJINHERIT)
+			di_flags |= XFS_DIFLAG_PROJINHERIT;
 	} else if (S_ISREG(ip->i_d.di_mode)) {
 		if (xflags & XFS_XFLAG_REALTIME)
 			di_flags |= XFS_DIFLAG_REALTIME;
diff --git a/fs/xfs/xfs_log.c b/fs/xfs/xfs_log.c
index b345a7c..a012b80 100644
--- a/fs/xfs/xfs_log.c
+++ b/fs/xfs/xfs_log.c
@@ -1126,11 +1126,14 @@ xlog_iodone(xfs_buf_t *bp)
 	/* log I/O is always issued ASYNC */
 	ASSERT(XFS_BUF_ISASYNC(bp));
 	xlog_state_done_syncing(iclog, aborted);
+
 	/*
-	 * do not reference the buffer (bp) here as we could race
-	 * with it being freed after writing the unmount record to the
-	 * log.
+	 * drop the buffer lock now that we are done. Nothing references
+	 * the buffer after this, so an unmount waiting on this lock can now
+	 * tear it down safely. As such, it is unsafe to reference the buffer
+	 * (bp) after the unlock as we could race with it being freed.
 	 */
+	xfs_buf_unlock(bp);
 }
 
 /*
@@ -1313,8 +1316,16 @@ xlog_alloc_log(
 	bp = xfs_buf_alloc(mp->m_logdev_targp, 0, BTOBB(log->l_iclog_size), 0);
 	if (!bp)
 		goto out_free_log;
-	bp->b_iodone = xlog_iodone;
+
+	/*
+	 * The iclogbuf buffer locks are held over IO but we are not going to do
+	 * IO yet.  Hence unlock the buffer so that the log IO path can grab it
+	 * when appropriately.
+	 */
 	ASSERT(xfs_buf_islocked(bp));
+	xfs_buf_unlock(bp);
+
+	bp->b_iodone = xlog_iodone;
 	log->l_xbuf = bp;
 
 	spin_lock_init(&log->l_icloglock);
@@ -1343,6 +1354,9 @@ xlog_alloc_log(
 		if (!bp)
 			goto out_free_iclog;
 
+		ASSERT(xfs_buf_islocked(bp));
+		xfs_buf_unlock(bp);
+
 		bp->b_iodone = xlog_iodone;
 		iclog->ic_bp = bp;
 		iclog->ic_data = bp->b_addr;
@@ -1367,7 +1381,6 @@ xlog_alloc_log(
 		iclog->ic_callback_tail = &(iclog->ic_callback);
 		iclog->ic_datap = (char *)iclog->ic_data + log->l_iclog_hsize;
 
-		ASSERT(xfs_buf_islocked(iclog->ic_bp));
 		init_waitqueue_head(&iclog->ic_force_wait);
 		init_waitqueue_head(&iclog->ic_write_wait);
 
@@ -1576,6 +1589,12 @@ xlog_cksum(
  * we transition the iclogs to IOERROR state *after* flushing all existing
  * iclogs to disk. This is because we don't want anymore new transactions to be
  * started or completed afterwards.
+ *
+ * We lock the iclogbufs here so that we can serialise against IO completion
+ * during unmount. We might be processing a shutdown triggered during unmount,
+ * and that can occur asynchronously to the unmount thread, and hence we need to
+ * ensure that completes before tearing down the iclogbufs. Hence we need to
+ * hold the buffer lock across the log IO to acheive that.
  */
 STATIC int
 xlog_bdstrat(
@@ -1583,6 +1602,7 @@ xlog_bdstrat(
 {
 	struct xlog_in_core	*iclog = bp->b_fspriv;
 
+	xfs_buf_lock(bp);
 	if (iclog->ic_state & XLOG_STATE_IOERROR) {
 		xfs_buf_ioerror(bp, EIO);
 		xfs_buf_stale(bp);
@@ -1590,7 +1610,8 @@ xlog_bdstrat(
 		/*
 		 * It would seem logical to return EIO here, but we rely on
 		 * the log state machine to propagate I/O errors instead of
-		 * doing it here.
+		 * doing it here. Similarly, IO completion will unlock the
+		 * buffer, so we don't do it here.
 		 */
 		return 0;
 	}
@@ -1792,14 +1813,28 @@ xlog_dealloc_log(
 	xlog_cil_destroy(log);
 
 	/*
-	 * always need to ensure that the extra buffer does not point to memory
-	 * owned by another log buffer before we free it.
+	 * Cycle all the iclogbuf locks to make sure all log IO completion
+	 * is done before we tear down these buffers.
 	 */
+	iclog = log->l_iclog;
+	for (i = 0; i < log->l_iclog_bufs; i++) {
+		xfs_buf_lock(iclog->ic_bp);
+		xfs_buf_unlock(iclog->ic_bp);
+		iclog = iclog->ic_next;
+	}
+
+	/*
+	 * Always need to ensure that the extra buffer does not point to memory
+	 * owned by another log buffer before we free it. Also, cycle the lock
+	 * first to ensure we've completed IO on it.
+	 */
+	xfs_buf_lock(log->l_xbuf);
+	xfs_buf_unlock(log->l_xbuf);
 	xfs_buf_set_empty(log->l_xbuf, BTOBB(log->l_iclog_size));
 	xfs_buf_free(log->l_xbuf);
 
 	iclog = log->l_iclog;
-	for (i=0; i<log->l_iclog_bufs; i++) {
+	for (i = 0; i < log->l_iclog_bufs; i++) {
 		xfs_buf_free(iclog->ic_bp);
 		next_iclog = iclog->ic_next;
 		kmem_free(iclog);
diff --git a/fs/xfs/xfs_mount.c b/fs/xfs/xfs_mount.c
index 49ba783..e2c46f3 100644
--- a/fs/xfs/xfs_mount.c
+++ b/fs/xfs/xfs_mount.c
@@ -1571,6 +1571,7 @@ xfs_mountfs(
  out_rele_rip:
 	IRELE(rip);
  out_log_dealloc:
+	mp->m_flags |= XFS_MOUNT_UNMOUNTING;
 	xfs_log_unmount(mp);
  out_fail_wait:
 	if (mp->m_logdev_targp && mp->m_logdev_targp != mp->m_ddev_targp)
@@ -1614,6 +1615,14 @@ xfs_unmountfs(
 	xfs_log_force(mp, XFS_LOG_SYNC);
 
 	/*
+	 * We now need to tell the world we are unmounting. This will allow
+	 * us to detect that the filesystem is going away and we should error
+	 * out anything that we have been retrying in the background. This will
+	 * prevent neverending retries in AIL pushing from hanging the unmount.
+	 */
+	mp->m_flags |= XFS_MOUNT_UNMOUNTING;
+
+	/*
 	 * Flush all pending changes from the AIL.
 	 */
 	xfs_ail_push_all_sync(mp->m_ail);
diff --git a/fs/xfs/xfs_mount.h b/fs/xfs/xfs_mount.h
index b004cec..83cae3c0 100644
--- a/fs/xfs/xfs_mount.h
+++ b/fs/xfs/xfs_mount.h
@@ -224,6 +224,7 @@ typedef struct xfs_mount {
 #define XFS_MOUNT_WSYNC		(1ULL << 0)	/* for nfs - all metadata ops
 						   must be synchronous except
 						   for space allocations */
+#define XFS_MOUNT_UNMOUNTING	(1ULL << 1)     /* filesystem is unmounting */
 #define XFS_MOUNT_WAS_CLEAN	(1ULL << 3)
 #define XFS_MOUNT_FS_SHUTDOWN	(1ULL << 4)	/* atomic stop of all filesystem
 						   operations, typically for
diff --git a/include/linux/backing-dev.h b/include/linux/backing-dev.h
index c388155..4cfdbf2 100644
--- a/include/linux/backing-dev.h
+++ b/include/linux/backing-dev.h
@@ -95,7 +95,7 @@ struct backing_dev_info {
 	unsigned int max_ratio, max_prop_frac;
 
 	struct bdi_writeback wb;  /* default writeback info for this bdi */
-	spinlock_t wb_lock;	  /* protects work_list */
+	spinlock_t wb_lock;	  /* protects work_list & wb.dwork scheduling */
 
 	struct list_head work_list;
 
diff --git a/include/linux/completion.h b/include/linux/completion.h
index 33f0280..59042e6 100644
--- a/include/linux/completion.h
+++ b/include/linux/completion.h
@@ -76,6 +76,18 @@ static inline void init_completion(struct completion *x)
 	init_waitqueue_head(&x->wait);
 }
 
+/**
+ * reinit_completion - reinitialize a completion structure
+ * @x:  pointer to completion structure that is to be reinitialized
+ *
+ * This inline function should be used to reinitialize a completion structure so it can
+ * be reused. This is especially important after complete_all() is used.
+ */
+static inline void reinit_completion(struct completion *x)
+{
+	x->done = 0;
+}
+
 extern void wait_for_completion(struct completion *);
 extern void wait_for_completion_io(struct completion *);
 extern int wait_for_completion_interruptible(struct completion *x);
diff --git a/include/linux/genhd.h b/include/linux/genhd.h
index 9f3c275..bacda71 100644
--- a/include/linux/genhd.h
+++ b/include/linux/genhd.h
@@ -200,6 +200,16 @@ struct gendisk {
 	struct blk_integrity *integrity;
 #endif
 	int node_id;
+
+#ifdef	CONFIG_BUFFALO_IOERRS
+	unsigned io_errors;		/* I/O error counter */
+	unsigned limit_io_errors;	/* I/O error limit */
+#ifdef	CONFIG_BUFFALO_ERRCNT
+	atomic_t nr_errs;		/* number of errors occur during
+					 * Block I/O execution. */
+#endif	/* CONFIG_BUFFALO_ERRCNT */
+#endif	/* CONFIG_BUFFALO_IOERRS */
+	
 };
 
 static inline struct gendisk *part_to_disk(struct hd_struct *part)
diff --git a/include/linux/mm.h b/include/linux/mm.h
index 3a6c8ea..79aa131 100644
--- a/include/linux/mm.h
+++ b/include/linux/mm.h
@@ -235,6 +235,8 @@ struct vm_operations_struct {
 	/* called by sys_remap_file_pages() to populate non-linear mapping */
 	int (*remap_pages)(struct vm_area_struct *vma, unsigned long addr,
 			   unsigned long size, pgoff_t pgoff);
+	/* unionfs support, CONFIG_BUFFALO_UNIONFS_FIX specific */
+	void (*update_mapping)(struct vm_area_struct *vma);
 };
 
 struct mmu_gather;
@@ -1706,6 +1708,7 @@ static inline struct page *follow_page(struct vm_area_struct *vma,
 #define FOLL_HWPOISON	0x100	/* check page is hwpoisoned */
 #define FOLL_NUMA	0x200	/* force NUMA hinting page fault */
 #define FOLL_MIGRATION	0x400	/* wait for page to replace migration entry */
+#define FOLL_COW	0x4000	/* internal GUP flag */
 
 typedef int (*pte_fn_t)(pte_t *pte, pgtable_t token, unsigned long addr,
 			void *data);
diff --git a/include/linux/percpu-refcount.h b/include/linux/percpu-refcount.h
new file mode 100644
index 00000000..95961f0
--- /dev/null
+++ b/include/linux/percpu-refcount.h
@@ -0,0 +1,174 @@
+/*
+ * Percpu refcounts:
+ * (C) 2012 Google, Inc.
+ * Author: Kent Overstreet <koverstreet@google.com>
+ *
+ * This implements a refcount with similar semantics to atomic_t - atomic_inc(),
+ * atomic_dec_and_test() - but percpu.
+ *
+ * There's one important difference between percpu refs and normal atomic_t
+ * refcounts; you have to keep track of your initial refcount, and then when you
+ * start shutting down you call percpu_ref_kill() _before_ dropping the initial
+ * refcount.
+ *
+ * The refcount will have a range of 0 to ((1U << 31) - 1), i.e. one bit less
+ * than an atomic_t - this is because of the way shutdown works, see
+ * percpu_ref_kill()/PCPU_COUNT_BIAS.
+ *
+ * Before you call percpu_ref_kill(), percpu_ref_put() does not check for the
+ * refcount hitting 0 - it can't, if it was in percpu mode. percpu_ref_kill()
+ * puts the ref back in single atomic_t mode, collecting the per cpu refs and
+ * issuing the appropriate barriers, and then marks the ref as shutting down so
+ * that percpu_ref_put() will check for the ref hitting 0.  After it returns,
+ * it's safe to drop the initial ref.
+ *
+ * USAGE:
+ *
+ * See fs/aio.c for some example usage; it's used there for struct kioctx, which
+ * is created when userspaces calls io_setup(), and destroyed when userspace
+ * calls io_destroy() or the process exits.
+ *
+ * In the aio code, kill_ioctx() is called when we wish to destroy a kioctx; it
+ * calls percpu_ref_kill(), then hlist_del_rcu() and sychronize_rcu() to remove
+ * the kioctx from the proccess's list of kioctxs - after that, there can't be
+ * any new users of the kioctx (from lookup_ioctx()) and it's then safe to drop
+ * the initial ref with percpu_ref_put().
+ *
+ * Code that does a two stage shutdown like this often needs some kind of
+ * explicit synchronization to ensure the initial refcount can only be dropped
+ * once - percpu_ref_kill() does this for you, it returns true once and false if
+ * someone else already called it. The aio code uses it this way, but it's not
+ * necessary if the code has some other mechanism to synchronize teardown.
+ * around.
+ */
+
+#ifndef _LINUX_PERCPU_REFCOUNT_H
+#define _LINUX_PERCPU_REFCOUNT_H
+
+#include <linux/atomic.h>
+#include <linux/kernel.h>
+#include <linux/percpu.h>
+#include <linux/rcupdate.h>
+
+struct percpu_ref;
+typedef void (percpu_ref_func_t)(struct percpu_ref *);
+
+struct percpu_ref {
+	atomic_t		count;
+	/*
+	 * The low bit of the pointer indicates whether the ref is in percpu
+	 * mode; if set, then get/put will manipulate the atomic_t (this is a
+	 * hack because we need to keep the pointer around for
+	 * percpu_ref_kill_rcu())
+	 */
+	unsigned __percpu	*pcpu_count;
+	percpu_ref_func_t	*release;
+	percpu_ref_func_t	*confirm_kill;
+	struct rcu_head		rcu;
+};
+
+int __must_check percpu_ref_init(struct percpu_ref *ref,
+				 percpu_ref_func_t *release);
+void percpu_ref_cancel_init(struct percpu_ref *ref);
+void percpu_ref_kill_and_confirm(struct percpu_ref *ref,
+				 percpu_ref_func_t *confirm_kill);
+
+/**
+ * percpu_ref_kill - drop the initial ref
+ * @ref: percpu_ref to kill
+ *
+ * Must be used to drop the initial ref on a percpu refcount; must be called
+ * precisely once before shutdown.
+ *
+ * Puts @ref in non percpu mode, then does a call_rcu() before gathering up the
+ * percpu counters and dropping the initial ref.
+ */
+static inline void percpu_ref_kill(struct percpu_ref *ref)
+{
+	return percpu_ref_kill_and_confirm(ref, NULL);
+}
+
+#define PCPU_STATUS_BITS	2
+#define PCPU_STATUS_MASK	((1 << PCPU_STATUS_BITS) - 1)
+#define PCPU_REF_PTR		0
+#define PCPU_REF_DEAD		1
+
+#define REF_STATUS(count)	(((unsigned long) count) & PCPU_STATUS_MASK)
+
+/**
+ * percpu_ref_get - increment a percpu refcount
+ * @ref: percpu_ref to get
+ *
+ * Analagous to atomic_inc().
+  */
+static inline void percpu_ref_get(struct percpu_ref *ref)
+{
+	unsigned __percpu *pcpu_count;
+
+	rcu_read_lock_sched();
+
+	pcpu_count = ACCESS_ONCE(ref->pcpu_count);
+
+	if (likely(REF_STATUS(pcpu_count) == PCPU_REF_PTR))
+		__this_cpu_inc(*pcpu_count);
+	else
+		atomic_inc(&ref->count);
+
+	rcu_read_unlock_sched();
+}
+
+/**
+ * percpu_ref_tryget - try to increment a percpu refcount
+ * @ref: percpu_ref to try-get
+ *
+ * Increment a percpu refcount unless it has already been killed.  Returns
+ * %true on success; %false on failure.
+ *
+ * Completion of percpu_ref_kill() in itself doesn't guarantee that tryget
+ * will fail.  For such guarantee, percpu_ref_kill_and_confirm() should be
+ * used.  After the confirm_kill callback is invoked, it's guaranteed that
+ * no new reference will be given out by percpu_ref_tryget().
+ */
+static inline bool percpu_ref_tryget(struct percpu_ref *ref)
+{
+	unsigned __percpu *pcpu_count;
+	int ret = false;
+
+	rcu_read_lock_sched();
+
+	pcpu_count = ACCESS_ONCE(ref->pcpu_count);
+
+	if (likely(REF_STATUS(pcpu_count) == PCPU_REF_PTR)) {
+		__this_cpu_inc(*pcpu_count);
+		ret = true;
+	}
+
+	rcu_read_unlock_sched();
+
+	return ret;
+}
+
+/**
+ * percpu_ref_put - decrement a percpu refcount
+ * @ref: percpu_ref to put
+ *
+ * Decrement the refcount, and if 0, call the release function (which was passed
+ * to percpu_ref_init())
+ */
+static inline void percpu_ref_put(struct percpu_ref *ref)
+{
+	unsigned __percpu *pcpu_count;
+
+	rcu_read_lock_sched();
+
+	pcpu_count = ACCESS_ONCE(ref->pcpu_count);
+
+	if (likely(REF_STATUS(pcpu_count) == PCPU_REF_PTR))
+		__this_cpu_dec(*pcpu_count);
+	else if (unlikely(atomic_dec_and_test(&ref->count)))
+		ref->release(ref);
+
+	rcu_read_unlock_sched();
+}
+
+#endif
diff --git a/include/linux/percpu_ida.h b/include/linux/percpu_ida.h
new file mode 100644
index 00000000..f5cfdd6
--- /dev/null
+++ b/include/linux/percpu_ida.h
@@ -0,0 +1,82 @@
+#ifndef __PERCPU_IDA_H__
+#define __PERCPU_IDA_H__
+
+#include <linux/types.h>
+#include <linux/bitops.h>
+#include <linux/init.h>
+#include <linux/sched.h>
+#include <linux/spinlock_types.h>
+#include <linux/wait.h>
+#include <linux/cpumask.h>
+
+struct percpu_ida_cpu;
+
+struct percpu_ida {
+	/*
+	 * number of tags available to be allocated, as passed to
+	 * percpu_ida_init()
+	 */
+	unsigned			nr_tags;
+	unsigned			percpu_max_size;
+	unsigned			percpu_batch_size;
+
+	struct percpu_ida_cpu __percpu	*tag_cpu;
+
+	/*
+	 * Bitmap of cpus that (may) have tags on their percpu freelists:
+	 * steal_tags() uses this to decide when to steal tags, and which cpus
+	 * to try stealing from.
+	 *
+	 * It's ok for a freelist to be empty when its bit is set - steal_tags()
+	 * will just keep looking - but the bitmap _must_ be set whenever a
+	 * percpu freelist does have tags.
+	 */
+	cpumask_t			cpus_have_tags;
+
+	struct {
+		spinlock_t		lock;
+		/*
+		 * When we go to steal tags from another cpu (see steal_tags()),
+		 * we want to pick a cpu at random. Cycling through them every
+		 * time we steal is a bit easier and more or less equivalent:
+		 */
+		unsigned		cpu_last_stolen;
+
+		/* For sleeping on allocation failure */
+		wait_queue_head_t	wait;
+
+		/*
+		 * Global freelist - it's a stack where nr_free points to the
+		 * top
+		 */
+		unsigned		nr_free;
+		unsigned		*freelist;
+	} ____cacheline_aligned_in_smp;
+};
+
+/*
+ * Number of tags we move between the percpu freelist and the global freelist at
+ * a time
+ */
+#define IDA_DEFAULT_PCPU_BATCH_MOVE	32U
+/* Max size of percpu freelist, */
+#define IDA_DEFAULT_PCPU_SIZE	((IDA_DEFAULT_PCPU_BATCH_MOVE * 3) / 2)
+
+int percpu_ida_alloc(struct percpu_ida *pool, int state);
+void percpu_ida_free(struct percpu_ida *pool, unsigned tag);
+
+void percpu_ida_destroy(struct percpu_ida *pool);
+int __percpu_ida_init(struct percpu_ida *pool, unsigned long nr_tags,
+	unsigned long max_size, unsigned long batch_size);
+static inline int percpu_ida_init(struct percpu_ida *pool, unsigned long nr_tags)
+{
+	return __percpu_ida_init(pool, nr_tags, IDA_DEFAULT_PCPU_SIZE,
+		IDA_DEFAULT_PCPU_BATCH_MOVE);
+}
+
+typedef int (*percpu_ida_cb)(unsigned, void *);
+int percpu_ida_for_each_free(struct percpu_ida *pool, percpu_ida_cb fn,
+	void *data);
+
+unsigned percpu_ida_free_tags(struct percpu_ida *pool, int cpu);
+#endif /* __PERCPU_IDA_H__ */
diff --git a/include/linux/phy.h b/include/linux/phy.h
index 9e11039..0437558 100644
--- a/include/linux/phy.h
+++ b/include/linux/phy.h
@@ -354,6 +354,14 @@ struct phy_device {
 	void (*adjust_link)(struct net_device *dev);
 
 	void (*adjust_state)(struct net_device *dev);
+#ifdef CONFIG_BUFFALO_USE_KERNEVNT
+	struct {
+		int speed;
+		int duplex;
+		unsigned link : 1;
+		unsigned downcnt : 31;
+	} state_cache;
+#endif /*CONFIG_BUFFALO_USE_KERNEVNT*/
 };
 #define to_phy_device(d) container_of(d, struct phy_device, dev)
 
diff --git a/include/linux/radix-tree.h b/include/linux/radix-tree.h
index 6c0cc25..c3e7bef 100644
--- a/include/linux/radix-tree.h
+++ b/include/linux/radix-tree.h
@@ -239,6 +239,7 @@ rdx_t radix_tree_next_hole(struct radix_tree_root *root,
 rdx_t radix_tree_prev_hole(struct radix_tree_root *root,
 				rdx_t index, rdx_t max_scan);
 int radix_tree_preload(gfp_t gfp_mask);
+int radix_tree_maybe_preload(gfp_t gfp_mask);
 void radix_tree_init(void);
 void *radix_tree_tag_set(struct radix_tree_root *root,
 			rdx_t index, unsigned int tag);
diff --git a/include/linux/splice.h b/include/linux/splice.h
index 74575cb..d9c2807 100644
--- a/include/linux/splice.h
+++ b/include/linux/splice.h
@@ -83,6 +83,11 @@ extern ssize_t splice_to_pipe(struct pipe_inode_info *,
 			      struct splice_pipe_desc *);
 extern ssize_t splice_direct_to_actor(struct file *, struct splice_desc *,
 				      splice_direct_actor *);
+extern long vfs_splice_from(struct pipe_inode_info *pipe, struct file *out,
+			    loff_t *ppos, size_t len, unsigned int flags);
+extern long vfs_splice_to(struct file *in, loff_t *ppos,
+			  struct pipe_inode_info *pipe, size_t len,
+			  unsigned int flags);
 
 /*
  * for dynamic pipe sizing
diff --git a/include/linux/union_fs.h b/include/linux/union_fs.h
new file mode 100644
index 00000000..e3e0959
--- /dev/null
+++ b/include/linux/union_fs.h
@@ -0,0 +1,22 @@
+/*
+ * Copyright (c) 2003-2013 Erez Zadok
+ * Copyright (c) 2005-2007 Josef 'Jeff' Sipek
+ * Copyright (c) 2003-2013 Stony Brook University
+ * Copyright (c) 2003-2013 The Research Foundation of SUNY
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
+ */
+
+#ifndef _LINUX_UNION_FS_H
+#define _LINUX_UNION_FS_H
+
+/*
+ * DEFINITIONS FOR USER AND KERNEL CODE:
+ */
+# define UNIONFS_IOCTL_INCGEN		_IOR(0x15, 11, int)
+# define UNIONFS_IOCTL_QUERYFILE	_IOR(0x15, 15, int)
+
+#endif /* _LINUX_UNIONFS_H */
+
diff --git a/include/linux/usb/hcd.h b/include/linux/usb/hcd.h
index 0fdff28..0c5a385 100644
--- a/include/linux/usb/hcd.h
+++ b/include/linux/usb/hcd.h
@@ -172,6 +172,16 @@ struct usb_hcd {
 #define	HC_IS_RUNNING(state) ((state) & __ACTIVE)
 #define	HC_IS_SUSPENDED(state) ((state) & __SUSPEND)
 
+#ifdef CONFIG_USB_ETRON_HCD
+	u8		chip_id;
+#define HCD_CHIP_ID_UNKNOWN 0x00
+#define HCD_CHIP_ID_ETRON_EJ168 0x10
+#define HCD_CHIP_ID_ETRON_EJ188 0x20
+
+	unsigned int		chip_quirks;
+#define HCD_BATTERY_CHARGE_QUIRK (1 << 0)
+#endif /*CONFIG_USB_ETRON_HCD*/
+
 	/* more shared queuing code would be good; it should support
 	 * smarter scheduling, handle transaction translators, etc;
 	 * input size of periodic table to an interrupt scheduler.
@@ -358,6 +368,10 @@ struct hc_driver {
 	int	(*disable_usb3_lpm_timeout)(struct usb_hcd *,
 			struct usb_device *, enum usb3_link_state state);
 	int	(*find_raw_port_number)(struct usb_hcd *, int);
+#ifdef CONFIG_USB_ETRON_HCD
+	void	(*stop_endpoint)(struct usb_hcd *, struct usb_device *,
+				struct usb_host_endpoint *);
+#endif /*CONFIG_USB_ETRON_HCD*/
 };
 
 extern int usb_hcd_link_urb_to_ep(struct usb_hcd *hcd, struct urb *urb);
diff --git a/include/scsi/iscsi_if.h b/include/scsi/iscsi_if.h
index fe7f06c..1bd684f 100644
--- a/include/scsi/iscsi_if.h
+++ b/include/scsi/iscsi_if.h
@@ -489,6 +489,7 @@ enum iscsi_param {
 
 	ISCSI_PARAM_CHAP_IN_IDX,
 	ISCSI_PARAM_CHAP_OUT_IDX,
+	ISCSI_PARAM_DISCOVERY_SESS,
 	/* must always be last */
 	ISCSI_PARAM_MAX,
 };
diff --git a/include/scsi/libiscsi.h b/include/scsi/libiscsi.h
index 09c041e..9ecd389 100644
--- a/include/scsi/libiscsi.h
+++ b/include/scsi/libiscsi.h
@@ -287,6 +287,7 @@ struct iscsi_session {
 	char			*targetalias;
 	char			*ifacename;
 	char			*initiatorname;
+	uint8_t			discovery_sess;
 	/* control data */
 	struct iscsi_transport	*tt;
 	struct Scsi_Host	*host;
diff --git a/include/scsi/scsi.h b/include/scsi/scsi.h
index 66216c1..9d447e3 100644
--- a/include/scsi/scsi.h
+++ b/include/scsi/scsi.h
@@ -139,6 +139,7 @@ struct scsi_cmnd;
 #define ACCESS_CONTROL_IN     0x86
 #define ACCESS_CONTROL_OUT    0x87
 #define READ_16               0x88
+#define COMPARE_AND_WRITE     0x89
 #define WRITE_16              0x8a
 #define READ_ATTRIBUTE        0x8c
 #define WRITE_ATTRIBUTE	      0x8d
@@ -149,6 +150,7 @@ struct scsi_cmnd;
 /* values for service action in */
 #define	SAI_READ_CAPACITY_16  0x10
 #define SAI_GET_LBA_STATUS    0x12
+#define SAI_REPORT_REFERRALS  0x13
 /* values for VARIABLE_LENGTH_CMD service action codes
  * see spc4r17 Section D.3.5, table D.7 and D.8 */
 #define VLC_SA_RECEIVE_CREDENTIAL 0x1800
@@ -452,6 +454,8 @@ static inline int scsi_is_wlun(unsigned int lun)
 				 * other paths */
 #define DID_NEXUS_FAILURE 0x11  /* Permanent nexus failure, retry on other
 				 * paths might yield different results */
+#define DID_ALLOC_FAILURE 0x12  /* Space allocation on the device failed */
+#define DID_MEDIUM_ERROR  0x13  /* Medium error */
 #define DRIVER_OK       0x00	/* Driver status                           */
 
 /*
diff --git a/include/scsi/scsi_device.h b/include/scsi/scsi_device.h
index cc64587..75dcff2 100644
--- a/include/scsi/scsi_device.h
+++ b/include/scsi/scsi_device.h
@@ -183,6 +183,10 @@ struct scsi_device {
 
 	struct scsi_dh_data	*scsi_dh_data;
 	enum scsi_device_state sdev_state;
+
+#ifdef CONFIG_BUFFALO_IGNORE_LUN
+	int ignore_lun;
+#endif	/* CONFIG_BUFFALO_IGNORE_LUN */
 	unsigned long		sdev_data[0];
 } __attribute__((aligned(sizeof(unsigned long))));
 
diff --git a/include/target/iscsi/iscsi_transport.h b/include/target/iscsi/iscsi_transport.h
old mode 100644
new mode 100755
index c5aade5..daef9da
--- a/include/target/iscsi/iscsi_transport.h
+++ b/include/target/iscsi/iscsi_transport.h
@@ -6,13 +6,14 @@ struct iscsit_transport {
 #define ISCSIT_TRANSPORT_NAME	16
 	char name[ISCSIT_TRANSPORT_NAME];
 	int transport_type;
+	int priv_size;
 	struct module *owner;
 	struct list_head t_node;
 	int (*iscsit_setup_np)(struct iscsi_np *, struct __kernel_sockaddr_storage *);
 	int (*iscsit_accept_np)(struct iscsi_np *, struct iscsi_conn *);
 	void (*iscsit_free_np)(struct iscsi_np *);
+	void (*iscsit_wait_conn)(struct iscsi_conn *);
 	void (*iscsit_free_conn)(struct iscsi_conn *);
-	struct iscsi_cmd *(*iscsit_alloc_cmd)(struct iscsi_conn *, gfp_t);
 	int (*iscsit_get_login_rx)(struct iscsi_conn *, struct iscsi_login *);
 	int (*iscsit_put_login_tx)(struct iscsi_conn *, struct iscsi_login *, u32);
 	int (*iscsit_immediate_queue)(struct iscsi_conn *, struct iscsi_cmd *, int);
@@ -20,8 +21,15 @@ struct iscsit_transport {
 	int (*iscsit_get_dataout)(struct iscsi_conn *, struct iscsi_cmd *, bool);
 	int (*iscsit_queue_data_in)(struct iscsi_conn *, struct iscsi_cmd *);
 	int (*iscsit_queue_status)(struct iscsi_conn *, struct iscsi_cmd *);
+	void (*iscsit_aborted_task)(struct iscsi_conn *, struct iscsi_cmd *);
+	enum target_prot_op (*iscsit_get_sup_prot_ops)(struct iscsi_conn *);
 };
 
+static inline void *iscsit_priv_cmd(struct iscsi_cmd *cmd)
+{
+	return (void *)(cmd + 1);
+}
+
 /*
  * From iscsi_target_transport.c
  */
@@ -43,18 +51,27 @@ extern int iscsit_check_dataout_hdr(struct iscsi_conn *, unsigned char *,
 				struct iscsi_cmd **);
 extern int iscsit_check_dataout_payload(struct iscsi_cmd *, struct iscsi_data *,
 				bool);
-extern int iscsit_handle_nop_out(struct iscsi_conn *, struct iscsi_cmd *,
-				unsigned char *);
+extern int iscsit_setup_nop_out(struct iscsi_conn *, struct iscsi_cmd *,
+				struct iscsi_nopout *);
+extern int iscsit_process_nop_out(struct iscsi_conn *, struct iscsi_cmd *,
+				struct iscsi_nopout *);
 extern int iscsit_handle_logout_cmd(struct iscsi_conn *, struct iscsi_cmd *,
 				unsigned char *);
 extern int iscsit_handle_task_mgt_cmd(struct iscsi_conn *, struct iscsi_cmd *,
 				unsigned char *);
+extern int iscsit_setup_text_cmd(struct iscsi_conn *, struct iscsi_cmd *,
+				 struct iscsi_text *);
+extern int iscsit_process_text_cmd(struct iscsi_conn *, struct iscsi_cmd *,
+				   struct iscsi_text *);
 extern void iscsit_build_rsp_pdu(struct iscsi_cmd *, struct iscsi_conn *,
 				bool, struct iscsi_scsi_rsp *);
 extern void iscsit_build_nopin_rsp(struct iscsi_cmd *, struct iscsi_conn *,
 				struct iscsi_nopin *, bool);
 extern void iscsit_build_task_mgt_rsp(struct iscsi_cmd *, struct iscsi_conn *,
 				struct iscsi_tm_rsp *);
+extern int iscsit_build_text_rsp(struct iscsi_cmd *, struct iscsi_conn *,
+				struct iscsi_text_rsp *,
+				enum iscsit_transport_type);
 extern void iscsit_build_reject(struct iscsi_cmd *, struct iscsi_conn *,
 				struct iscsi_reject *);
 extern int iscsit_build_logout_rsp(struct iscsi_cmd *, struct iscsi_conn *,
@@ -81,6 +98,7 @@ extern int iscsit_tmr_post_handler(struct iscsi_cmd *, struct iscsi_conn *);
 /*
  * From iscsi_target_util.c
  */
-extern struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *, gfp_t);
+extern struct iscsi_cmd *iscsit_allocate_cmd(struct iscsi_conn *, int);
 extern int iscsit_sequence_cmd(struct iscsi_conn *, struct iscsi_cmd *,
 			       unsigned char *, __be32);
+extern void iscsit_release_cmd(struct iscsi_cmd *);
diff --git a/include/target/target_core_backend.h b/include/target/target_core_backend.h
old mode 100644
new mode 100755
index ffa2696..4f4d2bf
--- a/include/target/target_core_backend.h
+++ b/include/target/target_core_backend.h
@@ -34,12 +34,21 @@ struct se_subsystem_api {
 	sense_reason_t (*parse_cdb)(struct se_cmd *cmd);
 	u32 (*get_device_type)(struct se_device *);
 	sector_t (*get_blocks)(struct se_device *);
+	sector_t (*get_alignment_offset_lbas)(struct se_device *);
+	/* lbppbe = logical blocks per physical block exponent. see SBC-3 */
+	unsigned int (*get_lbppbe)(struct se_device *);
+	unsigned int (*get_io_min)(struct se_device *);
+	unsigned int (*get_io_opt)(struct se_device *);
 	unsigned char *(*get_sense_buffer)(struct se_cmd *);
 	bool (*get_write_cache)(struct se_device *);
+	int (*init_prot)(struct se_device *);
+	int (*format_prot)(struct se_device *);
+	void (*free_prot)(struct se_device *);
 };
 
 struct sbc_ops {
-	sense_reason_t (*execute_rw)(struct se_cmd *cmd);
+	sense_reason_t (*execute_rw)(struct se_cmd *cmd, struct scatterlist *,
+				     u32, enum dma_data_direction);
 	sense_reason_t (*execute_sync_cache)(struct se_cmd *cmd);
 	sense_reason_t (*execute_write_same)(struct se_cmd *cmd);
 	sense_reason_t (*execute_write_same_unmap)(struct se_cmd *cmd);
@@ -50,6 +59,7 @@ int	transport_subsystem_register(struct se_subsystem_api *);
 void	transport_subsystem_release(struct se_subsystem_api *);
 
 void	target_complete_cmd(struct se_cmd *, u8);
+void	target_complete_cmd_with_length(struct se_cmd *, u8, int);
 
 sense_reason_t	spc_parse_cdb(struct se_cmd *cmd, unsigned int *size);
 sense_reason_t	spc_emulate_report_luns(struct se_cmd *cmd);
@@ -64,6 +74,12 @@ sense_reason_t sbc_execute_unmap(struct se_cmd *cmd,
 	sense_reason_t (*do_unmap_fn)(struct se_cmd *cmd, void *priv,
 				      sector_t lba, sector_t nolb),
 	void *priv);
+void	sbc_dif_generate(struct se_cmd *);
+sense_reason_t	sbc_dif_verify_write(struct se_cmd *, sector_t, unsigned int,
+				     unsigned int, struct scatterlist *, int);
+sense_reason_t	sbc_dif_verify_read(struct se_cmd *, sector_t, unsigned int,
+				    unsigned int, struct scatterlist *, int);
+sense_reason_t	sbc_dif_read_strip(struct se_cmd *);
 
 void	transport_set_vpd_proto_id(struct t10_vpd *, unsigned char *);
 int	transport_set_vpd_assoc(struct t10_vpd *, unsigned char *);
@@ -73,7 +89,15 @@ int	transport_set_vpd_ident(struct t10_vpd *, unsigned char *);
 /* core helpers also used by command snooping in pscsi */
 void	*transport_kmap_data_sg(struct se_cmd *);
 void	transport_kunmap_data_sg(struct se_cmd *);
+/* core helpers also used by xcopy during internal command setup */
+int	target_alloc_sgl(struct scatterlist **, unsigned int *, u32, bool);
+sense_reason_t	transport_generic_map_mem_to_cmd(struct se_cmd *,
+		struct scatterlist *, u32, struct scatterlist *, u32);
 
 void	array_free(void *array, int n);
 
+sector_t target_to_linux_sector(struct se_device *dev, sector_t lb);
+bool target_configure_unmap_from_queue(struct se_dev_attrib *attrib,
+				       struct request_queue *q);
+
 #endif /* TARGET_CORE_BACKEND_H */
diff --git a/include/target/target_core_base.h b/include/target/target_core_base.h
old mode 100644
new mode 100755
index 4ea4f98..b6d61a1
--- a/include/target/target_core_base.h
+++ b/include/target/target_core_base.h
@@ -5,11 +5,13 @@
 #include <linux/configfs.h>
 #include <linux/dma-mapping.h>
 #include <linux/blkdev.h>
+#include <linux/percpu_ida.h>
+#include <linux/percpu-refcount.h>
 #include <scsi/scsi_cmnd.h>
 #include <net/sock.h>
 #include <net/tcp.h>
 
-#define TARGET_CORE_MOD_VERSION		"v4.1.0-rc2-ml"
+#define TARGET_CORE_MOD_VERSION		"v4.1.0"
 #define TARGET_CORE_VERSION		TARGET_CORE_MOD_VERSION
 
 /* Maximum Number of LUNs per Target Portal Group */
@@ -36,6 +38,9 @@
 /* Used by transport_send_check_condition_and_sense() */
 #define SPC_SENSE_KEY_OFFSET			2
 #define SPC_ADD_SENSE_LEN_OFFSET		7
+#define SPC_DESC_TYPE_OFFSET			8
+#define SPC_ADDITIONAL_DESC_LEN_OFFSET		9
+#define SPC_VALIDITY_OFFSET			10
 #define SPC_ASC_KEY_OFFSET			12
 #define SPC_ASCQ_KEY_OFFSET			13
 #define TRANSPORT_IQN_LEN			224
@@ -96,6 +101,10 @@
  * block/blk-lib.c:blkdev_issue_discard()
  */
 #define DA_EMULATE_TPWS				0
+/* Emulation for CompareAndWrite (AtomicTestandSet) by default */
+#define DA_EMULATE_CAW				1
+/* Emulation for 3rd Party Copy (ExtendedCopy) by default */
+#define DA_EMULATE_3PC				1
 /* No Emulation for PSCSI by default */
 #define DA_EMULATE_ALUA				0
 /* Enforce SCSI Initiator Port TransportID with 'ISID' for PR */
@@ -107,7 +116,7 @@
 /* Queue Algorithm Modifier default for restricted reordering in control mode page */
 #define DA_EMULATE_REST_REORD			0
 
-#define SE_INQUIRY_BUF				512
+#define SE_INQUIRY_BUF				1024
 #define SE_MODE_PAGE_BUF			512
 #define SE_SENSE_BUF				96
 
@@ -154,10 +163,13 @@ enum se_cmd_flags_table {
 	SCF_SENT_CHECK_CONDITION	= 0x00000800,
 	SCF_OVERFLOW_BIT		= 0x00001000,
 	SCF_UNDERFLOW_BIT		= 0x00002000,
-	SCF_SENT_DELAYED_TAS		= 0x00004000,
+	SCF_SEND_DELAYED_TAS		= 0x00004000,
 	SCF_ALUA_NON_OPTIMIZED		= 0x00008000,
 	SCF_PASSTHROUGH_SG_TO_MEM_NOALLOC = 0x00020000,
 	SCF_ACK_KREF			= 0x00040000,
+	SCF_COMPARE_AND_WRITE		= 0x00080000,
+	SCF_COMPARE_AND_WRITE_POST	= 0x00100000,
+	SCF_CMD_XCOPY_PASSTHROUGH	= 0x00200000,
 };
 
 /* struct se_dev_entry->lun_flags and struct se_lun->lun_access */
@@ -196,6 +208,10 @@ enum tcm_sense_reason_table {
 	TCM_ADDRESS_OUT_OF_RANGE		= R(0x11),
 	TCM_OUT_OF_RESOURCES			= R(0x12),
 	TCM_PARAMETER_LIST_LENGTH_ERROR		= R(0x13),
+	TCM_MISCOMPARE_VERIFY			= R(0x14),
+	TCM_LOGICAL_BLOCK_GUARD_CHECK_FAILED	= R(0x15),
+	TCM_LOGICAL_BLOCK_APP_TAG_CHECK_FAILED	= R(0x16),
+	TCM_LOGICAL_BLOCK_REF_TAG_CHECK_FAILED	= R(0x17),
 #undef R
 };
 
@@ -218,14 +234,12 @@ enum tcm_tmreq_table {
 
 /* fabric independent task management response values */
 enum tcm_tmrsp_table {
-	TMR_FUNCTION_COMPLETE		= 0,
-	TMR_TASK_DOES_NOT_EXIST		= 1,
-	TMR_LUN_DOES_NOT_EXIST		= 2,
-	TMR_TASK_STILL_ALLEGIANT	= 3,
-	TMR_TASK_FAILOVER_NOT_SUPPORTED	= 4,
-	TMR_TASK_MGMT_FUNCTION_NOT_SUPPORTED	= 5,
-	TMR_FUNCTION_AUTHORIZATION_FAILED = 6,
-	TMR_FUNCTION_REJECTED		= 255,
+	TMR_FUNCTION_FAILED		= 0,
+	TMR_FUNCTION_COMPLETE		= 1,
+	TMR_TASK_DOES_NOT_EXIST		= 2,
+	TMR_LUN_DOES_NOT_EXIST		= 3,
+	TMR_TASK_MGMT_FUNCTION_NOT_SUPPORTED	= 4,
+	TMR_FUNCTION_REJECTED		= 5,
 };
 
 /*
@@ -240,10 +254,28 @@ typedef enum {
 
 struct se_cmd;
 
+struct t10_alua_lba_map_member {
+	struct list_head lba_map_mem_list;
+	int lba_map_mem_alua_state;
+	int lba_map_mem_alua_pg_id;
+};
+
+struct t10_alua_lba_map {
+	u64 lba_map_first_lba;
+	u64 lba_map_last_lba;
+	struct list_head lba_map_list;
+	struct list_head lba_map_mem_list;
+};
+
 struct t10_alua {
 	/* ALUA Target Port Group ID */
 	u16	alua_tg_pt_gps_counter;
 	u32	alua_tg_pt_gps_count;
+	/* Referrals support */
+	spinlock_t lba_map_lock;
+	u32     lba_map_segment_size;
+	u32     lba_map_segment_multiplier;
+	struct list_head lba_map_list;
 	spinlock_t tg_pt_gps_lock;
 	struct se_device *t10_dev;
 	/* Used for default ALUA Target Port Group */
@@ -276,16 +308,16 @@ struct t10_alua_lu_gp_member {
 struct t10_alua_tg_pt_gp {
 	u16	tg_pt_gp_id;
 	int	tg_pt_gp_valid_id;
+	int	tg_pt_gp_alua_supported_states;
+	int	tg_pt_gp_alua_pending_state;
+	int	tg_pt_gp_alua_previous_state;
 	int	tg_pt_gp_alua_access_status;
 	int	tg_pt_gp_alua_access_type;
 	int	tg_pt_gp_nonop_delay_msecs;
 	int	tg_pt_gp_trans_delay_msecs;
-	int	tg_pt_gp_implict_trans_secs;
+	int	tg_pt_gp_implicit_trans_secs;
 	int	tg_pt_gp_pref;
 	int	tg_pt_gp_write_metadata;
-	/* Used by struct t10_alua_tg_pt_gp->tg_pt_gp_md_buf_len */
-#define ALUA_MD_BUF_LEN				1024
-	u32	tg_pt_gp_md_buf_len;
 	u32	tg_pt_gp_members;
 	atomic_t tg_pt_gp_alua_access_state;
 	atomic_t tg_pt_gp_ref_cnt;
@@ -295,6 +327,10 @@ struct t10_alua_tg_pt_gp {
 	struct config_group tg_pt_gp_group;
 	struct list_head tg_pt_gp_list;
 	struct list_head tg_pt_gp_mem_list;
+	struct se_port *tg_pt_gp_alua_port;
+	struct se_node_acl *tg_pt_gp_alua_nacl;
+	struct delayed_work tg_pt_gp_transition_work;
+	struct completion *tg_pt_gp_transition_complete;
 };
 
 struct t10_alua_tg_pt_gp_member {
@@ -339,8 +375,6 @@ struct t10_pr_registration {
 	/* Used during APTPL metadata reading */
 #define PR_APTPL_MAX_TPORT_LEN			256
 	unsigned char pr_tport[PR_APTPL_MAX_TPORT_LEN];
-	/* For writing out live meta data */
-	unsigned char *pr_aptpl_buf;
 	u16 pr_aptpl_rpti;
 	u16 pr_reg_tpgt;
 	/* Reservation effects all target ports */
@@ -374,9 +408,7 @@ struct t10_reservation {
 	/* Activate Persistence across Target Power Loss enabled
 	 * for SCSI device */
 	int pr_aptpl_active;
-	/* Used by struct t10_reservation->pr_aptpl_buf_len */
-#define PR_APTPL_BUF_LEN			8192
-	u32 pr_aptpl_buf_len;
+#define PR_APTPL_BUF_LEN			262144
 	u32 pr_generation;
 	spinlock_t registration_lock;
 	spinlock_t aptpl_reg_lock;
@@ -410,6 +442,44 @@ struct se_tmr_req {
 	struct list_head	tmr_list;
 };
 
+enum target_prot_op {
+	TARGET_PROT_NORMAL	= 0,
+	TARGET_PROT_DIN_INSERT	= (1 << 0),
+	TARGET_PROT_DOUT_INSERT	= (1 << 1),
+	TARGET_PROT_DIN_STRIP	= (1 << 2),
+	TARGET_PROT_DOUT_STRIP	= (1 << 3),
+	TARGET_PROT_DIN_PASS	= (1 << 4),
+	TARGET_PROT_DOUT_PASS	= (1 << 5),
+};
+
+#define TARGET_PROT_ALL	TARGET_PROT_DIN_INSERT | TARGET_PROT_DOUT_INSERT | \
+			TARGET_PROT_DIN_STRIP | TARGET_PROT_DOUT_STRIP | \
+			TARGET_PROT_DIN_PASS | TARGET_PROT_DOUT_PASS
+
+enum target_prot_ho {
+	PROT_SEPERATED,
+	PROT_INTERLEAVED,
+};
+
+enum target_prot_type {
+	TARGET_DIF_TYPE0_PROT,
+	TARGET_DIF_TYPE1_PROT,
+	TARGET_DIF_TYPE2_PROT,
+	TARGET_DIF_TYPE3_PROT,
+};
+
+enum target_core_dif_check {
+	TARGET_DIF_CHECK_GUARD  = 0x1 << 0,
+	TARGET_DIF_CHECK_APPTAG = 0x1 << 1,
+	TARGET_DIF_CHECK_REFTAG = 0x1 << 2,
+};
+
+struct se_dif_v1_tuple {
+	__be16			guard_tag;
+	__be16			app_tag;
+	__be32			ref_tag;
+};
+
 struct se_cmd {
 	/* SAM response code being sent to initiator */
 	u8			scsi_status;
@@ -422,10 +492,10 @@ struct se_cmd {
 	enum dma_data_direction	data_direction;
 	/* For SAM Task Attribute */
 	int			sam_task_attr;
+	/* Used for se_sess->sess_tag_pool */
+	unsigned int		map_tag;
 	/* Transport protocol dependent state, see transport_state_table */
 	enum transport_state_table t_state;
-	/* Used to signal cmd->se_tfo->check_release_cmd() usage per cmd */
-	unsigned		check_release:1;
 	unsigned		cmd_wait_set:1;
 	unsigned		unknown_data_length:1;
 	/* See se_cmd_flags_table */
@@ -440,7 +510,6 @@ struct se_cmd {
 	/* Used for sense data */
 	void			*sense_buffer;
 	struct list_head	se_delayed_node;
-	struct list_head	se_lun_node;
 	struct list_head	se_qf_node;
 	struct se_device      *se_dev;
 	struct se_dev_entry   *se_deve;
@@ -453,33 +522,34 @@ struct se_cmd {
 	struct kref		cmd_kref;
 	struct target_core_fabric_ops *se_tfo;
 	sense_reason_t		(*execute_cmd)(struct se_cmd *);
-	void (*transport_complete_callback)(struct se_cmd *);
+	sense_reason_t		(*execute_rw)(struct se_cmd *, struct scatterlist *,
+					      u32, enum dma_data_direction);
+	sense_reason_t (*transport_complete_callback)(struct se_cmd *, bool, int *);
 
 	unsigned char		*t_task_cdb;
 	unsigned char		__t_task_cdb[TCM_MAX_COMMAND_SIZE];
 	unsigned long long	t_task_lba;
-	atomic_t		t_fe_count;
+	unsigned int		t_task_nolb;
 	unsigned int		transport_state;
 #define CMD_T_ABORTED		(1 << 0)
 #define CMD_T_ACTIVE		(1 << 1)
 #define CMD_T_COMPLETE		(1 << 2)
 #define CMD_T_SENT		(1 << 4)
 #define CMD_T_STOP		(1 << 5)
-#define CMD_T_FAILED		(1 << 6)
-#define CMD_T_LUN_STOP		(1 << 7)
-#define CMD_T_LUN_FE_STOP	(1 << 8)
-#define CMD_T_DEV_ACTIVE	(1 << 9)
-#define CMD_T_REQUEST_STOP	(1 << 10)
-#define CMD_T_BUSY		(1 << 11)
+#define CMD_T_DEV_ACTIVE	(1 << 7)
+#define CMD_T_REQUEST_STOP	(1 << 8)
+#define CMD_T_BUSY		(1 << 9)
+#define CMD_T_TAS		(1 << 10)
+#define CMD_T_FABRIC_STOP	(1 << 11)
 	spinlock_t		t_state_lock;
 	struct completion	t_transport_stop_comp;
-	struct completion	transport_lun_fe_stop_comp;
-	struct completion	transport_lun_stop_comp;
 
 	struct work_struct	work;
 
 	struct scatterlist	*t_data_sg;
+	struct scatterlist	*t_data_sg_orig;
 	unsigned int		t_data_nents;
+	unsigned int		t_data_nents_orig;
 	void			*t_data_vmap;
 	struct scatterlist	*t_bidi_data_sg;
 	unsigned int		t_bidi_data_nents;
@@ -492,13 +562,28 @@ struct se_cmd {
 
 	/* backend private data */
 	void			*priv;
+
+	/* Used for lun->lun_ref counting */
+	int			lun_ref_active;
+
+	/* DIF related members */
+	enum target_prot_op	prot_op;
+	enum target_prot_type	prot_type;
+	u8			prot_checks;
+	u32			prot_length;
+	u32			reftag_seed;
+	struct scatterlist	*t_prot_sg;
+	unsigned int		t_prot_nents;
+	enum target_prot_ho	prot_handover;
+	sense_reason_t		pi_err;
+	sector_t		bad_sector;
+	bool			prot_pto;
 };
 
 struct se_ua {
 	u8			ua_asc;
 	u8			ua_ascq;
 	struct se_node_acl	*ua_nacl;
-	struct list_head	ua_dev_list;
 	struct list_head	ua_nacl_list;
 };
 
@@ -511,10 +596,6 @@ struct se_node_acl {
 	u32			acl_index;
 #define MAX_ACL_TAG_SIZE 64
 	char			acl_tag[MAX_ACL_TAG_SIZE];
-	u64			num_cmds;
-	u64			read_bytes;
-	u64			write_bytes;
-	spinlock_t		stats_lock;
 	/* Used for PR SPEC_I_PT=1 and REGISTER_AND_MOVE */
 	atomic_t		acl_pr_ref_count;
 	struct se_dev_entry	**device_list;
@@ -537,6 +618,7 @@ struct se_node_acl {
 struct se_session {
 	unsigned		sess_tearing_down:1;
 	u64			sess_bin_isid;
+	enum target_prot_op	sup_prot_ops;
 	struct se_node_acl	*se_node_acl;
 	struct se_portal_group *se_tpg;
 	void			*fabric_sess_ptr;
@@ -546,6 +628,8 @@ struct se_session {
 	struct list_head	sess_wait_list;
 	spinlock_t		sess_cmd_lock;
 	struct kref		sess_kref;
+	void			*sess_cmd_map;
+	struct percpu_ida	sess_tag_pool;
 };
 
 struct se_device;
@@ -599,6 +683,11 @@ struct se_dev_attrib {
 	int		emulate_tas;
 	int		emulate_tpu;
 	int		emulate_tpws;
+	int		emulate_caw;
+	int		emulate_3pc;
+	int		pi_prot_format;
+	enum target_prot_type pi_prot_type;
+	enum target_prot_type hw_pi_prot_type;
 	int		enforce_pr_isids;
 	int		is_nonrot;
 	int		emulate_rest_reord;
@@ -614,10 +703,39 @@ struct se_dev_attrib {
 	u32		unmap_granularity;
 	u32		unmap_granularity_alignment;
 	u32		max_write_same_len;
+	u32		max_bytes_per_io;
 	struct se_device *da_dev;
 	struct config_group da_group;
 };
 
+struct se_port_stat_grps {
+	struct config_group stat_group;
+	struct config_group scsi_port_group;
+	struct config_group scsi_tgt_port_group;
+	struct config_group scsi_transport_group;
+};
+
+struct se_lun {
+#define SE_LUN_LINK_MAGIC			0xffff7771
+	u32			lun_link_magic;
+	/* See transport_lun_status_table */
+	enum transport_lun_status_table lun_status;
+	u32			lun_access;
+	u32			lun_flags;
+	u32			unpacked_lun;
+	atomic_t		lun_acl_count;
+	spinlock_t		lun_acl_lock;
+	spinlock_t		lun_sep_lock;
+	struct completion	lun_shutdown_comp;
+	struct list_head	lun_acl_list;
+	struct se_device	*lun_se_dev;
+	struct se_port		*lun_sep;
+	struct config_group	lun_group;
+	struct se_port_stat_grps port_stat_grps;
+	struct completion	lun_ref_comp;
+	struct percpu_ref	lun_ref;
+};
+
 struct se_dev_stat_grps {
 	struct config_group stat_group;
 	struct config_group scsi_dev_group;
@@ -646,11 +764,10 @@ struct se_device {
 	/* Pointer to transport specific device structure */
 	u32			dev_index;
 	u64			creation_time;
-	u32			num_resets;
-	u64			num_cmds;
-	u64			read_bytes;
-	u64			write_bytes;
-	spinlock_t		stats_lock;
+	atomic_long_t		num_resets;
+	atomic_long_t		num_cmds;
+	atomic_long_t		read_bytes;
+	atomic_long_t		write_bytes;
 	/* Active commands on this virtual SE device */
 	atomic_t		simple_cmds;
 	atomic_t		dev_ordered_id;
@@ -666,6 +783,7 @@ struct se_device {
 	spinlock_t		se_port_lock;
 	spinlock_t		se_tmr_lock;
 	spinlock_t		qf_cmd_lock;
+	struct semaphore	caw_sem;
 	/* Used for legacy SPC-2 reservationsa */
 	struct se_node_acl	*dev_reserved_node_acl;
 	/* Used for ALUA Logical Unit Group membership */
@@ -679,6 +797,7 @@ struct se_device {
 	struct list_head	delayed_cmd_list;
 	struct list_head	state_list;
 	struct list_head	qf_cmd_list;
+	struct list_head	g_dev_node;
 	/* Pointer to associated SE HBA */
 	struct se_hba		*se_hba;
 	/* T10 Inquiry and VPD WWN Information */
@@ -699,6 +818,9 @@ struct se_device {
 	struct se_subsystem_api *transport;
 	/* Linked list for struct se_hba struct se_device list */
 	struct list_head	dev_list;
+	struct se_lun		xcopy_lun;
+	/* Protection Information */
+	int			prot_length;
 };
 
 struct se_hba {
@@ -718,34 +840,6 @@ struct se_hba {
 	struct se_subsystem_api *transport;
 };
 
-struct se_port_stat_grps {
-	struct config_group stat_group;
-	struct config_group scsi_port_group;
-	struct config_group scsi_tgt_port_group;
-	struct config_group scsi_transport_group;
-};
-
-struct se_lun {
-#define SE_LUN_LINK_MAGIC			0xffff7771
-	u32			lun_link_magic;
-	/* See transport_lun_status_table */
-	enum transport_lun_status_table lun_status;
-	u32			lun_access;
-	u32			lun_flags;
-	u32			unpacked_lun;
-	atomic_t		lun_acl_count;
-	spinlock_t		lun_acl_lock;
-	spinlock_t		lun_cmd_lock;
-	spinlock_t		lun_sep_lock;
-	struct completion	lun_shutdown_comp;
-	struct list_head	lun_cmd_list;
-	struct list_head	lun_acl_list;
-	struct se_device	*lun_se_dev;
-	struct se_port		*lun_sep;
-	struct config_group	lun_group;
-	struct se_port_stat_grps port_stat_grps;
-};
-
 struct scsi_port_stats {
        u64     cmd_pdus;
        u64     tx_data_octets;
@@ -802,11 +896,12 @@ struct se_portal_group {
 	struct target_core_fabric_ops *se_tpg_tfo;
 	struct se_wwn		*se_tpg_wwn;
 	struct config_group	tpg_group;
-	struct config_group	*tpg_default_groups[6];
+	struct config_group	*tpg_default_groups[7];
 	struct config_group	tpg_lun_group;
 	struct config_group	tpg_np_group;
 	struct config_group	tpg_acl_group;
 	struct config_group	tpg_attrib_group;
+	struct config_group	tpg_auth_group;
 	struct config_group	tpg_param_group;
 };
 
diff --git a/include/target/target_core_configfs.h b/include/target/target_core_configfs.h
index 61250959..e080138 100644
--- a/include/target/target_core_configfs.h
+++ b/include/target/target_core_configfs.h
@@ -23,6 +23,7 @@ struct target_fabric_configfs_template {
 	struct config_item_type tfc_tpg_np_cit;
 	struct config_item_type tfc_tpg_np_base_cit;
 	struct config_item_type tfc_tpg_attrib_cit;
+	struct config_item_type tfc_tpg_auth_cit;
 	struct config_item_type tfc_tpg_param_cit;
 	struct config_item_type tfc_tpg_nacl_cit;
 	struct config_item_type tfc_tpg_nacl_base_cit;
@@ -53,4 +54,3 @@ struct target_fabric_configfs {
 	struct target_fabric_configfs_template tf_cit_tmpl;
 };
 
-#define TF_CIT_TMPL(tf) (&(tf)->tf_cit_tmpl)
diff --git a/include/target/target_core_fabric.h b/include/target/target_core_fabric.h
index 1dcce9c..1d10436 100644
--- a/include/target/target_core_fabric.h
+++ b/include/target/target_core_fabric.h
@@ -61,7 +61,8 @@ struct target_core_fabric_ops {
 	int (*get_cmd_state)(struct se_cmd *);
 	int (*queue_data_in)(struct se_cmd *);
 	int (*queue_status)(struct se_cmd *);
-	int (*queue_tm_rsp)(struct se_cmd *);
+	void (*queue_tm_rsp)(struct se_cmd *);
+	void (*aborted_task)(struct se_cmd *);
 	/*
 	 * fabric module calls for target_core_fabric_configfs.c
 	 */
@@ -84,6 +85,9 @@ struct target_core_fabric_ops {
 };
 
 struct se_session *transport_init_session(void);
+int transport_alloc_session_tags(struct se_session *, unsigned int,
+		unsigned int);
+struct se_session *transport_init_session_tags(unsigned int, unsigned int);
 void	__transport_register_session(struct se_portal_group *,
 		struct se_node_acl *, struct se_session *, void *);
 void	transport_register_session(struct se_portal_group *,
@@ -102,7 +106,8 @@ sense_reason_t transport_lookup_cmd_lun(struct se_cmd *, u32);
 sense_reason_t target_setup_cmd_from_cdb(struct se_cmd *, unsigned char *);
 int	target_submit_cmd_map_sgls(struct se_cmd *, struct se_session *,
 		unsigned char *, unsigned char *, u32, u32, int, int, int,
-		struct scatterlist *, u32, struct scatterlist *, u32);
+		struct scatterlist *, u32, struct scatterlist *, u32,
+		struct scatterlist *, u32);
 int	target_submit_cmd(struct se_cmd *, struct se_session *, unsigned char *,
 		unsigned char *, u32, u32, int, int, int);
 int	target_submit_tmr(struct se_cmd *se_cmd, struct se_session *se_sess,
@@ -131,8 +136,11 @@ int	core_tmr_alloc_req(struct se_cmd *, void *, u8, gfp_t);
 void	core_tmr_release_req(struct se_tmr_req *);
 int	transport_generic_handle_tmr(struct se_cmd *);
 void	transport_generic_request_failure(struct se_cmd *, sense_reason_t);
+void	__target_execute_cmd(struct se_cmd *);
 int	transport_lookup_tmr_lun(struct se_cmd *, u32);
 
+struct se_node_acl *core_tpg_get_initiator_node_acl(struct se_portal_group *tpg,
+		unsigned char *);
 struct se_node_acl *core_tpg_check_initiator_node_acl(struct se_portal_group *,
 		unsigned char *);
 void	core_tpg_clear_object_luns(struct se_portal_group *);
@@ -175,4 +183,30 @@ u32	iscsi_get_pr_transport_id_len(struct se_portal_group *, struct se_node_acl *
 char	*iscsi_parse_pr_out_transport_id(struct se_portal_group *, const char *,
 		u32 *, char **);
 
+/*
+ * The LIO target core uses DMA_TO_DEVICE to mean that data is going
+ * to the target (eg handling a WRITE) and DMA_FROM_DEVICE to mean
+ * that data is coming from the target (eg handling a READ).  However,
+ * this is just the opposite of what we have to tell the DMA mapping
+ * layer -- eg when handling a READ, the HBA will have to DMA the data
+ * out of memory so it can send it to the initiator, which means we
+ * need to use DMA_TO_DEVICE when we map the data.
+ */
+static inline enum dma_data_direction
+target_reverse_dma_direction(struct se_cmd *se_cmd)
+{
+	if (se_cmd->se_cmd_flags & SCF_BIDI)
+		return DMA_BIDIRECTIONAL;
+
+	switch (se_cmd->data_direction) {
+	case DMA_TO_DEVICE:
+		return DMA_FROM_DEVICE;
+	case DMA_FROM_DEVICE:
+		return DMA_TO_DEVICE;
+	case DMA_NONE:
+	default:
+		return DMA_NONE;
+	}
+}
+
 #endif /* TARGET_CORE_FABRICH */
diff --git a/include/target/target_core_fabric_configfs.h b/include/target/target_core_fabric_configfs.h
index a26fb75..b32a149 100644
--- a/include/target/target_core_fabric_configfs.h
+++ b/include/target/target_core_fabric_configfs.h
@@ -62,6 +62,17 @@ static struct target_fabric_tpg_attrib_attribute _fabric##_tpg_attrib_##_name =
 	_fabric##_tpg_attrib_show_##_name,				\
 	_fabric##_tpg_attrib_store_##_name);
 
+CONFIGFS_EATTR_STRUCT(target_fabric_tpg_auth, se_portal_group);
+#define TF_TPG_AUTH_ATTR(_fabric, _name, _mode) 			\
+static struct target_fabric_tpg_auth_attribute _fabric##_tpg_auth_##_name = \
+	__CONFIGFS_EATTR(_name, _mode,					\
+	_fabric##_tpg_auth_show_##_name,				\
+	_fabric##_tpg_auth_store_##_name);
+
+#define TF_TPG_AUTH_ATTR_RO(_fabric, _name)				\
+static struct target_fabric_tpg_auth_attribute _fabric##_tpg_auth_##_name = \
+	__CONFIGFS_EATTR_RO(_name,					\
+	_fabric##_tpg_auth_show_##_name);
 
 CONFIGFS_EATTR_STRUCT(target_fabric_tpg_param, se_portal_group);
 #define TF_TPG_PARAM_ATTR(_fabric, _name, _mode)			\
diff --git a/include/trace/events/target.h b/include/trace/events/target.h
new file mode 100644
index 00000000..da9cc0f
--- /dev/null
+++ b/include/trace/events/target.h
@@ -0,0 +1,214 @@
+#undef TRACE_SYSTEM
+#define TRACE_SYSTEM target
+
+#if !defined(_TRACE_TARGET_H) || defined(TRACE_HEADER_MULTI_READ)
+#define _TRACE_TARGET_H
+
+#include <linux/tracepoint.h>
+#include <linux/trace_seq.h>
+#include <scsi/scsi.h>
+#include <scsi/scsi_tcq.h>
+#include <target/target_core_base.h>
+
+/* cribbed verbatim from <trace/event/scsi.h> */
+#define scsi_opcode_name(opcode)	{ opcode, #opcode }
+#define show_opcode_name(val)					\
+	__print_symbolic(val,					\
+		scsi_opcode_name(TEST_UNIT_READY),		\
+		scsi_opcode_name(REZERO_UNIT),			\
+		scsi_opcode_name(REQUEST_SENSE),		\
+		scsi_opcode_name(FORMAT_UNIT),			\
+		scsi_opcode_name(READ_BLOCK_LIMITS),		\
+		scsi_opcode_name(REASSIGN_BLOCKS),		\
+		scsi_opcode_name(INITIALIZE_ELEMENT_STATUS),	\
+		scsi_opcode_name(READ_6),			\
+		scsi_opcode_name(WRITE_6),			\
+		scsi_opcode_name(SEEK_6),			\
+		scsi_opcode_name(READ_REVERSE),			\
+		scsi_opcode_name(WRITE_FILEMARKS),		\
+		scsi_opcode_name(SPACE),			\
+		scsi_opcode_name(INQUIRY),			\
+		scsi_opcode_name(RECOVER_BUFFERED_DATA),	\
+		scsi_opcode_name(MODE_SELECT),			\
+		scsi_opcode_name(RESERVE),			\
+		scsi_opcode_name(RELEASE),			\
+		scsi_opcode_name(COPY),				\
+		scsi_opcode_name(ERASE),			\
+		scsi_opcode_name(MODE_SENSE),			\
+		scsi_opcode_name(START_STOP),			\
+		scsi_opcode_name(RECEIVE_DIAGNOSTIC),		\
+		scsi_opcode_name(SEND_DIAGNOSTIC),		\
+		scsi_opcode_name(ALLOW_MEDIUM_REMOVAL),		\
+		scsi_opcode_name(SET_WINDOW),			\
+		scsi_opcode_name(READ_CAPACITY),		\
+		scsi_opcode_name(READ_10),			\
+		scsi_opcode_name(WRITE_10),			\
+		scsi_opcode_name(SEEK_10),			\
+		scsi_opcode_name(POSITION_TO_ELEMENT),		\
+		scsi_opcode_name(WRITE_VERIFY),			\
+		scsi_opcode_name(VERIFY),			\
+		scsi_opcode_name(SEARCH_HIGH),			\
+		scsi_opcode_name(SEARCH_EQUAL),			\
+		scsi_opcode_name(SEARCH_LOW),			\
+		scsi_opcode_name(SET_LIMITS),			\
+		scsi_opcode_name(PRE_FETCH),			\
+		scsi_opcode_name(READ_POSITION),		\
+		scsi_opcode_name(SYNCHRONIZE_CACHE),		\
+		scsi_opcode_name(LOCK_UNLOCK_CACHE),		\
+		scsi_opcode_name(READ_DEFECT_DATA),		\
+		scsi_opcode_name(MEDIUM_SCAN),			\
+		scsi_opcode_name(COMPARE),			\
+		scsi_opcode_name(COPY_VERIFY),			\
+		scsi_opcode_name(WRITE_BUFFER),			\
+		scsi_opcode_name(READ_BUFFER),			\
+		scsi_opcode_name(UPDATE_BLOCK),			\
+		scsi_opcode_name(READ_LONG),			\
+		scsi_opcode_name(WRITE_LONG),			\
+		scsi_opcode_name(CHANGE_DEFINITION),		\
+		scsi_opcode_name(WRITE_SAME),			\
+		scsi_opcode_name(UNMAP),			\
+		scsi_opcode_name(READ_TOC),			\
+		scsi_opcode_name(LOG_SELECT),			\
+		scsi_opcode_name(LOG_SENSE),			\
+		scsi_opcode_name(XDWRITEREAD_10),		\
+		scsi_opcode_name(MODE_SELECT_10),		\
+		scsi_opcode_name(RESERVE_10),			\
+		scsi_opcode_name(RELEASE_10),			\
+		scsi_opcode_name(MODE_SENSE_10),		\
+		scsi_opcode_name(PERSISTENT_RESERVE_IN),	\
+		scsi_opcode_name(PERSISTENT_RESERVE_OUT),	\
+		scsi_opcode_name(VARIABLE_LENGTH_CMD),		\
+		scsi_opcode_name(REPORT_LUNS),			\
+		scsi_opcode_name(MAINTENANCE_IN),		\
+		scsi_opcode_name(MAINTENANCE_OUT),		\
+		scsi_opcode_name(MOVE_MEDIUM),			\
+		scsi_opcode_name(EXCHANGE_MEDIUM),		\
+		scsi_opcode_name(READ_12),			\
+		scsi_opcode_name(WRITE_12),			\
+		scsi_opcode_name(WRITE_VERIFY_12),		\
+		scsi_opcode_name(SEARCH_HIGH_12),		\
+		scsi_opcode_name(SEARCH_EQUAL_12),		\
+		scsi_opcode_name(SEARCH_LOW_12),		\
+		scsi_opcode_name(READ_ELEMENT_STATUS),		\
+		scsi_opcode_name(SEND_VOLUME_TAG),		\
+		scsi_opcode_name(WRITE_LONG_2),			\
+		scsi_opcode_name(READ_16),			\
+		scsi_opcode_name(WRITE_16),			\
+		scsi_opcode_name(VERIFY_16),			\
+		scsi_opcode_name(WRITE_SAME_16),		\
+		scsi_opcode_name(SERVICE_ACTION_IN),		\
+		scsi_opcode_name(SAI_READ_CAPACITY_16),		\
+		scsi_opcode_name(SAI_GET_LBA_STATUS),		\
+		scsi_opcode_name(MI_REPORT_TARGET_PGS),		\
+		scsi_opcode_name(MO_SET_TARGET_PGS),		\
+		scsi_opcode_name(READ_32),			\
+		scsi_opcode_name(WRITE_32),			\
+		scsi_opcode_name(WRITE_SAME_32),		\
+		scsi_opcode_name(ATA_16),			\
+		scsi_opcode_name(ATA_12))
+
+#define show_task_attribute_name(val)				\
+	__print_symbolic(val,					\
+		{ MSG_SIMPLE_TAG,	"SIMPLE"	},	\
+		{ MSG_HEAD_TAG,		"HEAD"		},	\
+		{ MSG_ORDERED_TAG,	"ORDERED"	},	\
+		{ MSG_ACA_TAG,		"ACA"		} )
+
+#define show_scsi_status_name(val)				\
+	__print_symbolic(val,					\
+		{ SAM_STAT_GOOD,	"GOOD" },		\
+		{ SAM_STAT_CHECK_CONDITION, "CHECK CONDITION" }, \
+		{ SAM_STAT_CONDITION_MET, "CONDITION MET" },	\
+		{ SAM_STAT_BUSY,	"BUSY" },		\
+		{ SAM_STAT_INTERMEDIATE, "INTERMEDIATE" },	\
+		{ SAM_STAT_INTERMEDIATE_CONDITION_MET, "INTERMEDIATE CONDITION MET" }, \
+		{ SAM_STAT_RESERVATION_CONFLICT, "RESERVATION CONFLICT" }, \
+		{ SAM_STAT_COMMAND_TERMINATED, "COMMAND TERMINATED" }, \
+		{ SAM_STAT_TASK_SET_FULL, "TASK SET FULL" },	\
+		{ SAM_STAT_ACA_ACTIVE, "ACA ACTIVE" },		\
+		{ SAM_STAT_TASK_ABORTED, "TASK ABORTED" } )
+
+TRACE_EVENT(target_sequencer_start,
+
+	TP_PROTO(struct se_cmd *cmd),
+
+	TP_ARGS(cmd),
+
+	TP_STRUCT__entry(
+		__field( unsigned int,	unpacked_lun	)
+		__field( unsigned int,	opcode		)
+		__field( unsigned int,	data_length	)
+		__field( unsigned int,	task_attribute  )
+		__array( unsigned char,	cdb, TCM_MAX_COMMAND_SIZE	)
+		__string( initiator,	cmd->se_sess->se_node_acl->initiatorname	)
+	),
+
+	TP_fast_assign(
+		__entry->unpacked_lun	= cmd->orig_fe_lun;
+		__entry->opcode		= cmd->t_task_cdb[0];
+		__entry->data_length	= cmd->data_length;
+		__entry->task_attribute	= cmd->sam_task_attr;
+		memcpy(__entry->cdb, cmd->t_task_cdb, TCM_MAX_COMMAND_SIZE);
+		__assign_str(initiator, cmd->se_sess->se_node_acl->initiatorname);
+	),
+
+	TP_printk("%s -> LUN %03u %s data_length %6u  CDB %s  (TA:%s C:%02x)",
+		  __get_str(initiator), __entry->unpacked_lun,
+		  show_opcode_name(__entry->opcode),
+		  __entry->data_length, __print_hex(__entry->cdb, 16),
+		  show_task_attribute_name(__entry->task_attribute),
+		  scsi_command_size(__entry->cdb) <= 16 ?
+			__entry->cdb[scsi_command_size(__entry->cdb) - 1] :
+			__entry->cdb[1]
+	)
+);
+
+TRACE_EVENT(target_cmd_complete,
+
+	TP_PROTO(struct se_cmd *cmd),
+
+	TP_ARGS(cmd),
+
+	TP_STRUCT__entry(
+		__field( unsigned int,	unpacked_lun	)
+		__field( unsigned int,	opcode		)
+		__field( unsigned int,	data_length	)
+		__field( unsigned int,	task_attribute  )
+		__field( unsigned char,	scsi_status	)
+		__field( unsigned char,	sense_length	)
+		__array( unsigned char,	cdb, TCM_MAX_COMMAND_SIZE	)
+		__array( unsigned char,	sense_data, 18	)
+		__string(initiator,	cmd->se_sess->se_node_acl->initiatorname)
+	),
+
+	TP_fast_assign(
+		__entry->unpacked_lun	= cmd->orig_fe_lun;
+		__entry->opcode		= cmd->t_task_cdb[0];
+		__entry->data_length	= cmd->data_length;
+		__entry->task_attribute	= cmd->sam_task_attr;
+		__entry->scsi_status	= cmd->scsi_status;
+		__entry->sense_length	= cmd->scsi_status == SAM_STAT_CHECK_CONDITION ?
+			min(18, ((u8 *) cmd->sense_buffer)[SPC_ADD_SENSE_LEN_OFFSET] + 8) : 0;
+		memcpy(__entry->cdb, cmd->t_task_cdb, TCM_MAX_COMMAND_SIZE);
+		memcpy(__entry->sense_data, cmd->sense_buffer, __entry->sense_length);
+		__assign_str(initiator, cmd->se_sess->se_node_acl->initiatorname);
+	),
+
+	TP_printk("%s <- LUN %03u status %s (sense len %d%s%s)  %s data_length %6u  CDB %s  (TA:%s C:%02x)",
+		  __get_str(initiator), __entry->unpacked_lun,
+		  show_scsi_status_name(__entry->scsi_status),
+		  __entry->sense_length, __entry->sense_length ? " / " : "",
+		  __print_hex(__entry->sense_data, __entry->sense_length),
+		  show_opcode_name(__entry->opcode),
+		  __entry->data_length, __print_hex(__entry->cdb, 16),
+		  show_task_attribute_name(__entry->task_attribute),
+		  scsi_command_size(__entry->cdb) <= 16 ?
+			__entry->cdb[scsi_command_size(__entry->cdb) - 1] :
+			__entry->cdb[1]
+	)
+);
+
+#endif /*  _TRACE_TARGET_H */
+
+/* This part must be outside protection */
+#include <trace/define_trace.h>
diff --git a/include/uapi/linux/magic.h b/include/uapi/linux/magic.h
index 2944278..ebccf20 100644
--- a/include/uapi/linux/magic.h
+++ b/include/uapi/linux/magic.h
@@ -20,6 +20,10 @@
 #define EFS_SUPER_MAGIC		0x414A53
 #define EXT2_SUPER_MAGIC	0xEF53
 #define EXT3_SUPER_MAGIC	0xEF53
+#ifdef CONFIG_BUFFALO_EXT23_EXTENSION
+#define MEL_EXT2_SUPER_MAGIC	0xEF54
+#define MEL_EXT3_SUPER_MAGIC	0xEF54
+#endif	/* CONFIG_BUFFALO_EXT23_EXTENSION */
 #define XENFS_SUPER_MAGIC	0xabba1974
 #define EXT4_SUPER_MAGIC	0xEF53
 #define BTRFS_SUPER_MAGIC	0x9123683E
@@ -52,6 +56,8 @@
 #define REISER2FS_SUPER_MAGIC_STRING	"ReIsEr2Fs"
 #define REISER2FS_JR_SUPER_MAGIC_STRING	"ReIsEr3Fs"
 
+#define UNIONFS_SUPER_MAGIC 0xf15f083d
+
 #define SMB_SUPER_MAGIC		0x517B
 #define CGROUP_SUPER_MAGIC	0x27e0eb
 
diff --git a/include/uapi/linux/sysctl.h b/include/uapi/linux/sysctl.h
index 6d67213..3699ca5 100644
--- a/include/uapi/linux/sysctl.h
+++ b/include/uapi/linux/sysctl.h
@@ -867,7 +867,17 @@ enum {
 /* /proc/sys/dev/raid */
 enum {
 	DEV_RAID_SPEED_LIMIT_MIN=1,
+#ifdef CONFIG_BUFFALO_PLATFORM
+	DEV_RAID_SPEED_LIMIT_MAX=2,
+#ifdef CONFIG_BUFFALO_SKIP_RESYNC
+	DEV_RAID_SKIP_RESYNC=3,
+#endif	/* CONFIG_BUFFALO_SKIP_RESYNC */
+#ifdef CONFIG_BUFFALO_USE_MD_KERNEVNT
+	DEV_RAID_USE_KERNELEVENT=4,
+#endif	/* CONFIG_BUFFALO_USE_MD_KERNEVNT */
+#else	/* CONFIG_BUFFALO_PLATFORM */
 	DEV_RAID_SPEED_LIMIT_MAX=2
+#endif	/* CONFIG_BUFFALO_PLATFORM */
 };
 
 /* /proc/sys/dev/parport/default */
diff --git a/kernel/fork.c b/kernel/fork.c
index 80d92e9..864bcc8 100644
--- a/kernel/fork.c
+++ b/kernel/fork.c
@@ -431,6 +431,11 @@ static int dup_mmap(struct mm_struct *mm, struct mm_struct *oldmm)
 			else
 				vma_interval_tree_insert_after(tmp, mpnt,
 							&mapping->i_mmap);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+			if (tmp->vm_ops && tmp->vm_ops->update_mapping) {
+				tmp->vm_ops->update_mapping(tmp);
+			}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 			flush_dcache_mmap_unlock(mapping);
 			mutex_unlock(&mapping->i_mmap_mutex);
 		}
diff --git a/kernel/sched/core.c b/kernel/sched/core.c
index e8b3350..9db720d7 100644
--- a/kernel/sched/core.c
+++ b/kernel/sched/core.c
@@ -4340,7 +4340,15 @@ SYSCALL_DEFINE0(sched_yield)
 
 static inline int should_resched(void)
 {
+#ifdef CONFIG_BUFFALO_PLATFORM
+	/* backport from linux-3.13.y to prevent 'scheduling while atomic'
+	 * condition when dump_mem() called from sotrirq context.
+	 *  See https://bts.melco.ne.jp/issues/184812
+	 */
+	return need_resched() && !preempt_count();
+#else /* CONFIG_BUFFALO_PLATFORM */
 	return need_resched() && !(preempt_count() & PREEMPT_ACTIVE);
+#endif /* CONFIG_BUFFALO_PLATFORM */
 }
 
 static void __cond_resched(void)
diff --git a/lib/Makefile b/lib/Makefile
index c55a037..f4dee93 100644
--- a/lib/Makefile
+++ b/lib/Makefile
@@ -89,6 +89,8 @@ obj-$(CONFIG_TEXTSEARCH_KMP) += ts_kmp.o
 obj-$(CONFIG_TEXTSEARCH_BM) += ts_bm.o
 obj-$(CONFIG_TEXTSEARCH_FSM) += ts_fsm.o
 obj-$(CONFIG_SMP) += percpu_counter.o
+obj-$(CONFIG_SMP) += percpu_ida.o
+obj-$(CONFIG_SMP) += percpu-refcount.o
 obj-$(CONFIG_AUDIT_GENERIC) += audit.o
 
 obj-$(CONFIG_SWIOTLB) += swiotlb.o
diff --git a/lib/percpu-refcount.c b/lib/percpu-refcount.c
new file mode 100644
index 00000000..1a53d49
--- /dev/null
+++ b/lib/percpu-refcount.c
@@ -0,0 +1,161 @@
+#define pr_fmt(fmt) "%s: " fmt "\n", __func__
+
+#include <linux/kernel.h>
+#include <linux/percpu-refcount.h>
+
+/*
+ * Initially, a percpu refcount is just a set of percpu counters. Initially, we
+ * don't try to detect the ref hitting 0 - which means that get/put can just
+ * increment or decrement the local counter. Note that the counter on a
+ * particular cpu can (and will) wrap - this is fine, when we go to shutdown the
+ * percpu counters will all sum to the correct value
+ *
+ * (More precisely: because moduler arithmatic is commutative the sum of all the
+ * pcpu_count vars will be equal to what it would have been if all the gets and
+ * puts were done to a single integer, even if some of the percpu integers
+ * overflow or underflow).
+ *
+ * The real trick to implementing percpu refcounts is shutdown. We can't detect
+ * the ref hitting 0 on every put - this would require global synchronization
+ * and defeat the whole purpose of using percpu refs.
+ *
+ * What we do is require the user to keep track of the initial refcount; we know
+ * the ref can't hit 0 before the user drops the initial ref, so as long as we
+ * convert to non percpu mode before the initial ref is dropped everything
+ * works.
+ *
+ * Converting to non percpu mode is done with some RCUish stuff in
+ * percpu_ref_kill. Additionally, we need a bias value so that the atomic_t
+ * can't hit 0 before we've added up all the percpu refs.
+ */
+
+#define PCPU_COUNT_BIAS		(1U << 31)
+
+/**
+ * percpu_ref_init - initialize a percpu refcount
+ * @ref: percpu_ref to initialize
+ * @release: function which will be called when refcount hits 0
+ *
+ * Initializes the refcount in single atomic counter mode with a refcount of 1;
+ * analagous to atomic_set(ref, 1).
+ *
+ * Note that @release must not sleep - it may potentially be called from RCU
+ * callback context by percpu_ref_kill().
+ */
+int percpu_ref_init(struct percpu_ref *ref, percpu_ref_func_t *release)
+{
+	atomic_set(&ref->count, 1 + PCPU_COUNT_BIAS);
+
+	ref->pcpu_count = alloc_percpu(unsigned);
+	if (!ref->pcpu_count)
+		return -ENOMEM;
+
+	ref->release = release;
+	return 0;
+}
+EXPORT_SYMBOL_GPL(percpu_ref_init);
+
+/**
+ * percpu_ref_cancel_init - cancel percpu_ref_init()
+ * @ref: percpu_ref to cancel init for
+ *
+ * Once a percpu_ref is initialized, its destruction is initiated by
+ * percpu_ref_kill() and completes asynchronously, which can be painful to
+ * do when destroying a half-constructed object in init failure path.
+ *
+ * This function destroys @ref without invoking @ref->release and the
+ * memory area containing it can be freed immediately on return.  To
+ * prevent accidental misuse, it's required that @ref has finished
+ * percpu_ref_init(), whether successful or not, but never used.
+ *
+ * The weird name and usage restriction are to prevent people from using
+ * this function by mistake for normal shutdown instead of
+ * percpu_ref_kill().
+ */
+void percpu_ref_cancel_init(struct percpu_ref *ref)
+{
+	unsigned __percpu *pcpu_count = ref->pcpu_count;
+	int cpu;
+
+	WARN_ON_ONCE(atomic_read(&ref->count) != 1 + PCPU_COUNT_BIAS);
+
+	if (pcpu_count) {
+		for_each_possible_cpu(cpu)
+			WARN_ON_ONCE(*per_cpu_ptr(pcpu_count, cpu));
+		free_percpu(ref->pcpu_count);
+	}
+}
+EXPORT_SYMBOL_GPL(percpu_ref_cancel_init);
+
+static void percpu_ref_kill_rcu(struct rcu_head *rcu)
+{
+	struct percpu_ref *ref = container_of(rcu, struct percpu_ref, rcu);
+	unsigned __percpu *pcpu_count = ref->pcpu_count;
+	unsigned count = 0;
+	int cpu;
+
+	/* Mask out PCPU_REF_DEAD */
+	pcpu_count = (unsigned __percpu *)
+		(((unsigned long) pcpu_count) & ~PCPU_STATUS_MASK);
+
+	for_each_possible_cpu(cpu)
+		count += *per_cpu_ptr(pcpu_count, cpu);
+
+	free_percpu(pcpu_count);
+
+	pr_debug("global %i pcpu %i", atomic_read(&ref->count), (int) count);
+
+	/*
+	 * It's crucial that we sum the percpu counters _before_ adding the sum
+	 * to &ref->count; since gets could be happening on one cpu while puts
+	 * happen on another, adding a single cpu's count could cause
+	 * @ref->count to hit 0 before we've got a consistent value - but the
+	 * sum of all the counts will be consistent and correct.
+	 *
+	 * Subtracting the bias value then has to happen _after_ adding count to
+	 * &ref->count; we need the bias value to prevent &ref->count from
+	 * reaching 0 before we add the percpu counts. But doing it at the same
+	 * time is equivalent and saves us atomic operations:
+	 */
+
+	atomic_add((int) count - PCPU_COUNT_BIAS, &ref->count);
+
+	/* @ref is viewed as dead on all CPUs, send out kill confirmation */
+	if (ref->confirm_kill)
+		ref->confirm_kill(ref);
+
+	/*
+	 * Now we're in single atomic_t mode with a consistent refcount, so it's
+	 * safe to drop our initial ref:
+	 */
+	percpu_ref_put(ref);
+}
+
+/**
+ * percpu_ref_kill_and_confirm - drop the initial ref and schedule confirmation
+ * @ref: percpu_ref to kill
+ * @confirm_kill: optional confirmation callback
+ *
+ * Equivalent to percpu_ref_kill() but also schedules kill confirmation if
+ * @confirm_kill is not NULL.  @confirm_kill, which may not block, will be
+ * called after @ref is seen as dead from all CPUs - all further
+ * invocations of percpu_ref_tryget() will fail.  See percpu_ref_tryget()
+ * for more details.
+ *
+ * Due to the way percpu_ref is implemented, @confirm_kill will be called
+ * after at least one full RCU grace period has passed but this is an
+ * implementation detail and callers must not depend on it.
+ */
+void percpu_ref_kill_and_confirm(struct percpu_ref *ref,
+				 percpu_ref_func_t *confirm_kill)
+{
+	WARN_ONCE(REF_STATUS(ref->pcpu_count) == PCPU_REF_DEAD,
+		  "percpu_ref_kill() called more than once!\n");
+
+	ref->pcpu_count = (unsigned __percpu *)
+		(((unsigned long) ref->pcpu_count)|PCPU_REF_DEAD);
+	ref->confirm_kill = confirm_kill;
+
+	call_rcu_sched(&ref->rcu, percpu_ref_kill_rcu);
+}
+EXPORT_SYMBOL_GPL(percpu_ref_kill_and_confirm);
diff --git a/lib/percpu_ida.c b/lib/percpu_ida.c
new file mode 100644
index 00000000..7be235f
--- /dev/null
+++ b/lib/percpu_ida.c
@@ -0,0 +1,396 @@
+/*
+ * Percpu IDA library
+ *
+ * Copyright (C) 2013 Datera, Inc. Kent Overstreet
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2, or (at
+ * your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ */
+
+#include <linux/bitmap.h>
+#include <linux/bitops.h>
+#include <linux/bug.h>
+#include <linux/err.h>
+#include <linux/export.h>
+#include <linux/hardirq.h>
+#include <linux/idr.h>
+#include <linux/init.h>
+#include <linux/kernel.h>
+#include <linux/percpu.h>
+#include <linux/sched.h>
+#include <linux/slab.h>
+#include <linux/string.h>
+#include <linux/spinlock.h>
+#include <linux/percpu_ida.h>
+
+struct percpu_ida_cpu {
+	/*
+	 * Even though this is percpu, we need a lock for tag stealing by remote
+	 * CPUs:
+	 */
+	spinlock_t			lock;
+
+	/* nr_free/freelist form a stack of free IDs */
+	unsigned			nr_free;
+	unsigned			freelist[];
+};
+
+static inline void move_tags(unsigned *dst, unsigned *dst_nr,
+			     unsigned *src, unsigned *src_nr,
+			     unsigned nr)
+{
+	*src_nr -= nr;
+	memcpy(dst + *dst_nr, src + *src_nr, sizeof(unsigned) * nr);
+	*dst_nr += nr;
+}
+
+/*
+ * Try to steal tags from a remote cpu's percpu freelist.
+ *
+ * We first check how many percpu freelists have tags - we don't steal tags
+ * unless enough percpu freelists have tags on them that it's possible more than
+ * half the total tags could be stuck on remote percpu freelists.
+ *
+ * Then we iterate through the cpus until we find some tags - we don't attempt
+ * to find the "best" cpu to steal from, to keep cacheline bouncing to a
+ * minimum.
+ */
+static inline void steal_tags(struct percpu_ida *pool,
+			      struct percpu_ida_cpu *tags)
+{
+	unsigned cpus_have_tags, cpu = pool->cpu_last_stolen;
+	struct percpu_ida_cpu *remote;
+
+	for (cpus_have_tags = cpumask_weight(&pool->cpus_have_tags);
+	     cpus_have_tags * pool->percpu_max_size > pool->nr_tags / 2;
+	     cpus_have_tags--) {
+		cpu = cpumask_next(cpu, &pool->cpus_have_tags);
+
+		if (cpu >= nr_cpu_ids) {
+			cpu = cpumask_first(&pool->cpus_have_tags);
+			if (cpu >= nr_cpu_ids)
+				BUG();
+		}
+
+		pool->cpu_last_stolen = cpu;
+		remote = per_cpu_ptr(pool->tag_cpu, cpu);
+
+		cpumask_clear_cpu(cpu, &pool->cpus_have_tags);
+
+		if (remote == tags)
+			continue;
+
+		spin_lock(&remote->lock);
+
+		if (remote->nr_free) {
+			memcpy(tags->freelist,
+			       remote->freelist,
+			       sizeof(unsigned) * remote->nr_free);
+
+			tags->nr_free = remote->nr_free;
+			remote->nr_free = 0;
+		}
+
+		spin_unlock(&remote->lock);
+
+		if (tags->nr_free)
+			break;
+	}
+}
+
+/*
+ * Pop up to IDA_PCPU_BATCH_MOVE IDs off the global freelist, and push them onto
+ * our percpu freelist:
+ */
+static inline void alloc_global_tags(struct percpu_ida *pool,
+				     struct percpu_ida_cpu *tags)
+{
+	move_tags(tags->freelist, &tags->nr_free,
+		  pool->freelist, &pool->nr_free,
+		  min(pool->nr_free, pool->percpu_batch_size));
+}
+
+static inline unsigned alloc_local_tag(struct percpu_ida_cpu *tags)
+{
+	int tag = -ENOSPC;
+
+	spin_lock(&tags->lock);
+	if (tags->nr_free)
+		tag = tags->freelist[--tags->nr_free];
+	spin_unlock(&tags->lock);
+
+	return tag;
+}
+
+/**
+ * percpu_ida_alloc - allocate a tag
+ * @pool: pool to allocate from
+ * @state: task state for prepare_to_wait
+ *
+ * Returns a tag - an integer in the range [0..nr_tags) (passed to
+ * tag_pool_init()), or otherwise -ENOSPC on allocation failure.
+ *
+ * Safe to be called from interrupt context (assuming it isn't passed
+ * TASK_UNINTERRUPTIBLE | TASK_INTERRUPTIBLE, of course).
+ *
+ * @gfp indicates whether or not to wait until a free id is available (it's not
+ * used for internal memory allocations); thus if passed __GFP_WAIT we may sleep
+ * however long it takes until another thread frees an id (same semantics as a
+ * mempool).
+ *
+ * Will not fail if passed TASK_UNINTERRUPTIBLE | TASK_INTERRUPTIBLE.
+ */
+int percpu_ida_alloc(struct percpu_ida *pool, int state)
+{
+	DEFINE_WAIT(wait);
+	struct percpu_ida_cpu *tags;
+	unsigned long flags;
+	int tag;
+
+	local_irq_save(flags);
+	tags = this_cpu_ptr(pool->tag_cpu);
+
+	/* Fastpath */
+	tag = alloc_local_tag(tags);
+	if (likely(tag >= 0)) {
+		local_irq_restore(flags);
+		return tag;
+	}
+
+	while (1) {
+		spin_lock(&pool->lock);
+
+		/*
+		 * prepare_to_wait() must come before steal_tags(), in case
+		 * percpu_ida_free() on another cpu flips a bit in
+		 * cpus_have_tags
+		 *
+		 * global lock held and irqs disabled, don't need percpu lock
+		 */
+		if (state != TASK_RUNNING)
+			prepare_to_wait(&pool->wait, &wait, state);
+
+		if (!tags->nr_free)
+			alloc_global_tags(pool, tags);
+		if (!tags->nr_free)
+			steal_tags(pool, tags);
+
+		if (tags->nr_free) {
+			tag = tags->freelist[--tags->nr_free];
+			if (tags->nr_free)
+				cpumask_set_cpu(smp_processor_id(),
+						&pool->cpus_have_tags);
+		}
+
+		spin_unlock(&pool->lock);
+		local_irq_restore(flags);
+
+		if (tag >= 0 || state == TASK_RUNNING)
+			break;
+
+		if (signal_pending_state(state, current)) {
+			tag = -ERESTARTSYS;
+			break;
+		}
+
+		schedule();
+
+		local_irq_save(flags);
+		tags = this_cpu_ptr(pool->tag_cpu);
+	}
+	if (state != TASK_RUNNING)
+		finish_wait(&pool->wait, &wait);
+
+	return tag;
+}
+EXPORT_SYMBOL_GPL(percpu_ida_alloc);
+
+/**
+ * percpu_ida_free - free a tag
+ * @pool: pool @tag was allocated from
+ * @tag: a tag previously allocated with percpu_ida_alloc()
+ *
+ * Safe to be called from interrupt context.
+ */
+void percpu_ida_free(struct percpu_ida *pool, unsigned tag)
+{
+	struct percpu_ida_cpu *tags;
+	unsigned long flags;
+	unsigned nr_free;
+
+	BUG_ON(tag >= pool->nr_tags);
+
+	local_irq_save(flags);
+	tags = this_cpu_ptr(pool->tag_cpu);
+
+	spin_lock(&tags->lock);
+	tags->freelist[tags->nr_free++] = tag;
+
+	nr_free = tags->nr_free;
+	spin_unlock(&tags->lock);
+
+	if (nr_free == 1) {
+		cpumask_set_cpu(smp_processor_id(),
+				&pool->cpus_have_tags);
+		wake_up(&pool->wait);
+	}
+
+	if (nr_free == pool->percpu_max_size) {
+		spin_lock(&pool->lock);
+
+		/*
+		 * Global lock held and irqs disabled, don't need percpu
+		 * lock
+		 */
+		if (tags->nr_free == pool->percpu_max_size) {
+			move_tags(pool->freelist, &pool->nr_free,
+				  tags->freelist, &tags->nr_free,
+				  pool->percpu_batch_size);
+
+			wake_up(&pool->wait);
+		}
+		spin_unlock(&pool->lock);
+	}
+
+	local_irq_restore(flags);
+}
+EXPORT_SYMBOL_GPL(percpu_ida_free);
+
+/**
+ * percpu_ida_destroy - release a tag pool's resources
+ * @pool: pool to free
+ *
+ * Frees the resources allocated by percpu_ida_init().
+ */
+void percpu_ida_destroy(struct percpu_ida *pool)
+{
+	free_percpu(pool->tag_cpu);
+	free_pages((unsigned long) pool->freelist,
+		   get_order(pool->nr_tags * sizeof(unsigned)));
+}
+EXPORT_SYMBOL_GPL(percpu_ida_destroy);
+
+/**
+ * percpu_ida_init - initialize a percpu tag pool
+ * @pool: pool to initialize
+ * @nr_tags: number of tags that will be available for allocation
+ *
+ * Initializes @pool so that it can be used to allocate tags - integers in the
+ * range [0, nr_tags). Typically, they'll be used by driver code to refer to a
+ * preallocated array of tag structures.
+ *
+ * Allocation is percpu, but sharding is limited by nr_tags - for best
+ * performance, the workload should not span more cpus than nr_tags / 128.
+ */
+int __percpu_ida_init(struct percpu_ida *pool, unsigned long nr_tags,
+	unsigned long max_size, unsigned long batch_size)
+{
+	unsigned i, cpu, order;
+
+	memset(pool, 0, sizeof(*pool));
+
+	init_waitqueue_head(&pool->wait);
+	spin_lock_init(&pool->lock);
+	pool->nr_tags = nr_tags;
+	pool->percpu_max_size = max_size;
+	pool->percpu_batch_size = batch_size;
+
+	/* Guard against overflow */
+	if (nr_tags > (unsigned) INT_MAX + 1) {
+		pr_err("percpu_ida_init(): nr_tags too large\n");
+		return -EINVAL;
+	}
+
+	order = get_order(nr_tags * sizeof(unsigned));
+	pool->freelist = (void *) __get_free_pages(GFP_KERNEL, order);
+	if (!pool->freelist)
+		return -ENOMEM;
+
+	for (i = 0; i < nr_tags; i++)
+		pool->freelist[i] = i;
+
+	pool->nr_free = nr_tags;
+
+	pool->tag_cpu = __alloc_percpu(sizeof(struct percpu_ida_cpu) +
+				       pool->percpu_max_size * sizeof(unsigned),
+				       sizeof(unsigned));
+	if (!pool->tag_cpu)
+		goto err;
+
+	for_each_possible_cpu(cpu)
+		spin_lock_init(&per_cpu_ptr(pool->tag_cpu, cpu)->lock);
+
+	return 0;
+err:
+	percpu_ida_destroy(pool);
+	return -ENOMEM;
+}
+EXPORT_SYMBOL_GPL(__percpu_ida_init);
+
+/**
+ * percpu_ida_for_each_free - iterate free ids of a pool
+ * @pool: pool to iterate
+ * @fn: interate callback function
+ * @data: parameter for @fn
+ *
+ * Note, this doesn't guarantee to iterate all free ids restrictly. Some free
+ * ids might be missed, some might be iterated duplicated, and some might
+ * be iterated and not free soon.
+ */
+int percpu_ida_for_each_free(struct percpu_ida *pool, percpu_ida_cb fn,
+	void *data)
+{
+	unsigned long flags;
+	struct percpu_ida_cpu *remote;
+	unsigned cpu, i, err = 0;
+
+	local_irq_save(flags);
+	for_each_possible_cpu(cpu) {
+		remote = per_cpu_ptr(pool->tag_cpu, cpu);
+		spin_lock(&remote->lock);
+		for (i = 0; i < remote->nr_free; i++) {
+			err = fn(remote->freelist[i], data);
+			if (err)
+				break;
+		}
+		spin_unlock(&remote->lock);
+		if (err)
+			goto out;
+	}
+
+	spin_lock(&pool->lock);
+	for (i = 0; i < pool->nr_free; i++) {
+		err = fn(pool->freelist[i], data);
+		if (err)
+			break;
+	}
+	spin_unlock(&pool->lock);
+out:
+	local_irq_restore(flags);
+	return err;
+}
+EXPORT_SYMBOL_GPL(percpu_ida_for_each_free);
+
+/**
+ * percpu_ida_free_tags - return free tags number of a specific cpu or global pool
+ * @pool: pool related
+ * @cpu: specific cpu or global pool if @cpu == nr_cpu_ids
+ *
+ * Note: this just returns a snapshot of free tags number.
+ */
+unsigned percpu_ida_free_tags(struct percpu_ida *pool, int cpu)
+{
+	struct percpu_ida_cpu *remote;
+	if (cpu == nr_cpu_ids)
+		return pool->nr_free;
+	remote = per_cpu_ptr(pool->tag_cpu, cpu);
+	return remote->nr_free;
+}
+EXPORT_SYMBOL_GPL(percpu_ida_free_tags);
diff --git a/lib/radix-tree.c b/lib/radix-tree.c
index 86de0b2..6d45441 100644
--- a/lib/radix-tree.c
+++ b/lib/radix-tree.c
@@ -32,6 +32,7 @@
 #include <linux/string.h>
 #include <linux/bitops.h>
 #include <linux/rcupdate.h>
+#include <linux/hardirq.h>		/* in_interrupt() */
 
 #ifdef CONFIG_LFS_ON_32CPU
 #define RADIX_TREE_1	1ULL
@@ -214,7 +215,12 @@ radix_tree_node_alloc(struct radix_tree_root *root)
 	struct radix_tree_node *ret = NULL;
 	gfp_t gfp_mask = root_gfp_mask(root);
 
-	if (!(gfp_mask & __GFP_WAIT)) {
+	/*
+	 * Preload code isn't irq safe and it doesn't make sence to use
+	 * preloading in the interrupt anyway as all the allocations have to
+	 * be atomic. So just do normal allocation when in interrupt.
+	 */
+	if (!(gfp_mask & __GFP_WAIT) && !in_interrupt()) {
 		struct radix_tree_preload *rtp;
 
 		/*
@@ -271,7 +277,7 @@ radix_tree_node_free(struct radix_tree_node *node)
  * To make use of this facility, the radix tree must be initialised without
  * __GFP_WAIT being passed to INIT_RADIX_TREE().
  */
-int radix_tree_preload(gfp_t gfp_mask)
+static int __radix_tree_preload(gfp_t gfp_mask)
 {
 	struct radix_tree_preload *rtp;
 	struct radix_tree_node *node;
@@ -295,9 +301,40 @@ int radix_tree_preload(gfp_t gfp_mask)
 out:
 	return ret;
 }
+
+/*
+ * Load up this CPU's radix_tree_node buffer with sufficient objects to
+ * ensure that the addition of a single element in the tree cannot fail.  On
+ * success, return zero, with preemption disabled.  On error, return -ENOMEM
+ * with preemption not disabled.
+ *
+ * To make use of this facility, the radix tree must be initialised without
+ * __GFP_WAIT being passed to INIT_RADIX_TREE().
+ */
+int radix_tree_preload(gfp_t gfp_mask)
+{
+	/* Warn on non-sensical use... */
+	WARN_ON_ONCE(!(gfp_mask & __GFP_WAIT));
+	return __radix_tree_preload(gfp_mask);
+}
 EXPORT_SYMBOL(radix_tree_preload);
 
 /*
+ * The same as above function, except we don't guarantee preloading happens.
+ * We do it, if we decide it helps. On success, return zero with preemption
+ * disabled. On error, return -ENOMEM with preemption not disabled.
+ */
+int radix_tree_maybe_preload(gfp_t gfp_mask)
+{
+	if (gfp_mask & __GFP_WAIT)
+		return __radix_tree_preload(gfp_mask);
+	/* Preloading doesn't help anything with this gfp mask, skip it */
+	preempt_disable();
+	return 0;
+}
+EXPORT_SYMBOL(radix_tree_maybe_preload);
+
+/*
  *	Return the maximum key which can be store into a
  *	radix tree with height HEIGHT.
  */
diff --git a/mm/backing-dev.c b/mm/backing-dev.c
index 5025174..eea1a9d 100644
--- a/mm/backing-dev.c
+++ b/mm/backing-dev.c
@@ -287,13 +287,19 @@ int bdi_has_dirty_io(struct backing_dev_info *bdi)
  * Note, we wouldn't bother setting up the timer, but this function is on the
  * fast-path (used by '__mark_inode_dirty()'), so we save few context switches
  * by delaying the wake-up.
+ *
+ * We have to be careful not to postpone flush work if it is scheduled for
+ * earlier. Thus we use queue_delayed_work().
  */
 void bdi_wakeup_thread_delayed(struct backing_dev_info *bdi)
 {
 	unsigned long timeout;
 
 	timeout = msecs_to_jiffies(dirty_writeback_interval * 10);
-	mod_delayed_work(bdi_wq, &bdi->wb.dwork, timeout);
+	spin_lock_bh(&bdi->wb_lock);
+	if (test_bit(BDI_registered, &bdi->state))
+		queue_delayed_work(bdi_wq, &bdi->wb.dwork, timeout);
+	spin_unlock_bh(&bdi->wb_lock);
 }
 
 /*
@@ -306,9 +312,6 @@ static void bdi_remove_from_list(struct backing_dev_info *bdi)
 	spin_unlock_bh(&bdi_lock);
 
 	synchronize_rcu_expedited();
-
-	/* bdi_list is now unused, clear it to mark @bdi dying */
-	INIT_LIST_HEAD(&bdi->bdi_list);
 }
 
 int bdi_register(struct backing_dev_info *bdi, struct device *parent,
@@ -359,6 +362,11 @@ static void bdi_wb_shutdown(struct backing_dev_info *bdi)
 	 */
 	bdi_remove_from_list(bdi);
 
+	/* Make sure nobody queues further work */
+	spin_lock_bh(&bdi->wb_lock);
+	clear_bit(BDI_registered, &bdi->state);
+	spin_unlock_bh(&bdi->wb_lock);
+
 	/*
 	 * Drain work list and shutdown the delayed_work.  At this point,
 	 * @bdi->bdi_list is empty telling bdi_Writeback_workfn() that @bdi
diff --git a/mm/filemap.c b/mm/filemap.c
index cb91cb7..88ef144 100644
--- a/mm/filemap.c
+++ b/mm/filemap.c
@@ -469,7 +469,7 @@ int add_to_page_cache_locked(struct page *page, struct address_space *mapping,
 	if (error)
 		goto out;
 
-	error = radix_tree_preload(gfp_mask & ~__GFP_HIGHMEM);
+	error = radix_tree_maybe_preload(gfp_mask & ~__GFP_HIGHMEM);
 	if (error == 0) {
 		page_cache_get(page);
 		page->mapping = mapping;
diff --git a/mm/fremap.c b/mm/fremap.c
index 87da359..f7e0309 100644
--- a/mm/fremap.c
+++ b/mm/fremap.c
@@ -220,6 +220,11 @@ get_write_lock:
 		vma->vm_flags |= VM_NONLINEAR;
 		vma_interval_tree_remove(vma, &mapping->i_mmap);
 		vma_nonlinear_insert(vma, &mapping->i_mmap_nonlinear);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+		if (vma->vm_ops && vma->vm_ops->update_mapping) {
+			vma->vm_ops->update_mapping(vma);
+		}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 		flush_dcache_mmap_unlock(mapping);
 		mutex_unlock(&mapping->i_mmap_mutex);
 	}
diff --git a/mm/memory.c b/mm/memory.c
index 3e67df3..b256bdb 100644
--- a/mm/memory.c
+++ b/mm/memory.c
@@ -1462,6 +1462,16 @@ int zap_vma_ptes(struct vm_area_struct *vma, unsigned long address,
 }
 EXPORT_SYMBOL_GPL(zap_vma_ptes);
 
+/*
+ * FOLL_FORCE can write to even unwritable pte's, but only
+ * after we've gone through a COW cycle and they are dirty.
+ */
+static inline bool can_follow_write_pte(pte_t pte, unsigned int flags)
+{
+	return pte_write(pte) ||
+		((flags & FOLL_FORCE) && (flags & FOLL_COW) && pte_dirty(pte));
+}
+
 /**
  * follow_page_mask - look up a page descriptor from a user-virtual address
  * @vma: vm_area_struct mapping @address
@@ -1569,7 +1579,7 @@ split_fallthrough:
 	}
 	if ((flags & FOLL_NUMA) && pte_numa(pte))
 		goto no_page;
-	if ((flags & FOLL_WRITE) && !pte_write(pte))
+	if ((flags & FOLL_WRITE) && !can_follow_write_pte(pte, flags))
 		goto unlock;
 
 	page = vm_normal_page(vma, address, pte);
@@ -1876,7 +1886,7 @@ long __get_user_pages(struct task_struct *tsk, struct mm_struct *mm,
 				 */
 				if ((ret & VM_FAULT_WRITE) &&
 				    !(vma->vm_flags & VM_WRITE))
-					foll_flags &= ~FOLL_WRITE;
+					foll_flags |= FOLL_COW;
 
 				cond_resched();
 			}
diff --git a/mm/mmap.c b/mm/mmap.c
index 0ff3642..2cd1ce7 100644
--- a/mm/mmap.c
+++ b/mm/mmap.c
@@ -220,6 +220,11 @@ static void __remove_shared_vm_struct(struct vm_area_struct *vma,
 		list_del_init(&vma->shared.nonlinear);
 	else
 		vma_interval_tree_remove(vma, &mapping->i_mmap);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+	if (vma->vm_ops && vma->vm_ops->update_mapping) {
+		vma->vm_ops->update_mapping(vma);
+	}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 	flush_dcache_mmap_unlock(mapping);
 }
 
@@ -621,6 +626,11 @@ static void __vma_link_file(struct vm_area_struct *vma)
 			vma_nonlinear_insert(vma, &mapping->i_mmap_nonlinear);
 		else
 			vma_interval_tree_insert(vma, &mapping->i_mmap);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+		if (vma->vm_ops && vma->vm_ops->update_mapping) {
+			vma->vm_ops->update_mapping(vma);
+		}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 		flush_dcache_mmap_unlock(mapping);
 	}
 }
@@ -812,6 +822,11 @@ again:			remove_next = 1 + (end > next->vm_end);
 		if (adjust_next)
 			vma_interval_tree_insert(next, root);
 		vma_interval_tree_insert(vma, root);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+		if (vma->vm_ops && vma->vm_ops->update_mapping) {
+			vma->vm_ops->update_mapping(vma);
+		}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 		flush_dcache_mmap_unlock(mapping);
 	}
 
diff --git a/mm/nommu.c b/mm/nommu.c
index 298884d..98edeba 100644
--- a/mm/nommu.c
+++ b/mm/nommu.c
@@ -717,6 +717,11 @@ static void add_vma_to_mm(struct mm_struct *mm, struct vm_area_struct *vma)
 		mutex_lock(&mapping->i_mmap_mutex);
 		flush_dcache_mmap_lock(mapping);
 		vma_interval_tree_insert(vma, &mapping->i_mmap);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+		if (vma->vm_ops && vma->vm_ops->update_mapping) {
+			vma->vm_ops->update_mapping(vma);
+		}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 		flush_dcache_mmap_unlock(mapping);
 		mutex_unlock(&mapping->i_mmap_mutex);
 	}
@@ -783,6 +788,11 @@ static void delete_vma_from_mm(struct vm_area_struct *vma)
 		mutex_lock(&mapping->i_mmap_mutex);
 		flush_dcache_mmap_lock(mapping);
 		vma_interval_tree_remove(vma, &mapping->i_mmap);
+#ifdef CONFIG_BUFFALO_UNIONFS_FIX
+		if (vma->vm_ops && vma->vm_ops->update_mapping) {
+			vma->vm_ops->update_mapping(vma);
+		}
+#endif /*CONFIG_BUFFALO_UNIONFS_FIX*/
 		flush_dcache_mmap_unlock(mapping);
 		mutex_unlock(&mapping->i_mmap_mutex);
 	}
diff --git a/mm/shmem.c b/mm/shmem.c
index 509b393..fd3067a 100644
--- a/mm/shmem.c
+++ b/mm/shmem.c
@@ -1205,7 +1205,7 @@ repeat:
 						gfp & GFP_RECLAIM_MASK);
 		if (error)
 			goto decused;
-		error = radix_tree_preload(gfp & GFP_RECLAIM_MASK);
+		error = radix_tree_maybe_preload(gfp & GFP_RECLAIM_MASK);
 		if (!error) {
 			error = shmem_add_to_page_cache(page, mapping, index,
 							gfp, NULL);
diff --git a/mm/swap_state.c b/mm/swap_state.c
index f24ab0d..e6f15f8 100644
--- a/mm/swap_state.c
+++ b/mm/swap_state.c
@@ -122,7 +122,7 @@ int add_to_swap_cache(struct page *page, swp_entry_t entry, gfp_t gfp_mask)
 {
 	int error;
 
-	error = radix_tree_preload(gfp_mask);
+	error = radix_tree_maybe_preload(gfp_mask);
 	if (!error) {
 		error = __add_to_swap_cache(page, entry);
 		radix_tree_preload_end();
@@ -328,7 +328,7 @@ struct page *read_swap_cache_async(swp_entry_t entry, gfp_t gfp_mask,
 		/*
 		 * call radix_tree_preload() while we can wait.
 		 */
-		err = radix_tree_preload(gfp_mask & GFP_KERNEL);
+		err = radix_tree_maybe_preload(gfp_mask & GFP_KERNEL);
 		if (err)
 			break;
 
diff --git a/scripts/kconfig/Makefile b/scripts/kconfig/Makefile
index 844bc9d..1843a7c 100644
--- a/scripts/kconfig/Makefile
+++ b/scripts/kconfig/Makefile
@@ -102,7 +102,11 @@ else
 endif
 
 %_defconfig: $(obj)/conf
-	$(Q)$< --defconfig=arch/$(SRCARCH)/configs/$@ $(Kconfig)
+	$(Q)if [ -f $(srctree)/buffalo/arch/$(SRCARCH)/configs/$@ ]; then \
+		$< --defconfig=buffalo/arch/$(SRCARCH)/configs/$@ $(Kconfig) ; \
+	else \
+		$< --defconfig=arch/$(SRCARCH)/configs/$@ $(Kconfig) ; \
+	fi ;
 
 # Help text used by make help
 help:
diff --git a/security/security.c b/security/security.c
index a3dce87..1664f1f 100644
--- a/security/security.c
+++ b/security/security.c
@@ -542,6 +542,7 @@ int security_inode_permission(struct inode *inode, int mask)
 		return 0;
 	return security_ops->inode_permission(inode, mask);
 }
+EXPORT_SYMBOL(security_inode_permission);
 
 int security_inode_setattr(struct dentry *dentry, struct iattr *attr)
 {
